%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v23.07     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                         23 - July - 2023                         %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%CASE2869PEGASE  Power flow data for large part of European system.
%   Please see CASEFORMAT for details on the case file format.
%
%   This case accurately represents the size and complexity of part of the
%   European high voltage transmission network. The network contains 2,869
%   buses, 510 generators, and 4,582 branches and it operates at 380, 220,
%   150, and 110 kV. Please note that the data are fictitious and do not
%   correspond to real world data. They can thus be used to validate
%   methods and tools but should not be used for operation and planning of
%   the European grid.
%
%   The data stems from the Pan European Grid Advanced Simulation and State
%   Estimation (PEGASE) project, part of the 7th Framework Program of the
%   European Union (http://www.fp7-pegase.com/). When publishing results
%   based on this data, please cite:
%
%     S. Fliscounakis, P. Panciatici, F. Capitanescu, and L. Wehenkel,
%     "Contingency ranking with respect to overloads in very large power
%     systems taking into account uncertainty, preventive and corrective
%     actions", Power Systems, IEEE Trans. on, (28)4:4909-4917, 2013.
%     http://dx.doi.org/10.1109/TPWRS.2013.2251015
%
%   Remarks:
%
%   1. Line flow limits are the current flow limits found in PEGASE data.
%
%   2. PEGASE data contains asymmetric shunt conductance and susceptance in
%   the PI transmission line model of branches. Thus total line charging
%   susceptance of branches is set to 0 p.u. and the nodal representation
%   of shunt condutance and susceptance is used. As a result, power flow
%   equations are left unchanged compared with original PEGASE data.
%   However, line flow constraints in the optimal flow problem are
%   modified.
%
%   3. Identical linear costs are used for all generators to form a loss
%   minimizing OPF objective function.
%
%   4. Since some parts of the network are aggregated, some generators
%   (e.g. with negative PMIN) represent aggregations of multiple loads
%   and generators.
%
%   Cédric Josz, Stéphane Fliscounakis, Jean Maeght, Patrick Panciatici
%   firstname.lastname@rte-france.com
%   Réseau de Transport d'Electricité (French Transmission System Operator)
%   Département Expertise Système, Immeuble "Le Colbert"
%   9 rue de la Porte de Buc, 78000 Versailles Cedex, France
%   March 18th, 2015
%
%   Copyright (c) 2015 by Cédric Josz, Stéphane Fliscounakis, Jean Maeght,
%   and Patrick Panciatici
%   Licensed under the Creative Commons Attribution 4.0 International license,
%   http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case2869_pegase
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	3	 1	 151.0	 48.8	 0.0	 4.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4	 1	 171.41	 23.4	 0.0	 2.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10	 1	 134.0	 24.7	 0.0	 12.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	15	 1	 59.67	 26.7	 0.0	 12.84	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	21	 1	 161.2	 39.3	 0.0	 30.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	22	 1	 0.0	 -0.0	 0.0	 0.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	26	 1	 167.3	 54.8	 0.0	 110.54	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	29	 1	 152.9	 49.4	 0.0	 27.65	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	32	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	33	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	38	 1	 42.75	 12.8	 0.0	 13.3	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	39	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	42	 1	 20.82	 7.9	 0.0	 26.89	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	44	 1	 -0.0	 0.0	 0.0	 7.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	51	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	52	 1	 127.6	 31.8	 0.0	 20.51	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	53	 1	 48.65	 16.1	 0.0	 7.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	58	 1	 0.0	 0.0	 0.0	 2.31	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	59	 1	 119.2	 20.7	 0.0	 3.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	69	 1	 62.87	 20.5	 0.0	 1.15	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	71	 1	 126.3	 42.4	 0.0	 55.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	72	 1	 6.91	 -4.6	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	75	 1	 38.74	 6.1	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	76	 1	 22.13	 10.7	 0.0	 14.21	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	77	 1	 -0.0	 -0.0	 0.0	 0.73	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	89	 1	 0.0	 0.0	 0.199111	 4.530599	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	90	 1	 363.25	 115.39	 0.0	 3.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	91	 1	 -0.0	 0.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	96	 1	 -8.4	 28.66	 0.0	 3.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	113	 1	 -0.0	 -0.0	 0.0	 6.532711	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	115	 1	 0.0	 -0.0	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	118	 1	 704.53	 -35.33	 0.0	 13.102834	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	124	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	128	 1	 23.73	 12.7	 0.0	 0.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	130	 1	 -0.0	 0.0	 0.135375	 47.750675	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	132	 1	 0.0	 -0.0	 0.0	 21.39	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	133	 1	 38.14	 12.5	 0.0	 6.28	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	138	 1	 -75.38	 7.8	 0.0	 29.9	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	139	 1	 -764.34	 66.91	 0.0	 33.47	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	140	 1	 0.0	 0.0	 0.0	 4.14	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	143	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	145	 1	 38.34	 5.6	 0.0	 7.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	148	 1	 32.34	 12.0	 0.0	 6.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	150	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	163	 1	 147.76	 32.73	 0.0	 8.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	164	 1	 0.0	 -0.0	 0.0	 5.17	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	171	 1	 100.8	 13.2	 0.0	 5.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	172	 1	 111.7	 10.96	 0.0	 4.22	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	174	 1	 370.5	 -17.0	 0.0	 9.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	177	 1	 94.9	 36.2	 0.0	 16.46	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	179	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	184	 1	 -0.0	 -0.0	 0.0	 2.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	188	 1	 36.84	 13.9	 0.0	 3.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	194	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	195	 1	 73.14	 21.55	 0.0	 8.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	196	 1	 0.0	 -0.0	 0.0	 12.48	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	198	 1	 39.74	 11.8	 0.0	 1.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	199	 1	 86.8	 28.4	 0.0	 1.34	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	201	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	205	 1	 46.15	 18.2	 0.0	 1.29	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	207	 1	 321.98	 84.4	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	211	 1	 75.28	 19.2	 0.0	 1.9	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	216	 1	 155.6	 54.7	 0.0	 2.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	217	 1	 105.2	 0.1	 0.0	 7.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	218	 1	 69.83	 15.12	 0.0	 2.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	221	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	225	 1	 0.0	 0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	228	 1	 -23.43	 57.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	230	 1	 152.07	 22.52	 0.0	 7.87	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	231	 1	 -0.13	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	236	 1	 45.85	 7.0	 0.0	 1.05	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	243	 1	 0.0	 -0.01	 0.0	 13.49	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	244	 1	 -0.0	 -0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	249	 1	 -0.0	 -0.0	 0.0	 26.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	257	 1	 113.9	 24.5	 0.0	 6.72	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	261	 1	 -0.0	 0.0	 0.0	 1.29	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	264	 1	 38.74	 9.0	 0.0	 0.57	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	266	 1	 0.0	 -0.0	 0.0	 140.96	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	267	 1	 103.8	 2.7	 0.0	 3.33	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	268	 1	 -0.13	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	271	 1	 96.7	 26.8	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	275	 1	 102.1	 25.3	 0.0	 1.11	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	280	 1	 119.6	 29.6	 0.0	 5.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	281	 1	 -0.0	 -0.0	 0.0	 18.07	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	283	 1	 27.33	 11.9	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	284	 1	 191.2	 -3.4	 0.0	 19.21	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	292	 1	 13.82	 1.4	 0.0	 0.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	297	 1	 23.73	 9.4	 0.0	 1.45	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	299	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	304	 1	 2.2	 0.5	 0.0	 0.21	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	305	 1	 103.0	 12.0	 0.0	 0.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	306	 1	 -0.0	 0.0	 0.0	 4.76	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	311	 1	 42.05	 17.2	 0.0	 1.31	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	312	 1	 -0.16	 -2.91	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	314	 1	 163.1	 46.3	 0.0	 10.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	315	 1	 -0.0	 -0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	317	 1	 -0.0	 -0.0	 0.045946	 -1.82203	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	322	 1	 303.8	 85.4	 0.0	 3.63	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	326	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	333	 1	 524.5	 43.0	 0.0	 6.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	338	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	344	 1	 372.8	 147.5	 0.0	 27.73	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	346	 1	 197.5	 48.3	 0.0	 0.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	349	 1	 -0.0	 0.0	 0.0	 15.15	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	350	 1	 110.4	 26.2	 0.0	 5.62	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	351	 1	 -0.15	 -1.93	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	352	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	360	 1	 35.54	 11.5	 0.0	 3.65	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	367	 1	 65.17	 -51.5	 0.0	 4.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	369	 1	 -0.0	 0.0	 0.0	 3.78	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	370	 1	 56.76	 23.2	 0.0	 0.49	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	377	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	380	 1	 -95.71	 -2.8	 0.0	 7.25	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	385	 1	 -0.0	 -0.0	 0.0	 105.84	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	387	 1	 -0.19	 -4.38	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	389	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	392	 1	 134.1	 34.2	 0.0	 0.75	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	395	 1	 -0.0	 -0.0	 0.0	 7.85	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	401	 1	 56.5	 36.29	 0.0	 3.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	408	 1	 129.1	 7.4	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	410	 1	 170.89	 50.38	 0.0	 6.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	413	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	415	 1	 4.71	 0.7	 0.0	 11.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	416	 1	 70.68	 13.5	 0.0	 6.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	420	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	425	 1	 -0.0	 0.0	 0.0	 2.72	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	426	 1	 123.1	 6.5	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	427	 1	 -0.0	 0.0	 0.0	 1.24	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	429	 1	 26.93	 -22.4	 0.0	 4.95	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	432	 1	 -0.0	 -0.0	 0.0	 68.517663	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	440	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	441	 1	 -0.0	 0.0	 0.199768	 27.888516	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	442	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	444	 1	 0.0	 -0.0	 0.0	 2.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	445	 1	 36.74	 10.3	 0.0	 8.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	449	 1	 0.0	 0.0	 0.0	 29.42	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	453	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	455	 1	 274.32	 5.66	 0.0	 13.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	472	 1	 336.2	 131.6	 0.0	 64.01	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	473	 1	 -22.95	 -3.72	 0.0	 14.34	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	477	 1	 0.0	 0.0	 0.0	 70.37	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	481	 1	 -0.0	 0.0	 0.0	 17.44	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	483	 1	 57.26	 15.6	 0.0	 3.43	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	486	 1	 7.01	 2.0	 0.0	 0.44	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	489	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	490	 1	 20.52	 4.0	 0.0	 2.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	496	 1	 -0.0	 -0.0	 0.0	 10.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	500	 1	 144.4	 35.5	 0.0	 7.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	502	 1	 -0.0	 0.0	 0.0	 1.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	506	 1	 -0.0	 0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	509	 1	 77.29	 7.0	 0.0	 17.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	513	 1	 57.46	 17.1	 0.0	 1.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	516	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	519	 1	 207.2	 9.4	 0.0	 8.77	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	520	 1	 118.5	 20.4	 0.0	 2.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	523	 1	 189.9	 74.7	 0.0	 26.2	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	527	 1	 277.7	 45.4	 0.0	 0.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	536	 1	 87.8	 -1.4	 0.079073	 36.047349	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	539	 1	 57.96	 18.9	 0.0	 14.91	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	544	 1	 79.69	 39.6	 0.0	 18.83	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	548	 1	 30.93	 8.9	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	549	 1	 0.0	 -0.0	 0.0	 5.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	550	 1	 0.0	 -0.0	 0.0	 10.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	552	 1	 180.8	 90.8	 0.0	 2.42	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	554	 1	 0.0	 -0.0	 0.0	 1.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	556	 1	 16.52	 9.0	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	558	 1	 -0.18	 -3.57	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	559	 1	 42.25	 16.6	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	561	 1	 0.0	 -0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	564	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	575	 1	 0.0	 -0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	577	 1	 -0.13	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	579	 1	 17.32	 6.6	 0.0	 16.52	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	583	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	585	 1	 21.12	 8.3	 0.0	 4.26	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	593	 1	 -0.0	 0.0	 0.0	 29.2	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	594	 1	 67.57	 17.0	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	595	 1	 47.55	 5.3	 0.0	 7.59	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	597	 1	 33.34	 15.7	 0.0	 64.15	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	601	 1	 140.6	 42.6	 0.0	 5.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	602	 1	 110.8	 -8.8	 0.0	 3.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	604	 1	 33.24	 4.4	 0.0	 24.54	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	608	 1	 150.9	 10.4	 0.0	 4.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	609	 1	 -0.0	 -0.0	 0.0	 5.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	610	 1	 -0.0	 0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	615	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	616	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	618	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	619	 1	 72.88	 14.4	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	621	 1	 21.42	 8.1	 0.0	 7.38	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	628	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	639	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	641	 1	 45.32	 18.5	 0.0	 0.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	642	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	643	 1	 15.52	 6.3	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	649	 1	 40.94	 19.2	 0.0	 5.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	650	 1	 17.22	 4.4	 0.0	 1.71	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	656	 1	 -0.15	 -1.93	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	658	 1	 258.4	 66.7	 0.0	 5.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	659	 1	 -0.0	 -0.0	 0.174507	 73.977052	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	661	 1	 -0.0	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	662	 1	 0.0	 -0.0	 0.0	 4.14	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	666	 1	 -5.61	 -2.79	 0.0	 150.93	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	676	 1	 109.3	 35.4	 0.0	 1.91	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	678	 1	 232.1	 89.8	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	682	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	686	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	687	 1	 -0.0	 0.0	 0.0	 5.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	693	 1	 -0.0	 0.0	 0.0	 93.75	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	695	 1	 96.41	 26.5	 0.0	 0.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	698	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	699	 1	 36.54	 8.4	 0.0	 6.58	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	702	 1	 -0.0	 -0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	706	 1	 114.8	 22.8	 0.0	 5.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	707	 1	 83.99	 21.2	 0.0	 5.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	709	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	710	 1	 76.38	 5.1	 0.0	 3.97	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	712	 1	 110.4	 41.9	 0.0	 1.88	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	718	 1	 135.11	 41.0	 0.0	 5.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	720	 1	 -0.0	 -0.0	 0.0	 23.554121	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	722	 1	 0.0	 -0.0	 0.0	 0.78	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	726	 1	 400.3	 189.9	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	731	 1	 0.0	 0.0	 0.0	 61.48	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	733	 1	 58.36	 10.7	 0.0	 8.41	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	739	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	742	 1	 0.0	 -0.0	 0.0	 2.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	747	 1	 69.58	 16.0	 0.0	 3.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	749	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	750	 1	 -0.0	 -0.0	 0.0	 18.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	751	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	754	 1	 132.1	 32.4	 0.0	 58.29	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	757	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	766	 1	 -0.0	 0.0	 0.0	 7.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	769	 1	 152.57	 40.0	 0.0	 6.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	772	 1	 343.9	 141.9	 0.0	 5.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	775	 1	 -55.14	 -27.14	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	776	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	778	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	780	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	784	 1	 -26.0	 -14.72	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	785	 1	 -0.0	 -0.0	 0.0	 4.03	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	789	 1	 -0.0	 -0.0	 0.0	 6.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	790	 1	 -0.15	 -1.0	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	792	 1	 295.3	 41.9	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	795	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	797	 1	 2.0	 114.6	 0.0	 16.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	800	 1	 50.56	 18.0	 0.0	 0.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	803	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	804	 1	 -0.0	 -0.0	 0.0	 7.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	805	 1	 124.5	 29.6	 0.0	 15.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	806	 1	 -0.0	 -0.0	 0.0	 32.02	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	807	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	808	 1	 24.53	 8.6	 0.0	 7.01	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	809	 1	 0.0	 -0.0	 0.0	 58.088687	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	814	 1	 287.7	 16.3	 0.0	 12.86	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	819	 1	 0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	823	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	838	 1	 615.81	 286.69	 0.0	 101.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	839	 1	 -0.0	 -0.0	 0.0	 8.17514	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	849	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	851	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	854	 1	 49.96	 7.5	 0.0	 8.86	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	858	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	869	 1	 94.2	 5.5	 0.0	 6.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	870	 1	 110.0	 3.4	 0.0	 11.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	871	 1	 108.89	 -21.76	 0.0	 3.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	878	 1	 0.0	 -0.0	 0.0	 25.28	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	883	 1	 192.5	 78.3	 0.0	 6.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	891	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	892	 1	 -0.0	 -0.0	 0.0	 9.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	898	 1	 25.63	 7.9	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	900	 1	 0.0	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	903	 1	 82.69	 20.1	 0.0	 1.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	905	 1	 631.71	 -54.16	 0.0	 7.534129	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	907	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	908	 1	 125.9	 -0.5	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	913	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	916	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	919	 1	 -0.0	 0.0	 0.0	 13.89	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	920	 1	 34.44	 8.5	 0.0	 1.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	923	 1	 62.07	 14.7	 0.0	 4.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	928	 1	 112.9	 19.3	 0.0	 17.34	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	929	 1	 43.75	 12.4	 0.0	 9.35	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	930	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	932	 1	 77.59	 12.3	 0.0	 5.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	933	 1	 -0.0	 0.0	 0.0	 22.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	935	 1	 -0.0	 0.0	 0.0	 9.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	947	 1	 90.7	 5.8	 0.0	 4.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	948	 1	 15.82	 4.0	 0.0	 0.7	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	950	 1	 69.08	 22.6	 0.0	 0.54	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	953	 1	 108.7	 -12.15	 0.0	 37.11	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	954	 1	 66.27	 13.6	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	955	 1	 244.2	 152.7	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	957	 1	 65.77	 16.1	 0.0	 1.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	960	 1	 -0.0	 -0.0	 0.0	 108.728602	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	962	 1	 42.55	 17.1	 0.0	 1.67	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	964	 1	 88.5	 16.5	 0.0	 146.44	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	970	 1	 62.27	 -2.1	 0.0	 8.01	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	972	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	976	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	980	 1	 14.71	 4.6	 0.0	 7.88	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	981	 1	 0.0	 -0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	986	 1	 15.98	 0.86	 0.0	 5.96	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	987	 1	 -0.0	 0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	988	 1	 -0.0	 -0.0	 0.0	 8.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	994	 1	 -0.0	 -0.0	 0.0	 25.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	999	 1	 20.02	 6.8	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1000	 1	 0.0	 -0.0	 0.0	 1.8	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1001	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1002	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1005	 1	 0.0	 0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1010	 1	 21.32	 7.3	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1011	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1013	 1	 136.06	 40.4	 0.0	 12.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1015	 1	 44.55	 0.0	 0.0	 4.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1020	 1	 8.21	 3.31	 0.0	 8.38	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1021	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1023	 1	 -0.0	 0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1025	 1	 241.4	 -2.5	 0.224624	 31.280331	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1026	 1	 201.4	 53.0	 0.0	 9.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1027	 1	 -5.91	 -2.33	 0.0	 30.393595	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1030	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1033	 1	 26.33	 5.3	 0.0	 4.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1035	 1	 382.5	 57.9	 0.0	 8.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1036	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1037	 1	 -0.0	 0.0	 0.0	 0.55	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1039	 1	 34.64	 -0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1040	 1	 31.94	 8.8	 0.0	 3.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1043	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1046	 1	 47.05	 19.3	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1051	 1	 -0.0	 0.0	 0.0	 3.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1052	 1	 67.48	 32.6	 0.0	 13.11	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	1057	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	1060	 1	 -0.0	 0.0	 0.0	 75.38	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1064	 1	 215.2	 -7.6	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1065	 1	 89.6	 20.0	 0.0	 9.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1074	 1	 403.9	 -0.1	 0.0	 143.1	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1077	 1	 -0.0	 0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1078	 1	 -0.0	 -0.0	 0.0	 4.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1081	 1	 277.86	 58.95	 0.0	 182.880644	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1083	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1086	 1	 12.01	 5.6	 0.0	 39.29	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1090	 1	 56.06	 18.7	 0.0	 4.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1093	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1094	 1	 28.53	 11.3	 0.0	 3.25	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1096	 1	 0.0	 -0.0	 0.0	 0.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1100	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1101	 1	 -0.0	 -0.0	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1102	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1105	 1	 29.83	 7.3	 0.0	 6.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1106	 1	 192.4	 63.9	 0.0	 10.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1109	 1	 -54.06	 13.1	 0.0	 14.23	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1111	 1	 0.0	 0.0	 0.0	 1.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1114	 1	 59.27	 5.1	 0.0	 26.03	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1115	 1	 -40.54	 9.3	 0.0	 3.05	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1121	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1123	 1	 -9.0	 -10.19	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1124	 1	 -0.0	 -0.0	 0.0	 8.61	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	1129	 1	 190.47	 55.03	 0.0	 6.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1133	 1	 115.2	 319.2	 0.0	 290.91	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1136	 1	 16.22	 2.0	 0.0	 0.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1137	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1146	 1	 32.84	 -0.0	 0.0	 1.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1151	 1	 -0.0	 -0.0	 0.0	 18.82	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1153	 1	 12.41	 3.9	 0.0	 2.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1155	 1	 -0.0	 0.0	 0.0	 1.91	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1156	 1	 65.67	 24.0	 0.0	 9.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1159	 1	 112.4	 13.0	 0.0	 3.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1163	 1	 -0.0	 -0.0	 0.0	 16.04	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1168	 1	 0.0	 -0.0	 0.0	 89.06	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1172	 1	 -0.0	 -0.0	 0.0	 2.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1173	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1174	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	1175	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1179	 1	 86.6	 23.4	 0.0	 0.39	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1183	 1	 199.4	 -19.9	 0.0	 6.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1185	 1	 150.4	 15.3	 0.0	 8.09	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1187	 1	 67.57	 21.2	 0.0	 5.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1188	 1	 30.93	 6.6	 0.0	 9.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1194	 1	 129.6	 13.3	 0.0	 13.98	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1198	 1	 0.0	 0.0	 0.0	 30.637696	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1200	 1	 124.8	 7.9	 0.0	 48.99	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1201	 1	 114.1	 23.5	 0.0	 1.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1205	 1	 -0.19	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1207	 1	 70.18	 28.7	 0.0	 0.8	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1216	 1	 0.0	 0.0	 0.0	 4.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1221	 1	 230.5	 91.0	 0.0	 57.67	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1227	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1232	 1	 0.0	 -0.0	 0.0	 81.52	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1233	 1	 0.0	 -0.0	 0.0	 1.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1234	 1	 71.78	 17.9	 0.0	 1.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1237	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	1239	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1240	 1	 23.53	 4.0	 0.0	 9.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1241	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1248	 1	 0.0	 0.0	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1249	 1	 348.93	 26.47	 0.0	 9.36	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1250	 1	 39.44	 24.9	 0.0	 4.18	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	1251	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1255	 1	 20.62	 8.2	 0.0	 6.62	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1260	 1	 50.86	 36.6	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1262	 1	 -0.0	 0.0	 0.0	 10.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1265	 1	 173.0	 -21.3	 0.0	 5.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1271	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1275	 1	 52.46	 2.9	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1277	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1280	 1	 0.0	 -0.0	 0.0	 107.39	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1282	 1	 202.0	 34.1	 0.0	 1.94	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1294	 1	 6.11	 -0.0	 0.0	 2.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1295	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1301	 1	 479.0	 99.2	 0.0	 10.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1305	 1	 -0.0	 -0.0	 0.0	 4.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1311	 1	 37.94	 15.2	 0.0	 35.31	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1317	 1	 149.3	 -2.0	 0.0	 20.77	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1326	 1	 0.0	 0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1330	 1	 100.6	 15.3	 0.0	 1.28	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1331	 1	 -0.17	 -1.82	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1334	 1	 0.0	 0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1338	 1	 29.03	 9.4	 0.0	 5.11	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1339	 1	 108.4	 -2.4	 0.0	 80.12	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1341	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1343	 1	 -0.0	 -0.0	 0.0	 58.3	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1344	 1	 -0.0	 0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1347	 1	 0.0	 -0.0	 0.0	 12.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1350	 1	 30.53	 13.8	 0.0	 2.19	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1352	 1	 28.93	 11.9	 0.0	 3.84	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1354	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1355	 1	 -3.29	 -1.32	 0.0	 190.704588	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1362	 1	 -0.0	 -0.0	 0.0	 6.93	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	1364	 1	 40.85	 14.5	 0.0	 0.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1367	 1	 0.0	 -0.0	 0.175687	 -1.509401	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1380	 1	 145.2	 21.4	 0.0	 1.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1391	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1392	 1	 -0.0	 -0.0	 0.0	 4.2	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	1393	 1	 2.4	 0.7	 0.0	 10.69	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1394	 1	 30.93	 7.6	 0.0	 4.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1397	 1	 0.0	 -0.0	 0.0	 2.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1398	 1	 196.7	 44.2	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1399	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1401	 1	 11.91	 2.9	 0.0	 5.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1407	 1	 0.0	 -0.0	 0.0	 4.15	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	1409	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1411	 1	 0.0	 -0.0	 0.0	 7.52	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1414	 1	 144.7	 20.3	 0.0	 6.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1415	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1418	 1	 40.55	 3.6	 0.0	 1.88	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1421	 1	 42.95	 19.8	 0.0	 3.85	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1422	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1430	 1	 20.82	 7.9	 0.0	 5.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1435	 1	 -0.0	 0.0	 0.0	 3.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1436	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1437	 1	 204.6	 53.2	 0.0	 7.4	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1439	 1	 110.1	 2.0	 0.0	 13.85	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1445	 1	 238.4	 210.9	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	1448	 1	 0.0	 0.0	 0.0	 9.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1457	 1	 20.82	 36.0	 0.0	 0.97	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1458	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1459	 1	 -0.0	 -0.0	 0.0	 3.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1461	 1	 0.0	 0.0	 0.0	 1.44	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1462	 1	 -0.0	 0.0	 0.0	 0.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1463	 1	 109.6	 36.4	 0.0	 13.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1464	 1	 22.73	 6.4	 0.0	 2.1	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1465	 1	 -11.03	 -5.11	 0.0	 29.706803	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1471	 1	 95.61	 8.6	 0.0	 3.48	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1475	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1477	 1	 0.0	 -0.0	 0.0	 5.51	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1478	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1479	 1	 82.19	 23.4	 0.0	 17.91	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1483	 1	 0.0	 0.0	 0.0	 4.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1486	 1	 79.59	 18.8	 0.0	 6.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1489	 1	 0.0	 -0.0	 0.0	 2.54	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1491	 1	 117.5	 -3.0	 0.0	 5.38	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1494	 1	 -1.85	 -1.63	 0.0	 31.424588	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1498	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1501	 1	 -0.0	 -0.0	 0.0	 12.57	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1502	 1	 -0.0	 0.0	 0.0	 37.116157	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1503	 1	 142.8	 -6.4	 0.0	 12.36	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1504	 1	 0.0	 -0.0	 0.0	 1.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1513	 1	 -35.74	 38.6	 0.0	 4.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1516	 1	 22.02	 9.0	 0.0	 0.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1520	 1	 173.6	 72.9	 0.0	 2.5	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1526	 1	 -10.86	 -5.93	 0.0	 12.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1531	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	1538	 1	 36.34	 15.2	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1539	 1	 73.58	 3.24	 0.0	 52.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1541	 1	 125.4	 45.8	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1543	 1	 116.7	 64.0	 0.0	 10.41	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1545	 1	 42.55	 8.2	 0.0	 2.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1547	 1	 -0.0	 -0.0	 0.0	 1.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1549	 1	 300.2	 -3.1	 0.0	 29.94	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1551	 1	 -0.0	 -0.0	 0.0	 7.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1552	 1	 20.42	 8.1	 0.0	 35.15	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1554	 1	 0.0	 -0.0	 0.0	 4.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1556	 1	 -0.0	 -0.0	 0.0	 0.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1562	 1	 77.39	 24.1	 0.0	 2.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1564	 1	 140.4	 49.4	 0.0	 4.5	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1566	 1	 156.9	 -4.0	 0.0	 2.48	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1568	 1	 69.08	 21.5	 0.0	 1.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1570	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1578	 1	 0.0	 -0.0	 0.0	 1.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1579	 1	 -0.0	 0.0	 0.0	 16.56	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1584	 1	 0.0	 -0.0	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1591	 1	 -0.16	 -11.88	 0.0	 16.12	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1592	 1	 28.33	 44.8	 0.0	 0.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1595	 1	 71.77	 13.57	 0.0	 3.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1597	 1	 51.96	 13.4	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1599	 1	 0.0	 0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1600	 1	 38.74	 14.1	 0.0	 12.78	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1602	 1	 45.75	 4.2	 0.0	 4.9	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1604	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1605	 1	 -0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1607	 1	 73.78	 -0.0	 0.0	 2.69	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1609	 1	 0.0	 0.0	 0.0	 6.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1611	 1	 274.1	 166.5	 0.0	 0.56	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	1616	 1	 0.0	 0.0	 0.0	 14.45	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1618	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1625	 1	 73.18	 22.3	 0.0	 8.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1629	 1	 41.95	 8.5	 0.0	 1.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1632	 1	 20.82	 7.9	 0.0	 1.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1633	 1	 -0.0	 -0.0	 0.0	 45.02	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1635	 1	 -0.18	 -1.06	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1638	 1	 70.08	 11.1	 0.0	 9.84	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1639	 1	 51.66	 8.0	 0.0	 4.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1642	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1643	 1	 95.71	 25.9	 0.0	 11.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1644	 1	 449.56	 245.72	 0.0	 94.55	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1645	 1	 60.27	 9.4	 0.0	 0.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1662	 1	 3.67	 -1.86	 0.0	 3.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1666	 1	 34.04	 0.0	 0.0	 2.4	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1670	 1	 46.45	 19.1	 0.0	 6.66	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1672	 1	 -28.13	 -0.83	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1676	 1	 -0.0	 0.0	 0.171586	 -1.4632	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1680	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1685	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	1689	 1	 -0.0	 -0.0	 0.0	 58.96	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1692	 1	 83.19	 25.8	 0.0	 0.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1697	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1702	 1	 47.45	 18.7	 0.0	 1.36	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1703	 1	 68.28	 39.0	 0.19855	 79.84755	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1704	 1	 62.16	 8.0	 0.0	 2.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1708	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1709	 1	 -15.38	 -4.94	 0.0	 33.241519	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1711	 1	 25.13	 -61.6	 0.0	 3.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1716	 1	 0.0	 -0.0	 0.0	 16.62	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1721	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1722	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1728	 1	 34.44	 14.4	 0.0	 48.56	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1730	 1	 -17.18	 -4.35	 0.0	 44.419365	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1734	 1	 -0.0	 0.0	 0.0	 3.65	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1741	 1	 162.5	 48.4	 0.0	 5.73	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1742	 1	 0.0	 0.0	 0.0	 6.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1746	 1	 -0.0	 0.0	 0.0	 1.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1747	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1750	 1	 58.46	 6.6	 0.0	 10.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1752	 1	 85.8	 13.4	 0.0	 3.23	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1754	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1758	 1	 0.0	 -0.0	 0.0	 121.29	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1763	 1	 -0.0	 -0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1767	 1	 333.5	 -1.4	 0.0	 8.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1768	 1	 73.98	 22.5	 0.0	 1.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1769	 1	 35.14	 1.8	 0.0	 6.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1770	 1	 -0.0	 -0.0	 0.0	 2.55	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1774	 1	 -32.04	 10.3	 0.0	 82.52	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1775	 1	 -0.0	 0.0	 0.0	 1.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1777	 1	 0.0	 -0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1778	 1	 -0.18	 -3.85	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1787	 1	 32.94	 10.1	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1788	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1793	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1794	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1798	 1	 -0.63	 -0.83	 0.0	 22.810288	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1802	 1	 8.51	 3.2	 0.0	 2.93	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1803	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1808	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1810	 1	 52.46	 11.3	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1813	 1	 88.92	 19.79	 0.0	 2.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1815	 1	 63.66	 9.7	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	1817	 1	 108.91	 33.7	 0.0	 56.24	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1833	 1	 0.0	 0.0	 0.0	 3.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1836	 1	 62.37	 25.5	 0.0	 3.98	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1838	 1	 0.0	 -0.0	 0.0	 3.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1841	 1	 56.26	 8.5	 0.0	 5.32	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1844	 1	 -28.14	 -0.76	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1848	 1	 22.02	 21.8	 0.0	 10.29	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1850	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1851	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1852	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1857	 1	 0.0	 0.0	 0.0	 1.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1860	 1	 88.8	 -3.2	 0.0	 13.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1862	 1	 177.4	 41.7	 0.0	 2.98	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	1866	 1	 209.2	 23.5	 0.0	 6.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1868	 1	 11.71	 3.8	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1869	 1	 -2.23	 -1.27	 0.0	 3.64	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1870	 1	 -0.0	 0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1872	 1	 94.3	 13.8	 0.0	 5.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1876	 1	 -0.0	 -0.0	 0.0	 6.273568	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1880	 1	 50.26	 16.4	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1883	 1	 27.33	 5.0	 0.0	 6.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1888	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1889	 1	 57.16	 0.0	 0.0	 6.58	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1890	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1894	 1	 22.22	 5.9	 0.0	 10.28	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1895	 1	 20.82	 -0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1896	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1897	 1	 53.96	 4.9	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1898	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1899	 1	 0.0	 -0.0	 0.202076	 48.319777	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1909	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1910	 1	 -0.0	 0.0	 0.0	 2.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1912	 1	 52.06	 14.3	 0.0	 1.59	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1913	 1	 91.1	 54.8	 0.0	 30.59	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1914	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1917	 1	 197.5	 -31.0	 0.0	 17.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1923	 1	 192.11	 45.5	 0.0	 68.04	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1936	 1	 0.0	 0.0	 0.0	 30.78	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1940	 1	 0.0	 0.0	 0.0	 1.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1942	 1	 44.75	 4.1	 0.0	 3.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1947	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1956	 1	 0.0	 0.0	 0.0	 51.66	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1957	 1	 76.28	 2.9	 0.0	 7.28	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1959	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1965	 1	 248.7	 8.1	 0.0	 12.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1968	 1	 118.4	 137.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	1969	 1	 0.0	 -0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1973	 1	 210.1	 66.2	 0.0	 59.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1974	 1	 241.9	 38.8	 0.0	 12.46	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1979	 1	 0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1980	 1	 177.3	 36.4	 0.0	 0.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1984	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1985	 1	 147.4	 -55.9	 0.0	 1.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1989	 1	 69.78	 20.3	 0.0	 10.26	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1998	 1	 25.73	 7.3	 0.0	 2.82	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1999	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	2002	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	2006	 1	 -40.44	 1.5	 0.0	 14.2	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2009	 1	 154.8	 -47.1	 0.0	 4.18	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2012	 1	 41.45	 4.9	 0.0	 18.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2019	 1	 72.08	 21.3	 0.0	 7.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2020	 1	 0.0	 0.0	 0.0	 9.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2021	 1	 3.9	 1.0	 0.0	 3.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2030	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2031	 1	 -0.0	 -0.0	 0.104186	 55.436651	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	2035	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2042	 1	 14.02	 6.5	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2043	 1	 3.2	 1.7	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2044	 1	 0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2050	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2055	 1	 52.66	 21.5	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2056	 1	 -0.0	 0.0	 0.0	 7.338808	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2057	 1	 120.2	 20.5	 0.0	 19.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2058	 1	 0.0	 0.0	 0.0	 1.31	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	2060	 1	 115.1	 23.5	 0.0	 3.78	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2072	 1	 101.2	 2.1	 0.0	 38.43	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2077	 1	 72.18	 44.9	 0.0	 6.34	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2078	 1	 77.19	 18.6	 0.0	 2.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2079	 1	 0.0	 -0.0	 0.0	 13.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2081	 1	 30.93	 2.8	 0.0	 2.11	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2083	 1	 121.4	 20.2	 0.0	 16.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2085	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2088	 1	 -0.0	 0.0	 0.0	 6.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2089	 1	 199.86	 56.93	 0.0	 46.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2091	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2093	 1	 -5.64	 -2.84	 0.0	 34.582195	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2096	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2101	 1	 -0.0	 -0.0	 0.0	 38.32	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2107	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2116	 1	 53.36	 7.1	 0.0	 6.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2117	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2120	 1	 -0.19	 -3.76	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2126	 1	 92.3	 14.6	 0.0	 1.14	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2128	 1	 79.09	 18.7	 0.0	 10.8	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2129	 1	 0.0	 0.0	 0.0	 56.686515	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2132	 1	 107.3	 14.2	 0.0	 20.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2140	 1	 0.0	 0.0	 0.0	 1.2	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2142	 1	 0.0	 -0.0	 0.0	 7.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2143	 1	 129.5	 38.3	 0.0	 5.42	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2147	 1	 6.11	 -0.0	 0.0	 0.92	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2150	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	2154	 1	 0.0	 0.0	 0.29	 13.47	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2155	 1	 63.67	 20.2	 0.0	 6.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2161	 1	 35.66	 -9.39	 0.0	 7.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2166	 1	 20.92	 7.7	 0.0	 1.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2168	 1	 8.6	 -1.48	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	2172	 1	 114.2	 34.4	 0.0	 10.29	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2174	 1	 0.0	 0.0	 0.0	 61.795782	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2177	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2180	 1	 0.0	 -0.0	 0.0	 2.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2183	 1	 0.0	 0.0	 0.0	 32.849821	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2188	 1	 25.23	 11.9	 0.0	 18.72	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2189	 1	 -0.0	 0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2193	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2197	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2202	 1	 213.0	 39.6	 0.0	 20.63	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2206	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2208	 1	 74.98	 26.9	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2225	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2228	 1	 143.1	 18.9	 0.0	 3.42	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2229	 1	 0.0	 -0.0	 0.0	 2.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2230	 1	 0.0	 -0.0	 0.0	 1.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2231	 1	 0.0	 0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2233	 1	 269.9	 12.4	 0.0	 4.09	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2235	 1	 193.1	 69.9	 0.0	 28.91	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2236	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2240	 1	 66.87	 21.8	 0.0	 12.3	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2242	 1	 -0.0	 -0.0	 0.0	 2.76	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2248	 1	 110.3	 28.7	 0.0	 0.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2252	 1	 100.7	 -4.2	 0.0	 1.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2261	 1	 0.0	 -0.0	 0.0	 20.5	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2267	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2268	 1	 0.0	 -0.0	 0.183167	 22.675025	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2271	 1	 0.0	 -0.01	 0.0	 5.48	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2273	 1	 141.3	 32.4	 0.0	 7.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2276	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2286	 1	 208.88	 60.8	 0.0	 6.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2288	 1	 170.9	 39.0	 0.0	 11.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2291	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2297	 1	 93.2	 13.6	 0.0	 14.9	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2299	 1	 402.1	 110.2	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	2301	 1	 82.39	 12.3	 0.0	 9.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2303	 1	 0.0	 -0.0	 0.0	 7.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2304	 1	 88.7	 -0.1	 0.0	 2.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2305	 1	 21.22	 8.3	 0.0	 19.1	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2308	 1	 32.04	 6.6	 0.0	 0.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2313	 1	 0.0	 -0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2319	 1	 39.64	 20.9	 0.0	 0.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2327	 1	 114.5	 25.2	 0.0	 17.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2328	 1	 -0.0	 0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2330	 1	 -0.2	 -1.33	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2331	 1	 -0.15	 -1.4	 0.0	 0.01	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2335	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2337	 1	 103.4	 27.0	 0.0	 1.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2340	 1	 96.91	 13.9	 0.0	 3.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2341	 1	 -0.0	 0.0	 0.0	 3.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2343	 1	 33.04	 5.6	 0.0	 14.55	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2350	 1	 -0.0	 0.0	 0.0	 7.03	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2355	 1	 54.46	 11.9	 0.0	 3.93	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2358	 1	 52.96	 8.2	 0.0	 5.68	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2359	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2360	 1	 215.5	 31.3	 0.0	 14.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2361	 1	 16.9	 3.85	 0.0	 25.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2365	 1	 37.94	 15.4	 0.0	 117.386167	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2372	 1	 0.0	 -0.0	 0.0	 14.490904	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2377	 1	 101.7	 17.6	 0.0	 13.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2381	 1	 32.94	 13.0	 0.0	 4.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2393	 1	 20.82	 0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2403	 1	 37.24	 5.3	 0.0	 14.78	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2406	 1	 0.0	 0.0	 0.0	 1.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2407	 1	 117.13	 52.4	 0.0	 7.51	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2410	 1	 3.9	 -35.8	 0.0	 4.71	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2412	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2416	 1	 14.32	 5.6	 0.0	 88.82	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2421	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2424	 1	 44.55	 16.8	 0.0	 2.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2425	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2426	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2428	 1	 -0.0	 -0.0	 0.0	 50.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2430	 1	 -0.0	 0.0	 0.0	 6.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2432	 1	 291.2	 35.4	 0.0	 21.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2437	 1	 -0.0	 -8.6	 0.0	 297.94	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2438	 1	 -0.0	 0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2441	 1	 0.0	 -0.0	 0.242534	 1.143584	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2446	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2448	 1	 34.24	 16.5	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	2449	 1	 301.9	 -103.2	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	2457	 1	 30.73	 9.6	 0.0	 2.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2458	 1	 132.0	 26.0	 0.0	 27.18	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2459	 1	 -0.0	 0.0	 0.0	 145.98	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2460	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2467	 1	 0.0	 -0.0	 0.0	 11.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2468	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2471	 1	 103.5	 21.7	 0.0	 8.88	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2475	 1	 0.0	 0.0	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2478	 1	 50.96	 6.8	 0.0	 9.13	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2479	 1	 -2.65	 -1.17	 0.0	 65.673108	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2481	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2482	 1	 -0.21	 -1.98	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2489	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2494	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2496	 1	 50.56	 4.6	 0.0	 1.74	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2497	 1	 0.0	 0.0	 0.0	 9.36	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2503	 1	 -0.0	 0.0	 0.0	 2.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2504	 1	 119.2	 32.1	 0.0	 4.14	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2507	 1	 -0.0	 0.0	 0.0	 36.17	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2510	 1	 115.87	 29.41	 0.0	 7.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2517	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2518	 1	 -5.29	 -1.91	 0.0	 42.622979	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2520	 1	 -0.0	 -0.0	 0.057433	 3.80797	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2523	 1	 0.0	 0.0	 0.0	 7.06	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	2526	 1	 238.45	 46.86	 0.0	 125.534496	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2527	 1	 59.77	 16.7	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2535	 1	 51.56	 2.1	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2538	 1	 118.8	 39.5	 0.0	 2.61	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2549	 1	 0.0	 -0.0	 0.0	 3.86	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2550	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2551	 1	 205.3	 27.8	 0.0	 8.22	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2552	 1	 28.53	 11.3	 0.0	 6.81	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2555	 1	 -0.15	 -1.0	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2558	 1	 159.27	 38.31	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2562	 1	 -88.6	 -24.2	 0.0	 5.66	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2563	 1	 52.86	 13.0	 0.0	 6.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2564	 1	 0.0	 0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2566	 1	 0.0	 -0.0	 0.0	 68.93	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2572	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2575	 1	 62.97	 17.4	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2591	 1	 253.77	 84.6	 0.0	 20.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2597	 1	 14.72	 5.4	 0.0	 0.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2598	 1	 25.63	 12.7	 0.0	 8.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2600	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2616	 1	 -0.0	 0.0	 0.0	 1.46	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2619	 1	 0.0	 0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2622	 1	 -0.0	 0.0	 0.0	 6.91	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2627	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2629	 1	 203.1	 65.2	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2641	 1	 0.0	 0.0	 0.0	 1.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2642	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2644	 1	 0.0	 0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2648	 1	 46.65	 15.1	 0.0	 9.79	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2653	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2654	 1	 207.1	 50.4	 0.0	 4.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2656	 1	 -0.72	 0.0	 0.0	 69.582294	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2658	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2660	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2667	 1	 70.68	 10.7	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2668	 1	 252.9	 95.6	 0.0	 1.22	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2676	 1	 123.24	 23.65	 0.0	 6.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2686	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2689	 1	 0.0	 0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2692	 1	 285.2	 65.3	 0.0	 11.28	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2695	 1	 16.22	 8.9	 0.0	 2.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2698	 1	 0.0	 -1.2	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2700	 1	 -0.0	 0.0	 0.0	 3.08	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2702	 1	 151.7	 27.6	 0.0	 6.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2703	 1	 -0.2	 -4.97	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2708	 1	 47.75	 18.8	 0.0	 4.42	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2719	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2720	 1	 13.01	 14.2	 0.0	 15.78	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2721	 1	 -0.0	 0.0	 0.0	 10.040547	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2722	 1	 0.0	 0.0	 0.0	 56.39	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	2728	 1	 -0.13	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	2730	 1	 0.1	 152.7	 0.0	 233.41	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2732	 1	 85.59	 20.72	 0.0	 142.79	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2734	 1	 -61.67	 -0.9	 0.0	 12.33	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2740	 1	 36.24	 5.7	 0.0	 15.06	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2745	 1	 0.0	 -0.0	 0.0	 56.27	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2748	 1	 65.47	 26.7	 0.0	 18.6	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2749	 1	 55.56	 26.5	 0.0	 1.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2751	 1	 34.54	 8.6	 0.0	 5.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2754	 1	 -0.0	 0.0	 0.0	 3.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2760	 1	 64.87	 25.6	 0.0	 14.89	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2764	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2769	 1	 98.6	 28.3	 0.0	 4.76	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	2770	 1	 85.39	 14.3	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2782	 1	 -28.13	 -0.81	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2785	 1	 189.4	 25.8	 0.0	 3.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2786	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	2794	 1	 0.0	 -0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2795	 1	 -0.0	 -0.0	 0.0	 1.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2796	 1	 100.7	 17.5	 0.0	 6.54	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2797	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2799	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2800	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2801	 1	 0.0	 -0.0	 0.0	 12.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2804	 1	 31.33	 9.6	 0.0	 1.86	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2806	 1	 -0.0	 -0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2812	 1	 97.0	 18.6	 0.0	 1.25	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2815	 1	 25.33	 14.2	 0.0	 4.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2816	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2817	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2824	 1	 -0.0	 -0.0	 0.0	 4.17	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	2832	 1	 48.15	 14.8	 0.0	 2.16	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2841	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2842	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2844	 1	 179.0	 50.5	 0.0	 3.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2847	 1	 40.14	 8.8	 0.0	 0.82	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2848	 1	 453.23	 139.16	 0.0	 25.583218	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2849	 1	 0.0	 0.0	 0.0	 70.11	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2850	 1	 -0.0	 -0.0	 0.0	 4.76	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2853	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2854	 1	 -12.33	 -2.65	 0.0	 69.323028	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2863	 1	 37.73	 13.84	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2866	 1	 -0.0	 0.0	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2870	 1	 -0.0	 0.0	 0.0	 0.62	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2872	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2877	 1	 29.93	 -0.0	 0.0	 0.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2878	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2886	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2888	 1	 -0.0	 0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2889	 1	 -0.0	 0.0	 0.0	 3.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2894	 1	 -0.0	 0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2896	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2898	 1	 56.76	 13.4	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2899	 1	 -0.0	 -0.0	 0.0	 44.66	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	2900	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2902	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2907	 1	 241.0	 32.3	 0.0	 34.74	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2908	 1	 203.8	 61.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	2910	 1	 -0.0	 0.0	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2913	 1	 51.96	 9.4	 0.0	 42.51	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2916	 1	 63.47	 30.2	 0.0	 81.36	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2917	 1	 31.64	 7.5	 0.0	 21.91	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2918	 1	 0.0	 0.0	 0.0	 53.25003	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2919	 1	 -0.0	 0.0	 0.0	 32.049116	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2921	 1	 37.24	 7.1	 0.0	 1.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2924	 1	 19.92	 7.4	 0.0	 17.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2927	 1	 -0.0	 0.0	 0.0	 26.18	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	2928	 1	 0.0	 -0.0	 0.0	 92.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2930	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2931	 1	 230.7	 19.3	 0.0	 4.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2934	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2938	 1	 0.0	 -0.0	 0.0	 137.29	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2940	 1	 103.0	 28.7	 0.0	 2.88	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2946	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2949	 1	 -0.0	 -0.0	 0.0	 11.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2951	 1	 104.6	 40.7	 0.0	 1.42	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2954	 1	 4.81	 1.2	 0.0	 0.13	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2957	 1	 81.19	 24.4	 0.0	 0.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2961	 1	 159.9	 53.2	 0.0	 7.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2962	 1	 93.5	 42.5	 0.0	 133.56	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2965	 1	 -29.96	 -21.31	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2967	 1	 0.0	 -0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2968	 1	 112.51	 16.51	 0.0	 1.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2971	 1	 0.0	 0.0	 0.0	 11.55	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2972	 1	 97.82	 20.59	 0.0	 6.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2974	 1	 65.47	 26.7	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2978	 1	 0.0	 0.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2980	 1	 -0.0	 0.0	 0.0	 0.42	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2981	 1	 -0.0	 0.0	 0.0	 1.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2985	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2995	 1	 0.0	 -0.0	 0.0	 3.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3000	 1	 139.6	 68.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3007	 1	 108.8	 33.2	 0.358716	 45.62985	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	3008	 1	 0.0	 0.0	 0.0	 22.7	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3013	 1	 2.2	 1.1	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3018	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3019	 1	 0.0	 -0.0	 0.0	 1.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3021	 1	 74.38	 8.8	 0.0	 6.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3022	 1	 149.0	 19.8	 0.0	 23.89	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3023	 1	 0.0	 -0.0	 0.0	 27.69	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3027	 1	 0.0	 0.0	 0.0	 1.54	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3028	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3036	 1	 116.93	 33.6	 0.0	 3.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3037	 1	 221.0	 146.8	 0.0	 8.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3044	 1	 29.33	 5.6	 0.0	 6.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3047	 1	 0.0	 -0.0	 0.0	 3.84	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3051	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3054	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3061	 1	 493.4	 53.5	 0.0	 58.09	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3063	 1	 71.28	 6.9	 0.0	 1.93	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3065	 1	 55.86	 8.8	 0.0	 4.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3066	 1	 119.7	 3.7	 0.0	 0.88	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3067	 1	 272.3	 58.5	 0.0	 23.57	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3069	 1	 89.6	 22.7	 0.0	 4.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3070	 1	 0.0	 -0.0	 0.0	 4.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3071	 1	 0.0	 -0.0	 0.0	 2.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3072	 1	 92.9	 27.7	 0.0	 5.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3075	 1	 30.33	 10.5	 0.0	 0.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3076	 1	 164.0	 42.3	 0.0	 8.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3080	 1	 -0.0	 -0.0	 0.256503	 101.229042	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	3082	 1	 0.0	 0.0	 0.0	 75.076038	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3083	 1	 567.97	 130.73	 0.0	 1.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3085	 1	 64.67	 24.5	 0.0	 1.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3095	 1	 69.78	 15.3	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3097	 1	 128.11	 64.9	 0.0	 19.1	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	3106	 1	 30.63	 11.6	 0.0	 52.28	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3109	 1	 -0.0	 0.0	 0.0	 8.33	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3111	 1	 0.0	 0.0	 0.0	 20.96	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3112	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3113	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3114	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3119	 1	 99.9	 20.1	 0.0	 17.41	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3121	 1	 242.16	 73.64	 0.0	 12.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3125	 1	 -0.0	 0.0	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3126	 1	 104.78	 20.92	 0.0	 6.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3133	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3134	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3137	 1	 0.0	 -0.0	 0.0	 0.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3145	 1	 -0.0	 -0.0	 0.0	 24.909116	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3148	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3150	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3157	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3163	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3166	 1	 184.91	 32.8	 0.0	 8.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3169	 1	 0.0	 0.0	 0.0	 75.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3177	 1	 39.34	 11.2	 0.0	 0.85	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3178	 1	 180.2	 46.4	 0.0	 9.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3182	 1	 31.94	 12.6	 0.0	 10.67	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3183	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3184	 1	 14.12	 7.7	 0.0	 1.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3186	 1	 -20.92	 2.5	 0.0	 16.42	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3187	 1	 107.0	 34.7	 0.0	 1.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3190	 1	 0.0	 -0.0	 0.0	 35.14	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3191	 1	 127.8	 15.2	 0.0	 9.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3193	 1	 0.0	 0.0	 0.0	 207.85	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3200	 1	 86.2	 19.9	 0.0	 5.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3204	 1	 8.51	 3.2	 0.0	 0.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3205	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3206	 1	 146.7	 20.7	 0.0	 62.64	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3210	 1	 -0.0	 -0.0	 0.0	 47.99	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3211	 1	 0.0	 0.0	 0.0	 5.21	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3215	 1	 63.07	 25.8	 0.0	 18.63	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3216	 1	 73.58	 30.1	 0.0	 6.02	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3218	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3221	 1	 76.38	 24.8	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3224	 1	 0.0	 -0.0	 0.0	 1.86	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	3231	 1	 251.3	 42.6	 0.0	 5.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3233	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3239	 1	 -5.06	 -1.84	 0.0	 187.327025	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3240	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3241	 1	 132.0	 27.0	 0.0	 4.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3242	 1	 296.1	 82.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	3243	 1	 -0.0	 0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3246	 1	 20.9	 -171.5	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3248	 1	 84.19	 17.3	 0.0	 6.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3255	 1	 0.0	 0.0	 0.0	 1.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3256	 1	 -0.0	 0.0	 0.0	 1.87	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	3257	 1	 0.0	 -0.0	 0.0	 3.71	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	3265	 1	 0.0	 -0.0	 0.0	 61.52	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	3266	 1	 -0.0	 0.0	 0.0	 4.62	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3268	 1	 -0.0	 -0.0	 0.0	 29.27	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3275	 1	 -0.0	 0.0	 0.0	 17.75	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3276	 1	 -0.0	 -0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3279	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	3280	 1	 -0.0	 0.0	 0.0	 2.08	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3282	 1	 -0.0	 0.0	 0.0	 9.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3291	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3293	 1	 33.14	 11.6	 0.0	 4.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3299	 1	 332.9	 99.6	 0.0	 0.53	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3301	 1	 72.08	 29.5	 0.0	 1.06	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3306	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3314	 1	 -0.2	 -1.64	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3324	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3325	 1	 -0.0	 0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3327	 1	 -0.0	 -0.0	 0.0	 2.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3331	 1	 -0.0	 -0.0	 0.0	 4.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3334	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3335	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3341	 1	 46.85	 16.6	 0.0	 2.08	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	3342	 1	 76.18	 13.2	 0.0	 7.4	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3344	 1	 83.29	 24.1	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3346	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3352	 1	 -0.0	 -0.0	 0.0	 5.22	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3353	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3363	 1	 155.8	 38.4	 0.0	 3.77	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3364	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3367	 1	 57.46	 15.3	 0.0	 4.37	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3370	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3374	 1	 156.2	 24.5	 0.0	 2.22	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3377	 1	 77.49	 21.4	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3378	 1	 -0.0	 -0.0	 0.0	 13.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3382	 1	 115.0	 -4.5	 0.0	 15.05	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3388	 1	 -0.2	 -1.64	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3390	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3391	 1	 302.5	 65.1	 0.0	 8.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3397	 1	 24.12	 9.8	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3400	 1	 0.0	 0.0	 0.0	 17.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3401	 1	 23.22	 6.3	 0.0	 0.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3409	 1	 -0.0	 -0.0	 0.0	 16.4	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3412	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3413	 1	 19.42	 7.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	3416	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3422	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3425	 1	 83.59	 21.6	 0.0	 25.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3427	 1	 146.9	 26.6	 0.0	 11.95	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3428	 1	 -0.0	 -0.0	 0.0	 17.92	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3429	 1	 175.4	 28.8	 0.0	 2.03	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	3430	 1	 125.1	 44.0	 0.0	 6.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3435	 1	 -0.0	 0.0	 0.0	 10.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3436	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3442	 1	 54.96	 12.2	 0.0	 7.05	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3443	 1	 -0.0	 0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3445	 1	 -7.63	 -4.3	 0.0	 94.00001	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3450	 1	 78.99	 16.2	 0.0	 1.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3456	 1	 -0.0	 0.0	 0.0	 2.09	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3462	 1	 209.5	 95.0	 0.0	 24.39	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3468	 1	 50.36	 -36.2	 0.0	 1.25	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3478	 1	 -3.4	 -0.5	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3481	 1	 142.5	 23.6	 0.0	 4.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3483	 1	 157.78	 276.03	 0.0	 91.192543	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3484	 1	 -0.0	 0.0	 0.0	 37.1	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3485	 1	 -0.0	 0.0	 0.0	 6.501668	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3486	 1	 101.5	 -18.3	 0.0	 8.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3487	 1	 16.32	 7.6	 0.0	 3.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3488	 1	 55.66	 4.5	 0.0	 1.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3489	 1	 0.0	 -0.0	 0.0	 12.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3492	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3493	 1	 226.3	 61.1	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	3495	 1	 36.34	 3.3	 0.0	 2.16	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3496	 1	 99.3	 23.3	 0.0	 1.88	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3497	 1	 100.5	 32.0	 0.0	 1.89	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3498	 1	 138.5	 19.3	 0.0	 5.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3499	 1	 180.4	 71.6	 0.0	 81.042938	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3500	 1	 94.2	 21.6	 0.0	 2.88	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3502	 1	 98.2	 19.1	 0.0	 10.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3503	 1	 -0.0	 0.0	 0.0	 1.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3506	 1	 0.0	 0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	3509	 1	 23.62	 16.5	 0.0	 8.39	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3512	 1	 65.64	 -0.98	 0.0	 11.55	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3513	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3519	 1	 -0.0	 0.0	 0.0	 68.053762	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3520	 1	 -0.0	 0.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3526	 1	 33.34	 13.2	 0.0	 0.76	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3530	 1	 118.5	 21.0	 0.0	 2.19	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3535	 1	 -0.0	 0.0	 0.0	 0.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3538	 1	 0.0	 0.0	 0.0	 4.17	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	3541	 1	 0.0	 -0.0	 0.0	 3.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3543	 1	 -0.0	 -0.0	 0.0	 14.079026	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3544	 1	 0.0	 -0.0	 0.0	 83.96	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3545	 1	 20.12	 7.6	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3549	 1	 0.0	 0.0	 0.0	 3.91	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3557	 1	 87.2	 31.8	 0.0	 5.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3558	 1	 -0.0	 0.0	 0.0	 2.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3565	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3577	 1	 -38.7	 -12.99	 0.0	 13.47383	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3579	 1	 277.72	 7.35	 0.0	 3.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3580	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3582	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3584	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3585	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3587	 1	 0.0	 -0.0	 0.0	 78.22	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3589	 1	 37.54	 18.3	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3592	 1	 102.7	 77.5	 0.0	 4.89	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3594	 1	 31.43	 6.6	 0.0	 3.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3601	 1	 0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3602	 1	 86.6	 14.9	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3608	 1	 0.0	 -0.0	 0.0	 58.146813	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3609	 1	 -28.13	 -0.82	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3610	 1	 185.8	 31.8	 0.0	 3.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3611	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3613	 1	 152.5	 14.4	 0.0	 24.61	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3615	 1	 0.0	 -0.0	 0.0	 13.51	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3620	 1	 35.14	 16.1	 0.0	 0.45	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3621	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3623	 1	 0.0	 -0.0	 0.0	 4.08	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3629	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3633	 1	 -0.0	 0.0	 0.0	 15.23	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3643	 1	 24.23	 6.4	 0.0	 3.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3644	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3645	 1	 42.55	 17.6	 0.0	 17.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3649	 1	 -0.0	 -0.0	 0.0	 4.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3650	 1	 0.0	 -0.0	 0.0	 4.68	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3654	 1	 20.72	 5.0	 0.0	 6.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3656	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3657	 1	 131.0	 1.3	 0.0	 120.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3659	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	3661	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3662	 1	 -0.0	 -0.0	 0.0	 4.74	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3664	 1	 -0.2	 -0.96	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3665	 1	 295.4	 42.0	 0.0	 0.83	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3670	 1	 28.03	 6.5	 0.0	 6.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3672	 1	 82.99	 25.9	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3673	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3674	 1	 155.05	 39.56	 0.0	 6.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3680	 1	 -0.0	 -0.0	 0.0	 12.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3687	 1	 0.0	 -0.0	 0.0	 70.71	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3689	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3691	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3692	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3697	 1	 -32.71	 -13.76	 0.0	 135.136611	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3698	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3701	 1	 -0.0	 0.0	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3707	 1	 77.49	 17.3	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3711	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	3712	 1	 -0.19	 -0.87	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3715	 1	 68.78	 13.0	 0.0	 10.45	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3718	 1	 179.4	 58.3	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3723	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3728	 1	 67.77	 10.4	 0.0	 7.18	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3734	 1	 51.36	 -0.7	 0.0	 0.57	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3736	 1	 45.15	 4.1	 0.0	 2.61	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3737	 1	 42.48	 10.36	 0.0	 0.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3740	 1	 0.0	 -0.0	 0.0	 13.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3741	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3744	 1	 93.9	 10.95	 0.0	 4.98	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3747	 1	 39.44	 5.9	 0.0	 1.92	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3749	 1	 115.1	 16.4	 0.0	 7.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3754	 1	 -24.93	 11.8	 0.0	 3.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3758	 1	 83.49	 17.4	 0.0	 19.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3760	 1	 163.5	 44.9	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3768	 1	 19.82	 10.9	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3771	 1	 34.14	 13.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3775	 1	 55.54	 15.06	 0.0	 6.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3776	 1	 0.0	 -0.0	 0.0	 5.25	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3786	 1	 -0.0	 -0.0	 0.0	 26.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3791	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	3792	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3793	 1	 197.7	 67.65	 0.0	 13.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3794	 1	 165.3	 7.4	 0.0	 28.32	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3798	 1	 -0.0	 0.0	 0.0	 17.64	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3809	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3813	 1	 226.0	 55.79	 0.0	 18.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3814	 1	 130.5	 24.7	 0.0	 0.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3817	 1	 0.0	 -0.0	 0.0	 1.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3818	 1	 44.45	 10.9	 0.0	 2.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3819	 1	 0.0	 -0.0	 0.0	 35.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3821	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3825	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3830	 1	 -0.0	 0.0	 0.0	 97.326028	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3834	 1	 160.0	 69.2	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3840	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3843	 1	 123.9	 32.6	 0.0	 1.52	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3846	 1	 -0.0	 0.0	 0.0	 5.36	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3855	 1	 -38.73	 -15.32	 0.0	 97.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3857	 1	 -0.0	 -0.0	 0.0	 11.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3865	 1	 -0.0	 -0.0	 0.0	 2.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3866	 1	 201.06	 19.46	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3868	 1	 -8.43	 -7.98	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3869	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3876	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3878	 1	 -0.0	 -0.0	 0.0	 9.19	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	3880	 1	 -28.13	 -0.82	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3891	 1	 0.0	 0.0	 0.0	 7.89	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	3894	 1	 0.0	 0.0	 0.0	 4.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3898	 1	 121.5	 29.6	 0.0	 2.49	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3903	 1	 0.0	 0.0	 0.0	 4.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3906	 1	 0.0	 0.0	 0.0	 98.2	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3912	 1	 0.0	 -0.0	 0.0	 19.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3916	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3918	 1	 -11.8	 -5.47	 0.0	 88.050735	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3919	 1	 -0.0	 0.0	 0.0	 39.95	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3925	 1	 89.3	 25.1	 0.0	 2.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3928	 1	 105.2	 24.2	 0.0	 0.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3929	 1	 48.95	 11.6	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3932	 1	 -0.0	 0.0	 0.0	 4.86	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3937	 1	 83.19	 11.4	 0.0	 9.84	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3951	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3954	 1	 310.8	 162.6	 0.0	 19.47	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3956	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3957	 1	 -0.0	 -0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3960	 1	 0.0	 -0.0	 0.0	 5.62	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3961	 1	 42.35	 7.2	 0.0	 1.47	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3962	 1	 19.42	 11.8	 0.0	 2.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3966	 1	 220.7	 -14.8	 0.0	 125.52	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3968	 1	 -0.18	 -2.27	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3969	 1	 -0.0	 -0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3971	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3974	 1	 -0.18	 -1.42	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3975	 1	 148.0	 26.1	 0.0	 9.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3983	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3985	 1	 77.19	 26.5	 0.0	 6.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3987	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3990	 1	 7.01	 1.8	 0.0	 35.44	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	3994	 1	 36.34	 10.4	 0.0	 2.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3997	 1	 26.13	 9.7	 0.0	 2.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3999	 1	 110.8	 36.9	 0.0	 23.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4000	 1	 -0.0	 0.0	 0.0	 24.103274	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4005	 1	 171.18	 28.49	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4006	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4011	 1	 144.8	 39.7	 0.0	 12.64	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4013	 1	 0.0	 -0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4014	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4016	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4020	 1	 0.0	 -0.0	 0.0	 14.28	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4021	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4024	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4025	 1	 0.0	 0.0	 0.0	 2.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4026	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4031	 1	 0.0	 -0.0	 0.0	 6.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4032	 1	 265.7	 113.5	 0.0	 1.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4039	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4049	 1	 -0.0	 -0.0	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4054	 1	 0.0	 -0.0	 0.0	 2.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4056	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4057	 1	 74.78	 -31.4	 0.0	 1.74	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4058	 1	 0.0	 0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4059	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4060	 1	 -0.0	 0.0	 0.0	 2.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4062	 1	 6.31	 0.0	 0.0	 0.42	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4077	 1	 0.0	 -0.0	 0.0	 23.27	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4081	 1	 -0.0	 -0.0	 0.0	 6.9	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4082	 1	 -0.0	 0.0	 0.0	 1.14	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4084	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4087	 1	 -0.0	 -0.0	 0.0	 26.36	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4095	 1	 65.27	 6.0	 0.0	 3.89	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4096	 1	 47.65	 7.1	 0.0	 7.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4098	 1	 61.67	 28.3	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	4100	 1	 -0.0	 -0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4103	 1	 81.09	 12.5	 0.0	 2.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4104	 1	 40.34	 10.4	 0.0	 7.02	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4110	 1	 13.01	 3.8	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4112	 1	 64.77	 6.4	 0.0	 3.84	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4114	 1	 9.91	 5.4	 0.0	 4.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4116	 1	 2.2	 0.5	 0.0	 2.31	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4118	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4124	 1	 230.42	 -7.87	 0.0	 5.13	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4125	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4127	 1	 39.14	 7.7	 0.0	 11.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4128	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4130	 1	 0.0	 -0.0	 0.0	 2.1	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4132	 1	 25.43	 7.9	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4134	 1	 -0.0	 0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4141	 1	 -0.62	 0.0	 0.0	 75.020288	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4143	 1	 11.11	 4.1	 0.0	 0.8	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4144	 1	 310.2	 4.5	 0.0	 8.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4157	 1	 0.0	 0.0	 0.0	 1.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4165	 1	 325.2	 38.1	 0.0	 19.99	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4170	 1	 -0.0	 0.0	 0.0	 12.88	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	4177	 1	 20.22	 5.7	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4181	 1	 195.6	 -1.0	 0.0	 3.19	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4182	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4185	 1	 87.5	 21.3	 0.0	 7.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4186	 1	 -0.0	 0.0	 0.0	 5.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4188	 1	 59.17	 19.3	 0.0	 1.16	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4189	 1	 200.65	 30.72	 0.0	 9.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4192	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4196	 1	 -3.2	 -1.05	 0.0	 48.471563	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4197	 1	 9.01	 4.9	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4204	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4205	 1	 5.81	 1.7	 0.0	 0.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4209	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4215	 1	 -0.0	 -0.0	 0.0	 17.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4216	 1	 -0.17	 -8.06	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4224	 1	 -20.56	 -3.88	 0.0	 1.72	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4230	 1	 57.76	 16.0	 0.0	 2.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4231	 3	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4234	 1	 0.0	 0.0	 0.0	 8.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4235	 1	 -0.0	 -0.0	 0.0	 12.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4238	 1	 -0.0	 -0.0	 0.0	 8.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4239	 1	 190.7	 52.0	 0.0	 20.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4241	 1	 -0.0	 -0.0	 0.0	 93.61	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4245	 1	 24.93	 9.6	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4248	 1	 0.0	 -0.0	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	4249	 1	 57.06	 15.6	 0.0	 2.03	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4251	 1	 47.15	 15.7	 0.0	 5.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4253	 1	 105.0	 18.0	 0.0	 5.41	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4259	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4267	 1	 70.78	 19.6	 0.0	 7.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4272	 1	 184.7	 71.5	 0.0	 95.42	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4274	 1	 35.49	 11.53	 0.0	 1.31	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4277	 1	 -0.0	 0.0	 0.0	 1.63	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4279	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4281	 1	 -0.0	 -0.0	 0.0	 11.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4290	 1	 -1.9	 -28.1	 0.0	 100.56	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4291	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4293	 1	 80.59	 7.3	 0.0	 18.92	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4295	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4300	 1	 81.49	 25.1	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4301	 1	 -0.0	 -0.0	 0.0	 2.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4302	 1	 30.53	 9.0	 0.0	 1.9	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4306	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4313	 1	 133.4	 29.4	 0.0	 10.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4314	 1	 26.13	 2.7	 0.0	 1.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4315	 1	 -113.33	 45.2	 0.0	 67.52	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4317	 1	 -0.0	 0.0	 0.0	 3.81	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4318	 1	 51.06	 16.5	 0.0	 2.37	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4320	 1	 50.35	 24.3	 0.0	 3.64	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	4324	 1	 -0.0	 0.0	 0.0	 1.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4331	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4333	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	4336	 1	 55.46	 8.4	 0.0	 5.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4337	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4338	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4339	 1	 -0.0	 -0.0	 0.0	 42.345005	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4340	 1	 -0.0	 -0.0	 0.0	 4.03	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	4344	 1	 68.48	 -10.6	 0.0	 2.65	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4353	 1	 165.8	 44.0	 0.0	 6.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4355	 1	 65.07	 15.0	 0.0	 1.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4357	 1	 235.0	 58.9	 0.0	 14.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4360	 1	 20.82	 8.2	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4362	 1	 43.75	 17.3	 0.0	 7.73	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4363	 1	 0.0	 -0.0	 0.0	 18.66	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4368	 1	 90.6	 15.8	 0.0	 7.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4371	 1	 72.28	 6.6	 0.0	 1.42	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4380	 1	 -67.31	 -44.04	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4390	 1	 -0.0	 0.0	 0.0	 72.64	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4393	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	4395	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4397	 1	 193.0	 17.6	 0.0	 4.74	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4402	 1	 -0.0	 0.0	 0.0	 1.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4407	 1	 -0.0	 -0.0	 0.0	 51.43	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4409	 1	 -5.15	 -16.03	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4410	 1	 45.05	 13.2	 0.0	 44.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4413	 1	 0.0	 0.0	 0.0	 13.44	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4415	 1	 30.03	 9.7	 0.0	 4.1	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4418	 1	 -0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4419	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4423	 1	 -0.0	 -0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4426	 1	 485.5	 -63.38	 0.0	 34.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4427	 1	 296.8	 77.7	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4428	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4431	 1	 19.52	 5.6	 0.0	 1.46	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4432	 1	 -0.0	 0.0	 0.0	 0.8	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4435	 1	 -0.0	 -0.0	 0.0	 102.217726	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4442	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4446	 1	 0.0	 -0.0	 0.0	 9.25	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4450	 1	 140.2	 11.2	 0.0	 9.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4454	 1	 -0.0	 -0.0	 0.0	 1.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4467	 1	 -0.0	 0.0	 0.0	 7.22	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4477	 1	 -0.2	 -1.64	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4480	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4481	 1	 0.0	 0.0	 0.0	 2.7	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4482	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4484	 1	 69.78	 25.0	 0.0	 14.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4485	 1	 0.0	 0.0	 0.0	 18.32	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4489	 1	 0.0	 -0.0	 0.0	 5.9	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4491	 1	 0.0	 -0.0	 0.0	 1.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4493	 1	 15.32	 18.2	 0.0	 27.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4494	 1	 -0.0	 0.0	 0.0	 55.514618	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4495	 1	 336.3	 104.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4504	 1	 170.1	 -9.3	 0.0	 5.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4505	 1	 95.51	 17.1	 0.0	 8.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4506	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4507	 1	 -0.0	 0.0	 0.0	 43.44	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4509	 1	 77.99	 30.8	 0.0	 2.41	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4510	 1	 75.38	 21.8	 0.0	 0.63	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4511	 1	 81.89	 19.9	 0.0	 5.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4513	 1	 92.1	 29.5	 0.0	 3.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4520	 1	 -0.0	 -0.0	 0.0	 0.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4525	 1	 -0.0	 0.0	 0.0	 6.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4529	 1	 48.48	 8.7	 0.0	 10.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4541	 1	 0.0	 -0.0	 0.0	 150.797812	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4542	 1	 -0.0	 0.0	 0.0	 38.49	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4543	 1	 -0.0	 0.0	 0.0	 2.32	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	4544	 1	 -0.0	 -0.0	 0.0	 14.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4549	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4550	 1	 0.0	 -0.0	 0.0	 124.2	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4554	 1	 119.0	 21.9	 0.0	 0.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4556	 1	 138.2	 21.3	 0.0	 2.33	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4562	 1	 130.5	 25.7	 0.0	 2.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4565	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4566	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4577	 1	 2.2	 0.6	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4580	 1	 11.01	 3.9	 0.0	 7.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4586	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4588	 1	 -0.0	 0.0	 0.0	 75.38	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4592	 1	 183.8	 2.2	 0.0	 2.98	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4594	 1	 -1.73	 -1.71	 0.0	 22.062314	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4598	 1	 -0.0	 0.0	 0.0	 52.958443	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4600	 1	 19.12	 7.4	 0.0	 21.97	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4603	 1	 70.28	 10.3	 0.0	 13.73	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4614	 1	 74.18	 14.6	 0.0	 11.71	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4615	 1	 42.55	 17.6	 0.0	 1.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4616	 1	 30.83	 16.5	 0.0	 3.83	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4623	 1	 0.0	 -0.0	 0.0	 80.388213	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4624	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4632	 1	 0.0	 -0.0	 0.0	 3.21	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4644	 1	 18.22	 8.6	 0.0	 34.7	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4650	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	4651	 1	 0.0	 0.0	 0.0	 8.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4652	 1	 -0.0	 0.0	 0.0	 165.63	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4656	 1	 93.9	 -0.4	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4657	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4658	 1	 51.06	 7.4	 0.0	 2.49	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4661	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4663	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4665	 1	 390.5	 62.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4674	 1	 124.0	 29.2	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4679	 1	 102.7	 17.8	 0.0	 48.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4683	 1	 38.84	 8.5	 0.0	 7.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4685	 1	 46.15	 11.2	 0.0	 10.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4686	 1	 16.02	 5.1	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4687	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4689	 1	 109.7	 15.0	 0.0	 30.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4690	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4692	 1	 -0.0	 0.0	 0.0	 50.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4701	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4704	 1	 0.0	 -0.0	 0.304554	 30.256205	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	4706	 1	 0.0	 -0.0	 0.0	 20.81	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4710	 1	 195.4	 76.84	 0.0	 8.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4711	 1	 -0.0	 0.0	 0.0	 16.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4712	 1	 -0.0	 0.0	 0.073728	 5.986272	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	4717	 1	 0.0	 0.0	 0.0	 46.25	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4721	 1	 0.0	 -0.0	 0.0	 6.11	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4725	 1	 4.91	 1.6	 0.0	 4.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4728	 1	 3.1	 0.1	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4729	 1	 0.0	 0.0	 0.0	 2.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4733	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4734	 1	 0.0	 0.0	 0.0	 25.339116	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4735	 1	 0.0	 0.0	 0.0	 13.59	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4738	 1	 101.89	 25.72	 0.0	 5.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4740	 1	 -0.15	 -0.9	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4744	 1	 2.2	 0.0	 0.0	 4.81	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	4747	 1	 93.3	 27.8	 0.0	 6.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4748	 1	 -0.0	 -0.0	 0.0	 1.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4750	 1	 137.7	 32.6	 0.0	 5.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4752	 1	 101.1	 19.8	 0.0	 3.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4757	 1	 147.0	 56.3	 0.0	 0.51	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4765	 1	 33.04	 10.1	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4771	 1	 0.0	 0.0	 0.0	 1.32	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4772	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4773	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4774	 1	 63.27	 28.9	 0.0	 2.19	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4776	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4779	 1	 -777.45	 39.02	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4783	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4787	 1	 71.98	 27.1	 0.0	 7.2	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4795	 1	 0.0	 0.0	 0.0	 81.29	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4797	 1	 -0.01	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4799	 1	 0.0	 0.0	 0.0	 2.62	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4806	 1	 210.8	 -0.7	 0.0	 4.14	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4807	 1	 39.84	 6.4	 0.0	 34.58	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	4809	 1	 151.0	 7.1	 0.0	 4.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4816	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4819	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4823	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4825	 1	 -0.0	 0.0	 0.0	 46.7	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4826	 1	 103.6	 16.0	 0.0	 11.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4829	 1	 171.9	 39.1	 0.0	 4.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4831	 1	 130.4	 44.33	 0.0	 5.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4843	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4846	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4850	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4852	 1	 45.55	 -59.9	 0.0	 30.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4855	 1	 127.9	 -34.0	 0.0	 19.86	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4856	 1	 45.95	 7.5	 0.0	 8.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4858	 1	 -0.0	 -0.0	 0.0	 53.97	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4863	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4864	 1	 -28.21	 -6.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4867	 1	 65.77	 27.3	 0.0	 0.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4868	 1	 2.2	 0.5	 0.0	 2.88	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4872	 1	 15.42	 3.9	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4874	 1	 -0.58	 -53.03	 0.0	 6.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4880	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4885	 1	 166.4	 50.4	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4889	 1	 74.98	 19.8	 0.0	 6.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4890	 1	 185.0	 43.6	 0.0	 6.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4896	 1	 329.7	 32.4	 0.0	 4.5	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4897	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4906	 1	 175.8	 70.7	 0.0	 19.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4907	 1	 125.16	 29.2	 0.0	 2.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4908	 1	 50.06	 9.9	 0.0	 11.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4910	 1	 -0.0	 0.0	 0.0	 0.95	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4914	 1	 14.91	 -8.73	 0.0	 34.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4918	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4925	 1	 -0.0	 0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4926	 1	 3.8	 1.1	 0.0	 10.69	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	4929	 1	 37.0	 8.7	 0.070441	 50.913893	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	4931	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4936	 1	 312.2	 28.0	 0.0	 48.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4939	 1	 56.76	 31.1	 0.0	 0.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4942	 1	 109.9	 33.6	 0.0	 3.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4945	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4947	 1	 88.3	 2.8	 0.0	 5.21	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4948	 1	 10.21	 -3.2	 0.0	 5.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4950	 1	 218.7	 -9.1	 0.0	 49.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4951	 1	 71.98	 34.1	 0.0	 7.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4952	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4953	 1	 66.77	 11.1	 0.0	 2.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4954	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4957	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4958	 1	 -0.0	 -0.0	 0.0	 1.94	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4964	 1	 -0.0	 -0.0	 0.0	 29.32	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4967	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4968	 1	 -0.0	 -0.0	 0.0	 16.57	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4970	 1	 -0.0	 -0.0	 0.0	 171.931977	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4974	 1	 89.08	 26.9	 0.0	 4.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4993	 1	 -0.12	 -1.74	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5001	 1	 82.49	 24.5	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5002	 1	 -0.0	 0.0	 0.0	 4.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5003	 1	 17.87	 -8.59	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5004	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5006	 1	 -58.77	 18.7	 0.0	 4.23	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	5007	 1	 0.0	 0.0	 0.0	 40.291745	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5008	 1	 0.0	 -0.0	 0.0	 23.76	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5016	 1	 -0.0	 0.0	 0.0	 8.347383	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5019	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5025	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5031	 1	 174.7	 35.0	 0.0	 2.14	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5034	 1	 32.24	 4.8	 0.0	 0.85	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5042	 1	 24.33	 10.0	 0.0	 84.57	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5044	 1	 0.0	 -0.0	 0.0	 12.01	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5049	 1	 136.6	 29.0	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5051	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5060	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5065	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5067	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5077	 1	 30.93	 5.8	 0.0	 4.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5083	 1	 80.39	 10.8	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5091	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5093	 1	 70.78	 28.0	 0.0	 1.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5094	 1	 -0.0	 -0.0	 0.0	 5.02	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5096	 1	 -2.27	 -1.81	 0.0	 42.76	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5097	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	5099	 1	 0.0	 0.0	 0.0	 9.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5106	 1	 39.94	 13.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5108	 1	 -55.83	 -31.99	 0.0	 2.88	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5110	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5111	 1	 139.9	 1.1	 0.0	 5.58	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5117	 1	 46.25	 13.1	 0.0	 1.29	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5120	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5121	 1	 23.4	 8.38	 0.0	 1.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5125	 1	 0.0	 0.0	 0.0	 16.06	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5131	 1	 -0.0	 0.0	 0.0	 7.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5137	 1	 16.92	 0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5144	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5146	 1	 229.9	 48.9	 0.0	 8.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5147	 1	 -0.0	 0.0	 0.0	 17.81	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5155	 1	 411.3	 168.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	5162	 1	 55.26	 0.0	 0.0	 1.05	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5163	 1	 -11.81	 -12.0	 0.0	 19.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5165	 1	 -0.0	 -0.0	 0.0	 35.06	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5170	 1	 0.0	 0.0	 0.0	 19.57	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5171	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5174	 1	 0.0	 -0.0	 0.0	 8.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5179	 1	 179.8	 5.67	 0.0	 12.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5182	 1	 0.0	 0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5188	 1	 107.9	 17.6	 0.0	 1.03	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5189	 1	 24.33	 5.8	 0.0	 13.48	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5191	 1	 67.98	 9.2	 0.0	 7.77	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5202	 1	 85.09	 13.4	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5203	 1	 221.9	 86.3	 0.0	 2.18	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5205	 1	 -0.0	 -0.0	 0.0	 2.84	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5210	 1	 347.61	 74.37	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	5212	 1	 -0.0	 0.0	 0.0	 0.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5213	 1	 246.8	 36.3	 0.0	 16.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5214	 1	 0.0	 -0.0	 0.0	 0.88	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5215	 1	 -0.0	 -0.0	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5217	 1	 12.11	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5233	 1	 -0.0	 -0.0	 0.0	 14.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5237	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5239	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5241	 1	 0.0	 -0.0	 0.0	 70.905048	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5246	 1	 0.0	 -0.0	 0.0	 1.06	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5247	 1	 0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5255	 1	 43.95	 8.5	 0.0	 29.29	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5256	 1	 91.0	 36.0	 0.0	 5.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5257	 1	 -0.0	 0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5263	 1	 0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	5266	 1	 2.2	 0.5	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5270	 1	 -0.0	 -0.0	 0.0	 7.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5271	 1	 69.18	 19.7	 0.0	 6.99	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5274	 1	 2.2	 0.5	 0.0	 1.84	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	5276	 1	 143.2	 5.9	 0.0	 5.79	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5278	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5279	 1	 158.8	 105.3	 0.0	 21.76	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5280	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5286	 1	 17.22	 5.1	 0.0	 0.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5288	 1	 -0.0	 -0.0	 0.0	 3.06	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5289	 1	 -0.0	 -0.0	 0.0	 165.34	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5290	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5295	 1	 -0.0	 -0.0	 0.0	 2.08	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	5296	 1	 16.02	 4.7	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5297	 1	 55.26	 11.0	 0.0	 7.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5299	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5300	 1	 -0.0	 -0.0	 0.0	 1.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5308	 1	 0.0	 -0.0	 0.0	 42.19206	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5311	 1	 -0.0	 -0.0	 0.0	 7.85	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	5317	 1	 293.2	 87.4	 0.0	 26.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5320	 1	 18.12	 5.9	 0.0	 1.52	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5329	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5331	 1	 -0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	5332	 1	 366.6	 57.4	 0.0	 60.78	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5333	 1	 83.59	 -7.2	 0.0	 12.95	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5334	 1	 17.52	 6.6	 0.0	 3.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5339	 1	 -16.62	 8.7	 0.0	 7.68	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5340	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5341	 1	 64.27	 17.5	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5342	 1	 32.14	 13.1	 0.0	 1.72	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5346	 1	 0.0	 0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5348	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5350	 1	 0.0	 0.0	 0.0	 28.208233	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5351	 1	 0.0	 0.0	 0.0	 3.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5354	 1	 70.18	 19.5	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5361	 1	 -0.0	 0.0	 0.0	 2.77	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5362	 1	 152.73	 -17.2	 0.0	 45.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5364	 1	 110.6	 38.1	 0.0	 0.98	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5365	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5366	 1	 66.07	 12.5	 0.0	 2.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5372	 1	 21.02	 8.0	 0.0	 13.14	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5379	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	5383	 1	 0.0	 -0.0	 0.0	 24.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5388	 1	 159.5	 42.0	 0.0	 2.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5391	 1	 57.06	 11.9	 0.0	 1.68	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5393	 1	 -0.0	 0.0	 0.0	 9.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5395	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5400	 1	 241.62	 52.78	 0.0	 0.82	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5409	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5410	 1	 69.78	 26.0	 0.0	 5.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5413	 1	 -0.0	 -0.0	 0.0	 5.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5416	 1	 0.0	 0.0	 0.0	 25.13	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	5417	 1	 32.74	 5.3	 0.0	 3.07	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5418	 1	 -0.0	 0.0	 0.0	 3.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5419	 1	 349.3	 144.3	 0.0	 0.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5420	 1	 56.96	 1.94	 0.0	 26.48	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5421	 1	 -0.0	 -0.0	 0.0	 0.92	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5423	 1	 28.63	 7.3	 0.0	 4.36	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5425	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5426	 1	 152.8	 38.0	 0.0	 1.46	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5435	 1	 103.3	 24.1	 0.0	 9.41	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5441	 1	 138.01	 34.55	 0.0	 8.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5442	 1	 -0.17	 -0.84	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5450	 1	 -0.0	 -0.0	 0.0	 1.17	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5452	 1	 82.09	 39.8	 0.0	 2.35	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	5455	 1	 -0.0	 -0.0	 0.0	 5.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5458	 1	 0.0	 0.0	 0.0	 9.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5460	 1	 -15.89	 -6.42	 0.0	 38.657071	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5461	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5463	 1	 88.4	 -5.9	 0.0	 3.32	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5464	 1	 25.23	 3.3	 0.0	 35.45	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5465	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5469	 1	 106.6	 -18.8	 0.0	 4.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5477	 1	 -0.0	 -0.0	 0.0	 18.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5481	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5482	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5486	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5488	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5490	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5494	 1	 0.0	 -0.0	 0.0	 4.69	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5500	 1	 111.5	 24.8	 0.0	 9.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5502	 1	 -0.0	 -0.0	 0.0	 0.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5509	 1	 0.0	 0.0	 0.314057	 17.296509	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	5511	 1	 67.68	 6.2	 0.0	 6.83	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5512	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5517	 1	 34.24	 -19.6	 0.0	 3.59	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	5519	 1	 0.0	 -0.0	 0.0	 1.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5522	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5525	 1	 236.33	 59.35	 0.0	 18.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5526	 1	 -8.71	 -19.54	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5529	 1	 0.0	 0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5533	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5546	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5549	 1	 30.03	 12.2	 0.0	 0.93	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5550	 1	 0.0	 -0.0	 0.0	 10.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5558	 1	 -0.0	 -0.0	 0.0	 15.17	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5559	 1	 0.0	 -0.0	 0.0	 2.66	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5562	 1	 -0.0	 0.0	 0.19855	 29.549	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	5564	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5567	 1	 0.0	 0.0	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5571	 1	 -0.0	 0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5573	 1	 0.0	 -0.0	 0.0	 2.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5574	 1	 99.7	 6.0	 0.0	 2.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5586	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5587	 1	 -0.0	 -0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	5589	 1	 0.0	 0.0	 0.0	 173.904854	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5591	 1	 118.6	 41.5	 0.0	 0.58	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5592	 1	 20.82	 7.9	 0.0	 18.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5595	 1	 168.5	 54.8	 0.0	 5.34	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5608	 1	 449.4	 14.6	 0.0	 87.31	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5610	 1	 99.5	 9.2	 0.0	 27.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5616	 1	 225.2	 35.2	 0.0	 11.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5617	 1	 38.04	 3.4	 0.0	 3.43	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5618	 1	 -0.0	 0.0	 0.0	 1.75	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5627	 1	 -0.0	 -0.0	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5630	 1	 0.0	 0.0	 0.0	 11.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5631	 1	 105.5	 31.1	 0.0	 9.63	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5641	 1	 -0.0	 -0.0	 0.0	 5.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5643	 1	 -0.0	 -0.0	 0.0	 1.1	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5648	 1	 -0.0	 -0.0	 0.0	 115.528858	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5653	 1	 96.59	 7.28	 0.0	 2.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5655	 1	 -0.21	 -1.04	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5658	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5662	 1	 185.7	 18.4	 0.0	 23.68	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5664	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5666	 1	 124.8	 34.7	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5669	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5670	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5672	 1	 139.7	 9.7	 0.0	 12.61	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5674	 1	 -536.71	 -85.76	 0.0	 34.76	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5681	 1	 198.1	 33.9	 0.0	 22.82	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5685	 1	 34.74	 16.3	 0.0	 33.38	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5686	 1	 52.26	 19.6	 0.0	 2.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5688	 1	 14.12	 5.2	 0.0	 1.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5691	 1	 195.1	 -14.2	 0.0	 12.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5695	 1	 142.8	 20.3	 0.0	 6.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5697	 1	 131.6	 33.8	 0.0	 6.55	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5699	 1	 -0.0	 0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5709	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5712	 1	 183.07	 44.65	 0.0	 2.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5720	 1	 337.6	 -15.4	 0.0	 6.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5723	 1	 141.2	 45.4	 0.0	 7.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5726	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5735	 1	 161.3	 10.04	 0.0	 4.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5738	 1	 -0.0	 -0.0	 0.0	 8.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5740	 1	 -0.0	 0.0	 0.0	 1.26	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5742	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	5743	 1	 -0.0	 0.0	 0.0	 4.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5748	 1	 -0.0	 -0.0	 0.0	 4.27	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5753	 1	 -0.0	 -0.0	 0.0	 1.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5760	 1	 0.0	 -0.0	 0.0	 41.75	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5762	 1	 0.0	 0.0	 0.0	 2.23	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	5764	 1	 99.4	 4.3	 0.0	 3.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5767	 1	 -0.0	 0.0	 0.0	 1.87	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5771	 1	 190.5	 70.9	 0.0	 21.3	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5772	 1	 -38.01	 -22.73	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5773	 1	 0.0	 0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5776	 1	 222.7	 80.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	5780	 1	 0.0	 -0.0	 0.0	 0.95	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5781	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5783	 1	 69.08	 -49.6	 0.0	 3.42	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5787	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5789	 1	 0.0	 0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5790	 1	 4.4	 1.1	 0.0	 0.41	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5792	 1	 40.95	 13.4	 0.0	 51.25	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5793	 1	 6.11	 0.0	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5797	 1	 334.1	 103.5	 0.0	 14.78	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5799	 1	 -0.0	 -0.0	 0.0	 1.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5803	 1	 0.0	 -0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5805	 1	 167.6	 -9.0	 0.0	 0.39	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	5814	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5815	 1	 5.21	 1.3	 0.0	 24.85	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	5821	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5823	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5825	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5828	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5829	 1	 155.5	 38.3	 0.0	 52.84	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5831	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5835	 1	 0.0	 0.0	 0.0	 3.32	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5836	 1	 244.09	 48.92	 0.0	 5.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5837	 1	 -0.0	 -0.0	 0.0	 132.04744	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5843	 1	 -0.0	 0.0	 0.0	 8.58	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5848	 1	 0.0	 -0.0	 0.29	 -0.42	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	5853	 1	 122.5	 38.9	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5856	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5857	 1	 78.39	 21.2	 0.0	 0.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5872	 1	 177.5	 72.5	 0.0	 46.35	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5873	 1	 0.0	 0.0	 0.0	 132.84	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5877	 1	 -0.0	 0.0	 0.0	 67.98	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5881	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5884	 1	 -0.0	 -0.0	 0.0	 68.73	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5887	 1	 6.91	 -11.1	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5888	 1	 -0.0	 -0.0	 0.0	 93.07	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5890	 1	 0.0	 -0.0	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5891	 1	 14.02	 5.5	 0.0	 3.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5892	 1	 49.86	 14.1	 0.0	 11.33	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5893	 1	 26.03	 10.6	 0.0	 2.14	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5897	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5907	 1	 186.1	 14.8	 0.0	 17.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5916	 1	 -57.59	 -30.52	 0.0	 2.45	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5918	 1	 73.83	 16.41	 0.0	 15.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5919	 1	 -0.0	 0.0	 0.0	 33.03	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5923	 1	 74.08	 10.7	 0.0	 13.55	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5926	 1	 0.0	 -0.0	 0.0	 3.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5927	 1	 -0.0	 0.0	 0.0	 1.44	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	5933	 1	 78.49	 18.5	 0.0	 6.91	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5935	 1	 -0.0	 0.0	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5940	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5944	 1	 71.88	 21.7	 0.0	 9.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5946	 1	 0.0	 -0.0	 0.0	 5.96	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5948	 1	 57.06	 13.3	 0.0	 19.18	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5949	 1	 160.7	 40.3	 0.0	 3.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5952	 1	 40.34	 15.9	 0.0	 1.31	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5957	 1	 208.06	 36.6	 0.0	 3.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5960	 1	 -0.0	 0.0	 0.0	 2.78	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5961	 1	 113.5	 11.5	 0.0	 5.53	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5970	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5971	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	5974	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5979	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	5983	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5987	 1	 24.04	 1.68	 0.0	 4.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5990	 1	 0.0	 -0.0	 0.0	 4.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5991	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5993	 1	 0.0	 -0.0	 0.0	 2.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5994	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5996	 1	 -0.0	 -0.0	 0.164188	 4.023827	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6000	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.30000	    0.70000;
	6004	 1	 0.0	 0.0	 0.0	 2.37	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	6009	 1	 20.82	 7.9	 0.0	 6.73	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6010	 1	 0.0	 0.0	 0.0	 1.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6015	 1	 -0.0	 0.0	 0.0	 25.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6017	 1	 -0.0	 0.0	 0.0	 23.15	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6022	 1	 -0.0	 -0.0	 0.0	 5.5	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6025	 1	 -0.16	 -1.92	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6028	 1	 0.0	 0.0	 0.0	 3.24	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6031	 1	 0.0	 0.0	 0.0	 2.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6036	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6038	 1	 43.55	 -20.5	 0.0	 2.53	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6039	 1	 165.9	 154.6	 0.0	 15.17	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6040	 1	 -57.46	 -30.3	 0.0	 5.4	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6041	 1	 0.0	 0.0	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6045	 1	 -0.2	 -0.98	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6047	 1	 79.49	 22.7	 0.0	 9.26	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6052	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6053	 1	 412.1	 79.3	 0.0	 7.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6057	 1	 47.65	 19.4	 0.0	 0.79	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6058	 1	 0.0	 -0.0	 0.0	 1.73	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6060	 1	 0.0	 0.0	 0.0	 80.66	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6068	 1	 0.0	 0.0	 0.0	 33.08	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6069	 1	 -0.0	 -0.0	 0.285753	 52.671068	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6071	 1	 163.5	 35.6	 0.0	 4.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6080	 1	 0.0	 0.0	 0.361	 33.735	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	6090	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6092	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6093	 1	 21.02	 12.4	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6101	 1	 103.0	 40.2	 0.0	 1.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6104	 1	 93.12	 4.99	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6110	 1	 78.59	 16.0	 0.0	 1.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6112	 1	 45.28	 15.27	 0.0	 7.88	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6114	 1	 0.0	 0.0	 0.0	 8.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6115	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6118	 1	 82.55	 30.58	 0.0	 4.26	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	6119	 1	 221.25	 72.56	 0.0	 8.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6127	 1	 -0.1	 68.5	 0.0	 17.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6131	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.30000	    0.70000;
	6132	 1	 60.67	 5.9	 0.0	 5.32	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6134	 1	 42.55	 6.5	 0.0	 3.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6135	 1	 2.2	 0.5	 0.0	 0.5	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6138	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6139	 1	 76.89	 35.1	 0.0	 1.9	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6145	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6146	 1	 0.0	 -0.0	 0.0	 3.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6149	 1	 39.05	 24.8	 0.0	 7.47	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6151	 1	 60.67	 33.2	 0.0	 0.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6153	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6163	 1	 0.0	 -0.0	 0.0	 4.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6167	 1	 152.6	 61.8	 0.0	 2.35	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6168	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6174	 1	 289.1	 84.2	 0.0	 17.34	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6178	 1	 91.0	 28.4	 0.0	 10.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6179	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6183	 1	 59.37	 12.7	 0.0	 22.18	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6186	 1	 63.07	 13.4	 0.0	 15.52	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6187	 1	 -0.0	 0.0	 0.361	 25.935	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	6188	 1	 209.9	 38.0	 0.0	 5.26	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6192	 1	 50.56	 5.9	 0.0	 10.58	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6194	 1	 0.0	 -0.0	 0.0	 3.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6199	 1	 -4.82	 -0.88	 0.0	 224.85	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6202	 1	 83.79	 33.1	 0.0	 65.16	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6203	 1	 14.02	 5.6	 0.0	 2.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6206	 1	 -7.62	 -2.52	 0.0	 33.197994	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6209	 1	 69.48	 19.7	 0.0	 22.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6218	 1	 88.8	 35.1	 0.0	 1.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6219	 1	 -0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6220	 1	 231.9	 27.6	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6224	 1	 0.0	 0.0	 0.0	 58.990785	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6231	 1	 -0.0	 0.0	 0.0	 11.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6232	 1	 49.25	 12.0	 0.0	 7.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6233	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6239	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6240	 1	 0.0	 -0.0	 0.0	 6.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6243	 1	 88.41	 34.42	 0.0	 3.45	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6244	 1	 0.0	 -0.0	 0.0	 2.44	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6246	 1	 -0.0	 0.0	 0.0	 86.73	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6252	 1	 164.7	 44.5	 0.0	 3.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6253	 1	 128.8	 29.3	 0.0	 26.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6254	 1	 0.0	 -0.0	 0.0	 9.9	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6261	 1	 75.88	 11.2	 0.0	 4.58	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6263	 1	 0.0	 -0.0	 0.0	 42.81	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6267	 1	 91.3	 18.1	 0.0	 3.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6271	 1	 3.7	 2.6	 0.0	 4.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6275	 1	 122.8	 37.2	 0.0	 37.13	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6280	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6282	 1	 -0.28	 -5.54	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	6283	 1	 0.0	 -0.0	 0.0	 18.64	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6288	 1	 25.23	 10.3	 0.0	 2.69	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6290	 1	 47.65	 20.4	 0.0	 3.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6291	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6292	 1	 186.5	 49.9	 0.0	 13.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6293	 1	 -0.0	 0.0	 0.0	 33.66	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6295	 1	 0.0	 -0.0	 0.0	 46.83	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6298	 1	 0.0	 -0.0	 0.274712	 52.929035	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	6299	 1	 -0.0	 -0.0	 0.0	 2.37	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6306	 1	 0.0	 -0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6308	 1	 0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6311	 1	 0.0	 -0.0	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6313	 1	 48.95	 14.9	 0.0	 4.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6315	 1	 95.71	 19.6	 0.0	 20.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6320	 1	 -0.2	 -1.64	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6323	 1	 116.1	 30.2	 0.0	 4.38	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6329	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6331	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6332	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6333	 1	 42.75	 4.0	 0.0	 5.41	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6337	 1	 0.0	 0.0	 0.0	 8.26	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6340	 1	 -0.0	 0.0	 0.0	 2.27	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	6342	 1	 -0.0	 0.0	 0.0	 3.25	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6344	 1	 -0.0	 0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6345	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6349	 1	 55.46	 14.1	 0.0	 0.92	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6351	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6354	 1	 0.0	 -0.0	 0.0	 47.06	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6356	 1	 44.95	 12.8	 0.0	 2.61	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6357	 1	 430.8	 107.9	 0.0	 11.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6359	 1	 74.68	 10.8	 0.0	 5.82	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6368	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6371	 1	 -0.0	 -0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6376	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6381	 1	 246.2	 119.1	 0.0	 31.72	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6382	 1	 75.43	 10.49	 0.0	 7.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6383	 1	 15.62	 5.3	 0.0	 2.17	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6384	 1	 159.9	 47.4	 0.0	 3.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6390	 1	 -0.0	 0.0	 0.0	 3.36	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	6393	 1	 93.7	 29.9	 0.0	 2.1	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6394	 1	 53.86	 -15.3	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6395	 1	 154.7	 48.2	 0.0	 5.49	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6397	 1	 0.0	 0.0	 0.0	 27.4	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6399	 1	 44.05	 18.0	 0.0	 0.88	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6405	 1	 76.48	 19.8	 0.0	 5.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6415	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6416	 1	 67.67	 16.4	 0.0	 3.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6423	 1	 -0.0	 0.0	 0.0	 2.26	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6424	 1	 -0.18	 -2.28	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6426	 1	 10.21	 3.8	 0.0	 4.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6427	 1	 83.19	 22.9	 0.0	 28.5	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6429	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6430	 1	 0.0	 -0.0	 0.0	 6.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6436	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6439	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6442	 1	 163.3	 70.3	 0.0	 5.2	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6443	 1	 43.95	 15.5	 0.0	 6.36	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6450	 1	 5.51	 2.1	 0.0	 1.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6454	 1	 -0.0	 -0.0	 0.0	 11.67	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6455	 1	 20.52	 13.3	 0.0	 0.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6456	 1	 159.4	 28.4	 0.0	 15.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6459	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6472	 1	 0.0	 -0.0	 0.0	 9.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6474	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6475	 1	 -0.0	 0.0	 0.0	 149.047157	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6477	 1	 0.0	 0.0	 0.0	 1.99	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	6478	 1	 141.2	 34.8	 0.0	 2.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6480	 1	 -0.21	 -1.04	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6484	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6486	 1	 31.74	 17.4	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6489	 1	 -0.12	 -1.74	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6490	 1	 84.59	 12.9	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6494	 1	 0.0	 -0.0	 0.0	 8.2	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6495	 1	 49.66	 12.3	 0.0	 2.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6496	 1	 0.0	 -0.0	 0.0	 24.38	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6499	 1	 -0.0	 -0.0	 0.0	 13.86	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6504	 1	 49.26	 30.9	 0.097351	 12.97086	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6510	 1	 88.2	 26.7	 0.0	 8.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6512	 1	 -0.0	 0.0	 0.0	 3.4	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6514	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6516	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6519	 1	 -0.19	 -1.94	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6521	 1	 0.0	 0.0	 0.0	 2.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6526	 1	 8.41	 2.6	 0.0	 1.77	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6532	 1	 120.69	 18.1	 0.0	 15.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6539	 1	 68.48	 22.4	 0.0	 4.38	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6540	 1	 0.9	 0.3	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6542	 1	 336.7	 -115.3	 0.0	 0.78	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	6543	 1	 118.4	 7.1	 0.0	 11.11	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6544	 1	 62.17	 0.7	 0.0	 5.98	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6552	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6555	 1	 -37.81	 -21.64	 0.0	 83.362314	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6556	 1	 -0.0	 -0.0	 0.0	 4.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6559	 1	 105.5	 35.3	 0.0	 1.23	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6561	 1	 216.0	 56.2	 0.0	 6.98	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6563	 1	 0.0	 -0.0	 0.0	 8.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6564	 1	 328.9	 -9.3	 0.0	 28.37	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6565	 1	 0.0	 -0.0	 0.0	 4.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6570	 1	 -0.0	 0.0	 0.0	 32.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6581	 1	 153.8	 23.4	 0.0	 87.73	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6582	 1	 0.0	 -0.0	 0.0	 10.15	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6596	 1	 109.1	 15.0	 0.0	 8.82	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6597	 1	 52.36	 7.4	 0.0	 26.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6600	 1	 25.83	 7.2	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6604	 1	 15.22	 7.2	 0.0	 1.81	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6607	 1	 0.0	 0.0	 0.0	 40.86	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6612	 1	 41.14	 15.25	 0.0	 3.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6616	 1	 -0.0	 -0.0	 0.0	 3.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6619	 1	 -0.0	 -0.0	 0.0	 10.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6624	 1	 -37.33	 -11.88	 0.0	 145.18	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6625	 1	 18.82	 1.7	 0.0	 6.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6629	 1	 62.63	 16.3	 0.0	 2.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6630	 1	 134.1	 24.8	 0.0	 13.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6632	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6636	 1	 -0.0	 0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6638	 1	 61.65	 10.24	 0.0	 3.48	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6639	 1	 388.04	 52.61	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6648	 1	 -26.03	 -0.84	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6654	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6656	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6659	 1	 199.6	 27.1	 0.0	 33.58	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6660	 1	 435.2	 1.3	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6662	 1	 -0.2	 -1.64	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6663	 1	 74.58	 16.6	 0.0	 2.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6664	 1	 -0.0	 0.0	 0.0	 10.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6669	 1	 132.9	 13.6	 0.0	 3.44	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6675	 1	 37.94	 7.5	 0.0	 11.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6679	 1	 0.0	 -0.0	 0.0	 2.48	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6681	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6684	 1	 -0.0	 0.0	 0.0	 9.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6687	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6691	 1	 42.55	 12.5	 0.0	 1.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6692	 1	 10.33	 3.3	 0.0	 4.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6697	 1	 309.0	 74.5	 0.0	 3.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6704	 1	 -0.0	 -0.0	 0.211099	 0.672832	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6707	 1	 119.5	 44.5	 0.0	 3.61	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6714	 1	 -0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6717	 1	 -20.82	 -8.8	 0.0	 9.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6723	 1	 0.0	 0.0	 0.0	 1.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6730	 1	 -0.0	 0.0	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6734	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6735	 1	 -0.0	 -0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6737	 1	 0.0	 -0.0	 0.0	 9.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6738	 1	 -4.91	 -2.53	 0.0	 120.576812	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6742	 1	 137.4	 23.9	 0.0	 7.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6744	 1	 244.12	 95.29	 0.0	 7.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6745	 1	 25.63	 51.6	 0.0	 2.79	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6747	 1	 0.0	 -0.0	 0.0	 75.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6749	 1	 5.91	 1.7	 0.0	 8.75	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6757	 1	 0.0	 0.0	 0.0	 6.57	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6760	 1	 4.21	 1.2	 0.0	 30.55	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	6763	 1	 0.0	 -0.0	 0.0	 5.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6766	 1	 -0.0	 0.0	 0.0	 5.12	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6768	 1	 27.53	 9.9	 0.0	 85.25	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6769	 1	 99.0	 23.2	 0.0	 10.16	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6771	 1	 -0.0	 0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6772	 1	 61.37	 23.2	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6773	 1	 0.0	 -0.0	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6783	 1	 140.1	 25.5	 0.0	 10.78	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6785	 1	 0.0	 0.0	 0.0	 8.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6791	 1	 46.35	 9.1	 0.0	 18.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6795	 1	 -73.98	 -29.8	 0.0	 17.77	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6797	 1	 42.25	 5.9	 0.0	 13.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6798	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6802	 1	 -0.0	 0.0	 0.0	 7.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6806	 1	 135.84	 15.97	 0.0	 4.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6807	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6816	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6820	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6823	 1	 36.84	 14.4	 0.0	 5.09	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6824	 1	 68.78	 28.2	 0.0	 0.26	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6826	 1	 326.9	 -82.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	6828	 1	 58.16	 16.5	 0.0	 6.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6831	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6832	 1	 -0.12	 -1.74	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6833	 1	 0.0	 0.0	 0.246363	 4.841277	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	6835	 1	 -0.15	 -1.93	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	6836	 1	 184.88	 -21.11	 0.0	 39.26	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6837	 1	 47.75	 11.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6838	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6841	 1	 122.8	 20.8	 0.0	 0.47	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6842	 1	 98.0	 21.7	 0.0	 6.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6844	 1	 -0.0	 -0.0	 0.0	 1.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6845	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6846	 1	 44.35	 19.3	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6852	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6854	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6857	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6869	 1	 54.9	 -96.8	 0.0	 16.42	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6877	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6879	 1	 199.6	 24.4	 0.0	 10.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6880	 1	 0.0	 0.0	 0.0	 1.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6882	 1	 67.47	 6.1	 0.0	 1.46	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6883	 1	 0.0	 -0.0	 0.0	 12.4	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6884	 1	 -0.12	 -1.31	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6887	 1	 -0.0	 -0.0	 0.0	 3.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6888	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6889	 1	 -12.49	 -5.83	 0.0	 6.235224	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6891	 1	 135.61	 26.86	 0.0	 1.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6897	 1	 176.8	 39.4	 0.0	 28.24	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6901	 1	 -37.84	 -19.23	 0.0	 28.140258	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6904	 1	 0.0	 0.0	 0.0	 6.97	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6908	 1	 0.0	 0.0	 0.0	 3.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6909	 1	 122.5	 8.7	 0.0	 15.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6915	 1	 11.71	 3.7	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6917	 1	 -0.0	 -0.0	 0.0	 96.89	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6921	 1	 -37.34	 -13.33	 0.0	 251.529665	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6922	 1	 113.6	 44.7	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6923	 1	 33.34	 8.6	 0.0	 3.93	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6926	 1	 124.5	 101.4	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6932	 1	 117.0	 20.4	 0.0	 22.34	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6936	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6940	 1	 0.0	 -0.0	 0.0	 10.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6947	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6949	 1	 35.44	 5.3	 0.0	 2.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6952	 1	 180.9	 33.2	 0.0	 29.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6953	 1	 61.77	 10.2	 0.0	 4.01	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6954	 1	 18.12	 10.0	 0.0	 1.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6960	 1	 389.8	 -68.1	 0.0	 5.03	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6961	 1	 56.56	 18.4	 0.0	 3.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6964	 1	 120.1	 2.5	 0.0	 6.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6969	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6970	 1	 0.0	 0.0	 0.0	 27.8	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6982	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6985	 1	 125.2	 1.2	 0.0	 15.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6987	 1	 112.1	 36.3	 0.0	 6.4	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6989	 1	 0.0	 0.0	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6990	 1	 -0.0	 0.0	 0.0	 4.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6994	 1	 0.0	 0.0	 0.0	 11.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6998	 1	 30.03	 8.6	 0.0	 21.45	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7002	 1	 51.16	 12.0	 0.0	 6.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7004	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7011	 1	 84.59	 21.7	 0.0	 7.42	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7014	 1	 0.0	 0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7018	 1	 53.26	 29.5	 0.0	 41.35	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7019	 1	 52.56	 12.8	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7021	 1	 226.8	 53.3	 0.0	 3.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7029	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7030	 1	 0.0	 0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7036	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7037	 1	 -0.0	 -0.0	 0.0	 2.77	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7041	 1	 -175.8	 -19.6	 0.0	 14.58	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7042	 1	 220.98	 91.0	 0.0	 1.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7047	 1	 339.9	 70.5	 0.0	 28.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7049	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7050	 1	 120.0	 26.0	 0.0	 22.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7051	 1	 0.0	 0.0	 0.0	 21.19	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7052	 1	 111.0	 36.6	 0.0	 2.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7053	 1	 -0.0	 0.0	 0.0	 34.13	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7056	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7058	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7059	 1	 28.93	 8.3	 0.0	 0.42	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7064	 1	 -0.0	 0.0	 0.0	 1.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7069	 1	 258.79	 42.82	 0.0	 9.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7070	 1	 142.9	 25.8	 0.0	 24.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7073	 1	 -0.0	 -0.0	 0.0	 15.47	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7075	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7076	 1	 0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7079	 1	 -0.0	 0.0	 0.0	 2.2	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7090	 1	 82.89	 41.3	 0.0	 36.2	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7092	 1	 44.65	 8.8	 0.0	 20.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7096	 1	 -0.0	 -0.0	 0.0	 57.66	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7098	 1	 0.0	 -0.0	 0.0	 7.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7104	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7110	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7115	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7117	 1	 0.0	 -0.6	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7119	 1	 149.53	 34.9	 0.0	 8.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7124	 1	 -0.0	 0.0	 0.0	 16.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7129	 1	 33.34	 5.0	 0.0	 0.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7132	 1	 222.0	 90.5	 0.0	 0.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7133	 1	 102.3	 19.0	 0.0	 1.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7136	 1	 29.23	 9.4	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7137	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7138	 1	 150.2	 51.6	 0.0	 2.79	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7139	 1	 99.4	 22.2	 0.0	 2.16	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7144	 1	 8.48	 -1.82	 0.0	 0.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7145	 1	 46.75	 24.4	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7146	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7148	 1	 -0.0	 -0.0	 0.0	 10.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7156	 1	 -0.0	 -0.0	 0.0	 14.82	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7159	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7162	 1	 -0.0	 0.0	 0.0	 2.48	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7163	 1	 -0.0	 0.0	 0.0	 2.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7164	 1	 -18.6	 -6.72	 0.0	 152.683271	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7165	 1	 -0.0	 -0.0	 0.0	 9.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7178	 1	 -0.0	 -0.0	 0.0	 2.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7180	 1	 -0.0	 0.0	 0.234234	 4.220723	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7183	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	7191	 1	 55.46	 15.7	 0.0	 13.46	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7193	 1	 -0.0	 -0.0	 0.0	 7.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7195	 1	 99.9	 19.9	 0.0	 6.19	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7196	 1	 72.68	 1.1	 0.0	 6.06	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7202	 1	 18.62	 6.1	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7209	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7222	 1	 0.0	 -0.0	 0.0	 5.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7226	 1	 144.0	 31.3	 0.0	 3.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7230	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7231	 1	 0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7235	 1	 -893.43	 260.67	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	7236	 1	 0.0	 0.0	 0.0	 1.99	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7249	 1	 37.94	 9.8	 0.0	 2.26	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7252	 1	 220.8	 68.6	 0.0	 1.97	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7253	 1	 7.51	 3.1	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7256	 1	 392.25	 92.02	 0.0	 9.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7257	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7259	 1	 82.39	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7260	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7264	 1	 0.0	 -0.0	 0.0	 3.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7266	 1	 -0.0	 -0.0	 0.0	 2.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7267	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7270	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	7273	 1	 219.6	 36.4	 0.0	 17.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7274	 1	 54.93	 16.5	 0.0	 6.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7275	 1	 79.39	 31.3	 0.0	 2.23	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7279	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	7282	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7283	 1	 101.1	 6.6	 0.0	 5.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7284	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7287	 1	 0.0	 -0.0	 0.0	 46.28	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7289	 1	 0.0	 -0.0	 0.0	 26.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7295	 1	 -0.0	 0.0	 0.0	 2.63	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7297	 1	 -0.0	 0.0	 0.0	 2.67	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7303	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7305	 1	 82.89	 32.6	 0.0	 45.84	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7309	 1	 0.0	 -0.0	 0.0	 1.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7310	 1	 256.0	 69.9	 0.0	 43.56	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7312	 1	 56.66	 15.6	 0.0	 7.45	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7316	 1	 -0.0	 0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7325	 1	 0.0	 0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7327	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7328	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7329	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7338	 1	 0.0	 -0.0	 0.0	 2.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7341	 1	 37.44	 0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7342	 1	 169.0	 70.8	 0.0	 5.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7343	 1	 -0.0	 0.0	 0.0	 61.36	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7347	 1	 101.3	 17.6	 0.0	 0.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7349	 1	 75.56	 13.04	 0.0	 8.77	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7351	 1	 61.67	 16.3	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7353	 1	 127.3	 26.7	 0.0	 7.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7358	 1	 -40.95	 -28.4	 0.0	 7.29	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	7361	 1	 -0.0	 -0.0	 0.0	 14.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7366	 1	 70.48	 22.5	 0.0	 4.82	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7367	 1	 1.5	 0.4	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7373	 1	 0.0	 -0.0	 0.0	 1.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7374	 1	 -0.2	 -0.83	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7377	 1	 0.0	 0.0	 0.0	 0.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7380	 1	 105.67	 0.56	 0.0	 18.05	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7388	 1	 0.0	 0.0	 0.0	 12.79	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	7392	 1	 142.0	 27.8	 0.0	 17.77	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7394	 1	 55.66	 22.4	 0.0	 2.11	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7395	 1	 0.0	 -0.0	 0.0	 87.69	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7396	 1	 -0.0	 0.0	 0.0	 5.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7398	 1	 100.3	 17.2	 0.0	 6.63	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7404	 1	 19.02	 5.4	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7406	 1	 94.5	 -27.8	 0.0	 5.52	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7407	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7411	 1	 -0.0	 0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	7413	 1	 33.64	 13.7	 0.0	 0.75	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7417	 1	 106.4	 19.0	 0.0	 4.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7422	 1	 65.67	 25.6	 0.0	 2.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7423	 1	 -0.0	 0.0	 0.0	 7.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7425	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7428	 1	 0.0	 -0.0	 0.0	 120.17	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7431	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7436	 1	 0.0	 -0.0	 0.0	 19.61	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7437	 1	 18.32	 5.3	 0.0	 7.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7438	 1	 121.3	 20.7	 0.0	 2.39	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7442	 1	 -0.0	 0.0	 0.0	 36.77	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7446	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7450	 1	 108.8	 28.1	 0.0	 30.9	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7460	 1	 -0.0	 -0.0	 0.0	 37.99	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7463	 1	 178.7	 31.3	 0.0	 5.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7464	 1	 197.65	 28.23	 0.0	 5.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7466	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7471	 1	 -18.95	 -6.93	 0.0	 33.11439	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7473	 1	 113.44	 71.42	 0.0	 11.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7474	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7475	 1	 84.79	 12.5	 0.0	 2.55	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7476	 1	 59.67	 27.1	 0.0	 43.03	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7480	 1	 -0.18	 -3.54	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7485	 1	 44.35	 10.8	 0.0	 8.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7491	 1	 0.0	 -0.0	 0.0	 4.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7495	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7503	 1	 -0.0	 -0.0	 0.0	 1.86	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7504	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7507	 1	 4.0	 0.8	 0.0	 17.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7508	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7509	 1	 88.0	 36.2	 0.0	 60.0	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7510	 1	 46.35	 14.9	 0.0	 20.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7513	 1	 0.0	 -0.0	 0.0	 38.549494	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7519	 1	 97.97	 31.8	 0.0	 5.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7520	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7522	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7523	 1	 -0.0	 0.0	 0.0	 2.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7525	 1	 -8.66	 -6.01	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7526	 1	 0.0	 -0.0	 0.0	 1.88	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7530	 1	 0.0	 0.0	 0.0	 31.242294	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7537	 1	 0.0	 0.0	 0.0	 17.184121	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7539	 1	 40.85	 15.7	 0.0	 2.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7541	 1	 346.42	 89.04	 0.0	 43.55	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7556	 1	 0.0	 -0.0	 0.0	 3.1	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7561	 1	 0.0	 0.0	 0.0	 20.54	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7563	 1	 531.7	 -12.8	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	7565	 1	 -0.0	 0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7569	 1	 0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	7571	 1	 -0.0	 -0.0	 0.0	 13.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7573	 1	 126.6	 28.7	 0.0	 15.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7575	 1	 29.03	 6.1	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7576	 1	 0.0	 0.0	 0.0	 0.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7577	 1	 0.0	 0.0	 0.0	 6.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7579	 1	 136.9	 11.4	 0.0	 3.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7580	 1	 0.0	 0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7582	 1	 0.0	 -0.0	 0.0	 3.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7583	 1	 5.01	 1.8	 0.0	 3.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7584	 1	 127.6	 45.3	 0.0	 57.43	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7586	 1	 -18.27	 -12.99	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7596	 1	 59.07	 23.4	 0.0	 21.88	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7599	 1	 0.0	 -0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7600	 1	 119.0	 31.7	 0.0	 1.94	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7611	 1	 115.4	 31.0	 0.0	 28.85	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7615	 1	 70.48	 17.6	 0.0	 3.92	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7624	 1	 32.74	 10.5	 0.0	 1.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7626	 1	 78.89	 45.6	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7628	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7629	 1	 0.0	 0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7630	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7632	 1	 37.94	 3.4	 0.0	 11.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7635	 1	 0.0	 0.0	 0.0	 1.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7637	 1	 0.0	 0.0	 0.29	 6.18	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7640	 1	 68.78	 35.0	 0.0	 34.52	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7641	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7644	 1	 124.1	 -30.3	 0.0	 14.26	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7647	 1	 -0.0	 -0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7653	 1	 33.94	 11.4	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7659	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7661	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7662	 1	 -0.21	 -2.37	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7663	 1	 37.14	 2.7	 0.0	 2.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7666	 1	 93.4	 27.8	 0.0	 29.52	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7669	 1	 67.08	 25.2	 0.0	 8.11	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7673	 1	 20.82	 7.9	 0.0	 42.36	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7675	 1	 66.07	 21.6	 0.0	 0.75	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7685	 1	 49.45	 6.5	 0.0	 3.53	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7688	 1	 12.71	 5.1	 0.0	 15.31	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7691	 1	 0.0	 -0.0	 0.0	 96.48	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7694	 1	 -14.96	 -4.7	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7697	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7699	 1	 -0.0	 0.0	 0.0	 19.62	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7700	 1	 66.17	 27.4	 0.0	 14.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7701	 1	 11.91	 3.5	 0.0	 0.43	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7702	 1	 -0.0	 -0.0	 0.0	 11.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7709	 1	 2.2	 0.5	 0.0	 0.58	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7726	 1	 0.0	 0.0	 0.0	 2.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7729	 1	 20.82	 6.7	 0.0	 2.25	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7736	 1	 0.0	 -0.0	 0.0	 55.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7738	 1	 31.84	 9.2	 0.0	 5.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7751	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7752	 1	 524.5	 126.0	 0.0	 7.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7755	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7761	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7762	 1	 -0.0	 0.0	 0.304243	 48.453399	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7766	 1	 78.89	 25.6	 0.0	 1.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7770	 1	 47.15	 15.5	 0.0	 9.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7772	 1	 223.6	 51.8	 0.0	 18.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7775	 1	 151.5	 7.9	 0.0	 5.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7776	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	7778	 1	 153.0	 21.5	 0.0	 28.85	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7779	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7791	 1	 -0.0	 0.0	 0.0	 1.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7792	 1	 0.0	 -0.0	 0.0	 0.46	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	7795	 1	 44.35	 5.1	 0.0	 4.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7797	 1	 -0.0	 -0.0	 0.0	 2.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7805	 1	 -0.0	 0.0	 0.0	 30.46	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7808	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7809	 1	 169.5	 27.7	 0.0	 3.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7810	 1	 0.0	 -0.0	 0.0	 43.0	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7819	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7820	 1	 127.2	 -10.7	 0.0	 7.8	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7821	 1	 179.0	 22.9	 0.0	 25.28	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7824	 1	 9.21	 3.4	 0.0	 2.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7827	 1	 137.2	 41.9	 0.101088	 13.207291	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7829	 1	 -3.2	 -7.9	 0.0	 1.95	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	7831	 1	 -17.17	 -7.1	 0.0	 57.019803	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7833	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7834	 1	 134.7	 17.5	 0.0	 4.53	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7840	 1	 -0.0	 0.0	 0.0	 2.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7842	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7844	 1	 -0.0	 0.0	 0.0	 27.39	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7845	 1	 38.64	 6.0	 0.0	 3.26	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7847	 1	 0.0	 -0.0	 0.0	 1.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7852	 1	 -3.53	 -4.62	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7856	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	7857	 1	 0.0	 0.0	 0.0	 2.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7860	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7861	 1	 178.9	 9.1	 0.0	 15.71	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7862	 1	 0.0	 0.0	 0.0	 9.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7865	 1	 84.99	 19.6	 0.0	 4.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7869	 1	 101.9	 20.0	 0.0	 22.64	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7873	 1	 -20.94	 -6.16	 0.0	 11.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7875	 1	 -0.0	 0.0	 0.0	 6.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7877	 1	 64.21	 5.59	 0.0	 2.57	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7879	 1	 73.58	 48.6	 0.0	 2.87	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	7881	 1	 -0.0	 -0.0	 0.0	 7.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7883	 1	 47.55	 17.8	 0.0	 0.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7884	 1	 35.84	 14.1	 0.0	 50.11	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7885	 1	 142.4	 20.0	 0.0	 2.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7886	 1	 162.5	 42.7	 0.0	 12.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7892	 1	 36.94	 11.0	 0.0	 0.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7895	 1	 338.7	 52.5	 0.0	 11.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7901	 1	 191.7	 6.8	 0.0	 11.58	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7903	 1	 0.0	 -0.0	 0.0	 7.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7905	 1	 347.1	 87.2	 0.0	 88.35	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7913	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7915	 1	 -0.18	 -1.31	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7918	 1	 -0.0	 -0.0	 0.0	 117.47	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7923	 1	 0.0	 -0.0	 0.0	 0.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7925	 1	 36.84	 14.1	 0.0	 33.55	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7927	 1	 2.2	 0.5	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7929	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7935	 1	 4.5	 1.1	 0.0	 12.56	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7937	 1	 56.06	 17.0	 0.0	 2.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7943	 1	 38.44	 2.0	 0.0	 0.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7945	 1	 17.92	 5.8	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7951	 1	 156.0	 60.7	 0.0	 1.52	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7955	 1	 111.6	 8.9	 0.0	 16.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7958	 1	 -0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7960	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7961	 1	 50.56	 8.1	 0.0	 8.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7965	 1	 0.0	 0.0	 0.0	 79.5	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7967	 1	 0.0	 -0.0	 0.0	 5.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7969	 1	 0.0	 -0.0	 0.2527	 79.80215	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7972	 1	 237.9	 68.5	 0.0	 5.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7973	 1	 115.7	 10.7	 0.0	 19.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7974	 1	 234.0	 13.1	 0.0	 51.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7980	 1	 233.5	 151.0	 0.0	 35.31	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7982	 1	 112.0	 19.7	 0.0	 38.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7988	 1	 -3.55	 -1.43	 0.0	 11.834121	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7989	 1	 0.0	 0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7994	 1	 11.91	 3.3	 0.0	 6.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7996	 1	 0.0	 -0.0	 0.0	 55.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7998	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7999	 1	 0.0	 -0.0	 0.0	 9.68	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8005	 1	 -0.0	 -0.0	 0.0	 16.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8007	 1	 7.91	 2.7	 0.0	 0.01	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8012	 1	 36.84	 14.1	 0.0	 17.84	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8016	 1	 23.33	 9.1	 0.0	 15.36	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8017	 1	 -0.0	 -0.0	 0.0	 8.99	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8021	 1	 14.22	 4.7	 0.0	 5.58	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8030	 1	 -0.0	 0.0	 0.0	 122.13	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8034	 1	 83.99	 6.0	 0.0	 65.12	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8035	 1	 -0.0	 0.0	 0.0	 4.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8037	 1	 0.0	 -0.0	 0.0	 5.73	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8043	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8044	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8057	 1	 69.18	 9.5	 0.0	 3.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8058	 1	 10.71	 17.7	 0.0	 10.58	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8060	 1	 0.0	 -0.0	 0.0	 9.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8066	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8068	 1	 41.74	 7.4	 0.0	 18.54	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8079	 1	 0.0	 0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8086	 1	 0.0	 0.0	 0.0	 17.69	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8087	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8088	 1	 0.0	 -0.0	 0.379958	 52.33965	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	8098	 1	 206.4	 21.0	 0.0	 8.55	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8103	 1	 39.34	 -10.7	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	8104	 1	 127.2	 40.8	 0.0	 0.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8107	 1	 68.18	 16.1	 0.0	 3.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8109	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8112	 1	 87.9	 29.3	 0.0	 1.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8114	 1	 -0.0	 0.0	 0.0	 30.39	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8124	 1	 80.49	 7.3	 0.0	 1.81	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8128	 1	 -0.0	 0.0	 0.0	 8.1	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8138	 1	 -0.0	 0.0	 0.0	 6.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8141	 1	 0.0	 0.0	 0.0	 50.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8147	 1	 303.5	 56.2	 0.0	 21.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8149	 1	 111.36	 27.44	 0.0	 2.59	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8151	 1	 0.0	 0.0	 0.0	 14.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8155	 1	 125.3	 34.6	 0.0	 4.36	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8158	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8159	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8163	 1	 76.58	 16.2	 0.0	 21.54	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8164	 1	 1.8	 0.6	 0.0	 0.43	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8165	 1	 0.0	 -0.0	 0.0	 2.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8167	 1	 -0.0	 0.0	 0.0	 1.22	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8179	 1	 -0.0	 0.0	 0.194464	 19.1468	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8180	 1	 291.6	 47.0	 0.0	 2.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8181	 1	 0.0	 -0.0	 0.210824	 6.620599	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8183	 1	 0.0	 0.0	 0.0	 2.97	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	8186	 1	 99.6	 22.9	 0.0	 15.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8189	 1	 0.0	 -0.0	 0.0	 9.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8190	 1	 0.0	 -0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8191	 1	 0.0	 0.0	 0.0	 11.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8194	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8195	 1	 -101.01	 -129.29	 0.0	 37.176703	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8197	 1	 -134.35	 -6.5	 0.0	 3.38	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8200	 1	 0.0	 -0.0	 0.0	 39.58	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8204	 1	 -0.0	 -0.0	 0.0	 0.25	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8207	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8209	 1	 83.39	 16.5	 0.0	 16.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8210	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8211	 1	 -0.0	 0.0	 0.0	 65.93	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8213	 1	 207.9	 25.4	 0.0	 1.75	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8214	 1	 58.97	 11.1	 0.0	 1.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8222	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8223	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8224	 1	 92.7	 -5.6	 0.2527	 35.620175	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	8225	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8229	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	8230	 1	 0.0	 0.0	 0.0	 59.43	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8236	 1	 118.1	 20.2	 0.0	 1.47	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8240	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8242	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8247	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8249	 1	 0.0	 0.0	 0.0	 17.8	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8250	 1	 196.1	 32.1	 0.0	 3.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8255	 1	 39.04	 13.1	 0.0	 3.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8260	 1	 0.0	 -0.0	 0.0	 10.21	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8264	 1	 0.0	 -0.0	 0.0	 65.73	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8265	 1	 40.44	 20.5	 0.0	 0.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8267	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8277	 1	 57.66	 6.1	 0.0	 1.77	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8278	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8284	 1	 -0.12	 -1.31	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8285	 1	 156.6	 16.9	 0.0	 12.26	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8288	 1	 16.02	 5.1	 0.0	 8.6	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8291	 1	 0.0	 -0.0	 0.0	 6.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8293	 1	 112.7	 14.5	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8294	 1	 14.22	 6.3	 0.0	 0.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8298	 1	 0.0	 0.0	 0.0	 14.35	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8301	 1	 59.67	 9.2	 0.0	 18.03	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8307	 1	 -0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8310	 1	 -0.0	 0.0	 0.0	 2.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8311	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8312	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8316	 1	 0.0	 0.0	 0.0	 0.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8318	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8328	 1	 82.39	 14.4	 0.0	 13.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8329	 1	 0.0	 0.0	 0.149712	 2.04987	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8331	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8334	 1	 263.96	 -98.64	 0.0	 27.848535	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8335	 1	 637.92	 139.57	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	8337	 1	 149.9	 -0.0	 0.0	 28.38	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8338	 1	 -2.3	 -3.34	 0.0	 8.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8347	 1	 -2.09	 -1.43	 0.0	 48.358243	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8352	 1	 67.27	 15.9	 0.0	 2.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8353	 1	 155.1	 39.9	 0.0	 6.37	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8356	 1	 -0.0	 -0.0	 0.0	 0.72	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8361	 1	 126.54	 29.1	 0.0	 12.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8367	 1	 77.99	 19.3	 0.0	 3.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8369	 1	 -0.0	 -0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8373	 1	 216.3	 -6.9	 0.0	 2.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8374	 1	 153.4	 86.8	 0.0	 53.98	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8378	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8380	 1	 0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8381	 1	 -0.0	 -0.0	 0.0	 17.92	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8389	 1	 72.18	 49.6	 0.0	 37.52	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8392	 1	 100.8	 32.3	 0.0	 7.16	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8393	 1	 -757.23	 63.89	 0.0	 34.18	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8396	 1	 131.7	 32.9	 0.0	 108.56	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8397	 1	 -0.0	 0.0	 0.0	 4.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8405	 1	 40.75	 12.5	 0.0	 2.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8406	 1	 0.0	 0.0	 0.0	 14.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8411	 1	 39.64	 9.6	 0.0	 1.8	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8417	 1	 266.0	 62.8	 0.0	 1.95	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8419	 1	 99.1	 -98.6	 0.0	 6.83	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8420	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	8432	 1	 -0.19	 -17.71	 0.0	 28.98	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8438	 1	 125.5	 22.5	 0.0	 9.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8439	 1	 380.8	 62.8	 0.0	 7.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8442	 1	 31.44	 12.4	 0.0	 2.89	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8448	 1	 286.1	 89.3	 0.0	 8.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8458	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8459	 1	 285.2	 83.5	 0.0	 5.6	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8463	 1	 24.13	 10.8	 0.0	 15.2	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8466	 1	 0.0	 -0.0	 0.0	 1.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8467	 1	 216.2	 75.3	 0.0	 2.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8468	 1	 21.42	 11.8	 0.0	 28.85	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8473	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8475	 1	 -0.0	 0.0	 0.0	 8.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8477	 1	 0.0	 0.0	 0.0	 2.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8478	 1	 -0.0	 0.0	 0.0	 3.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8480	 1	 0.0	 0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8483	 1	 -0.17	 -1.82	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8485	 1	 149.0	 99.8	 0.0	 9.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8486	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8487	 1	 44.45	 7.68	 0.0	 17.83	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8490	 1	 -0.19	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8492	 1	 98.6	 27.1	 0.0	 42.45	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8493	 1	 -0.0	 -0.0	 0.0	 13.01	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8494	 1	 235.97	 34.52	 0.0	 7.15	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8497	 1	 38.84	 14.2	 0.0	 3.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8504	 1	 6.41	 2.2	 0.0	 52.07	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8507	 1	 37.44	 9.1	 0.0	 7.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8508	 1	 -8.02	 -15.14	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8510	 1	 0.0	 0.0	 0.0	 8.78	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	8511	 1	 93.6	 -43.5	 0.0	 33.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8512	 1	 140.7	 10.4	 0.0	 2.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8515	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8522	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8525	 1	 -0.0	 -3.7	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8529	 1	 76.99	 -0.7	 0.0	 1.06	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8530	 1	 -0.0	 0.0	 0.0	 1.31	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8534	 1	 295.2	 39.3	 0.0	 7.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8535	 1	 72.68	 24.3	 0.0	 3.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8542	 1	 87.7	 26.0	 0.0	 47.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8546	 1	 5.01	 1.8	 0.0	 0.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8547	 1	 21.22	 9.9	 0.0	 4.64	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8560	 1	 -0.0	 0.0	 0.0	 1.11	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8561	 1	 -0.0	 -0.0	 0.0	 237.54	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8564	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8565	 1	 -0.19	 -0.92	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8568	 1	 175.7	 56.2	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8571	 1	 126.8	 21.4	 0.0	 11.43	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8574	 1	 -0.0	 0.0	 0.447839	 20.994738	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8575	 1	 89.6	 13.1	 0.0	 8.14	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8578	 1	 0.0	 -0.0	 0.0	 4.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8581	 1	 0.0	 -0.0	 0.0	 1.79	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8582	 1	 27.83	 -2.6	 0.0	 6.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8592	 1	 -0.0	 0.0	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8601	 1	 0.0	 0.0	 0.0	 1.96	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	8604	 1	 0.0	 -0.0	 0.0	 20.81	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8605	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8613	 1	 101.8	 20.2	 0.0	 0.91	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8621	 1	 -70.45	 -35.14	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8625	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8626	 1	 136.0	 36.1	 0.0	 6.07	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8627	 1	 -0.0	 0.0	 0.0	 4.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8628	 1	 277.1	 37.0	 0.0	 21.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8629	 1	 98.61	 50.3	 0.0	 0.17	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8630	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	8636	 1	 31.43	 10.6	 0.0	 1.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8642	 1	 163.2	 31.9	 0.0	 4.9	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8651	 1	 162.49	 45.11	 0.0	 5.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8653	 1	 44.55	 7.5	 0.0	 0.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8656	 1	 5.51	 1.3	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8658	 1	 38.54	 12.0	 0.0	 16.52	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8661	 1	 226.7	 39.3	 0.0	 0.99	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8662	 1	 -0.12	 -1.74	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8664	 1	 34.54	 15.4	 0.0	 29.82	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8668	 1	 69.88	 19.3	 0.0	 1.63	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8669	 1	 74.98	 10.5	 0.0	 12.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8670	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8671	 1	 62.77	 5.7	 0.0	 2.41	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8672	 1	 -0.0	 -0.0	 0.0	 28.515005	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8676	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8677	 1	 0.0	 0.0	 0.0	 2.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8683	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8689	 1	 42.65	 18.2	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8691	 1	 305.04	 77.16	 0.0	 17.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8701	 1	 82.59	 23.4	 0.0	 6.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8702	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8704	 1	 180.7	 71.8	 0.0	 2.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8706	 1	 40.34	 15.9	 0.0	 6.02	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8707	 1	 101.9	 24.3	 0.0	 8.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8710	 1	 124.5	 -6.0	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8711	 1	 0.0	 0.0	 0.0	 3.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8719	 1	 91.8	 8.3	 0.0	 2.44	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8721	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8722	 1	 -0.0	 0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8729	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8731	 1	 191.2	 16.4	 0.0	 17.99	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8732	 1	 66.27	 19.3	 0.0	 12.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8738	 1	 -0.0	 0.0	 0.0	 3.78	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8743	 1	 11.61	 7.6	 0.0	 6.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8748	 1	 279.7	 4.6	 0.0	 3.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8756	 1	 54.66	 18.6	 0.0	 3.04	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8763	 1	 0.0	 -0.0	 0.0	 215.65	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8765	 1	 -0.0	 -0.0	 0.0	 11.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8771	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8772	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8773	 1	 0.0	 -0.0	 0.0	 30.31	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8776	 1	 -0.0	 -0.0	 0.0	 6.28	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8784	 1	 100.5	 19.3	 0.0	 13.51	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8787	 1	 22.83	 8.0	 0.0	 3.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8788	 1	 143.8	 46.45	 0.0	 3.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8789	 1	 -29.73	 23.6	 0.0	 11.75	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8791	 1	 -0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8792	 1	 107.9	 35.9	 0.0	 5.48	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8795	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8804	 1	 22.02	 4.4	 0.0	 4.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8806	 1	 -0.0	 0.0	 0.0	 342.15	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8807	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8808	 1	 203.6	 19.81	 0.0	 15.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8809	 1	 101.2	 -2.9	 0.0	 0.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8814	 1	 89.9	 29.3	 0.0	 6.77	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8818	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8819	 1	 37.87	 11.59	 0.0	 1.88	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8825	 1	 0.0	 -0.0	 0.0	 44.95	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8828	 1	 0.0	 0.0	 0.0	 1.05	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8829	 1	 91.6	 27.1	 0.0	 10.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8832	 1	 0.0	 -0.0	 0.0	 2.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8834	 1	 -0.0	 0.0	 0.0	 1.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8835	 1	 113.7	 22.3	 0.0	 15.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8843	 1	 208.7	 63.0	 0.0	 3.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8846	 1	 20.82	 0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8847	 1	 -0.0	 0.0	 0.18076	 -0.881251	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8853	 1	 410.3	 91.6	 0.0	 13.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8854	 1	 69.18	 35.1	 0.0	 12.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8858	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8860	 1	 57.16	 19.7	 0.0	 22.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8861	 1	 -0.0	 0.0	 0.0	 3.95	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8862	 1	 50.96	 15.7	 0.0	 1.52	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8864	 1	 63.31	 -9.8	 0.0	 5.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8867	 1	 131.5	 12.9	 0.0	 18.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8870	 1	 -0.0	 0.0	 0.0	 129.47	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8871	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8872	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8873	 1	 0.0	 -0.0	 0.0	 1.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8874	 1	 285.2	 61.4	 0.0	 26.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8875	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8877	 1	 -0.0	 0.0	 0.0	 1.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8878	 1	 58.26	 16.9	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8879	 1	 0.0	 0.0	 0.0	 1.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8881	 1	 0.0	 0.0	 0.0	 3.86	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8882	 1	 -0.16	 -1.44	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8886	 1	 0.0	 -0.0	 0.0	 -1.392036	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8887	 1	 0.0	 0.0	 0.0	 102.70867	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8888	 1	 101.6	 4.5	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8889	 1	 -8.15	 -5.23	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8893	 1	 278.3	 33.6	 0.0	 25.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8895	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8898	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8900	 1	 3.1	 1.6	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8903	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8906	 1	 91.0	 21.0	 0.0	 11.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8913	 1	 -0.0	 0.0	 0.0	 1.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8917	 1	 59.67	 13.1	 0.0	 2.26	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8921	 1	 0.0	 0.0	 0.0	 16.37	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8926	 1	 67.08	 35.5	 0.0	 32.32	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8927	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8930	 1	 139.4	 21.2	 0.0	 6.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8931	 1	 -0.56	 -0.0	 0.0	 108.21	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8936	 1	 -0.0	 -0.0	 0.0	 3.13	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8939	 1	 186.8	 22.9	 0.0	 9.94	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8946	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8947	 1	 3.7	 0.2	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8950	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8953	 1	 516.7	 144.3	 0.0	 2.32	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8956	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8957	 1	 0.0	 0.0	 0.0	 4.39	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8961	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8963	 1	 -0.0	 0.0	 0.0	 2.78	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8964	 1	 925.91	 147.97	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	8973	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8975	 1	 0.0	 -0.0	 0.0	 11.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8976	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8977	 1	 81.29	 26.5	 0.0	 7.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8980	 1	 63.97	 12.8	 0.0	 0.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8981	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8987	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8989	 1	 88.5	 24.5	 0.0	 2.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8991	 1	 -8.49	 -17.09	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8992	 1	 -0.0	 -0.0	 0.0	 14.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8993	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8994	 1	 69.28	 31.3	 0.0	 32.76	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8997	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8998	 1	 -0.0	 0.0	 0.0	 4.08	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8999	 1	 41.15	 10.3	 0.0	 2.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9001	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9002	 1	 119.02	 12.54	 0.0	 23.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9007	 1	 73.68	 24.0	 0.0	 0.46	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9011	 1	 88.4	 25.2	 0.0	 12.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9012	 1	 25.63	 6.5	 0.0	 0.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9014	 1	 70.78	 19.6	 0.0	 8.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9018	 1	 55.46	 16.9	 0.0	 1.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9019	 1	 91.4	 18.1	 0.0	 4.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9021	 1	 152.18	 21.63	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9024	 1	 0.0	 0.0	 0.141019	 25.246	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	9025	 1	 0.0	 -0.0	 0.205903	 3.0768	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	9028	 1	 81.99	 32.2	 0.0	 7.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9029	 1	 -0.0	 -0.0	 0.0	 7.92	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9032	 1	 0.0	 -0.0	 0.0	 2.42	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	9033	 1	 76.88	 16.4	 0.0	 6.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9039	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9043	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9045	 1	 60.57	 18.9	 0.0	 1.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9049	 1	 36.84	 14.1	 0.0	 3.8	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9051	 1	 0.0	 -0.0	 0.0	 2.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9055	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9057	 1	 72.38	 23.0	 0.0	 0.28	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9059	 1	 0.0	 -0.0	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9063	 1	 -41.57	 -23.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9064	 1	 0.0	 -0.0	 0.0	 15.26	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	9065	 1	 -0.0	 -0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9066	 1	 23.26	 3.01	 0.0	 9.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9067	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9072	 1	 0.0	 -0.0	 0.0	 1.41	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9083	 1	 88.1	 36.0	 0.0	 27.89	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9091	 1	 0.0	 0.0	 0.0	 3.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9094	 1	 187.4	 72.8	 0.0	 34.95	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9097	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9101	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9106	 1	 -0.0	 0.0	 0.0	 1.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9108	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9109	 1	 0.0	 -0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9112	 1	 0.0	 -0.0	 0.0	 19.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9117	 1	 36.74	 14.1	 0.0	 16.98	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	9118	 1	 -0.22	 -3.34	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9119	 1	 -0.0	 0.0	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9120	 1	 0.0	 0.0	 0.0	 4.13	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9127	 1	 38.84	 9.6	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	9128	 1	 50.56	 8.7	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9130	 1	 245.51	 9.17	 0.0	 24.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9131	 1	 -0.0	 -0.0	 0.0	 6.62	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9136	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	9137	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9140	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9146	 1	 35.44	 11.4	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	9150	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9155	 1	 -0.0	 -0.0	 0.0	 5.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9158	 1	 54.96	 9.42	 0.0	 5.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9159	 1	 -0.0	 -0.0	 0.0	 81.15	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	9162	 1	 94.9	 40.3	 0.0	 17.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9164	 1	 7.71	 2.4	 0.0	 6.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9173	 1	 66.07	 15.6	 0.0	 5.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9174	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9176	 1	 -0.0	 0.0	 0.0	 1.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9180	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9181	 1	 2.43	 1.35	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9185	 1	 66.97	 18.6	 0.0	 18.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9189	 1	 62.57	 -61.0	 0.0	 55.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9191	 1	 -0.0	 -0.0	 0.0	 2.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9192	 1	 17.92	 23.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	9201	 1	 137.9	 25.6	 0.0	 8.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9203	 1	 627.36	 -73.13	 0.0	 27.185221	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9205	 1	 23.43	 7.3	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	9206	 1	 226.1	 88.8	 0.0	 122.78	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9213	 1	 -0.0	 -0.0	 0.0	 10.210952	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9216	 1	 103.6	 4.69	 0.0	 36.68	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9217	 1	 -0.0	 0.0	 0.0	 6.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9222	 1	 -5.15	 -2.04	 0.0	 154.446402	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9223	 1	 133.5	 24.1	 0.0	 2.92	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	9231	 1	 242.08	 59.98	 0.0	 5.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9239	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	9241	 1	 0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin
mpc.gen = [
	32	 8.1	 0.675	 5.91	 -4.56	 1.0	 100.0	 1	 16.2	 0.0; % COW
	33	 2.69	 0.595	 2.27	 -1.08	 1.0	 100.0	 1	 5.38	 0.0; % NG
	39	 20.0	 5.31	 17.76	 -7.14	 1.0	 100.0	 1	 40.0	 0.0; % NG
	51	 -46.335	 0.645	 5.48	 -4.19	 1.0	 100.0	 1	 100.0	 -192.67; % NG
	124	 666.665	 133.865	 440.32	 -172.59	 1.0	 100.0	 1	 1000.0	 333.33; % NUC
	150	 80.0	 27.275	 77.09	 -22.54	 1.0	 100.0	 1	 160.0	 0.0; % NG
	179	 -69.465	 0.46	 52.64	 -51.72	 1.0	 100.0	 1	 100.0	 -238.93; % PEL
	194	 200.0	 38.33	 130.19	 -53.53	 1.0	 100.0	 1	 300.0	 100.0; % COW
	201	 2.685	 0.6	 2.27	 -1.07	 1.0	 100.0	 1	 5.37	 0.0; % NG
	221	 -53.59	 59.31	 183.92	 -65.3	 1.0	 100.0	 1	 100.0	 -207.18; % NG
	299	 1066.665	 231.27	 721.25	 -258.71	 1.0	 100.0	 1	 1600.0	 533.33; % COW
	338	 60.0	 18.19	 55.54	 -19.16	 1.0	 100.0	 1	 120.0	 0.0; % COW
	352	 1333.335	 314.335	 926.35	 -297.68	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	389	 60.0	 19.445	 56.73	 -17.84	 1.0	 100.0	 1	 120.0	 0.0; % NG
	413	 140.0	 37.14	 124.12	 -49.84	 1.0	 100.0	 1	 280.0	 0.0; % NG
	440	 60.0	 18.36	 55.73	 -19.01	 1.0	 100.0	 1	 120.0	 0.0; % NG
	442	 23.1	 0.51	 1.95	 -0.93	 1.0	 100.0	 1	 100.0	 -53.8; % NG
	453	 270.0	 91.415	 257.23	 -74.4	 1.0	 100.0	 1	 540.0	 0.0; % COW
	489	 -21.6	 0.73	 6.28	 -4.82	 1.0	 100.0	 1	 100.0	 -143.2; % NG
	516	 400.0	 77.56	 261.79	 -106.67	 1.0	 100.0	 1	 600.0	 200.0; % COW
	564	 15.555	 -0.44	 18.47	 -19.35	 1.0	 100.0	 1	 100.0	 -68.89; % NG
	583	 -130.0	 5.425	 17.88	 -7.03	 1.0	 100.0	 1	 100.0	 -360.0; % NG
	615	 20.0	 4.65	 17.09	 -7.79	 1.0	 100.0	 1	 40.0	 0.0; % NG
	616	 320.0	 68.37	 217.9	 -81.16	 1.0	 100.0	 1	 480.0	 160.0; % COW
	618	 533.335	 106.035	 351.18	 -139.11	 1.0	 100.0	 1	 800.0	 266.67; % COW
	628	 90.0	 23.55	 78.79	 -31.69	 1.0	 100.0	 1	 180.0	 0.0; % NG
	639	 19.2	 48.31	 135.52	 -38.9	 1.0	 100.0	 1	 100.0	 -61.6; % NG
	642	 138.045	 -1.45	 90.13	 -93.03	 1.0	 100.0	 1	 276.09	 0.0; % COW
	682	 40.0	 13.855	 38.77	 -11.06	 1.0	 100.0	 1	 80.0	 0.0; % NG
	686	 35.57	 0.245	 34.75	 -34.26	 1.0	 100.0	 1	 100.0	 -28.86; % NG
	698	 200.0	 38.015	 129.94	 -53.91	 1.0	 100.0	 1	 300.0	 100.0; % NG
	709	 32.65	 0.7	 22.23	 -20.83	 1.0	 100.0	 1	 65.3	 0.0; % COW
	739	 333.335	 59.76	 212.97	 -93.45	 1.0	 100.0	 1	 500.0	 166.67; % NG
	749	 120.0	 30.925	 105.69	 -43.84	 1.0	 100.0	 1	 240.0	 0.0; % NG
	751	 150.0	 44.85	 136.94	 -47.24	 1.0	 100.0	 1	 300.0	 0.0; % NG
	757	 60.0	 13.945	 51.3	 -23.41	 1.0	 100.0	 1	 120.0	 0.0; % NG
	776	 -24.265	 5.715	 18.16	 -6.73	 1.0	 100.0	 1	 100.0	 -148.53; % NG
	778	 16.79	 1.505	 12.37	 -9.36	 1.0	 100.0	 1	 33.58	 0.0; % NG
	780	 40.0	 12.555	 37.43	 -12.32	 1.0	 100.0	 1	 80.0	 0.0; % NG
	795	 40.0	 11.855	 36.75	 -13.04	 1.0	 100.0	 1	 80.0	 0.0; % NG
	803	 -9.465	 24.245	 74.03	 -25.54	 1.0	 100.0	 1	 100.0	 -118.93; % NG
	807	 1333.335	 251.75	 864.47	 -360.97	 1.0	 100.0	 1	 2000.0	 666.67; % NG
	823	 1333.335	 314.185	 926.68	 -298.31	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	849	 8.785	 0.77	 6.45	 -4.91	 1.0	 100.0	 1	 17.57	 0.0; % PEL
	851	 100.0	 34.415	 96.64	 -27.81	 1.0	 100.0	 1	 200.0	 0.0; % NG
	858	 666.665	 134.26	 440.67	 -172.15	 1.0	 100.0	 1	 1000.0	 333.33; % NUC
	891	 1600.0	 361.75	 1097.41	 -373.91	 1.0	 100.0	 1	 2400.0	 800.0; % NUC
	913	 1133.335	 251.085	 772.11	 -269.94	 1.0	 100.0	 1	 1700.0	 566.67; % COW
	916	 150.0	 42.345	 134.45	 -49.76	 1.0	 100.0	 1	 300.0	 0.0; % NG
	930	 600.0	 130.955	 406.66	 -144.75	 1.0	 100.0	 1	 900.0	 300.0; % COW
	972	 1333.335	 321.605	 934.73	 -291.52	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	976	 53.915	 0.335	 36.02	 -35.35	 1.0	 100.0	 1	 107.83	 0.0; % COW
	1001	 60.0	 17.605	 55.02	 -19.81	 1.0	 100.0	 1	 120.0	 0.0; % COW
	1002	 100.0	 27.2	 89.55	 -35.15	 1.0	 100.0	 1	 200.0	 0.0; % NG
	1021	 -69.535	 21.055	 58.34	 -16.23	 1.0	 100.0	 1	 100.0	 -239.07; % NG
	1030	 250.0	 21.885	 71.66	 -27.89	 1.0	 100.0	 1	 400.0	 100.0; % NG
	1036	 200.0	 45.47	 137.39	 -46.45	 1.0	 100.0	 1	 300.0	 100.0; % NG
	1043	 600.0	 112.24	 387.88	 -163.4	 1.0	 100.0	 1	 900.0	 300.0; % COW
	1083	 60.0	 17.515	 54.91	 -19.88	 1.0	 100.0	 1	 120.0	 0.0; % NG
	1093	 800.0	 182.77	 550.69	 -185.15	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	1100	 40.0	 11.895	 36.8	 -13.01	 1.0	 100.0	 1	 80.0	 0.0; % NG
	1102	 -32.77	 13.23	 38.05	 -11.59	 1.0	 100.0	 1	 100.0	 -165.54; % COW
	1121	 180.0	 47.695	 158.2	 -62.81	 1.0	 100.0	 1	 360.0	 0.0; % NG
	1173	 -33.135	 0.485	 1.85	 -0.88	 1.0	 100.0	 1	 100.0	 -166.27; % NG
	1174	 20.0	 6.165	 18.61	 -6.28	 1.0	 100.0	 1	 40.0	 0.0; % COW
	1175	 450.0	 34.615	 108.35	 -39.12	 1.0	 100.0	 1	 700.0	 200.0; % COW
	1237	 1333.335	 293.585	 906.61	 -319.44	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	1241	 32.815	 0.655	 22.29	 -20.98	 1.0	 100.0	 1	 65.63	 0.0; % PEL
	1251	 800.0	 182.77	 550.69	 -185.15	 1.0	 100.0	 1	 1200.0	 400.0; % NUC
	1271	 -17.0	 0.215	 32.54	 -32.11	 1.0	 100.0	 1	 100.0	 -134.0; % COW
	1295	 -32.735	 12.02	 36.92	 -12.88	 1.0	 100.0	 1	 100.0	 -165.47; % COW
	1341	 60.0	 19.705	 57.03	 -17.62	 1.0	 100.0	 1	 120.0	 0.0; % PEL
	1354	 -114.335	 13.175	 38.08	 -11.73	 1.0	 100.0	 1	 100.0	 -328.67; % COW
	1391	 20.0	 6.285	 18.74	 -6.17	 1.0	 100.0	 1	 40.0	 0.0; % NG
	1399	 -66.4	 0.72	 11.64	 -10.2	 1.0	 100.0	 1	 100.0	 -232.8; % NG
	1409	 533.335	 93.45	 338.66	 -151.76	 1.0	 100.0	 1	 800.0	 266.67; % COW
	1422	 -17.335	 5.65	 18.09	 -6.79	 1.0	 100.0	 1	 100.0	 -134.67; % COW
	1436	 40.0	 12.815	 37.72	 -12.09	 1.0	 100.0	 1	 80.0	 0.0; % NG
	1458	 1333.335	 282.225	 895.23	 -330.78	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	1475	 600.0	 118.725	 394.45	 -157.0	 1.0	 100.0	 1	 900.0	 300.0; % COW
	1478	 40.0	 11.48	 36.4	 -13.44	 1.0	 100.0	 1	 80.0	 0.0; % NG
	1498	 2.655	 0.595	 2.25	 -1.06	 1.0	 100.0	 1	 5.31	 0.0; % PEL
	1570	 133.335	 31.835	 93.16	 -29.49	 1.0	 100.0	 1	 200.0	 66.67; % NG
	1604	 40.0	 12.745	 37.66	 -12.17	 1.0	 100.0	 1	 80.0	 0.0; % NG
	1618	 -41.065	 0.6	 21.27	 -20.07	 1.0	 100.0	 1	 100.0	 -182.13; % NG
	1642	 40.0	 12.815	 37.74	 -12.11	 1.0	 100.0	 1	 80.0	 0.0; % NG
	1680	 1333.335	 316.395	 928.89	 -296.1	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	1685	 60.0	 20.095	 57.41	 -17.22	 1.0	 100.0	 1	 120.0	 0.0; % NG
	1697	 -76.0	 0.35	 31.94	 -31.24	 1.0	 100.0	 1	 100.0	 -252.0; % NG
	1708	 666.665	 133.035	 439.37	 -173.3	 1.0	 100.0	 1	 1000.0	 333.33; % NUC
	1721	 20.0	 6.065	 18.52	 -6.39	 1.0	 100.0	 1	 40.0	 0.0; % NG
	1747	 600.0	 111.97	 387.67	 -163.73	 1.0	 100.0	 1	 900.0	 300.0; % COW
	1754	 20.53	 4.535	 16.99	 -7.92	 1.0	 100.0	 1	 41.06	 0.0; % NG
	1788	 400.0	 88.665	 272.25	 -94.92	 1.0	 100.0	 1	 600.0	 200.0; % COW
	1793	 -10.2	 9.72	 34.64	 -15.2	 1.0	 100.0	 1	 100.0	 -120.4; % NG
	1794	 1333.335	 314.335	 926.35	 -297.68	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	1808	 49.6	 36.535	 111.23	 -38.16	 1.0	 100.0	 1	 100.0	 -0.8; % NG
	1850	 16.485	 0.715	 11.52	 -10.09	 1.0	 100.0	 1	 32.97	 0.0; % NG
	1851	 15.96	 1.435	 11.76	 -8.89	 1.0	 100.0	 1	 31.92	 0.0; % PEL
	1852	 -111.2	 20.82	 58.16	 -16.52	 1.0	 100.0	 1	 100.0	 -322.4; % COW
	1888	 612.78	 120.095	 396.02	 -155.83	 1.0	 100.0	 1	 912.78	 312.78; % COW
	1890	 1066.665	 196.055	 686.73	 -294.62	 1.0	 100.0	 1	 1600.0	 533.33; % COW
	1898	 150.0	 40.93	 133.11	 -51.25	 1.0	 100.0	 1	 300.0	 0.0; % NG
	1909	 29.215	 13.785	 38.67	 -11.1	 1.0	 100.0	 1	 100.0	 -41.57; % NG
	1914	 255.755	 4.705	 160.36	 -150.95	 1.0	 100.0	 1	 472.16	 39.35; % COW
	1947	 38.65	 0.54	 2.05	 -0.97	 1.0	 100.0	 1	 100.0	 -22.7; % COW
	1959	 20.0	 5.695	 18.14	 -6.75	 1.0	 100.0	 1	 40.0	 0.0; % NG
	1999	 90.0	 25.22	 80.51	 -30.07	 1.0	 100.0	 1	 180.0	 0.0; % COW
	2030	 400.0	 73.075	 257.0	 -110.85	 1.0	 100.0	 1	 600.0	 200.0; % COW
	2035	 666.665	 135.29	 441.85	 -171.27	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	2050	 1333.335	 349.275	 962.2	 -263.65	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	2085	 100.0	 26.1	 88.39	 -36.19	 1.0	 100.0	 1	 200.0	 0.0; % NG
	2091	 20.0	 5.42	 17.88	 -7.04	 1.0	 100.0	 1	 40.0	 0.0; % NG
	2096	 800.0	 155.185	 522.74	 -212.37	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	2107	 1000.0	 202.14	 661.9	 -257.62	 1.0	 100.0	 1	 1500.0	 500.0; % COW
	2150	 400.0	 82.335	 266.17	 -101.5	 1.0	 100.0	 1	 600.0	 200.0; % NG
	2177	 -30.865	 21.045	 58.35	 -16.26	 1.0	 100.0	 1	 100.0	 -161.73; % NG
	2193	 8.06	 2.455	 7.47	 -2.56	 1.0	 100.0	 1	 16.12	 0.0; % NG
	2197	 14.475	 2.385	 19.51	 -14.74	 1.0	 100.0	 1	 100.0	 -71.05; % NG
	2206	 200.0	 45.355	 137.29	 -46.58	 1.0	 100.0	 1	 300.0	 100.0; % COW
	2225	 -5.665	 0.615	 2.27	 -1.04	 1.0	 100.0	 1	 100.0	 -111.33; % NG
	2236	 24.37	 0.58	 2.23	 -1.07	 1.0	 100.0	 1	 100.0	 -51.26; % COW
	2267	 333.335	 74.665	 228.16	 -78.83	 1.0	 100.0	 1	 500.0	 166.67; % COW
	2276	 59.65	 2.585	 41.67	 -36.5	 1.0	 100.0	 1	 119.3	 0.0; % NG
	2291	 100.0	 33.38	 95.69	 -28.93	 1.0	 100.0	 1	 200.0	 0.0; % NG
	2335	 400.0	 89.695	 273.49	 -94.1	 1.0	 100.0	 1	 600.0	 200.0; % COW
	2359	 40.0	 9.425	 34.35	 -15.5	 1.0	 100.0	 1	 80.0	 0.0; % NG
	2412	 204.545	 -0.875	 134.54	 -136.29	 1.0	 100.0	 1	 409.09	 0.0; % NG
	2421	 -163.6	 12.47	 37.39	 -12.45	 1.0	 100.0	 1	 100.0	 -427.2; % NG
	2425	 -17.0	 16.905	 54.3	 -20.49	 1.0	 100.0	 1	 100.0	 -134.0; % NG
	2426	 21.2	 3.16	 105.34	 -99.02	 1.0	 100.0	 1	 100.0	 -57.6; % NG
	2446	 1333.335	 308.445	 921.62	 -304.73	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	2460	 40.0	 13.135	 38.01	 -11.74	 1.0	 100.0	 1	 80.0	 0.0; % NG
	2468	 40.0	 13.105	 38.02	 -11.81	 1.0	 100.0	 1	 80.0	 0.0; % NG
	2481	 40.0	 14.205	 39.12	 -10.71	 1.0	 100.0	 1	 80.0	 0.0; % NG
	2489	 180.0	 50.305	 162.4	 -61.79	 1.0	 100.0	 1	 360.0	 0.0; % NG
	2517	 117.26	 0.53	 78.13	 -77.07	 1.0	 100.0	 1	 234.52	 0.0; % NG
	2550	 60.0	 20.87	 58.23	 -16.49	 1.0	 100.0	 1	 120.0	 0.0; % COW
	2572	 400.0	 92.28	 276.19	 -91.63	 1.0	 100.0	 1	 600.0	 200.0; % COW
	2600	 80.0	 26.245	 76.08	 -23.59	 1.0	 100.0	 1	 160.0	 0.0; % NG
	2627	 1333.335	 308.365	 921.52	 -304.79	 1.0	 100.0	 1	 2000.0	 666.67; % NUC
	2642	 1333.335	 235.545	 848.76	 -377.67	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	2653	 60.0	 14.57	 51.94	 -22.8	 1.0	 100.0	 1	 120.0	 0.0; % NG
	2658	 450.0	 32.645	 124.68	 -59.39	 1.0	 100.0	 1	 700.0	 200.0; % COW
	2660	 90.0	 24.46	 79.69	 -30.77	 1.0	 100.0	 1	 180.0	 0.0; % NG
	2686	 1.4	 -0.445	 69.01	 -69.9	 1.0	 100.0	 1	 100.0	 -97.2; % NG
	2719	 98.36	 6.025	 70.15	 -58.1	 1.0	 100.0	 1	 196.72	 0.0; % NG
	2764	 600.0	 141.1	 416.7	 -134.5	 1.0	 100.0	 1	 900.0	 300.0; % COW
	2786	 1333.335	 321.67	 934.81	 -291.47	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	2797	 -13.4	 26.0	 88.33	 -36.33	 1.0	 100.0	 1	 100.0	 -126.8; % COW
	2799	 80.0	 28.125	 77.91	 -21.66	 1.0	 100.0	 1	 160.0	 0.0; % NG
	2800	 800.0	 157.75	 525.34	 -209.84	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	2816	 1333.335	 314.26	 926.26	 -297.74	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	2817	 40.0	 9.93	 34.8	 -14.94	 1.0	 100.0	 1	 80.0	 0.0; % NG
	2841	 60.0	 18.61	 55.98	 -18.76	 1.0	 100.0	 1	 120.0	 0.0; % NG
	2842	 20.0	 5.725	 18.19	 -6.74	 1.0	 100.0	 1	 40.0	 0.0; % NG
	2853	 80.0	 22.275	 72.02	 -27.47	 1.0	 100.0	 1	 160.0	 0.0; % COW
	2872	 4.525	 0.385	 3.31	 -2.54	 1.0	 100.0	 1	 9.05	 0.0; % PEL
	2878	 107.43	 2.12	 72.95	 -68.71	 1.0	 100.0	 1	 214.86	 0.0; % NG
	2886	 60.0	 20.335	 57.69	 -17.02	 1.0	 100.0	 1	 120.0	 0.0; % PEL
	2896	 -98.935	 0.395	 1.52	 -0.73	 1.0	 100.0	 1	 100.0	 -297.87; % COW
	2902	 20.0	 6.735	 19.19	 -5.72	 1.0	 100.0	 1	 40.0	 0.0; % NG
	2930	 40.0	 12.35	 37.24	 -12.54	 1.0	 100.0	 1	 80.0	 0.0; % NG
	2934	 3.415	 0.3	 2.51	 -1.91	 1.0	 100.0	 1	 6.83	 0.0; % NG
	2946	 -98.065	 0.48	 1.83	 -0.87	 1.0	 100.0	 1	 100.0	 -296.13; % NG
	2985	 246.675	 25.895	 184.46	 -132.67	 1.0	 100.0	 1	 493.35	 0.0; % COW
	3018	 100.0	 27.395	 89.61	 -34.82	 1.0	 100.0	 1	 200.0	 0.0; % NG
	3028	 666.665	 135.29	 441.85	 -171.27	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	3054	 266.665	 45.305	 167.72	 -77.11	 1.0	 100.0	 1	 400.0	 133.33; % NG
	3113	 36.465	 0.7	 22.39	 -20.99	 1.0	 100.0	 1	 100.0	 -27.07; % NG
	3114	 20.0	 4.86	 17.33	 -7.61	 1.0	 100.0	 1	 40.0	 0.0; % PEL
	3133	 120.0	 39.205	 113.97	 -35.56	 1.0	 100.0	 1	 240.0	 0.0; % NG
	3134	 -40.865	 20.46	 70.25	 -29.33	 1.0	 100.0	 1	 100.0	 -181.73; % NG
	3150	 29.105	 0.78	 6.66	 -5.1	 1.0	 100.0	 1	 100.0	 -41.79; % COW
	3157	 9.205	 0.825	 6.78	 -5.13	 1.0	 100.0	 1	 18.41	 0.0; % NG
	3163	 103.43	 -0.55	 67.92	 -69.02	 1.0	 100.0	 1	 206.86	 0.0; % NG
	3183	 60.0	 16.36	 53.7	 -20.98	 1.0	 100.0	 1	 120.0	 0.0; % NG
	3205	 270.0	 77.575	 243.61	 -88.46	 1.0	 100.0	 1	 540.0	 0.0; % NG
	3218	 -21.6	 11.895	 36.79	 -13.0	 1.0	 100.0	 1	 100.0	 -143.2; % COW
	3233	 210.0	 49.68	 178.47	 -79.11	 1.0	 100.0	 1	 420.0	 0.0; % NG
	3240	 21.8	 5.43	 62.23	 -51.37	 1.0	 100.0	 1	 100.0	 -56.4; % NG
	3291	 333.335	 75.99	 229.0	 -77.02	 1.0	 100.0	 1	 500.0	 166.67; % NG
	3306	 666.665	 132.885	 439.2	 -173.43	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	3324	 32.35	 13.245	 38.13	 -11.64	 1.0	 100.0	 1	 100.0	 -35.3; % NG
	3334	 19.665	 9.535	 34.41	 -15.34	 1.0	 100.0	 1	 100.0	 -60.67; % NG
	3335	 0.0	 0.0	 99999.0	 -99999.0	 1.0	 100.0	 1	 630.0	 -630.0; % COW
	3346	 40.0	 12.17	 37.1	 -12.76	 1.0	 100.0	 1	 80.0	 0.0; % COW
	3353	 40.0	 13.295	 38.2	 -11.61	 1.0	 100.0	 1	 80.0	 0.0; % NG
	3364	 67.635	 2.875	 47.19	 -41.44	 1.0	 100.0	 1	 135.27	 0.0; % NG
	3390	 60.0	 17.2	 54.59	 -20.19	 1.0	 100.0	 1	 120.0	 0.0; % COW
	3416	 90.0	 21.155	 76.43	 -34.12	 1.0	 100.0	 1	 180.0	 0.0; % NG
	3422	 60.0	 20.845	 58.19	 -16.5	 1.0	 100.0	 1	 120.0	 0.0; % NG
	3436	 800.0	 183.04	 550.97	 -184.89	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	3492	 -197.2	 16.335	 53.75	 -21.08	 1.0	 100.0	 1	 100.0	 -494.4; % NG
	3513	 600.0	 112.24	 387.88	 -163.4	 1.0	 100.0	 1	 900.0	 300.0; % COW
	3565	 40.0	 13.93	 38.83	 -10.97	 1.0	 100.0	 1	 80.0	 0.0; % COW
	3580	 300.0	 77.17	 261.7	 -107.36	 1.0	 100.0	 1	 600.0	 0.0; % COW
	3582	 -164.535	 0.395	 52.83	 -52.04	 1.0	 100.0	 1	 100.0	 -429.07; % COW
	3584	 -8.935	 2.34	 19.8	 -15.12	 1.0	 100.0	 1	 100.0	 -117.87; % NG
	3585	 40.0	 12.555	 37.43	 -12.32	 1.0	 100.0	 1	 80.0	 0.0; % NG
	3611	 -33.6	 17.235	 54.59	 -20.12	 1.0	 100.0	 1	 100.0	 -167.2; % NG
	3621	 150.0	 37.985	 130.01	 -54.04	 1.0	 100.0	 1	 300.0	 0.0; % NG
	3629	 80.0	 27.105	 76.85	 -22.64	 1.0	 100.0	 1	 160.0	 0.0; % NG
	3644	 33.045	 0.565	 22.35	 -21.22	 1.0	 100.0	 1	 66.09	 0.0; % PEL
	3656	 32.535	 41.375	 116.07	 -33.32	 1.0	 100.0	 1	 100.0	 -34.93; % NG
	3659	 1333.335	 330.815	 943.64	 -282.01	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	3661	 666.665	 134.495	 441.04	 -172.05	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	3673	 400.0	 73.59	 257.61	 -110.43	 1.0	 100.0	 1	 600.0	 200.0; % COW
	3689	 3.1	 0.565	 2.18	 -1.05	 1.0	 100.0	 1	 6.2	 0.0; % NG
	3691	 200.0	 41.975	 133.84	 -49.89	 1.0	 100.0	 1	 300.0	 100.0; % NG
	3692	 210.0	 51.135	 180.11	 -77.84	 1.0	 100.0	 1	 420.0	 0.0; % NG
	3698	 41.61	 11.435	 36.34	 -13.47	 1.0	 100.0	 1	 100.0	 -16.78; % COW
	3711	 40.0	 13.49	 38.36	 -11.38	 1.0	 100.0	 1	 80.0	 0.0; % NG
	3723	 800.0	 146.21	 514.15	 -221.73	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	3741	 800.0	 180.705	 548.57	 -187.16	 1.0	 100.0	 1	 1200.0	 400.0; % NG
	3791	 60.0	 17.365	 54.7	 -19.97	 1.0	 100.0	 1	 120.0	 0.0; % COW
	3792	 120.0	 33.405	 108.06	 -41.25	 1.0	 100.0	 1	 240.0	 0.0; % COW
	3809	 466.665	 98.14	 313.01	 -116.73	 1.0	 100.0	 1	 700.0	 233.33; % COW
	3821	 266.665	 43.295	 165.76	 -79.17	 1.0	 100.0	 1	 400.0	 133.33; % NG
	3825	 600.0	 112.385	 388.17	 -163.4	 1.0	 100.0	 1	 900.0	 300.0; % PEL
	3840	 34.7	 0.435	 36.29	 -35.42	 1.0	 100.0	 1	 100.0	 -30.6; % NG
	3869	 666.665	 134.275	 440.69	 -172.14	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	3876	 33.265	 9.375	 34.27	 -15.52	 1.0	 100.0	 1	 100.0	 -33.47; % NG
	3916	 35.815	 13.125	 38.02	 -11.77	 1.0	 100.0	 1	 100.0	 -28.37; % COW
	3951	 31.935	 -0.7	 126.16	 -127.56	 1.0	 100.0	 1	 100.0	 -36.13; % NG
	3971	 -39.665	 18.29	 55.67	 -19.09	 1.0	 100.0	 1	 100.0	 -179.33; % NG
	3983	 200.0	 43.115	 134.98	 -48.75	 1.0	 100.0	 1	 300.0	 100.0; % NG
	3987	 40.0	 13.165	 38.05	 -11.72	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4016	 60.0	 14.905	 52.25	 -22.44	 1.0	 100.0	 1	 120.0	 0.0; % NG
	4024	 100.0	 34.815	 97.07	 -27.44	 1.0	 100.0	 1	 200.0	 0.0; % NG
	4026	 333.335	 69.685	 223.07	 -83.7	 1.0	 100.0	 1	 500.0	 166.67; % COW
	4056	 -1.265	 13.14	 38.05	 -11.77	 1.0	 100.0	 1	 100.0	 -102.53; % NG
	4084	 300.0	 80.6	 264.94	 -103.74	 1.0	 100.0	 1	 600.0	 0.0; % NG
	4118	 40.0	 13.485	 38.37	 -11.4	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4125	 40.0	 11.945	 36.89	 -13.0	 1.0	 100.0	 1	 80.0	 0.0; % PEL
	4128	 60.0	 19.7	 57.03	 -17.63	 1.0	 100.0	 1	 120.0	 0.0; % NG
	4182	 533.335	 99.42	 344.9	 -146.06	 1.0	 100.0	 1	 800.0	 266.67; % COW
	4192	 600.0	 120.695	 396.38	 -154.99	 1.0	 100.0	 1	 900.0	 300.0; % COW
	4204	 17.895	 0.49	 1.83	 -0.85	 1.0	 100.0	 1	 100.0	 -64.21; % NG
	4231	 2761.14	 0.0	 99999.0	 -99999.0	 1.0	 100.0	 1	 4188.95	 1333.33; % NUC
	4259	 20.0	 5.98	 18.41	 -6.45	 1.0	 100.0	 1	 40.0	 0.0; % NG
	4279	 400.0	 77.605	 261.6	 -106.39	 1.0	 100.0	 1	 600.0	 200.0; % COW
	4291	 210.0	 67.1	 196.08	 -61.88	 1.0	 100.0	 1	 420.0	 0.0; % NG
	4331	 40.0	 11.805	 36.73	 -13.12	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4333	 90.0	 23.82	 79.1	 -31.46	 1.0	 100.0	 1	 180.0	 0.0; % NG
	4337	 1750.0	 209.295	 576.78	 -158.19	 1.0	 100.0	 1	 2700.0	 800.0; % COW
	4338	 15.0	 4.48	 16.93	 -7.97	 1.0	 100.0	 1	 100.0	 -70.0; % NG
	4393	 200.0	 50.065	 142.0	 -41.87	 1.0	 100.0	 1	 300.0	 100.0; % COW
	4395	 -36.065	 13.575	 38.48	 -11.33	 1.0	 100.0	 1	 100.0	 -172.13; % NG
	4419	 666.665	 134.495	 441.04	 -172.05	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	4428	 30.12	 0.625	 20.49	 -19.24	 1.0	 100.0	 1	 60.24	 0.0; % PEL
	4442	 42.51	 0.345	 34.61	 -33.92	 1.0	 100.0	 1	 100.0	 -14.98; % NG
	4480	 666.665	 132.885	 439.2	 -173.43	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	4482	 40.0	 13.95	 38.85	 -10.95	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4506	 -64.535	 12.955	 37.86	 -11.95	 1.0	 100.0	 1	 100.0	 -229.07; % NG
	4566	 29.745	 13.035	 37.94	 -11.87	 1.0	 100.0	 1	 100.0	 -40.51; % NG
	4586	 -313.8	 31.575	 92.96	 -29.81	 1.0	 100.0	 1	 100.0	 -727.6; % COW
	4624	 40.0	 10.715	 35.62	 -14.19	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4657	 150.0	 48.835	 140.98	 -43.31	 1.0	 100.0	 1	 300.0	 0.0; % NG
	4661	 -2.6	 6.685	 19.14	 -5.77	 1.0	 100.0	 1	 100.0	 -105.2; % NG
	4663	 -27.335	 17.72	 55.07	 -19.63	 1.0	 100.0	 1	 100.0	 -154.67; % NG
	4690	 600.0	 142.755	 417.98	 -132.47	 1.0	 100.0	 1	 900.0	 300.0; % NUC
	4701	 140.925	 6.055	 98.4	 -86.29	 1.0	 100.0	 1	 281.85	 0.0; % NG
	4772	 100.0	 27.28	 89.54	 -34.98	 1.0	 100.0	 1	 200.0	 0.0; % NG
	4773	 32.65	 0.625	 22.15	 -20.9	 1.0	 100.0	 1	 65.3	 0.0; % NG
	4776	 600.0	 114.335	 389.83	 -161.16	 1.0	 100.0	 1	 900.0	 300.0; % COW
	4783	 666.665	 132.885	 439.2	 -173.43	 1.0	 100.0	 1	 1000.0	 333.33; % NUC
	4816	 32.615	 13.465	 38.37	 -11.44	 1.0	 100.0	 1	 100.0	 -34.77; % NG
	4819	 666.665	 134.275	 440.69	 -172.14	 1.0	 100.0	 1	 1000.0	 333.33; % NUC
	4823	 5.23	 1.185	 4.44	 -2.07	 1.0	 100.0	 1	 10.46	 0.0; % NG
	4843	 6.815	 0.595	 5.0	 -3.81	 1.0	 100.0	 1	 13.63	 0.0; % NG
	4846	 200.0	 41.975	 133.84	 -49.89	 1.0	 100.0	 1	 300.0	 100.0; % NG
	4850	 80.0	 26.665	 76.52	 -23.19	 1.0	 100.0	 1	 160.0	 0.0; % NG
	4880	 23.135	 25.83	 75.62	 -23.96	 1.0	 100.0	 1	 100.0	 -53.73; % NG
	4897	 40.0	 12.675	 37.58	 -12.23	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4918	 40.0	 12.35	 37.27	 -12.57	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4931	 51.395	 0.375	 34.39	 -33.64	 1.0	 100.0	 1	 102.79	 0.0; % COW
	4945	 333.335	 71.09	 224.4	 -82.22	 1.0	 100.0	 1	 500.0	 166.67; % COW
	4952	 41.615	 12.31	 37.23	 -12.61	 1.0	 100.0	 1	 100.0	 -16.77; % NG
	4954	 60.0	 17.1	 54.46	 -20.26	 1.0	 100.0	 1	 120.0	 0.0; % COW
	4957	 800.0	 166.135	 533.39	 -201.12	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	4967	 210.0	 53.185	 182.2	 -75.83	 1.0	 100.0	 1	 420.0	 0.0; % NG
	5004	 110.06	 2.16	 74.73	 -70.41	 1.0	 100.0	 1	 220.12	 0.0; % NG
	5019	 40.0	 12.815	 37.72	 -12.09	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5025	 -53.4	 0.675	 5.65	 -4.3	 1.0	 100.0	 1	 100.0	 -206.8; % NG
	5051	 80.0	 24.79	 74.55	 -24.97	 1.0	 100.0	 1	 160.0	 0.0; % NG
	5060	 20.34	 0.895	 14.22	 -12.43	 1.0	 100.0	 1	 40.68	 0.0; % NG
	5065	 800.0	 164.885	 532.96	 -203.19	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	5067	 300.0	 74.665	 258.91	 -109.58	 1.0	 100.0	 1	 600.0	 0.0; % COW
	5091	 180.0	 41.28	 151.81	 -69.25	 1.0	 100.0	 1	 360.0	 0.0; % NG
	5097	 14.155	 2.4	 8.91	 -4.11	 1.0	 100.0	 1	 21.23	 7.08; % NG
	5110	 14.995	 13.39	 38.28	 -11.5	 1.0	 100.0	 1	 100.0	 -70.01; % COW
	5120	 60.0	 18.965	 56.35	 -18.42	 1.0	 100.0	 1	 120.0	 0.0; % COW
	5144	 1333.335	 269.81	 882.86	 -343.24	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	5171	 -8.4	 0.3	 32.89	 -32.29	 1.0	 100.0	 1	 100.0	 -116.8; % NG
	5237	 80.0	 25.14	 75.02	 -24.74	 1.0	 100.0	 1	 160.0	 0.0; % NG
	5239	 -846.265	 0.0	 99999.0	 -99999.0	 1.0	 100.0	 1	 100.0	 -1792.53; % NG
	5278	 60.0	 13.905	 51.3	 -23.49	 1.0	 100.0	 1	 120.0	 0.0; % COW
	5280	 -79.265	 0.615	 2.29	 -1.06	 1.0	 100.0	 1	 100.0	 -258.53; % NG
	5290	 180.0	 49.125	 159.67	 -61.42	 1.0	 100.0	 1	 360.0	 0.0; % NG
	5299	 870.165	 -19.975	 542.73	 -582.68	 1.0	 100.0	 1	 1689.14	 51.19; % COW
	5329	 13.475	 0.325	 35.25	 -34.6	 1.0	 100.0	 1	 100.0	 -73.05; % NG
	5340	 -56.0	 11.47	 36.37	 -13.43	 1.0	 100.0	 1	 100.0	 -212.0; % NG
	5348	 16.37	 0.64	 11.36	 -10.08	 1.0	 100.0	 1	 32.74	 0.0; % PEL
	5365	 20.0	 5.695	 18.14	 -6.75	 1.0	 100.0	 1	 40.0	 0.0; % NG
	5379	 1333.335	 314.42	 926.47	 -297.63	 1.0	 100.0	 1	 2000.0	 666.67; % NUC
	5395	 -213.865	 20.7	 58.06	 -16.66	 1.0	 100.0	 1	 100.0	 -527.73; % NG
	5409	 120.0	 28.955	 102.6	 -44.69	 1.0	 100.0	 1	 240.0	 0.0; % NG
	5425	 120.0	 34.535	 108.27	 -39.2	 1.0	 100.0	 1	 240.0	 0.0; % COW
	5461	 40.0	 13.355	 38.26	 -11.55	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5465	 46.735	 0.165	 31.09	 -30.76	 1.0	 100.0	 1	 93.47	 0.0; % NG
	5481	 1333.335	 307.335	 920.31	 -305.64	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	5482	 124.53	 26.6	 101.32	 -48.12	 1.0	 100.0	 1	 249.06	 0.0; % NG
	5486	 666.665	 134.495	 441.04	 -172.05	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	5488	 -14.265	 12.58	 37.49	 -12.33	 1.0	 100.0	 1	 100.0	 -128.53; % NG
	5490	 2666.665	 539.345	 1765.36	 -686.67	 1.0	 100.0	 1	 4000.0	 1333.33; % NG
	5512	 80.0	 19.835	 69.67	 -30.0	 1.0	 100.0	 1	 160.0	 0.0; % NG
	5533	 100.0	 26.58	 88.87	 -35.71	 1.0	 100.0	 1	 200.0	 0.0; % NG
	5546	 20.0	 6.705	 19.16	 -5.75	 1.0	 100.0	 1	 40.0	 0.0; % NG
	5564	 40.0	 11.905	 36.8	 -12.99	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5658	 120.0	 28.465	 103.18	 -46.25	 1.0	 100.0	 1	 240.0	 0.0; % NG
	5664	 80.0	 22.83	 72.71	 -27.05	 1.0	 100.0	 1	 160.0	 0.0; % NG
	5669	 350.0	 9.565	 34.47	 -15.34	 1.0	 100.0	 1	 600.0	 100.0; % COW
	5670	 33.88	 0.635	 22.97	 -21.7	 1.0	 100.0	 1	 67.76	 0.0; % PEL
	5709	 800.0	 182.77	 550.69	 -185.15	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	5726	 47.99	 0.22	 31.98	 -31.54	 1.0	 100.0	 1	 95.98	 0.0; % NG
	5742	 56.76	 9.63	 35.69	 -16.43	 1.0	 100.0	 1	 85.14	 28.38; % NG
	5781	 1200.0	 227.25	 779.29	 -324.79	 1.0	 100.0	 1	 1800.0	 600.0; % NG
	5787	 120.0	 41.055	 114.67	 -32.56	 1.0	 100.0	 1	 240.0	 0.0; % NG
	5814	 293.335	 59.905	 196.98	 -77.17	 1.0	 100.0	 1	 440.0	 146.67; % NG
	5821	 0.53	 -0.235	 45.83	 -46.3	 1.0	 100.0	 1	 100.0	 -98.94; % NG
	5823	 333.335	 67.605	 220.75	 -85.54	 1.0	 100.0	 1	 500.0	 166.67; % NG
	5825	 350.0	 21.225	 76.5	 -34.05	 1.0	 100.0	 1	 600.0	 100.0; % COW
	5828	 19.99	 0.83	 13.93	 -12.27	 1.0	 100.0	 1	 39.98	 0.0; % NG
	5831	 -69.6	 0.42	 1.58	 -0.74	 1.0	 100.0	 1	 100.0	 -239.2; % NG
	5856	 320.0	 64.565	 214.13	 -85.0	 1.0	 100.0	 1	 480.0	 160.0; % COW
	5881	 40.0	 11.795	 36.72	 -13.13	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5940	 0.065	 4.74	 17.21	 -7.73	 1.0	 100.0	 1	 100.0	 -99.87; % COW
	5970	 180.0	 62.065	 172.47	 -48.34	 1.0	 100.0	 1	 360.0	 0.0; % NG
	5971	 1333.335	 321.45	 934.54	 -291.64	 1.0	 100.0	 1	 2000.0	 666.67; % NG
	5983	 -18.335	 12.34	 37.27	 -12.59	 1.0	 100.0	 1	 100.0	 -136.67; % COW
	5991	 800.0	 150.15	 517.55	 -217.25	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	5994	 -8.2	 -0.285	 60.51	 -61.08	 1.0	 100.0	 1	 100.0	 -116.4; % NG
	6000	 600.0	 136.225	 411.66	 -139.21	 1.0	 100.0	 1	 900.0	 300.0; % COW
	6036	 600.0	 114.62	 390.4	 -161.16	 1.0	 100.0	 1	 900.0	 300.0; % NG
	6090	 40.0	 11.675	 36.58	 -13.23	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6092	 600.0	 119.855	 395.59	 -155.88	 1.0	 100.0	 1	 900.0	 300.0; % COW
	6131	 600.0	 139.465	 415.26	 -136.33	 1.0	 100.0	 1	 900.0	 300.0; % COW
	6138	 -31.265	 4.46	 16.91	 -7.99	 1.0	 100.0	 1	 100.0	 -162.53; % NG
	6145	 120.0	 31.08	 104.76	 -42.6	 1.0	 100.0	 1	 240.0	 0.0; % NG
	6153	 401.01	 -6.085	 249.65	 -261.82	 1.0	 100.0	 1	 769.94	 32.08; % COW
	6168	 26.88	 2.465	 19.86	 -14.93	 1.0	 100.0	 1	 53.76	 0.0; % COW
	6179	 40.0	 10.51	 35.43	 -14.41	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6233	 800.0	 177.855	 545.68	 -189.97	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	6239	 2.66	 0.585	 2.24	 -1.07	 1.0	 100.0	 1	 5.32	 0.0; % PEL
	6280	 60.0	 13.88	 51.25	 -23.49	 1.0	 100.0	 1	 120.0	 0.0; % PEL
	6291	 60.0	 20.76	 58.12	 -16.6	 1.0	 100.0	 1	 120.0	 0.0; % NG
	6329	 200.0	 42.465	 134.08	 -49.15	 1.0	 100.0	 1	 300.0	 100.0; % NG
	6331	 40.0	 12.855	 37.76	 -12.05	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6332	 100.0	 34.305	 96.56	 -27.95	 1.0	 100.0	 1	 200.0	 0.0; % NG
	6351	 40.0	 13.365	 38.29	 -11.56	 1.0	 100.0	 1	 80.0	 0.0; % PEL
	6368	 -46.865	 13.825	 51.11	 -23.46	 1.0	 100.0	 1	 100.0	 -193.73; % COW
	6376	 31.465	 48.96	 148.65	 -50.73	 1.0	 100.0	 1	 100.0	 -37.07; % COW
	6415	 450.0	 22.4	 83.58	 -38.78	 1.0	 100.0	 1	 700.0	 200.0; % COW
	6429	 100.0	 26.57	 88.83	 -35.69	 1.0	 100.0	 1	 200.0	 0.0; % NG
	6436	 -7.67	 0.61	 2.26	 -1.04	 1.0	 100.0	 1	 100.0	 -115.34; % NG
	6459	 90.0	 30.96	 86.17	 -24.25	 1.0	 100.0	 1	 180.0	 0.0; % NG
	6474	 666.665	 132.285	 438.72	 -174.15	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	6484	 800.0	 140.36	 508.02	 -227.3	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	6516	 140.0	 39.45	 126.73	 -47.83	 1.0	 100.0	 1	 280.0	 0.0; % NG
	6552	 -86.135	 12.71	 37.58	 -12.16	 1.0	 100.0	 1	 100.0	 -272.27; % NG
	6632	 2000.0	 459.55	 1378.19	 -459.09	 1.0	 100.0	 1	 3000.0	 1000.0; % COW
	6654	 533.335	 91.89	 337.04	 -153.26	 1.0	 100.0	 1	 800.0	 266.67; % COW
	6656	 150.0	 39.82	 131.88	 -52.24	 1.0	 100.0	 1	 300.0	 0.0; % NG
	6681	 54.19	 0.36	 36.22	 -35.5	 1.0	 100.0	 1	 108.38	 0.0; % NG
	6734	 360.0	 89.715	 311.52	 -132.09	 1.0	 100.0	 1	 720.0	 0.0; % NUC
	6798	 666.665	 123.065	 429.61	 -183.48	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	6807	 80.0	 27.34	 77.14	 -22.46	 1.0	 100.0	 1	 160.0	 0.0; % NG
	6816	 80.0	 27.545	 77.35	 -22.26	 1.0	 100.0	 1	 160.0	 0.0; % COW
	6820	 16.265	 1.465	 11.99	 -9.06	 1.0	 100.0	 1	 32.53	 0.0; % PEL
	6831	 11.665	 10.685	 35.62	 -14.25	 1.0	 100.0	 1	 100.0	 -76.67; % COW
	6838	 400.0	 71.46	 255.23	 -112.31	 1.0	 100.0	 1	 600.0	 200.0; % COW
	6845	 60.0	 15.885	 53.24	 -21.47	 1.0	 100.0	 1	 120.0	 0.0; % NG
	6852	 -179.935	 6.11	 18.56	 -6.34	 1.0	 100.0	 1	 100.0	 -459.87; % NG
	6857	 2666.665	 639.94	 1865.83	 -585.95	 1.0	 100.0	 1	 4000.0	 1333.33; % COW
	6877	 50.255	 0.31	 33.57	 -32.95	 1.0	 100.0	 1	 100.51	 0.0; % COW
	6888	 194.335	 64.72	 189.31	 -59.87	 1.0	 100.0	 1	 300.0	 88.67; % COW
	6936	 600.0	 113.03	 388.7	 -162.64	 1.0	 100.0	 1	 900.0	 300.0; % COW
	6947	 140.0	 38.9	 126.09	 -48.29	 1.0	 100.0	 1	 280.0	 0.0; % NG
	6969	 40.0	 13.63	 38.53	 -11.27	 1.0	 100.0	 1	 80.0	 0.0; % COW
	6982	 41.6	 18.89	 56.22	 -18.44	 1.0	 100.0	 1	 100.0	 -16.8; % COW
	7029	 800.0	 140.5	 507.73	 -226.73	 1.0	 100.0	 1	 1200.0	 400.0; % NG
	7036	 40.0	 11.22	 36.16	 -13.72	 1.0	 100.0	 1	 80.0	 0.0; % NG
	7049	 60.0	 20.81	 58.18	 -16.56	 1.0	 100.0	 1	 120.0	 0.0; % NG
	7056	 400.0	 83.19	 267.36	 -100.98	 1.0	 100.0	 1	 600.0	 200.0; % COW
	7058	 40.0	 12.695	 37.59	 -12.2	 1.0	 100.0	 1	 80.0	 0.0; % NG
	7075	 17.085	 0.76	 13.41	 -11.89	 1.0	 100.0	 1	 100.0	 -65.83; % NG
	7104	 200.0	 41.365	 133.02	 -50.29	 1.0	 100.0	 1	 300.0	 100.0; % NG
	7115	 136.14	 5.86	 95.06	 -83.34	 1.0	 100.0	 1	 272.28	 0.0; % NG
	7137	 800.0	 148.43	 516.03	 -219.17	 1.0	 100.0	 1	 1200.0	 400.0; % NUC
	7159	 666.665	 134.495	 441.04	 -172.05	 1.0	 100.0	 1	 1000.0	 333.33; % NUC
	7183	 1333.335	 314.42	 926.47	 -297.63	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	7209	 3.675	 0.83	 3.12	 -1.46	 1.0	 100.0	 1	 7.35	 0.0; % NG
	7257	 53.645	 0.27	 35.77	 -35.23	 1.0	 100.0	 1	 107.29	 0.0; % NG
	7260	 21.8	 3.725	 13.73	 -6.28	 1.0	 100.0	 1	 32.7	 10.9; % NG
	7267	 23.535	 27.5	 89.84	 -34.84	 1.0	 100.0	 1	 100.0	 -52.93; % NG
	7270	 600.0	 119.37	 394.86	 -156.12	 1.0	 100.0	 1	 900.0	 300.0; % COW
	7279	 -404.465	 4.07	 14.78	 -6.64	 1.0	 100.0	 1	 100.0	 -908.93; % PEL
	7282	 2666.665	 637.065	 1862.29	 -588.16	 1.0	 100.0	 1	 4000.0	 1333.33; % COW
	7303	 600.0	 108.65	 384.34	 -167.04	 1.0	 100.0	 1	 900.0	 300.0; % COW
	7327	 80.0	 26.245	 76.11	 -23.62	 1.0	 100.0	 1	 160.0	 0.0; % NG
	7328	 40.0	 12.53	 37.45	 -12.39	 1.0	 100.0	 1	 80.0	 0.0; % NG
	7329	 40.0	 11.355	 36.26	 -13.55	 1.0	 100.0	 1	 80.0	 0.0; % NG
	7431	 600.0	 124.25	 399.88	 -151.38	 1.0	 100.0	 1	 900.0	 300.0; % COW
	7446	 20.48	 0.865	 14.28	 -12.55	 1.0	 100.0	 1	 40.96	 0.0; % PEL
	7466	 -85.02	 -0.605	 75.85	 -77.06	 1.0	 100.0	 1	 100.0	 -270.04; % COW
	7474	 60.0	 18.93	 56.27	 -18.41	 1.0	 100.0	 1	 120.0	 0.0; % COW
	7495	 125.265	 77.23	 214.23	 -59.77	 1.0	 100.0	 1	 200.0	 50.53; % NG
	7504	 2.65	 0.595	 2.24	 -1.05	 1.0	 100.0	 1	 5.3	 0.0; % NG
	7508	 600.0	 126.49	 402.15	 -149.17	 1.0	 100.0	 1	 900.0	 300.0; % NUC
	7520	 533.335	 104.815	 350.36	 -140.73	 1.0	 100.0	 1	 800.0	 266.67; % COW
	7522	 533.335	 125.72	 371.11	 -119.67	 1.0	 100.0	 1	 800.0	 266.67; % COW
	7628	 200.0	 41.87	 133.78	 -50.04	 1.0	 100.0	 1	 300.0	 100.0; % NG
	7630	 65.91	 2.675	 45.85	 -40.5	 1.0	 100.0	 1	 131.82	 0.0; % COW
	7641	 540.0	 107.93	 378.21	 -162.35	 1.0	 100.0	 1	 880.0	 200.0; % NUC
	7659	 23.665	 24.96	 74.7	 -24.78	 1.0	 100.0	 1	 100.0	 -52.67; % COW
	7661	 90.0	 21.48	 76.75	 -33.79	 1.0	 100.0	 1	 180.0	 0.0; % COW
	7697	 140.0	 39.45	 126.73	 -47.83	 1.0	 100.0	 1	 280.0	 0.0; % NG
	7755	 6.45	 0.605	 4.78	 -3.57	 1.0	 100.0	 1	 12.9	 0.0; % NG
	7761	 60.0	 15.39	 52.75	 -21.97	 1.0	 100.0	 1	 120.0	 0.0; % NG
	7776	 1333.335	 321.605	 934.73	 -291.52	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	7779	 400.0	 98.05	 281.92	 -85.82	 1.0	 100.0	 1	 600.0	 200.0; % NUC
	7808	 1333.335	 314.335	 926.35	 -297.68	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	7819	 25.77	 2.23	 18.9	 -14.44	 1.0	 100.0	 1	 51.54	 0.0; % PEL
	7833	 120.0	 31.98	 106.77	 -42.81	 1.0	 100.0	 1	 240.0	 0.0; % NG
	7842	 100.0	 27.76	 90.08	 -34.56	 1.0	 100.0	 1	 200.0	 0.0; % NG
	7860	 533.335	 135.225	 380.36	 -109.91	 1.0	 100.0	 1	 800.0	 266.67; % NUC
	7913	 1333.335	 307.415	 920.41	 -305.58	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	7929	 1066.665	 207.95	 698.07	 -282.17	 1.0	 100.0	 1	 1600.0	 533.33; % COW
	7960	 400.0	 90.49	 274.2	 -93.22	 1.0	 100.0	 1	 600.0	 200.0; % COW
	7998	 600.0	 115.31	 391.57	 -160.95	 1.0	 100.0	 1	 900.0	 300.0; % COW
	8043	 32.0	 25.855	 75.67	 -23.96	 1.0	 100.0	 1	 100.0	 -36.0; % NG
	8044	 400.0	 97.96	 281.63	 -85.71	 1.0	 100.0	 1	 600.0	 200.0; % COW
	8066	 -75.935	 0.6	 10.73	 -9.53	 1.0	 100.0	 1	 100.0	 -251.87; % NG
	8087	 210.0	 48.475	 177.22	 -80.27	 1.0	 100.0	 1	 420.0	 0.0; % NG
	8109	 520.8	 0.0	 99999.0	 -99999.0	 1.0	 100.0	 1	 1041.6	 0.0; % COW
	8158	 100.0	 29.33	 91.67	 -33.01	 1.0	 100.0	 1	 200.0	 0.0; % NG
	8159	 473.245	 77.15	 291.71	 -137.41	 1.0	 100.0	 1	 709.87	 236.62; % COW
	8207	 103.635	 1.86	 70.17	 -66.45	 1.0	 100.0	 1	 207.27	 0.0; % NG
	8210	 1066.665	 219.065	 709.44	 -271.31	 1.0	 100.0	 1	 1600.0	 533.33; % PEL
	8222	 40.0	 10.855	 35.76	 -14.05	 1.0	 100.0	 1	 80.0	 0.0; % PEL
	8223	 400.0	 92.965	 276.81	 -90.88	 1.0	 100.0	 1	 600.0	 200.0; % COW
	8225	 20.0	 7.035	 19.49	 -5.42	 1.0	 100.0	 1	 40.0	 0.0; % NG
	8240	 39.575	 0.375	 36.34	 -35.59	 1.0	 100.0	 1	 100.0	 -20.85; % NG
	8242	 210.0	 48.94	 177.81	 -79.93	 1.0	 100.0	 1	 420.0	 0.0; % NG
	8247	 180.0	 53.725	 164.3	 -56.85	 1.0	 100.0	 1	 360.0	 0.0; % NG
	8267	 120.0	 32.14	 106.84	 -42.56	 1.0	 100.0	 1	 240.0	 0.0; % NG
	8278	 60.0	 16.54	 53.88	 -20.8	 1.0	 100.0	 1	 120.0	 0.0; % NG
	8311	 44.17	 5.335	 17.8	 -7.13	 1.0	 100.0	 1	 100.0	 -11.66; % NG
	8312	 1600.0	 360.845	 1096.33	 -374.64	 1.0	 100.0	 1	 2400.0	 800.0; % COW
	8378	 20.0	 5.335	 17.78	 -7.11	 1.0	 100.0	 1	 40.0	 0.0; % NG
	8458	 666.665	 167.965	 474.42	 -138.49	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	8473	 -40.0	 27.88	 90.21	 -34.45	 1.0	 100.0	 1	 100.0	 -180.0; % NG
	8486	 40.0	 9.245	 34.16	 -15.67	 1.0	 100.0	 1	 80.0	 0.0; % NG
	8515	 100.0	 30.8	 93.03	 -31.43	 1.0	 100.0	 1	 200.0	 0.0; % NG
	8522	 -0.46	 0.96	 3.61	 -1.69	 1.0	 100.0	 1	 100.0	 -100.92; % NG
	8564	 6.665	 14.525	 51.91	 -22.86	 1.0	 100.0	 1	 100.0	 -86.67; % NG
	8605	 400.0	 90.145	 273.94	 -93.65	 1.0	 100.0	 1	 600.0	 200.0; % COW
	8625	 51.515	 0.38	 34.48	 -33.72	 1.0	 100.0	 1	 103.03	 0.0; % NG
	8630	 200.0	 32.685	 124.56	 -59.19	 1.0	 100.0	 1	 300.0	 100.0; % NG
	8670	 -42.2	 12.47	 37.4	 -12.46	 1.0	 100.0	 1	 100.0	 -184.4; % NG
	8676	 -122.735	 9.98	 34.92	 -14.96	 1.0	 100.0	 1	 100.0	 -345.47; % NG
	8683	 25.15	 16.965	 54.32	 -20.39	 1.0	 100.0	 1	 100.0	 -49.7; % NG
	8702	 180.0	 62.765	 173.2	 -47.67	 1.0	 100.0	 1	 360.0	 0.0; % NG
	8721	 1333.335	 319.77	 932.68	 -293.14	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	8729	 50.18	 2.075	 34.95	 -30.8	 1.0	 100.0	 1	 100.36	 0.0; % COW
	8771	 20.0	 6.635	 19.07	 -5.8	 1.0	 100.0	 1	 40.0	 0.0; % NG
	8795	 120.0	 36.925	 111.7	 -37.85	 1.0	 100.0	 1	 240.0	 0.0; % NG
	8807	 -152.665	 10.885	 35.84	 -14.07	 1.0	 100.0	 1	 100.0	 -405.33; % NG
	8818	 80.0	 27.06	 76.87	 -22.75	 1.0	 100.0	 1	 160.0	 0.0; % NG
	8858	 180.0	 53.465	 163.91	 -56.98	 1.0	 100.0	 1	 360.0	 0.0; % NG
	8871	 -105.865	 32.935	 106.62	 -40.75	 1.0	 100.0	 1	 100.0	 -311.73; % NG
	8872	 1333.335	 319.77	 932.68	 -293.14	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	8875	 400.0	 88.875	 272.77	 -95.02	 1.0	 100.0	 1	 600.0	 200.0; % COW
	8903	 43.365	 0.29	 28.99	 -28.41	 1.0	 100.0	 1	 86.73	 0.0; % NG
	8927	 40.0	 13.76	 38.64	 -11.12	 1.0	 100.0	 1	 80.0	 0.0; % PEL
	8946	 533.335	 93.92	 339.05	 -151.21	 1.0	 100.0	 1	 800.0	 266.67; % COW
	8950	 -120.47	 13.31	 38.23	 -11.61	 1.0	 100.0	 1	 100.0	 -340.94; % NG
	8956	 400.0	 82.335	 266.17	 -101.5	 1.0	 100.0	 1	 600.0	 200.0; % COW
	8961	 8.8	 1.57	 53.52	 -50.38	 1.0	 100.0	 1	 100.0	 -82.4; % NG
	8973	 1333.335	 245.94	 859.0	 -367.12	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	8976	 100.0	 33.35	 95.65	 -28.95	 1.0	 100.0	 1	 200.0	 0.0; % NG
	8981	 48.99	 0.24	 32.66	 -32.18	 1.0	 100.0	 1	 97.98	 0.0; % NG
	8987	 35.365	 0.88	 31.68	 -29.92	 1.0	 100.0	 1	 100.0	 -29.27; % NG
	8993	 19.21	 14.08	 38.98	 -10.82	 1.0	 100.0	 1	 100.0	 -61.58; % NG
	8997	 158.545	 3.055	 107.59	 -101.48	 1.0	 100.0	 1	 317.09	 0.0; % NG
	9001	 333.335	 67.175	 220.49	 -86.14	 1.0	 100.0	 1	 500.0	 166.67; % COW
	9039	 23.435	 0.58	 2.23	 -1.07	 1.0	 100.0	 1	 100.0	 -53.13; % NG
	9043	 42.965	 5.365	 17.82	 -7.09	 1.0	 100.0	 1	 100.0	 -14.07; % NG
	9055	 -10.0	 0.685	 11.6	 -10.23	 1.0	 100.0	 1	 100.0	 -120.0; % NG
	9067	 293.335	 60.865	 198.07	 -76.34	 1.0	 100.0	 1	 440.0	 146.67; % NG
	9097	 20.58	 4.565	 17.03	 -7.9	 1.0	 100.0	 1	 41.16	 0.0; % NG
	9101	 666.665	 136.535	 442.99	 -169.92	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	9108	 -109.485	 2.245	 18.65	 -14.16	 1.0	 100.0	 1	 100.0	 -318.97; % NG
	9137	 64.235	 121.365	 335.96	 -93.23	 1.0	 100.0	 1	 100.0	 28.47; % NG
	9140	 25.2	 23.355	 73.19	 -26.48	 1.0	 100.0	 1	 100.0	 -49.6; % COW
	9150	 666.665	 133.05	 439.38	 -173.28	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	9174	 -170.935	 62.92	 175.0	 -49.16	 1.0	 100.0	 1	 100.0	 -441.87; % NG
	9180	 80.0	 27.86	 77.69	 -21.97	 1.0	 100.0	 1	 160.0	 0.0; % NG
	9239	 400.0	 90.49	 274.2	 -93.22	 1.0	 100.0	 1	 600.0	 200.0; % COW
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.000000	  31.541850	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.788873	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.259135	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.222557	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.831746	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  25.158881	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.683605	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.731624	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.098373	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.353439	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.318110	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.918182	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.155789	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.145150	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.581832	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.078298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.164131	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.398785	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.315499	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.195140	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.524070	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.923969	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.942796	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.475733	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.179463	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.911222	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.661481	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.681820	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  56.690369	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.564121	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.862119	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.565617	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.265658	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.325968	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.016818	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.596808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.251545	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  62.738660	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.860505	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.156019	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.367631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.285403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.055608	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 115.760204	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.133068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.784258	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   7.557856	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  22.295268	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.168853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.568495	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.176607	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.909096	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.099784	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.652520	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.885807	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.278757	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.754235	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.567138	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.298140	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.637713	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.292757	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.809839	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.054880	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.867485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.860848	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.771301	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.572045	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.349398	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   7.313398	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  10.055947	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.069051	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 129.259362	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  13.896074	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.444798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.368173	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.858522	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.312819	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.704584	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.939041	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.301527	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.727593	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.851404	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.853594	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.267518	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.330172	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.389860	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.363807	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.469484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.834657	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.733122	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  37.980462	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.052280	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.236093	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.731964	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.519412	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.770291	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.803437	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.721650	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.609781	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.073148	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.769285	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.282484	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  57.546543	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.412877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.272721	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.809671	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.454440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.547352	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.651844	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.064945	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.889236	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.995576	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.958470	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.208096	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.557393	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.723795	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.384640	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.188814	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.590276	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.374446	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.112308	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.809591	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.889109	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.786739	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.514751	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.227207	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.676397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.513954	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.282341	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.243993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.757817	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.302912	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.969144	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.333446	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.622306	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.097854	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.287736	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.094528	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.174469	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.769063	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.339046	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  27.607326	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.721585	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.668915	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.758357	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.825286	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.646661	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.067232	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.970659	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.921934	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.600653	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.376379	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.029629	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.308365	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.592384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.166446	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.631872	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 117.318042	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.823604	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.595784	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.828949	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.966792	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.786891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.897676	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.317995	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.388353	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.747682	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.910533	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.291461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.666185	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.786992	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.144391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.513908	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.995910	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.130245	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.092327	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.920229	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.214411	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.360129	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.605840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.601319	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.162113	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.943738	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.885950	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.568533	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.464531	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.699122	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.589241	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.010324	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.863182	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.344902	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.380987	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.694497	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.352738	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.157455	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.945828	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.065550	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.460222	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.347023	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.260292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.306877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.255721	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.776151	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.536936	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.627918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.452118	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.787417	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.780031	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.269555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.165825	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.593364	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.960075	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.061655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.870464	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.473786	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.210079	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.025976	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.168828	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.348974	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.528425	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.398571	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.210931	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.654176	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.437260	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.080298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.104540	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.152712	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.844146	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.436756	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.966178	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.383703	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.896920	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.061933	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.480880	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.547716	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.515426	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.362324	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.295391	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.370740	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.674161	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  26.704298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.327940	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.801994	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.283179	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.003024	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.881293	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.042676	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.597539	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.444784	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.218081	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 100.759630	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   6.276527	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.437866	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.786287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.004615	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.040493	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.957522	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.722698	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.052024	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.070565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.776075	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.972941	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  44.623171	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.688233	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.021694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.972427	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.483027	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  48.699610	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.618594	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  36.357673	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.332990	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.950891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.153908	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.444806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.319930	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.013495	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.323342	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.960693	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.383838	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.652438	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.298973	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.975567	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.453155	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.252199	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.062049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.982867	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.284791	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.911091	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.753691	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.832039	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.585816	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.486853	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.404442	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.383807	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.555041	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.969995	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.302538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.434553	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.822683	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.366440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.092760	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.608085	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.002639	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.051879	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  54.552713	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.167338	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  37.135968	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.190497	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.714206	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.539791	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.781481	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.507897	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.909441	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.517926	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.910451	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.821367	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.887224	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.475536	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.477403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.323265	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.354186	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.305101	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.808633	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 113.091631	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.985521	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.246608	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.234330	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.869603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.077711	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.178823	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.867127	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.730736	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.044308	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.915480	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.800154	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.637750	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.987850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.420686	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.688002	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.459539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.308237	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.024487	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.381969	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.313945	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.820301	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.835562	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.482629	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.783710	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.854627	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.188662	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.388942	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.301832	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.838185	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.017097	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 115.541502	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  92.234145	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.618812	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.105510	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.133914	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.089619	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.205747	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.555640	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.396463	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.676121	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.509699	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.524708	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.526600	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.922739	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.400485	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.912316	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.937053	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.814255	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.075220	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.053385	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.487551	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.772041	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  26.178311	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.942146	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.153476	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.126651	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   9.798002	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.732007	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.513631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.889369	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.301824	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.790039	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.442331	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.253885	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.029363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.880819	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.642644	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.770207	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.566850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.256398	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.329280	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.551290	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.581514	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.228343	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.195777	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.060734	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   7.118640	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  15.691331	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  55.812566	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.216163	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.536925	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.176487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.447289	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 113.700175	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.307251	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.282330	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.733236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.134624	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.705672	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.965343	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  92.775990	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.682751	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.994930	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.806473	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.312797	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.724389	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  14.324733	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.889861	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.127154	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.129130	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.363583	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  23.050827	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.551462	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.945447	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.544507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.737296	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.010779	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.976982	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  24.660098	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 104.749093	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.797390	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.289824	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.505292	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  23.564868	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.188047	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.394727	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.640640	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.948544	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.566498	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.916968	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.519690	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.010401	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.504205	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.591181	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.512426	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.497763	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.347715	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.016432	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.630104	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.909843	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.909468	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.603980	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.335991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.796323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.111751	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.601616	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.181065	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.813916	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.539512	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.791157	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.920838	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.214876	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.883002	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.886561	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.242523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.642634	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.078214	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.814053	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.970070	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.678842	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.286309	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.181151	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.985405	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.393251	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.110271	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.588208	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.377417	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.583151	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.430403	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.165409	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.612469	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.353390	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.011452	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.253073	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.240061	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.005074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.621066	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.635438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.059844	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.569068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.899843	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.979363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.059413	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.369052	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.073036	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.597630	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.601524	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.457267	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.802402	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.192118	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.170558	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.495290	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.866259	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.972183	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.504452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.051288	   0.000000; % COW
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	5147	 3097	 0.0006	 0.00616	 0.0	 823.0	 5104	 5104	 0.0	 0.0	 1	 -30.0	 30.0;
	5147	 8763	 0.0005	 0.0074	 0.0	 921.0	 4259	 4259	 0.0	 0.0	 1	 -30.0	 30.0;
	427	 5425	 7e-05	 0.00057	 0.0	 1711.0	 55004	 55004	 0.0	 0.0	 1	 -30.0	 30.0;
	427	 4704	 6e-05	 0.00056	 0.0	 1514.0	 56085	 56085	 0.0	 0.0	 1	 -30.0	 30.0;
	5960	 7431	 0.003349	 0.01656	 0.0	 1870	 1870	 1870	 0.0	 0.0	 1	 -30.0	 30.0;
	5960	 3186	 0.003409	 0.016211	 0.0	 1907	 1907	 1907	 0.0	 0.0	 1	 -30.0	 30.0;
	4481	 7431	 0.003479	 0.01586	 0.0	 1946	 1946	 1946	 0.0	 0.0	 1	 -30.0	 30.0;
	4481	 3186	 0.003099	 0.017969	 0.0	 1733	 1733	 1733	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 7833	 0.00236	 0.01418	 0.0	 553.0	 2198	 2198	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 7770	 0.002169	 0.015909	 0.0	 514.0	 1968	 1968	 0.0	 0.0	 1	 -30.0	 30.0;
	5773	 6542	 0.00014	 0.0012	 0.0	 26146	 26146	 26146	 0.0	 0.0	 1	 -30.0	 30.0;
	5773	 7840	 0.000211	 0.001539	 0.0	 20335	 20335	 20335	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 6542	 0.000401	 0.004901	 0.0	 6424	 6424	 6424	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 7840	 0.000219	 0.00151	 0.0	 533.0	 20703	 20703	 0.0	 0.0	 1	 -30.0	 30.0;
	2971	 6069	 0.00052	 0.00407	 0.0	 1481.0	 7699	 7699	 0.0	 0.0	 1	 -30.0	 30.0;
	2971	 3445	 0.00034	 0.00502	 0.0	 1843.0	 6278	 6278	 0.0	 0.0	 1	 -30.0	 30.0;
	7561	 6069	 0.00065	 0.00698	 0.0	 1711.0	 4506	 4506	 0.0	 0.0	 1	 -30.0	 30.0;
	7561	 8825	 0.00059	 0.00806	 0.0	 1678.0	 3909	 3909	 0.0	 0.0	 1	 -30.0	 30.0;
	7556	 7058	 0.00374	 0.02095	 0.0	 800.0	 1485	 1485	 0.0	 0.0	 1	 -30.0	 30.0;
	7556	 4324	 0.00511	 0.019461	 0.0	 800.0	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	132	 2962	 0.00064	 0.00715	 0.0	 1481.0	 4401	 4401	 0.0	 0.0	 1	 -30.0	 30.0;
	132	 4393	 0.00089	 0.00712	 0.0	 1283.0	 4403	 4403	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 693	 0.00048	 0.00555	 0.0	 987.0	 5671	 5671	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 7860	 0.00047	 0.00566	 0.0	 1086.0	 5562	 5562	 0.0	 0.0	 1	 -30.0	 30.0;
	6883	 693	 0.00046	 0.00524	 0.0	 1053.0	 6006	 6006	 0.0	 0.0	 1	 -30.0	 30.0;
	6883	 7860	 0.00052	 0.00514	 0.0	 1053.0	 6115	 6115	 0.0	 0.0	 1	 -30.0	 30.0;
	6494	 4945	 0.00029	 0.00298	 0.0	 1613.0	 10550	 10550	 0.0	 0.0	 1	 -30.0	 30.0;
	6494	 6080	 0.0003	 0.00291	 0.0	 1514.0	 10798	 10798	 0.0	 0.0	 1	 -30.0	 30.0;
	7146	 7388	 0.00042	 0.02666	 0.0	 1185.0	 1185	 1185	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 5239	 0.00058	 0.00534	 0.0	 1876.0	 5881	 5881	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 3145	 0.00054	 0.00589	 0.0	 1843.0	 5341	 5341	 0.0	 0.0	 1	 -30.0	 30.0;
	3615	 8731	 0.00036	 0.00485	 0.0	 6495	 6495	 6495	 0.0	 0.0	 1	 -30.0	 30.0;
	3615	 6246	 0.00042	 0.00415	 0.0	 7573	 7573	 7573	 0.0	 0.0	 1	 -30.0	 30.0;
	2549	 7829	 0.003349	 0.02445	 0.0	 553.0	 1280	 1280	 0.0	 0.0	 1	 -30.0	 30.0;
	2549	 4951	 0.003281	 0.02493	 0.0	 553.0	 1257	 1257	 0.0	 0.0	 1	 -30.0	 30.0;
	7004	 3370	 0.0	 0.00046	 0.0	 757.0	 68669	 68669	 0.0	 0.0	 1	 -30.0	 30.0;
	8381	 4795	 0.00053	 0.00587	 0.0	 1777.0	 5360	 5360	 0.0	 0.0	 1	 -30.0	 30.0;
	8381	 5562	 0.00055	 0.00666	 0.0	 1711.0	 4727	 4727	 0.0	 0.0	 1	 -30.0	 30.0;
	3409	 1716	 0.00051	 0.00614	 0.0	 5127	 5127	 5127	 0.0	 0.0	 1	 -30.0	 30.0;
	3409	 6246	 0.00043	 0.00406	 0.0	 7737	 7737	 7737	 0.0	 0.0	 1	 -30.0	 30.0;
	1000	 6145	 0.002211	 0.014419	 0.0	 438.0	 2166	 2166	 0.0	 0.0	 1	 -30.0	 30.0;
	1000	 3186	 0.002169	 0.013349	 0.0	 457.0	 2336	 2336	 0.0	 0.0	 1	 -30.0	 30.0;
	6060	 5289	 0.00033	 0.00101	 0.0	 823.0	 29729	 29729	 0.0	 0.0	 1	 -30.0	 30.0;
	7965	 5289	 0.00028	 0.00104	 0.0	 757.0	 29329	 29329	 0.0	 0.0	 1	 -30.0	 30.0;
	4363	 4507	 0.00057	 0.0071	 0.0	 1613.0	 4435	 4435	 0.0	 0.0	 1	 -30.0	 30.0;
	4363	 6246	 0.00057	 0.00697	 0.0	 1613.0	 4517	 4517	 0.0	 0.0	 1	 -30.0	 30.0;
	425	 7526	 0.0001	 0.00119	 0.0	 1810.0	 26451	 26451	 0.0	 0.0	 1	 -30.0	 30.0;
	425	 5674	 0.0001	 0.0013	 0.0	 1613.0	 24227	 24227	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 8581	 9e-05	 0.00121	 0.0	 1514.0	 26034	 26034	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 4337	 0.0001	 0.00134	 0.0	 1251.0	 23508	 23508	 0.0	 0.0	 1	 -30.0	 30.0;
	4968	 2154	 0.00039	 0.00474	 0.0	 1843.0	 6642	 6642	 0.0	 0.0	 1	 -30.0	 30.0;
	4968	 1747	 0.00045	 0.00467	 0.0	 1448.0	 6733	 6733	 0.0	 0.0	 1	 -30.0	 30.0;
	7699	 2154	 0.00052	 0.00567	 0.0	 1645.0	 5548	 5548	 0.0	 0.0	 1	 -30.0	 30.0;
	7699	 1689	 0.00054	 0.00667	 0.0	 1316.0	 4721	 4721	 0.0	 0.0	 1	 -30.0	 30.0;
	3097	 659	 0.00073	 0.00905	 0.0	 1185.0	 3480	 3480	 0.0	 0.0	 1	 -30.0	 30.0;
	9024	 4929	 0.00192	 0.02296	 0.0	 889.0	 1371	 1371	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 6542	 0.01431	 0.05899	 0.0	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	6542	 1445	 0.02607	 0.07168	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 6833	 0.00054	 0.00465	 0.0	 1580.0	 6748	 6748	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 2268	 0.00126	 0.01124	 0.0	 1613.0	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 7180	 0.00048	 0.00527	 0.0	 1547.0	 5970	 5970	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 6293	 0.00082	 0.00938	 0.0	 1580.0	 3355	 3355	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 9192	 0.00028	 0.003502	 0.0	 8992	 8992	 8992	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 3493	 0.691467	 4.414711	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 955	 0.02004	 0.0916	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 228	 0.841911	 4.768444	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 6826	 0.026	 0.08948	 0.0	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 8964	 0.002631	 0.011889	 0.0	 299.0	 2595	 2595	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 5776	 0.7232	 1.944	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	9192	 955	 0.156169	 0.546756	 0.0	 56	 56	 56	 0.0	 0.0	 1	 -30.0	 30.0;
	9192	 6826	 0.168809	 0.580622	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	9192	 8964	 0.019222	 0.068209	 0.0	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	8574	 1616	 0.00039	 0.00386	 0.0	 1415.0	 8142	 8142	 0.0	 0.0	 1	 -30.0	 30.0;
	8574	 1163	 0.00096	 0.01138	 0.0	 1448.0	 2766	 2766	 0.0	 0.0	 1	 -30.0	 30.0;
	8574	 9064	 0.00037	 0.00325	 0.0	 1415.0	 9657	 9657	 0.0	 0.0	 1	 -30.0	 30.0;
	8574	 8921	 0.00029	 0.00339	 0.0	 1580.0	 9284	 9284	 0.0	 0.0	 1	 -30.0	 30.0;
	3493	 2299	 0.009458	 0.158871	 0.0	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	2299	 4423	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6826	 2299	 0.312951	 7.130667	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 2299	 0.247649	 1.075911	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 2299	 0.06056	 0.18612	 0.0	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 2299	 2.142489	 4.347733	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 2299	 0.07132	 1.068889	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 2299	 0.02268	 0.08652	 0.0	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 2299	 2.007778	 4.494222	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 2299	 0.006178	 0.028938	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 2299	 0.027711	 0.260951	 0.0	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	3493	 5587	 0.0	 0.000222	 0.0	 299.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4586	 3493	 0.00692	 0.337378	 0.0	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 3493	 0.025991	 0.10048	 0.0	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	6826	 3493	 0.083711	 0.8648	 0.0	 37	 37	 37	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 3493	 0.447378	 1.862089	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 3493	 0.062169	 0.153191	 0.0	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 3493	 2.492533	 4.725778	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 3493	 0.020271	 0.08244	 0.0	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 3493	 0.11416	 1.777556	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 3493	 0.574978	 2.992578	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 3493	 1.887067	 4.964444	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 3493	 0.250778	 0.817422	 0.0	 37	 37	 37	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 3493	 0.007049	 0.029609	 0.0	 1038	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	5587	 4586	 0.003049	 0.020218	 0.0	 1545	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	4423	 4586	 0.002911	 0.020262	 0.0	 1544	 1544	 1544	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 2870	 4e-05	 0.00041	 0.0	 757.0	 76679	 76679	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 659	 0.00087	 0.01087	 0.0	 1283.0	 2897	 2897	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 1037	 4e-05	 0.00046	 0.0	 757.0	 68410	 68410	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 659	 0.00095	 0.00924	 0.0	 1481.0	 3401	 3401	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 5210	 0.528017	 2.636157	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 1445	 0.032031	 0.128659	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	1616	 7762	 0.00044	 0.0032	 0.0	 1645.0	 9780	 9780	 0.0	 0.0	 1	 -30.0	 30.0;
	1616	 2520	 0.00046	 0.00489	 0.0	 1711.0	 6432	 6432	 0.0	 0.0	 1	 -30.0	 30.0;
	9064	 7762	 0.0003	 0.00352	 0.0	 1580.0	 8942	 8942	 0.0	 0.0	 1	 -30.0	 30.0;
	9064	 89	 0.00051	 0.00454	 0.0	 1645.0	 6915	 6915	 0.0	 0.0	 1	 -30.0	 30.0;
	1317	 659	 0.00068	 0.00746	 0.0	 1613.0	 4217	 4217	 0.0	 0.0	 1	 -30.0	 30.0;
	1317	 8605	 0.00093	 0.01022	 0.0	 1744.0	 3079	 3079	 0.0	 0.0	 1	 -30.0	 30.0;
	8605	 1367	 4e-05	 0.0004	 0.0	 1481.0	 78577	 78577	 0.0	 0.0	 1	 -30.0	 30.0;
	8605	 8921	 0.00078	 0.00698	 0.0	 1744.0	 4498	 4498	 0.0	 0.0	 1	 -30.0	 30.0;
	1163	 1676	 4e-05	 0.00043	 0.0	 1580.0	 73144	 73144	 0.0	 0.0	 1	 -30.0	 30.0;
	1163	 7051	 0.00025	 0.00309	 0.0	 1678.0	 10190	 10190	 0.0	 0.0	 1	 -30.0	 30.0;
	913	 7762	 0.00047	 0.00538	 0.0	 1613.0	 5849	 5849	 0.0	 0.0	 1	 -30.0	 30.0;
	2107	 7762	 0.00046	 0.00548	 0.0	 1744.0	 5744	 5744	 0.0	 0.0	 1	 -30.0	 30.0;
	2107	 5996	 0.00016	 0.00173	 0.0	 1843.0	 18181	 18181	 0.0	 0.0	 1	 -30.0	 30.0;
	2107	 6293	 0.00166	 0.01471	 0.0	 1744.0	 2134	 2134	 0.0	 0.0	 1	 -30.0	 30.0;
	913	 7762	 0.00051	 0.00512	 0.0	 1777.0	 6140	 6140	 0.0	 0.0	 1	 -30.0	 30.0;
	6704	 8921	 0.00021	 0.00248	 0.0	 1514.0	 12692	 12692	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 4586	 0.004391	 0.021689	 0.0	 286.0	 1428	 1428	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 6293	 0.00024	 0.00289	 0.0	 1645.0	 10893	 10893	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 3506	 0.0	 0.000222	 0.0	 338.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 8964	 0.01788	 0.100471	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	3506	 2908	 0.006458	 0.039982	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 6826	 0.106151	 0.993333	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 5776	 0.699778	 3.232311	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	8964	 6826	 0.257058	 0.43592	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 6826	 0.002769	 0.011449	 0.0	 2682	 2682	 2682	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 8329	 0.00034	 0.00305	 0.0	 1580.0	 10293	 10293	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 7051	 0.00123	 0.01255	 0.0	 1843.0	 2505	 2505	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 9239	 6e-05	 0.00065	 0.0	 1415.0	 48391	 48391	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 7960	 6e-05	 0.00063	 0.0	 1514.0	 49913	 49913	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 6233	 6e-05	 0.00055	 0.0	 1744.0	 57093	 57093	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 5416	 0.00079	 0.00968	 0.0	 1349.0	 3253	 3253	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 6798	 7e-05	 0.00079	 0.0	 39828	 39828	 39828	 0.0	 0.0	 1	 -30.0	 30.0;
	792	 3279	 0.0	 0.000222	 0.0	 377.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 792	 2.064178	 7.545333	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	7279	 792	 0.153711	 0.482489	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 792	 0.015809	 0.12368	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 792	 0.057978	 0.363422	 0.0	 86	 86	 86	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 792	 0.6932	 2.196889	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 792	 0.560356	 2.395867	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	5416	 2267	 0.00024	 0.00213	 0.0	 757.0	 14737	 14737	 0.0	 0.0	 1	 -30.0	 30.0;
	5416	 7637	 0.00093	 0.00884	 0.0	 1283.0	 3554	 3554	 0.0	 0.0	 1	 -30.0	 30.0;
	8964	 2168	 0.0	 0.000222	 0.0	 312.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3659	 5996	 0.00018	 0.00204	 0.0	 1777.0	 15425	 15425	 0.0	 0.0	 1	 -30.0	 30.0;
	5762	 5996	 0.00018	 0.00208	 0.0	 757.0	 15130	 15130	 0.0	 0.0	 1	 -30.0	 30.0;
	3242	 5097	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 3242	 0.02068	 0.093391	 0.0	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 3242	 0.777778	 7.408	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	3242	 7279	 0.00884	 0.07292	 0.0	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 3242	 0.131671	 8.295556	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	3242	 1611	 0.082462	 0.568222	 0.0	 56	 56	 56	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 1611	 0.0042	 0.02624	 0.0	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	8181	 8179	 0.00031	 0.00317	 0.0	 1251.0	 9918	 9918	 0.0	 0.0	 1	 -30.0	 30.0;
	8181	 7762	 0.00043	 0.00498	 0.0	 1481.0	 6320	 6320	 0.0	 0.0	 1	 -30.0	 30.0;
	9025	 7762	 0.00042	 0.00508	 0.0	 1711.0	 6197	 6197	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 4427	 0.110671	 0.773067	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 7279	 0.00912	 0.037609	 0.0	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 8335	 0.098049	 0.598711	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 5155	 0.019031	 1.160356	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 271	 0.024071	 0.915733	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 7563	 1.484267	 4.479111	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 7563	 0.011578	 0.063271	 0.0	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 7563	 0.654889	 1.839111	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	7563	 1611	 0.022049	 0.10076	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 7279	 0.459867	 2.604711	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 8335	 2.320222	 6.088	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 5155	 0.006369	 0.048089	 0.0	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 271	 0.006631	 0.0432	 0.0	 723	 723	 723	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 4427	 2.567244	 6.767111	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 4427	 0.309889	 1.214178	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 4427	 0.009191	 0.043289	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	4427	 1611	 0.691022	 5.239556	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	5210	 1445	 0.002669	 0.01718	 0.0	 1817	 1817	 1817	 0.0	 0.0	 1	 -30.0	 30.0;
	8179	 5509	 0.00074	 0.00694	 0.0	 1251.0	 4526	 4526	 0.0	 0.0	 1	 -30.0	 30.0;
	8179	 7762	 0.00068	 0.008	 0.0	 1547.0	 3935	 3935	 0.0	 0.0	 1	 -30.0	 30.0;
	7279	 4014	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 7279	 0.00524	 0.030631	 0.0	 1017	 1017	 1017	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 7279	 0.33932	 3.814667	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 7279	 0.22696	 2.614933	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 7279	 0.190671	 0.719378	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 7279	 1.050222	 2.105556	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 7279	 1.431644	 4.294578	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 7279	 0.022618	 0.161089	 0.0	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5509	 1579	 0.00088	 0.00895	 0.0	 1810.0	 3513	 3513	 0.0	 0.0	 1	 -30.0	 30.0;
	8335	 1531	 0.0	 0.000222	 0.0	 299.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 8335	 1.827778	 7.768	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 8335	 0.020849	 0.153382	 0.0	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 8335	 0.156231	 0.656267	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 8335	 0.176498	 0.891556	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	7762	 2268	 0.00067	 0.00777	 0.0	 1613.0	 4051	 4051	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 271	 0.004578	 0.061889	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 2908	 0.01348	 0.05932	 0.0	 520	 520	 520	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 5155	 0.066391	 2.802622	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 5155	 0.194258	 2.220444	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 1611	 0.008151	 0.072822	 0.0	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 2908	 0.016502	 0.055382	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 271	 0.0806	 4.633778	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 271	 0.831556	 3.729644	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	271	 1611	 0.007951	 0.074151	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	1579	 5848	 0.0004	 0.00362	 0.0	 1613.0	 8673	 8673	 0.0	 0.0	 1	 -30.0	 30.0;
	7051	 8847	 0.00015	 0.00177	 0.0	 1580.0	 17783	 17783	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 8229	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	317	 6233	 2e-05	 0.00022	 0.0	 1678.0	 142990	 142990	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 2449	 0.02864	 0.172902	 0.0	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 4495	 0.017591	 0.1404	 0.0	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 4495	 0.00752	 0.031711	 0.0	 970	 970	 970	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 8420	 0.0	 0.000222	 0.0	 546.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6561	 1294	 0.003289	 0.019091	 0.0	 457.0	 1631	 1631	 0.0	 0.0	 1	 -30.0	 30.0;
	6561	 1666	 0.004169	 0.025349	 0.0	 476.0	 1230	 1230	 0.0	 0.0	 1	 -30.0	 30.0;
	6561	 4096	 0.00439	 0.023909	 0.0	 457.0	 1300	 1300	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 4241	 0.00156	 0.01956	 0.0	 1316.0	 1610	 1610	 0.0	 0.0	 1	 -30.0	 30.0;
	4241	 7395	 0.00029	 0.00391	 0.0	 1843.0	 8057	 8057	 0.0	 0.0	 1	 -30.0	 30.0;
	4241	 5873	 0.00179	 0.02522	 0.0	 1250	 1250	 1250	 0.0	 0.0	 1	 -30.0	 30.0;
	1479	 4241	 0.00079	 0.00756	 0.0	 1843.0	 4156	 4156	 0.0	 0.0	 1	 -30.0	 30.0;
	4241	 1475	 0.00027	 0.00281	 0.0	 1645.0	 11190	 11190	 0.0	 0.0	 1	 -30.0	 30.0;
	4241	 1475	 0.00026	 0.00286	 0.0	 1547.0	 11000	 11000	 0.0	 0.0	 1	 -30.0	 30.0;
	2248	 264	 0.000281	 0.00213	 0.0	 14703	 14703	 14703	 0.0	 0.0	 1	 -30.0	 30.0;
	2248	 8530	 0.000419	 0.00299	 0.0	 10463	 10463	 10463	 0.0	 0.0	 1	 -30.0	 30.0;
	3744	 4806	 0.001659	 0.009091	 0.0	 3419	 3419	 3419	 0.0	 0.0	 1	 -30.0	 30.0;
	3744	 6239	 0.00439	 0.03324	 0.0	 381.0	 943	 943	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 8671	 0.000841	 0.00612	 0.0	 400.0	 5114	 5114	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 201	 0.003341	 0.022841	 0.0	 533.0	 1369	 1369	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 3512	 0.00581	 0.04232	 0.0	 740	 740	 740	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 1430	 0.00495	 0.02919	 0.0	 438.0	 1067	 1067	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 5592	 0.01789	 0.07795	 0.0	 381.0	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 4953	 0.00186	 0.014289	 0.0	 381.0	 2193	 2193	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 2355	 0.002281	 0.014401	 0.0	 2167	 2167	 2167	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 2957	 0.00031	 0.00132	 0.0	 23296	 23296	 23296	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 6936	 0.001349	 0.0077	 0.0	 381.0	 4041	 4041	 0.0	 0.0	 1	 -30.0	 30.0;
	5697	 5933	 0.00586	 0.02574	 0.0	 476.0	 1197	 1197	 0.0	 0.0	 1	 -30.0	 30.0;
	5697	 6040	 0.00556	 0.020211	 0.0	 591.0	 1507	 1507	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 2917	 0.00026	 0.001159	 0.0	 553.0	 26594	 26594	 0.0	 0.0	 1	 -30.0	 30.0;
	2917	 6654	 0.000599	 0.002419	 0.0	 591.0	 12676	 12676	 0.0	 0.0	 1	 -30.0	 30.0;
	6679	 7139	 0.0005	 0.00386	 0.0	 8116	 8116	 8116	 0.0	 0.0	 1	 -30.0	 30.0;
	6679	 6134	 0.00107	 0.008289	 0.0	 533.0	 3780	 3780	 0.0	 0.0	 1	 -30.0	 30.0;
	6679	 6134	 0.001091	 0.00811	 0.0	 3861	 3861	 3861	 0.0	 0.0	 1	 -30.0	 30.0;
	7413	 6679	 0.00038	 0.00255	 0.0	 533.0	 12252	 12252	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 6456	 0.000271	 0.000979	 0.0	 31096	 31096	 31096	 0.0	 0.0	 1	 -30.0	 30.0;
	2358	 1638	 7e-05	 0.00076	 0.0	 41388	 41388	 41388	 0.0	 0.0	 1	 -30.0	 30.0;
	2358	 8571	 0.000521	 0.003901	 0.0	 8026	 8026	 8026	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 8247	 0.0016	 0.01839	 0.0	 1251.0	 1712	 1712	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 1393	 0.007651	 0.058781	 0.0	 476.0	 533	 533	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 6243	 0.00394	 0.02182	 0.0	 1425	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 8338	 0.003461	 0.03005	 0.0	 553.0	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 751	 0.00337	 0.01831	 0.0	 438.0	 1697	 1697	 0.0	 0.0	 1	 -30.0	 30.0;
	8285	 4293	 0.000581	 0.00194	 0.0	 495.0	 15598	 15598	 0.0	 0.0	 1	 -30.0	 30.0;
	7392	 4293	 0.000539	 0.001719	 0.0	 17534	 17534	 17534	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 930	 0.00249	 0.03075	 0.0	 1024	 1024	 1024	 0.0	 0.0	 1	 -30.0	 30.0;
	930	 4407	 0.0014	 0.01409	 0.0	 1678.0	 2231	 2231	 0.0	 0.0	 1	 -30.0	 30.0;
	7834	 6596	 0.008	 0.050031	 0.0	 381.0	 624	 624	 0.0	 0.0	 1	 -30.0	 30.0;
	7834	 5592	 0.002211	 0.01562	 0.0	 572.0	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	1418	 3633	 0.00281	 0.021831	 0.0	 476.0	 1436	 1436	 0.0	 0.0	 1	 -30.0	 30.0;
	1418	 7820	 0.000711	 0.004919	 0.0	 6356	 6356	 6356	 0.0	 0.0	 1	 -30.0	 30.0;
	2921	 6093	 0.001841	 0.00738	 0.0	 4153	 4153	 4153	 0.0	 0.0	 1	 -30.0	 30.0;
	2921	 3487	 0.002849	 0.008979	 0.0	 3354	 3354	 3354	 0.0	 0.0	 1	 -30.0	 30.0;
	8353	 3633	 0.00232	 0.014099	 0.0	 2211	 2211	 2211	 0.0	 0.0	 1	 -30.0	 30.0;
	8353	 3633	 0.00237	 0.0138	 0.0	 2256	 2256	 2256	 0.0	 0.0	 1	 -30.0	 30.0;
	8353	 6904	 0.00081	 0.004591	 0.0	 476.0	 6776	 6776	 0.0	 0.0	 1	 -30.0	 30.0;
	8353	 6625	 0.002219	 0.010469	 0.0	 2952	 2952	 2952	 0.0	 0.0	 1	 -30.0	 30.0;
	6261	 1872	 0.001081	 0.00851	 0.0	 3683	 3683	 3683	 0.0	 0.0	 1	 -30.0	 30.0;
	1872	 7973	 0.00087	 0.006969	 0.0	 4498	 4498	 4498	 0.0	 0.0	 1	 -30.0	 30.0;
	1872	 7973	 0.00088	 0.006831	 0.0	 4587	 4587	 4587	 0.0	 0.0	 1	 -30.0	 30.0;
	1872	 4651	 0.000349	 0.00237	 0.0	 13186	 13186	 13186	 0.0	 0.0	 1	 -30.0	 30.0;
	710	 6499	 0.00232	 0.00924	 0.0	 381.0	 3316	 3316	 0.0	 0.0	 1	 -30.0	 30.0;
	710	 3792	 0.00812	 0.03669	 0.0	 400.0	 841	 841	 0.0	 0.0	 1	 -30.0	 30.0;
	2193	 6717	 0.003521	 0.02825	 0.0	 476.0	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	2193	 4752	 0.00264	 0.017651	 0.0	 1770	 1770	 1770	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 6499	 0.00486	 0.02149	 0.0	 457.0	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 6769	 0.006831	 0.034669	 0.0	 419.0	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 7075	 0.017211	 0.108151	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 8213	 0.00063	 0.00475	 0.0	 419.0	 6593	 6593	 0.0	 0.0	 1	 -30.0	 30.0;
	7644	 8213	 0.00062	 0.004841	 0.0	 6473	 6473	 6473	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 2507	 0.0009	 0.01092	 0.0	 1843.0	 2883	 2883	 0.0	 0.0	 1	 -30.0	 30.0;
	2507	 6917	 0.00124	 0.01096	 0.0	 1777.0	 2864	 2864	 0.0	 0.0	 1	 -30.0	 30.0;
	3095	 2951	 0.003211	 0.00176	 0.0	 8627	 8627	 8627	 0.0	 0.0	 1	 -30.0	 30.0;
	3095	 7820	 0.001521	 0.008031	 0.0	 3865	 3865	 3865	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 1898	 0.0005	 0.00441	 0.0	 1415.0	 7118	 7118	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 1498	 0.00247	 0.02573	 0.0	 1223	 1223	 1223	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 1280	 0.00042	 0.00367	 0.0	 1283.0	 8552	 8552	 0.0	 0.0	 1	 -30.0	 30.0;
	7431	 4279	 0.0023	 0.01644	 0.0	 457.0	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	7431	 4279	 0.00226	 0.01676	 0.0	 457.0	 1868	 1868	 0.0	 0.0	 1	 -30.0	 30.0;
	7431	 4279	 0.0023	 0.0162	 0.0	 476.0	 1931	 1931	 0.0	 0.0	 1	 -30.0	 30.0;
	7431	 4279	 0.00225	 0.015	 0.0	 419.0	 2083	 2083	 0.0	 0.0	 1	 -30.0	 30.0;
	2343	 5946	 0.007281	 0.035729	 0.0	 438.0	 867	 867	 0.0	 0.0	 1	 -30.0	 30.0;
	2236	 5946	 0.001919	 0.00945	 0.0	 438.0	 3276	 3276	 0.0	 0.0	 1	 -30.0	 30.0;
	3821	 1173	 0.005211	 0.02981	 0.0	 514.0	 1044	 1044	 0.0	 0.0	 1	 -30.0	 30.0;
	3821	 6936	 0.000659	 0.00586	 0.0	 5357	 5357	 5357	 0.0	 0.0	 1	 -30.0	 30.0;
	3821	 6936	 0.000591	 0.00664	 0.0	 4739	 4739	 4739	 0.0	 0.0	 1	 -30.0	 30.0;
	3821	 2946	 0.011969	 0.07424	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	6261	 3065	 0.000531	 0.003919	 0.0	 7988	 7988	 7988	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 3378	 0.001521	 0.00718	 0.0	 438.0	 4304	 4304	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 3378	 0.001211	 0.00613	 0.0	 476.0	 5056	 5056	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 4809	 0.00676	 0.03725	 0.0	 419.0	 835	 835	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 4750	 0.00399	 0.018091	 0.0	 381.0	 1706	 1706	 0.0	 0.0	 1	 -30.0	 30.0;
	6663	 5217	 0.000341	 0.00339	 0.0	 9272	 9272	 9272	 0.0	 0.0	 1	 -30.0	 30.0;
	6663	 4096	 0.001271	 0.0102	 0.0	 3074	 3074	 3074	 0.0	 0.0	 1	 -30.0	 30.0;
	6663	 4096	 0.00125	 0.010401	 0.0	 3016	 3016	 3016	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 509	 0.00261	 0.016651	 0.0	 1875	 1875	 1875	 0.0	 0.0	 1	 -30.0	 30.0;
	9162	 509	 0.000219	 0.002409	 0.0	 514.0	 13059	 13059	 0.0	 0.0	 1	 -30.0	 30.0;
	6769	 6964	 0.00601	 0.02814	 0.0	 438.0	 1098	 1098	 0.0	 0.0	 1	 -30.0	 30.0;
	6964	 7002	 0.008969	 0.03787	 0.0	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	6964	 6879	 0.00232	 0.01094	 0.0	 438.0	 2825	 2825	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 6917	 0.00196	 0.02382	 0.0	 1322	 1322	 1322	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 8870	 0.00422	 0.03598	 0.0	 872	 872	 872	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 8870	 0.0043	 0.03522	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	8504	 6632	 0.00208	 0.01691	 0.0	 1547.0	 1854	 1854	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 2730	 0.00544	 0.05439	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 7508	 0.00239	 0.02598	 0.0	 1211	 1211	 1211	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 385	 0.00396	 0.03096	 0.0	 1013	 1013	 1013	 0.0	 0.0	 1	 -30.0	 30.0;
	6632	 385	 0.00353	 0.03509	 0.0	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 8858	 0.000531	 0.003729	 0.0	 514.0	 8387	 8387	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 8858	 0.00038	 0.0025	 0.0	 12492	 12492	 12492	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 8858	 0.00039	 0.00244	 0.0	 12784	 12784	 12784	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 4856	 0.00836	 0.044521	 0.0	 400.0	 698	 698	 0.0	 0.0	 1	 -30.0	 30.0;
	1618	 1060	 0.00264	 0.03029	 0.0	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	1618	 8806	 0.00396	 0.04589	 0.0	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	8547	 6669	 0.00411	 0.021729	 0.0	 400.0	 1429	 1429	 0.0	 0.0	 1	 -30.0	 30.0;
	8547	 7398	 0.00607	 0.0285	 0.0	 457.0	 1085	 1085	 0.0	 0.0	 1	 -30.0	 30.0;
	8124	 2496	 0.00075	 0.0047	 0.0	 6637	 6637	 6637	 0.0	 0.0	 1	 -30.0	 30.0;
	8419	 2496	 0.00114	 0.007969	 0.0	 553.0	 3924	 3924	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 2916	 0.00036	 0.00324	 0.0	 1316.0	 9690	 9690	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 8973	 0.00094	 0.00874	 0.0	 1218.0	 3594	 3594	 0.0	 0.0	 1	 -30.0	 30.0;
	2471	 8888	 0.00949	 0.05145	 0.0	 476.0	 604	 604	 0.0	 0.0	 1	 -30.0	 30.0;
	2471	 4906	 0.011719	 0.0337	 0.0	 400.0	 886	 886	 0.0	 0.0	 1	 -30.0	 30.0;
	3076	 2471	 0.0022	 0.012331	 0.0	 419.0	 2522	 2522	 0.0	 0.0	 1	 -30.0	 30.0;
	4182	 2235	 0.00038	 0.00448	 0.0	 1382.0	 7026	 7026	 0.0	 0.0	 1	 -30.0	 30.0;
	4182	 5873	 0.00098	 0.01126	 0.0	 987.0	 2795	 2795	 0.0	 0.0	 1	 -30.0	 30.0;
	42	 5919	 0.00055	 0.00621	 0.0	 1777.0	 5067	 5067	 0.0	 0.0	 1	 -30.0	 30.0;
	42	 2096	 0.00163	 0.01287	 0.0	 1711.0	 2435	 2435	 0.0	 0.0	 1	 -30.0	 30.0;
	6292	 6127	 0.0018	 0.01886	 0.0	 1668	 1668	 1668	 0.0	 0.0	 1	 -30.0	 30.0;
	6292	 6127	 0.0047	 0.024969	 0.0	 1244	 1244	 1244	 0.0	 0.0	 1	 -30.0	 30.0;
	6292	 2658	 0.009711	 0.059669	 0.0	 400.0	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	6292	 5191	 0.005271	 0.03451	 0.0	 905	 905	 905	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 1175	 0.016169	 0.11936	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 1344	 0.00226	 0.014789	 0.0	 419.0	 2112	 2112	 0.0	 0.0	 1	 -30.0	 30.0;
	8671	 1421	 0.00151	 0.01081	 0.0	 591.0	 2894	 2894	 0.0	 0.0	 1	 -30.0	 30.0;
	709	 4652	 0.00228	 0.0217	 0.0	 1448	 1448	 1448	 0.0	 0.0	 1	 -30.0	 30.0;
	709	 3587	 0.00137	 0.01593	 0.0	 1711.0	 1976	 1976	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 3798	 0.00099	 0.0121	 0.0	 1086.0	 2602	 2602	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 2261	 0.0	 0.01881	 0.0	 1119.0	 1680	 1680	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 7755	 0.00143	 0.0163	 0.0	 1185.0	 1931	 1931	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 7287	 0.00057	 0.00562	 0.0	 1119.0	 5592	 5592	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 7287	 0.00055	 0.00572	 0.0	 1185.0	 5497	 5497	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 6496	 0.00057	 0.00658	 0.0	 1448.0	 4783	 4783	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 5372	 0.00075	 0.0082	 0.0	 1251.0	 3837	 3837	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 807	 0.00253	 0.02153	 0.0	 1316.0	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	201	 8582	 0.00236	 0.011219	 0.0	 533.0	 2756	 2756	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 7053	 0.00173	 0.0154	 0.0	 1415.0	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 2764	 0.00385	 0.04172	 0.0	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 2764	 0.00377	 0.04251	 0.0	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 1498	 0.00199	 0.02121	 0.0	 1483	 1483	 1483	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 1133	 0.00236	 0.01933	 0.0	 1185.0	 1623	 1623	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 1133	 0.00241	 0.01891	 0.0	 1119.0	 1658	 1658	 0.0	 0.0	 1	 -30.0	 30.0;
	2301	 3427	 0.000521	 0.004729	 0.0	 6640	 6640	 6640	 0.0	 0.0	 1	 -30.0	 30.0;
	2301	 8575	 0.00094	 0.005581	 0.0	 5582	 5582	 5582	 0.0	 0.0	 1	 -30.0	 30.0;
	4644	 1086	 0.00134	 0.01324	 0.0	 1218.0	 2374	 2374	 0.0	 0.0	 1	 -30.0	 30.0;
	4644	 2849	 0.00073	 0.00638	 0.0	 1283.0	 4919	 4919	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 2459	 0.00248	 0.02774	 0.0	 1135	 1135	 1135	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 477	 0.00152	 0.013	 0.0	 1580.0	 2414	 2414	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 477	 0.00155	 0.01272	 0.0	 1678.0	 2466	 2466	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 8210	 0.00117	 0.01301	 0.0	 1349.0	 2419	 2419	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 3113	 0.00197	 0.02054	 0.0	 1119.0	 1531	 1531	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 8987	 0.00157	 0.01909	 0.0	 1613.0	 1650	 1650	 0.0	 0.0	 1	 -30.0	 30.0;
	3065	 4450	 0.00107	 0.008669	 0.0	 3617	 3617	 3617	 0.0	 0.0	 1	 -30.0	 30.0;
	4450	 1501	 0.000469	 0.00314	 0.0	 9950	 9950	 9950	 0.0	 0.0	 1	 -30.0	 30.0;
	1185	 706	 0.000409	 0.00305	 0.0	 10265	 10265	 10265	 0.0	 0.0	 1	 -30.0	 30.0;
	1240	 706	 0.00569	 0.032979	 0.0	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	3500	 8871	 0.00087	 0.006771	 0.0	 514.0	 4628	 4628	 0.0	 0.0	 1	 -30.0	 30.0;
	3500	 8582	 0.002151	 0.014039	 0.0	 533.0	 2225	 2225	 0.0	 0.0	 1	 -30.0	 30.0;
	6359	 6783	 9.9e-05	 0.00043	 0.0	 553.0	 71587	 71587	 0.0	 0.0	 1	 -30.0	 30.0;
	6454	 6359	 0.000151	 0.0005	 0.0	 60477	 60477	 60477	 0.0	 0.0	 1	 -30.0	 30.0;
	7833	 8438	 0.001531	 0.00812	 0.0	 3823	 3823	 3823	 0.0	 0.0	 1	 -30.0	 30.0;
	7833	 8438	 0.00113	 0.00857	 0.0	 3655	 3655	 3655	 0.0	 0.0	 1	 -30.0	 30.0;
	4253	 7196	 0.00226	 0.01868	 0.0	 514.0	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	4253	 4651	 0.000401	 0.00239	 0.0	 13035	 13035	 13035	 0.0	 0.0	 1	 -30.0	 30.0;
	4230	 1912	 0.001169	 0.008349	 0.0	 514.0	 3747	 3747	 0.0	 0.0	 1	 -30.0	 30.0;
	4230	 6315	 0.00324	 0.02312	 0.0	 533.0	 1354	 1354	 0.0	 0.0	 1	 -30.0	 30.0;
	621	 4360	 0.006031	 0.034789	 0.0	 495.0	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	621	 808	 0.0103	 0.05269	 0.0	 438.0	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	2962	 6917	 0.00129	 0.01494	 0.0	 1481.0	 2107	 2107	 0.0	 0.0	 1	 -30.0	 30.0;
	2962	 6917	 0.00126	 0.01523	 0.0	 1349.0	 2067	 2067	 0.0	 0.0	 1	 -30.0	 30.0;
	4958	 4906	 0.001031	 0.00601	 0.0	 5181	 5181	 5181	 0.0	 0.0	 1	 -30.0	 30.0;
	4958	 4906	 0.00105	 0.00588	 0.0	 5289	 5289	 5289	 0.0	 0.0	 1	 -30.0	 30.0;
	2642	 5823	 0.00197	 0.01719	 0.0	 1119.0	 1826	 1826	 0.0	 0.0	 1	 -30.0	 30.0;
	2642	 1947	 0.00114	 0.01237	 0.0	 1382.0	 2543	 2543	 0.0	 0.0	 1	 -30.0	 30.0;
	2642	 3966	 0.00314	 0.02868	 0.0	 1095	 1095	 1095	 0.0	 0.0	 1	 -30.0	 30.0;
	2642	 1074	 0.00294	 0.03326	 0.0	 947	 947	 947	 0.0	 0.0	 1	 -30.0	 30.0;
	2642	 1074	 0.00288	 0.0308	 0.0	 1022	 1022	 1022	 0.0	 0.0	 1	 -30.0	 30.0;
	2642	 807	 0.00088	 0.02821	 0.0	 1086.0	 1120	 1120	 0.0	 0.0	 1	 -30.0	 30.0;
	4165	 6659	 0.00152	 0.01702	 0.0	 889.0	 1849	 1849	 0.0	 0.0	 1	 -30.0	 30.0;
	4165	 7303	 0.00022	 0.00209	 0.0	 1481.0	 15031	 15031	 0.0	 0.0	 1	 -30.0	 30.0;
	1793	 2668	 0.00087	 0.005	 0.0	 6224	 6224	 6224	 0.0	 0.0	 1	 -30.0	 30.0;
	1793	 8338	 0.000711	 0.00439	 0.0	 381.0	 7103	 7103	 0.0	 0.0	 1	 -30.0	 30.0;
	1793	 8338	 0.000729	 0.004289	 0.0	 419.0	 7261	 7261	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 6443	 0.001031	 0.00549	 0.0	 5655	 5655	 5655	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 519	 0.003219	 0.01512	 0.0	 2044	 2044	 2044	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 595	 0.007271	 0.031419	 0.0	 381.0	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 3291	 0.02145	 0.085781	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	6138	 7504	 0.002841	 0.017771	 0.0	 1756	 1756	 1756	 0.0	 0.0	 1	 -30.0	 30.0;
	6138	 2896	 0.003331	 0.017289	 0.0	 400.0	 1795	 1795	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 2343	 0.01524	 0.064091	 0.0	 480	 480	 480	 0.0	 0.0	 1	 -30.0	 30.0;
	8534	 5121	 0.000831	 0.0052	 0.0	 514.0	 5999	 5999	 0.0	 0.0	 1	 -30.0	 30.0;
	5121	 9039	 0.00164	 0.0103	 0.0	 495.0	 3029	 3029	 0.0	 0.0	 1	 -30.0	 30.0;
	3961	 4238	 0.00139	 0.00864	 0.0	 381.0	 3610	 3610	 0.0	 0.0	 1	 -30.0	 30.0;
	3961	 1411	 0.00143	 0.00764	 0.0	 438.0	 4064	 4064	 0.0	 0.0	 1	 -30.0	 30.0;
	3961	 5793	 0.000229	 0.00126	 0.0	 24666	 24666	 24666	 0.0	 0.0	 1	 -30.0	 30.0;
	3961	 5793	 0.000211	 0.00143	 0.0	 21853	 21853	 21853	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 1549	 0.0008	 0.01072	 0.0	 1547.0	 2939	 2939	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 4600	 0.00067	 0.00661	 0.0	 1119.0	 4755	 4755	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 2800	 0.0003	 0.00427	 0.0	 1382.0	 7380	 7380	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 2800	 0.00068	 0.00648	 0.0	 1349.0	 4848	 4848	 0.0	 0.0	 1	 -30.0	 30.0;
	1600	 8186	 0.0002	 0.001289	 0.0	 24216	 24216	 24216	 0.0	 0.0	 1	 -30.0	 30.0;
	1600	 4011	 0.00013	 0.000961	 0.0	 533.0	 32573	 32573	 0.0	 0.0	 1	 -30.0	 30.0;
	5771	 2235	 0.00118	 0.01285	 0.0	 1613.0	 2448	 2448	 0.0	 0.0	 1	 -30.0	 30.0;
	5771	 5239	 0.00062	 0.00577	 0.0	 1086.0	 5444	 5444	 0.0	 0.0	 1	 -30.0	 30.0;
	9216	 1409	 9.1e-05	 0.000289	 0.0	 104253	 104253	 104253	 0.0	 0.0	 1	 -30.0	 30.0;
	9216	 1409	 9.1e-05	 0.000271	 0.0	 110496	 110496	 110496	 0.0	 0.0	 1	 -30.0	 30.0;
	9216	 6597	 0.0003	 0.002719	 0.0	 476.0	 11548	 11548	 0.0	 0.0	 1	 -30.0	 30.0;
	9216	 6836	 0.00049	 0.002091	 0.0	 14708	 14708	 14708	 0.0	 0.0	 1	 -30.0	 30.0;
	9216	 15	 0.000159	 0.001461	 0.0	 572.0	 21494	 21494	 0.0	 0.0	 1	 -30.0	 30.0;
	429	 6132	 0.00301	 0.02281	 0.0	 1373	 1373	 1373	 0.0	 0.0	 1	 -30.0	 30.0;
	6660	 6132	 0.0027	 0.019979	 0.0	 1567	 1567	 1567	 0.0	 0.0	 1	 -30.0	 30.0;
	1439	 649	 0.00019	 0.000539	 0.0	 55271	 55271	 55271	 0.0	 0.0	 1	 -30.0	 30.0;
	649	 6836	 0.000169	 0.00061	 0.0	 514.0	 49903	 49903	 0.0	 0.0	 1	 -30.0	 30.0;
	8417	 5435	 0.00163	 0.00939	 0.0	 533.0	 3315	 3315	 0.0	 0.0	 1	 -30.0	 30.0;
	8417	 5435	 0.001159	 0.009031	 0.0	 514.0	 3470	 3470	 0.0	 0.0	 1	 -30.0	 30.0;
	8417	 4058	 9.9e-05	 0.00037	 0.0	 457.0	 82471	 82471	 0.0	 0.0	 1	 -30.0	 30.0;
	5617	 9055	 0.003789	 0.01805	 0.0	 1713	 1713	 1713	 0.0	 0.0	 1	 -30.0	 30.0;
	5617	 1471	 0.00069	 0.00389	 0.0	 7996	 7996	 7996	 0.0	 0.0	 1	 -30.0	 30.0;
	8396	 7925	 0.00201	 0.01845	 0.0	 1283.0	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	8806	 7925	 0.00121	 0.00902	 0.0	 1283.0	 3471	 3471	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 1947	 0.00155	 0.01573	 0.0	 1283.0	 1999	 1999	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 8337	 0.00031	 0.00274	 0.0	 1316.0	 11456	 11456	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 3966	 0.00047	 0.00563	 0.0	 1185.0	 5592	 5592	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 3544	 0.00066	 0.00721	 0.0	 1152.0	 4363	 4363	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 4806	 0.00326	 0.016711	 0.0	 1856	 1856	 1856	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 2907	 0.002479	 0.01262	 0.0	 629.0	 2457	 2457	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 2907	 0.00243	 0.01286	 0.0	 610.0	 2414	 2414	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 4338	 0.004521	 0.02306	 0.0	 476.0	 1345	 1345	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 1282	 0.00211	 0.00899	 0.0	 3421	 3421	 3421	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 7795	 0.001289	 0.005651	 0.0	 553.0	 5450	 5450	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 3382	 0.002479	 0.009021	 0.0	 3377	 3377	 3377	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 6456	 0.00151	 0.010521	 0.0	 419.0	 2972	 2972	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 8352	 0.00101	 0.004151	 0.0	 438.0	 7394	 7394	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 797	 0.015599	 0.079	 0.0	 381.0	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 8207	 0.013961	 0.067591	 0.0	 457.0	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 1241	 0.007099	 0.043169	 0.0	 514.0	 723	 723	 0.0	 0.0	 1	 -30.0	 30.0;
	2416	 5042	 0.00317	 0.02987	 0.0	 987.0	 1052	 1052	 0.0	 0.0	 1	 -30.0	 30.0;
	2416	 2764	 0.00081	 0.0088	 0.0	 1119.0	 3575	 3575	 0.0	 0.0	 1	 -30.0	 30.0;
	2416	 2764	 0.00098	 0.00961	 0.0	 987.0	 3270	 3270	 0.0	 0.0	 1	 -30.0	 30.0;
	2416	 179	 0.00194	 0.02225	 0.0	 921.0	 1415	 1415	 0.0	 0.0	 1	 -30.0	 30.0;
	9001	 5463	 0.001031	 0.006349	 0.0	 4911	 4911	 4911	 0.0	 0.0	 1	 -30.0	 30.0;
	9001	 445	 0.00668	 0.0297	 0.0	 553.0	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	4809	 2538	 0.00439	 0.02236	 0.0	 533.0	 1387	 1387	 0.0	 0.0	 1	 -30.0	 30.0;
	2538	 6397	 0.00249	 0.01349	 0.0	 591.0	 2303	 2303	 0.0	 0.0	 1	 -30.0	 30.0;
	2081	 4556	 0.001969	 0.01205	 0.0	 495.0	 2588	 2588	 0.0	 0.0	 1	 -30.0	 30.0;
	2081	 4592	 0.000461	 0.003031	 0.0	 572.0	 10303	 10303	 0.0	 0.0	 1	 -30.0	 30.0;
	3592	 267	 0.00444	 0.023479	 0.0	 438.0	 1322	 1322	 0.0	 0.0	 1	 -30.0	 30.0;
	3592	 4632	 0.00175	 0.01288	 0.0	 2431	 2431	 2431	 0.0	 0.0	 1	 -30.0	 30.0;
	3592	 4632	 0.001711	 0.01312	 0.0	 2388	 2388	 2388	 0.0	 0.0	 1	 -30.0	 30.0;
	1549	 579	 0.0008	 0.00784	 0.0	 1481.0	 4009	 4009	 0.0	 0.0	 1	 -30.0	 30.0;
	1549	 9117	 0.00051	 0.00612	 0.0	 1382.0	 5144	 5144	 0.0	 0.0	 1	 -30.0	 30.0;
	3282	 7145	 0.00137	 0.00905	 0.0	 3451	 3451	 3451	 0.0	 0.0	 1	 -30.0	 30.0;
	3282	 4855	 0.002771	 0.021409	 0.0	 381.0	 1464	 1464	 0.0	 0.0	 1	 -30.0	 30.0;
	3282	 4855	 0.00314	 0.020979	 0.0	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	3282	 4095	 0.002	 0.01118	 0.0	 2782	 2782	 2782	 0.0	 0.0	 1	 -30.0	 30.0;
	8285	 699	 0.00119	 0.00875	 0.0	 3578	 3578	 3578	 0.0	 0.0	 1	 -30.0	 30.0;
	8285	 6882	 0.00031	 0.00236	 0.0	 13271	 13271	 13271	 0.0	 0.0	 1	 -30.0	 30.0;
	8285	 7820	 0.000831	 0.00539	 0.0	 5792	 5792	 5792	 0.0	 0.0	 1	 -30.0	 30.0;
	267	 7349	 0.004349	 0.02394	 0.0	 419.0	 1299	 1299	 0.0	 0.0	 1	 -30.0	 30.0;
	1200	 8731	 0.0007	 0.00782	 0.0	 1678.0	 4024	 4024	 0.0	 0.0	 1	 -30.0	 30.0;
	1200	 1716	 0.00046	 0.00432	 0.0	 1843.0	 7271	 7271	 0.0	 0.0	 1	 -30.0	 30.0;
	1200	 3067	 0.00049	 0.00617	 0.0	 1678.0	 5104	 5104	 0.0	 0.0	 1	 -30.0	 30.0;
	1200	 1074	 0.00127	 0.01514	 0.0	 1777.0	 2080	 2080	 0.0	 0.0	 1	 -30.0	 30.0;
	3549	 6544	 0.00232	 0.01843	 0.0	 1701	 1701	 1701	 0.0	 0.0	 1	 -30.0	 30.0;
	3549	 1503	 0.00488	 0.032151	 0.0	 553.0	 972	 972	 0.0	 0.0	 1	 -30.0	 30.0;
	1409	 3715	 0.000229	 0.00136	 0.0	 533.0	 22904	 22904	 0.0	 0.0	 1	 -30.0	 30.0;
	1409	 6836	 0.0003	 0.001531	 0.0	 476.0	 20247	 20247	 0.0	 0.0	 1	 -30.0	 30.0;
	1409	 5892	 0.00026	 0.00126	 0.0	 400.0	 24553	 24553	 0.0	 0.0	 1	 -30.0	 30.0;
	1409	 5948	 0.00056	 0.002091	 0.0	 553.0	 14593	 14593	 0.0	 0.0	 1	 -30.0	 30.0;
	4407	 2962	 0.00103	 0.0093	 0.0	 1711.0	 3376	 3376	 0.0	 0.0	 1	 -30.0	 30.0;
	4407	 2437	 0.00183	 0.01689	 0.0	 1316.0	 1860	 1860	 0.0	 0.0	 1	 -30.0	 30.0;
	7058	 5163	 0.00324	 0.01095	 0.0	 857.0	 2767	 2767	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 8236	 0.001419	 0.008539	 0.0	 3650	 3650	 3650	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 3427	 0.00068	 0.00438	 0.0	 495.0	 7127	 7127	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 5884	 0.00178	 0.01651	 0.0	 1283.0	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 4315	 0.00151	 0.01827	 0.0	 1251.0	 1724	 1724	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 4315	 0.00148	 0.01862	 0.0	 1316.0	 1692	 1692	 0.0	 0.0	 1	 -30.0	 30.0;
	2962	 2437	 0.00201	 0.02546	 0.0	 1237	 1237	 1237	 0.0	 0.0	 1	 -30.0	 30.0;
	2962	 2437	 0.00197	 0.02357	 0.0	 1336	 1336	 1336	 0.0	 0.0	 1	 -30.0	 30.0;
	3747	 3427	 0.001091	 0.00775	 0.0	 4036	 4036	 4036	 0.0	 0.0	 1	 -30.0	 30.0;
	3747	 988	 0.000841	 0.006669	 0.0	 4700	 4700	 4700	 0.0	 0.0	 1	 -30.0	 30.0;
	932	 3728	 0.00151	 0.012081	 0.0	 514.0	 2595	 2595	 0.0	 0.0	 1	 -30.0	 30.0;
	932	 7463	 0.00032	 0.002521	 0.0	 438.0	 12430	 12430	 0.0	 0.0	 1	 -30.0	 30.0;
	8087	 3342	 0.006091	 0.03019	 0.0	 514.0	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	8087	 7659	 0.003651	 0.016461	 0.0	 553.0	 1874	 1874	 0.0	 0.0	 1	 -30.0	 30.0;
	8087	 3334	 0.00076	 0.00425	 0.0	 381.0	 7317	 7317	 0.0	 0.0	 1	 -30.0	 30.0;
	8087	 3334	 0.00087	 0.004031	 0.0	 7660	 7660	 7660	 0.0	 0.0	 1	 -30.0	 30.0;
	1639	 3728	 0.000651	 0.004729	 0.0	 591.0	 6618	 6618	 0.0	 0.0	 1	 -30.0	 30.0;
	1639	 8936	 0.00045	 0.00337	 0.0	 514.0	 9291	 9291	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 481	 0.001539	 0.00839	 0.0	 438.0	 3704	 3704	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 481	 0.001919	 0.010479	 0.0	 514.0	 2966	 2966	 0.0	 0.0	 1	 -30.0	 30.0;
	481	 9057	 0.001169	 0.007031	 0.0	 438.0	 4432	 4432	 0.0	 0.0	 1	 -30.0	 30.0;
	1894	 481	 0.00739	 0.034081	 0.0	 906	 906	 906	 0.0	 0.0	 1	 -30.0	 30.0;
	4890	 481	 0.00164	 0.00964	 0.0	 419.0	 3231	 3231	 0.0	 0.0	 1	 -30.0	 30.0;
	5890	 481	 0.00206	 0.012	 0.0	 457.0	 2595	 2595	 0.0	 0.0	 1	 -30.0	 30.0;
	5391	 481	 0.000961	 0.00531	 0.0	 457.0	 5854	 5854	 0.0	 0.0	 1	 -30.0	 30.0;
	3544	 6771	 6e-05	 0.00029	 0.0	 987.0	 106663	 106663	 0.0	 0.0	 1	 -30.0	 30.0;
	1344	 4806	 0.001919	 0.013151	 0.0	 381.0	 2377	 2377	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 4806	 0.00019	 0.00107	 0.0	 400.0	 29067	 29067	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 4806	 0.00018	 0.001091	 0.0	 438.0	 28567	 28567	 0.0	 0.0	 1	 -30.0	 30.0;
	5685	 2459	 0.00147	 0.01714	 0.0	 1514.0	 1837	 1837	 0.0	 0.0	 1	 -30.0	 30.0;
	2730	 2459	 0.00143	 0.01632	 0.0	 1283.0	 1929	 1929	 0.0	 0.0	 1	 -30.0	 30.0;
	2730	 2459	 0.00142	 0.01416	 0.0	 1580.0	 2220	 2220	 0.0	 0.0	 1	 -30.0	 30.0;
	2730	 2459	 0.00145	 0.01386	 0.0	 1744.0	 2267	 2267	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 8987	 0.00073	 0.00732	 0.0	 1613.0	 4294	 4294	 0.0	 0.0	 1	 -30.0	 30.0;
	1185	 1240	 0.009039	 0.05989	 0.0	 476.0	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	1185	 4016	 0.007919	 0.04975	 0.0	 457.0	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	2668	 981	 0.000521	 0.005841	 0.0	 457.0	 5387	 5387	 0.0	 0.0	 1	 -30.0	 30.0;
	2668	 6344	 0.000521	 0.0028	 0.0	 11091	 11091	 11091	 0.0	 0.0	 1	 -30.0	 30.0;
	6564	 1074	 0.0007	 0.00744	 0.0	 889.0	 4227	 4227	 0.0	 0.0	 1	 -30.0	 30.0;
	6564	 4026	 0.00159	 0.0148	 0.0	 921.0	 2123	 2123	 0.0	 0.0	 1	 -30.0	 30.0;
	4336	 4249	 0.000659	 0.005151	 0.0	 553.0	 6083	 6083	 0.0	 0.0	 1	 -30.0	 30.0;
	7196	 4249	 0.000729	 0.004901	 0.0	 419.0	 6375	 6375	 0.0	 0.0	 1	 -30.0	 30.0;
	4600	 642	 0.00064	 0.00772	 0.0	 1119.0	 4078	 4078	 0.0	 0.0	 1	 -30.0	 30.0;
	7573	 6186	 0.00018	 0.00093	 0.0	 591.0	 33347	 33347	 0.0	 0.0	 1	 -30.0	 30.0;
	7573	 8186	 0.00019	 0.00118	 0.0	 495.0	 26429	 26429	 0.0	 0.0	 1	 -30.0	 30.0;
	7413	 7573	 0.000409	 0.002341	 0.0	 514.0	 13292	 13292	 0.0	 0.0	 1	 -30.0	 30.0;
	8719	 1023	 0.00087	 0.006591	 0.0	 381.0	 4752	 4752	 0.0	 0.0	 1	 -30.0	 30.0;
	8719	 3063	 0.00162	 0.0098	 0.0	 3181	 3181	 3181	 0.0	 0.0	 1	 -30.0	 30.0;
	7508	 7053	 0.00096	 0.00849	 0.0	 1547.0	 3697	 3697	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 6932	 0.000341	 0.001081	 0.0	 495.0	 27867	 27867	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 6932	 0.0003	 0.001219	 0.0	 514.0	 25162	 25162	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 8068	 9.9e-05	 0.00076	 0.0	 533.0	 41215	 41215	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 8068	 0.00011	 0.00074	 0.0	 553.0	 42222	 42222	 0.0	 0.0	 1	 -30.0	 30.0;
	1602	 4855	 0.00151	 0.009039	 0.0	 3447	 3447	 3447	 0.0	 0.0	 1	 -30.0	 30.0;
	1602	 2551	 0.00356	 0.02331	 0.0	 1340	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	7999	 1439	 0.000281	 0.00169	 0.0	 18438	 18438	 18438	 0.0	 0.0	 1	 -30.0	 30.0;
	7999	 6597	 0.000169	 0.001531	 0.0	 495.0	 20508	 20508	 0.0	 0.0	 1	 -30.0	 30.0;
	7999	 8661	 0.00038	 0.00326	 0.0	 9625	 9625	 9625	 0.0	 0.0	 1	 -30.0	 30.0;
	1086	 7257	 0.00136	 0.01738	 0.0	 1481.0	 1812	 1812	 0.0	 0.0	 1	 -30.0	 30.0;
	6443	 519	 0.00186	 0.0133	 0.0	 2353	 2353	 2353	 0.0	 0.0	 1	 -30.0	 30.0;
	6443	 519	 0.00182	 0.01356	 0.0	 2309	 2309	 2309	 0.0	 0.0	 1	 -30.0	 30.0;
	2009	 6443	 0.002531	 0.015919	 0.0	 533.0	 1960	 1960	 0.0	 0.0	 1	 -30.0	 30.0;
	6443	 6749	 0.00289	 0.015969	 0.0	 419.0	 1947	 1947	 0.0	 0.0	 1	 -30.0	 30.0;
	1121	 4947	 0.001771	 0.01107	 0.0	 400.0	 2818	 2818	 0.0	 0.0	 1	 -30.0	 30.0;
	4204	 4947	 0.007969	 0.04238	 0.0	 733	 733	 733	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 7191	 0.00013	 0.00062	 0.0	 495.0	 49864	 49864	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 284	 0.0002	 0.00201	 0.0	 572.0	 15638	 15638	 0.0	 0.0	 1	 -30.0	 30.0;
	477	 9159	 0.00095	 0.01024	 0.0	 1349.0	 3072	 3072	 0.0	 0.0	 1	 -30.0	 30.0;
	1133	 9159	 0.00553	 0.04909	 0.0	 640	 640	 640	 0.0	 0.0	 1	 -30.0	 30.0;
	3178	 6499	 0.009229	 0.03693	 0.0	 438.0	 830	 830	 0.0	 0.0	 1	 -30.0	 30.0;
	3792	 6499	 0.00451	 0.028469	 0.0	 438.0	 1096	 1096	 0.0	 0.0	 1	 -30.0	 30.0;
	6499	 6038	 0.003591	 0.01906	 0.0	 400.0	 1629	 1629	 0.0	 0.0	 1	 -30.0	 30.0;
	6499	 7398	 0.010159	 0.05169	 0.0	 495.0	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	75	 2126	 0.00039	 0.003099	 0.0	 10113	 10113	 10113	 0.0	 0.0	 1	 -30.0	 30.0;
	75	 6869	 0.000729	 0.0048	 0.0	 6507	 6507	 6507	 0.0	 0.0	 1	 -30.0	 30.0;
	7137	 6659	 0.00141	 0.01296	 0.0	 921.0	 2423	 2423	 0.0	 0.0	 1	 -30.0	 30.0;
	3673	 6745	 0.001969	 0.019229	 0.0	 1635	 1635	 1635	 0.0	 0.0	 1	 -30.0	 30.0;
	3673	 8953	 0.001081	 0.0105	 0.0	 2993	 2993	 2993	 0.0	 0.0	 1	 -30.0	 30.0;
	3673	 8953	 0.00105	 0.010711	 0.0	 2935	 2935	 2935	 0.0	 0.0	 1	 -30.0	 30.0;
	5685	 2849	 0.00052	 0.00449	 0.0	 1415.0	 6989	 6989	 0.0	 0.0	 1	 -30.0	 30.0;
	3378	 6397	 0.01024	 0.056349	 0.0	 476.0	 552	 552	 0.0	 0.0	 1	 -30.0	 30.0;
	3378	 1520	 0.004599	 0.023659	 0.0	 419.0	 1311	 1311	 0.0	 0.0	 1	 -30.0	 30.0;
	3378	 3233	 0.010021	 0.057409	 0.0	 438.0	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	3378	 3291	 0.00275	 0.01525	 0.0	 457.0	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	693	 8240	 0.00107	 0.01122	 0.0	 1547.0	 2803	 2803	 0.0	 0.0	 1	 -30.0	 30.0;
	693	 5884	 0.00242	 0.02336	 0.0	 1218.0	 1345	 1345	 0.0	 0.0	 1	 -30.0	 30.0;
	693	 3587	 0.00165	 0.01303	 0.0	 823.0	 2405	 2405	 0.0	 0.0	 1	 -30.0	 30.0;
	693	 3587	 0.00155	 0.01332	 0.0	 856.0	 2356	 2356	 0.0	 0.0	 1	 -30.0	 30.0;
	6994	 5970	 0.00087	 0.005469	 0.0	 5704	 5704	 5704	 0.0	 0.0	 1	 -30.0	 30.0;
	6994	 5970	 0.002281	 0.011909	 0.0	 2606	 2606	 2606	 0.0	 0.0	 1	 -30.0	 30.0;
	6994	 970	 0.00106	 0.01076	 0.0	 2922	 2922	 2922	 0.0	 0.0	 1	 -30.0	 30.0;
	6994	 5348	 0.001409	 0.01618	 0.0	 381.0	 1945	 1945	 0.0	 0.0	 1	 -30.0	 30.0;
	6994	 1909	 0.00306	 0.015521	 0.0	 457.0	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	3843	 8534	 0.000969	 0.006831	 0.0	 438.0	 4579	 4579	 0.0	 0.0	 1	 -30.0	 30.0;
	3843	 9039	 0.002531	 0.016961	 0.0	 533.0	 1842	 1842	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 257	 0.01207	 0.077901	 0.0	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 6936	 0.014091	 0.080581	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 2946	 0.003289	 0.01481	 0.0	 2083	 2083	 2083	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 172	 0.003349	 0.0145	 0.0	 2123	 2123	 2123	 0.0	 0.0	 1	 -30.0	 30.0;
	8138	 3792	 0.005651	 0.026479	 0.0	 419.0	 1167	 1167	 0.0	 0.0	 1	 -30.0	 30.0;
	8138	 7659	 0.01193	 0.064669	 0.0	 457.0	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	6669	 5111	 0.004151	 0.017281	 0.0	 419.0	 1778	 1778	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 7145	 0.00213	 0.014091	 0.0	 2217	 2217	 2217	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 1894	 0.00113	 0.00651	 0.0	 419.0	 4781	 4781	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 1894	 0.001159	 0.00637	 0.0	 419.0	 4879	 4879	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 6456	 0.00611	 0.03288	 0.0	 457.0	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	8946	 849	 0.00012	 0.00156	 0.0	 1744.0	 20189	 20189	 0.0	 0.0	 1	 -30.0	 30.0;
	8946	 849	 0.00013	 0.00153	 0.0	 1645.0	 20572	 20572	 0.0	 0.0	 1	 -30.0	 30.0;
	8946	 6768	 0.00285	 0.03071	 0.0	 1025	 1025	 1025	 0.0	 0.0	 1	 -30.0	 30.0;
	5970	 2896	 0.00676	 0.03787	 0.0	 495.0	 822	 822	 0.0	 0.0	 1	 -30.0	 30.0;
	5970	 9049	 0.004461	 0.023521	 0.0	 438.0	 1320	 1320	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 618	 0.00064	 0.0078	 0.0	 1514.0	 4037	 4037	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 618	 0.00065	 0.00764	 0.0	 1514.0	 4120	 4120	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 579	 0.00066	 0.00602	 0.0	 1481.0	 5216	 5216	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 4442	 0.00149	 0.01224	 0.0	 889.0	 2562	 2562	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 814	 0.00061	 0.00582	 0.0	 1020.0	 5398	 5398	 0.0	 0.0	 1	 -30.0	 30.0;
	3633	 6904	 0.001461	 0.00744	 0.0	 4167	 4167	 4167	 0.0	 0.0	 1	 -30.0	 30.0;
	3633	 7820	 0.00386	 0.02406	 0.0	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	3633	 7632	 0.00306	 0.01555	 0.0	 1994	 1994	 1994	 0.0	 0.0	 1	 -30.0	 30.0;
	3633	 7632	 0.003	 0.01586	 0.0	 1957	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	3629	 4112	 0.003271	 0.020651	 0.0	 1511	 1511	 1511	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 7630	 0.000849	 0.00657	 0.0	 4769	 4769	 4769	 0.0	 0.0	 1	 -30.0	 30.0;
	1645	 3066	 0.000211	 0.001169	 0.0	 476.0	 26592	 26592	 0.0	 0.0	 1	 -30.0	 30.0;
	1645	 7973	 0.000469	 0.00345	 0.0	 495.0	 9073	 9073	 0.0	 0.0	 1	 -30.0	 30.0;
	4945	 7508	 0.00126	 0.0145	 0.0	 1382.0	 2171	 2171	 0.0	 0.0	 1	 -30.0	 30.0;
	1957	 5933	 0.008219	 0.04925	 0.0	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	1957	 1769	 0.006771	 0.04132	 0.0	 438.0	 755	 755	 0.0	 0.0	 1	 -30.0	 30.0;
	7417	 7600	 0.000841	 0.004539	 0.0	 591.0	 6843	 6843	 0.0	 0.0	 1	 -30.0	 30.0;
	7417	 3792	 0.00701	 0.03161	 0.0	 476.0	 976	 976	 0.0	 0.0	 1	 -30.0	 30.0;
	7417	 6879	 0.000781	 0.004271	 0.0	 572.0	 7276	 7276	 0.0	 0.0	 1	 -30.0	 30.0;
	7417	 962	 0.00049	 0.0032	 0.0	 533.0	 9758	 9758	 0.0	 0.0	 1	 -30.0	 30.0;
	3489	 3813	 0.000331	 0.00199	 0.0	 629.0	 15658	 15658	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 3813	 0.00032	 0.002031	 0.0	 629.0	 15364	 15364	 0.0	 0.0	 1	 -30.0	 30.0;
	3813	 5500	 9.1e-05	 0.00057	 0.0	 476.0	 54724	 54724	 0.0	 0.0	 1	 -30.0	 30.0;
	5366	 869	 0.001651	 0.006789	 0.0	 533.0	 4521	 4521	 0.0	 0.0	 1	 -30.0	 30.0;
	5366	 3382	 0.001461	 0.007229	 0.0	 4283	 4283	 4283	 0.0	 0.0	 1	 -30.0	 30.0;
	8352	 9049	 0.00437	 0.023979	 0.0	 438.0	 1296	 1296	 0.0	 0.0	 1	 -30.0	 30.0;
	1869	 473	 0.00781	 0.04595	 0.0	 419.0	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	1869	 6243	 0.0015	 0.006531	 0.0	 457.0	 4714	 4714	 0.0	 0.0	 1	 -30.0	 30.0;
	5767	 9057	 0.001031	 0.006469	 0.0	 4823	 4823	 4823	 0.0	 0.0	 1	 -30.0	 30.0;
	2800	 3061	 0.00183	 0.01686	 0.0	 1119.0	 1863	 1863	 0.0	 0.0	 1	 -30.0	 30.0;
	2800	 618	 0.0002	 0.00294	 0.0	 1514.0	 10720	 10720	 0.0	 0.0	 1	 -30.0	 30.0;
	2800	 618	 0.00021	 0.00288	 0.0	 1316.0	 10939	 10939	 0.0	 0.0	 1	 -30.0	 30.0;
	2800	 5042	 0.00171	 0.01889	 0.0	 1283.0	 1666	 1666	 0.0	 0.0	 1	 -30.0	 30.0;
	8870	 2764	 0.00069	 0.00565	 0.0	 1185.0	 5550	 5550	 0.0	 0.0	 1	 -30.0	 30.0;
	8870	 2764	 0.0007	 0.00553	 0.0	 1382.0	 5667	 5667	 0.0	 0.0	 1	 -30.0	 30.0;
	7096	 4290	 0.00011	 0.00115	 0.0	 1119.0	 27343	 27343	 0.0	 0.0	 1	 -30.0	 30.0;
	7096	 6681	 0.00012	 0.00126	 0.0	 1316.0	 24957	 24957	 0.0	 0.0	 1	 -30.0	 30.0;
	7096	 8973	 0.00326	 0.02919	 0.0	 1076	 1076	 1076	 0.0	 0.0	 1	 -30.0	 30.0;
	7096	 5060	 0.00092	 0.00876	 0.0	 823.0	 3587	 3587	 0.0	 0.0	 1	 -30.0	 30.0;
	5780	 6932	 0.00087	 0.005409	 0.0	 457.0	 5766	 5766	 0.0	 0.0	 1	 -30.0	 30.0;
	5780	 6869	 0.00131	 0.00701	 0.0	 438.0	 4430	 4430	 0.0	 0.0	 1	 -30.0	 30.0;
	4291	 6656	 0.002531	 0.018781	 0.0	 1667	 1667	 1667	 0.0	 0.0	 1	 -30.0	 30.0;
	4291	 8729	 0.00894	 0.056909	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 5463	 0.00187	 0.010659	 0.0	 553.0	 2919	 2919	 0.0	 0.0	 1	 -30.0	 30.0;
	7685	 5463	 0.00286	 0.01538	 0.0	 610.0	 2020	 2020	 0.0	 0.0	 1	 -30.0	 30.0;
	5463	 4967	 0.0008	 0.00444	 0.0	 419.0	 7002	 7002	 0.0	 0.0	 1	 -30.0	 30.0;
	1013	 7875	 0.00545	 0.03936	 0.0	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	1741	 7875	 0.00119	 0.009031	 0.0	 3468	 3468	 3468	 0.0	 0.0	 1	 -30.0	 30.0;
	51	 5670	 0.00295	 0.0162	 0.0	 419.0	 1919	 1919	 0.0	 0.0	 1	 -30.0	 30.0;
	51	 6174	 0.001581	 0.0087	 0.0	 514.0	 3573	 3573	 0.0	 0.0	 1	 -30.0	 30.0;
	51	 2517	 0.007729	 0.025401	 0.0	 591.0	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 3425	 0.00013	 0.001461	 0.0	 457.0	 21536	 21536	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 8658	 0.000341	 0.02219	 0.0	 1424	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 4011	 0.00018	 0.001211	 0.0	 591.0	 25801	 25801	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 9028	 0.003099	 0.0147	 0.0	 591.0	 2103	 2103	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 9028	 0.003159	 0.014401	 0.0	 533.0	 2143	 2143	 0.0	 0.0	 1	 -30.0	 30.0;
	6932	 4274	 0.00281	 0.01305	 0.0	 2367	 2367	 2367	 0.0	 0.0	 1	 -30.0	 30.0;
	6932	 8871	 0.002281	 0.01075	 0.0	 495.0	 2875	 2875	 0.0	 0.0	 1	 -30.0	 30.0;
	6932	 8871	 0.00232	 0.010521	 0.0	 457.0	 2932	 2932	 0.0	 0.0	 1	 -30.0	 30.0;
	6932	 3442	 0.000151	 0.000841	 0.0	 36969	 36969	 36969	 0.0	 0.0	 1	 -30.0	 30.0;
	6953	 2658	 0.002771	 0.012091	 0.0	 572.0	 2547	 2547	 0.0	 0.0	 1	 -30.0	 30.0;
	6953	 5592	 0.00613	 0.03005	 0.0	 457.0	 1030	 1030	 0.0	 0.0	 1	 -30.0	 30.0;
	3342	 7659	 0.003219	 0.02486	 0.0	 1261	 1261	 1261	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 8068	 0.000211	 0.001331	 0.0	 572.0	 23440	 23440	 0.0	 0.0	 1	 -30.0	 30.0;
	8504	 1898	 0.00185	 0.01917	 0.0	 1613.0	 1641	 1641	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 869	 0.00082	 0.00381	 0.0	 572.0	 8106	 8106	 0.0	 0.0	 1	 -30.0	 30.0;
	9043	 7819	 0.00075	 0.004531	 0.0	 381.0	 6878	 6878	 0.0	 0.0	 1	 -30.0	 30.0;
	9043	 7819	 0.000729	 0.00419	 0.0	 419.0	 7428	 7428	 0.0	 0.0	 1	 -30.0	 30.0;
	9043	 32	 0.02626	 0.15576	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	9043	 7423	 0.011469	 0.03937	 0.0	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	7139	 8186	 0.00011	 0.00061	 0.0	 514.0	 50961	 50961	 0.0	 0.0	 1	 -30.0	 30.0;
	7139	 1065	 0.000531	 0.00313	 0.0	 381.0	 9950	 9950	 0.0	 0.0	 1	 -30.0	 30.0;
	7139	 6134	 0.001211	 0.00864	 0.0	 3621	 3621	 3621	 0.0	 0.0	 1	 -30.0	 30.0;
	4336	 4651	 0.00094	 0.006289	 0.0	 4968	 4968	 4968	 0.0	 0.0	 1	 -30.0	 30.0;
	731	 4020	 0.001	 0.00886	 0.0	 823.0	 3543	 3543	 0.0	 0.0	 1	 -30.0	 30.0;
	6769	 3178	 0.001979	 0.010469	 0.0	 514.0	 2965	 2965	 0.0	 0.0	 1	 -30.0	 30.0;
	6769	 3178	 0.0017	 0.00855	 0.0	 553.0	 3624	 3624	 0.0	 0.0	 1	 -30.0	 30.0;
	3178	 2116	 0.00757	 0.04624	 0.0	 419.0	 675	 675	 0.0	 0.0	 1	 -30.0	 30.0;
	3178	 7283	 0.001719	 0.00794	 0.0	 495.0	 3889	 3889	 0.0	 0.0	 1	 -30.0	 30.0;
	3178	 7283	 0.00176	 0.007781	 0.0	 3960	 3960	 3960	 0.0	 0.0	 1	 -30.0	 30.0;
	3157	 916	 0.00126	 0.0053	 0.0	 400.0	 5799	 5799	 0.0	 0.0	 1	 -30.0	 30.0;
	3157	 1241	 0.00444	 0.022789	 0.0	 419.0	 1361	 1361	 0.0	 0.0	 1	 -30.0	 30.0;
	477	 2437	 0.00163	 0.0145	 0.0	 1086.0	 2165	 2165	 0.0	 0.0	 1	 -30.0	 30.0;
	6769	 257	 0.003281	 0.02124	 0.0	 495.0	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	6769	 7283	 0.004979	 0.025271	 0.0	 476.0	 1227	 1227	 0.0	 0.0	 1	 -30.0	 30.0;
	8858	 2403	 0.0072	 0.055289	 0.0	 495.0	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	8858	 4772	 0.00787	 0.04582	 0.0	 680	 680	 680	 0.0	 0.0	 1	 -30.0	 30.0;
	8858	 4016	 0.003961	 0.017711	 0.0	 1741	 1741	 1741	 0.0	 0.0	 1	 -30.0	 30.0;
	2403	 6797	 0.00756	 0.04826	 0.0	 457.0	 647	 647	 0.0	 0.0	 1	 -30.0	 30.0;
	6192	 8207	 0.003401	 0.02086	 0.0	 457.0	 1495	 1495	 0.0	 0.0	 1	 -30.0	 30.0;
	6192	 3937	 0.001341	 0.00669	 0.0	 419.0	 4630	 4630	 0.0	 0.0	 1	 -30.0	 30.0;
	7669	 8867	 6e-05	 0.000581	 0.0	 438.0	 54080	 54080	 0.0	 0.0	 1	 -30.0	 30.0;
	7669	 5948	 9.1e-05	 0.00074	 0.0	 514.0	 42367	 42367	 0.0	 0.0	 1	 -30.0	 30.0;
	7392	 8939	 0.000531	 0.00175	 0.0	 17273	 17273	 17273	 0.0	 0.0	 1	 -30.0	 30.0;
	1114	 5096	 0.00116	 0.01159	 0.0	 1382.0	 2712	 2712	 0.0	 0.0	 1	 -30.0	 30.0;
	1114	 4315	 0.00038	 0.00457	 0.0	 1613.0	 6889	 6889	 0.0	 0.0	 1	 -30.0	 30.0;
	3066	 7973	 0.000729	 0.00405	 0.0	 553.0	 7676	 7676	 0.0	 0.0	 1	 -30.0	 30.0;
	264	 7064	 0.000331	 0.001919	 0.0	 16221	 16221	 16221	 0.0	 0.0	 1	 -30.0	 30.0;
	2188	 4706	 0.00086	 0.01029	 0.0	 1909.0	 3060	 3060	 0.0	 0.0	 1	 -30.0	 30.0;
	7428	 2188	 0.00027	 0.00332	 0.0	 1711.0	 9483	 9483	 0.0	 0.0	 1	 -30.0	 30.0;
	5170	 5681	 0.00012	 0.00156	 0.0	 20189	 20189	 20189	 0.0	 0.0	 1	 -30.0	 30.0;
	5170	 5681	 0.00012	 0.001531	 0.0	 20569	 20569	 20569	 0.0	 0.0	 1	 -30.0	 30.0;
	8756	 2060	 0.00256	 0.014211	 0.0	 2188	 2188	 2188	 0.0	 0.0	 1	 -30.0	 30.0;
	8756	 8419	 0.00049	 0.00338	 0.0	 9249	 9249	 9249	 0.0	 0.0	 1	 -30.0	 30.0;
	6009	 1430	 0.007531	 0.04444	 0.0	 400.0	 701	 701	 0.0	 0.0	 1	 -30.0	 30.0;
	6009	 5592	 0.007409	 0.03226	 0.0	 955	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	3150	 8147	 0.001789	 0.012841	 0.0	 2437	 2437	 2437	 0.0	 0.0	 1	 -30.0	 30.0;
	3150	 4096	 0.001831	 0.01257	 0.0	 2487	 2487	 2487	 0.0	 0.0	 1	 -30.0	 30.0;
	1632	 3621	 0.000169	 0.00143	 0.0	 21937	 21937	 21937	 0.0	 0.0	 1	 -30.0	 30.0;
	1632	 6869	 0.00088	 0.005099	 0.0	 610.0	 6105	 6105	 0.0	 0.0	 1	 -30.0	 30.0;
	3061	 7460	 0.0004	 0.00479	 0.0	 1678.0	 6572	 6572	 0.0	 0.0	 1	 -30.0	 30.0;
	3061	 7460	 0.00052	 0.00481	 0.0	 1744.0	 6529	 6529	 0.0	 0.0	 1	 -30.0	 30.0;
	3061	 7929	 0.00135	 0.01431	 0.0	 1744.0	 2198	 2198	 0.0	 0.0	 1	 -30.0	 30.0;
	3061	 814	 0.00051	 0.00549	 0.0	 1481.0	 5729	 5729	 0.0	 0.0	 1	 -30.0	 30.0;
	699	 6882	 0.00105	 0.007969	 0.0	 476.0	 3930	 3930	 0.0	 0.0	 1	 -30.0	 30.0;
	699	 947	 0.00339	 0.020531	 0.0	 1518	 1518	 1518	 0.0	 0.0	 1	 -30.0	 30.0;
	699	 2951	 0.00169	 0.009331	 0.0	 3332	 3332	 3332	 0.0	 0.0	 1	 -30.0	 30.0;
	3584	 4177	 0.00374	 0.01905	 0.0	 438.0	 1628	 1628	 0.0	 0.0	 1	 -30.0	 30.0;
	3584	 5276	 0.00487	 0.026341	 0.0	 533.0	 1180	 1180	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 8301	 0.00057	 0.004581	 0.0	 6843	 6843	 6843	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 8582	 0.000409	 0.00301	 0.0	 10399	 10399	 10399	 0.0	 0.0	 1	 -30.0	 30.0;
	1461	 3754	 9.1e-05	 0.00076	 0.0	 419.0	 41268	 41268	 0.0	 0.0	 1	 -30.0	 30.0;
	1461	 6179	 0.003919	 0.01682	 0.0	 476.0	 1829	 1829	 0.0	 0.0	 1	 -30.0	 30.0;
	5823	 1060	 0.00117	 0.0131	 0.0	 1514.0	 2402	 2402	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 4954	 0.008271	 0.02787	 0.0	 495.0	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 1121	 0.016599	 0.0572	 0.0	 419.0	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 7861	 0.00999	 0.057	 0.0	 546	 546	 546	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 7861	 0.01132	 0.05586	 0.0	 555	 555	 555	 0.0	 0.0	 1	 -30.0	 30.0;
	7303	 4690	 4e-05	 0.00045	 0.0	 921.0	 69919	 69919	 0.0	 0.0	 1	 -30.0	 30.0;
	4954	 8534	 0.003281	 0.01038	 0.0	 495.0	 2902	 2902	 0.0	 0.0	 1	 -30.0	 30.0;
	4317	 72	 0.003711	 0.01725	 0.0	 457.0	 1791	 1791	 0.0	 0.0	 1	 -30.0	 30.0;
	4317	 6333	 0.00069	 0.00232	 0.0	 457.0	 13051	 13051	 0.0	 0.0	 1	 -30.0	 30.0;
	8702	 4948	 0.004151	 0.02436	 0.0	 514.0	 1279	 1279	 0.0	 0.0	 1	 -30.0	 30.0;
	5163	 4948	 0.006781	 0.028729	 0.0	 476.0	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	3489	 6869	 0.000331	 0.00151	 0.0	 438.0	 20434	 20434	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 6869	 0.000331	 0.001479	 0.0	 629.0	 20842	 20842	 0.0	 0.0	 1	 -30.0	 30.0;
	3687	 5877	 0.0001	 0.00144	 0.0	 1514.0	 21883	 21883	 0.0	 0.0	 1	 -30.0	 30.0;
	3687	 5919	 0.00027	 0.00221	 0.0	 1053.0	 14188	 14188	 0.0	 0.0	 1	 -30.0	 30.0;
	1232	 4588	 0.0001	 0.00141	 0.0	 1711.0	 22347	 22347	 0.0	 0.0	 1	 -30.0	 30.0;
	1232	 2764	 0.00054	 0.00546	 0.0	 1448.0	 5758	 5758	 0.0	 0.0	 1	 -30.0	 30.0;
	7428	 5877	 7e-05	 0.00053	 0.0	 1382.0	 59086	 59086	 0.0	 0.0	 1	 -30.0	 30.0;
	4588	 7428	 6e-05	 0.0006	 0.0	 1481.0	 52385	 52385	 0.0	 0.0	 1	 -30.0	 30.0;
	8939	 4371	 0.000341	 0.00245	 0.0	 12770	 12770	 12770	 0.0	 0.0	 1	 -30.0	 30.0;
	8939	 7820	 0.000841	 0.006719	 0.0	 4665	 4665	 4665	 0.0	 0.0	 1	 -30.0	 30.0;
	6209	 7191	 0.000401	 0.00164	 0.0	 476.0	 18710	 18710	 0.0	 0.0	 1	 -30.0	 30.0;
	519	 7349	 0.004409	 0.032531	 0.0	 963	 963	 963	 0.0	 0.0	 1	 -30.0	 30.0;
	429	 7877	 0.001961	 0.013581	 0.0	 381.0	 2302	 2302	 0.0	 0.0	 1	 -30.0	 30.0;
	1894	 4890	 0.006659	 0.03437	 0.0	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	4062	 1599	 9.1e-05	 0.0007	 0.0	 44749	 44749	 44749	 0.0	 0.0	 1	 -30.0	 30.0;
	4062	 8079	 0.00051	 0.004211	 0.0	 7447	 7447	 7447	 0.0	 0.0	 1	 -30.0	 30.0;
	6841	 8936	 0.00043	 0.0027	 0.0	 11554	 11554	 11554	 0.0	 0.0	 1	 -30.0	 30.0;
	6841	 2564	 0.00038	 0.00306	 0.0	 10244	 10244	 10244	 0.0	 0.0	 1	 -30.0	 30.0;
	8710	 1491	 0.001461	 0.009479	 0.0	 3294	 3294	 3294	 0.0	 0.0	 1	 -30.0	 30.0;
	8710	 7406	 0.001841	 0.011081	 0.0	 514.0	 2813	 2813	 0.0	 0.0	 1	 -30.0	 30.0;
	970	 7504	 0.00094	 0.007169	 0.0	 553.0	 4369	 4369	 0.0	 0.0	 1	 -30.0	 30.0;
	6039	 8034	 0.00082	 0.00846	 0.0	 1415.0	 3717	 3717	 0.0	 0.0	 1	 -30.0	 30.0;
	6039	 7428	 0.00029	 0.00325	 0.0	 1711.0	 9681	 9681	 0.0	 0.0	 1	 -30.0	 30.0;
	7973	 7475	 0.000781	 0.0062	 0.0	 5055	 5055	 5055	 0.0	 0.0	 1	 -30.0	 30.0;
	7973	 2740	 8.1e-05	 0.00187	 0.0	 495.0	 16876	 16876	 0.0	 0.0	 1	 -30.0	 30.0;
	7973	 2297	 8.1e-05	 0.001909	 0.0	 419.0	 16532	 16532	 0.0	 0.0	 1	 -30.0	 30.0;
	6877	 1060	 0.00113	 0.00956	 0.0	 1185.0	 3282	 3282	 0.0	 0.0	 1	 -30.0	 30.0;
	6877	 1060	 0.00115	 0.00935	 0.0	 1218.0	 3354	 3354	 0.0	 0.0	 1	 -30.0	 30.0;
	8981	 4428	 0.00161	 0.02036	 0.0	 1547	 1547	 1547	 0.0	 0.0	 1	 -30.0	 30.0;
	8981	 4428	 0.00157	 0.02075	 0.0	 1518	 1518	 1518	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 3728	 0.00101	 0.007401	 0.0	 533.0	 4229	 4229	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 7463	 0.00087	 0.00711	 0.0	 476.0	 4410	 4410	 0.0	 0.0	 1	 -30.0	 30.0;
	3582	 5919	 0.00135	 0.01442	 0.0	 1349.0	 2181	 2181	 0.0	 0.0	 1	 -30.0	 30.0;
	3582	 2096	 0.00176	 0.01441	 0.0	 1777.0	 2176	 2176	 0.0	 0.0	 1	 -30.0	 30.0;
	2009	 7349	 0.00682	 0.03187	 0.0	 419.0	 970	 970	 0.0	 0.0	 1	 -30.0	 30.0;
	8034	 1399	 0.00109	 0.00987	 0.0	 1185.0	 3181	 3181	 0.0	 0.0	 1	 -30.0	 30.0;
	4652	 8034	 0.00273	 0.02829	 0.0	 1112	 1112	 1112	 0.0	 0.0	 1	 -30.0	 30.0;
	1752	 7845	 0.001581	 0.011289	 0.0	 400.0	 2772	 2772	 0.0	 0.0	 1	 -30.0	 30.0;
	1752	 3427	 0.001669	 0.013099	 0.0	 2393	 2393	 2393	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 1599	 9.9e-05	 0.00069	 0.0	 495.0	 45315	 45315	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 8079	 9.9e-05	 0.000669	 0.0	 514.0	 46708	 46708	 0.0	 0.0	 1	 -30.0	 30.0;
	4896	 3736	 0.000591	 0.00382	 0.0	 8172	 8172	 8172	 0.0	 0.0	 1	 -30.0	 30.0;
	4896	 7632	 0.00524	 0.02276	 0.0	 1353	 1353	 1353	 0.0	 0.0	 1	 -30.0	 30.0;
	3736	 6625	 0.002719	 0.01143	 0.0	 2689	 2689	 2689	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 8561	 0.00294	 0.02744	 0.0	 954.0	 1145	 1145	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 7395	 0.0011	 0.01339	 0.0	 1020.0	 2352	 2352	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 5873	 0.00193	 0.01695	 0.0	 1349.0	 1852	 1852	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 4843	 0.00134	 0.01054	 0.0	 1020.0	 2973	 2973	 0.0	 0.0	 1	 -30.0	 30.0;
	6092	 739	 0.00245	 0.02064	 0.0	 1382.0	 1520	 1520	 0.0	 0.0	 1	 -30.0	 30.0;
	1393	 6717	 0.001841	 0.00901	 0.0	 457.0	 3435	 3435	 0.0	 0.0	 1	 -30.0	 30.0;
	1393	 6717	 0.00187	 0.00882	 0.0	 495.0	 3504	 3504	 0.0	 0.0	 1	 -30.0	 30.0;
	8337	 807	 0.00197	 0.02312	 0.0	 1283.0	 1362	 1362	 0.0	 0.0	 1	 -30.0	 30.0;
	2235	 7395	 0.00078	 0.00887	 0.0	 1382.0	 3548	 3548	 0.0	 0.0	 1	 -30.0	 30.0;
	8512	 5435	 0.003771	 0.0288	 0.0	 438.0	 1088	 1088	 0.0	 0.0	 1	 -30.0	 30.0;
	8512	 4658	 0.000909	 0.00737	 0.0	 457.0	 4254	 4254	 0.0	 0.0	 1	 -30.0	 30.0;
	7929	 7460	 0.00086	 0.00783	 0.0	 1744.0	 4011	 4011	 0.0	 0.0	 1	 -30.0	 30.0;
	7929	 7460	 0.00095	 0.00855	 0.0	 1547.0	 3672	 3672	 0.0	 0.0	 1	 -30.0	 30.0;
	299	 7460	 0.00012	 0.00157	 0.0	 1843.0	 20061	 20061	 0.0	 0.0	 1	 -30.0	 30.0;
	299	 7460	 0.00013	 0.00154	 0.0	 757.0	 20439	 20439	 0.0	 0.0	 1	 -30.0	 30.0;
	5117	 6456	 0.00089	 0.004771	 0.0	 533.0	 6509	 6509	 0.0	 0.0	 1	 -30.0	 30.0;
	5117	 6394	 0.002	 0.00881	 0.0	 553.0	 3497	 3497	 0.0	 0.0	 1	 -30.0	 30.0;
	6397	 7075	 0.007711	 0.035331	 0.0	 874	 874	 874	 0.0	 0.0	 1	 -30.0	 30.0;
	7075	 6936	 0.005919	 0.030419	 0.0	 495.0	 1020	 1020	 0.0	 0.0	 1	 -30.0	 30.0;
	7075	 2946	 0.0053	 0.031719	 0.0	 591.0	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 1969	 0.00025	 0.001289	 0.0	 24058	 24058	 24058	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 2116	 0.0062	 0.040039	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 5464	 0.0008	 0.00707	 0.0	 1514.0	 4440	 4440	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 4957	 0.0002	 0.00207	 0.0	 954.0	 15189	 15189	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 4446	 0.00036	 0.00322	 0.0	 1053.0	 9749	 9749	 0.0	 0.0	 1	 -30.0	 30.0;
	1115	 6090	 0.0023	 0.0157	 0.0	 381.0	 1991	 1991	 0.0	 0.0	 1	 -30.0	 30.0;
	1115	 4204	 0.003479	 0.021159	 0.0	 419.0	 1474	 1474	 0.0	 0.0	 1	 -30.0	 30.0;
	3966	 3428	 0.00107	 0.01013	 0.0	 1382.0	 3101	 3101	 0.0	 0.0	 1	 -30.0	 30.0;
	1439	 6836	 0.00025	 0.000909	 0.0	 514.0	 33506	 33506	 0.0	 0.0	 1	 -30.0	 30.0;
	1439	 5892	 0.00037	 0.00188	 0.0	 438.0	 16486	 16486	 0.0	 0.0	 1	 -30.0	 30.0;
	9201	 3937	 0.0003	 0.00145	 0.0	 419.0	 21333	 21333	 0.0	 0.0	 1	 -30.0	 30.0;
	9201	 3692	 0.001419	 0.007539	 0.0	 476.0	 4118	 4118	 0.0	 0.0	 1	 -30.0	 30.0;
	8561	 266	 0.0012	 0.0122	 0.0	 1251.0	 2577	 2577	 0.0	 0.0	 1	 -30.0	 30.0;
	8561	 2566	 0.00397	 0.02936	 0.0	 1067	 1067	 1067	 0.0	 0.0	 1	 -30.0	 30.0;
	8561	 8806	 0.00092	 0.01112	 0.0	 1185.0	 2831	 2831	 0.0	 0.0	 1	 -30.0	 30.0;
	8561	 7428	 0.00387	 0.0452	 0.0	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	8561	 1280	 0.00432	 0.03156	 0.0	 992	 992	 992	 0.0	 0.0	 1	 -30.0	 30.0;
	2730	 1133	 0.00407	 0.03937	 0.0	 799	 799	 799	 0.0	 0.0	 1	 -30.0	 30.0;
	2730	 1133	 0.00415	 0.03856	 0.0	 815	 815	 815	 0.0	 0.0	 1	 -30.0	 30.0;
	6127	 5111	 0.00869	 0.05343	 0.0	 572.0	 584	 584	 0.0	 0.0	 1	 -30.0	 30.0;
	6127	 2172	 0.0068	 0.036961	 0.0	 457.0	 841	 841	 0.0	 0.0	 1	 -30.0	 30.0;
	6127	 2658	 0.01805	 0.095469	 0.0	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	7600	 7283	 0.00045	 0.00206	 0.0	 533.0	 14981	 14981	 0.0	 0.0	 1	 -30.0	 30.0;
	473	 7193	 0.0095	 0.037159	 0.0	 419.0	 824	 824	 0.0	 0.0	 1	 -30.0	 30.0;
	473	 5025	 0.02106	 0.0885	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	7395	 5873	 0.00157	 0.02318	 0.0	 1360	 1360	 1360	 0.0	 0.0	 1	 -30.0	 30.0;
	7395	 3662	 0.00032	 0.00282	 0.0	 1711.0	 11130	 11130	 0.0	 0.0	 1	 -30.0	 30.0;
	7395	 4931	 0.00165	 0.01605	 0.0	 889.0	 1958	 1958	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 489	 0.00107	 0.00714	 0.0	 400.0	 4376	 4376	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 489	 0.000961	 0.00555	 0.0	 400.0	 5608	 5608	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 8529	 0.00074	 0.00461	 0.0	 6766	 6766	 6766	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 7064	 0.00076	 0.00451	 0.0	 6907	 6907	 6907	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 4058	 0.001419	 0.01093	 0.0	 533.0	 2866	 2866	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 4658	 0.003729	 0.024599	 0.0	 476.0	 1270	 1270	 0.0	 0.0	 1	 -30.0	 30.0;
	2437	 7029	 0.00233	 0.01992	 0.0	 1575	 1575	 1575	 0.0	 0.0	 1	 -30.0	 30.0;
	2437	 7029	 0.00238	 0.01949	 0.0	 1609	 1609	 1609	 0.0	 0.0	 1	 -30.0	 30.0;
	2437	 4795	 0.00217	 0.0253	 0.0	 1244	 1244	 1244	 0.0	 0.0	 1	 -30.0	 30.0;
	2437	 4795	 0.00212	 0.02579	 0.0	 1221	 1221	 1221	 0.0	 0.0	 1	 -30.0	 30.0;
	2437	 1133	 0.00458	 0.04138	 0.0	 759	 759	 759	 0.0	 0.0	 1	 -30.0	 30.0;
	3792	 550	 0.01555	 0.089841	 0.0	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	6299	 3792	 0.00274	 0.0168	 0.0	 476.0	 1856	 1856	 0.0	 0.0	 1	 -30.0	 30.0;
	3792	 6879	 0.005831	 0.032211	 0.0	 438.0	 965	 965	 0.0	 0.0	 1	 -30.0	 30.0;
	3792	 4181	 0.006669	 0.031341	 0.0	 476.0	 986	 986	 0.0	 0.0	 1	 -30.0	 30.0;
	8702	 5163	 0.01081	 0.0538	 0.0	 476.0	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	8702	 7861	 0.005581	 0.02457	 0.0	 495.0	 1254	 1254	 0.0	 0.0	 1	 -30.0	 30.0;
	8702	 7861	 0.00569	 0.024039	 0.0	 533.0	 1279	 1279	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 7446	 0.002081	 0.01294	 0.0	 457.0	 2411	 2411	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 4897	 0.001599	 0.00919	 0.0	 3387	 3387	 3387	 0.0	 0.0	 1	 -30.0	 30.0;
	5239	 5873	 0.00083	 0.00768	 0.0	 1744.0	 4090	 4090	 0.0	 0.0	 1	 -30.0	 30.0;
	8438	 8147	 0.004979	 0.024099	 0.0	 1284	 1284	 1284	 0.0	 0.0	 1	 -30.0	 30.0;
	8438	 8147	 0.005081	 0.023591	 0.0	 476.0	 1309	 1309	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 266	 0.00412	 0.03917	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	266	 4843	 0.00086	 0.00798	 0.0	 1119.0	 3936	 3936	 0.0	 0.0	 1	 -30.0	 30.0;
	3275	 266	 0.00087	 0.00961	 0.0	 1218.0	 3274	 3274	 0.0	 0.0	 1	 -30.0	 30.0;
	8247	 266	 0.00095	 0.01034	 0.0	 1251.0	 3043	 3043	 0.0	 0.0	 1	 -30.0	 30.0;
	8374	 266	 0.00211	 0.0196	 0.0	 1119.0	 1603	 1603	 0.0	 0.0	 1	 -30.0	 30.0;
	7193	 5025	 0.00963	 0.05281	 0.0	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	1064	 3734	 0.00018	 0.001349	 0.0	 553.0	 23210	 23210	 0.0	 0.0	 1	 -30.0	 30.0;
	1064	 6456	 0.000961	 0.006021	 0.0	 381.0	 5181	 5181	 0.0	 0.0	 1	 -30.0	 30.0;
	1064	 6456	 0.000979	 0.00589	 0.0	 381.0	 5291	 5291	 0.0	 0.0	 1	 -30.0	 30.0;
	7877	 3063	 0.000461	 0.002729	 0.0	 610.0	 11413	 11413	 0.0	 0.0	 1	 -30.0	 30.0;
	986	 3367	 0.005039	 0.01901	 0.0	 381.0	 1607	 1607	 0.0	 0.0	 1	 -30.0	 30.0;
	986	 4603	 0.00812	 0.028919	 0.0	 419.0	 1052	 1052	 0.0	 0.0	 1	 -30.0	 30.0;
	7257	 6970	 0.00106	 0.01005	 0.0	 954.0	 3126	 3126	 0.0	 0.0	 1	 -30.0	 30.0;
	5873	 6768	 0.00074	 0.0081	 0.0	 1218.0	 3884	 3884	 0.0	 0.0	 1	 -30.0	 30.0;
	8147	 6174	 0.012961	 0.03605	 0.0	 825	 825	 825	 0.0	 0.0	 1	 -30.0	 30.0;
	8147	 6174	 0.00844	 0.0378	 0.0	 400.0	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	8147	 5162	 0.000591	 0.004169	 0.0	 553.0	 7502	 7502	 0.0	 0.0	 1	 -30.0	 30.0;
	6879	 6038	 0.003091	 0.012289	 0.0	 457.0	 2493	 2493	 0.0	 0.0	 1	 -30.0	 30.0;
	4556	 4592	 0.000969	 0.0053	 0.0	 553.0	 5863	 5863	 0.0	 0.0	 1	 -30.0	 30.0;
	2412	 2686	 0.00161	 0.012919	 0.0	 2427	 2427	 2427	 0.0	 0.0	 1	 -30.0	 30.0;
	2412	 2686	 0.003219	 0.01795	 0.0	 1733	 1733	 1733	 0.0	 0.0	 1	 -30.0	 30.0;
	2412	 3644	 0.004331	 0.025	 0.0	 1245	 1245	 1245	 0.0	 0.0	 1	 -30.0	 30.0;
	2412	 3644	 0.004409	 0.02445	 0.0	 1272	 1272	 1272	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 2551	 0.00425	 0.02014	 0.0	 1535	 1535	 1535	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 6904	 0.009531	 0.060979	 0.0	 495.0	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 1897	 0.002409	 0.0135	 0.0	 2304	 2304	 2304	 0.0	 0.0	 1	 -30.0	 30.0;
	3268	 8210	 0.0006	 0.00662	 0.0	 1678.0	 4753	 4753	 0.0	 0.0	 1	 -30.0	 30.0;
	3268	 2849	 0.00173	 0.01701	 0.0	 1678.0	 1848	 1848	 0.0	 0.0	 1	 -30.0	 30.0;
	6397	 1173	 0.004289	 0.018531	 0.0	 438.0	 1661	 1661	 0.0	 0.0	 1	 -30.0	 30.0;
	6397	 6936	 0.006919	 0.039789	 0.0	 419.0	 783	 783	 0.0	 0.0	 1	 -30.0	 30.0;
	6397	 6936	 0.007591	 0.035539	 0.0	 495.0	 870	 870	 0.0	 0.0	 1	 -30.0	 30.0;
	6397	 4750	 0.00961	 0.05225	 0.0	 419.0	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 6544	 0.000581	 0.004599	 0.0	 6815	 6815	 6815	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 6544	 0.00057	 0.00469	 0.0	 6686	 6686	 6686	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 6544	 0.00087	 0.003159	 0.0	 591.0	 9641	 9641	 0.0	 0.0	 1	 -30.0	 30.0;
	6436	 5217	 0.00018	 0.001419	 0.0	 22084	 22084	 22084	 0.0	 0.0	 1	 -30.0	 30.0;
	6436	 6717	 0.00195	 0.018841	 0.0	 1668	 1668	 1668	 0.0	 0.0	 1	 -30.0	 30.0;
	72	 6093	 0.00293	 0.01293	 0.0	 400.0	 2383	 2383	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 3233	 0.001969	 0.010599	 0.0	 438.0	 2931	 2931	 0.0	 0.0	 1	 -30.0	 30.0;
	6985	 854	 3.9e-05	 0.000591	 0.0	 53332	 53332	 53332	 0.0	 0.0	 1	 -30.0	 30.0;
	6985	 415	 0.00364	 0.02431	 0.0	 1286	 1286	 1286	 0.0	 0.0	 1	 -30.0	 30.0;
	6985	 1501	 0.00114	 0.007211	 0.0	 4327	 4327	 4327	 0.0	 0.0	 1	 -30.0	 30.0;
	489	 4238	 0.001271	 0.008659	 0.0	 381.0	 3610	 3610	 0.0	 0.0	 1	 -30.0	 30.0;
	489	 1411	 0.00105	 0.00668	 0.0	 4672	 4672	 4672	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 6681	 0.00011	 0.00122	 0.0	 987.0	 25787	 25787	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 3587	 0.00117	 0.0124	 0.0	 1349.0	 2537	 2537	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 8374	 0.00168	 0.01891	 0.0	 1185.0	 1664	 1664	 0.0	 0.0	 1	 -30.0	 30.0;
	797	 7819	 0.00132	 0.008281	 0.0	 572.0	 3767	 3767	 0.0	 0.0	 1	 -30.0	 30.0;
	797	 8378	 0.004531	 0.01924	 0.0	 1599	 1599	 1599	 0.0	 0.0	 1	 -30.0	 30.0;
	797	 1241	 0.007841	 0.041909	 0.0	 419.0	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	7929	 7755	 0.00113	 0.01235	 0.0	 1777.0	 2548	 2548	 0.0	 0.0	 1	 -30.0	 30.0;
	7929	 7755	 0.00128	 0.0121	 0.0	 1744.0	 2597	 2597	 0.0	 0.0	 1	 -30.0	 30.0;
	7929	 8625	 0.0015	 0.01792	 0.0	 1415.0	 1757	 1757	 0.0	 0.0	 1	 -30.0	 30.0;
	4592	 1471	 0.00111	 0.005281	 0.0	 5854	 5854	 5854	 0.0	 0.0	 1	 -30.0	 30.0;
	4592	 1471	 0.00113	 0.005169	 0.0	 5970	 5970	 5970	 0.0	 0.0	 1	 -30.0	 30.0;
	6040	 3111	 0.00563	 0.03255	 0.0	 476.0	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	1175	 3111	 0.005289	 0.022539	 0.0	 1365	 1365	 1365	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 6239	 0.007159	 0.05086	 0.0	 400.0	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 3689	 0.009669	 0.05649	 0.0	 552	 552	 552	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 6179	 0.0092	 0.052169	 0.0	 553.0	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	8396	 5091	 0.00197	 0.01594	 0.0	 1316.0	 1967	 1967	 0.0	 0.0	 1	 -30.0	 30.0;
	8396	 8806	 0.00343	 0.02573	 0.0	 1217	 1217	 1217	 0.0	 0.0	 1	 -30.0	 30.0;
	8396	 8247	 0.00151	 0.01485	 0.0	 1185.0	 2117	 2117	 0.0	 0.0	 1	 -30.0	 30.0;
	8396	 5060	 0.00092	 0.01042	 0.0	 1020.0	 3020	 3020	 0.0	 0.0	 1	 -30.0	 30.0;
	8396	 8012	 0.00029	 0.00336	 0.0	 1547.0	 9367	 9367	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 4489	 0.001711	 0.01255	 0.0	 2494	 2494	 2494	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 1503	 0.005	 0.03962	 0.0	 553.0	 791	 791	 0.0	 0.0	 1	 -30.0	 30.0;
	849	 1168	 0.0014	 0.01687	 0.0	 1251.0	 1866	 1866	 0.0	 0.0	 1	 -30.0	 30.0;
	849	 1168	 0.00067	 0.00678	 0.0	 1942.0	 4637	 4637	 0.0	 0.0	 1	 -30.0	 30.0;
	849	 1168	 0.00065	 0.00692	 0.0	 1678.0	 4545	 4545	 0.0	 0.0	 1	 -30.0	 30.0;
	6092	 849	 0.00137	 0.01524	 0.0	 1218.0	 2065	 2065	 0.0	 0.0	 1	 -30.0	 30.0;
	3840	 686	 0.00424	 0.02376	 0.0	 1309	 1309	 1309	 0.0	 0.0	 1	 -30.0	 30.0;
	3840	 5821	 0.005591	 0.031711	 0.0	 476.0	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	3840	 2225	 0.00138	 0.00649	 0.0	 419.0	 4761	 4761	 0.0	 0.0	 1	 -30.0	 30.0;
	3840	 2225	 0.00107	 0.00544	 0.0	 514.0	 5698	 5698	 0.0	 0.0	 1	 -30.0	 30.0;
	5091	 4390	 3e-05	 0.00041	 0.0	 1777.0	 76837	 76837	 0.0	 0.0	 1	 -30.0	 30.0;
	5091	 4390	 3e-05	 0.00041	 0.0	 1613.0	 76837	 76837	 0.0	 0.0	 1	 -30.0	 30.0;
	5091	 4957	 0.00044	 0.00342	 0.0	 1316.0	 9161	 9161	 0.0	 0.0	 1	 -30.0	 30.0;
	7446	 2504	 0.003841	 0.01737	 0.0	 438.0	 1776	 1776	 0.0	 0.0	 1	 -30.0	 30.0;
	1741	 1912	 0.001771	 0.01337	 0.0	 495.0	 2343	 2343	 0.0	 0.0	 1	 -30.0	 30.0;
	483	 2658	 0.00139	 0.007349	 0.0	 533.0	 4224	 4224	 0.0	 0.0	 1	 -30.0	 30.0;
	483	 5592	 0.00625	 0.03463	 0.0	 533.0	 898	 898	 0.0	 0.0	 1	 -30.0	 30.0;
	5111	 4360	 0.00055	 0.00255	 0.0	 12109	 12109	 12109	 0.0	 0.0	 1	 -30.0	 30.0;
	6596	 3512	 0.00489	 0.043331	 0.0	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	8701	 8207	 0.00145	 0.013099	 0.0	 381.0	 2397	 2397	 0.0	 0.0	 1	 -30.0	 30.0;
	8701	 1271	 0.004039	 0.02881	 0.0	 1086	 1086	 1086	 0.0	 0.0	 1	 -30.0	 30.0;
	2236	 4967	 0.002219	 0.00988	 0.0	 438.0	 3120	 3120	 0.0	 0.0	 1	 -30.0	 30.0;
	8575	 7845	 0.001919	 0.0153	 0.0	 400.0	 2049	 2049	 0.0	 0.0	 1	 -30.0	 30.0;
	8664	 1399	 0.00189	 0.01319	 0.0	 1382.0	 2371	 2371	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 8936	 0.00011	 0.000659	 0.0	 495.0	 47279	 47279	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 2564	 0.00011	 0.00064	 0.0	 457.0	 48642	 48642	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 3027	 0.000211	 0.00111	 0.0	 27957	 27957	 27957	 0.0	 0.0	 1	 -30.0	 30.0;
	6836	 6209	 0.000469	 0.001669	 0.0	 400.0	 18221	 18221	 0.0	 0.0	 1	 -30.0	 30.0;
	5923	 854	 6e-05	 0.000849	 0.0	 37113	 37113	 37113	 0.0	 0.0	 1	 -30.0	 30.0;
	7137	 7310	 0.00051	 0.00597	 0.0	 1580.0	 5272	 5272	 0.0	 0.0	 1	 -30.0	 30.0;
	7137	 6970	 0.00119	 0.01087	 0.0	 1218.0	 2889	 2889	 0.0	 0.0	 1	 -30.0	 30.0;
	5831	 7137	 0.00219	 0.01922	 0.0	 1382.0	 1633	 1633	 0.0	 0.0	 1	 -30.0	 30.0;
	5919	 2764	 0.00051	 0.00465	 0.0	 1580.0	 6753	 6753	 0.0	 0.0	 1	 -30.0	 30.0;
	8871	 8819	 0.00055	 0.0067	 0.0	 4699	 4699	 4699	 0.0	 0.0	 1	 -30.0	 30.0;
	2504	 5329	 0.005099	 0.027349	 0.0	 553.0	 1136	 1136	 0.0	 0.0	 1	 -30.0	 30.0;
	3233	 2844	 0.000599	 0.003961	 0.0	 476.0	 7885	 7885	 0.0	 0.0	 1	 -30.0	 30.0;
	3233	 3291	 0.005461	 0.032719	 0.0	 476.0	 953	 953	 0.0	 0.0	 1	 -30.0	 30.0;
	8149	 2896	 0.00349	 0.02256	 0.0	 476.0	 1384	 1384	 0.0	 0.0	 1	 -30.0	 30.0;
	8149	 1802	 0.00132	 0.00861	 0.0	 400.0	 3627	 3627	 0.0	 0.0	 1	 -30.0	 30.0;
	5828	 440	 0.0045	 0.01838	 0.0	 1670	 1670	 1670	 0.0	 0.0	 1	 -30.0	 30.0;
	5828	 1391	 0.004289	 0.019719	 0.0	 400.0	 1566	 1566	 0.0	 0.0	 1	 -30.0	 30.0;
	8236	 3027	 0.001409	 0.00881	 0.0	 495.0	 3541	 3541	 0.0	 0.0	 1	 -30.0	 30.0;
	1168	 6607	 0.00212	 0.01857	 0.0	 1415.0	 1691	 1691	 0.0	 0.0	 1	 -30.0	 30.0;
	1168	 7673	 0.00049	 0.00574	 0.0	 1613.0	 5484	 5484	 0.0	 0.0	 1	 -30.0	 30.0;
	1168	 754	 0.00184	 0.021	 0.0	 1499	 1499	 1499	 0.0	 0.0	 1	 -30.0	 30.0;
	2686	 4773	 0.00593	 0.037409	 0.0	 419.0	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	2225	 4177	 0.00514	 0.024169	 0.0	 438.0	 1279	 1279	 0.0	 0.0	 1	 -30.0	 30.0;
	3798	 2913	 0.00041	 0.00492	 0.0	 1251.0	 6399	 6399	 0.0	 0.0	 1	 -30.0	 30.0;
	3544	 2913	 0.00296	 0.02677	 0.0	 1173	 1173	 1173	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 550	 0.0072	 0.03406	 0.0	 381.0	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	3427	 6949	 0.00043	 0.00276	 0.0	 419.0	 11309	 11309	 0.0	 0.0	 1	 -30.0	 30.0;
	3427	 9028	 0.001789	 0.013469	 0.0	 533.0	 2325	 2325	 0.0	 0.0	 1	 -30.0	 30.0;
	4890	 7406	 0.00163	 0.011091	 0.0	 457.0	 2818	 2818	 0.0	 0.0	 1	 -30.0	 30.0;
	4890	 6349	 0.00036	 0.002651	 0.0	 11807	 11807	 11807	 0.0	 0.0	 1	 -30.0	 30.0;
	8867	 15	 0.00013	 0.00132	 0.0	 514.0	 23815	 23815	 0.0	 0.0	 1	 -30.0	 30.0;
	8867	 284	 0.000169	 0.001659	 0.0	 457.0	 18942	 18942	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 8534	 0.00136	 0.012831	 0.0	 2449	 2449	 2449	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 8534	 0.00139	 0.01256	 0.0	 2500	 2500	 2500	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 5276	 0.00126	 0.009521	 0.0	 3289	 3289	 3289	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 5276	 0.00143	 0.009331	 0.0	 3347	 3347	 3347	 0.0	 0.0	 1	 -30.0	 30.0;
	3644	 4428	 0.00164	 0.012961	 0.0	 2418	 2418	 2418	 0.0	 0.0	 1	 -30.0	 30.0;
	3644	 4428	 0.001599	 0.012	 0.0	 2610	 2610	 2610	 0.0	 0.0	 1	 -30.0	 30.0;
	6936	 2957	 0.001271	 0.00524	 0.0	 438.0	 5859	 5859	 0.0	 0.0	 1	 -30.0	 30.0;
	8240	 8973	 0.00226	 0.02465	 0.0	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	6543	 3715	 0.00032	 0.0015	 0.0	 514.0	 20595	 20595	 0.0	 0.0	 1	 -30.0	 30.0;
	6543	 5948	 0.00032	 0.00112	 0.0	 419.0	 27118	 27118	 0.0	 0.0	 1	 -30.0	 30.0;
	3275	 4931	 0.00075	 0.00817	 0.0	 1053.0	 3851	 3851	 0.0	 0.0	 1	 -30.0	 30.0;
	8163	 3425	 0.00037	 0.0027	 0.0	 553.0	 11591	 11591	 0.0	 0.0	 1	 -30.0	 30.0;
	3425	 6783	 3.9e-05	 0.000219	 0.0	 142001	 142001	 142001	 0.0	 0.0	 1	 -30.0	 30.0;
	2172	 595	 0.012781	 0.05762	 0.0	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	8658	 1065	 0.00036	 0.001289	 0.0	 23603	 23603	 23603	 0.0	 0.0	 1	 -30.0	 30.0;
	6090	 1175	 0.006771	 0.039349	 0.0	 792	 792	 792	 0.0	 0.0	 1	 -30.0	 30.0;
	3106	 7673	 0.00292	 0.02831	 0.0	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	3106	 2096	 0.00134	 0.01229	 0.0	 1514.0	 2556	 2556	 0.0	 0.0	 1	 -30.0	 30.0;
	8163	 5500	 0.00011	 0.00063	 0.0	 572.0	 49392	 49392	 0.0	 0.0	 1	 -30.0	 30.0;
	7249	 8207	 0.0003	 0.003331	 0.0	 9445	 9445	 9445	 0.0	 0.0	 1	 -30.0	 30.0;
	7249	 3692	 0.001289	 0.01555	 0.0	 2025	 2025	 2025	 0.0	 0.0	 1	 -30.0	 30.0;
	6783	 5923	 0.00011	 0.0017	 0.0	 553.0	 18543	 18543	 0.0	 0.0	 1	 -30.0	 30.0;
	6783	 8575	 0.00043	 0.00249	 0.0	 533.0	 12501	 12501	 0.0	 0.0	 1	 -30.0	 30.0;
	1121	 4657	 0.002651	 0.016771	 0.0	 1861	 1861	 1861	 0.0	 0.0	 1	 -30.0	 30.0;
	3487	 1121	 0.0082	 0.025081	 0.0	 400.0	 1198	 1198	 0.0	 0.0	 1	 -30.0	 30.0;
	3442	 8819	 0.00037	 0.002781	 0.0	 591.0	 11260	 11260	 0.0	 0.0	 1	 -30.0	 30.0;
	4856	 4906	 0.010719	 0.054719	 0.0	 400.0	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	3076	 4906	 0.006469	 0.04074	 0.0	 400.0	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	5884	 8973	 0.00101	 0.01274	 0.0	 1283.0	 2472	 2472	 0.0	 0.0	 1	 -30.0	 30.0;
	8207	 5961	 9.1e-05	 0.05076	 0.0	 419.0	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	8207	 3629	 0.00588	 0.03938	 0.0	 457.0	 794	 794	 0.0	 0.0	 1	 -30.0	 30.0;
	8207	 3692	 0.003591	 0.022099	 0.0	 438.0	 1411	 1411	 0.0	 0.0	 1	 -30.0	 30.0;
	8207	 7630	 0.00555	 0.032521	 0.0	 958	 958	 958	 0.0	 0.0	 1	 -30.0	 30.0;
	6877	 7755	 0.00116	 0.01347	 0.0	 1514.0	 2337	 2337	 0.0	 0.0	 1	 -30.0	 30.0;
	6877	 7755	 0.00113	 0.01247	 0.0	 1547.0	 2523	 2523	 0.0	 0.0	 1	 -30.0	 30.0;
	5042	 179	 0.00107	 0.00871	 0.0	 954.0	 3600	 3600	 0.0	 0.0	 1	 -30.0	 30.0;
	5042	 4442	 0.00078	 0.00609	 0.0	 1382.0	 5145	 5145	 0.0	 0.0	 1	 -30.0	 30.0;
	2566	 6768	 0.00075	 0.00604	 0.0	 1119.0	 5190	 5190	 0.0	 0.0	 1	 -30.0	 30.0;
	4897	 6717	 0.00224	 0.011091	 0.0	 2792	 2792	 2792	 0.0	 0.0	 1	 -30.0	 30.0;
	7475	 6949	 0.001961	 0.013969	 0.0	 400.0	 2240	 2240	 0.0	 0.0	 1	 -30.0	 30.0;
	1294	 5162	 0.001271	 0.00761	 0.0	 476.0	 4095	 4095	 0.0	 0.0	 1	 -30.0	 30.0;
	6681	 8806	 0.00374	 0.03581	 0.0	 878	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	6681	 8806	 0.00385	 0.03284	 0.0	 956	 956	 956	 0.0	 0.0	 1	 -30.0	 30.0;
	6681	 8806	 0.00392	 0.03216	 0.0	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	6681	 8973	 0.00307	 0.03131	 0.0	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	7819	 32	 0.027	 0.131289	 0.0	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	6333	 5512	 0.005539	 0.0195	 0.0	 1559	 1559	 1559	 0.0	 0.0	 1	 -30.0	 30.0;
	8534	 9039	 0.003099	 0.017849	 0.0	 495.0	 1744	 1744	 0.0	 0.0	 1	 -30.0	 30.0;
	8534	 5276	 0.002831	 0.014099	 0.0	 533.0	 2197	 2197	 0.0	 0.0	 1	 -30.0	 30.0;
	4026	 2261	 0.0	 0.01368	 0.0	 1580.0	 2310	 2310	 0.0	 0.0	 1	 -30.0	 30.0;
	4204	 4657	 0.01082	 0.079719	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	731	 2764	 0.00102	 0.00941	 0.0	 1251.0	 3338	 3338	 0.0	 0.0	 1	 -30.0	 30.0;
	731	 597	 0.00183	 0.01819	 0.0	 1728	 1728	 1728	 0.0	 0.0	 1	 -30.0	 30.0;
	731	 385	 0.00028	 0.00346	 0.0	 1251.0	 9100	 9100	 0.0	 0.0	 1	 -30.0	 30.0;
	3728	 2564	 0.0012	 0.00982	 0.0	 3193	 3193	 3193	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 2622	 0.00027	 0.0032	 0.0	 1810.0	 9837	 9837	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 7688	 0.00064	 0.00679	 0.0	 1152.0	 4632	 4632	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 8260	 0.00047	 0.00442	 0.0	 1711.0	 7107	 7107	 0.0	 0.0	 1	 -30.0	 30.0;
	415	 3367	 0.00493	 0.017599	 0.0	 495.0	 1729	 1729	 0.0	 0.0	 1	 -30.0	 30.0;
	415	 4081	 0.00207	 0.0153	 0.0	 2046	 2046	 2046	 0.0	 0.0	 1	 -30.0	 30.0;
	7287	 7755	 0.00094	 0.0092	 0.0	 1909.0	 3416	 3416	 0.0	 0.0	 1	 -30.0	 30.0;
	7287	 7755	 0.00095	 0.00901	 0.0	 1711.0	 3487	 3487	 0.0	 0.0	 1	 -30.0	 30.0;
	947	 2785	 0.00101	 0.00719	 0.0	 4351	 4351	 4351	 0.0	 0.0	 1	 -30.0	 30.0;
	3734	 6654	 0.000419	 0.00331	 0.0	 572.0	 9468	 9468	 0.0	 0.0	 1	 -30.0	 30.0;
	2551	 1897	 0.002099	 0.015599	 0.0	 2007	 2007	 2007	 0.0	 0.0	 1	 -30.0	 30.0;
	8806	 8664	 0.00163	 0.01283	 0.0	 1283.0	 2443	 2443	 0.0	 0.0	 1	 -30.0	 30.0;
	8806	 7428	 0.00445	 0.03788	 0.0	 829	 829	 829	 0.0	 0.0	 1	 -30.0	 30.0;
	8806	 4652	 0.00092	 0.00703	 0.0	 1218.0	 4456	 4456	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 32	 9.1e-05	 0.000961	 0.0	 32723	 32723	 32723	 0.0	 0.0	 1	 -30.0	 30.0;
	1741	 249	 0.00387	 0.028599	 0.0	 1095	 1095	 1095	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 5290	 0.00949	 0.06625	 0.0	 472	 472	 472	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 4467	 0.00414	 0.035331	 0.0	 888	 888	 888	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 5290	 0.009781	 0.065581	 0.0	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	1391	 32	 0.02818	 0.116099	 0.0	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	32	 2143	 0.00324	 0.01912	 0.0	 381.0	 1629	 1629	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 6768	 0.00135	 0.01609	 0.0	 1613.0	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 5670	 0.00294	 0.0182	 0.0	 438.0	 1714	 1714	 0.0	 0.0	 1	 -30.0	 30.0;
	8066	 5961	 0.000711	 0.00649	 0.0	 457.0	 4839	 4839	 0.0	 0.0	 1	 -30.0	 30.0;
	442	 8066	 0.002651	 0.01375	 0.0	 2256	 2256	 2256	 0.0	 0.0	 1	 -30.0	 30.0;
	1271	 5961	 0.00105	 0.008469	 0.0	 419.0	 3702	 3702	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 4489	 0.002229	 0.016461	 0.0	 495.0	 1902	 1902	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 4489	 0.002281	 0.01613	 0.0	 495.0	 1940	 1940	 0.0	 0.0	 1	 -30.0	 30.0;
	602	 4489	 0.003341	 0.012651	 0.0	 2415	 2415	 2415	 0.0	 0.0	 1	 -30.0	 30.0;
	602	 4489	 0.003271	 0.012901	 0.0	 2374	 2374	 2374	 0.0	 0.0	 1	 -30.0	 30.0;
	6484	 7918	 0.00101	 0.01218	 0.0	 1843.0	 2585	 2585	 0.0	 0.0	 1	 -30.0	 30.0;
	6484	 7436	 0.0009	 0.0095	 0.0	 3311	 3311	 3311	 0.0	 0.0	 1	 -30.0	 30.0;
	7918	 4690	 0.00098	 0.01241	 0.0	 2538	 2538	 2538	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 1942	 0.001219	 0.00951	 0.0	 3295	 3295	 3295	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 8419	 0.001789	 0.01382	 0.0	 2267	 2267	 2267	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 8419	 0.00175	 0.014081	 0.0	 2227	 2227	 2227	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 3382	 9.1e-05	 0.00087	 0.0	 36111	 36111	 36111	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 3382	 9.1e-05	 0.00086	 0.0	 36526	 36526	 36526	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 7869	 0.000229	 0.00236	 0.0	 400.0	 13322	 13322	 0.0	 0.0	 1	 -30.0	 30.0;
	686	 5171	 0.00125	 0.00557	 0.0	 591.0	 5534	 5534	 0.0	 0.0	 1	 -30.0	 30.0;
	2172	 5191	 0.00757	 0.04013	 0.0	 774	 774	 774	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 179	 0.00157	 0.01604	 0.0	 1382.0	 1960	 1960	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 179	 0.00154	 0.01634	 0.0	 1283.0	 1925	 1925	 0.0	 0.0	 1	 -30.0	 30.0;
	179	 2096	 0.00169	 0.02383	 0.0	 1323	 1323	 1323	 0.0	 0.0	 1	 -30.0	 30.0;
	1728	 179	 0.00068	 0.0089	 0.0	 1547.0	 3539	 3539	 0.0	 0.0	 1	 -30.0	 30.0;
	1850	 4603	 0.010289	 0.036651	 0.0	 476.0	 830	 830	 0.0	 0.0	 1	 -30.0	 30.0;
	1850	 4603	 0.00563	 0.03395	 0.0	 918	 918	 918	 0.0	 0.0	 1	 -30.0	 30.0;
	3109	 5726	 0.003591	 0.02763	 0.0	 1134	 1134	 1134	 0.0	 0.0	 1	 -30.0	 30.0;
	3109	 5726	 0.00351	 0.028159	 0.0	 1114	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	5726	 4773	 0.00143	 0.00838	 0.0	 3716	 3716	 3716	 0.0	 0.0	 1	 -30.0	 30.0;
	7659	 6879	 0.01213	 0.06156	 0.0	 476.0	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 5171	 0.004789	 0.022849	 0.0	 553.0	 1354	 1354	 0.0	 0.0	 1	 -30.0	 30.0;
	527	 8242	 0.00019	 0.00211	 0.0	 457.0	 14910	 14910	 0.0	 0.0	 1	 -30.0	 30.0;
	527	 8529	 0.000331	 0.002349	 0.0	 13316	 13316	 13316	 0.0	 0.0	 1	 -30.0	 30.0;
	527	 8530	 9.1e-05	 0.000539	 0.0	 381.0	 57786	 57786	 0.0	 0.0	 1	 -30.0	 30.0;
	6496	 6607	 0.00088	 0.00776	 0.0	 1382.0	 4045	 4045	 0.0	 0.0	 1	 -30.0	 30.0;
	4652	 4706	 0.00039	 0.00368	 0.0	 8536	 8536	 8536	 0.0	 0.0	 1	 -30.0	 30.0;
	6656	 2091	 0.00275	 0.01268	 0.0	 400.0	 2435	 2435	 0.0	 0.0	 1	 -30.0	 30.0;
	6656	 8993	 0.00205	 0.00874	 0.0	 3519	 3519	 3519	 0.0	 0.0	 1	 -30.0	 30.0;
	6656	 1241	 0.00082	 0.00519	 0.0	 591.0	 6012	 6012	 0.0	 0.0	 1	 -30.0	 30.0;
	2658	 808	 0.00519	 0.02355	 0.0	 457.0	 1310	 1310	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 6749	 0.016711	 0.08874	 0.0	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	7406	 4397	 0.005099	 0.022659	 0.0	 476.0	 1361	 1361	 0.0	 0.0	 1	 -30.0	 30.0;
	7406	 1769	 0.001469	 0.01213	 0.0	 591.0	 2586	 2586	 0.0	 0.0	 1	 -30.0	 30.0;
	7406	 1769	 0.001659	 0.01189	 0.0	 533.0	 2632	 2632	 0.0	 0.0	 1	 -30.0	 30.0;
	1013	 4467	 0.000521	 0.00374	 0.0	 419.0	 8366	 8366	 0.0	 0.0	 1	 -30.0	 30.0;
	1013	 5025	 0.006461	 0.048349	 0.0	 648	 648	 648	 0.0	 0.0	 1	 -30.0	 30.0;
	7918	 7310	 0.00293	 0.0257	 0.0	 1222	 1222	 1222	 0.0	 0.0	 1	 -30.0	 30.0;
	7918	 5608	 0.00178	 0.0157	 0.0	 1415.0	 2000	 2000	 0.0	 0.0	 1	 -30.0	 30.0;
	5831	 7918	 0.00115	 0.01332	 0.0	 1086.0	 2363	 2363	 0.0	 0.0	 1	 -30.0	 30.0;
	7918	 2202	 0.00078	 0.00752	 0.0	 1678.0	 4179	 4179	 0.0	 0.0	 1	 -30.0	 30.0;
	77	 6660	 3.9e-05	 0.00037	 0.0	 84901	 84901	 84901	 0.0	 0.0	 1	 -30.0	 30.0;
	8124	 8419	 0.0012	 0.006729	 0.0	 533.0	 4622	 4622	 0.0	 0.0	 1	 -30.0	 30.0;
	33	 3334	 0.000211	 0.001659	 0.0	 18888	 18888	 18888	 0.0	 0.0	 1	 -30.0	 30.0;
	6490	 8301	 0.001659	 0.011919	 0.0	 495.0	 2625	 2625	 0.0	 0.0	 1	 -30.0	 30.0;
	6490	 6869	 0.002	 0.0133	 0.0	 438.0	 2349	 2349	 0.0	 0.0	 1	 -30.0	 30.0;
	4371	 7820	 0.00105	 0.00837	 0.0	 3745	 3745	 3745	 0.0	 0.0	 1	 -30.0	 30.0;
	2896	 5348	 0.00138	 0.014979	 0.0	 2100	 2100	 2100	 0.0	 0.0	 1	 -30.0	 30.0;
	5767	 6836	 0.0	 0.0003	 0.0	 105292	 105292	 105292	 0.0	 0.0	 1	 -30.0	 30.0;
	2978	 6836	 0.0	 0.0003	 0.0	 419.0	 105292	 105292	 0.0	 0.0	 1	 -30.0	 30.0;
	2978	 5391	 0.00164	 0.00782	 0.0	 400.0	 3954	 3954	 0.0	 0.0	 1	 -30.0	 30.0;
	3629	 230	 0.007099	 0.04044	 0.0	 514.0	 770	 770	 0.0	 0.0	 1	 -30.0	 30.0;
	9039	 7861	 0.00181	 0.00914	 0.0	 572.0	 3391	 3391	 0.0	 0.0	 1	 -30.0	 30.0;
	1479	 7343	 0.00027	 0.00247	 0.0	 1942.0	 12713	 12713	 0.0	 0.0	 1	 -30.0	 30.0;
	7343	 4957	 0.00266	 0.03206	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	8338	 981	 0.000591	 0.005081	 0.0	 400.0	 6176	 6176	 0.0	 0.0	 1	 -30.0	 30.0;
	8338	 751	 0.002229	 0.016099	 0.0	 419.0	 1944	 1944	 0.0	 0.0	 1	 -30.0	 30.0;
	4026	 5372	 0.00205	 0.02585	 0.0	 1086.0	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	7821	 642	 0.00101	 0.0091	 0.0	 1316.0	 3450	 3450	 0.0	 0.0	 1	 -30.0	 30.0;
	7821	 5608	 0.001	 0.00871	 0.0	 1316.0	 3603	 3603	 0.0	 0.0	 1	 -30.0	 30.0;
	9097	 1513	 0.00112	 0.00895	 0.0	 3502	 3502	 3502	 0.0	 0.0	 1	 -30.0	 30.0;
	9097	 1513	 0.001099	 0.008289	 0.0	 3778	 3778	 3778	 0.0	 0.0	 1	 -30.0	 30.0;
	9097	 3125	 0.001289	 0.0095	 0.0	 3295	 3295	 3295	 0.0	 0.0	 1	 -30.0	 30.0;
	9097	 3125	 0.00126	 0.00968	 0.0	 3236	 3236	 3236	 0.0	 0.0	 1	 -30.0	 30.0;
	4315	 5464	 0.00065	 0.00723	 0.0	 1547.0	 4352	 4352	 0.0	 0.0	 1	 -30.0	 30.0;
	1942	 4095	 0.001781	 0.012669	 0.0	 2470	 2470	 2470	 0.0	 0.0	 1	 -30.0	 30.0;
	3966	 1074	 0.00086	 0.00956	 0.0	 1053.0	 3291	 3291	 0.0	 0.0	 1	 -30.0	 30.0;
	3966	 807	 0.00248	 0.02429	 0.0	 1283.0	 1294	 1294	 0.0	 0.0	 1	 -30.0	 30.0;
	3966	 4507	 0.00151	 0.01699	 0.0	 1316.0	 1852	 1852	 0.0	 0.0	 1	 -30.0	 30.0;
	5890	 3689	 0.003159	 0.01537	 0.0	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	8210	 3113	 0.00075	 0.00683	 0.0	 1349.0	 4598	 4598	 0.0	 0.0	 1	 -30.0	 30.0;
	8210	 2849	 0.00223	 0.02524	 0.0	 1247	 1247	 1247	 0.0	 0.0	 1	 -30.0	 30.0;
	642	 5608	 0.00191	 0.0208	 0.0	 987.0	 1513	 1513	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 642	 0.00074	 0.00784	 0.0	 921.0	 4012	 4012	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 642	 0.00073	 0.00799	 0.0	 1086.0	 3937	 3937	 0.0	 0.0	 1	 -30.0	 30.0;
	1421	 3621	 0.000789	 0.00482	 0.0	 514.0	 6468	 6468	 0.0	 0.0	 1	 -30.0	 30.0;
	2126	 1421	 0.000789	 0.004409	 0.0	 381.0	 7053	 7053	 0.0	 0.0	 1	 -30.0	 30.0;
	2844	 3291	 0.005461	 0.03161	 0.0	 533.0	 985	 985	 0.0	 0.0	 1	 -30.0	 30.0;
	1638	 8575	 6e-05	 0.00087	 0.0	 36222	 36222	 36222	 0.0	 0.0	 1	 -30.0	 30.0;
	3163	 1411	 0.00593	 0.040961	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	3163	 5025	 0.003771	 0.030841	 0.0	 1017	 1017	 1017	 0.0	 0.0	 1	 -30.0	 30.0;
	6454	 8571	 0.00038	 0.001461	 0.0	 533.0	 20925	 20925	 0.0	 0.0	 1	 -30.0	 30.0;
	8571	 4081	 0.00149	 0.00938	 0.0	 3326	 3326	 3326	 0.0	 0.0	 1	 -30.0	 30.0;
	8571	 4081	 0.001521	 0.00918	 0.0	 3395	 3395	 3395	 0.0	 0.0	 1	 -30.0	 30.0;
	2091	 440	 0.00407	 0.015469	 0.0	 1975	 1975	 1975	 0.0	 0.0	 1	 -30.0	 30.0;
	4953	 1421	 0.00082	 0.006219	 0.0	 5036	 5036	 5036	 0.0	 0.0	 1	 -30.0	 30.0;
	2667	 1969	 0.00161	 0.00888	 0.0	 438.0	 3501	 3501	 0.0	 0.0	 1	 -30.0	 30.0;
	2667	 9028	 0.00118	 0.006461	 0.0	 514.0	 4810	 4810	 0.0	 0.0	 1	 -30.0	 30.0;
	8819	 6134	 0.00082	 0.009091	 0.0	 3461	 3461	 3461	 0.0	 0.0	 1	 -30.0	 30.0;
	751	 4493	 0.01893	 0.0848	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	751	 4493	 0.01313	 0.082409	 0.0	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	751	 6344	 0.000281	 0.00149	 0.0	 20833	 20833	 20833	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 3113	 0.00019	 0.00199	 0.0	 1349.0	 15802	 15802	 0.0	 0.0	 1	 -30.0	 30.0;
	3113	 5289	 0.0002	 0.00188	 0.0	 1382.0	 16708	 16708	 0.0	 0.0	 1	 -30.0	 30.0;
	172	 2946	 0.003159	 0.025331	 0.0	 1238	 1238	 1238	 0.0	 0.0	 1	 -30.0	 30.0;
	7685	 6394	 0.00445	 0.01886	 0.0	 610.0	 1631	 1631	 0.0	 0.0	 1	 -30.0	 30.0;
	5821	 5329	 0.00461	 0.02205	 0.0	 514.0	 1403	 1403	 0.0	 0.0	 1	 -30.0	 30.0;
	7283	 8213	 0.00061	 0.00494	 0.0	 6347	 6347	 6347	 0.0	 0.0	 1	 -30.0	 30.0;
	7283	 962	 0.00082	 0.00462	 0.0	 6732	 6732	 6732	 0.0	 0.0	 1	 -30.0	 30.0;
	3468	 8661	 0.000331	 0.003271	 0.0	 553.0	 9608	 9608	 0.0	 0.0	 1	 -30.0	 30.0;
	3468	 1769	 0.00056	 0.004081	 0.0	 591.0	 7669	 7669	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 9055	 0.00163	 0.007521	 0.0	 4105	 4105	 4105	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 1471	 0.001659	 0.00736	 0.0	 4187	 4187	 4187	 0.0	 0.0	 1	 -30.0	 30.0;
	6544	 1503	 0.00719	 0.049211	 0.0	 636	 636	 636	 0.0	 0.0	 1	 -30.0	 30.0;
	7463	 1969	 6e-05	 0.00039	 0.0	 438.0	 80052	 80052	 0.0	 0.0	 1	 -30.0	 30.0;
	1030	 6022	 0.00288	 0.018	 0.0	 533.0	 1733	 1733	 0.0	 0.0	 1	 -30.0	 30.0;
	1030	 8776	 0.00288	 0.0182	 0.0	 495.0	 1715	 1715	 0.0	 0.0	 1	 -30.0	 30.0;
	1030	 5290	 0.00111	 0.008531	 0.0	 438.0	 3672	 3672	 0.0	 0.0	 1	 -30.0	 30.0;
	1030	 4279	 0.00307	 0.022289	 0.0	 514.0	 1404	 1404	 0.0	 0.0	 1	 -30.0	 30.0;
	3067	 4507	 0.00091	 0.00868	 0.0	 1547.0	 3620	 3620	 0.0	 0.0	 1	 -30.0	 30.0;
	5608	 9117	 0.00098	 0.0118	 0.0	 1481.0	 2668	 2668	 0.0	 0.0	 1	 -30.0	 30.0;
	5608	 7436	 0.00053	 0.00591	 0.0	 1645.0	 5324	 5324	 0.0	 0.0	 1	 -30.0	 30.0;
	5608	 2202	 0.00086	 0.00991	 0.0	 1349.0	 3176	 3176	 0.0	 0.0	 1	 -30.0	 30.0;
	7002	 3334	 0.00545	 0.034099	 0.0	 495.0	 915	 915	 0.0	 0.0	 1	 -30.0	 30.0;
	2060	 3495	 0.00095	 0.006091	 0.0	 553.0	 5124	 5124	 0.0	 0.0	 1	 -30.0	 30.0;
	3544	 807	 0.00305	 0.0272	 0.0	 1155	 1155	 1155	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 4910	 0.000281	 0.001841	 0.0	 438.0	 16962	 16962	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 6456	 0.004531	 0.02451	 0.0	 1268	 1268	 1268	 0.0	 0.0	 1	 -30.0	 30.0;
	4397	 1503	 0.00618	 0.02961	 0.0	 533.0	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	1513	 6745	 0.00064	 0.004461	 0.0	 7010	 7010	 7010	 0.0	 0.0	 1	 -30.0	 30.0;
	916	 4224	 0.00143	 0.00513	 0.0	 553.0	 5932	 5932	 0.0	 0.0	 1	 -30.0	 30.0;
	916	 1241	 0.0052	 0.021841	 0.0	 457.0	 1407	 1407	 0.0	 0.0	 1	 -30.0	 30.0;
	602	 4910	 0.00138	 0.008669	 0.0	 438.0	 3599	 3599	 0.0	 0.0	 1	 -30.0	 30.0;
	6456	 602	 0.00314	 0.013169	 0.0	 2334	 2334	 2334	 0.0	 0.0	 1	 -30.0	 30.0;
	4224	 1909	 0.002479	 0.01331	 0.0	 476.0	 2334	 2334	 0.0	 0.0	 1	 -30.0	 30.0;
	2297	 2740	 7e-05	 0.00194	 0.0	 16272	 16272	 16272	 0.0	 0.0	 1	 -30.0	 30.0;
	9162	 8419	 0.001159	 0.00931	 0.0	 3367	 3367	 3367	 0.0	 0.0	 1	 -30.0	 30.0;
	5391	 6349	 0.00062	 0.003669	 0.0	 8489	 8489	 8489	 0.0	 0.0	 1	 -30.0	 30.0;
	2517	 5163	 0.015969	 0.056711	 0.0	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	5163	 3754	 0.0085	 0.03719	 0.0	 419.0	 828	 828	 0.0	 0.0	 1	 -30.0	 30.0;
	2785	 9055	 0.001531	 0.00732	 0.0	 4224	 4224	 4224	 0.0	 0.0	 1	 -30.0	 30.0;
	2785	 9055	 0.00205	 0.01062	 0.0	 2921	 2921	 2921	 0.0	 0.0	 1	 -30.0	 30.0;
	4957	 5464	 0.00091	 0.01056	 0.0	 757.0	 2981	 2981	 0.0	 0.0	 1	 -30.0	 30.0;
	807	 8625	 0.00167	 0.02069	 0.0	 1522	 1522	 1522	 0.0	 0.0	 1	 -30.0	 30.0;
	6299	 6879	 0.002719	 0.016219	 0.0	 514.0	 1921	 1921	 0.0	 0.0	 1	 -30.0	 30.0;
	8247	 4390	 0.002	 0.02376	 0.0	 1325	 1325	 1325	 0.0	 0.0	 1	 -30.0	 30.0;
	8247	 4390	 0.00226	 0.02328	 0.0	 1351	 1351	 1351	 0.0	 0.0	 1	 -30.0	 30.0;
	7630	 442	 0.004151	 0.02119	 0.0	 533.0	 1463	 1463	 0.0	 0.0	 1	 -30.0	 30.0;
	8993	 8378	 0.001841	 0.010909	 0.0	 2856	 2856	 2856	 0.0	 0.0	 1	 -30.0	 30.0;
	6879	 4181	 0.000669	 0.00399	 0.0	 476.0	 7808	 7808	 0.0	 0.0	 1	 -30.0	 30.0;
	3662	 1475	 8e-05	 0.00098	 0.0	 1613.0	 32126	 32126	 0.0	 0.0	 1	 -30.0	 30.0;
	8242	 8530	 0.0002	 0.0025	 0.0	 12595	 12595	 12595	 0.0	 0.0	 1	 -30.0	 30.0;
	5494	 5290	 0.006219	 0.031599	 0.0	 533.0	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	5494	 1437	 0.00438	 0.023169	 0.0	 533.0	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	6145	 4279	 0.00581	 0.03088	 0.0	 514.0	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	6145	 4279	 0.0065	 0.02637	 0.0	 438.0	 1164	 1164	 0.0	 0.0	 1	 -30.0	 30.0;
	4652	 597	 0.00198	 0.02208	 0.0	 1425	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	3109	 5329	 0.00093	 0.006659	 0.0	 4698	 4698	 4698	 0.0	 0.0	 1	 -30.0	 30.0;
	3109	 5329	 0.000909	 0.006789	 0.0	 4612	 4612	 4612	 0.0	 0.0	 1	 -30.0	 30.0;
	4026	 1074	 0.00244	 0.01919	 0.0	 856.0	 1633	 1633	 0.0	 0.0	 1	 -30.0	 30.0;
	2355	 8582	 0.00194	 0.01549	 0.0	 2024	 2024	 2024	 0.0	 0.0	 1	 -30.0	 30.0;
	1666	 4058	 0.0002	 0.001479	 0.0	 514.0	 21165	 21165	 0.0	 0.0	 1	 -30.0	 30.0;
	4493	 1513	 0.001091	 0.009461	 0.0	 610.0	 3317	 3317	 0.0	 0.0	 1	 -30.0	 30.0;
	1513	 6604	 0.003081	 0.00899	 0.0	 495.0	 3324	 3324	 0.0	 0.0	 1	 -30.0	 30.0;
	6604	 1457	 0.00357	 0.0138	 0.0	 457.0	 2216	 2216	 0.0	 0.0	 1	 -30.0	 30.0;
	3495	 7629	 0.001229	 0.00986	 0.0	 476.0	 3179	 3179	 0.0	 0.0	 1	 -30.0	 30.0;
	1985	 9106	 0.001211	 0.00913	 0.0	 572.0	 3430	 3430	 0.0	 0.0	 1	 -30.0	 30.0;
	4957	 8012	 0.00116	 0.01053	 0.0	 1580.0	 2982	 2982	 0.0	 0.0	 1	 -30.0	 30.0;
	4651	 5681	 0.0017	 0.009781	 0.0	 3182	 3182	 3182	 0.0	 0.0	 1	 -30.0	 30.0;
	4651	 5681	 0.001521	 0.011091	 0.0	 2822	 2822	 2822	 0.0	 0.0	 1	 -30.0	 30.0;
	7795	 445	 0.0043	 0.0233	 0.0	 572.0	 1334	 1334	 0.0	 0.0	 1	 -30.0	 30.0;
	2700	 4446	 0.00019	 0.0016	 0.0	 987.0	 19605	 19605	 0.0	 0.0	 1	 -30.0	 30.0;
	4772	 8301	 0.00838	 0.072479	 0.0	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	4772	 988	 0.00787	 0.049211	 0.0	 634	 634	 634	 0.0	 0.0	 1	 -30.0	 30.0;
	442	 230	 0.00557	 0.03376	 0.0	 924	 924	 924	 0.0	 0.0	 1	 -30.0	 30.0;
	4238	 7312	 0.01213	 0.06564	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	7366	 3125	 0.003531	 0.01086	 0.0	 400.0	 2767	 2767	 0.0	 0.0	 1	 -30.0	 30.0;
	7366	 7423	 0.0158	 0.057031	 0.0	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	754	 2096	 0.00289	 0.0244	 0.0	 1283.0	 1286	 1286	 0.0	 0.0	 1	 -30.0	 30.0;
	1599	 4096	 0.000521	 0.00413	 0.0	 553.0	 7589	 7589	 0.0	 0.0	 1	 -30.0	 30.0;
	8079	 4096	 0.000531	 0.004039	 0.0	 495.0	 7754	 7754	 0.0	 0.0	 1	 -30.0	 30.0;
	230	 1802	 0.00431	 0.02226	 0.0	 419.0	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	3027	 4081	 0.00163	 0.00899	 0.0	 553.0	 3458	 3458	 0.0	 0.0	 1	 -30.0	 30.0;
	4652	 1280	 0.00274	 0.02428	 0.0	 1293	 1293	 1293	 0.0	 0.0	 1	 -30.0	 30.0;
	6315	 6022	 0.0093	 0.056979	 0.0	 514.0	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	6315	 8729	 0.011281	 0.080039	 0.0	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	6315	 5631	 0.00449	 0.02376	 0.0	 438.0	 1307	 1307	 0.0	 0.0	 1	 -30.0	 30.0;
	2622	 8260	 0.00014	 0.00148	 0.0	 1744.0	 21248	 21248	 0.0	 0.0	 1	 -30.0	 30.0;
	6797	 8301	 0.0055	 0.033659	 0.0	 419.0	 927	 927	 0.0	 0.0	 1	 -30.0	 30.0;
	4467	 5465	 0.00249	 0.02082	 0.0	 457.0	 1507	 1507	 0.0	 0.0	 1	 -30.0	 30.0;
	1728	 2096	 0.00164	 0.02252	 0.0	 1399	 1399	 1399	 0.0	 0.0	 1	 -30.0	 30.0;
	5793	 2147	 0.000961	 0.0047	 0.0	 6585	 6585	 6585	 0.0	 0.0	 1	 -30.0	 30.0;
	5793	 2147	 0.000979	 0.004599	 0.0	 6718	 6718	 6718	 0.0	 0.0	 1	 -30.0	 30.0;
	7688	 385	 0.00057	 0.00515	 0.0	 1251.0	 6097	 6097	 0.0	 0.0	 1	 -30.0	 30.0;
	8301	 6869	 0.00143	 0.011651	 0.0	 381.0	 2691	 2691	 0.0	 0.0	 1	 -30.0	 30.0;
	1501	 4081	 0.00126	 0.009211	 0.0	 3398	 3398	 3398	 0.0	 0.0	 1	 -30.0	 30.0;
	6022	 695	 9.1e-05	 0.000211	 0.0	 381.0	 137464	 137464	 0.0	 0.0	 1	 -30.0	 30.0;
	8776	 695	 0.000211	 0.000711	 0.0	 42591	 42591	 42591	 0.0	 0.0	 1	 -30.0	 30.0;
	8776	 5631	 0.01095	 0.07062	 0.0	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 5631	 0.00125	 0.007281	 0.0	 4276	 4276	 4276	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 5631	 0.001	 0.0045	 0.0	 6853	 6853	 6853	 0.0	 0.0	 1	 -30.0	 30.0;
	5465	 5025	 0.00282	 0.026419	 0.0	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	7632	 6625	 0.003479	 0.01456	 0.0	 2111	 2111	 2111	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 4279	 0.005521	 0.03418	 0.0	 457.0	 913	 913	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 4279	 0.00563	 0.033461	 0.0	 476.0	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	5025	 4752	 0.00095	 0.0072	 0.0	 419.0	 4350	 4350	 0.0	 0.0	 1	 -30.0	 30.0;
	5025	 7312	 0.00093	 0.007159	 0.0	 514.0	 4376	 4376	 0.0	 0.0	 1	 -30.0	 30.0;
	1437	 4279	 0.00988	 0.058651	 0.0	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	6654	 7869	 3.9e-05	 0.00044	 0.0	 591.0	 71510	 71510	 0.0	 0.0	 1	 -30.0	 30.0;
	6654	 7869	 3.9e-05	 0.00043	 0.0	 533.0	 73159	 73159	 0.0	 0.0	 1	 -30.0	 30.0;
	7351	 5441	 0.00018	 0.000781	 0.0	 39412	 39412	 39412	 0.0	 0.0	 1	 -30.0	 30.0;
	4314	 7571	 0.002961	 0.01669	 0.0	 419.0	 1864	 1864	 0.0	 0.0	 1	 -30.0	 30.0;
	5803	 3916	 0.00056	 0.00432	 0.0	 7252	 7252	 7252	 0.0	 0.0	 1	 -30.0	 30.0;
	6757	 6036	 0.0002	 0.00246	 0.0	 757.0	 12799	 12799	 0.0	 0.0	 1	 -30.0	 30.0;
	6757	 6921	 0.0003	 0.00377	 0.0	 1415.0	 8353	 8353	 0.0	 0.0	 1	 -30.0	 30.0;
	5019	 9112	 0.00014	 0.00057	 0.0	 53817	 53817	 53817	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 9112	 0.00013	 0.000729	 0.0	 42657	 42657	 42657	 0.0	 0.0	 1	 -30.0	 30.0;
	1436	 9112	 0.00012	 0.000581	 0.0	 53244	 53244	 53244	 0.0	 0.0	 1	 -30.0	 30.0;
	1851	 9112	 0.00011	 0.00064	 0.0	 48642	 48642	 48642	 0.0	 0.0	 1	 -30.0	 30.0;
	8331	 9112	 0.00019	 0.00056	 0.0	 53416	 53416	 53416	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 8791	 0.00062	 0.004909	 0.0	 629.0	 6384	 6384	 0.0	 0.0	 1	 -30.0	 30.0;
	9203	 7842	 7e-05	 0.00076	 0.0	 987.0	 41388	 41388	 0.0	 0.0	 1	 -30.0	 30.0;
	9203	 8997	 0.00066	 0.00622	 0.0	 1711.0	 5051	 5051	 0.0	 0.0	 1	 -30.0	 30.0;
	9203	 2129	 0.00054	 0.00752	 0.0	 4190	 4190	 4190	 0.0	 0.0	 1	 -30.0	 30.0;
	9203	 29	 0.00105	 0.00877	 0.0	 1415.0	 3577	 3577	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 8903	 8e-05	 0.00091	 0.0	 757.0	 34578	 34578	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 4598	 0.00056	 0.00719	 0.0	 1053.0	 4380	 4380	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 5533	 0.000531	 0.002039	 0.0	 419.0	 14992	 14992	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 4831	 0.008659	 0.03769	 0.0	 400.0	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 8961	 0.003849	 0.021099	 0.0	 1473	 1473	 1473	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 8522	 0.00688	 0.035969	 0.0	 400.0	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 6888	 0.006729	 0.03713	 0.0	 838	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 3401	 0.00111	 0.006651	 0.0	 514.0	 4685	 4685	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 641	 0.0023	 0.008909	 0.0	 3433	 3433	 3433	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 2600	 0.000841	 0.00313	 0.0	 9747	 9747	 9747	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 5351	 0.003521	 0.017479	 0.0	 400.0	 1772	 1772	 0.0	 0.0	 1	 -30.0	 30.0;
	3051	 718	 3.9e-05	 0.00025	 0.0	 610.0	 124840	 124840	 0.0	 0.0	 1	 -30.0	 30.0;
	3036	 2327	 0.000159	 0.000729	 0.0	 457.0	 42335	 42335	 0.0	 0.0	 1	 -30.0	 30.0;
	8651	 7473	 0.005281	 0.032099	 0.0	 495.0	 972	 972	 0.0	 0.0	 1	 -30.0	 30.0;
	8651	 7473	 0.005651	 0.029419	 0.0	 476.0	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	903	 3654	 0.000271	 0.00036	 0.0	 70101	 70101	 70101	 0.0	 0.0	 1	 -30.0	 30.0;
	8732	 7050	 0.00044	 0.00143	 0.0	 572.0	 21113	 21113	 0.0	 0.0	 1	 -30.0	 30.0;
	8732	 3912	 0.000159	 0.00074	 0.0	 553.0	 41734	 41734	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 1973	 0.00019	 0.000591	 0.0	 438.0	 50883	 50883	 0.0	 0.0	 1	 -30.0	 30.0;
	5131	 2928	 0.00019	 0.00087	 0.0	 35472	 35472	 35472	 0.0	 0.0	 1	 -30.0	 30.0;
	6629	 4918	 0.002591	 0.013659	 0.0	 419.0	 2273	 2273	 0.0	 0.0	 1	 -30.0	 30.0;
	6629	 7309	 0.00305	 0.01168	 0.0	 2617	 2617	 2617	 0.0	 0.0	 1	 -30.0	 30.0;
	413	 1102	 0.000159	 0.000599	 0.0	 533.0	 50969	 50969	 0.0	 0.0	 1	 -30.0	 30.0;
	413	 1102	 0.000159	 0.00062	 0.0	 495.0	 49351	 49351	 0.0	 0.0	 1	 -30.0	 30.0;
	3248	 4918	 0.00101	 0.004229	 0.0	 572.0	 7265	 7265	 0.0	 0.0	 1	 -30.0	 30.0;
	3248	 4281	 0.00319	 0.018651	 0.0	 553.0	 1670	 1670	 0.0	 0.0	 1	 -30.0	 30.0;
	3248	 7309	 0.000729	 0.00337	 0.0	 9162	 9162	 9162	 0.0	 0.0	 1	 -30.0	 30.0;
	1146	 1187	 0.002961	 0.012831	 0.0	 381.0	 2399	 2399	 0.0	 0.0	 1	 -30.0	 30.0;
	1146	 7945	 0.000591	 0.00339	 0.0	 9180	 9180	 9180	 0.0	 0.0	 1	 -30.0	 30.0;
	8900	 2421	 0.00024	 0.001219	 0.0	 25425	 25425	 25425	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 2972	 0.006219	 0.036341	 0.0	 476.0	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 6031	 0.001841	 0.01193	 0.0	 572.0	 2617	 2617	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 7264	 0.001409	 0.01113	 0.0	 514.0	 2816	 2816	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 283	 0.00151	 0.00768	 0.0	 476.0	 4036	 4036	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 3069	 0.00599	 0.03313	 0.0	 495.0	 939	 939	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 3390	 0.001771	 0.010151	 0.0	 457.0	 3066	 3066	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 4936	 0.00074	 0.00311	 0.0	 9881	 9881	 9881	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 4936	 0.000729	 0.003159	 0.0	 9744	 9744	 9744	 0.0	 0.0	 1	 -30.0	 30.0;
	3218	 7809	 0.005271	 0.01906	 0.0	 381.0	 1598	 1598	 0.0	 0.0	 1	 -30.0	 30.0;
	3218	 5455	 0.00906	 0.053151	 0.0	 419.0	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	3218	 1857	 0.00405	 0.0153	 0.0	 1996	 1996	 1996	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 5410	 0.00055	 0.003961	 0.0	 495.0	 7899	 7899	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 5410	 0.00055	 0.003729	 0.0	 438.0	 8381	 8381	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 1609	 0.00107	 0.007789	 0.0	 514.0	 4018	 4018	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 1609	 0.00112	 0.00775	 0.0	 572.0	 4034	 4034	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 1609	 0.001031	 0.00775	 0.0	 4041	 4041	 4041	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 2438	 0.00062	 0.003219	 0.0	 9636	 9636	 9636	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 954	 0.00068	 0.002659	 0.0	 514.0	 11510	 11510	 0.0	 0.0	 1	 -30.0	 30.0;
	9140	 502	 0.00193	 0.012479	 0.0	 591.0	 2502	 2502	 0.0	 0.0	 1	 -30.0	 30.0;
	9140	 3013	 0.001159	 0.007229	 0.0	 4315	 4315	 4315	 0.0	 0.0	 1	 -30.0	 30.0;
	9140	 2949	 0.00137	 0.008729	 0.0	 495.0	 3575	 3575	 0.0	 0.0	 1	 -30.0	 30.0;
	9140	 2949	 0.001401	 0.00855	 0.0	 533.0	 3646	 3646	 0.0	 0.0	 1	 -30.0	 30.0;
	9140	 2949	 0.001331	 0.008521	 0.0	 533.0	 3663	 3663	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 2208	 0.00031	 0.00081	 0.0	 381.0	 36421	 36421	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 8060	 0.000341	 0.00119	 0.0	 381.0	 25518	 25518	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 4484	 0.00031	 0.001281	 0.0	 476.0	 23967	 23967	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 4239	 0.00094	 0.0035	 0.0	 533.0	 8717	 8717	 0.0	 0.0	 1	 -30.0	 30.0;
	8535	 7047	 7e-05	 0.000651	 0.0	 48244	 48244	 48244	 0.0	 0.0	 1	 -30.0	 30.0;
	5477	 3657	 0.00019	 0.00124	 0.0	 591.0	 25180	 25180	 0.0	 0.0	 1	 -30.0	 30.0;
	5477	 2928	 0.000331	 0.002539	 0.0	 533.0	 12337	 12337	 0.0	 0.0	 1	 -30.0	 30.0;
	3145	 2918	 0.0016	 0.02113	 0.0	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	7770	 5317	 0.000909	 0.004711	 0.0	 457.0	 6584	 6584	 0.0	 0.0	 1	 -30.0	 30.0;
	7770	 5317	 0.00088	 0.004969	 0.0	 419.0	 6260	 6260	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 8676	 0.001841	 0.0088	 0.0	 3514	 3514	 3514	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 8189	 0.01013	 0.04238	 0.0	 495.0	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 2938	 0.00059	 0.00802	 0.0	 823.0	 3928	 3928	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 2938	 0.00054	 0.0079	 0.0	 757.0	 3990	 3990	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 3918	 0.00171	 0.02128	 0.0	 1086.0	 1480	 1480	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 3918	 0.00174	 0.02084	 0.0	 954.0	 1511	 1511	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 6581	 0.00086	 0.01433	 0.0	 1251.0	 2201	 2201	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 6581	 0.00087	 0.01404	 0.0	 823.0	 2246	 2246	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 3830	 0.00126	 0.01447	 0.0	 1218.0	 2175	 2175	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 5648	 0.00122	 0.01509	 0.0	 1152.0	 2087	 2087	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 5648	 0.00154	 0.019	 0.0	 1382.0	 1658	 1658	 0.0	 0.0	 1	 -30.0	 30.0;
	4918	 4907	 0.00474	 0.03564	 0.0	 572.0	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	4918	 5957	 0.006	 0.047849	 0.0	 533.0	 656	 656	 0.0	 0.0	 1	 -30.0	 30.0;
	4918	 5233	 0.008039	 0.03375	 0.0	 381.0	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	6854	 7309	 2.1e-05	 0.000211	 0.0	 610.0	 148968	 148968	 0.0	 0.0	 1	 -30.0	 30.0;
	8311	 3680	 0.00045	 0.002341	 0.0	 13251	 13251	 13251	 0.0	 0.0	 1	 -30.0	 30.0;
	2770	 8804	 0.000669	 0.004281	 0.0	 533.0	 7291	 7291	 0.0	 0.0	 1	 -30.0	 30.0;
	9241	 8804	 0.00068	 0.00419	 0.0	 7442	 7442	 7442	 0.0	 0.0	 1	 -30.0	 30.0;
	3083	 7124	 0.000729	 0.00431	 0.0	 610.0	 7227	 7227	 0.0	 0.0	 1	 -30.0	 30.0;
	3083	 7124	 0.000591	 0.004651	 0.0	 553.0	 6738	 6738	 0.0	 0.0	 1	 -30.0	 30.0;
	3083	 8873	 0.00099	 0.005081	 0.0	 438.0	 6103	 6103	 0.0	 0.0	 1	 -30.0	 30.0;
	1566	 7582	 0.00212	 0.013031	 0.0	 2393	 2393	 2393	 0.0	 0.0	 1	 -30.0	 30.0;
	1566	 3541	 0.002159	 0.01275	 0.0	 2443	 2443	 2443	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 3698	 0.00025	 0.00095	 0.0	 32156	 32156	 32156	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 3698	 0.000271	 0.00089	 0.0	 33953	 33953	 33953	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 2801	 0.001961	 0.012409	 0.0	 381.0	 2515	 2515	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 8328	 0.00044	 0.00207	 0.0	 572.0	 14927	 14927	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 8511	 0.000469	 0.00143	 0.0	 629.0	 20990	 20990	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 6570	 0.001271	 0.01406	 0.0	 629.0	 2238	 2238	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 6570	 0.00124	 0.013021	 0.0	 629.0	 2415	 2415	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 8975	 0.000409	 0.00239	 0.0	 13028	 13028	 13028	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 216	 0.00094	 0.005	 0.0	 438.0	 6209	 6209	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 2961	 0.000219	 0.0007	 0.0	 629.0	 43067	 43067	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 6773	 6e-05	 0.00025	 0.0	 122861	 122861	 122861	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 5278	 5e-05	 0.000229	 0.0	 134762	 134762	 134762	 0.0	 0.0	 1	 -30.0	 30.0;
	3768	 2751	 0.00019	 0.000909	 0.0	 34015	 34015	 34015	 0.0	 0.0	 1	 -30.0	 30.0;
	2276	 5546	 0.001711	 0.00782	 0.0	 3946	 3946	 3946	 0.0	 0.0	 1	 -30.0	 30.0;
	2276	 6816	 0.002651	 0.01176	 0.0	 419.0	 2621	 2621	 0.0	 0.0	 1	 -30.0	 30.0;
	7766	 444	 0.001409	 0.010599	 0.0	 2955	 2955	 2955	 0.0	 0.0	 1	 -30.0	 30.0;
	7766	 5334	 0.001419	 0.010219	 0.0	 3062	 3062	 3062	 0.0	 0.0	 1	 -30.0	 30.0;
	839	 3918	 0.00013	 0.00212	 0.0	 856.0	 14872	 14872	 0.0	 0.0	 1	 -30.0	 30.0;
	839	 809	 0.00026	 0.00313	 0.0	 1382.0	 10058	 10058	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 2286	 0.0047	 0.0318	 0.0	 476.0	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 6802	 0.00136	 0.00768	 0.0	 438.0	 4050	 4050	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 3520	 0.005669	 0.027789	 0.0	 400.0	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 6271	 0.004409	 0.033091	 0.0	 381.0	 947	 947	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 1435	 0.01056	 0.044469	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 7148	 0.01963	 0.07736	 0.0	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 7437	 0.01157	 0.04694	 0.0	 457.0	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 871	 0.000479	 0.00255	 0.0	 457.0	 12175	 12175	 0.0	 0.0	 1	 -30.0	 30.0;
	7580	 871	 0.000469	 0.00236	 0.0	 13128	 13128	 13128	 0.0	 0.0	 1	 -30.0	 30.0;
	1188	 1539	 0.01237	 0.067039	 0.0	 381.0	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	1188	 8515	 0.0132	 0.056229	 0.0	 381.0	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	3971	 4084	 0.00026	 0.001711	 0.0	 18252	 18252	 18252	 0.0	 0.0	 1	 -30.0	 30.0;
	3971	 4084	 0.000271	 0.001669	 0.0	 18682	 18682	 18682	 0.0	 0.0	 1	 -30.0	 30.0;
	6845	 5340	 0.000211	 0.000401	 0.0	 69711	 69711	 69711	 0.0	 0.0	 1	 -30.0	 30.0;
	8294	 5814	 0.00105	 0.005159	 0.0	 6000	 6000	 6000	 0.0	 0.0	 1	 -30.0	 30.0;
	7115	 6807	 0.00212	 0.00931	 0.0	 419.0	 3309	 3309	 0.0	 0.0	 1	 -30.0	 30.0;
	619	 6791	 0.000151	 0.00068	 0.0	 45348	 45348	 45348	 0.0	 0.0	 1	 -30.0	 30.0;
	5418	 4908	 0.00019	 0.00082	 0.0	 37527	 37527	 37527	 0.0	 0.0	 1	 -30.0	 30.0;
	5120	 6816	 0.003219	 0.01405	 0.0	 400.0	 2192	 2192	 0.0	 0.0	 1	 -30.0	 30.0;
	6692	 9158	 0.007271	 0.033159	 0.0	 381.0	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	6692	 8035	 0.006659	 0.03132	 0.0	 400.0	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 2848	 0.00057	 0.00668	 0.0	 1580.0	 4712	 4712	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 7056	 0.00057	 0.00758	 0.0	 1514.0	 4156	 4156	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 7056	 0.00039	 0.00607	 0.0	 921.0	 5194	 5194	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 1642	 0.00155	 0.0179	 0.0	 1759	 1759	 1759	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 4594	 0.00036	 0.00485	 0.0	 1645.0	 6495	 6495	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 1692	 0.000581	 0.004229	 0.0	 438.0	 7400	 7400	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 8190	 0.00056	 0.00431	 0.0	 7268	 7268	 7268	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 5836	 0.003099	 0.020531	 0.0	 572.0	 1522	 1522	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 3191	 0.00118	 0.016919	 0.0	 610.0	 1863	 1863	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 5300	 0.00188	 0.01407	 0.0	 2226	 2226	 2226	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 4889	 0.00545	 0.04082	 0.0	 457.0	 768	 768	 0.0	 0.0	 1	 -30.0	 30.0;
	7264	 444	 0.00214	 0.01639	 0.0	 553.0	 1912	 1912	 0.0	 0.0	 1	 -30.0	 30.0;
	7264	 4747	 0.002479	 0.01549	 0.0	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 9011	 0.000159	 0.001229	 0.0	 572.0	 25490	 25490	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 6675	 0.00026	 0.00162	 0.0	 553.0	 19252	 19252	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 6909	 0.000159	 0.00113	 0.0	 476.0	 27681	 27681	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 8835	 0.000461	 0.003219	 0.0	 572.0	 9714	 9714	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 4186	 0.000159	 0.001229	 0.0	 25490	 25490	 25490	 0.0	 0.0	 1	 -30.0	 30.0;
	1604	 502	 0.000229	 0.00139	 0.0	 476.0	 22423	 22423	 0.0	 0.0	 1	 -30.0	 30.0;
	2842	 502	 0.0002	 0.00156	 0.0	 438.0	 20084	 20084	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 513	 0.00145	 0.00824	 0.0	 381.0	 3776	 3776	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 502	 0.00069	 0.005	 0.0	 591.0	 6259	 6259	 0.0	 0.0	 1	 -30.0	 30.0;
	891	 3697	 0.00036	 0.00455	 0.0	 1909.0	 6921	 6921	 0.0	 0.0	 1	 -30.0	 30.0;
	891	 3697	 0.00036	 0.00453	 0.0	 1876.0	 6952	 6952	 0.0	 0.0	 1	 -30.0	 30.0;
	8312	 7541	 0.00066	 0.00997	 0.0	 1448.0	 3162	 3162	 0.0	 0.0	 1	 -30.0	 30.0;
	8312	 7541	 0.00064	 0.01016	 0.0	 1086.0	 3103	 3103	 0.0	 0.0	 1	 -30.0	 30.0;
	6306	 4826	 9.9e-05	 0.00044	 0.0	 629.0	 70039	 70039	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 4418	 6e-05	 0.000469	 0.0	 66806	 66806	 66806	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 1605	 3.9e-05	 0.000341	 0.0	 92032	 92032	 92032	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 6952	 0.002531	 0.01943	 0.0	 533.0	 1613	 1613	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 7124	 0.00945	 0.06418	 0.0	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	9128	 217	 0.000591	 0.002831	 0.0	 457.0	 10923	 10923	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 217	 0.00087	 0.00387	 0.0	 7964	 7964	 7964	 0.0	 0.0	 1	 -30.0	 30.0;
	720	 5350	 0.0015	 0.01785	 0.0	 1283.0	 1764	 1764	 0.0	 0.0	 1	 -30.0	 30.0;
	720	 5350	 0.00147	 0.0182	 0.0	 1251.0	 1730	 1730	 0.0	 0.0	 1	 -30.0	 30.0;
	1711	 639	 0.00151	 0.0113	 0.0	 476.0	 2771	 2771	 0.0	 0.0	 1	 -30.0	 30.0;
	1711	 639	 0.001479	 0.011521	 0.0	 495.0	 2720	 2720	 0.0	 0.0	 1	 -30.0	 30.0;
	1711	 9130	 0.00174	 0.010341	 0.0	 514.0	 3013	 3013	 0.0	 0.0	 1	 -30.0	 30.0;
	1711	 9130	 0.001659	 0.01206	 0.0	 553.0	 2595	 2595	 0.0	 0.0	 1	 -30.0	 30.0;
	8209	 1998	 0.00069	 0.000479	 0.0	 37606	 37606	 37606	 0.0	 0.0	 1	 -30.0	 30.0;
	8209	 7974	 0.00044	 0.00139	 0.0	 21666	 21666	 21666	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 8180	 0.002039	 0.01601	 0.0	 1958	 1958	 1958	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 7466	 0.01349	 0.05662	 0.0	 457.0	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 305	 0.00082	 0.00438	 0.0	 400.0	 7089	 7089	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 305	 0.0008	 0.004461	 0.0	 381.0	 6970	 6970	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 5106	 0.001091	 0.00888	 0.0	 553.0	 3531	 3531	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 5106	 0.00111	 0.007039	 0.0	 591.0	 4433	 4433	 0.0	 0.0	 1	 -30.0	 30.0;
	2527	 8466	 0.000849	 0.00537	 0.0	 533.0	 5811	 5811	 0.0	 0.0	 1	 -30.0	 30.0;
	8669	 8893	 0.00061	 0.00275	 0.0	 457.0	 11214	 11214	 0.0	 0.0	 1	 -30.0	 30.0;
	6206	 7691	 0.00141	 0.0188	 0.0	 1415.0	 1676	 1676	 0.0	 0.0	 1	 -30.0	 30.0;
	6206	 6624	 0.00121	 0.01427	 0.0	 1645.0	 2206	 2206	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 8158	 0.001711	 0.007159	 0.0	 438.0	 4292	 4292	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 8795	 0.00545	 0.02381	 0.0	 400.0	 1294	 1294	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 4143	 0.000771	 0.004331	 0.0	 7181	 7181	 7181	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 2797	 0.00414	 0.03282	 0.0	 553.0	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 6331	 0.00264	 0.011521	 0.0	 438.0	 2673	 2673	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 6384	 0.00261	 0.011	 0.0	 476.0	 2795	 2795	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 7523	 0.00239	 0.00919	 0.0	 419.0	 3327	 3327	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 2889	 0.000539	 0.00226	 0.0	 13596	 13596	 13596	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 6887	 0.00325	 0.017979	 0.0	 572.0	 1729	 1729	 0.0	 0.0	 1	 -30.0	 30.0;
	1249	 4541	 0.00076	 0.0071	 0.0	 1316.0	 4424	 4424	 0.0	 0.0	 1	 -30.0	 30.0;
	819	 7523	 0.000651	 0.00343	 0.0	 9048	 9048	 9048	 0.0	 0.0	 1	 -30.0	 30.0;
	2304	 4353	 0.001219	 0.00812	 0.0	 438.0	 3847	 3847	 0.0	 0.0	 1	 -30.0	 30.0;
	2304	 4816	 0.00243	 0.01439	 0.0	 591.0	 2165	 2165	 0.0	 0.0	 1	 -30.0	 30.0;
	9174	 6246	 0.0006	 0.00839	 0.0	 1251.0	 3756	 3756	 0.0	 0.0	 1	 -30.0	 30.0;
	9174	 6246	 0.00059	 0.00856	 0.0	 1185.0	 3682	 3682	 0.0	 0.0	 1	 -30.0	 30.0;
	9174	 5658	 0.00087	 0.01328	 0.0	 1777.0	 2374	 2374	 0.0	 0.0	 1	 -30.0	 30.0;
	9174	 5658	 0.00073	 0.01595	 0.0	 1349.0	 1979	 1979	 0.0	 0.0	 1	 -30.0	 30.0;
	2924	 3645	 0.00163	 0.002039	 0.0	 12101	 12101	 12101	 0.0	 0.0	 1	 -30.0	 30.0;
	2924	 3645	 0.001659	 0.002	 0.0	 12156	 12156	 12156	 0.0	 0.0	 1	 -30.0	 30.0;
	59	 5764	 0.00339	 0.019669	 0.0	 572.0	 1583	 1583	 0.0	 0.0	 1	 -30.0	 30.0;
	59	 2360	 0.00239	 0.017281	 0.0	 629.0	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	6510	 9033	 0.00032	 0.00112	 0.0	 495.0	 27118	 27118	 0.0	 0.0	 1	 -30.0	 30.0;
	6510	 5918	 0.0018	 0.01401	 0.0	 495.0	 2237	 2237	 0.0	 0.0	 1	 -30.0	 30.0;
	6510	 5918	 0.00212	 0.012469	 0.0	 533.0	 2498	 2498	 0.0	 0.0	 1	 -30.0	 30.0;
	1275	 2850	 0.00063	 0.00411	 0.0	 7597	 7597	 7597	 0.0	 0.0	 1	 -30.0	 30.0;
	6426	 4110	 0.009729	 0.03505	 0.0	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	6426	 3558	 0.01007	 0.03056	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 2816	 0.00042	 0.00623	 0.0	 5059	 5059	 5059	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 352	 0.00036	 0.00722	 0.0	 1843.0	 4370	 4370	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 6581	 0.00053	 0.0078	 0.0	 954.0	 4041	 4041	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 1923	 0.00109	 0.0173	 0.0	 823.0	 1823	 1823	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 5837	 0.00071	 0.01144	 0.0	 2756	 2756	 2756	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 3830	 0.00157	 0.01884	 0.0	 1251.0	 1671	 1671	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 3577	 0.00032	 0.00384	 0.0	 856.0	 8198	 8198	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 1794	 0.00041	 0.00649	 0.0	 1547.0	 4858	 4858	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 7808	 0.0004	 0.00658	 0.0	 4792	 4792	 4792	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 6581	 0.00054	 0.00763	 0.0	 954.0	 4130	 4130	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 1923	 0.00107	 0.01602	 0.0	 921.0	 1968	 1968	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 5837	 0.0007	 0.01165	 0.0	 2707	 2707	 2707	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 5648	 0.0016	 0.01844	 0.0	 1349.0	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 3577	 0.00032	 0.00376	 0.0	 954.0	 8371	 8371	 0.0	 0.0	 1	 -30.0	 30.0;
	4615	 171	 0.00212	 0.01207	 0.0	 495.0	 2578	 2578	 0.0	 0.0	 1	 -30.0	 30.0;
	3137	 2341	 5e-05	 0.00037	 0.0	 84603	 84603	 84603	 0.0	 0.0	 1	 -30.0	 30.0;
	6271	 8787	 0.00355	 0.024651	 0.0	 419.0	 1269	 1269	 0.0	 0.0	 1	 -30.0	 30.0;
	6252	 9137	 0.00675	 0.04145	 0.0	 533.0	 753	 753	 0.0	 0.0	 1	 -30.0	 30.0;
	5533	 7133	 0.00195	 0.014341	 0.0	 438.0	 2183	 2183	 0.0	 0.0	 1	 -30.0	 30.0;
	8361	 4355	 0.00018	 0.00043	 0.0	 381.0	 67762	 67762	 0.0	 0.0	 1	 -30.0	 30.0;
	8361	 2928	 0.00037	 0.000969	 0.0	 457.0	 30454	 30454	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 1341	 0.00257	 0.017169	 0.0	 476.0	 1820	 1820	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 5419	 0.00076	 0.00399	 0.0	 495.0	 7777	 7777	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 5419	 0.00075	 0.00406	 0.0	 495.0	 7651	 7651	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 2079	 0.003901	 0.023961	 0.0	 572.0	 1302	 1302	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 772	 0.00249	 0.019211	 0.0	 457.0	 1631	 1631	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 2928	 0.00025	 0.001159	 0.0	 476.0	 26642	 26642	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 7282	 0.00195	 0.02924	 0.0	 1078	 1078	 1078	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 2197	 0.00152	 0.01527	 0.0	 1481.0	 2059	 2059	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 7640	 0.00149	 0.01558	 0.0	 1613.0	 2019	 2019	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 1081	 0.00253	 0.0276	 0.0	 1140	 1140	 1140	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 1081	 0.00263	 0.02648	 0.0	 1188	 1188	 1188	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 2359	 0.00077	 0.0092	 0.0	 1415.0	 3422	 3422	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 4196	 0.00112	 0.01705	 0.0	 757.0	 1849	 1849	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 8546	 0.00226	 0.01101	 0.0	 2811	 2811	 2811	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 5987	 0.004531	 0.029039	 0.0	 495.0	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 8005	 0.002081	 0.030409	 0.0	 1037	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 3925	 0.0053	 0.03257	 0.0	 438.0	 958	 958	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 3324	 0.00513	 0.041901	 0.0	 553.0	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 4748	 0.001461	 0.01056	 0.0	 457.0	 2964	 2964	 0.0	 0.0	 1	 -30.0	 30.0;
	8265	 4816	 0.0005	 0.002591	 0.0	 11971	 11971	 11971	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6313	 0.00055	 0.0033	 0.0	 457.0	 9442	 9442	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 6532	 0.002289	 0.01763	 0.0	 476.0	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 2177	 0.0075	 0.043531	 0.0	 457.0	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	5723	 2079	 0.00138	 0.019961	 0.0	 1579	 1579	 1579	 0.0	 0.0	 1	 -30.0	 30.0;
	5723	 789	 0.00126	 0.018729	 0.0	 591.0	 1683	 1683	 0.0	 0.0	 1	 -30.0	 30.0;
	2327	 9189	 0.00038	 0.001331	 0.0	 495.0	 22821	 22821	 0.0	 0.0	 1	 -30.0	 30.0;
	2327	 3400	 0.00019	 0.001461	 0.0	 21440	 21440	 21440	 0.0	 0.0	 1	 -30.0	 30.0;
	207	 4747	 0.002151	 0.013401	 0.0	 476.0	 2328	 2328	 0.0	 0.0	 1	 -30.0	 30.0;
	207	 7791	 0.000789	 0.005669	 0.0	 572.0	 5519	 5519	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 6735	 3e-05	 0.00042	 0.0	 757.0	 75017	 75017	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 666	 0.00079	 0.00899	 0.0	 1382.0	 3501	 3501	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 666	 0.0008	 0.00879	 0.0	 1547.0	 3579	 3579	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 4435	 0.00334	 0.03393	 0.0	 927	 927	 927	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 1644	 0.00063	 0.00789	 0.0	 3991	 3991	 3991	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 3483	 0.0006	 0.00842	 0.0	 1316.0	 3742	 3742	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 7989	 0.00011	 0.00125	 0.0	 25173	 25173	 25173	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 6516	 0.00012	 0.001091	 0.0	 28780	 28780	 28780	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 7697	 9.9e-05	 0.00125	 0.0	 25191	 25191	 25191	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 416	 0.00294	 0.02443	 0.0	 629.0	 1284	 1284	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 2847	 0.00144	 0.011151	 0.0	 495.0	 2810	 2810	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 2563	 0.001831	 0.010849	 0.0	 591.0	 2871	 2871	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 2563	 0.001599	 0.01055	 0.0	 572.0	 2961	 2961	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 2995	 0.00144	 0.019591	 0.0	 381.0	 1609	 1609	 0.0	 0.0	 1	 -30.0	 30.0;
	5691	 1001	 0.0133	 0.09551	 0.0	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5691	 4426	 0.009591	 0.073961	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	5350	 2721	 0.0007	 0.00671	 0.0	 1547.0	 4683	 4683	 0.0	 0.0	 1	 -30.0	 30.0;
	5350	 2721	 0.00072	 0.00658	 0.0	 1580.0	 4773	 4773	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 4936	 0.001901	 0.00964	 0.0	 629.0	 3215	 3215	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 5179	 0.001711	 0.01189	 0.0	 610.0	 2630	 2630	 0.0	 0.0	 1	 -30.0	 30.0;
	2044	 4748	 0.00025	 0.00187	 0.0	 16743	 16743	 16743	 0.0	 0.0	 1	 -30.0	 30.0;
	4197	 5522	 0.00043	 0.002211	 0.0	 14024	 14024	 14024	 0.0	 0.0	 1	 -30.0	 30.0;
	5699	 8670	 0.000401	 0.00243	 0.0	 12826	 12826	 12826	 0.0	 0.0	 1	 -30.0	 30.0;
	7809	 5110	 0.00336	 0.017	 0.0	 457.0	 1823	 1823	 0.0	 0.0	 1	 -30.0	 30.0;
	7222	 4816	 0.005521	 0.031031	 0.0	 1003	 1003	 1003	 0.0	 0.0	 1	 -30.0	 30.0;
	4402	 3817	 9.9e-05	 0.00026	 0.0	 113538	 113538	 113538	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 2732	 0.00045	 0.00718	 0.0	 1086.0	 4391	 4391	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 4550	 0.00044	 0.00665	 0.0	 921.0	 4740	 4740	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 4339	 0.00103	 0.01516	 0.0	 1283.0	 2079	 2079	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 7513	 0.00101	 0.01546	 0.0	 954.0	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	5016	 26	 0.00045	 0.00608	 0.0	 1514.0	 5182	 5182	 0.0	 0.0	 1	 -30.0	 30.0;
	5016	 9213	 0.0004	 0.00501	 0.0	 1349.0	 6285	 6285	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 9002	 0.001729	 0.01337	 0.0	 591.0	 2344	 2344	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 6231	 0.00264	 0.01489	 0.0	 514.0	 2089	 2089	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 883	 0.002341	 0.018961	 0.0	 514.0	 1654	 1654	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 5738	 0.001841	 0.01363	 0.0	 476.0	 2297	 2297	 0.0	 0.0	 1	 -30.0	 30.0;
	8860	 7700	 0.001219	 0.00949	 0.0	 495.0	 3302	 3302	 0.0	 0.0	 1	 -30.0	 30.0;
	8860	 9002	 0.002271	 0.01151	 0.0	 495.0	 2693	 2693	 0.0	 0.0	 1	 -30.0	 30.0;
	8860	 5990	 0.010781	 0.05775	 0.0	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	8860	 6450	 0.00251	 0.013919	 0.0	 400.0	 2234	 2234	 0.0	 0.0	 1	 -30.0	 30.0;
	8860	 7726	 0.00101	 0.007331	 0.0	 514.0	 4269	 4269	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 4110	 0.00061	 0.003909	 0.0	 629.0	 7985	 7985	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 6376	 0.004289	 0.019331	 0.0	 1596	 1596	 1596	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 4110	 0.0008	 0.004401	 0.0	 629.0	 7062	 7062	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 4829	 0.008099	 0.03519	 0.0	 610.0	 875	 875	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 7857	 0.00063	 0.004591	 0.0	 514.0	 6817	 6817	 0.0	 0.0	 1	 -30.0	 30.0;
	2806	 7857	 0.000651	 0.00456	 0.0	 6858	 6858	 6858	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 9012	 0.00114	 0.00581	 0.0	 5335	 5335	 5335	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 2231	 0.001211	 0.00538	 0.0	 5728	 5728	 5728	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 3793	 0.00418	 0.030159	 0.0	 572.0	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 8497	 0.00324	 0.02413	 0.0	 610.0	 1298	 1298	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 8497	 0.003169	 0.024591	 0.0	 629.0	 1274	 1274	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 9002	 0.000219	 0.00088	 0.0	 495.0	 34833	 34833	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 9002	 0.000289	 0.00095	 0.0	 514.0	 31811	 31811	 0.0	 0.0	 1	 -30.0	 30.0;
	6313	 44	 0.0035	 0.022211	 0.0	 553.0	 1405	 1405	 0.0	 0.0	 1	 -30.0	 30.0;
	6313	 7582	 0.00313	 0.02256	 0.0	 1387	 1387	 1387	 0.0	 0.0	 1	 -30.0	 30.0;
	5944	 8808	 0.000831	 0.00162	 0.0	 17349	 17349	 17349	 0.0	 0.0	 1	 -30.0	 30.0;
	3183	 8515	 0.002099	 0.01068	 0.0	 400.0	 2903	 2903	 0.0	 0.0	 1	 -30.0	 30.0;
	1005	 8515	 0.00224	 0.00976	 0.0	 3155	 3155	 3155	 0.0	 0.0	 1	 -30.0	 30.0;
	8787	 1448	 0.00169	 0.01231	 0.0	 629.0	 2543	 2543	 0.0	 0.0	 1	 -30.0	 30.0;
	6636	 9051	 0.00011	 0.00076	 0.0	 41134	 41134	 41134	 0.0	 0.0	 1	 -30.0	 30.0;
	9109	 9051	 0.00011	 0.00068	 0.0	 45856	 45856	 45856	 0.0	 0.0	 1	 -30.0	 30.0;
	6961	 6376	 0.005479	 0.021909	 0.0	 1399	 1399	 1399	 0.0	 0.0	 1	 -30.0	 30.0;
	6961	 8818	 0.003331	 0.017039	 0.0	 438.0	 1820	 1820	 0.0	 0.0	 1	 -30.0	 30.0;
	5077	 4353	 0.000479	 0.001271	 0.0	 23256	 23256	 23256	 0.0	 0.0	 1	 -30.0	 30.0;
	7471	 5241	 0.00109	 0.01629	 0.0	 823.0	 1935	 1935	 0.0	 0.0	 1	 -30.0	 30.0;
	7471	 8200	 4e-05	 0.00063	 0.0	 1810.0	 50038	 50038	 0.0	 0.0	 1	 -30.0	 30.0;
	549	 6290	 0.0053	 0.024531	 0.0	 572.0	 1259	 1259	 0.0	 0.0	 1	 -30.0	 30.0;
	549	 2291	 0.004659	 0.021919	 0.0	 419.0	 1410	 1410	 0.0	 0.0	 1	 -30.0	 30.0;
	549	 3656	 0.001659	 0.01043	 0.0	 572.0	 2991	 2991	 0.0	 0.0	 1	 -30.0	 30.0;
	5002	 4144	 0.006961	 0.053539	 0.0	 495.0	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	1888	 5441	 0.00036	 0.00288	 0.0	 629.0	 10884	 10884	 0.0	 0.0	 1	 -30.0	 30.0;
	1888	 5441	 0.00038	 0.003	 0.0	 629.0	 10446	 10446	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 4970	 0.00048	 0.00643	 0.0	 4899	 4899	 4899	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 4970	 0.00051	 0.0066	 0.0	 4772	 4772	 4772	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 4970	 0.00046	 0.00729	 0.0	 1876.0	 4325	 4325	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 5461	 0.0006	 0.00868	 0.0	 1810.0	 3631	 3631	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 7778	 0.00068	 0.01076	 0.0	 1942.0	 2930	 2930	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 6897	 0.00066	 0.01096	 0.0	 1909.0	 2877	 2877	 0.0	 0.0	 1	 -30.0	 30.0;
	3075	 4562	 0.00101	 0.005099	 0.0	 400.0	 6077	 6077	 0.0	 0.0	 1	 -30.0	 30.0;
	564	 8475	 0.003901	 0.02437	 0.0	 1280	 1280	 1280	 0.0	 0.0	 1	 -30.0	 30.0;
	564	 2252	 0.00276	 0.016461	 0.0	 553.0	 1893	 1893	 0.0	 0.0	 1	 -30.0	 30.0;
	564	 7903	 0.00588	 0.047081	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	4331	 1857	 3.9e-05	 0.000219	 0.0	 142001	 142001	 142001	 0.0	 0.0	 1	 -30.0	 30.0;
	2877	 3674	 0.00131	 0.00538	 0.0	 5705	 5705	 5705	 0.0	 0.0	 1	 -30.0	 30.0;
	2854	 1081	 0.00679	 0.04679	 0.0	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	2854	 8267	 0.00138	 0.01466	 0.0	 1086.0	 2146	 2146	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 9176	 0.003531	 0.01724	 0.0	 1795	 1795	 1795	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 1422	 0.01324	 0.06936	 0.0	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 8515	 0.00363	 0.01743	 0.0	 438.0	 1775	 1775	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 8515	 0.00257	 0.01662	 0.0	 533.0	 1879	 1879	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 5051	 0.01399	 0.056289	 0.0	 419.0	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 1051	 0.00343	 0.01751	 0.0	 457.0	 1771	 1771	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 1397	 0.00301	 0.015409	 0.0	 2012	 2012	 2012	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 1584	 0.00857	 0.033091	 0.0	 476.0	 925	 925	 0.0	 0.0	 1	 -30.0	 30.0;
	6168	 6888	 0.003341	 0.01689	 0.0	 1835	 1835	 1835	 0.0	 0.0	 1	 -30.0	 30.0;
	7653	 3019	 3.9e-05	 0.000219	 0.0	 142001	 142001	 142001	 0.0	 0.0	 1	 -30.0	 30.0;
	7341	 7098	 0.00087	 0.00714	 0.0	 457.0	 4392	 4392	 0.0	 0.0	 1	 -30.0	 30.0;
	4701	 8267	 0.00011	 0.001	 0.0	 757.0	 31398	 31398	 0.0	 0.0	 1	 -30.0	 30.0;
	1672	 5365	 0.000219	 0.00101	 0.0	 30565	 30565	 30565	 0.0	 0.0	 1	 -30.0	 30.0;
	3880	 5365	 0.000219	 0.001031	 0.0	 29969	 29969	 29969	 0.0	 0.0	 1	 -30.0	 30.0;
	6648	 5365	 0.000271	 0.00101	 0.0	 30207	 30207	 30207	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 5365	 0.000271	 0.000979	 0.0	 31096	 31096	 31096	 0.0	 0.0	 1	 -30.0	 30.0;
	2782	 5365	 0.000289	 0.00107	 0.0	 28500	 28500	 28500	 0.0	 0.0	 1	 -30.0	 30.0;
	1844	 5365	 0.000289	 0.00105	 0.0	 29005	 29005	 29005	 0.0	 0.0	 1	 -30.0	 30.0;
	4353	 6053	 0.001591	 0.012289	 0.0	 381.0	 2550	 2550	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 5237	 0.000271	 0.001901	 0.0	 495.0	 16450	 16450	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 2886	 0.00186	 0.010711	 0.0	 514.0	 2906	 2906	 0.0	 0.0	 1	 -30.0	 30.0;
	1043	 3513	 1e-05	 0.0002	 0.0	 157740	 157740	 157740	 0.0	 0.0	 1	 -30.0	 30.0;
	4049	 883	 0.000169	 0.000271	 0.0	 98903	 98903	 98903	 0.0	 0.0	 1	 -30.0	 30.0;
	4520	 883	 0.000169	 0.00031	 0.0	 89464	 89464	 89464	 0.0	 0.0	 1	 -30.0	 30.0;
	1704	 5814	 0.00526	 0.03787	 0.0	 553.0	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	8107	 1486	 0.000229	 0.000599	 0.0	 49257	 49257	 49257	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 5522	 0.00089	 0.004091	 0.0	 438.0	 7545	 7545	 0.0	 0.0	 1	 -30.0	 30.0;
	4482	 8670	 0.00093	 0.004	 0.0	 400.0	 7692	 7692	 0.0	 0.0	 1	 -30.0	 30.0;
	8795	 7523	 0.00289	 0.013099	 0.0	 400.0	 2355	 2355	 0.0	 0.0	 1	 -30.0	 30.0;
	2337	 6430	 0.002599	 0.016479	 0.0	 533.0	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 7775	 0.00369	 0.02712	 0.0	 553.0	 1155	 1155	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 3857	 0.0062	 0.04864	 0.0	 629.0	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 333	 0.008021	 0.059031	 0.0	 531	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 6940	 0.004979	 0.0295	 0.0	 572.0	 1056	 1056	 0.0	 0.0	 1	 -30.0	 30.0;
	8225	 3656	 0.001159	 0.005281	 0.0	 5843	 5843	 5843	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 7752	 0.00361	 0.01824	 0.0	 1699	 1699	 1699	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 1940	 0.001521	 0.01075	 0.0	 2910	 2910	 2910	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 4234	 0.00868	 0.041711	 0.0	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 6828	 0.01118	 0.05986	 0.0	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 7571	 0.003229	 0.02543	 0.0	 591.0	 1233	 1233	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 7571	 0.00218	 0.01869	 0.0	 1679	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 7571	 0.001901	 0.021909	 0.0	 572.0	 1437	 1437	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 7994	 0.00974	 0.043969	 0.0	 400.0	 702	 702	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 7226	 0.003461	 0.01814	 0.0	 457.0	 1711	 1711	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 1554	 0.00487	 0.027669	 0.0	 419.0	 1125	 1125	 0.0	 0.0	 1	 -30.0	 30.0;
	9011	 1156	 0.000651	 0.003961	 0.0	 610.0	 7870	 7870	 0.0	 0.0	 1	 -30.0	 30.0;
	8689	 5502	 0.00169	 0.00887	 0.0	 400.0	 3499	 3499	 0.0	 0.0	 1	 -30.0	 30.0;
	3085	 8873	 0.001711	 0.01336	 0.0	 514.0	 2346	 2346	 0.0	 0.0	 1	 -30.0	 30.0;
	1568	 980	 0.00031	 0.000539	 0.0	 400.0	 50801	 50801	 0.0	 0.0	 1	 -30.0	 30.0;
	3204	 3331	 0.0027	 0.01157	 0.0	 2659	 2659	 2659	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 639	 0.000909	 0.006901	 0.0	 514.0	 4539	 4539	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 4936	 0.001729	 0.01214	 0.0	 514.0	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	416	 3492	 0.00614	 0.03106	 0.0	 438.0	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	416	 7937	 0.00418	 0.02388	 0.0	 514.0	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	3255	 1262	 0.00238	 0.017771	 0.0	 1762	 1762	 1762	 0.0	 0.0	 1	 -30.0	 30.0;
	3255	 1803	 8.1e-05	 0.00063	 0.0	 49730	 49730	 49730	 0.0	 0.0	 1	 -30.0	 30.0;
	7373	 367	 0.001599	 0.01618	 0.0	 1943	 1943	 1943	 0.0	 0.0	 1	 -30.0	 30.0;
	4251	 2132	 0.00532	 0.026961	 0.0	 419.0	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	4251	 2132	 0.00361	 0.02814	 0.0	 553.0	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	4251	 5567	 0.002469	 0.01025	 0.0	 533.0	 2996	 2996	 0.0	 0.0	 1	 -30.0	 30.0;
	6376	 1808	 0.005229	 0.02675	 0.0	 400.0	 1159	 1159	 0.0	 0.0	 1	 -30.0	 30.0;
	6376	 1808	 0.00512	 0.02726	 0.0	 419.0	 1139	 1139	 0.0	 0.0	 1	 -30.0	 30.0;
	6376	 7857	 0.00355	 0.01694	 0.0	 400.0	 1826	 1826	 0.0	 0.0	 1	 -30.0	 30.0;
	9185	 7289	 0.00139	 0.007659	 0.0	 457.0	 4058	 4058	 0.0	 0.0	 1	 -30.0	 30.0;
	9185	 3999	 0.000169	 0.000669	 0.0	 514.0	 45778	 45778	 0.0	 0.0	 1	 -30.0	 30.0;
	8653	 2303	 0.00111	 0.00712	 0.0	 476.0	 4384	 4384	 0.0	 0.0	 1	 -30.0	 30.0;
	908	 6474	 0.00031	 0.001901	 0.0	 533.0	 16400	 16400	 0.0	 0.0	 1	 -30.0	 30.0;
	7030	 6474	 0.000281	 0.002091	 0.0	 14972	 14972	 14972	 0.0	 0.0	 1	 -30.0	 30.0;
	4205	 6556	 0.000281	 0.001651	 0.0	 18862	 18862	 18862	 0.0	 0.0	 1	 -30.0	 30.0;
	7325	 6556	 0.000271	 0.00169	 0.0	 18455	 18455	 18455	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 3391	 0.001521	 0.00843	 0.0	 381.0	 3688	 3688	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 3760	 0.000841	 0.0062	 0.0	 533.0	 5049	 5049	 0.0	 0.0	 1	 -30.0	 30.0;
	3707	 8765	 0.00019	 0.00126	 0.0	 514.0	 24790	 24790	 0.0	 0.0	 1	 -30.0	 30.0;
	900	 6619	 0.000219	 0.00143	 0.0	 21835	 21835	 21835	 0.0	 0.0	 1	 -30.0	 30.0;
	2918	 8109	 0.00121	 0.01796	 0.0	 1755	 1755	 1755	 0.0	 0.0	 1	 -30.0	 30.0;
	2918	 8109	 0.0014	 0.01512	 0.0	 2081	 2081	 2081	 0.0	 0.0	 1	 -30.0	 30.0;
	6532	 2177	 0.008409	 0.063651	 0.0	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	6532	 5317	 0.00918	 0.07344	 0.0	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	6532	 608	 0.004219	 0.0345	 0.0	 514.0	 909	 909	 0.0	 0.0	 1	 -30.0	 30.0;
	6532	 608	 0.0042	 0.031651	 0.0	 457.0	 990	 990	 0.0	 0.0	 1	 -30.0	 30.0;
	4494	 8763	 0.00121	 0.01381	 0.0	 1547.0	 2279	 2279	 0.0	 0.0	 1	 -30.0	 30.0;
	4494	 7056	 0.00107	 0.01326	 0.0	 1580.0	 2375	 2375	 0.0	 0.0	 1	 -30.0	 30.0;
	6828	 5814	 0.003401	 0.02607	 0.0	 1202	 1202	 1202	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 21	 0.000289	 0.00138	 0.0	 419.0	 22404	 22404	 0.0	 0.0	 1	 -30.0	 30.0;
	5137	 7702	 0.001031	 0.006039	 0.0	 5156	 5156	 5156	 0.0	 0.0	 1	 -30.0	 30.0;
	1334	 7702	 0.00105	 0.005909	 0.0	 5264	 5264	 5264	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 7624	 0.001091	 0.007901	 0.0	 419.0	 3961	 3961	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 1129	 0.00332	 0.024021	 0.0	 553.0	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 3070	 0.00344	 0.021419	 0.0	 400.0	 1457	 1457	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 306	 0.00095	 0.010419	 0.0	 514.0	 3020	 3020	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 306	 0.00093	 0.01062	 0.0	 476.0	 2963	 2963	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 7491	 0.00474	 0.025409	 0.0	 1223	 1223	 1223	 0.0	 0.0	 1	 -30.0	 30.0;
	4685	 2089	 0.000271	 0.000841	 0.0	 381.0	 35750	 35750	 0.0	 0.0	 1	 -30.0	 30.0;
	7485	 6253	 0.000271	 0.00119	 0.0	 381.0	 25882	 25882	 0.0	 0.0	 1	 -30.0	 30.0;
	7485	 1562	 0.000289	 0.00076	 0.0	 38849	 38849	 38849	 0.0	 0.0	 1	 -30.0	 30.0;
	7776	 1644	 0.00031	 0.00454	 0.0	 1942.0	 10592	 10592	 0.0	 0.0	 1	 -30.0	 30.0;
	5971	 3483	 0.00032	 0.0044	 0.0	 10925	 10925	 10925	 0.0	 0.0	 1	 -30.0	 30.0;
	2786	 1644	 0.00028	 0.00494	 0.0	 9741	 9741	 9741	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 3483	 0.00028	 0.00508	 0.0	 9474	 9474	 9474	 0.0	 0.0	 1	 -30.0	 30.0;
	8906	 923	 0.000531	 0.00093	 0.0	 29496	 29496	 29496	 0.0	 0.0	 1	 -30.0	 30.0;
	8906	 4914	 0.0003	 0.001031	 0.0	 495.0	 29418	 29418	 0.0	 0.0	 1	 -30.0	 30.0;
	2656	 9101	 0.00139	 0.02163	 0.0	 757.0	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	2656	 7164	 0.00164	 0.02321	 0.0	 1358	 1358	 1358	 0.0	 0.0	 1	 -30.0	 30.0;
	3519	 9101	 0.00136	 0.02205	 0.0	 757.0	 1430	 1430	 0.0	 0.0	 1	 -30.0	 30.0;
	3519	 7164	 0.0016	 0.02367	 0.0	 757.0	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 9137	 0.002091	 0.01174	 0.0	 381.0	 2649	 2649	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 9137	 0.001719	 0.00961	 0.0	 553.0	 3236	 3236	 0.0	 0.0	 1	 -30.0	 30.0;
	5641	 1026	 0.012341	 0.076781	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	5641	 9137	 0.00176	 0.009419	 0.0	 591.0	 3297	 3297	 0.0	 0.0	 1	 -30.0	 30.0;
	1096	 2889	 0.00031	 0.00182	 0.0	 17110	 17110	 17110	 0.0	 0.0	 1	 -30.0	 30.0;
	7380	 2732	 0.00386	 0.02348	 0.0	 1283.0	 1328	 1328	 0.0	 0.0	 1	 -30.0	 30.0;
	7380	 4787	 0.00017	 0.00104	 0.0	 1152.0	 29975	 29975	 0.0	 0.0	 1	 -30.0	 30.0;
	3543	 5308	 0.00061	 0.00808	 0.0	 1613.0	 3899	 3899	 0.0	 0.0	 1	 -30.0	 30.0;
	3543	 3830	 0.00059	 0.0067	 0.0	 4697	 4697	 4697	 0.0	 0.0	 1	 -30.0	 30.0;
	2372	 1027	 0.00059	 0.00748	 0.0	 1481.0	 4210	 4210	 0.0	 0.0	 1	 -30.0	 30.0;
	2372	 5648	 0.00061	 0.0063	 0.0	 4991	 4991	 4991	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 1172	 0.001031	 0.008789	 0.0	 629.0	 3570	 3570	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 9191	 0.00051	 0.006169	 0.0	 629.0	 5103	 5103	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 8722	 0.0005	 0.00619	 0.0	 629.0	 5087	 5087	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 3610	 0.00049	 0.00376	 0.0	 572.0	 8331	 8331	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 3610	 0.000539	 0.003229	 0.0	 533.0	 9649	 9649	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 3962	 0.001031	 0.00882	 0.0	 3558	 3558	 3558	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 1838	 0.000711	 0.00463	 0.0	 457.0	 6744	 6744	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 2230	 0.000711	 0.004539	 0.0	 6876	 6876	 6876	 0.0	 0.0	 1	 -30.0	 30.0;
	5388	 2467	 0.00206	 0.015341	 0.0	 514.0	 2041	 2041	 0.0	 0.0	 1	 -30.0	 30.0;
	5388	 2467	 0.002021	 0.01564	 0.0	 514.0	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	6110	 8853	 0.00094	 0.005781	 0.0	 610.0	 5394	 5394	 0.0	 0.0	 1	 -30.0	 30.0;
	6110	 1001	 0.002219	 0.016969	 0.0	 629.0	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	7583	 1808	 0.00238	 0.01187	 0.0	 381.0	 2610	 2610	 0.0	 0.0	 1	 -30.0	 30.0;
	7583	 2889	 0.00707	 0.03095	 0.0	 381.0	 995	 995	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 6624	 0.00256	 0.03401	 0.0	 927	 927	 927	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 2479	 0.00203	 0.02416	 0.0	 1152.0	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 4598	 0.001	 0.01459	 0.0	 2160	 2160	 2160	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 4231	 0.00103	 0.00987	 0.0	 1613.0	 3184	 3184	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 5144	 0.00038	 0.00483	 0.0	 1448.0	 6520	 6520	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 5144	 0.00041	 0.00398	 0.0	 1316.0	 7895	 7895	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 2479	 0.00167	 0.01721	 0.0	 1382.0	 1827	 1827	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 2129	 0.00098	 0.01487	 0.0	 987.0	 2120	 2120	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 9213	 0.00042	 0.00342	 0.0	 1349.0	 9168	 9168	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 9213	 0.00019	 0.00248	 0.0	 1580.0	 12700	 12700	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 4231	 0.00105	 0.00966	 0.0	 1909.0	 3251	 3251	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 3513	 0.00043	 0.00473	 0.0	 1382.0	 6651	 6651	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 3513	 0.00041	 0.00397	 0.0	 1316.0	 7915	 7915	 0.0	 0.0	 1	 -30.0	 30.0;
	1876	 3906	 0.00051	 0.00514	 0.0	 1218.0	 6116	 6116	 0.0	 0.0	 1	 -30.0	 30.0;
	113	 3906	 0.00053	 0.00503	 0.0	 1415.0	 6246	 6246	 0.0	 0.0	 1	 -30.0	 30.0;
	7752	 3758	 0.00455	 0.022771	 0.0	 400.0	 1361	 1361	 0.0	 0.0	 1	 -30.0	 30.0;
	7752	 3758	 0.00557	 0.02055	 0.0	 381.0	 1484	 1484	 0.0	 0.0	 1	 -30.0	 30.0;
	7752	 3758	 0.00339	 0.02026	 0.0	 1538	 1538	 1538	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 8976	 0.00237	 0.01068	 0.0	 438.0	 2888	 2888	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 8189	 0.0037	 0.019479	 0.0	 381.0	 1594	 1594	 0.0	 0.0	 1	 -30.0	 30.0;
	6119	 7886	 0.01407	 0.056849	 0.0	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	6119	 4544	 0.001669	 0.015409	 0.0	 610.0	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	6119	 4544	 0.001711	 0.015091	 0.0	 2080	 2080	 2080	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 3697	 0.00172	 0.01619	 0.0	 1678.0	 1941	 1941	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 7541	 0.00029	 0.00447	 0.0	 987.0	 7052	 7052	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 7541	 0.00033	 0.00387	 0.0	 1119.0	 8133	 8133	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 4141	 0.00079	 0.01154	 0.0	 987.0	 2731	 2731	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 4141	 0.00077	 0.01177	 0.0	 987.0	 2678	 2678	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 3022	 0.00127	 0.01498	 0.0	 1547.0	 2102	 2102	 0.0	 0.0	 1	 -30.0	 30.0;
	1768	 163	 0.00214	 0.012599	 0.0	 495.0	 2472	 2472	 0.0	 0.0	 1	 -30.0	 30.0;
	4245	 2425	 0.000159	 0.00125	 0.0	 457.0	 25068	 25068	 0.0	 0.0	 1	 -30.0	 30.0;
	3698	 5297	 0.000211	 0.000669	 0.0	 457.0	 45030	 45030	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 8328	 0.000341	 0.001169	 0.0	 514.0	 25940	 25940	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 870	 0.00024	 0.001469	 0.0	 572.0	 21222	 21222	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 2961	 0.00018	 0.000669	 0.0	 533.0	 45595	 45595	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 7988	 0.00033	 0.00683	 0.0	 921.0	 4620	 4620	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 2197	 0.00121	 0.01211	 0.0	 1415.0	 2596	 2596	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 7640	 0.00123	 0.01185	 0.0	 1448.0	 2652	 2652	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 4231	 0.00058	 0.0097	 0.0	 1185.0	 3251	 3251	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 5144	 0.00103	 0.01292	 0.0	 1251.0	 2438	 2438	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 3513	 0.00116	 0.01266	 0.0	 921.0	 2485	 2485	 0.0	 0.0	 1	 -30.0	 30.0;
	7289	 3999	 0.0013	 0.006841	 0.0	 457.0	 4537	 4537	 0.0	 0.0	 1	 -30.0	 30.0;
	3018	 1051	 6e-05	 0.000349	 0.0	 438.0	 89200	 89200	 0.0	 0.0	 1	 -30.0	 30.0;
	2702	 3435	 0.000169	 0.0007	 0.0	 400.0	 43865	 43865	 0.0	 0.0	 1	 -30.0	 30.0;
	9131	 2020	 0.000169	 0.000719	 0.0	 42767	 42767	 42767	 0.0	 0.0	 1	 -30.0	 30.0;
	6308	 6684	 0.000271	 0.001031	 0.0	 29632	 29632	 29632	 0.0	 0.0	 1	 -30.0	 30.0;
	4831	 3680	 0.008271	 0.036841	 0.0	 837	 837	 837	 0.0	 0.0	 1	 -30.0	 30.0;
	5410	 2751	 0.002969	 0.02299	 0.0	 419.0	 1363	 1363	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 4623	 0.00124	 0.01273	 0.0	 1218.0	 2470	 2470	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 4339	 0.00106	 0.00989	 0.0	 1481.0	 3176	 3176	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 5288	 7e-05	 0.00029	 0.0	 757.0	 105881	 105881	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 5421	 9e-05	 0.00079	 0.0	 757.0	 39728	 39728	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 6475	 0.00196	 0.02049	 0.0	 1535	 1535	 1535	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 8468	 0.00158	 0.01519	 0.0	 1283.0	 2069	 2069	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 2732	 0.00172	 0.01811	 0.0	 1613.0	 1737	 1737	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 7513	 0.00096	 0.01121	 0.0	 1744.0	 2808	 2808	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 6475	 0.00147	 0.01707	 0.0	 1844	 1844	 1844	 0.0	 0.0	 1	 -30.0	 30.0;
	2174	 4623	 0.00129	 0.0129	 0.0	 1316.0	 2437	 2437	 0.0	 0.0	 1	 -30.0	 30.0;
	2174	 4550	 0.00179	 0.01737	 0.0	 1645.0	 1809	 1809	 0.0	 0.0	 1	 -30.0	 30.0;
	2174	 6475	 0.00131	 0.01935	 0.0	 1629	 1629	 1629	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 9231	 0.003901	 0.01614	 0.0	 419.0	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 9231	 0.002591	 0.014771	 0.0	 553.0	 2107	 2107	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 9231	 0.00224	 0.0173	 0.0	 476.0	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 4054	 0.00012	 0.000849	 0.0	 36840	 36840	 36840	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 3481	 0.00394	 0.03039	 0.0	 495.0	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 3602	 0.00189	 0.01	 0.0	 3104	 3104	 3104	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 2794	 0.00032	 0.00257	 0.0	 12197	 12197	 12197	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 2794	 0.00038	 0.00224	 0.0	 13903	 13903	 13903	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 8467	 0.00751	 0.03955	 0.0	 495.0	 785	 785	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 1136	 0.00086	 0.006531	 0.0	 4796	 4796	 4796	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 22	 0.00087	 0.006591	 0.0	 4752	 4752	 4752	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 1001	 0.003031	 0.02276	 0.0	 629.0	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 4950	 0.006331	 0.03911	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 4410	 0.00605	 0.02986	 0.0	 381.0	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 6697	 0.003919	 0.01612	 0.0	 438.0	 1905	 1905	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 1159	 0.002039	 0.0108	 0.0	 438.0	 2874	 2874	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 7165	 0.006289	 0.026271	 0.0	 514.0	 1170	 1170	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 2848	 0.00042	 0.00547	 0.0	 856.0	 5758	 5758	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 2848	 0.00043	 0.00536	 0.0	 757.0	 5875	 5875	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 7522	 0.00147	 0.01373	 0.0	 1777.0	 2288	 2288	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 7522	 0.00131	 0.01555	 0.0	 1547.0	 2025	 2025	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 1642	 0.00221	 0.02217	 0.0	 1418	 1418	 1418	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 809	 0.00224	 0.0217	 0.0	 1448	 1448	 1448	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 6791	 0.00095	 0.003289	 0.0	 400.0	 9227	 9227	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 3400	 0.000229	 0.00082	 0.0	 37102	 37102	 37102	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 7092	 0.00068	 0.00306	 0.0	 10077	 10077	 10077	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 3718	 0.00049	 0.00256	 0.0	 419.0	 12119	 12119	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 3701	 0.000531	 0.0022	 0.0	 13958	 13958	 13958	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 7507	 0.00136	 0.00956	 0.0	 514.0	 3272	 3272	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 7507	 0.0012	 0.010729	 0.0	 476.0	 2926	 2926	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 7507	 0.00105	 0.00861	 0.0	 3642	 3642	 3642	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 2406	 0.000591	 0.006969	 0.0	 4517	 4517	 4517	 0.0	 0.0	 1	 -30.0	 30.0;
	2801	 8511	 0.00025	 0.0008	 0.0	 37687	 37687	 37687	 0.0	 0.0	 1	 -30.0	 30.0;
	2801	 216	 0.00113	 0.00632	 0.0	 400.0	 4920	 4920	 0.0	 0.0	 1	 -30.0	 30.0;
	453	 2129	 0.0003	 0.00275	 0.0	 954.0	 11419	 11419	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 6952	 0.00836	 0.051659	 0.0	 604	 604	 604	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 6952	 0.01338	 0.073469	 0.0	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 1183	 0.0027	 0.02089	 0.0	 1500	 1500	 1500	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 4410	 0.003419	 0.02636	 0.0	 610.0	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 8743	 0.009531	 0.033711	 0.0	 457.0	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	2446	 8763	 0.0004	 0.00707	 0.0	 4461	 4461	 4461	 0.0	 0.0	 1	 -30.0	 30.0;
	2627	 8763	 0.00035	 0.00701	 0.0	 4501	 4501	 4501	 0.0	 0.0	 1	 -30.0	 30.0;
	4951	 6785	 0.00194	 0.01751	 0.0	 533.0	 1793	 1793	 0.0	 0.0	 1	 -30.0	 30.0;
	4951	 6785	 0.00156	 0.01936	 0.0	 514.0	 1627	 1627	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 964	 0.00078	 0.00941	 0.0	 1349.0	 3346	 3346	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 964	 0.00074	 0.00969	 0.0	 1580.0	 3251	 3251	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 8347	 0.00042	 0.00532	 0.0	 1678.0	 5920	 5920	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 8347	 0.0004	 0.00473	 0.0	 1843.0	 6655	 6655	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 8347	 0.0006	 0.00499	 0.0	 1547.0	 6285	 6285	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 6552	 0.00086	 0.00638	 0.0	 610.0	 4907	 4907	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 6552	 0.000969	 0.00625	 0.0	 610.0	 4995	 4995	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 8999	 0.002781	 0.01725	 0.0	 457.0	 1808	 1808	 0.0	 0.0	 1	 -30.0	 30.0;
	4368	 4816	 0.005031	 0.028081	 0.0	 553.0	 1108	 1108	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 960	 1e-05	 0.00021	 0.0	 150246	 150246	 150246	 0.0	 0.0	 1	 -30.0	 30.0;
	7913	 960	 1e-05	 0.00025	 0.0	 126249	 126249	 126249	 0.0	 0.0	 1	 -30.0	 30.0;
	506	 960	 2e-05	 0.00031	 0.0	 757.0	 101684	 101684	 0.0	 0.0	 1	 -30.0	 30.0;
	2980	 960	 3e-05	 0.0004	 0.0	 757.0	 78748	 78748	 0.0	 0.0	 1	 -30.0	 30.0;
	4554	 6382	 0.000841	 0.00474	 0.0	 533.0	 6562	 6562	 0.0	 0.0	 1	 -30.0	 30.0;
	4554	 6382	 0.00082	 0.00487	 0.0	 533.0	 6397	 6397	 0.0	 0.0	 1	 -30.0	 30.0;
	6844	 1595	 0.00186	 0.011979	 0.0	 2606	 2606	 2606	 0.0	 0.0	 1	 -30.0	 30.0;
	3672	 5334	 0.00056	 0.003021	 0.0	 381.0	 10281	 10281	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 5334	 0.00055	 0.003081	 0.0	 10093	 10093	 10093	 0.0	 0.0	 1	 -30.0	 30.0;
	8997	 6153	 0.00114	 0.01063	 0.0	 2955	 2955	 2955	 0.0	 0.0	 1	 -30.0	 30.0;
	1852	 5935	 0.003719	 0.02295	 0.0	 629.0	 1359	 1359	 0.0	 0.0	 1	 -30.0	 30.0;
	1852	 5695	 0.006669	 0.04288	 0.0	 514.0	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	2931	 5799	 0.00243	 0.0198	 0.0	 1584	 1584	 1584	 0.0	 0.0	 1	 -30.0	 30.0;
	2931	 7124	 0.00845	 0.04339	 0.0	 533.0	 715	 715	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 3674	 0.00219	 0.015169	 0.0	 381.0	 2061	 2061	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 2132	 0.00357	 0.0302	 0.0	 419.0	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	2558	 7571	 0.005849	 0.032419	 0.0	 419.0	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	8834	 1129	 0.00406	 0.01688	 0.0	 1820	 1820	 1820	 0.0	 0.0	 1	 -30.0	 30.0;
	7377	 3324	 0.00113	 0.0065	 0.0	 4788	 4788	 4788	 0.0	 0.0	 1	 -30.0	 30.0;
	1265	 4426	 0.0068	 0.04613	 0.0	 514.0	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	1265	 1965	 0.00337	 0.02011	 0.0	 419.0	 1550	 1550	 0.0	 0.0	 1	 -30.0	 30.0;
	8060	 7162	 0.00011	 0.0005	 0.0	 61700	 61700	 61700	 0.0	 0.0	 1	 -30.0	 30.0;
	6922	 5482	 0.003711	 0.018521	 0.0	 438.0	 1673	 1673	 0.0	 0.0	 1	 -30.0	 30.0;
	6922	 1295	 0.000271	 0.00145	 0.0	 457.0	 21414	 21414	 0.0	 0.0	 1	 -30.0	 30.0;
	8369	 4710	 0.00326	 0.01824	 0.0	 1705	 1705	 1705	 0.0	 0.0	 1	 -30.0	 30.0;
	8961	 7133	 0.00118	 0.00712	 0.0	 419.0	 4377	 4377	 0.0	 0.0	 1	 -30.0	 30.0;
	8961	 6888	 0.00482	 0.02232	 0.0	 381.0	 1384	 1384	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 7019	 0.00013	 0.000469	 0.0	 381.0	 64904	 64904	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 6253	 0.000229	 0.00075	 0.0	 419.0	 40281	 40281	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 3391	 0.004591	 0.035021	 0.0	 533.0	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 1448	 0.005469	 0.03924	 0.0	 610.0	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 1448	 0.00536	 0.0403	 0.0	 777	 777	 777	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 115	 0.00424	 0.033031	 0.0	 949	 949	 949	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 4306	 2e-05	 0.00024	 0.0	 757.0	 131160	 131160	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 1763	 1e-05	 0.00021	 0.0	 757.0	 150246	 150246	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 3697	 0.00286	 0.03653	 0.0	 863	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 3794	 0.00117	 0.01183	 0.0	 1744.0	 2658	 2658	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 3613	 0.00103	 0.01336	 0.0	 1481.0	 2358	 2358	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 1502	 0.00156	 0.01969	 0.0	 1547.0	 1600	 1600	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 6555	 0.00449	 0.05772	 0.0	 546	 546	 546	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 3608	 0.00259	 0.03469	 0.0	 909	 909	 909	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 4134	 0.000219	 0.00118	 0.0	 26320	 26320	 26320	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 1979	 6e-05	 0.00095	 0.0	 33184	 33184	 33184	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 516	 6e-05	 0.000651	 0.0	 629.0	 48317	 48317	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 3580	 8.1e-05	 0.000841	 0.0	 629.0	 37387	 37387	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 3809	 0.00274	 0.020831	 0.0	 514.0	 1504	 1504	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 5616	 0.004781	 0.027729	 0.0	 553.0	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 5616	 0.002849	 0.02093	 0.0	 572.0	 1496	 1496	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 6697	 0.00513	 0.03014	 0.0	 514.0	 1034	 1034	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 7165	 0.00113	 0.00651	 0.0	 4781	 4781	 4781	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 892	 0.00125	 0.00707	 0.0	 572.0	 4400	 4400	 0.0	 0.0	 1	 -30.0	 30.0;
	7438	 5334	 0.003349	 0.01463	 0.0	 2105	 2105	 2105	 0.0	 0.0	 1	 -30.0	 30.0;
	7438	 1526	 0.00245	 0.0122	 0.0	 495.0	 2539	 2539	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 6952	 0.00587	 0.036521	 0.0	 400.0	 854	 854	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 6952	 0.00569	 0.03774	 0.0	 828	 828	 828	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 6952	 0.006031	 0.03545	 0.0	 629.0	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 7883	 0.000531	 0.00301	 0.0	 10335	 10335	 10335	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 6430	 0.00076	 0.006099	 0.0	 514.0	 5140	 5140	 0.0	 0.0	 1	 -30.0	 30.0;
	778	 7209	 0.008841	 0.028919	 0.0	 1045	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	778	 1910	 0.00169	 0.007091	 0.0	 4334	 4334	 4334	 0.0	 0.0	 1	 -30.0	 30.0;
	778	 6820	 0.001031	 0.00361	 0.0	 8414	 8414	 8414	 0.0	 0.0	 1	 -30.0	 30.0;
	778	 3071	 0.00813	 0.030961	 0.0	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 6267	 0.00013	 0.00068	 0.0	 533.0	 45626	 45626	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 3855	 0.000211	 0.000729	 0.0	 629.0	 41622	 41622	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 3855	 0.000169	 0.000669	 0.0	 591.0	 45778	 45778	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 2928	 0.000669	 0.00251	 0.0	 495.0	 12161	 12161	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 2928	 0.000711	 0.00238	 0.0	 476.0	 12717	 12717	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 1172	 0.000229	 0.00238	 0.0	 591.0	 13211	 13211	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 9191	 0.0007	 0.0065	 0.0	 553.0	 4832	 4832	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 8722	 0.00061	 0.006031	 0.0	 514.0	 5211	 5211	 0.0	 0.0	 1	 -30.0	 30.0;
	6472	 5362	 0.000281	 0.0018	 0.0	 629.0	 17339	 17339	 0.0	 0.0	 1	 -30.0	 30.0;
	6472	 3962	 0.000211	 0.002409	 0.0	 13063	 13063	 13063	 0.0	 0.0	 1	 -30.0	 30.0;
	1198	 1343	 0.00056	 0.00773	 0.0	 757.0	 4076	 4076	 0.0	 0.0	 1	 -30.0	 30.0;
	1198	 29	 0.0023	 0.01581	 0.0	 1218.0	 1978	 1978	 0.0	 0.0	 1	 -30.0	 30.0;
	7473	 3680	 0.005039	 0.032151	 0.0	 971	 971	 971	 0.0	 0.0	 1	 -30.0	 30.0;
	7473	 96	 0.00364	 0.01713	 0.0	 457.0	 1804	 1804	 0.0	 0.0	 1	 -30.0	 30.0;
	7473	 1868	 0.002169	 0.012409	 0.0	 2508	 2508	 2508	 0.0	 0.0	 1	 -30.0	 30.0;
	346	 3184	 0.00113	 0.004719	 0.0	 6510	 6510	 6510	 0.0	 0.0	 1	 -30.0	 30.0;
	346	 6570	 0.00113	 0.004979	 0.0	 476.0	 6187	 6187	 0.0	 0.0	 1	 -30.0	 30.0;
	3184	 4728	 0.00264	 0.01174	 0.0	 2626	 2626	 2626	 0.0	 0.0	 1	 -30.0	 30.0;
	2654	 7886	 0.00494	 0.03181	 0.0	 476.0	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	2654	 2132	 0.003711	 0.023961	 0.0	 610.0	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 8874	 0.001409	 0.01101	 0.0	 457.0	 2846	 2846	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 1625	 0.001169	 0.00593	 0.0	 381.0	 5227	 5227	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 1625	 0.00118	 0.00587	 0.0	 5276	 5276	 5276	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 3786	 0.00264	 0.012469	 0.0	 533.0	 2479	 2479	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 3786	 0.002349	 0.01414	 0.0	 495.0	 2204	 2204	 0.0	 0.0	 1	 -30.0	 30.0;
	3422	 4100	 0.00014	 0.0007	 0.0	 44249	 44249	 44249	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 4419	 3e-05	 0.00054	 0.0	 1876.0	 58406	 58406	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 7159	 3e-05	 0.00055	 0.0	 1810.0	 57347	 57347	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 3661	 4e-05	 0.00058	 0.0	 1777.0	 54332	 54332	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 5486	 4e-05	 0.00054	 0.0	 1876.0	 58336	 58336	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 4231	 0.00171	 0.02197	 0.0	 1382.0	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 4231	 0.00164	 0.02064	 0.0	 1526	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 6921	 0.00136	 0.01756	 0.0	 1711.0	 1794	 1794	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 432	 0.00097	 0.00942	 0.0	 1481.0	 3336	 3336	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 432	 0.00086	 0.01109	 0.0	 1481.0	 2840	 2840	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 432	 0.00085	 0.0113	 0.0	 1448.0	 2788	 2788	 0.0	 0.0	 1	 -30.0	 30.0;
	3353	 6887	 0.000979	 0.0058	 0.0	 400.0	 5371	 5371	 0.0	 0.0	 1	 -30.0	 30.0;
	2479	 2050	 0.00052	 0.00593	 0.0	 1909.0	 5307	 5307	 0.0	 0.0	 1	 -30.0	 30.0;
	2479	 2050	 0.00046	 0.00672	 0.0	 1909.0	 4690	 4690	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 8704	 0.001151	 0.00636	 0.0	 572.0	 4888	 4888	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 8704	 0.001031	 0.007211	 0.0	 591.0	 4337	 4337	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 4710	 0.002341	 0.02286	 0.0	 533.0	 1375	 1375	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 1295	 0.002281	 0.02518	 0.0	 400.0	 1250	 1250	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 1910	 0.005479	 0.02114	 0.0	 381.0	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 2985	 0.011159	 0.08856	 0.0	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 5853	 0.000669	 0.00249	 0.0	 400.0	 12252	 12252	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 7824	 0.00193	 0.01643	 0.0	 572.0	 1910	 1910	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 3071	 0.00024	 0.0017	 0.0	 438.0	 18399	 18399	 0.0	 0.0	 1	 -30.0	 30.0;
	4525	 195	 0.010159	 0.065849	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	9066	 7367	 0.00294	 0.02131	 0.0	 514.0	 1469	 1469	 0.0	 0.0	 1	 -30.0	 30.0;
	9066	 9155	 0.018841	 0.07469	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	9066	 6357	 0.015599	 0.052169	 0.0	 400.0	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	7886	 3126	 0.005831	 0.03969	 0.0	 495.0	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	7886	 8564	 0.00087	 0.00661	 0.0	 457.0	 4738	 4738	 0.0	 0.0	 1	 -30.0	 30.0;
	7886	 5567	 0.00637	 0.024659	 0.0	 381.0	 1241	 1241	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 3069	 0.0027	 0.020419	 0.0	 553.0	 1534	 1534	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 3876	 0.000409	 0.00314	 0.0	 438.0	 9976	 9976	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 8804	 0.001669	 0.01301	 0.0	 476.0	 2409	 2409	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 8804	 0.00164	 0.01325	 0.0	 495.0	 2366	 2366	 0.0	 0.0	 1	 -30.0	 30.0;
	7831	 4550	 0.00089	 0.00556	 0.0	 1283.0	 5610	 5610	 0.0	 0.0	 1	 -30.0	 30.0;
	7831	 4125	 0.00186	 0.01809	 0.0	 1613.0	 1737	 1737	 0.0	 0.0	 1	 -30.0	 30.0;
	7831	 3346	 0.00381	 0.02853	 0.0	 1020.0	 1098	 1098	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 2377	 0.012419	 0.072151	 0.0	 400.0	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 1401	 0.0042	 0.02556	 0.0	 400.0	 1220	 1220	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 2850	 0.010771	 0.0493	 0.0	 476.0	 626	 626	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 2430	 0.010159	 0.04995	 0.0	 400.0	 620	 620	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 9164	 0.013169	 0.05113	 0.0	 495.0	 599	 599	 0.0	 0.0	 1	 -30.0	 30.0;
	8511	 1033	 0.000469	 0.001159	 0.0	 400.0	 25264	 25264	 0.0	 0.0	 1	 -30.0	 30.0;
	8511	 6178	 0.000229	 0.00105	 0.0	 457.0	 29393	 29393	 0.0	 0.0	 1	 -30.0	 30.0;
	3400	 980	 0.000271	 0.001271	 0.0	 533.0	 24306	 24306	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 4598	 0.00099	 0.01194	 0.0	 1645.0	 2637	 2637	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 4541	 0.00077	 0.01184	 0.0	 2663	 2663	 2663	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 5144	 0.00034	 0.00426	 0.0	 7392	 7392	 7392	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 2129	 0.00101	 0.01168	 0.0	 1744.0	 2695	 2695	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 4541	 0.00086	 0.01046	 0.0	 1810.0	 3010	 3010	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 3513	 0.00035	 0.00417	 0.0	 7549	 7549	 7549	 0.0	 0.0	 1	 -30.0	 30.0;
	6675	 1486	 0.000159	 0.00069	 0.0	 533.0	 44610	 44610	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 5836	 0.000781	 0.00488	 0.0	 629.0	 6392	 6392	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 575	 0.000781	 0.00511	 0.0	 533.0	 6111	 6111	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 8214	 0.00064	 0.003539	 0.0	 457.0	 8784	 8784	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 8214	 0.00057	 0.003781	 0.0	 438.0	 8261	 8261	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 3021	 0.000531	 0.00111	 0.0	 25671	 25671	 25671	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 7967	 0.000521	 0.00113	 0.0	 25386	 25386	 25386	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 5993	 0.00176	 0.00843	 0.0	 438.0	 3668	 3668	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 8804	 0.002461	 0.01975	 0.0	 572.0	 1588	 1588	 0.0	 0.0	 1	 -30.0	 30.0;
	4513	 6831	 0.000591	 0.00105	 0.0	 26216	 26216	 26216	 0.0	 0.0	 1	 -30.0	 30.0;
	2043	 1422	 0.00012	 0.00064	 0.0	 48510	 48510	 48510	 0.0	 0.0	 1	 -30.0	 30.0;
	6714	 1808	 0.000581	 0.004419	 0.0	 7088	 7088	 7088	 0.0	 0.0	 1	 -30.0	 30.0;
	6371	 1808	 0.000651	 0.004331	 0.0	 7213	 7213	 7213	 0.0	 0.0	 1	 -30.0	 30.0;
	513	 2866	 0.001289	 0.008289	 0.0	 495.0	 3766	 3766	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 9222	 0.00233	 0.03502	 0.0	 757.0	 900	 900	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 9222	 0.00238	 0.03781	 0.0	 757.0	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 2072	 0.00052	 0.00605	 0.0	 1382.0	 5202	 5202	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 5461	 0.00023	 0.00275	 0.0	 1514.0	 11447	 11447	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 8109	 0.00134	 0.01343	 0.0	 1711.0	 2341	 2341	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 8109	 0.00116	 0.01552	 0.0	 1481.0	 2030	 2030	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 707	 0.004169	 0.027919	 0.0	 514.0	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 4816	 0.00063	 0.008	 0.0	 3937	 3937	 3937	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 1866	 0.004841	 0.028581	 0.0	 629.0	 1090	 1090	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 5488	 0.007419	 0.05787	 0.0	 542	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	5093	 2467	 0.002719	 0.020331	 0.0	 495.0	 1540	 1540	 0.0	 0.0	 1	 -30.0	 30.0;
	2328	 7178	 0.000789	 0.005	 0.0	 6241	 6241	 6241	 0.0	 0.0	 1	 -30.0	 30.0;
	9180	 195	 0.00238	 0.013219	 0.0	 457.0	 2352	 2352	 0.0	 0.0	 1	 -30.0	 30.0;
	9180	 3133	 0.003771	 0.02701	 0.0	 495.0	 1159	 1159	 0.0	 0.0	 1	 -30.0	 30.0;
	292	 4544	 0.001271	 0.00939	 0.0	 3334	 3334	 3334	 0.0	 0.0	 1	 -30.0	 30.0;
	9002	 6737	 0.000841	 0.00131	 0.0	 20291	 20291	 20291	 0.0	 0.0	 1	 -30.0	 30.0;
	8439	 3758	 0.005711	 0.043039	 0.0	 591.0	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	8439	 3758	 0.00562	 0.041901	 0.0	 495.0	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 2940	 0.00356	 0.019781	 0.0	 533.0	 1572	 1572	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 163	 0.004841	 0.03149	 0.0	 533.0	 992	 992	 0.0	 0.0	 1	 -30.0	 30.0;
	747	 8507	 0.00057	 0.00107	 0.0	 26055	 26055	 26055	 0.0	 0.0	 1	 -30.0	 30.0;
	6909	 4914	 0.000539	 0.00213	 0.0	 514.0	 14377	 14377	 0.0	 0.0	 1	 -30.0	 30.0;
	444	 4747	 0.0007	 0.00425	 0.0	 7334	 7334	 7334	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 6495	 0.0012	 0.009531	 0.0	 3289	 3289	 3289	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 2751	 0.00206	 0.015901	 0.0	 1971	 1971	 1971	 0.0	 0.0	 1	 -30.0	 30.0;
	3601	 4728	 0.00063	 0.00312	 0.0	 9924	 9924	 9924	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 6475	 3e-05	 0.00041	 0.0	 1481.0	 76837	 76837	 0.0	 0.0	 1	 -30.0	 30.0;
	1093	 6475	 2e-05	 0.00043	 0.0	 73380	 73380	 73380	 0.0	 0.0	 1	 -30.0	 30.0;
	5709	 6475	 3e-05	 0.00039	 0.0	 1283.0	 80755	 80755	 0.0	 0.0	 1	 -30.0	 30.0;
	3825	 6475	 3e-05	 0.00038	 0.0	 82867	 82867	 82867	 0.0	 0.0	 1	 -30.0	 30.0;
	1415	 3503	 0.0008	 0.004151	 0.0	 7473	 7473	 7473	 0.0	 0.0	 1	 -30.0	 30.0;
	4549	 3503	 0.000901	 0.00381	 0.0	 8069	 8069	 8069	 0.0	 0.0	 1	 -30.0	 30.0;
	3072	 639	 0.000591	 0.004341	 0.0	 476.0	 7210	 7210	 0.0	 0.0	 1	 -30.0	 30.0;
	3072	 639	 0.000591	 0.00405	 0.0	 495.0	 7718	 7718	 0.0	 0.0	 1	 -30.0	 30.0;
	5007	 4541	 0.00218	 0.0275	 0.0	 1146	 1146	 1146	 0.0	 0.0	 1	 -30.0	 30.0;
	5007	 8195	 0.00184	 0.01677	 0.0	 1086.0	 1873	 1873	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 964	 0.00058	 0.00807	 0.0	 1086.0	 3905	 3905	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 964	 0.00056	 0.00823	 0.0	 921.0	 3830	 3830	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 3906	 0.00123	 0.01146	 0.0	 1415.0	 2741	 2741	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 3906	 0.0011	 0.01298	 0.0	 1481.0	 2425	 2425	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 8347	 0.00156	 0.01585	 0.0	 1777.0	 1984	 1984	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 2919	 0.00226	 0.02781	 0.0	 1133	 1133	 1133	 0.0	 0.0	 1	 -30.0	 30.0;
	3758	 188	 0.00614	 0.02831	 0.0	 400.0	 1091	 1091	 0.0	 0.0	 1	 -30.0	 30.0;
	3758	 2242	 0.00513	 0.03401	 0.0	 919	 919	 919	 0.0	 0.0	 1	 -30.0	 30.0;
	3903	 4114	 0.013219	 0.0597	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	5743	 6990	 0.012969	 0.06087	 0.0	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	8626	 8930	 0.00437	 0.032831	 0.0	 553.0	 954	 954	 0.0	 0.0	 1	 -30.0	 30.0;
	8626	 2467	 0.005651	 0.033229	 0.0	 591.0	 938	 938	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 5488	 0.008969	 0.03625	 0.0	 438.0	 846	 846	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 7772	 0.012409	 0.05645	 0.0	 419.0	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	5003	 6382	 0.00038	 0.002271	 0.0	 400.0	 13719	 13719	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 4084	 0.00138	 0.01089	 0.0	 572.0	 2878	 2878	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 4084	 0.001539	 0.012521	 0.0	 591.0	 2504	 2504	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 53	 0.00205	 0.014229	 0.0	 533.0	 2198	 2198	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 7259	 0.00026	 0.00164	 0.0	 495.0	 19023	 19023	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 2475	 0.000289	 0.00169	 0.0	 18424	 18424	 18424	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 7577	 0.003349	 0.051211	 0.0	 457.0	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	7961	 2288	 0.00038	 0.001479	 0.0	 20686	 20686	 20686	 0.0	 0.0	 1	 -30.0	 30.0;
	1592	 7098	 0.00082	 0.00625	 0.0	 553.0	 5012	 5012	 0.0	 0.0	 1	 -30.0	 30.0;
	3187	 2079	 0.00275	 0.015581	 0.0	 572.0	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	6041	 5926	 0.000909	 0.00739	 0.0	 4243	 4243	 4243	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 8486	 0.00082	 0.01038	 0.0	 1547.0	 3034	 3034	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 7530	 0.00093	 0.01017	 0.0	 1382.0	 3094	 3094	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 1502	 0.00137	 0.01431	 0.0	 1876.0	 2198	 2198	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 1552	 0.00215	 0.02021	 0.0	 1555	 1555	 1555	 0.0	 0.0	 1	 -30.0	 30.0;
	6952	 3793	 0.01189	 0.058841	 0.0	 457.0	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 2526	 0.00104	 0.01241	 0.0	 1251.0	 2537	 2537	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 2526	 0.00092	 0.014	 0.0	 1251.0	 2252	 2252	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 2365	 0.00055	 0.00845	 0.0	 1152.0	 3731	 3731	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 2365	 0.00054	 0.00861	 0.0	 987.0	 3662	 3662	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 3794	 0.00105	 0.01057	 0.0	 1810.0	 2974	 2974	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 3613	 0.00089	 0.01122	 0.0	 1613.0	 2807	 2807	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 6901	 0.00223	 0.02584	 0.0	 1218	 1218	 1218	 0.0	 0.0	 1	 -30.0	 30.0;
	8180	 5106	 0.00101	 0.007841	 0.0	 553.0	 3996	 3996	 0.0	 0.0	 1	 -30.0	 30.0;
	8180	 5106	 0.001081	 0.008099	 0.0	 572.0	 3866	 3866	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 7165	 0.011081	 0.068479	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	9222	 8721	 2e-05	 0.00033	 0.0	 95544	 95544	 95544	 0.0	 0.0	 1	 -30.0	 30.0;
	9222	 8872	 1e-05	 0.00029	 0.0	 1777.0	 108858	 108858	 0.0	 0.0	 1	 -30.0	 30.0;
	9222	 8672	 0.00071	 0.00892	 0.0	 1580.0	 3531	 3531	 0.0	 0.0	 1	 -30.0	 30.0;
	9222	 7164	 0.00136	 0.01526	 0.0	 1448.0	 2062	 2062	 0.0	 0.0	 1	 -30.0	 30.0;
	5935	 7772	 0.005401	 0.036021	 0.0	 591.0	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	3134	 3430	 0.00437	 0.033719	 0.0	 457.0	 930	 930	 0.0	 0.0	 1	 -30.0	 30.0;
	3134	 1051	 0.005151	 0.034919	 0.0	 514.0	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	283	 800	 0.00038	 0.00139	 0.0	 21921	 21921	 21921	 0.0	 0.0	 1	 -30.0	 30.0;
	283	 1077	 0.00037	 0.0015	 0.0	 20446	 20446	 20446	 0.0	 0.0	 1	 -30.0	 30.0;
	283	 4747	 0.00069	 0.004461	 0.0	 533.0	 6998	 6998	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 5213	 0.00688	 0.040591	 0.0	 381.0	 768	 768	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 115	 0.001341	 0.008349	 0.0	 476.0	 3736	 3736	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 115	 0.001229	 0.009669	 0.0	 629.0	 3241	 3241	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 5753	 0.00137	 0.006039	 0.0	 419.0	 5101	 5101	 0.0	 0.0	 1	 -30.0	 30.0;
	7539	 6556	 0.001919	 0.01261	 0.0	 476.0	 2477	 2477	 0.0	 0.0	 1	 -30.0	 30.0;
	7539	 871	 0.00163	 0.0095	 0.0	 533.0	 3278	 3278	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 8874	 0.00488	 0.0497	 0.0	 572.0	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 4505	 0.001289	 0.0087	 0.0	 553.0	 3592	 3592	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 3436	 0.00211	 0.01524	 0.0	 572.0	 2054	 2054	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 3436	 0.00206	 0.015539	 0.0	 591.0	 2016	 2016	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 3436	 0.00276	 0.01631	 0.0	 514.0	 1910	 1910	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 6556	 0.00305	 0.019521	 0.0	 610.0	 1599	 1599	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 8765	 0.000409	 0.0023	 0.0	 495.0	 13522	 13522	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 6619	 0.00036	 0.00268	 0.0	 514.0	 11682	 11682	 0.0	 0.0	 1	 -30.0	 30.0;
	8165	 6734	 0.00032	 0.00049	 0.0	 53974	 53974	 53974	 0.0	 0.0	 1	 -30.0	 30.0;
	1078	 6734	 0.00013	 0.000349	 0.0	 84816	 84816	 84816	 0.0	 0.0	 1	 -30.0	 30.0;
	7988	 4231	 0.0002	 0.00327	 0.0	 9642	 9642	 9642	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 2142	 0.000919	 0.00561	 0.0	 533.0	 5557	 5557	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 2142	 0.00094	 0.00549	 0.0	 533.0	 5672	 5672	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 7519	 0.00175	 0.01976	 0.0	 533.0	 1593	 1593	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 6744	 0.001729	 0.019331	 0.0	 476.0	 1628	 1628	 0.0	 0.0	 1	 -30.0	 30.0;
	2286	 6802	 0.00406	 0.02581	 0.0	 572.0	 1209	 1209	 0.0	 0.0	 1	 -30.0	 30.0;
	2286	 769	 0.00526	 0.025961	 0.0	 514.0	 1193	 1193	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 1081	 0.00179	 0.02098	 0.0	 1349.0	 1501	 1501	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 5983	 0.00162	 0.02148	 0.0	 1382.0	 1467	 1467	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 8267	 0.00492	 0.04991	 0.0	 630	 630	 630	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 960	 0.00109	 0.01361	 0.0	 1086.0	 2314	 2314	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 960	 0.00097	 0.0153	 0.0	 889.0	 2061	 2061	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 3906	 0.00322	 0.03022	 0.0	 1040	 1040	 1040	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 7361	 0.032831	 0.074151	 0.0	 390	 390	 390	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 6852	 0.01411	 0.058711	 0.0	 514.0	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 8515	 0.02725	 0.102979	 0.0	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 3166	 0.012229	 0.04049	 0.0	 400.0	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 2676	 0.01994	 0.066719	 0.0	 454	 454	 454	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 3793	 0.018591	 0.07462	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 4529	 0.008979	 0.03251	 0.0	 937	 937	 937	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 4234	 0.016531	 0.086031	 0.0	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 44	 0.003591	 0.02137	 0.0	 591.0	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 6630	 0.00124	 0.008	 0.0	 400.0	 3902	 3902	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 6630	 0.001271	 0.007831	 0.0	 438.0	 3982	 3982	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 1545	 0.000469	 0.00294	 0.0	 495.0	 10610	 10610	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 4215	 0.000841	 0.003289	 0.0	 495.0	 9305	 9305	 0.0	 0.0	 1	 -30.0	 30.0;
	7163	 1917	 0.00219	 0.016539	 0.0	 400.0	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	7163	 5519	 0.002901	 0.020901	 0.0	 400.0	 1497	 1497	 0.0	 0.0	 1	 -30.0	 30.0;
	7647	 225	 0.0002	 0.001211	 0.0	 25736	 25736	 25736	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 1397	 9.1e-05	 0.000479	 0.0	 64786	 64786	 64786	 0.0	 0.0	 1	 -30.0	 30.0;
	7021	 7119	 0.005461	 0.029469	 0.0	 419.0	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	7021	 3324	 0.001979	 0.011289	 0.0	 591.0	 2757	 2757	 0.0	 0.0	 1	 -30.0	 30.0;
	1248	 163	 0.0023	 0.01289	 0.0	 2413	 2413	 2413	 0.0	 0.0	 1	 -30.0	 30.0;
	9045	 2457	 0.000159	 0.00037	 0.0	 78436	 78436	 78436	 0.0	 0.0	 1	 -30.0	 30.0;
	8874	 3786	 0.002789	 0.01562	 0.0	 533.0	 1991	 1991	 0.0	 0.0	 1	 -30.0	 30.0;
	5891	 5574	 0.002531	 0.012331	 0.0	 381.0	 2510	 2510	 0.0	 0.0	 1	 -30.0	 30.0;
	5891	 7663	 0.00357	 0.023289	 0.0	 400.0	 1341	 1341	 0.0	 0.0	 1	 -30.0	 30.0;
	5891	 4889	 0.00076	 0.006039	 0.0	 514.0	 5190	 5190	 0.0	 0.0	 1	 -30.0	 30.0;
	3997	 1526	 0.000469	 0.00075	 0.0	 35710	 35710	 35710	 0.0	 0.0	 1	 -30.0	 30.0;
	184	 1526	 0.00044	 0.00069	 0.0	 38599	 38599	 38599	 0.0	 0.0	 1	 -30.0	 30.0;
	2972	 2088	 0.00561	 0.035521	 0.0	 591.0	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	8676	 933	 0.004539	 0.03468	 0.0	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	8676	 933	 0.00175	 0.0067	 0.0	 419.0	 4562	 4562	 0.0	 0.0	 1	 -30.0	 30.0;
	8676	 3643	 0.007461	 0.031419	 0.0	 400.0	 979	 979	 0.0	 0.0	 1	 -30.0	 30.0;
	8704	 6723	 0.00224	 0.012909	 0.0	 610.0	 2411	 2411	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 21	 0.0003	 0.000961	 0.0	 419.0	 31376	 31376	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 21	 0.00032	 0.001409	 0.0	 21862	 21862	 21862	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 1551	 0.002031	 0.0157	 0.0	 553.0	 1996	 1996	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 4103	 0.00038	 0.00306	 0.0	 514.0	 10244	 10244	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 7862	 0.00118	 0.0083	 0.0	 553.0	 3768	 3768	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 5458	 0.001229	 0.00787	 0.0	 572.0	 3966	 3966	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 5666	 0.00301	 0.01538	 0.0	 514.0	 2016	 2016	 0.0	 0.0	 1	 -30.0	 30.0;
	6742	 5458	 0.00063	 0.00114	 0.0	 381.0	 24252	 24252	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 7862	 0.00064	 0.00111	 0.0	 24653	 24653	 24653	 0.0	 0.0	 1	 -30.0	 30.0;
	7775	 3857	 0.004919	 0.03837	 0.0	 629.0	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	6290	 3436	 0.001831	 0.008349	 0.0	 438.0	 3696	 3696	 0.0	 0.0	 1	 -30.0	 30.0;
	3430	 401	 0.00536	 0.03188	 0.0	 533.0	 978	 978	 0.0	 0.0	 1	 -30.0	 30.0;
	2967	 8976	 0.00038	 0.001461	 0.0	 20925	 20925	 20925	 0.0	 0.0	 1	 -30.0	 30.0;
	2967	 8976	 0.000289	 0.001521	 0.0	 20403	 20403	 20403	 0.0	 0.0	 1	 -30.0	 30.0;
	8976	 2481	 0.00305	 0.016841	 0.0	 476.0	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	8976	 9108	 0.001781	 0.012729	 0.0	 457.0	 2458	 2458	 0.0	 0.0	 1	 -30.0	 30.0;
	2056	 7520	 0.00041	 0.00461	 0.0	 954.0	 6825	 6825	 0.0	 0.0	 1	 -30.0	 30.0;
	2056	 7520	 0.0004	 0.0047	 0.0	 1020.0	 6697	 6697	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 5340	 0.00213	 0.01401	 0.0	 629.0	 2230	 2230	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 2319	 0.001271	 0.00887	 0.0	 438.0	 3526	 3526	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 2878	 0.00462	 0.02743	 0.0	 533.0	 1136	 1136	 0.0	 0.0	 1	 -30.0	 30.0;
	2597	 7422	 0.001539	 0.00776	 0.0	 3993	 3993	 3993	 0.0	 0.0	 1	 -30.0	 30.0;
	7183	 8931	 0.00025	 0.00478	 0.0	 10070	 10070	 10070	 0.0	 0.0	 1	 -30.0	 30.0;
	5379	 8931	 0.00025	 0.00487	 0.0	 9884	 9884	 9884	 0.0	 0.0	 1	 -30.0	 30.0;
	8128	 8931	 0.00025	 0.00435	 0.0	 823.0	 7250	 7250	 0.0	 0.0	 1	 -30.0	 30.0;
	6337	 8931	 0.00026	 0.00426	 0.0	 757.0	 7402	 7402	 0.0	 0.0	 1	 -30.0	 30.0;
	1237	 8931	 0.00025	 0.00479	 0.0	 10049	 10049	 10049	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 9173	 0.000169	 0.00076	 0.0	 438.0	 40572	 40572	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 7974	 0.00039	 0.00126	 0.0	 495.0	 23949	 23949	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 4816	 0.011229	 0.074659	 0.0	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 1866	 0.014521	 0.058081	 0.0	 400.0	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 8809	 0.00064	 0.003919	 0.0	 533.0	 7955	 7955	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 5146	 0.014789	 0.07768	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 6940	 0.00938	 0.05355	 0.0	 572.0	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 1742	 0.00124	 0.004289	 0.0	 419.0	 7075	 7075	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 8627	 0.00968	 0.04388	 0.0	 703	 703	 703	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 174	 0.008531	 0.067151	 0.0	 457.0	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 7437	 0.00731	 0.04106	 0.0	 438.0	 758	 758	 0.0	 0.0	 1	 -30.0	 30.0;
	7342	 5940	 0.004349	 0.02555	 0.0	 533.0	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	7342	 7495	 0.00599	 0.03462	 0.0	 476.0	 900	 900	 0.0	 0.0	 1	 -30.0	 30.0;
	8808	 4816	 0.002961	 0.021591	 0.0	 553.0	 1450	 1450	 0.0	 0.0	 1	 -30.0	 30.0;
	8808	 4816	 0.002901	 0.02206	 0.0	 572.0	 1420	 1420	 0.0	 0.0	 1	 -30.0	 30.0;
	8808	 6053	 0.002979	 0.016969	 0.0	 476.0	 1834	 1834	 0.0	 0.0	 1	 -30.0	 30.0;
	5764	 4189	 0.00312	 0.020021	 0.0	 476.0	 1559	 1559	 0.0	 0.0	 1	 -30.0	 30.0;
	8507	 1973	 0.000219	 0.000909	 0.0	 33783	 33783	 33783	 0.0	 0.0	 1	 -30.0	 30.0;
	1394	 1973	 0.000219	 0.00093	 0.0	 457.0	 33061	 33061	 0.0	 0.0	 1	 -30.0	 30.0;
	2898	 2128	 0.000151	 0.000289	 0.0	 96873	 96873	 96873	 0.0	 0.0	 1	 -30.0	 30.0;
	4942	 8255	 0.00563	 0.043599	 0.0	 719	 719	 719	 0.0	 0.0	 1	 -30.0	 30.0;
	4942	 4748	 0.000969	 0.00612	 0.0	 514.0	 5098	 5098	 0.0	 0.0	 1	 -30.0	 30.0;
	3486	 3594	 0.005021	 0.020719	 0.0	 438.0	 1482	 1482	 0.0	 0.0	 1	 -30.0	 30.0;
	3486	 4679	 0.00988	 0.041039	 0.0	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	4656	 4235	 0.003159	 0.02011	 0.0	 476.0	 1552	 1552	 0.0	 0.0	 1	 -30.0	 30.0;
	4656	 4235	 0.003219	 0.01969	 0.0	 476.0	 1584	 1584	 0.0	 0.0	 1	 -30.0	 30.0;
	7129	 5441	 0.00049	 0.00238	 0.0	 13000	 13000	 13000	 0.0	 0.0	 1	 -30.0	 30.0;
	7129	 5441	 0.000479	 0.002419	 0.0	 12810	 12810	 12810	 0.0	 0.0	 1	 -30.0	 30.0;
	8250	 5720	 0.00264	 0.019729	 0.0	 533.0	 1587	 1587	 0.0	 0.0	 1	 -30.0	 30.0;
	8250	 5720	 0.002581	 0.02011	 0.0	 495.0	 1558	 1558	 0.0	 0.0	 1	 -30.0	 30.0;
	6831	 6723	 0.00037	 0.002831	 0.0	 553.0	 11064	 11064	 0.0	 0.0	 1	 -30.0	 30.0;
	6831	 5686	 0.00213	 0.012789	 0.0	 514.0	 2437	 2437	 0.0	 0.0	 1	 -30.0	 30.0;
	2377	 805	 0.018669	 0.092281	 0.0	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	907	 9091	 3.9e-05	 0.000401	 0.0	 78402	 78402	 78402	 0.0	 0.0	 1	 -30.0	 30.0;
	4056	 9091	 6e-05	 0.00044	 0.0	 381.0	 71132	 71132	 0.0	 0.0	 1	 -30.0	 30.0;
	6837	 2142	 6e-05	 0.0005	 0.0	 514.0	 62725	 62725	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 2641	 0.001271	 0.007031	 0.0	 476.0	 4421	 4421	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 7577	 0.00055	 0.003159	 0.0	 610.0	 9851	 9851	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 7577	 0.00055	 0.00338	 0.0	 591.0	 9225	 9225	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 7577	 0.00105	 0.004771	 0.0	 495.0	 6466	 6466	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 1629	 0.003289	 0.015039	 0.0	 381.0	 2052	 2052	 0.0	 0.0	 1	 -30.0	 30.0;
	726	 687	 0.00036	 0.004349	 0.0	 610.0	 7239	 7239	 0.0	 0.0	 1	 -30.0	 30.0;
	3526	 687	 0.00038	 0.003669	 0.0	 8564	 8564	 8564	 0.0	 0.0	 1	 -30.0	 30.0;
	6382	 2425	 0.00118	 0.00701	 0.0	 4444	 4444	 4444	 0.0	 0.0	 1	 -30.0	 30.0;
	6382	 2425	 0.001229	 0.00686	 0.0	 533.0	 4533	 4533	 0.0	 0.0	 1	 -30.0	 30.0;
	6382	 5907	 0.00301	 0.0217	 0.0	 1442	 1442	 1442	 0.0	 0.0	 1	 -30.0	 30.0;
	6382	 5907	 0.003409	 0.01924	 0.0	 1617	 1617	 1617	 0.0	 0.0	 1	 -30.0	 30.0;
	6382	 5907	 0.003409	 0.01938	 0.0	 572.0	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	7847	 9217	 0.002719	 0.02131	 0.0	 1471	 1471	 1471	 0.0	 0.0	 1	 -30.0	 30.0;
	2981	 1448	 0.00295	 0.01956	 0.0	 1597	 1597	 1597	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 5686	 0.001091	 0.00831	 0.0	 476.0	 3769	 3769	 0.0	 0.0	 1	 -30.0	 30.0;
	2968	 5907	 0.00111	 0.008211	 0.0	 553.0	 3813	 3813	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 2155	 0.002469	 0.015271	 0.0	 629.0	 2042	 2042	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 8112	 0.00212	 0.01601	 0.0	 1956	 1956	 1956	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 2535	 0.00037	 0.0028	 0.0	 533.0	 11184	 11184	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 7098	 0.00162	 0.01238	 0.0	 2530	 2530	 2530	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 7098	 0.001909	 0.01162	 0.0	 2683	 2683	 2683	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 7098	 0.001909	 0.010729	 0.0	 553.0	 2899	 2899	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 3737	 0.00089	 0.00526	 0.0	 419.0	 5922	 5922	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 5529	 0.00087	 0.00536	 0.0	 5818	 5818	 5818	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 5753	 0.001521	 0.01176	 0.0	 533.0	 2664	 2664	 0.0	 0.0	 1	 -30.0	 30.0;
	9019	 6563	 0.00014	 0.000591	 0.0	 476.0	 52008	 52008	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 1101	 0.003531	 0.028781	 0.0	 1090	 1090	 1090	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 8291	 0.004599	 0.03657	 0.0	 553.0	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 8367	 0.00307	 0.019159	 0.0	 591.0	 1628	 1628	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 1100	 0.000581	 0.004461	 0.0	 514.0	 7022	 7022	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 6887	 0.00164	 0.01161	 0.0	 591.0	 2694	 2694	 0.0	 0.0	 1	 -30.0	 30.0;
	4939	 6880	 0.00057	 0.003281	 0.0	 533.0	 9486	 9486	 0.0	 0.0	 1	 -30.0	 30.0;
	7738	 6982	 0.020419	 0.063669	 0.0	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	6565	 3121	 0.01424	 0.04751	 0.0	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	8707	 280	 0.00157	 0.008849	 0.0	 553.0	 3515	 3515	 0.0	 0.0	 1	 -30.0	 30.0;
	8707	 2510	 0.01218	 0.07524	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	1625	 766	 0.00037	 0.00151	 0.0	 20318	 20318	 20318	 0.0	 0.0	 1	 -30.0	 30.0;
	8411	 6232	 0.000219	 0.000531	 0.0	 54993	 54993	 54993	 0.0	 0.0	 1	 -30.0	 30.0;
	3951	 1397	 0.002849	 0.0137	 0.0	 2258	 2258	 2258	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 7282	 0.00116	 0.01692	 0.0	 1283.0	 1863	 1863	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 7282	 0.00133	 0.01462	 0.0	 1415.0	 2152	 2152	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 6475	 0.00063	 0.00821	 0.0	 987.0	 3837	 3837	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 6475	 0.00064	 0.00804	 0.0	 1283.0	 3917	 3917	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 5420	 0.00126	 0.01272	 0.0	 1382.0	 2472	 2472	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 8267	 0.00337	 0.0494	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 7328	 0.0014	 0.0214	 0.0	 1473	 1473	 1473	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 7328	 0.00137	 0.02182	 0.0	 1445	 1445	 1445	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 7164	 0.00212	 0.02063	 0.0	 1218.0	 1524	 1524	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 410	 0.00186	 0.01045	 0.0	 610.0	 2976	 2976	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 7579	 0.00426	 0.021771	 0.0	 438.0	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 7579	 0.002659	 0.020539	 0.0	 495.0	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 4189	 0.00606	 0.049919	 0.0	 457.0	 629	 629	 0.0	 0.0	 1	 -30.0	 30.0;
	7282	 4196	 0.00109	 0.01192	 0.0	 889.0	 2639	 2639	 0.0	 0.0	 1	 -30.0	 30.0;
	1526	 3916	 0.013021	 0.049219	 0.0	 438.0	 621	 621	 0.0	 0.0	 1	 -30.0	 30.0;
	1526	 4747	 0.00236	 0.01239	 0.0	 438.0	 2505	 2505	 0.0	 0.0	 1	 -30.0	 30.0;
	1526	 4747	 0.0027	 0.015169	 0.0	 419.0	 2051	 2051	 0.0	 0.0	 1	 -30.0	 30.0;
	4541	 3346	 0.00285	 0.03283	 0.0	 959	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	4541	 3346	 0.00529	 0.03969	 0.0	 789	 789	 789	 0.0	 0.0	 1	 -30.0	 30.0;
	1343	 3346	 0.00254	 0.03721	 0.0	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 2719	 0.000159	 0.00069	 0.0	 44610	 44610	 44610	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 2719	 0.000229	 0.000979	 0.0	 31417	 31417	 31417	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 2719	 0.00024	 0.00082	 0.0	 36971	 36971	 36971	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 795	 0.000169	 0.00075	 0.0	 41087	 41087	 41087	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 4880	 0.00368	 0.01756	 0.0	 1761	 1761	 1761	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 1868	 0.002599	 0.020659	 0.0	 1518	 1518	 1518	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 5564	 0.00018	 0.00064	 0.0	 47512	 47512	 47512	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 7036	 0.000159	 0.000771	 0.0	 381.0	 40125	 40125	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 5940	 0.00357	 0.01981	 0.0	 476.0	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 7495	 0.006021	 0.03205	 0.0	 533.0	 969	 969	 0.0	 0.0	 1	 -30.0	 30.0;
	4850	 2886	 0.001781	 0.01164	 0.0	 533.0	 2683	 2683	 0.0	 0.0	 1	 -30.0	 30.0;
	4850	 7049	 0.002781	 0.018831	 0.0	 514.0	 1660	 1660	 0.0	 0.0	 1	 -30.0	 30.0;
	2510	 6146	 0.000349	 0.00281	 0.0	 11156	 11156	 11156	 0.0	 0.0	 1	 -30.0	 30.0;
	90	 1860	 0.00313	 0.02444	 0.0	 610.0	 1282	 1282	 0.0	 0.0	 1	 -30.0	 30.0;
	90	 1860	 0.00368	 0.02074	 0.0	 591.0	 1500	 1500	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 3276	 9.1e-05	 0.001539	 0.0	 20489	 20489	 20489	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 3545	 0.00251	 0.01111	 0.0	 2774	 2774	 2774	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 6842	 0.003081	 0.017961	 0.0	 419.0	 1734	 1734	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 6744	 0.005341	 0.030419	 0.0	 438.0	 1023	 1023	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 7635	 9.9e-05	 0.00126	 0.0	 514.0	 24993	 24993	 0.0	 0.0	 1	 -30.0	 30.0;
	9091	 1040	 0.002169	 0.017901	 0.0	 419.0	 1752	 1752	 0.0	 0.0	 1	 -30.0	 30.0;
	2457	 6178	 0.00011	 0.00038	 0.0	 79847	 79847	 79847	 0.0	 0.0	 1	 -30.0	 30.0;
	1422	 1462	 0.00212	 0.00494	 0.0	 5876	 5876	 5876	 0.0	 0.0	 1	 -30.0	 30.0;
	1422	 7772	 0.018901	 0.077349	 0.0	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	7881	 5365	 0.00957	 0.0395	 0.0	 457.0	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	7881	 6982	 0.02324	 0.063469	 0.0	 400.0	 468	 468	 0.0	 0.0	 1	 -30.0	 30.0;
	6926	 3327	 0.000531	 0.004331	 0.0	 610.0	 7240	 7240	 0.0	 0.0	 1	 -30.0	 30.0;
	1959	 615	 0.002581	 0.006229	 0.0	 4685	 4685	 4685	 0.0	 0.0	 1	 -30.0	 30.0;
	6455	 1262	 0.00031	 0.002211	 0.0	 419.0	 14149	 14149	 0.0	 0.0	 1	 -30.0	 30.0;
	803	 6982	 0.01087	 0.06114	 0.0	 438.0	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	803	 5918	 0.011581	 0.061099	 0.0	 419.0	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	7624	 3070	 0.002099	 0.016271	 0.0	 400.0	 1926	 1926	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 1547	 0.00093	 0.005461	 0.0	 5703	 5703	 5703	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 5237	 0.009591	 0.037039	 0.0	 419.0	 826	 826	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 772	 0.002591	 0.017211	 0.0	 553.0	 1815	 1815	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 8950	 0.00164	 0.013651	 0.0	 495.0	 2298	 2298	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 2079	 0.003219	 0.014719	 0.0	 457.0	 2097	 2097	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 2229	 0.00401	 0.022229	 0.0	 457.0	 1399	 1399	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 7049	 0.00126	 0.010211	 0.0	 591.0	 3071	 3071	 0.0	 0.0	 1	 -30.0	 30.0;
	4118	 7873	 0.009169	 0.03993	 0.0	 772	 772	 772	 0.0	 0.0	 1	 -30.0	 30.0;
	4118	 3865	 0.001349	 0.006081	 0.0	 5072	 5072	 5072	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 8486	 0.00156	 0.01931	 0.0	 1580.0	 1631	 1631	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 7530	 0.00152	 0.01968	 0.0	 1481.0	 1601	 1601	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 7778	 0.00094	 0.01433	 0.0	 1678.0	 2200	 2200	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 6897	 0.00092	 0.01461	 0.0	 1448.0	 2158	 2158	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 960	 0.00137	 0.02012	 0.0	 1119.0	 1567	 1567	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 960	 0.00134	 0.02051	 0.0	 921.0	 1537	 1537	 0.0	 0.0	 1	 -30.0	 30.0;
	3857	 4491	 0.00314	 0.042151	 0.0	 572.0	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	3857	 6010	 0.000651	 0.00494	 0.0	 6340	 6340	 6340	 0.0	 0.0	 1	 -30.0	 30.0;
	3857	 6940	 0.003961	 0.02426	 0.0	 591.0	 1286	 1286	 0.0	 0.0	 1	 -30.0	 30.0;
	858	 1642	 0.00013	 0.0015	 0.0	 20980	 20980	 20980	 0.0	 0.0	 1	 -30.0	 30.0;
	3028	 809	 0.00013	 0.00147	 0.0	 1876.0	 21405	 21405	 0.0	 0.0	 1	 -30.0	 30.0;
	4819	 1642	 0.00011	 0.00172	 0.0	 1876.0	 18328	 18328	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 809	 0.00012	 0.00166	 0.0	 18979	 18979	 18979	 0.0	 0.0	 1	 -30.0	 30.0;
	3869	 1642	 0.00012	 0.00168	 0.0	 1909.0	 18755	 18755	 0.0	 0.0	 1	 -30.0	 30.0;
	3741	 809	 0.00012	 0.00172	 0.0	 1909.0	 18321	 18321	 0.0	 0.0	 1	 -30.0	 30.0;
	742	 687	 0.00093	 0.005669	 0.0	 5499	 5499	 5499	 0.0	 0.0	 1	 -30.0	 30.0;
	2910	 7098	 0.00105	 0.00506	 0.0	 6113	 6113	 6113	 0.0	 0.0	 1	 -30.0	 30.0;
	5688	 6231	 0.00113	 0.006539	 0.0	 4761	 4761	 4761	 0.0	 0.0	 1	 -30.0	 30.0;
	5182	 5455	 0.00037	 0.002919	 0.0	 10736	 10736	 10736	 0.0	 0.0	 1	 -30.0	 30.0;
	707	 5695	 0.005169	 0.03738	 0.0	 476.0	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	3814	 954	 0.00125	 0.006669	 0.0	 457.0	 4656	 4656	 0.0	 0.0	 1	 -30.0	 30.0;
	2313	 2438	 0.001281	 0.00661	 0.0	 4692	 4692	 4692	 0.0	 0.0	 1	 -30.0	 30.0;
	195	 2985	 0.00226	 0.0138	 0.0	 457.0	 2259	 2259	 0.0	 0.0	 1	 -30.0	 30.0;
	2518	 3513	 0.00213	 0.02677	 0.0	 1177	 1177	 1177	 0.0	 0.0	 1	 -30.0	 30.0;
	2518	 3346	 0.00154	 0.01919	 0.0	 1349.0	 1641	 1641	 0.0	 0.0	 1	 -30.0	 30.0;
	4544	 601	 0.00687	 0.04413	 0.0	 708	 708	 708	 0.0	 0.0	 1	 -30.0	 30.0;
	4544	 3241	 0.0045	 0.04725	 0.0	 457.0	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	4544	 7338	 0.00138	 0.00837	 0.0	 3724	 3724	 3724	 0.0	 0.0	 1	 -30.0	 30.0;
	3069	 1538	 0.000419	 0.001901	 0.0	 16227	 16227	 16227	 0.0	 0.0	 1	 -30.0	 30.0;
	3069	 1538	 0.00043	 0.00186	 0.0	 16547	 16547	 16547	 0.0	 0.0	 1	 -30.0	 30.0;
	6115	 4729	 0.003331	 0.015099	 0.0	 591.0	 2043	 2043	 0.0	 0.0	 1	 -30.0	 30.0;
	3344	 6616	 0.002099	 0.01631	 0.0	 533.0	 1921	 1921	 0.0	 0.0	 1	 -30.0	 30.0;
	3809	 5616	 0.001331	 0.01082	 0.0	 591.0	 2898	 2898	 0.0	 0.0	 1	 -30.0	 30.0;
	3809	 6691	 0.00199	 0.00818	 0.0	 381.0	 3753	 3753	 0.0	 0.0	 1	 -30.0	 30.0;
	3809	 6691	 0.00169	 0.008831	 0.0	 3514	 3514	 3514	 0.0	 0.0	 1	 -30.0	 30.0;
	1326	 892	 0.001771	 0.014281	 0.0	 2196	 2196	 2196	 0.0	 0.0	 1	 -30.0	 30.0;
	601	 616	 0.003099	 0.01844	 0.0	 495.0	 1690	 1690	 0.0	 0.0	 1	 -30.0	 30.0;
	3496	 1551	 0.003409	 0.01819	 0.0	 438.0	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	4925	 2230	 0.00057	 0.00369	 0.0	 8460	 8460	 8460	 0.0	 0.0	 1	 -30.0	 30.0;
	8057	 5907	 0.001081	 0.00468	 0.0	 6577	 6577	 6577	 0.0	 0.0	 1	 -30.0	 30.0;
	5354	 5907	 0.00105	 0.004771	 0.0	 6466	 6466	 6466	 0.0	 0.0	 1	 -30.0	 30.0;
	3674	 616	 0.001979	 0.01549	 0.0	 591.0	 2023	 2023	 0.0	 0.0	 1	 -30.0	 30.0;
	3674	 7338	 0.001469	 0.015151	 0.0	 2076	 2076	 2076	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 5083	 0.000711	 0.003969	 0.0	 419.0	 7834	 7834	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 7576	 0.00051	 0.00274	 0.0	 11334	 11334	 11334	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 3191	 0.000521	 0.00306	 0.0	 495.0	 10177	 10177	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 3488	 0.00188	 0.011841	 0.0	 2635	 2635	 2635	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 1578	 0.002469	 0.010539	 0.0	 2919	 2919	 2919	 0.0	 0.0	 1	 -30.0	 30.0;
	575	 5300	 0.00045	 0.00351	 0.0	 514.0	 8927	 8927	 0.0	 0.0	 1	 -30.0	 30.0;
	3929	 9173	 0.00037	 0.000659	 0.0	 41796	 41796	 41796	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 3818	 0.000401	 0.0007	 0.0	 39156	 39156	 39156	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 6232	 0.00014	 0.000531	 0.0	 57521	 57521	 57521	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 1643	 0.000289	 0.0013	 0.0	 495.0	 23719	 23719	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 6253	 7e-05	 0.000289	 0.0	 106228	 106228	 106228	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 6684	 0.00051	 0.002151	 0.0	 381.0	 14289	 14289	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 8151	 0.00037	 0.00157	 0.0	 533.0	 19583	 19583	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 449	 0.00022	 0.00277	 0.0	 1448.0	 11368	 11368	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 449	 0.00025	 0.00271	 0.0	 1547.0	 11607	 11607	 0.0	 0.0	 1	 -30.0	 30.0;
	7641	 3037	 0.000271	 0.002081	 0.0	 572.0	 15052	 15052	 0.0	 0.0	 1	 -30.0	 30.0;
	7641	 3037	 0.00025	 0.00231	 0.0	 533.0	 13595	 13595	 0.0	 0.0	 1	 -30.0	 30.0;
	3191	 2340	 0.00095	 0.00331	 0.0	 9173	 9173	 9173	 0.0	 0.0	 1	 -30.0	 30.0;
	3191	 8711	 0.00093	 0.00336	 0.0	 9061	 9061	 9061	 0.0	 0.0	 1	 -30.0	 30.0;
	8104	 8722	 0.000341	 0.002211	 0.0	 591.0	 14120	 14120	 0.0	 0.0	 1	 -30.0	 30.0;
	2644	 9191	 0.00032	 0.00232	 0.0	 13488	 13488	 13488	 0.0	 0.0	 1	 -30.0	 30.0;
	4128	 8522	 3.9e-05	 0.000271	 0.0	 514.0	 115370	 115370	 0.0	 0.0	 1	 -30.0	 30.0;
	604	 7522	 0.00075	 0.0101	 0.0	 1613.0	 3119	 3119	 0.0	 0.0	 1	 -30.0	 30.0;
	604	 4000	 0.00118	 0.01455	 0.0	 1547.0	 2164	 2164	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 9021	 0.0017	 0.0098	 0.0	 514.0	 3176	 3176	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 9021	 0.001521	 0.01111	 0.0	 2817	 2817	 2817	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 2042	 0.000169	 0.001401	 0.0	 22385	 22385	 22385	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 687	 0.002591	 0.01725	 0.0	 610.0	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 3520	 0.000169	 0.001159	 0.0	 438.0	 26969	 26969	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 4729	 0.00307	 0.01339	 0.0	 533.0	 2300	 2300	 0.0	 0.0	 1	 -30.0	 30.0;
	2641	 4889	 0.002591	 0.013521	 0.0	 514.0	 2295	 2295	 0.0	 0.0	 1	 -30.0	 30.0;
	9067	 9051	 0.000581	 0.005031	 0.0	 553.0	 6238	 6238	 0.0	 0.0	 1	 -30.0	 30.0;
	6969	 5573	 0.001419	 0.00595	 0.0	 381.0	 5164	 5164	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 1494	 0.00205	 0.02664	 0.0	 1183	 1183	 1183	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 2732	 0.00295	 0.03721	 0.0	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 4550	 0.00335	 0.03648	 0.0	 863	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 1607	 0.00022	 0.00251	 0.0	 1251.0	 12537	 12537	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 2093	 0.00059	 0.00651	 0.0	 1645.0	 4833	 4833	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 2177	 0.008539	 0.041979	 0.0	 381.0	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 2841	 0.001349	 0.0052	 0.0	 400.0	 5880	 5880	 0.0	 0.0	 1	 -30.0	 30.0;
	3611	 7972	 0.00245	 0.013909	 0.0	 514.0	 2237	 2237	 0.0	 0.0	 1	 -30.0	 30.0;
	3611	 2481	 0.001469	 0.008419	 0.0	 553.0	 3697	 3697	 0.0	 0.0	 1	 -30.0	 30.0;
	5420	 7164	 0.00084	 0.00836	 0.0	 1349.0	 3760	 3760	 0.0	 0.0	 1	 -30.0	 30.0;
	7119	 2078	 0.002591	 0.017789	 0.0	 514.0	 1758	 1758	 0.0	 0.0	 1	 -30.0	 30.0;
	7119	 7873	 0.009651	 0.05968	 0.0	 419.0	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	7422	 7519	 0.00143	 0.00799	 0.0	 381.0	 3892	 3892	 0.0	 0.0	 1	 -30.0	 30.0;
	7422	 6744	 0.001969	 0.014909	 0.0	 572.0	 2101	 2101	 0.0	 0.0	 1	 -30.0	 30.0;
	1026	 1860	 0.01039	 0.06406	 0.0	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	4765	 3327	 0.000719	 0.005331	 0.0	 438.0	 5873	 5873	 0.0	 0.0	 1	 -30.0	 30.0;
	6036	 6921	 0.00052	 0.00565	 0.0	 1415.0	 5568	 5568	 0.0	 0.0	 1	 -30.0	 30.0;
	8670	 7069	 0.002409	 0.019479	 0.0	 495.0	 1610	 1610	 0.0	 0.0	 1	 -30.0	 30.0;
	8670	 7069	 0.00256	 0.019151	 0.0	 419.0	 1635	 1635	 0.0	 0.0	 1	 -30.0	 30.0;
	8670	 2866	 0.00656	 0.02288	 0.0	 381.0	 1328	 1328	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 6450	 0.0027	 0.014901	 0.0	 400.0	 2086	 2086	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 5738	 0.003591	 0.01362	 0.0	 400.0	 2243	 2243	 0.0	 0.0	 1	 -30.0	 30.0;
	7327	 2481	 0.002211	 0.01188	 0.0	 2614	 2614	 2614	 0.0	 0.0	 1	 -30.0	 30.0;
	7327	 8189	 0.00068	 0.00357	 0.0	 400.0	 8692	 8692	 0.0	 0.0	 1	 -30.0	 30.0;
	7474	 1584	 0.000211	 0.000969	 0.0	 400.0	 31852	 31852	 0.0	 0.0	 1	 -30.0	 30.0;
	8947	 3390	 9.9e-05	 0.000539	 0.0	 57640	 57640	 57640	 0.0	 0.0	 1	 -30.0	 30.0;
	1808	 6384	 0.00645	 0.0263	 0.0	 419.0	 1167	 1167	 0.0	 0.0	 1	 -30.0	 30.0;
	4624	 6031	 0.00063	 0.001901	 0.0	 15773	 15773	 15773	 0.0	 0.0	 1	 -30.0	 30.0;
	1721	 3558	 0.000281	 0.000669	 0.0	 43532	 43532	 43532	 0.0	 0.0	 1	 -30.0	 30.0;
	7694	 3865	 0.000219	 0.00064	 0.0	 46697	 46697	 46697	 0.0	 0.0	 1	 -30.0	 30.0;
	9181	 6723	 0.00014	 0.00105	 0.0	 29820	 29820	 29820	 0.0	 0.0	 1	 -30.0	 30.0;
	8373	 8748	 0.003219	 0.020729	 0.0	 533.0	 1506	 1506	 0.0	 0.0	 1	 -30.0	 30.0;
	8373	 8475	 0.00051	 0.003151	 0.0	 572.0	 9896	 9896	 0.0	 0.0	 1	 -30.0	 30.0;
	8373	 8475	 0.000409	 0.00331	 0.0	 514.0	 9471	 9471	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 6639	 0.002289	 0.017479	 0.0	 591.0	 1792	 1792	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 1187	 0.002831	 0.01895	 0.0	 533.0	 1649	 1649	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 7274	 0.006289	 0.036521	 0.0	 853	 853	 853	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 8992	 0.005651	 0.032169	 0.0	 438.0	 968	 968	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 7266	 0.00414	 0.02262	 0.0	 476.0	 1374	 1374	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 6734	 0.01095	 0.05814	 0.0	 457.0	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 1015	 0.009	 0.0368	 0.0	 495.0	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 8310	 0.000229	 0.00181	 0.0	 553.0	 17314	 17314	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 6570	 0.00119	 0.00726	 0.0	 610.0	 4294	 4294	 0.0	 0.0	 1	 -30.0	 30.0;
	9137	 749	 0.011771	 0.051669	 0.0	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	7522	 2183	 0.00209	 0.02279	 0.0	 1381	 1381	 1381	 0.0	 0.0	 1	 -30.0	 30.0;
	7571	 3916	 0.002031	 0.01443	 0.0	 2168	 2168	 2168	 0.0	 0.0	 1	 -30.0	 30.0;
	7571	 6891	 0.00145	 0.008479	 0.0	 553.0	 3673	 3673	 0.0	 0.0	 1	 -30.0	 30.0;
	2526	 6199	 0.00124	 0.01433	 0.0	 1514.0	 2197	 2197	 0.0	 0.0	 1	 -30.0	 30.0;
	2526	 6199	 0.00127	 0.01402	 0.0	 1876.0	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	1483	 3649	 0.013039	 0.052841	 0.0	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 6199	 0.00235	 0.02739	 0.0	 954.0	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 6199	 0.0024	 0.02681	 0.0	 1174	 1174	 1174	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 4141	 0.00135	 0.02056	 0.0	 757.0	 1534	 1534	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 1311	 0.00087	 0.01124	 0.0	 954.0	 2802	 2802	 0.0	 0.0	 1	 -30.0	 30.0;
	8316	 174	 0.0012	 0.00818	 0.0	 629.0	 3821	 3821	 0.0	 0.0	 1	 -30.0	 30.0;
	174	 6430	 0.006961	 0.05561	 0.0	 495.0	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 7892	 0.00105	 0.00763	 0.0	 476.0	 4102	 4102	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 561	 0.000219	 0.00182	 0.0	 17232	 17232	 17232	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 8843	 3.9e-05	 0.0002	 0.0	 155017	 155017	 155017	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 8843	 4.5e-05	 0.000195	 0.0	 157839	 157839	 157839	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 4239	 0.0035	 0.022651	 0.0	 533.0	 1379	 1379	 0.0	 0.0	 1	 -30.0	 30.0;
	3866	 1860	 0.004281	 0.02319	 0.0	 457.0	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	3866	 5395	 0.003729	 0.014021	 0.0	 419.0	 2178	 2178	 0.0	 0.0	 1	 -30.0	 30.0;
	7042	 2177	 0.00212	 0.01582	 0.0	 572.0	 1979	 1979	 0.0	 0.0	 1	 -30.0	 30.0;
	8672	 7164	 0.00056	 0.00784	 0.0	 757.0	 4019	 4019	 0.0	 0.0	 1	 -30.0	 30.0;
	1860	 7772	 0.004401	 0.01813	 0.0	 1694	 1694	 1694	 0.0	 0.0	 1	 -30.0	 30.0;
	1860	 7772	 0.005021	 0.02144	 0.0	 1435	 1435	 1435	 0.0	 0.0	 1	 -30.0	 30.0;
	4885	 2928	 0.00018	 0.000219	 0.0	 381.0	 111427	 111427	 0.0	 0.0	 1	 -30.0	 30.0;
	4157	 2928	 0.000151	 0.000211	 0.0	 121741	 121741	 121741	 0.0	 0.0	 1	 -30.0	 30.0;
	4432	 2928	 0.000151	 0.000211	 0.0	 121741	 121741	 121741	 0.0	 0.0	 1	 -30.0	 30.0;
	2072	 5983	 0.00282	 0.02591	 0.0	 1212	 1212	 1212	 0.0	 0.0	 1	 -30.0	 30.0;
	3450	 6552	 0.00131	 0.008539	 0.0	 533.0	 3657	 3657	 0.0	 0.0	 1	 -30.0	 30.0;
	3956	 7507	 0.002159	 0.015969	 0.0	 1961	 1961	 1961	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 1838	 0.00019	 0.000281	 0.0	 93122	 93122	 93122	 0.0	 0.0	 1	 -30.0	 30.0;
	5571	 2230	 0.0002	 0.000281	 0.0	 91583	 91583	 91583	 0.0	 0.0	 1	 -30.0	 30.0;
	2078	 8005	 0.00139	 0.00774	 0.0	 572.0	 4017	 4017	 0.0	 0.0	 1	 -30.0	 30.0;
	639	 6351	 0.01101	 0.06739	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	639	 2749	 0.00063	 0.00463	 0.0	 438.0	 6761	 6761	 0.0	 0.0	 1	 -30.0	 30.0;
	639	 9130	 0.002341	 0.009599	 0.0	 476.0	 3197	 3197	 0.0	 0.0	 1	 -30.0	 30.0;
	410	 4189	 0.00375	 0.021659	 0.0	 476.0	 1438	 1438	 0.0	 0.0	 1	 -30.0	 30.0;
	1494	 5781	 0.00056	 0.00749	 0.0	 1283.0	 4206	 4206	 0.0	 0.0	 1	 -30.0	 30.0;
	583	 6616	 0.00118	 0.00926	 0.0	 533.0	 3384	 3384	 0.0	 0.0	 1	 -30.0	 30.0;
	583	 6031	 0.002039	 0.013081	 0.0	 514.0	 2386	 2386	 0.0	 0.0	 1	 -30.0	 30.0;
	1746	 7507	 0.00155	 0.010961	 0.0	 2854	 2854	 2854	 0.0	 0.0	 1	 -30.0	 30.0;
	3276	 7635	 3.9e-05	 0.00036	 0.0	 419.0	 87233	 87233	 0.0	 0.0	 1	 -30.0	 30.0;
	1105	 196	 0.00024	 0.000409	 0.0	 381.0	 66610	 66610	 0.0	 0.0	 1	 -30.0	 30.0;
	8522	 7132	 0.000341	 0.001659	 0.0	 553.0	 18651	 18651	 0.0	 0.0	 1	 -30.0	 30.0;
	8522	 5351	 0.005461	 0.024919	 0.0	 457.0	 1239	 1239	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 7056	 0.00158	 0.02413	 0.0	 954.0	 1307	 1307	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 8825	 0.00155	 0.02458	 0.0	 856.0	 1283	 1283	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 6889	 0.00021	 0.00256	 0.0	 1415.0	 12298	 12298	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 6889	 0.00024	 0.00243	 0.0	 1514.0	 12936	 12936	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 8887	 0.00144	 0.02266	 0.0	 1392	 1392	 1392	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 8887	 0.0014	 0.02098	 0.0	 1503	 1503	 1503	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 8487	 0.00086	 0.01074	 0.0	 2932	 2932	 2932	 0.0	 0.0	 1	 -30.0	 30.0;
	8748	 8475	 0.003341	 0.02611	 0.0	 553.0	 1200	 1200	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 6785	 0.00387	 0.02063	 0.0	 514.0	 1505	 1505	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 6785	 0.00405	 0.018271	 0.0	 514.0	 1688	 1688	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 1179	 0.00101	 0.00462	 0.0	 400.0	 6680	 6680	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 2575	 0.00088	 0.00389	 0.0	 419.0	 7921	 7921	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 7274	 0.005081	 0.039	 0.0	 514.0	 804	 804	 0.0	 0.0	 1	 -30.0	 30.0;
	7972	 8189	 0.00257	 0.0208	 0.0	 553.0	 1508	 1508	 0.0	 0.0	 1	 -30.0	 30.0;
	7972	 8189	 0.00251	 0.01926	 0.0	 514.0	 1627	 1627	 0.0	 0.0	 1	 -30.0	 30.0;
	7972	 1039	 0.002531	 0.01314	 0.0	 2361	 2361	 2361	 0.0	 0.0	 1	 -30.0	 30.0;
	7253	 7840	 0.00132	 0.00869	 0.0	 3594	 3594	 3594	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 8913	 0.00082	 0.004021	 0.0	 419.0	 7698	 7698	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 4852	 0.00143	 0.007479	 0.0	 438.0	 4149	 4149	 0.0	 0.0	 1	 -30.0	 30.0;
	2795	 1183	 0.000659	 0.005771	 0.0	 5439	 5439	 5439	 0.0	 0.0	 1	 -30.0	 30.0;
	2795	 1183	 0.000591	 0.006539	 0.0	 4811	 4811	 4811	 0.0	 0.0	 1	 -30.0	 30.0;
	1305	 6291	 0.00589	 0.025599	 0.0	 476.0	 1203	 1203	 0.0	 0.0	 1	 -30.0	 30.0;
	1305	 6982	 0.00614	 0.02343	 0.0	 438.0	 1305	 1305	 0.0	 0.0	 1	 -30.0	 30.0;
	2732	 1798	 0.00155	 0.01994	 0.0	 1481.0	 1580	 1580	 0.0	 0.0	 1	 -30.0	 30.0;
	2732	 3346	 0.00205	 0.03218	 0.0	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	4550	 3346	 0.00233	 0.03154	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	4725	 5738	 0.002341	 0.01982	 0.0	 1583	 1583	 1583	 0.0	 0.0	 1	 -30.0	 30.0;
	1083	 8310	 8.1e-05	 0.000521	 0.0	 533.0	 59909	 59909	 0.0	 0.0	 1	 -30.0	 30.0;
	1398	 5567	 9.9e-05	 0.00069	 0.0	 591.0	 45315	 45315	 0.0	 0.0	 1	 -30.0	 30.0;
	4281	 4580	 0.00276	 0.016419	 0.0	 553.0	 1898	 1898	 0.0	 0.0	 1	 -30.0	 30.0;
	7050	 4908	 0.00036	 0.001229	 0.0	 457.0	 24666	 24666	 0.0	 0.0	 1	 -30.0	 30.0;
	7050	 3740	 0.000229	 0.000711	 0.0	 514.0	 42288	 42288	 0.0	 0.0	 1	 -30.0	 30.0;
	6563	 870	 0.00013	 0.00099	 0.0	 514.0	 31635	 31635	 0.0	 0.0	 1	 -30.0	 30.0;
	8999	 6495	 0.001159	 0.00689	 0.0	 419.0	 4522	 4522	 0.0	 0.0	 1	 -30.0	 30.0;
	6888	 5994	 0.008531	 0.03045	 0.0	 381.0	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 8005	 0.000781	 0.004531	 0.0	 514.0	 6871	 6871	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 8005	 0.00075	 0.00474	 0.0	 533.0	 6583	 6583	 0.0	 0.0	 1	 -30.0	 30.0;
	5881	 4031	 0.002159	 0.008349	 0.0	 3663	 3663	 3663	 0.0	 0.0	 1	 -30.0	 30.0;
	8195	 8334	 0.00162	 0.01651	 0.0	 1547.0	 1905	 1905	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 6357	 0.01236	 0.044211	 0.0	 400.0	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 6357	 0.00825	 0.03989	 0.0	 419.0	 776	 776	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 3775	 0.02187	 0.066961	 0.0	 449	 449	 449	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 3975	 0.01212	 0.06661	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3918	 1642	 0.00036	 0.00534	 0.0	 889.0	 5902	 5902	 0.0	 0.0	 1	 -30.0	 30.0;
	6802	 1153	 0.000229	 0.00063	 0.0	 47123	 47123	 47123	 0.0	 0.0	 1	 -30.0	 30.0;
	6802	 7599	 0.000219	 0.000581	 0.0	 50874	 50874	 50874	 0.0	 0.0	 1	 -30.0	 30.0;
	4025	 3994	 0.000281	 0.00063	 0.0	 45791	 45791	 45791	 0.0	 0.0	 1	 -30.0	 30.0;
	1595	 1414	 0.005021	 0.035659	 0.0	 419.0	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	3114	 3656	 0.00174	 0.007901	 0.0	 3905	 3905	 3905	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 2229	 0.003919	 0.020581	 0.0	 495.0	 1508	 1508	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 9108	 0.003341	 0.016349	 0.0	 495.0	 1893	 1893	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 1478	 0.003271	 0.016669	 0.0	 457.0	 1860	 1860	 0.0	 0.0	 1	 -30.0	 30.0;
	2799	 8515	 0.000151	 0.000659	 0.0	 419.0	 46722	 46722	 0.0	 0.0	 1	 -30.0	 30.0;
	6405	 7873	 0.00736	 0.035659	 0.0	 868	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	6405	 3894	 0.00944	 0.042169	 0.0	 731	 731	 731	 0.0	 0.0	 1	 -30.0	 30.0;
	4435	 4734	 0.00068	 0.00652	 0.0	 856.0	 4819	 4819	 0.0	 0.0	 1	 -30.0	 30.0;
	4435	 3483	 0.00188	 0.02281	 0.0	 1381	 1381	 1381	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 7052	 0.00168	 0.00956	 0.0	 533.0	 3255	 3255	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 7052	 0.001669	 0.00981	 0.0	 514.0	 3175	 3175	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 772	 0.002229	 0.01599	 0.0	 591.0	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 772	 0.00218	 0.01631	 0.0	 610.0	 1920	 1920	 0.0	 0.0	 1	 -30.0	 30.0;
	1081	 6475	 0.00238	 0.02124	 0.0	 1053.0	 1478	 1478	 0.0	 0.0	 1	 -30.0	 30.0;
	1081	 6475	 0.00194	 0.02023	 0.0	 1251.0	 1555	 1555	 0.0	 0.0	 1	 -30.0	 30.0;
	7361	 3166	 0.013831	 0.05955	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	7361	 426	 0.00876	 0.04875	 0.0	 419.0	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	2863	 1857	 0.0002	 0.00099	 0.0	 400.0	 31275	 31275	 0.0	 0.0	 1	 -30.0	 30.0;
	1364	 2430	 0.00105	 0.00826	 0.0	 476.0	 3794	 3794	 0.0	 0.0	 1	 -30.0	 30.0;
	2177	 749	 0.0172	 0.06637	 0.0	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	3594	 2850	 0.00305	 0.015781	 0.0	 476.0	 1966	 1966	 0.0	 0.0	 1	 -30.0	 30.0;
	6555	 3608	 0.00208	 0.02105	 0.0	 1481.0	 1494	 1494	 0.0	 0.0	 1	 -30.0	 30.0;
	8475	 1965	 0.00614	 0.043729	 0.0	 476.0	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	8475	 5926	 0.000229	 0.001849	 0.0	 553.0	 16954	 16954	 0.0	 0.0	 1	 -30.0	 30.0;
	5735	 6053	 0.00386	 0.025789	 0.0	 438.0	 1212	 1212	 0.0	 0.0	 1	 -30.0	 30.0;
	5735	 2341	 0.002031	 0.012	 0.0	 591.0	 2596	 2596	 0.0	 0.0	 1	 -30.0	 30.0;
	2629	 7507	 0.000591	 0.004	 0.0	 495.0	 7813	 7813	 0.0	 0.0	 1	 -30.0	 30.0;
	1137	 2406	 9.1e-05	 0.00051	 0.0	 60973	 60973	 60973	 0.0	 0.0	 1	 -30.0	 30.0;
	7577	 5814	 0.00732	 0.039969	 0.0	 419.0	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	7577	 3231	 0.004581	 0.02031	 0.0	 629.0	 1518	 1518	 0.0	 0.0	 1	 -30.0	 30.0;
	7663	 5814	 0.00132	 0.00537	 0.0	 457.0	 5713	 5713	 0.0	 0.0	 1	 -30.0	 30.0;
	1183	 1159	 0.007521	 0.0387	 0.0	 476.0	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	6852	 5051	 0.005159	 0.031281	 0.0	 533.0	 997	 997	 0.0	 0.0	 1	 -30.0	 30.0;
	8307	 8807	 9.9e-05	 0.001159	 0.0	 27156	 27156	 27156	 0.0	 0.0	 1	 -30.0	 30.0;
	6947	 8807	 9.9e-05	 0.00113	 0.0	 27847	 27847	 27847	 0.0	 0.0	 1	 -30.0	 30.0;
	4505	 4357	 0.00019	 0.000909	 0.0	 381.0	 34015	 34015	 0.0	 0.0	 1	 -30.0	 30.0;
	7144	 7791	 0.00107	 0.00413	 0.0	 7404	 7404	 7404	 0.0	 0.0	 1	 -30.0	 30.0;
	6889	 2085	 9e-05	 0.00058	 0.0	 1251.0	 53817	 53817	 0.0	 0.0	 1	 -30.0	 30.0;
	6889	 4024	 9e-05	 0.00059	 0.0	 1152.0	 52926	 52926	 0.0	 0.0	 1	 -30.0	 30.0;
	6889	 9065	 8e-05	 0.00053	 0.0	 757.0	 58932	 58932	 0.0	 0.0	 1	 -30.0	 30.0;
	6889	 661	 8e-05	 0.00052	 0.0	 757.0	 60039	 60039	 0.0	 0.0	 1	 -30.0	 30.0;
	6612	 8864	 0.000271	 0.00151	 0.0	 495.0	 20590	 20590	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 6199	 0.00053	 0.00585	 0.0	 1909.0	 5378	 5378	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 6199	 0.00047	 0.00663	 0.0	 1448.0	 4753	 4753	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 6199	 0.00046	 0.00676	 0.0	 1251.0	 4662	 4662	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 6199	 0.00045	 0.00689	 0.0	 1251.0	 4575	 4575	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 8494	 0.00028	 0.00338	 0.0	 1580.0	 9314	 9314	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 8494	 0.0003	 0.00319	 0.0	 1349.0	 9859	 9859	 0.0	 0.0	 1	 -30.0	 30.0;
	1643	 4511	 0.00025	 0.00101	 0.0	 476.0	 30359	 30359	 0.0	 0.0	 1	 -30.0	 30.0;
	196	 1973	 0.000281	 0.00119	 0.0	 25834	 25834	 25834	 0.0	 0.0	 1	 -30.0	 30.0;
	2902	 5573	 0.00018	 0.00063	 0.0	 48210	 48210	 48210	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 4410	 0.00382	 0.02868	 0.0	 1092	 1092	 1092	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 333	 0.00361	 0.0235	 0.0	 572.0	 1329	 1329	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 6908	 0.00538	 0.03569	 0.0	 876	 876	 876	 0.0	 0.0	 1	 -30.0	 30.0;
	3377	 7726	 6e-05	 0.000409	 0.0	 514.0	 76413	 76413	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 3243	 9e-05	 0.00102	 0.0	 757.0	 30849	 30849	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 2458	 0.0014	 0.01649	 0.0	 1711.0	 1909	 1909	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 2919	 0.00034	 0.00427	 0.0	 1119.0	 7375	 7375	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 8560	 0.0001	 0.00109	 0.0	 757.0	 28859	 28859	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 6427	 0.00137	 0.01682	 0.0	 1777.0	 1872	 1872	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 8347	 0.00131	 0.01262	 0.0	 1514.0	 2490	 2490	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 5610	 0.00262	 0.019669	 0.0	 533.0	 1592	 1592	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 2421	 0.00082	 0.00526	 0.0	 476.0	 5934	 5934	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 2421	 0.000841	 0.005151	 0.0	 457.0	 6053	 6053	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 2421	 0.000669	 0.005081	 0.0	 476.0	 6164	 6164	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 6989	 0.001919	 0.012669	 0.0	 476.0	 2466	 2466	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 1545	 0.002659	 0.02	 0.0	 1566	 1566	 1566	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 3541	 0.003031	 0.02343	 0.0	 572.0	 1338	 1338	 0.0	 0.0	 1	 -30.0	 30.0;
	6231	 4710	 0.01176	 0.059159	 0.0	 400.0	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	6231	 8367	 0.002469	 0.017531	 0.0	 495.0	 1785	 1785	 0.0	 0.0	 1	 -30.0	 30.0;
	6231	 2288	 0.000669	 0.005729	 0.0	 5477	 5477	 5477	 0.0	 0.0	 1	 -30.0	 30.0;
	8291	 8473	 0.000781	 0.00876	 0.0	 381.0	 3592	 3592	 0.0	 0.0	 1	 -30.0	 30.0;
	8291	 5455	 0.00062	 0.00482	 0.0	 553.0	 6500	 6500	 0.0	 0.0	 1	 -30.0	 30.0;
	8291	 7635	 0.001349	 0.012599	 0.0	 533.0	 2493	 2493	 0.0	 0.0	 1	 -30.0	 30.0;
	6842	 8473	 0.000979	 0.0082	 0.0	 3825	 3825	 3825	 0.0	 0.0	 1	 -30.0	 30.0;
	6842	 883	 0.008091	 0.028831	 0.0	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	6842	 2288	 0.000711	 0.005969	 0.0	 514.0	 5255	 5255	 0.0	 0.0	 1	 -30.0	 30.0;
	3969	 7726	 0.00145	 0.00857	 0.0	 3635	 3635	 3635	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 1129	 0.00869	 0.03768	 0.0	 400.0	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 3070	 0.001719	 0.00837	 0.0	 457.0	 3697	 3697	 0.0	 0.0	 1	 -30.0	 30.0;
	8515	 5365	 0.01582	 0.067349	 0.0	 438.0	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	8515	 5365	 0.01457	 0.06469	 0.0	 400.0	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	8515	 4529	 0.021711	 0.090539	 0.0	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	8515	 3364	 0.00019	 0.000729	 0.0	 400.0	 41929	 41929	 0.0	 0.0	 1	 -30.0	 30.0;
	935	 5383	 0.001271	 0.00638	 0.0	 400.0	 4856	 4856	 0.0	 0.0	 1	 -30.0	 30.0;
	920	 6570	 3.9e-05	 0.0002	 0.0	 400.0	 155017	 155017	 0.0	 0.0	 1	 -30.0	 30.0;
	6664	 4426	 0.000281	 0.00236	 0.0	 629.0	 13291	 13291	 0.0	 0.0	 1	 -30.0	 30.0;
	4339	 2183	 0.00019	 0.00329	 0.0	 1744.0	 9586	 9586	 0.0	 0.0	 1	 -30.0	 30.0;
	7513	 4000	 0.00035	 0.00324	 0.0	 9693	 9693	 9693	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 8542	 0.00049	 0.00349	 0.0	 419.0	 8963	 8963	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 8542	 0.000469	 0.00331	 0.0	 419.0	 9449	 9449	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 1662	 0.00313	 0.01324	 0.0	 2322	 2322	 2322	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 9119	 0.001031	 0.006719	 0.0	 476.0	 4647	 4647	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 1151	 0.00038	 0.00401	 0.0	 7843	 7843	 7843	 0.0	 0.0	 1	 -30.0	 30.0;
	502	 3589	 0.00037	 0.002849	 0.0	 495.0	 10995	 10995	 0.0	 0.0	 1	 -30.0	 30.0;
	8473	 1040	 0.00032	 0.00256	 0.0	 476.0	 12244	 12244	 0.0	 0.0	 1	 -30.0	 30.0;
	8473	 145	 0.00037	 0.00118	 0.0	 381.0	 25543	 25543	 0.0	 0.0	 1	 -30.0	 30.0;
	8473	 4267	 0.00068	 0.001151	 0.0	 23628	 23628	 23628	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 5179	 0.00168	 0.009841	 0.0	 495.0	 3164	 3164	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 8854	 0.000599	 0.002401	 0.0	 400.0	 12765	 12765	 0.0	 0.0	 1	 -30.0	 30.0;
	9018	 4	 0.002169	 0.00911	 0.0	 400.0	 3374	 3374	 0.0	 0.0	 1	 -30.0	 30.0;
	9018	 4829	 0.002849	 0.01282	 0.0	 457.0	 2406	 2406	 0.0	 0.0	 1	 -30.0	 30.0;
	6253	 5383	 0.001229	 0.01207	 0.0	 553.0	 2604	 2604	 0.0	 0.0	 1	 -30.0	 30.0;
	6253	 7507	 0.001289	 0.01089	 0.0	 610.0	 2881	 2881	 0.0	 0.0	 1	 -30.0	 30.0;
	8887	 1644	 0.00093	 0.01036	 0.0	 856.0	 3037	 3037	 0.0	 0.0	 1	 -30.0	 30.0;
	8887	 3483	 0.00083	 0.01174	 0.0	 823.0	 2684	 2684	 0.0	 0.0	 1	 -30.0	 30.0;
	6639	 7840	 0.00118	 0.009469	 0.0	 3311	 3311	 3311	 0.0	 0.0	 1	 -30.0	 30.0;
	6639	 7840	 0.001151	 0.009651	 0.0	 3250	 3250	 3250	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 8109	 0.00101	 0.01327	 0.0	 1580.0	 2374	 2374	 0.0	 0.0	 1	 -30.0	 30.0;
	6291	 4189	 0.00364	 0.02486	 0.0	 572.0	 1258	 1258	 0.0	 0.0	 1	 -30.0	 30.0;
	8405	 4747	 0.00056	 0.00425	 0.0	 533.0	 7369	 7369	 0.0	 0.0	 1	 -30.0	 30.0;
	8405	 4580	 0.00369	 0.02681	 0.0	 533.0	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	338	 7824	 0.000531	 0.00276	 0.0	 400.0	 11239	 11239	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 7824	 0.000521	 0.00281	 0.0	 381.0	 11053	 11053	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 7824	 0.000419	 0.00232	 0.0	 13399	 13399	 13399	 0.0	 0.0	 1	 -30.0	 30.0;
	2189	 7824	 0.000409	 0.00237	 0.0	 13134	 13134	 13134	 0.0	 0.0	 1	 -30.0	 30.0;
	8458	 8267	 0.00014	 0.00193	 0.0	 1514.0	 16324	 16324	 0.0	 0.0	 1	 -30.0	 30.0;
	2676	 5987	 0.003211	 0.01481	 0.0	 419.0	 2085	 2085	 0.0	 0.0	 1	 -30.0	 30.0;
	1187	 5712	 0.00381	 0.01175	 0.0	 2558	 2558	 2558	 0.0	 0.0	 1	 -30.0	 30.0;
	1187	 6521	 0.003781	 0.02676	 0.0	 419.0	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 8636	 0.000919	 0.005461	 0.0	 553.0	 5704	 5704	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 8829	 0.000271	 0.001211	 0.0	 381.0	 25455	 25455	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 4235	 0.002229	 0.017401	 0.0	 572.0	 1801	 1801	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 4235	 0.00243	 0.017659	 0.0	 610.0	 1773	 1773	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 4235	 0.002531	 0.01705	 0.0	 591.0	 1833	 1833	 0.0	 0.0	 1	 -30.0	 30.0;
	8818	 5099	 0.012531	 0.05451	 0.0	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 4734	 0.00087	 0.01212	 0.0	 1349.0	 2600	 2600	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 905	 0.0006	 0.00802	 0.0	 1711.0	 3928	 3928	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 8334	 0.00072	 0.00667	 0.0	 1843.0	 4709	 4709	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 2093	 0.00234	 0.02626	 0.0	 1199	 1199	 1199	 0.0	 0.0	 1	 -30.0	 30.0;
	6772	 6989	 0.00038	 0.002969	 0.0	 514.0	 10553	 10553	 0.0	 0.0	 1	 -30.0	 30.0;
	7885	 3912	 0.00024	 0.00045	 0.0	 61936	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	6730	 3912	 0.000229	 0.000409	 0.0	 67388	 67388	 67388	 0.0	 0.0	 1	 -30.0	 30.0;
	4301	 3912	 0.000281	 0.000401	 0.0	 64510	 64510	 64510	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 5610	 0.001211	 0.005271	 0.0	 5841	 5841	 5841	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 350	 0.000281	 0.00107	 0.0	 438.0	 28553	 28553	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 6763	 0.00025	 0.001091	 0.0	 28222	 28222	 28222	 0.0	 0.0	 1	 -30.0	 30.0;
	3855	 1973	 0.00019	 0.00081	 0.0	 629.0	 37967	 37967	 0.0	 0.0	 1	 -30.0	 30.0;
	3855	 1973	 0.00045	 0.00136	 0.0	 591.0	 22051	 22051	 0.0	 0.0	 1	 -30.0	 30.0;
	3481	 554	 0.003461	 0.023289	 0.0	 1342	 1342	 1342	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 8222	 0.0013	 0.01609	 0.0	 1843.0	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 8222	 0.00128	 0.0164	 0.0	 1711.0	 1921	 1921	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 2721	 0.00089	 0.01082	 0.0	 1580.0	 2910	 2910	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 2721	 0.00087	 0.01102	 0.0	 1645.0	 2858	 2858	 0.0	 0.0	 1	 -30.0	 30.0;
	3786	 8578	 0.003349	 0.02514	 0.0	 533.0	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	490	 2653	 0.0003	 0.00061	 0.0	 46468	 46468	 46468	 0.0	 0.0	 1	 -30.0	 30.0;
	148	 7069	 0.000289	 0.001211	 0.0	 514.0	 25372	 25372	 0.0	 0.0	 1	 -30.0	 30.0;
	7256	 8743	 0.01301	 0.044091	 0.0	 438.0	 688	 688	 0.0	 0.0	 1	 -30.0	 30.0;
	7256	 1742	 0.02162	 0.065969	 0.0	 400.0	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	8930	 314	 0.006461	 0.05275	 0.0	 514.0	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	6954	 7974	 0.0002	 0.000271	 0.0	 93784	 93784	 93784	 0.0	 0.0	 1	 -30.0	 30.0;
	3325	 7974	 0.00018	 0.00026	 0.0	 99888	 99888	 99888	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 1742	 0.00032	 0.00188	 0.0	 16564	 16564	 16564	 0.0	 0.0	 1	 -30.0	 30.0;
	5610	 6989	 0.00105	 0.006591	 0.0	 476.0	 4733	 4733	 0.0	 0.0	 1	 -30.0	 30.0;
	21	 6163	 0.00013	 0.00055	 0.0	 55892	 55892	 55892	 0.0	 0.0	 1	 -30.0	 30.0;
	3749	 5365	 0.006151	 0.04013	 0.0	 629.0	 779	 779	 0.0	 0.0	 1	 -30.0	 30.0;
	3749	 6982	 0.007159	 0.040591	 0.0	 533.0	 767	 767	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 3133	 0.00874	 0.048461	 0.0	 400.0	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 4738	 0.004159	 0.01606	 0.0	 1905	 1905	 1905	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 3656	 0.002919	 0.01912	 0.0	 533.0	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 4300	 0.00094	 0.00394	 0.0	 419.0	 7799	 7799	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 5789	 0.000901	 0.00395	 0.0	 7797	 7797	 7797	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 2467	 0.003159	 0.017789	 0.0	 572.0	 1749	 1749	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 2467	 0.002419	 0.018331	 0.0	 1709	 1709	 1709	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 5256	 0.00375	 0.018281	 0.0	 419.0	 1693	 1693	 0.0	 0.0	 1	 -30.0	 30.0;
	3200	 2653	 0.00025	 0.001031	 0.0	 419.0	 29775	 29775	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 4852	 0.00264	 0.01238	 0.0	 419.0	 2496	 2496	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 4852	 0.001289	 0.00795	 0.0	 457.0	 3923	 3923	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 1151	 0.00087	 0.003081	 0.0	 476.0	 9867	 9867	 0.0	 0.0	 1	 -30.0	 30.0;
	8568	 5215	 0.000401	 0.00224	 0.0	 419.0	 13881	 13881	 0.0	 0.0	 1	 -30.0	 30.0;
	58	 221	 0.0003	 0.00385	 0.0	 8180	 8180	 8180	 0.0	 0.0	 1	 -30.0	 30.0;
	6807	 851	 0.00126	 0.008219	 0.0	 533.0	 3799	 3799	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 5099	 0.01905	 0.055729	 0.0	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 3558	 0.00201	 0.00444	 0.0	 6482	 6482	 6482	 0.0	 0.0	 1	 -30.0	 30.0;
	7209	 2934	 0.00101	 0.00324	 0.0	 9308	 9308	 9308	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 4787	 0.00105	 0.00677	 0.0	 1218.0	 4611	 4611	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 3830	 0.00039	 0.00502	 0.0	 1152.0	 6274	 6274	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 5648	 0.0004	 0.00492	 0.0	 954.0	 6400	 6400	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 4000	 0.00051	 0.00617	 0.0	 1349.0	 5103	 5103	 0.0	 0.0	 1	 -30.0	 30.0;
	7537	 3485	 0.0003	 0.00314	 0.0	 1580.0	 10015	 10015	 0.0	 0.0	 1	 -30.0	 30.0;
	7537	 3830	 0.00051	 0.00668	 0.0	 1645.0	 4715	 4715	 0.0	 0.0	 1	 -30.0	 30.0;
	7537	 5648	 0.0005	 0.00678	 0.0	 1777.0	 4647	 4647	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 2424	 0.002909	 0.017	 0.0	 1832	 1832	 1832	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 1156	 0.00245	 0.011281	 0.0	 476.0	 2737	 2737	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 4914	 0.0027	 0.01532	 0.0	 457.0	 2031	 2031	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 4914	 0.00105	 0.011151	 0.0	 2821	 2821	 2821	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 3834	 0.00036	 0.002669	 0.0	 11729	 11729	 11729	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 556	 0.0018	 0.011169	 0.0	 457.0	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 3019	 0.000711	 0.007771	 0.0	 4048	 4048	 4048	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 7923	 0.00036	 0.00257	 0.0	 12172	 12172	 12172	 0.0	 0.0	 1	 -30.0	 30.0;
	1551	 4103	 0.00201	 0.01195	 0.0	 610.0	 2607	 2607	 0.0	 0.0	 1	 -30.0	 30.0;
	1551	 7862	 0.001091	 0.00731	 0.0	 572.0	 4274	 4274	 0.0	 0.0	 1	 -30.0	 30.0;
	1551	 5458	 0.00105	 0.007591	 0.0	 629.0	 4122	 4122	 0.0	 0.0	 1	 -30.0	 30.0;
	1551	 1838	 0.00299	 0.02256	 0.0	 476.0	 1389	 1389	 0.0	 0.0	 1	 -30.0	 30.0;
	3070	 2888	 0.00036	 0.00288	 0.0	 10884	 10884	 10884	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 4504	 0.00589	 0.045599	 0.0	 553.0	 688	 688	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 3579	 0.00157	 0.0127	 0.0	 476.0	 2469	 2469	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 3579	 0.00168	 0.011969	 0.0	 2614	 2614	 2614	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 7903	 0.00289	 0.021031	 0.0	 438.0	 1488	 1488	 0.0	 0.0	 1	 -30.0	 30.0;
	6368	 1102	 0.00395	 0.025211	 0.0	 572.0	 1238	 1238	 0.0	 0.0	 1	 -30.0	 30.0;
	6368	 9217	 0.002771	 0.021659	 0.0	 476.0	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	6368	 5653	 0.002979	 0.016901	 0.0	 553.0	 1841	 1841	 0.0	 0.0	 1	 -30.0	 30.0;
	8478	 5907	 0.007419	 0.034021	 0.0	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	5241	 6921	 0.00056	 0.00813	 0.0	 889.0	 3877	 3877	 0.0	 0.0	 1	 -30.0	 30.0;
	4	 1813	 0.00361	 0.015211	 0.0	 438.0	 2021	 2021	 0.0	 0.0	 1	 -30.0	 30.0;
	8950	 7049	 0.000409	 0.003331	 0.0	 629.0	 9413	 9413	 0.0	 0.0	 1	 -30.0	 30.0;
	6846	 8788	 0.004091	 0.019599	 0.0	 476.0	 1578	 1578	 0.0	 0.0	 1	 -30.0	 30.0;
	6846	 6734	 0.00294	 0.012841	 0.0	 495.0	 2398	 2398	 0.0	 0.0	 1	 -30.0	 30.0;
	4426	 5616	 0.020771	 0.080479	 0.0	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	4426	 1965	 0.00662	 0.0513	 0.0	 553.0	 611	 611	 0.0	 0.0	 1	 -30.0	 30.0;
	4426	 1767	 0.00607	 0.04581	 0.0	 533.0	 684	 684	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 1102	 0.000669	 0.0042	 0.0	 476.0	 7428	 7428	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 8485	 0.001271	 0.007419	 0.0	 476.0	 4197	 4197	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 5653	 0.001599	 0.012271	 0.0	 572.0	 2553	 2553	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 4661	 0.009599	 0.05024	 0.0	 419.0	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 520	 0.00149	 0.009219	 0.0	 438.0	 3383	 3383	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 6816	 0.01488	 0.06724	 0.0	 400.0	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 5918	 0.003599	 0.024031	 0.0	 419.0	 1300	 1300	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 5918	 0.00519	 0.024	 0.0	 438.0	 1287	 1287	 0.0	 0.0	 1	 -30.0	 30.0;
	8636	 1380	 0.003461	 0.013349	 0.0	 400.0	 2291	 2291	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 4239	 0.00105	 0.01236	 0.0	 2547	 2547	 2547	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 4239	 0.00199	 0.012331	 0.0	 495.0	 2529	 2529	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 3656	 0.00711	 0.044711	 0.0	 438.0	 698	 698	 0.0	 0.0	 1	 -30.0	 30.0;
	6203	 7124	 0.006729	 0.02543	 0.0	 1201	 1201	 1201	 0.0	 0.0	 1	 -30.0	 30.0;
	9059	 7124	 0.005771	 0.02999	 0.0	 1035	 1035	 1035	 0.0	 0.0	 1	 -30.0	 30.0;
	5994	 96	 0.0048	 0.021771	 0.0	 1417	 1417	 1417	 0.0	 0.0	 1	 -30.0	 30.0;
	5049	 306	 0.00286	 0.02212	 0.0	 533.0	 1417	 1417	 0.0	 0.0	 1	 -30.0	 30.0;
	718	 8397	 0.00351	 0.02175	 0.0	 514.0	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	718	 6982	 0.008401	 0.0448	 0.0	 572.0	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	7202	 8807	 0.0018	 0.01187	 0.0	 2632	 2632	 2632	 0.0	 0.0	 1	 -30.0	 30.0;
	7202	 8807	 0.001831	 0.01163	 0.0	 2683	 2683	 2683	 0.0	 0.0	 1	 -30.0	 30.0;
	8592	 2995	 0.00075	 0.00538	 0.0	 5816	 5816	 5816	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 823	 2e-05	 0.00033	 0.0	 95544	 95544	 95544	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 1680	 1e-05	 0.00034	 0.0	 1810.0	 92864	 92864	 0.0	 0.0	 1	 -30.0	 30.0;
	6199	 953	 0.00023	 0.00258	 0.0	 823.0	 12195	 12195	 0.0	 0.0	 1	 -30.0	 30.0;
	6199	 1817	 0.00023	 0.00252	 0.0	 757.0	 12483	 12483	 0.0	 0.0	 1	 -30.0	 30.0;
	3231	 1504	 0.002031	 0.008531	 0.0	 3602	 3602	 3602	 0.0	 0.0	 1	 -30.0	 30.0;
	3231	 7226	 0.005349	 0.020789	 0.0	 419.0	 1472	 1472	 0.0	 0.0	 1	 -30.0	 30.0;
	2928	 7865	 0.0002	 0.00082	 0.0	 495.0	 37425	 37425	 0.0	 0.0	 1	 -30.0	 30.0;
	3916	 6891	 0.002091	 0.011219	 0.0	 2768	 2768	 2768	 0.0	 0.0	 1	 -30.0	 30.0;
	6053	 171	 0.00262	 0.016979	 0.0	 533.0	 1839	 1839	 0.0	 0.0	 1	 -30.0	 30.0;
	6053	 171	 0.002669	 0.01663	 0.0	 591.0	 1876	 1876	 0.0	 0.0	 1	 -30.0	 30.0;
	8829	 3044	 0.00025	 0.00118	 0.0	 514.0	 26188	 26188	 0.0	 0.0	 1	 -30.0	 30.0;
	1552	 1194	 0.00056	 0.00715	 0.0	 1645.0	 4405	 4405	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 3740	 0.0007	 0.00455	 0.0	 438.0	 6862	 6862	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 2695	 0.000331	 0.001711	 0.0	 381.0	 18126	 18126	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 2695	 0.00011	 0.000781	 0.0	 553.0	 40050	 40050	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 8877	 0.00111	 0.00664	 0.0	 438.0	 4693	 4693	 0.0	 0.0	 1	 -30.0	 30.0;
	7520	 8222	 0.00066	 0.00838	 0.0	 1547.0	 3758	 3758	 0.0	 0.0	 1	 -30.0	 30.0;
	7520	 8222	 0.00064	 0.00854	 0.0	 1547.0	 3689	 3689	 0.0	 0.0	 1	 -30.0	 30.0;
	2421	 3610	 0.003091	 0.017091	 0.0	 572.0	 1819	 1819	 0.0	 0.0	 1	 -30.0	 30.0;
	2421	 1414	 0.00643	 0.03687	 0.0	 629.0	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	8879	 3610	 0.00275	 0.01937	 0.0	 1615	 1615	 1615	 0.0	 0.0	 1	 -30.0	 30.0;
	8397	 5918	 0.00357	 0.021289	 0.0	 514.0	 1464	 1464	 0.0	 0.0	 1	 -30.0	 30.0;
	1914	 6982	 0.000289	 0.002789	 0.0	 11266	 11266	 11266	 0.0	 0.0	 1	 -30.0	 30.0;
	7873	 6638	 0.002531	 0.01345	 0.0	 381.0	 2308	 2308	 0.0	 0.0	 1	 -30.0	 30.0;
	4562	 7702	 0.00162	 0.012159	 0.0	 514.0	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	4562	 7702	 0.00262	 0.01168	 0.0	 419.0	 2639	 2639	 0.0	 0.0	 1	 -30.0	 30.0;
	8835	 1156	 0.00099	 0.006081	 0.0	 5127	 5127	 5127	 0.0	 0.0	 1	 -30.0	 30.0;
	8835	 1233	 0.000909	 0.005979	 0.0	 5224	 5224	 5224	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 408	 0.00011	 0.0008	 0.0	 39117	 39117	 39117	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 7231	 0.00011	 0.00068	 0.0	 45856	 45856	 45856	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 5993	 0.00207	 0.008341	 0.0	 495.0	 3676	 3676	 0.0	 0.0	 1	 -30.0	 30.0;
	1910	 2550	 0.00019	 0.001031	 0.0	 30131	 30131	 30131	 0.0	 0.0	 1	 -30.0	 30.0;
	3975	 7353	 0.014039	 0.0667	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	3126	 7495	 0.004961	 0.03043	 0.0	 438.0	 1025	 1025	 0.0	 0.0	 1	 -30.0	 30.0;
	2689	 5753	 0.00056	 0.003531	 0.0	 8836	 8836	 8836	 0.0	 0.0	 1	 -30.0	 30.0;
	1201	 4235	 0.001461	 0.00889	 0.0	 514.0	 3507	 3507	 0.0	 0.0	 1	 -30.0	 30.0;
	7626	 7076	 6e-05	 0.000419	 0.0	 495.0	 74627	 74627	 0.0	 0.0	 1	 -30.0	 30.0;
	4823	 4060	 0.00139	 0.005169	 0.0	 5902	 5902	 5902	 0.0	 0.0	 1	 -30.0	 30.0;
	4141	 1311	 0.00069	 0.00825	 0.0	 757.0	 3816	 3816	 0.0	 0.0	 1	 -30.0	 30.0;
	7124	 4566	 0.004969	 0.030781	 0.0	 1014	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	7124	 8873	 0.00012	 0.000969	 0.0	 591.0	 32351	 32351	 0.0	 0.0	 1	 -30.0	 30.0;
	6684	 5383	 0.001091	 0.010159	 0.0	 572.0	 3092	 3092	 0.0	 0.0	 1	 -30.0	 30.0;
	8151	 5383	 0.000969	 0.00887	 0.0	 553.0	 3541	 3541	 0.0	 0.0	 1	 -30.0	 30.0;
	4357	 6619	 0.00099	 0.006789	 0.0	 514.0	 4605	 4605	 0.0	 0.0	 1	 -30.0	 30.0;
	8191	 8765	 0.001031	 0.00586	 0.0	 381.0	 5309	 5309	 0.0	 0.0	 1	 -30.0	 30.0;
	7466	 5469	 0.00401	 0.03345	 0.0	 629.0	 938	 938	 0.0	 0.0	 1	 -30.0	 30.0;
	3401	 5351	 9.1e-05	 0.000349	 0.0	 87580	 87580	 87580	 0.0	 0.0	 1	 -30.0	 30.0;
	3760	 225	 0.00125	 0.00745	 0.0	 591.0	 4182	 4182	 0.0	 0.0	 1	 -30.0	 30.0;
	53	 4031	 0.003711	 0.024219	 0.0	 514.0	 1290	 1290	 0.0	 0.0	 1	 -30.0	 30.0;
	8222	 6921	 0.00169	 0.02156	 0.0	 1461	 1461	 1461	 0.0	 0.0	 1	 -30.0	 30.0;
	8222	 6921	 0.00171	 0.02114	 0.0	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	6556	 4239	 0.00088	 0.00562	 0.0	 533.0	 5553	 5553	 0.0	 0.0	 1	 -30.0	 30.0;
	6556	 4239	 0.0008	 0.00618	 0.0	 572.0	 5069	 5069	 0.0	 0.0	 1	 -30.0	 30.0;
	2940	 7178	 0.00161	 0.01014	 0.0	 3077	 3077	 3077	 0.0	 0.0	 1	 -30.0	 30.0;
	3928	 2563	 0.00032	 0.002031	 0.0	 533.0	 15364	 15364	 0.0	 0.0	 1	 -30.0	 30.0;
	3928	 6521	 0.00011	 0.000659	 0.0	 495.0	 47279	 47279	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 3830	 0.00042	 0.00505	 0.0	 1086.0	 6234	 6234	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 5648	 0.00043	 0.00494	 0.0	 1251.0	 6371	 6371	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 4914	 0.00038	 0.000711	 0.0	 39182	 39182	 39182	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 4914	 0.00037	 0.000659	 0.0	 41796	 41796	 41796	 0.0	 0.0	 1	 -30.0	 30.0;
	4125	 1644	 0.00248	 0.03096	 0.0	 1018	 1018	 1018	 0.0	 0.0	 1	 -30.0	 30.0;
	163	 3498	 0.00375	 0.019729	 0.0	 495.0	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	163	 2430	 0.00518	 0.020021	 0.0	 438.0	 1528	 1528	 0.0	 0.0	 1	 -30.0	 30.0;
	7943	 9108	 0.000771	 0.003711	 0.0	 495.0	 8334	 8334	 0.0	 0.0	 1	 -30.0	 30.0;
	7943	 1478	 0.00076	 0.003789	 0.0	 457.0	 8174	 8174	 0.0	 0.0	 1	 -30.0	 30.0;
	2308	 3541	 0.000781	 0.00574	 0.0	 5453	 5453	 5453	 0.0	 0.0	 1	 -30.0	 30.0;
	3535	 7582	 0.00089	 0.00562	 0.0	 5552	 5552	 5552	 0.0	 0.0	 1	 -30.0	 30.0;
	2019	 8542	 0.000331	 0.001401	 0.0	 21943	 21943	 21943	 0.0	 0.0	 1	 -30.0	 30.0;
	5174	 8542	 0.000401	 0.00137	 0.0	 22129	 22129	 22129	 0.0	 0.0	 1	 -30.0	 30.0;
	7945	 5215	 0.00051	 0.003349	 0.0	 9325	 9325	 9325	 0.0	 0.0	 1	 -30.0	 30.0;
	2057	 9130	 0.000461	 0.00168	 0.0	 18132	 18132	 18132	 0.0	 0.0	 1	 -30.0	 30.0;
	2057	 9130	 0.000469	 0.00164	 0.0	 18519	 18519	 18519	 0.0	 0.0	 1	 -30.0	 30.0;
	4661	 6816	 0.006081	 0.03114	 0.0	 457.0	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	7519	 776	 0.005831	 0.02218	 0.0	 495.0	 1378	 1378	 0.0	 0.0	 1	 -30.0	 30.0;
	8989	 3435	 0.00013	 0.000461	 0.0	 65948	 65948	 65948	 0.0	 0.0	 1	 -30.0	 30.0;
	7797	 2020	 0.00013	 0.000461	 0.0	 65948	 65948	 65948	 0.0	 0.0	 1	 -30.0	 30.0;
	871	 4031	 0.00262	 0.020289	 0.0	 514.0	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	871	 2878	 0.00164	 0.01194	 0.0	 553.0	 2621	 2621	 0.0	 0.0	 1	 -30.0	 30.0;
	7353	 9164	 0.006479	 0.02845	 0.0	 514.0	 1083	 1083	 0.0	 0.0	 1	 -30.0	 30.0;
	7974	 2012	 0.00294	 0.014419	 0.0	 495.0	 2147	 2147	 0.0	 0.0	 1	 -30.0	 30.0;
	7974	 2012	 0.00238	 0.01463	 0.0	 495.0	 2132	 2132	 0.0	 0.0	 1	 -30.0	 30.0;
	7974	 1750	 0.002219	 0.00993	 0.0	 476.0	 3105	 3105	 0.0	 0.0	 1	 -30.0	 30.0;
	1401	 2303	 0.008651	 0.04886	 0.0	 400.0	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	4504	 7903	 0.00464	 0.030979	 0.0	 1009	 1009	 1009	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 449	 0.00092	 0.00889	 0.0	 1547.0	 3535	 3535	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 449	 0.00093	 0.00869	 0.0	 1448.0	 3615	 3615	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 1817	 0.0022	 0.03485	 0.0	 905	 905	 905	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 2458	 0.00074	 0.00941	 0.0	 1843.0	 3347	 3347	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 6427	 0.00087	 0.00884	 0.0	 1678.0	 3557	 3557	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 1730	 0.00139	 0.01662	 0.0	 1894	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	9217	 594	 0.002781	 0.022979	 0.0	 400.0	 1365	 1365	 0.0	 0.0	 1	 -30.0	 30.0;
	6351	 5393	 0.000521	 0.00407	 0.0	 629.0	 7699	 7699	 0.0	 0.0	 1	 -30.0	 30.0;
	6194	 7702	 0.008479	 0.032841	 0.0	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	2503	 7491	 0.005669	 0.02901	 0.0	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	4031	 2872	 0.001031	 0.004099	 0.0	 7474	 7474	 7474	 0.0	 0.0	 1	 -30.0	 30.0;
	4031	 8043	 0.00301	 0.018719	 0.0	 476.0	 1667	 1667	 0.0	 0.0	 1	 -30.0	 30.0;
	1813	 2866	 0.00257	 0.01713	 0.0	 438.0	 1824	 1824	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 5417	 0.010461	 0.03836	 0.0	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 4100	 0.001719	 0.011531	 0.0	 514.0	 2710	 2710	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 1556	 9.1e-05	 0.00056	 0.0	 400.0	 55676	 55676	 0.0	 0.0	 1	 -30.0	 30.0;
	3894	 3865	 0.00476	 0.025289	 0.0	 1228	 1228	 1228	 0.0	 0.0	 1	 -30.0	 30.0;
	128	 1554	 0.000219	 0.00164	 0.0	 419.0	 19092	 19092	 0.0	 0.0	 1	 -30.0	 30.0;
	198	 7994	 0.002159	 0.01163	 0.0	 2671	 2671	 2671	 0.0	 0.0	 1	 -30.0	 30.0;
	198	 1554	 0.00295	 0.01539	 0.0	 400.0	 2016	 2016	 0.0	 0.0	 1	 -30.0	 30.0;
	2985	 3133	 0.007789	 0.033039	 0.0	 400.0	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	7316	 3071	 0.00026	 0.0013	 0.0	 23827	 23827	 23827	 0.0	 0.0	 1	 -30.0	 30.0;
	6486	 8992	 0.00162	 0.013229	 0.0	 438.0	 2371	 2371	 0.0	 0.0	 1	 -30.0	 30.0;
	8485	 594	 0.007919	 0.04194	 0.0	 438.0	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	682	 8477	 0.001229	 0.00401	 0.0	 400.0	 7532	 7532	 0.0	 0.0	 1	 -30.0	 30.0;
	5146	 5488	 0.008021	 0.042831	 0.0	 438.0	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	6638	 776	 0.007711	 0.03006	 0.0	 438.0	 1018	 1018	 0.0	 0.0	 1	 -30.0	 30.0;
	8788	 789	 0.00261	 0.015469	 0.0	 419.0	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	6332	 1556	 0.00139	 0.00536	 0.0	 5705	 5705	 5705	 0.0	 0.0	 1	 -30.0	 30.0;
	6332	 1556	 0.001419	 0.00525	 0.0	 5809	 5809	 5809	 0.0	 0.0	 1	 -30.0	 30.0;
	1883	 7702	 0.006289	 0.032271	 0.0	 961	 961	 961	 0.0	 0.0	 1	 -30.0	 30.0;
	1883	 2132	 0.011031	 0.05625	 0.0	 552	 552	 552	 0.0	 0.0	 1	 -30.0	 30.0;
	171	 2341	 0.001841	 0.01324	 0.0	 572.0	 2364	 2364	 0.0	 0.0	 1	 -30.0	 30.0;
	6630	 10	 0.000599	 0.00186	 0.0	 553.0	 16165	 16165	 0.0	 0.0	 1	 -30.0	 30.0;
	4484	 4239	 0.00036	 0.001591	 0.0	 533.0	 19365	 19365	 0.0	 0.0	 1	 -30.0	 30.0;
	3044	 4235	 0.003849	 0.027651	 0.0	 553.0	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	851	 4454	 0.00186	 0.00874	 0.0	 591.0	 3535	 3535	 0.0	 0.0	 1	 -30.0	 30.0;
	3485	 2183	 0.00025	 0.00285	 0.0	 1580.0	 11041	 11041	 0.0	 0.0	 1	 -30.0	 30.0;
	1156	 7923	 0.00207	 0.008841	 0.0	 419.0	 3479	 3479	 0.0	 0.0	 1	 -30.0	 30.0;
	1156	 1233	 6e-05	 0.00039	 0.0	 553.0	 80052	 80052	 0.0	 0.0	 1	 -30.0	 30.0;
	8913	 4852	 0.002159	 0.008909	 0.0	 457.0	 3446	 3446	 0.0	 0.0	 1	 -30.0	 30.0;
	4039	 1233	 0.000219	 0.00039	 0.0	 70621	 70621	 70621	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 2653	 0.00011	 0.000521	 0.0	 400.0	 59321	 59321	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 2653	 0.00011	 0.00049	 0.0	 400.0	 62899	 62899	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 556	 0.000771	 0.003789	 0.0	 438.0	 8170	 8170	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 3019	 0.000229	 0.002849	 0.0	 11052	 11052	 11052	 0.0	 0.0	 1	 -30.0	 30.0;
	7994	 5256	 0.00445	 0.027599	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 3346	 0.00218	 0.02	 0.0	 1481.0	 1571	 1571	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 8468	 0.00074	 0.00865	 0.0	 1218.0	 3639	 3639	 0.0	 0.0	 1	 -30.0	 30.0;
	7702	 1234	 0.002531	 0.019419	 0.0	 400.0	 1613	 1613	 0.0	 0.0	 1	 -30.0	 30.0;
	7702	 8035	 0.003	 0.01631	 0.0	 1905	 1905	 1905	 0.0	 0.0	 1	 -30.0	 30.0;
	8677	 3331	 0.008461	 0.025081	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	8189	 3643	 0.00382	 0.013669	 0.0	 495.0	 2226	 2226	 0.0	 0.0	 1	 -30.0	 30.0;
	3133	 8477	 0.002581	 0.01814	 0.0	 514.0	 1724	 1724	 0.0	 0.0	 1	 -30.0	 30.0;
	6744	 6101	 0.00201	 0.012219	 0.0	 533.0	 2551	 2551	 0.0	 0.0	 1	 -30.0	 30.0;
	8542	 4313	 0.00087	 0.001599	 0.0	 17353	 17353	 17353	 0.0	 0.0	 1	 -30.0	 30.0;
	769	 5233	 0.00455	 0.02394	 0.0	 419.0	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	1965	 5926	 0.005651	 0.041771	 0.0	 457.0	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	9014	 3999	 0.00069	 0.001271	 0.0	 21842	 21842	 21842	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 8406	 0.00068	 0.00269	 0.0	 400.0	 11385	 11385	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 2021	 0.00036	 0.00261	 0.0	 476.0	 11989	 11989	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 8293	 0.001669	 0.012031	 0.0	 419.0	 2601	 2601	 0.0	 0.0	 1	 -30.0	 30.0;
	4738	 3656	 0.009669	 0.03513	 0.0	 867	 867	 867	 0.0	 0.0	 1	 -30.0	 30.0;
	4738	 8477	 0.001099	 0.00862	 0.0	 3636	 3636	 3636	 0.0	 0.0	 1	 -30.0	 30.0;
	7998	 1644	 0.0005	 0.00711	 0.0	 757.0	 4432	 4432	 0.0	 0.0	 1	 -30.0	 30.0;
	6734	 1015	 0.003919	 0.017781	 0.0	 495.0	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	6734	 8992	 0.00161	 0.019781	 0.0	 1592	 1592	 1592	 0.0	 0.0	 1	 -30.0	 30.0;
	6734	 789	 0.0007	 0.01256	 0.0	 610.0	 2512	 2512	 0.0	 0.0	 1	 -30.0	 30.0;
	5004	 5393	 0.000409	 0.0018	 0.0	 17113	 17113	 17113	 0.0	 0.0	 1	 -30.0	 30.0;
	1708	 3906	 2e-05	 0.00043	 0.0	 73380	 73380	 73380	 0.0	 0.0	 1	 -30.0	 30.0;
	9150	 3906	 3e-05	 0.0004	 0.0	 1810.0	 78748	 78748	 0.0	 0.0	 1	 -30.0	 30.0;
	280	 9158	 0.00968	 0.056659	 0.0	 457.0	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	8043	 3656	 0.003969	 0.02925	 0.0	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 8992	 0.00219	 0.01468	 0.0	 514.0	 2129	 2129	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 8466	 0.000401	 0.003159	 0.0	 476.0	 9920	 9920	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 6880	 0.000531	 0.003	 0.0	 476.0	 10368	 10368	 0.0	 0.0	 1	 -30.0	 30.0;
	5215	 7266	 0.00136	 0.00576	 0.0	 476.0	 5338	 5338	 0.0	 0.0	 1	 -30.0	 30.0;
	8807	 8992	 0.000849	 0.006289	 0.0	 457.0	 4978	 4978	 0.0	 0.0	 1	 -30.0	 30.0;
	8807	 8992	 0.000841	 0.006409	 0.0	 457.0	 4887	 4887	 0.0	 0.0	 1	 -30.0	 30.0;
	8807	 8992	 0.00045	 0.00506	 0.0	 6219	 6219	 6219	 0.0	 0.0	 1	 -30.0	 30.0;
	218	 2088	 0.003669	 0.02988	 0.0	 495.0	 1050	 1050	 0.0	 0.0	 1	 -30.0	 30.0;
	520	 5918	 0.002	 0.01568	 0.0	 514.0	 1999	 1999	 0.0	 0.0	 1	 -30.0	 30.0;
	2653	 2128	 0.00031	 0.0008	 0.0	 419.0	 36817	 36817	 0.0	 0.0	 1	 -30.0	 30.0;
	1216	 5233	 0.00043	 0.00038	 0.0	 55045	 55045	 55045	 0.0	 0.0	 1	 -30.0	 30.0;
	8980	 5993	 0.00043	 0.002229	 0.0	 13915	 13915	 13915	 0.0	 0.0	 1	 -30.0	 30.0;
	5212	 5993	 0.00049	 0.00218	 0.0	 14137	 14137	 14137	 0.0	 0.0	 1	 -30.0	 30.0;
	3656	 4060	 0.00282	 0.01844	 0.0	 629.0	 1694	 1694	 0.0	 0.0	 1	 -30.0	 30.0;
	883	 3331	 0.00462	 0.014849	 0.0	 2032	 2032	 2032	 0.0	 0.0	 1	 -30.0	 30.0;
	5144	 3346	 0.00263	 0.04076	 0.0	 774	 774	 774	 0.0	 0.0	 1	 -30.0	 30.0;
	3498	 2563	 0.01062	 0.056719	 0.0	 457.0	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	1896	 8200	 0.0001	 0.00105	 0.0	 757.0	 29948	 29948	 0.0	 0.0	 1	 -30.0	 30.0;
	9130	 8864	 0.00239	 0.017341	 0.0	 476.0	 1805	 1805	 0.0	 0.0	 1	 -30.0	 30.0;
	3503	 2510	 0.001341	 0.010581	 0.0	 533.0	 2962	 2962	 0.0	 0.0	 1	 -30.0	 30.0;
	3503	 6146	 0.00101	 0.007599	 0.0	 572.0	 4121	 4121	 0.0	 0.0	 1	 -30.0	 30.0;
	401	 1584	 0.00011	 0.000289	 0.0	 495.0	 102150	 102150	 0.0	 0.0	 1	 -30.0	 30.0;
	7328	 6921	 0.00146	 0.01769	 0.0	 1780	 1780	 1780	 0.0	 0.0	 1	 -30.0	 30.0;
	7328	 6921	 0.0013	 0.02004	 0.0	 1573	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	6816	 5573	 0.007909	 0.028349	 0.0	 419.0	 1074	 1074	 0.0	 0.0	 1	 -30.0	 30.0;
	7396	 8564	 0.00012	 0.00049	 0.0	 62614	 62614	 62614	 0.0	 0.0	 1	 -30.0	 30.0;
	7396	 8564	 0.00012	 0.000479	 0.0	 63968	 63968	 63968	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 432	 0.00076	 0.01018	 0.0	 1613.0	 3095	 3095	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 432	 0.0009	 0.00865	 0.0	 1777.0	 3633	 3633	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 432	 0.00096	 0.01294	 0.0	 1645.0	 2435	 2435	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 432	 0.0004	 0.00756	 0.0	 1711.0	 4173	 4173	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 432	 0.00039	 0.00771	 0.0	 1547.0	 4092	 4092	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 8200	 0.00163	 0.02291	 0.0	 1376	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	2949	 3121	 0.00636	 0.03855	 0.0	 495.0	 809	 809	 0.0	 0.0	 1	 -30.0	 30.0;
	2949	 3121	 0.00639	 0.03863	 0.0	 514.0	 807	 807	 0.0	 0.0	 1	 -30.0	 30.0;
	953	 1730	 0.00113	 0.01362	 0.0	 790.0	 2312	 2312	 0.0	 0.0	 1	 -30.0	 30.0;
	1767	 892	 0.00861	 0.05318	 0.0	 587	 587	 587	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 4889	 0.0012	 0.004669	 0.0	 438.0	 6553	 6553	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 7076	 0.00018	 0.001091	 0.0	 514.0	 28567	 28567	 0.0	 0.0	 1	 -30.0	 30.0;
	1234	 8035	 0.001401	 0.00612	 0.0	 457.0	 5032	 5032	 0.0	 0.0	 1	 -30.0	 30.0;
	115	 225	 0.00068	 0.00387	 0.0	 591.0	 8039	 8039	 0.0	 0.0	 1	 -30.0	 30.0;
	5720	 8578	 0.0043	 0.033591	 0.0	 514.0	 933	 933	 0.0	 0.0	 1	 -30.0	 30.0;
	3579	 5469	 0.003039	 0.01911	 0.0	 591.0	 1633	 1633	 0.0	 0.0	 1	 -30.0	 30.0;
	3246	 124	 6e-05	 0.00111	 0.0	 953.0	 28416	 28416	 0.0	 0.0	 1	 -30.0	 30.0;
	8846	 4783	 5e-05	 0.001091	 0.0	 953.0	 28923	 28923	 0.0	 0.0	 1	 -30.0	 30.0;
	2393	 3306	 3.9e-05	 0.00089	 0.0	 953.0	 35458	 35458	 0.0	 0.0	 1	 -30.0	 30.0;
	1895	 4480	 3.9e-05	 0.000901	 0.0	 953.0	 35026	 35026	 0.0	 0.0	 1	 -30.0	 30.0;
	678	 4454	 0.000169	 0.00111	 0.0	 610.0	 28133	 28133	 0.0	 0.0	 1	 -30.0	 30.0;
	1002	 4852	 0.000331	 0.0027	 0.0	 11613	 11613	 11613	 0.0	 0.0	 1	 -30.0	 30.0;
	6429	 2012	 0.00026	 0.00369	 0.0	 8540	 8540	 8540	 0.0	 0.0	 1	 -30.0	 30.0;
	4889	 7076	 0.000341	 0.00274	 0.0	 11440	 11440	 11440	 0.0	 0.0	 1	 -30.0	 30.0;
	5341	 7491	 0.00038	 0.00506	 0.0	 514.0	 6226	 6226	 0.0	 0.0	 1	 -30.0	 30.0;
	2563	 6521	 0.00012	 0.000831	 0.0	 476.0	 37622	 37622	 0.0	 0.0	 1	 -30.0	 30.0;
	1111	 594	 0.003031	 0.0123	 0.0	 2494	 2494	 2494	 0.0	 0.0	 1	 -30.0	 30.0;
	4747	 7791	 0.001521	 0.00774	 0.0	 495.0	 4005	 4005	 0.0	 0.0	 1	 -30.0	 30.0;
	3906	 3022	 0.00059	 0.00552	 0.0	 1711.0	 5690	 5690	 0.0	 0.0	 1	 -30.0	 30.0;
	3906	 1194	 0.00053	 0.00625	 0.0	 1645.0	 5036	 5036	 0.0	 0.0	 1	 -30.0	 30.0;
	5993	 8804	 0.00143	 0.01076	 0.0	 629.0	 2911	 2911	 0.0	 0.0	 1	 -30.0	 30.0;
	1798	 8487	 0.00056	 0.00593	 0.0	 5304	 5304	 5304	 0.0	 0.0	 1	 -30.0	 30.0;
	2467	 7178	 0.00205	 0.01461	 0.0	 514.0	 2142	 2142	 0.0	 0.0	 1	 -30.0	 30.0;
	2132	 2303	 0.01068	 0.054521	 0.0	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	8992	 8466	 0.00194	 0.011039	 0.0	 533.0	 2819	 2819	 0.0	 0.0	 1	 -30.0	 30.0;
	8992	 6880	 0.00131	 0.010099	 0.0	 533.0	 3102	 3102	 0.0	 0.0	 1	 -30.0	 30.0;
	8992	 2995	 0.001289	 0.014229	 0.0	 419.0	 2211	 2211	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 3221	 0.00455	 0.027031	 0.0	 495.0	 1153	 1153	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 3327	 0.00239	 0.01414	 0.0	 610.0	 2203	 2203	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 8310	 0.004039	 0.029669	 0.0	 591.0	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 2088	 0.001099	 0.007771	 0.0	 629.0	 4025	 4025	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 2021	 0.00082	 0.00762	 0.0	 514.0	 4122	 4122	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 4114	 0.000719	 0.0033	 0.0	 9353	 9353	 9353	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 5519	 0.000599	 0.00361	 0.0	 400.0	 8632	 8632	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 8293	 0.000521	 0.004039	 0.0	 476.0	 7757	 7757	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 3435	 0.000901	 0.0088	 0.0	 533.0	 3571	 3571	 0.0	 0.0	 1	 -30.0	 30.0;
	7507	 6990	 0.000781	 0.00306	 0.0	 10003	 10003	 10003	 0.0	 0.0	 1	 -30.0	 30.0;
	7507	 2406	 0.000419	 0.00399	 0.0	 7874	 7874	 7874	 0.0	 0.0	 1	 -30.0	 30.0;
	7507	 2020	 0.000841	 0.009841	 0.0	 381.0	 3199	 3199	 0.0	 0.0	 1	 -30.0	 30.0;
	6478	 6146	 0.004021	 0.03064	 0.0	 514.0	 1023	 1023	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 2695	 0.0023	 0.009031	 0.0	 438.0	 3390	 3390	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 2695	 0.002081	 0.009469	 0.0	 476.0	 3259	 3259	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 5502	 0.00164	 0.008831	 0.0	 3517	 3517	 3517	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 8877	 0.00094	 0.00488	 0.0	 419.0	 6356	 6356	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 9119	 0.000901	 0.00551	 0.0	 553.0	 5658	 5658	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 1151	 0.00051	 0.005961	 0.0	 5280	 5280	 5280	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 1750	 0.00113	 0.004349	 0.0	 533.0	 7030	 7030	 0.0	 0.0	 1	 -30.0	 30.0;
	1478	 6616	 0.002081	 0.013031	 0.0	 495.0	 2394	 2394	 0.0	 0.0	 1	 -30.0	 30.0;
	809	 4594	 0.00116	 0.01438	 0.0	 2190	 2190	 2190	 0.0	 0.0	 1	 -30.0	 30.0;
	8656	 4729	 0.00013	 0.001031	 0.0	 30397	 30397	 30397	 0.0	 0.0	 1	 -30.0	 30.0;
	4100	 615	 0.00036	 0.002659	 0.0	 514.0	 11773	 11773	 0.0	 0.0	 1	 -30.0	 30.0;
	4060	 5393	 0.000771	 0.004539	 0.0	 629.0	 6861	 6861	 0.0	 0.0	 1	 -30.0	 30.0;
	6000	 1689	 0.00017	 0.01734	 0.0	 1185.0	 2780	 2780	 0.0	 0.0	 1	 -30.0	 30.0;
	4192	 8230	 0.00017	 0.01767	 0.0	 1086.0	 1788	 1788	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 2030	 0.0006	 0.040218	 0.0	 637.0	 786	 786	 0.0	 0.0	 1	 -30.0	 30.0;
	8832	 2180	 0.00076	 0.002409	 0.0	 12505	 12505	 12505	 0.0	 0.0	 1	 -30.0	 30.0;
	8832	 3771	 0.0	 0.000538	 0.0	 58713	 58713	 58713	 0.0	 0.0	 1	 -30.0	 30.0;
	6395	 1564	 0.00528	 0.027569	 0.0	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	6395	 1564	 0.005382	 0.026978	 0.0	 1149	 1149	 1149	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 6395	 0.00104	 0.009649	 0.0	 3255	 3255	 3255	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 6395	 0.001062	 0.009449	 0.0	 273.0	 3323	 3323	 0.0	 0.0	 1	 -30.0	 30.0;
	3397	 5247	 0.000289	 0.000889	 0.0	 33791	 33791	 33791	 0.0	 0.0	 1	 -30.0	 30.0;
	1207	 5247	 0.003502	 0.01524	 0.0	 2021	 2021	 2021	 0.0	 0.0	 1	 -30.0	 30.0;
	3397	 7958	 0.000289	 0.00088	 0.0	 34103	 34103	 34103	 0.0	 0.0	 1	 -30.0	 30.0;
	1207	 7958	 0.003431	 0.014111	 0.0	 2176	 2176	 2176	 0.0	 0.0	 1	 -30.0	 30.0;
	8389	 5526	 0.001502	 0.1272	 0.0	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	91	 722	 8e-05	 0.000729	 0.0	 312.0	 43072	 43072	 0.0	 0.0	 1	 -30.0	 30.0;
	1207	 722	 0.003818	 0.012911	 0.0	 2347	 2347	 2347	 0.0	 0.0	 1	 -30.0	 30.0;
	9083	 722	 0.001618	 0.013711	 0.0	 2288	 2288	 2288	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 1870	 0.001062	 0.007791	 0.0	 4018	 4018	 4018	 0.0	 0.0	 1	 -30.0	 30.0;
	6539	 1870	 0.001809	 0.008951	 0.0	 3459	 3459	 3459	 0.0	 0.0	 1	 -30.0	 30.0;
	5792	 1870	 0.007142	 0.020311	 0.0	 1468	 1468	 1468	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 8356	 0.000942	 0.008831	 0.0	 3557	 3557	 3557	 0.0	 0.0	 1	 -30.0	 30.0;
	6539	 8356	 0.001769	 0.008289	 0.0	 3727	 3727	 3727	 0.0	 0.0	 1	 -30.0	 30.0;
	5792	 8356	 0.00728	 0.019898	 0.0	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	8828	 5740	 0.003569	 0.017951	 0.0	 1726	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	3443	 8828	 0.001991	 0.007271	 0.0	 4191	 4191	 4191	 0.0	 0.0	 1	 -30.0	 30.0;
	7701	 8828	 0.000391	 0.001462	 0.0	 20873	 20873	 20873	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 8167	 0.003502	 0.018289	 0.0	 1697	 1697	 1697	 0.0	 0.0	 1	 -30.0	 30.0;
	244	 2619	 0.001769	 0.00824	 0.0	 3749	 3749	 3749	 0.0	 0.0	 1	 -30.0	 30.0;
	7701	 2619	 0.0004	 0.001431	 0.0	 21259	 21259	 21259	 0.0	 0.0	 1	 -30.0	 30.0;
	1810	 4740	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 7525	 0.001471	 0.1296	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	2180	 7374	 0.00056	 0.015018	 0.0	 2102	 2102	 2102	 0.0	 0.0	 1	 -30.0	 30.0;
	164	 8490	 0.000631	 0.01472	 0.0	 2144	 2144	 2144	 0.0	 0.0	 1	 -30.0	 30.0;
	164	 2180	 0.0	 0.001169	 0.0	 27021	 27021	 27021	 0.0	 0.0	 1	 -30.0	 30.0;
	164	 7596	 0.000942	 0.003342	 0.0	 9098	 9098	 9098	 0.0	 0.0	 1	 -30.0	 30.0;
	164	 2708	 0.001582	 0.002831	 0.0	 9741	 9741	 9741	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 7059	 0.0008	 0.003422	 0.0	 8989	 8989	 8989	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 7059	 0.000822	 0.003351	 0.0	 9155	 9155	 9155	 0.0	 0.0	 1	 -30.0	 30.0;
	7596	 2708	 0.002631	 0.004889	 0.0	 5690	 5690	 5690	 0.0	 0.0	 1	 -30.0	 30.0;
	7596	 2305	 0.005418	 0.022489	 0.0	 1366	 1366	 1366	 0.0	 0.0	 1	 -30.0	 30.0;
	7596	 2305	 0.00552	 0.022018	 0.0	 1392	 1392	 1392	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 7575	 0.004091	 0.020893	 0.0	 1484	 1484	 1484	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 7575	 0.004	 0.019339	 0.0	 1600	 1600	 1600	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 4415	 0.016479	 0.037058	 0.0	 779	 779	 779	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 4686	 0.016347	 0.05124	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 7575	 0.007058	 0.030587	 0.0	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 7575	 0.007149	 0.029934	 0.0	 1027	 1027	 1027	 0.0	 0.0	 1	 -30.0	 30.0;
	6823	 6202	 0.002089	 0.003449	 0.0	 7834	 7834	 7834	 0.0	 0.0	 1	 -30.0	 30.0;
	6823	 6202	 0.002129	 0.003378	 0.0	 7911	 7911	 7911	 0.0	 0.0	 1	 -30.0	 30.0;
	2330	 712	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	712	 4272	 0.007489	 0.0516	 0.0	 606	 606	 606	 0.0	 0.0	 1	 -30.0	 30.0;
	712	 4272	 0.008489	 0.050569	 0.0	 617	 617	 617	 0.0	 0.0	 1	 -30.0	 30.0;
	878	 3206	 0.0	 0.047951	 0.0	 659	 659	 659	 0.0	 0.0	 1	 -30.0	 30.0;
	7090	 3206	 0.001649	 0.016591	 0.0	 1895	 1895	 1895	 0.0	 0.0	 1	 -30.0	 30.0;
	7844	 3206	 0.001618	 0.016898	 0.0	 1861	 1861	 1861	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 6202	 0.006871	 0.039911	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 6202	 0.007009	 0.039089	 0.0	 796	 796	 796	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 3182	 0.001658	 0.011871	 0.0	 2636	 2636	 2636	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 3182	 0.001631	 0.010991	 0.0	 2843	 2843	 2843	 0.0	 0.0	 1	 -30.0	 30.0;
	5426	 9120	 0.00092	 0.004689	 0.0	 6611	 6611	 6611	 0.0	 0.0	 1	 -30.0	 30.0;
	133	 9120	 0.002049	 0.0038	 0.0	 7317	 7317	 7317	 0.0	 0.0	 1	 -30.0	 30.0;
	6323	 9120	 0.005649	 0.026	 0.0	 1188	 1188	 1188	 0.0	 0.0	 1	 -30.0	 30.0;
	5426	 3047	 0.000902	 0.004782	 0.0	 6492	 6492	 6492	 0.0	 0.0	 1	 -30.0	 30.0;
	275	 3047	 0.003471	 0.014471	 0.0	 2123	 2123	 2123	 0.0	 0.0	 1	 -30.0	 30.0;
	133	 3047	 0.002089	 0.00372	 0.0	 7404	 7404	 7404	 0.0	 0.0	 1	 -30.0	 30.0;
	4188	 1880	 0.003569	 0.010671	 0.0	 2808	 2808	 2808	 0.0	 0.0	 1	 -30.0	 30.0;
	3898	 4188	 0.019782	 0.061658	 0.0	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	486	 5740	 0.000409	 0.0014	 0.0	 21658	 21658	 21658	 0.0	 0.0	 1	 -30.0	 30.0;
	5740	 539	 0.003302	 0.017311	 0.0	 1793	 1793	 1793	 0.0	 0.0	 1	 -30.0	 30.0;
	486	 8167	 0.000409	 0.001369	 0.0	 22108	 22108	 22108	 0.0	 0.0	 1	 -30.0	 30.0;
	8167	 539	 0.003231	 0.016031	 0.0	 1932	 1932	 1932	 0.0	 0.0	 1	 -30.0	 30.0;
	9094	 8463	 0.000751	 0.005711	 0.0	 5484	 5484	 5484	 0.0	 0.0	 1	 -30.0	 30.0;
	9094	 8994	 0.0018	 0.00716	 0.0	 299.0	 4279	 4279	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 9094	 0.001978	 0.013462	 0.0	 2322	 2322	 2322	 0.0	 0.0	 1	 -30.0	 30.0;
	9094	 1936	 0.001502	 0.0056	 0.0	 5449	 5449	 5449	 0.0	 0.0	 1	 -30.0	 30.0;
	3280	 6423	 0.005991	 0.0284	 0.0	 1089	 1089	 1089	 0.0	 0.0	 1	 -30.0	 30.0;
	2055	 6423	 0.000302	 0.000858	 0.0	 34727	 34727	 34727	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 6423	 0.002622	 0.013231	 0.0	 2342	 2342	 2342	 0.0	 0.0	 1	 -30.0	 30.0;
	7138	 5618	 0.004271	 0.019502	 0.0	 1583	 1583	 1583	 0.0	 0.0	 1	 -30.0	 30.0;
	2055	 5618	 0.000271	 0.000969	 0.0	 31394	 31394	 31394	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 5618	 0.00356	 0.014378	 0.0	 2133	 2133	 2133	 0.0	 0.0	 1	 -30.0	 30.0;
	6288	 3456	 0.0022	 0.009569	 0.0	 3218	 3218	 3218	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 3456	 0.000311	 0.001169	 0.0	 26113	 26113	 26113	 0.0	 0.0	 1	 -30.0	 30.0;
	3301	 3456	 0.001889	 0.006311	 0.0	 4795	 4795	 4795	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 3280	 0.000271	 0.00132	 0.0	 23441	 23441	 23441	 0.0	 0.0	 1	 -30.0	 30.0;
	3301	 3280	 0.001929	 0.006178	 0.0	 260.0	 4881	 4881	 0.0	 0.0	 1	 -30.0	 30.0;
	790	 6600	 0.000339	 0.001149	 0.0	 26368	 26368	 26368	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 8889	 0.002591	 0.014418	 0.0	 2157	 2157	 2157	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 775	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6356	 3443	 0.0014	 0.00652	 0.0	 4737	 4737	 4737	 0.0	 0.0	 1	 -30.0	 30.0;
	8164	 3443	 0.000418	 0.001338	 0.0	 22534	 22534	 22534	 0.0	 0.0	 1	 -30.0	 30.0;
	6356	 244	 0.001369	 0.006649	 0.0	 4654	 4654	 4654	 0.0	 0.0	 1	 -30.0	 30.0;
	8164	 244	 0.000369	 0.00152	 0.0	 20195	 20195	 20195	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 5320	 0.004689	 0.018151	 0.0	 1685	 1685	 1685	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 5320	 0.004591	 0.018498	 0.0	 1658	 1658	 1658	 0.0	 0.0	 1	 -30.0	 30.0;
	1255	 143	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	1255	 3974	 0.003698	 0.0198	 0.0	 1569	 1569	 1569	 0.0	 0.0	 1	 -30.0	 30.0;
	8016	 1255	 0.005471	 0.0206	 0.0	 1482	 1482	 1482	 0.0	 0.0	 1	 -30.0	 30.0;
	8016	 1255	 0.0062	 0.020191	 0.0	 1496	 1496	 1496	 0.0	 0.0	 1	 -30.0	 30.0;
	1255	 4362	 0.006098	 0.030551	 0.0	 1014	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	950	 5792	 0.004809	 0.019751	 0.0	 1554	 1554	 1554	 0.0	 0.0	 1	 -30.0	 30.0;
	950	 5792	 0.004711	 0.018289	 0.0	 260.0	 1673	 1673	 0.0	 0.0	 1	 -30.0	 30.0;
	3397	 6045	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6288	 7138	 0.007929	 0.044022	 0.0	 707	 707	 707	 0.0	 0.0	 1	 -30.0	 30.0;
	6057	 1352	 0.009782	 0.033938	 0.0	 895	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	6057	 6559	 0.003609	 0.016889	 0.0	 1829	 1829	 1829	 0.0	 0.0	 1	 -30.0	 30.0;
	656	 1392	 0.00044	 0.027591	 0.0	 1145	 1145	 1145	 0.0	 0.0	 1	 -30.0	 30.0;
	6835	 3538	 0.000419	 0.027979	 0.0	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	351	 3538	 0.000409	 0.02851	 0.0	 1108	 1108	 1108	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 3538	 0.0	 0.000461	 0.0	 68520	 68520	 68520	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 2824	 0.000531	 0.005581	 0.0	 5635	 5635	 5635	 0.0	 0.0	 1	 -30.0	 30.0;
	1052	 1392	 0.003841	 0.022461	 0.0	 476.0	 1387	 1387	 0.0	 0.0	 1	 -30.0	 30.0;
	3538	 140	 0.000539	 0.005461	 0.0	 400.0	 5757	 5757	 0.0	 0.0	 1	 -30.0	 30.0;
	3878	 3538	 0.00376	 0.022901	 0.0	 457.0	 1362	 1362	 0.0	 0.0	 1	 -30.0	 30.0;
	5001	 8862	 0.028843	 0.060992	 0.0	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	5001	 8862	 0.029397	 0.059744	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	1810	 6342	 0.001727	 0.00924	 0.0	 3361	 3361	 3361	 0.0	 0.0	 1	 -30.0	 30.0;
	1777	 1810	 0.004851	 0.02724	 0.0	 1142	 1142	 1142	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 6559	 0.0138	 0.040249	 0.0	 260.0	 743	 743	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 643	 0.007098	 0.022329	 0.0	 1349	 1349	 1349	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 1836	 0.001902	 0.008391	 0.0	 3672	 3672	 3672	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 1836	 0.001929	 0.008209	 0.0	 3746	 3746	 3746	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 1352	 0.001649	 0.01228	 0.0	 2550	 2550	 2550	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 1352	 0.001471	 0.01392	 0.0	 2257	 2257	 2257	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 7628	 0.000582	 0.040991	 0.0	 299.0	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 311	 0.01116	 0.033671	 0.0	 286.0	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 2482	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 8249	 0.00031	 0.00312	 0.0	 1251.0	 10075	 10075	 0.0	 0.0	 1	 -30.0	 30.0;
	6068	 8249	 0.00069	 0.00769	 0.0	 1810.0	 4092	 4092	 0.0	 0.0	 1	 -30.0	 30.0;
	6139	 5450	 0.010471	 0.029289	 0.0	 1016	 1016	 1016	 0.0	 0.0	 1	 -30.0	 30.0;
	6139	 5450	 0.010671	 0.028671	 0.0	 1033	 1033	 1033	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 6139	 0.00624	 0.021871	 0.0	 299.0	 1389	 1389	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 6139	 0.007071	 0.021431	 0.0	 299.0	 1400	 1400	 0.0	 0.0	 1	 -30.0	 30.0;
	8881	 7751	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	8881	 6559	 0.001062	 0.003351	 0.0	 8986	 8986	 8986	 0.0	 0.0	 1	 -30.0	 30.0;
	8881	 5342	 0.002111	 0.02008	 0.0	 1565	 1565	 1565	 0.0	 0.0	 1	 -30.0	 30.0;
	8881	 6399	 0.001009	 0.010929	 0.0	 2878	 2878	 2878	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 8881	 0.004711	 0.050609	 0.0	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	8881	 9083	 0.011462	 0.02396	 0.0	 1190	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 2350	 0.0	 0.0444	 0.0	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 1123	 0.001698	 0.1128	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 1633	 8.9e-05	 0.000742	 0.0	 42268	 42268	 42268	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 1633	 8.9e-05	 0.000729	 0.0	 43011	 43011	 43011	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 2812	 0.000302	 0.000809	 0.0	 36580	 36580	 36580	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 9029	 0.001502	 0.002182	 0.0	 11925	 11925	 11925	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 6149	 0.001311	 0.001871	 0.0	 13827	 13827	 13827	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 6149	 0.001369	 0.00204	 0.0	 12858	 12858	 12858	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 4616	 0.001049	 0.00308	 0.0	 273.0	 9709	 9709	 0.0	 0.0	 1	 -30.0	 30.0;
	1777	 5893	 0.014967	 0.09105	 0.0	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 5893	 0.028959	 0.12905	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	2478	 5893	 0.006438	 0.041256	 0.0	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	2478	 5893	 0.006554	 0.040364	 0.0	 773	 773	 773	 0.0	 0.0	 1	 -30.0	 30.0;
	2350	 1260	 0.0	 0.012742	 0.0	 2479	 2479	 2479	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 8463	 0.001018	 0.00868	 0.0	 3615	 3615	 3615	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 8994	 0.001871	 0.00548	 0.0	 5455	 5455	 5455	 0.0	 0.0	 1	 -30.0	 30.0;
	8994	 7476	 0.00228	 0.004338	 0.0	 6446	 6446	 6446	 0.0	 0.0	 1	 -30.0	 30.0;
	8994	 7476	 0.00224	 0.004431	 0.0	 6362	 6362	 6362	 0.0	 0.0	 1	 -30.0	 30.0;
	3023	 806	 0.00076	 0.00747	 0.0	 1678.0	 4207	 4207	 0.0	 0.0	 1	 -30.0	 30.0;
	5674	 806	 0.00103	 0.01061	 0.0	 1481.0	 2964	 2964	 0.0	 0.0	 1	 -30.0	 30.0;
	2240	 8991	 0.002689	 0.013818	 0.0	 2244	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	539	 2240	 0.002111	 0.003769	 0.0	 7313	 7313	 7313	 0.0	 0.0	 1	 -30.0	 30.0;
	539	 2240	 0.002151	 0.003689	 0.0	 273.0	 7397	 7397	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 5426	 0.00176	 0.012702	 0.0	 2464	 2464	 2464	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 5426	 0.001729	 0.012951	 0.0	 2418	 2418	 2418	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 1046	 0.000151	 0.000511	 0.0	 59281	 59281	 59281	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 1046	 0.000151	 0.000502	 0.0	 260.0	 60257	 60257	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 1836	 0.01076	 0.05508	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 1836	 0.010542	 0.05616	 0.0	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 6824	 0.003089	 0.009	 0.0	 3320	 3320	 3320	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 6824	 0.003031	 0.009169	 0.0	 3271	 3271	 3271	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 6275	 0.001849	 0.00872	 0.0	 3544	 3544	 3544	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 6275	 0.00188	 0.008538	 0.0	 3614	 3614	 3614	 0.0	 0.0	 1	 -30.0	 30.0;
	2974	 3301	 0.004151	 0.01556	 0.0	 1962	 1962	 1962	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 2974	 0.006591	 0.026778	 0.0	 299.0	 1146	 1146	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 8875	 0.00056	 0.038671	 0.0	 507.0	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	1747	 593	 0.0	 0.00045	 0.0	 757.0	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	593	 8230	 0.00162	 0.01968	 0.0	 1600	 1600	 1600	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 8772	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 6356	 0.002649	 0.015111	 0.0	 2059	 2059	 2059	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 6356	 0.002702	 0.014809	 0.0	 2099	 2099	 2099	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 5031	 0.0008	 0.005711	 0.0	 5478	 5478	 5478	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 5031	 0.000782	 0.005809	 0.0	 5390	 5390	 5390	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 3299	 0.001049	 0.007738	 0.0	 286.0	 4046	 4046	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 3299	 0.001071	 0.007569	 0.0	 299.0	 4133	 4133	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 3119	 0.005138	 0.025338	 0.0	 1222	 1222	 1222	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 3119	 0.005031	 0.025831	 0.0	 1201	 1201	 1201	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 1464	 0.003658	 0.029071	 0.0	 1079	 1079	 1079	 0.0	 0.0	 1	 -30.0	 30.0;
	6998	 1464	 0.004151	 0.028489	 0.0	 1098	 1098	 1098	 0.0	 0.0	 1	 -30.0	 30.0;
	1221	 1350	 0.001471	 0.011471	 0.0	 2732	 2732	 2732	 0.0	 0.0	 1	 -30.0	 30.0;
	1221	 1350	 0.001502	 0.011218	 0.0	 2791	 2791	 2791	 0.0	 0.0	 1	 -30.0	 30.0;
	2305	 1350	 0.001871	 0.014511	 0.0	 2159	 2159	 2159	 0.0	 0.0	 1	 -30.0	 30.0;
	2305	 1350	 0.001902	 0.0142	 0.0	 2205	 2205	 2205	 0.0	 0.0	 1	 -30.0	 30.0;
	199	 7195	 0.000351	 0.004662	 0.0	 6757	 6757	 6757	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 199	 0.00772	 0.033818	 0.0	 911	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	4964	 8432	 0.0	 0.00051	 0.0	 1909.0	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	8432	 3190	 0.00076	 0.0119	 0.0	 790.0	 2650	 2650	 0.0	 0.0	 1	 -30.0	 30.0;
	8432	 3352	 0.00025	 0.00316	 0.0	 1580.0	 9965	 9965	 0.0	 0.0	 1	 -30.0	 30.0;
	4964	 3484	 0.00077	 0.01164	 0.0	 823.0	 2708	 2708	 0.0	 0.0	 1	 -30.0	 30.0;
	4964	 6766	 0.00025	 0.00322	 0.0	 1481.0	 9781	 9781	 0.0	 0.0	 1	 -30.0	 30.0;
	838	 6295	 0.001369	 0.021182	 0.0	 494.0	 1489	 1489	 0.0	 0.0	 1	 -30.0	 30.0;
	3190	 3484	 0.0	 0.00052	 0.0	 757.0	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	3190	 6263	 0.00015	 0.00328	 0.0	 790.0	 9621	 9621	 0.0	 0.0	 1	 -30.0	 30.0;
	395	 3190	 0.00016	 0.00314	 0.0	 1349.0	 10047	 10047	 0.0	 0.0	 1	 -30.0	 30.0;
	3484	 6068	 0.00017	 0.00321	 0.0	 987.0	 9827	 9827	 0.0	 0.0	 1	 -30.0	 30.0;
	5843	 3484	 0.00018	 0.00308	 0.0	 954.0	 10239	 10239	 0.0	 0.0	 1	 -30.0	 30.0;
	3210	 4021	 0.00024	 0.01948	 0.0	 757.0	 1622	 1622	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 7425	 0.000631	 0.037902	 0.0	 834	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	2381	 5772	 0.00244	 0.01532	 0.0	 2037	 2037	 2037	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 8086	 0.0	 0.00053	 0.0	 757.0	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 6068	 0.00013	 0.00282	 0.0	 987.0	 11190	 11190	 0.0	 0.0	 1	 -30.0	 30.0;
	4077	 281	 0.00038	 0.00708	 0.0	 1218.0	 4456	 4456	 0.0	 0.0	 1	 -30.0	 30.0;
	8086	 6263	 0.00013	 0.00261	 0.0	 1086.0	 12088	 12088	 0.0	 0.0	 1	 -30.0	 30.0;
	5888	 8086	 0.00038	 0.00722	 0.0	 1448.0	 4369	 4369	 0.0	 0.0	 1	 -30.0	 30.0;
	1477	 5255	 0.00016	 0.002769	 0.0	 11389	 11389	 11389	 0.0	 0.0	 1	 -30.0	 30.0;
	3960	 5255	 0.00016	 0.00272	 0.0	 299.0	 11593	 11593	 0.0	 0.0	 1	 -30.0	 30.0;
	8037	 5255	 0.00016	 0.002662	 0.0	 299.0	 11845	 11845	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 1597	 0.024479	 0.081727	 0.0	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	6923	 1597	 0.024248	 0.064893	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	676	 8706	 0.0084	 0.04056	 0.0	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	8706	 205	 0.003809	 0.0248	 0.0	 1259	 1259	 1259	 0.0	 0.0	 1	 -30.0	 30.0;
	8706	 4362	 0.002542	 0.014569	 0.0	 2136	 2136	 2136	 0.0	 0.0	 1	 -30.0	 30.0;
	8706	 4362	 0.002591	 0.01428	 0.0	 2177	 2177	 2177	 0.0	 0.0	 1	 -30.0	 30.0;
	7584	 7736	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	7584	 5591	 0.003071	 0.01636	 0.0	 1898	 1898	 1898	 0.0	 0.0	 1	 -30.0	 30.0;
	7584	 5364	 0.003889	 0.027022	 0.0	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 7584	 0.00624	 0.036009	 0.0	 865	 865	 865	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 7584	 0.00636	 0.035258	 0.0	 882	 882	 882	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 2796	 0.000982	 0.001529	 0.0	 17383	 17383	 17383	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 2796	 0.000991	 0.001502	 0.0	 17554	 17554	 17554	 0.0	 0.0	 1	 -30.0	 30.0;
	8642	 5255	 0.00052	 0.004991	 0.0	 260.0	 6295	 6295	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 2703	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	650	 4104	 0.012182	 0.034826	 0.0	 857	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 650	 0.025744	 0.059	 0.0	 491	 491	 491	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 1635	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6167	 4130	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6167	 5872	 0.003129	 0.015031	 0.0	 2058	 2058	 2058	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 496	 0.00228	 0.019871	 0.0	 1580	 1580	 1580	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 5872	 0.002791	 0.017031	 0.0	 1831	 1831	 1831	 0.0	 0.0	 1	 -30.0	 30.0;
	6582	 3462	 0.001431	 0.01252	 0.0	 2507	 2507	 2507	 0.0	 0.0	 1	 -30.0	 30.0;
	6582	 4082	 0.001649	 0.007631	 0.0	 4046	 4046	 4046	 0.0	 0.0	 1	 -30.0	 30.0;
	6582	 5246	 0.001471	 0.008649	 0.0	 3601	 3601	 3601	 0.0	 0.0	 1	 -30.0	 30.0;
	496	 5872	 0.00656	 0.009071	 0.0	 260.0	 2822	 2822	 0.0	 0.0	 1	 -30.0	 30.0;
	6047	 3664	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2077	 9063	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3224	 8044	 0.000521	 0.001529	 0.0	 391.0	 19555	 19555	 0.0	 0.0	 1	 -30.0	 30.0;
	76	 5742	 0.000219	 0.00095	 0.0	 438.0	 32401	 32401	 0.0	 0.0	 1	 -30.0	 30.0;
	38	 5742	 0.000219	 0.00088	 0.0	 533.0	 34833	 34833	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 9118	 0.002391	 0.015618	 0.0	 2000	 2000	 2000	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 919	 0.0	 0.00054	 0.0	 1448.0	 58496	 58496	 0.0	 0.0	 1	 -30.0	 30.0;
	1788	 5008	 0.00079	 0.01037	 0.0	 1678.0	 3038	 3038	 0.0	 0.0	 1	 -30.0	 30.0;
	662	 5008	 0.00022	 0.00296	 0.0	 1645.0	 10643	 10643	 0.0	 0.0	 1	 -30.0	 30.0;
	8604	 919	 0.00077	 0.01056	 0.0	 1810.0	 2984	 2984	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 4295	 0.000649	 0.03712	 0.0	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 5203	 0.003302	 0.019138	 0.0	 1627	 1627	 1627	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 5203	 0.003369	 0.018742	 0.0	 1659	 1659	 1659	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 472	 0.001769	 0.018222	 0.0	 1726	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 7476	 0.000858	 0.006809	 0.0	 4603	 4603	 4603	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 7476	 0.000969	 0.006671	 0.0	 4686	 4686	 4686	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 8792	 0.005551	 0.03908	 0.0	 801	 801	 801	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 8792	 0.005431	 0.039822	 0.0	 786	 786	 786	 0.0	 0.0	 1	 -30.0	 30.0;
	6354	 8792	 0.005311	 0.036871	 0.0	 848	 848	 848	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 1094	 0.002169	 0.016271	 0.0	 1925	 1925	 1925	 0.0	 0.0	 1	 -30.0	 30.0;
	3182	 1094	 0.007418	 0.07832	 0.0	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 3023	 0.0	 0.0005	 0.0	 757.0	 63175	 63175	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 6345	 0.0	 0.00049	 0.0	 757.0	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 8114	 0.00079	 0.00848	 0.0	 1580.0	 3709	 3709	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 3210	 0.00183	 0.0174	 0.0	 1415.0	 1806	 1806	 0.0	 0.0	 1	 -30.0	 30.0;
	3023	 6345	 0.0	 0.00048	 0.0	 757.0	 65807	 65807	 0.0	 0.0	 1	 -30.0	 30.0;
	3023	 8773	 0.0008	 0.0083	 0.0	 1678.0	 3789	 3789	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 71	 0.004449	 0.02404	 0.0	 1293	 1293	 1293	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 71	 0.004529	 0.023551	 0.0	 1318	 1318	 1318	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 6202	 0.006791	 0.013271	 0.0	 260.0	 2119	 2119	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 1106	 0.00424	 0.030378	 0.0	 1030	 1030	 1030	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 1106	 0.004151	 0.028129	 0.0	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 7305	 0.002311	 0.003622	 0.0	 7352	 7352	 7352	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 7305	 0.002062	 0.004102	 0.0	 6881	 6881	 6881	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 6987	 0.00452	 0.029609	 0.0	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 6987	 0.004422	 0.030169	 0.0	 1036	 1036	 1036	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 4774	 0.00416	 0.023058	 0.0	 1349	 1349	 1349	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 3620	 0.002831	 0.020742	 0.0	 273.0	 1509	 1509	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 1722	 0.002338	 0.01592	 0.0	 1964	 1964	 1964	 0.0	 0.0	 1	 -30.0	 30.0;
	585	 3148	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 585	 0.004969	 0.03636	 0.0	 861	 861	 861	 0.0	 0.0	 1	 -30.0	 30.0;
	6987	 585	 0.003431	 0.015698	 0.0	 1966	 1966	 1966	 0.0	 0.0	 1	 -30.0	 30.0;
	7275	 585	 0.00456	 0.027582	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	8114	 8773	 0.0	 0.00047	 0.0	 757.0	 67208	 67208	 0.0	 0.0	 1	 -30.0	 30.0;
	8393	 8114	 0.00093	 0.01185	 0.0	 1810.0	 2658	 2658	 0.0	 0.0	 1	 -30.0	 30.0;
	139	 8773	 0.00091	 0.01207	 0.0	 1810.0	 2610	 2610	 0.0	 0.0	 1	 -30.0	 30.0;
	676	 6439	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	8738	 676	 0.000529	 0.003151	 0.0	 9887	 9887	 9887	 0.0	 0.0	 1	 -30.0	 30.0;
	8738	 676	 0.00052	 0.003209	 0.0	 9717	 9717	 9717	 0.0	 0.0	 1	 -30.0	 30.0;
	676	 205	 0.00352	 0.020578	 0.0	 1514	 1514	 1514	 0.0	 0.0	 1	 -30.0	 30.0;
	8862	 6915	 0.039182	 0.089413	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	8862	 9205	 0.033686	 0.067124	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	6393	 4057	 0.044992	 0.093174	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 6393	 0.013678	 0.052479	 0.0	 583	 583	 583	 0.0	 0.0	 1	 -30.0	 30.0;
	4872	 6393	 0.005686	 0.022893	 0.0	 1340	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	6393	 7136	 0.034281	 0.094653	 0.0	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	2769	 6118	 0.0	 0.00045	 0.0	 70195	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	76	 2769	 0.00032	 0.001469	 0.0	 438.0	 21010	 21010	 0.0	 0.0	 1	 -30.0	 30.0;
	38	 6118	 0.000289	 0.001039	 0.0	 457.0	 29290	 29290	 0.0	 0.0	 1	 -30.0	 30.0;
	3224	 7117	 0.00324	 0.017628	 0.0	 1763	 1763	 1763	 0.0	 0.0	 1	 -30.0	 30.0;
	3224	 8525	 0.002678	 0.019298	 0.0	 1622	 1622	 1622	 0.0	 0.0	 1	 -30.0	 30.0;
	3224	 5346	 0.000529	 0.001504	 0.0	 19813	 19813	 19813	 0.0	 0.0	 1	 -30.0	 30.0;
	4993	 3335	 0.00042	 0.0261	 0.0	 757.0	 1211	 1211	 0.0	 0.0	 1	 -30.0	 30.0;
	6832	 4797	 0.00043	 0.02555	 0.0	 757.0	 1237	 1237	 0.0	 0.0	 1	 -30.0	 30.0;
	6489	 4797	 0.00044	 0.02499	 0.0	 757.0	 1264	 1264	 0.0	 0.0	 1	 -30.0	 30.0;
	8284	 4797	 0.00039	 0.02833	 0.0	 757.0	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	577	 1362	 0.00019	 0.01594	 0.0	 1982	 1982	 1982	 0.0	 0.0	 1	 -30.0	 30.0;
	268	 1057	 0.000419	 0.026099	 0.0	 1211	 1211	 1211	 0.0	 0.0	 1	 -30.0	 30.0;
	2728	 5979	 0.00043	 0.02555	 0.0	 1237	 1237	 1237	 0.0	 0.0	 1	 -30.0	 30.0;
	8662	 8298	 0.00038	 0.02888	 0.0	 757.0	 1094	 1094	 0.0	 0.0	 1	 -30.0	 30.0;
	6884	 4059	 0.00038	 0.02944	 0.0	 757.0	 1073	 1073	 0.0	 0.0	 1	 -30.0	 30.0;
	3723	 3335	 0.00037	 0.02999	 0.0	 1054	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	1890	 3335	 0.00036	 0.02777	 0.0	 1138	 1138	 1138	 0.0	 0.0	 1	 -30.0	 30.0;
	71	 8141	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	7295	 71	 0.003951	 0.02048	 0.0	 1515	 1515	 1515	 0.0	 0.0	 1	 -30.0	 30.0;
	71	 7297	 0.003858	 0.020871	 0.0	 1489	 1489	 1489	 0.0	 0.0	 1	 -30.0	 30.0;
	4797	 8298	 0.0	 0.00046	 0.0	 757.0	 68669	 68669	 0.0	 0.0	 1	 -30.0	 30.0;
	4797	 4059	 0.0	 0.00045	 0.0	 757.0	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	4797	 7388	 0.0	 0.00051	 0.0	 823.0	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	4797	 2002	 0.0	 0.00052	 0.0	 823.0	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 5979	 0.0	 0.00051	 0.0	 61936	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 1057	 0.0	 0.000521	 0.0	 60629	 60629	 60629	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 6282	 0.0	 0.000531	 0.0	 381.0	 59487	 59487	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 4340	 0.0	 0.000539	 0.0	 58604	 58604	 58604	 0.0	 0.0	 1	 -30.0	 30.0;
	3335	 8298	 0.0	 0.00053	 0.0	 1415.0	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	3335	 4059	 0.0	 0.00054	 0.0	 954.0	 58496	 58496	 0.0	 0.0	 1	 -30.0	 30.0;
	3335	 7388	 0.0	 0.0005	 0.0	 1119.0	 63175	 63175	 0.0	 0.0	 1	 -30.0	 30.0;
	3335	 2002	 0.0	 0.00049	 0.0	 921.0	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	326	 5979	 0.0	 0.0005	 0.0	 63175	 63175	 63175	 0.0	 0.0	 1	 -30.0	 30.0;
	326	 1057	 0.0	 0.00049	 0.0	 64464	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	326	 6282	 0.0	 0.000479	 0.0	 65945	 65945	 65945	 0.0	 0.0	 1	 -30.0	 30.0;
	326	 4340	 0.0	 0.000469	 0.0	 67351	 67351	 67351	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 8298	 0.00043	 0.00544	 0.0	 1580.0	 5789	 5789	 0.0	 0.0	 1	 -30.0	 30.0;
	2523	 5979	 0.0	 0.000461	 0.0	 476.0	 68520	 68520	 0.0	 0.0	 1	 -30.0	 30.0;
	1057	 1362	 0.0	 0.00045	 0.0	 457.0	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	1956	 7388	 0.00038	 0.00616	 0.0	 1448.0	 5119	 5119	 0.0	 0.0	 1	 -30.0	 30.0;
	5299	 2002	 0.00041	 0.02721	 0.0	 1086.0	 1161	 1161	 0.0	 0.0	 1	 -30.0	 30.0;
	4340	 1052	 0.002081	 0.023	 0.0	 533.0	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	6662	 838	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 2722	 0.0	 0.00048	 0.0	 1514.0	 65807	 65807	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 1689	 0.0011	 0.01189	 0.0	 1810.0	 2646	 2646	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 3210	 0.00084	 0.00906	 0.0	 1020.0	 3472	 3472	 0.0	 0.0	 1	 -30.0	 30.0;
	2722	 1689	 0.00112	 0.01165	 0.0	 1876.0	 2699	 2699	 0.0	 0.0	 1	 -30.0	 30.0;
	2722	 8230	 0.00115	 0.0114	 0.0	 1744.0	 2757	 2757	 0.0	 0.0	 1	 -30.0	 30.0;
	2722	 5674	 0.00086	 0.00887	 0.0	 1283.0	 3545	 3545	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 7195	 0.00116	 0.00912	 0.0	 260.0	 3436	 3436	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 7195	 0.001129	 0.009298	 0.0	 3373	 3373	 3373	 0.0	 0.0	 1	 -30.0	 30.0;
	7195	 8977	 0.000609	 0.005058	 0.0	 6201	 6201	 6201	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 7195	 0.008009	 0.04	 0.0	 775	 775	 775	 0.0	 0.0	 1	 -30.0	 30.0;
	7195	 3868	 0.002289	 0.016218	 0.0	 1929	 1929	 1929	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 392	 0.003098	 0.032729	 0.0	 961	 961	 961	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 3530	 0.002982	 0.013058	 0.0	 2359	 2359	 2359	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 3530	 0.00304	 0.0128	 0.0	 2401	 2401	 2401	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 5829	 0.008791	 0.059622	 0.0	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	8977	 6539	 0.000511	 0.004409	 0.0	 7117	 7117	 7117	 0.0	 0.0	 1	 -30.0	 30.0;
	7675	 6539	 0.009391	 0.030809	 0.0	 981	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	7675	 6539	 0.009191	 0.031391	 0.0	 260.0	 966	 966	 0.0	 0.0	 1	 -30.0	 30.0;
	1702	 2900	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	6202	 1702	 0.00276	 0.014782	 0.0	 2101	 2101	 2101	 0.0	 0.0	 1	 -30.0	 30.0;
	6202	 1702	 0.002809	 0.014458	 0.0	 2145	 2145	 2145	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 1702	 0.003138	 0.017502	 0.0	 1777	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 1702	 0.0032	 0.017138	 0.0	 1812	 1812	 1812	 0.0	 0.0	 1	 -30.0	 30.0;
	5916	 6342	 0.002033	 0.005273	 0.0	 5590	 5590	 5590	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 6342	 0.036066	 0.160107	 0.0	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	733	 8917	 0.027686	 0.04614	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 8917	 0.025107	 0.051372	 0.0	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	1777	 548	 0.002479	 0.01086	 0.0	 2836	 2836	 2836	 0.0	 0.0	 1	 -30.0	 30.0;
	548	 6923	 0.013603	 0.051876	 0.0	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	9029	 8508	 0.00176	 0.108	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	1591	 5558	 0.0	 0.00047	 0.0	 987.0	 67208	 67208	 0.0	 0.0	 1	 -30.0	 30.0;
	1591	 8604	 0.00038	 0.00366	 0.0	 1744.0	 8585	 8585	 0.0	 0.0	 1	 -30.0	 30.0;
	1591	 8264	 0.00052	 0.00633	 0.0	 1909.0	 4974	 4974	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 8510	 0.0	 0.00051	 0.0	 61936	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 3257	 0.001599	 0.015599	 0.0	 2015	 2015	 2015	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 1124	 0.00212	 0.022349	 0.0	 1408	 1408	 1408	 0.0	 0.0	 1	 -30.0	 30.0;
	5558	 1788	 0.00034	 0.00415	 0.0	 1645.0	 7586	 7586	 0.0	 0.0	 1	 -30.0	 30.0;
	8211	 5558	 0.00051	 0.00646	 0.0	 1744.0	 4875	 4875	 0.0	 0.0	 1	 -30.0	 30.0;
	8510	 369	 0.00163	 0.015271	 0.0	 2057	 2057	 2057	 0.0	 0.0	 1	 -30.0	 30.0;
	3891	 8510	 0.002159	 0.021901	 0.0	 1436	 1436	 1436	 0.0	 0.0	 1	 -30.0	 30.0;
	5952	 784	 0.00224	 0.015018	 0.0	 2081	 2081	 2081	 0.0	 0.0	 1	 -30.0	 30.0;
	5952	 3182	 0.004111	 0.00652	 0.0	 4099	 4099	 4099	 0.0	 0.0	 1	 -30.0	 30.0;
	5952	 3182	 0.004191	 0.006391	 0.0	 4134	 4134	 4134	 0.0	 0.0	 1	 -30.0	 30.0;
	6923	 5108	 0.00238	 0.006744	 0.0	 4417	 4417	 4417	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 392	 0.003329	 0.033129	 0.0	 949	 949	 949	 0.0	 0.0	 1	 -30.0	 30.0;
	1633	 8389	 0.005809	 0.021182	 0.0	 1439	 1439	 1439	 0.0	 0.0	 1	 -30.0	 30.0;
	1633	 8389	 0.005689	 0.021591	 0.0	 1415	 1415	 1415	 0.0	 0.0	 1	 -30.0	 30.0;
	8389	 2720	 0.00132	 0.01052	 0.0	 2980	 2980	 2980	 0.0	 0.0	 1	 -30.0	 30.0;
	8389	 243	 0.001129	 0.012329	 0.0	 2552	 2552	 2552	 0.0	 0.0	 1	 -30.0	 30.0;
	8389	 4409	 0.001569	 0.1224	 0.0	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 2572	 0.000662	 0.036351	 0.0	 468.0	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 7404	 0.001777	 0.009107	 0.0	 3405	 3405	 3405	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 1338	 0.002967	 0.002901	 0.0	 7613	 7613	 7613	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 8288	 0.017893	 0.057479	 0.0	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	7404	 8882	 0.000554	 0.001091	 0.0	 25816	 25816	 25816	 0.0	 0.0	 1	 -30.0	 30.0;
	7404	 7565	 0.006339	 0.022603	 0.0	 1346	 1346	 1346	 0.0	 0.0	 1	 -30.0	 30.0;
	1338	 360	 0.004174	 0.006702	 0.0	 4001	 4001	 4001	 0.0	 0.0	 1	 -30.0	 30.0;
	360	 7565	 0.009818	 0.040099	 0.0	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	275	 6323	 0.003729	 0.01876	 0.0	 1652	 1652	 1652	 0.0	 0.0	 1	 -30.0	 30.0;
	5872	 7230	 0.000782	 0.059938	 0.0	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	8194	 5872	 0.000769	 0.061111	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 6514	 0.000382	 0.019378	 0.0	 1630	 1630	 1630	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 387	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 6838	 1.8e-05	 0.00188	 0.0	 637.0	 16802	 16802	 0.0	 0.0	 1	 -30.0	 30.0;
	8480	 6025	 0.000372	 0.001223	 0.0	 24710	 24710	 24710	 0.0	 0.0	 1	 -30.0	 30.0;
	9029	 5835	 0.000809	 0.001751	 0.0	 16377	 16377	 16377	 0.0	 0.0	 1	 -30.0	 30.0;
	3374	 878	 0.0	 0.043511	 0.0	 726	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	7450	 3374	 0.003529	 0.022178	 0.0	 1407	 1407	 1407	 0.0	 0.0	 1	 -30.0	 30.0;
	7450	 3374	 0.0036	 0.021711	 0.0	 1436	 1436	 1436	 0.0	 0.0	 1	 -30.0	 30.0;
	6383	 231	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 6383	 0.047479	 0.102603	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 6383	 0.053727	 0.091281	 0.0	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	1010	 6383	 0.021678	 0.045669	 0.0	 625	 625	 625	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 8878	 0.004397	 0.030678	 0.0	 1020	 1020	 1020	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 8878	 0.004314	 0.031256	 0.0	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 7117	 0.008347	 0.055512	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 2698	 0.006223	 0.039744	 0.0	 786	 786	 786	 0.0	 0.0	 1	 -30.0	 30.0;
	8277	 2228	 0.006124	 0.041686	 0.0	 750	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	8277	 2228	 0.006942	 0.040851	 0.0	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	4057	 5783	 0.019248	 0.039041	 0.0	 191.0	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	7136	 4057	 0.015719	 0.04943	 0.0	 609	 609	 609	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 1207	 0.00296	 0.011871	 0.0	 2582	 2582	 2582	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 9083	 0.01328	 0.04144	 0.0	 726	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 7138	 0.00736	 0.033222	 0.0	 929	 929	 929	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 7138	 0.007502	 0.032529	 0.0	 947	 947	 947	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 2745	 0.00192	 0.02576	 0.0	 299.0	 1223	 1223	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 2745	 0.002169	 0.02524	 0.0	 299.0	 1247	 1247	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 8492	 0.00656	 0.017071	 0.0	 1728	 1728	 1728	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 2748	 0.002662	 0.007471	 0.0	 3983	 3983	 3983	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 3215	 0.003191	 0.009062	 0.0	 3288	 3288	 3288	 0.0	 0.0	 1	 -30.0	 30.0;
	6915	 8668	 0.00981	 0.057298	 0.0	 544	 544	 544	 0.0	 0.0	 1	 -30.0	 30.0;
	3177	 6356	 0.008342	 0.037031	 0.0	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	1464	 6356	 0.0086	 0.039791	 0.0	 776	 776	 776	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 8230	 0.0	 0.00046	 0.0	 1843.0	 68669	 68669	 0.0	 0.0	 1	 -30.0	 30.0;
	6068	 1689	 0.00055	 0.00685	 0.0	 1645.0	 4597	 4597	 0.0	 0.0	 1	 -30.0	 30.0;
	6263	 8230	 0.00054	 0.00699	 0.0	 1645.0	 4506	 4506	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 69	 0.0056	 0.052889	 0.0	 594	 594	 594	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 5949	 0.006058	 0.023591	 0.0	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 5949	 0.0054	 0.026729	 0.0	 1159	 1159	 1159	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 8613	 0.00168	 0.01188	 0.0	 299.0	 2633	 2633	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 9007	 0.003178	 0.028658	 0.0	 1096	 1096	 1096	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 5188	 0.003178	 0.028542	 0.0	 299.0	 1100	 1100	 0.0	 0.0	 1	 -30.0	 30.0;
	2077	 6442	 0.00068	 0.004449	 0.0	 7019	 7019	 7019	 0.0	 0.0	 1	 -30.0	 30.0;
	2077	 3462	 0.00076	 0.004818	 0.0	 6477	 6477	 6477	 0.0	 0.0	 1	 -30.0	 30.0;
	2812	 1778	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2812	 1633	 9e-06	 0.000222	 0.0	 142169	 142169	 142169	 0.0	 0.0	 1	 -30.0	 30.0;
	3983	 1633	 0.0	 0.000222	 0.0	 299.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7442	 1633	 1.8e-05	 0.004329	 0.0	 7297	 7297	 7297	 0.0	 0.0	 1	 -30.0	 30.0;
	6047	 5271	 0.001831	 0.001698	 0.0	 12650	 12650	 12650	 0.0	 0.0	 1	 -30.0	 30.0;
	6047	 5271	 0.002209	 0.001471	 0.0	 11902	 11902	 11902	 0.0	 0.0	 1	 -30.0	 30.0;
	211	 2832	 0.017653	 0.070289	 0.0	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 2832	 0.013231	 0.042207	 0.0	 715	 715	 715	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 2832	 0.013479	 0.041331	 0.0	 727	 727	 727	 0.0	 0.0	 1	 -30.0	 30.0;
	2804	 2832	 0.013934	 0.055702	 0.0	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	4216	 6028	 0.000537	 0.001471	 0.0	 20172	 20172	 20172	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 4872	 0.009967	 0.048959	 0.0	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 9146	 0.030612	 0.055058	 0.0	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 9146	 0.031207	 0.053934	 0.0	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 6028	 0.01314	 0.040579	 0.0	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 6028	 0.012851	 0.03757	 0.0	 796	 796	 796	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 7011	 0.006901	 0.021174	 0.0	 1419	 1419	 1419	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 7011	 0.007653	 0.01924	 0.0	 1526	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	7295	 5595	 0.008982	 0.038462	 0.0	 800	 800	 800	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 7297	 0.009151	 0.037649	 0.0	 816	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 1020	 0.004258	 0.03952	 0.0	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	2616	 5595	 0.003489	 0.0264	 0.0	 1187	 1187	 1187	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 2305	 0.003849	 0.05232	 0.0	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 4104	 0.032669	 0.080273	 0.0	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	1889	 4104	 0.004901	 0.014967	 0.0	 2006	 2006	 2006	 0.0	 0.0	 1	 -30.0	 30.0;
	312	 5783	 0.000562	 0.001058	 0.0	 26367	 26367	 26367	 0.0	 0.0	 1	 -30.0	 30.0;
	8393	 139	 0.0	 0.00045	 0.0	 1547.0	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	8393	 8264	 0.001	 0.01169	 0.0	 1481.0	 2693	 2693	 0.0	 0.0	 1	 -30.0	 30.0;
	139	 8211	 0.00098	 0.01192	 0.0	 1448.0	 2642	 2642	 0.0	 0.0	 1	 -30.0	 30.0;
	6600	 7565	 0.002339	 0.006223	 0.0	 4752	 4752	 4752	 0.0	 0.0	 1	 -30.0	 30.0;
	6600	 7565	 0.002388	 0.006091	 0.0	 4829	 4829	 4829	 0.0	 0.0	 1	 -30.0	 30.0;
	2555	 6600	 0.000504	 0.001207	 0.0	 24150	 24150	 24150	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 7565	 0.00105	 0.007959	 0.0	 248.0	 3935	 3935	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 7565	 0.001033	 0.007372	 0.0	 267.0	 4244	 4244	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 2648	 0.018752	 0.042339	 0.0	 683	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 2648	 0.018339	 0.039231	 0.0	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 6923	 0.036793	 0.081719	 0.0	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 8480	 0.003702	 0.015132	 0.0	 2028	 2028	 2028	 0.0	 0.0	 1	 -30.0	 30.0;
	2478	 1989	 0.00124	 0.007314	 0.0	 219.0	 4258	 4258	 0.0	 0.0	 1	 -30.0	 30.0;
	523	 5760	 0.002329	 0.00356	 0.0	 299.0	 7426	 7426	 0.0	 0.0	 1	 -30.0	 30.0;
	523	 5760	 0.002378	 0.00348	 0.0	 299.0	 7495	 7495	 0.0	 0.0	 1	 -30.0	 30.0;
	523	 5760	 0.00212	 0.003951	 0.0	 299.0	 7045	 7045	 0.0	 0.0	 1	 -30.0	 30.0;
	523	 7476	 0.001951	 0.003791	 0.0	 364.0	 7409	 7409	 0.0	 0.0	 1	 -30.0	 30.0;
	69	 7852	 0.002542	 0.01472	 0.0	 2115	 2115	 2115	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 5342	 0.003262	 0.024151	 0.0	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	9206	 4757	 0.0036	 0.01548	 0.0	 260.0	 1988	 1988	 0.0	 0.0	 1	 -30.0	 30.0;
	9206	 4757	 0.00352	 0.014329	 0.0	 260.0	 2141	 2141	 0.0	 0.0	 1	 -30.0	 30.0;
	1880	 4380	 0.002591	 0.014418	 0.0	 2157	 2157	 2157	 0.0	 0.0	 1	 -30.0	 30.0;
	3530	 1880	 0.001071	 0.003058	 0.0	 9749	 9749	 9749	 0.0	 0.0	 1	 -30.0	 30.0;
	3530	 4687	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	3530	 1330	 0.017458	 0.052129	 0.0	 575	 575	 575	 0.0	 0.0	 1	 -30.0	 30.0;
	7295	 8442	 0.00136	 0.00216	 0.0	 12376	 12376	 12376	 0.0	 0.0	 1	 -30.0	 30.0;
	7297	 8442	 0.001391	 0.00212	 0.0	 12458	 12458	 12458	 0.0	 0.0	 1	 -30.0	 30.0;
	6399	 9083	 0.005858	 0.016591	 0.0	 1796	 1796	 1796	 0.0	 0.0	 1	 -30.0	 30.0;
	898	 8668	 0.004562	 0.011653	 0.0	 2525	 2525	 2525	 0.0	 0.0	 1	 -30.0	 30.0;
	898	 6526	 0.030868	 0.064174	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	3257	 369	 0.0	 0.000521	 0.0	 60629	 60629	 60629	 0.0	 0.0	 1	 -30.0	 30.0;
	2381	 1020	 0.005929	 0.053271	 0.0	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	2381	 297	 0.00664	 0.040849	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	2381	 3182	 0.00968	 0.049382	 0.0	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 4692	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 69	 0.00044	 0.004489	 0.0	 7004	 7004	 7004	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 3898	 0.01064	 0.043751	 0.0	 702	 702	 702	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 3898	 0.0104	 0.040511	 0.0	 756	 756	 756	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 5829	 0.0024	 0.025498	 0.0	 1234	 1234	 1234	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 1205	 0.00264	 0.01412	 0.0	 2199	 2199	 2199	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 6131	 0.000609	 0.03944	 0.0	 663.0	 1222	 1222	 0.0	 0.0	 1	 -30.0	 30.0;
	8565	 472	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 5760	 0.001182	 0.003018	 0.0	 299.0	 9746	 9746	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 5760	 0.0012	 0.002951	 0.0	 299.0	 9916	 9916	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 5760	 0.001071	 0.003351	 0.0	 286.0	 8979	 8979	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 7073	 0.001031	 0.01544	 0.0	 2042	 2042	 2042	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 349	 0.001009	 0.015738	 0.0	 2003	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 7156	 0.000991	 0.01604	 0.0	 1966	 1966	 1966	 0.0	 0.0	 1	 -30.0	 30.0;
	6202	 7305	 0.003898	 0.008862	 0.0	 3263	 3263	 3263	 0.0	 0.0	 1	 -30.0	 30.0;
	6202	 7305	 0.003818	 0.009031	 0.0	 3222	 3222	 3222	 0.0	 0.0	 1	 -30.0	 30.0;
	643	 311	 0.003831	 0.012502	 0.0	 2416	 2416	 2416	 0.0	 0.0	 1	 -30.0	 30.0;
	6068	 6263	 0.0	 0.00051	 0.0	 856.0	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	6017	 6263	 0.00127	 0.0132	 0.0	 1481.0	 2382	 2382	 0.0	 0.0	 1	 -30.0	 30.0;
	7450	 2271	 0.0	 0.000222	 0.0	 299.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7450	 7666	 0.001338	 0.011209	 0.0	 2799	 2799	 2799	 0.0	 0.0	 1	 -30.0	 30.0;
	7450	 7018	 0.004222	 0.030062	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	8784	 7450	 0.001182	 0.0104	 0.0	 3018	 3018	 3018	 0.0	 0.0	 1	 -30.0	 30.0;
	2271	 3846	 9e-06	 0.000222	 0.0	 142169	 142169	 142169	 0.0	 0.0	 1	 -30.0	 30.0;
	2271	 7018	 0.004138	 0.03064	 0.0	 1022	 1022	 1022	 0.0	 0.0	 1	 -30.0	 30.0;
	3846	 7018	 0.004049	 0.031209	 0.0	 1004	 1004	 1004	 0.0	 0.0	 1	 -30.0	 30.0;
	733	 5423	 0.022603	 0.051959	 0.0	 558	 558	 558	 0.0	 0.0	 1	 -30.0	 30.0;
	4614	 733	 0.013636	 0.032041	 0.0	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	8492	 3216	 0.00228	 0.009222	 0.0	 3326	 3326	 3326	 0.0	 0.0	 1	 -30.0	 30.0;
	2748	 3216	 0.002471	 0.010302	 0.0	 273.0	 2982	 2982	 0.0	 0.0	 1	 -30.0	 30.0;
	3215	 3216	 0.001831	 0.007378	 0.0	 273.0	 4156	 4156	 0.0	 0.0	 1	 -30.0	 30.0;
	8878	 4302	 0.006843	 0.049248	 0.0	 636	 636	 636	 0.0	 0.0	 1	 -30.0	 30.0;
	8878	 4302	 0.006686	 0.045603	 0.0	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	2760	 8016	 0.004102	 0.011529	 0.0	 2582	 2582	 2582	 0.0	 0.0	 1	 -30.0	 30.0;
	2760	 8016	 0.004182	 0.01128	 0.0	 2626	 2626	 2626	 0.0	 0.0	 1	 -30.0	 30.0;
	1913	 2120	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8155	 1913	 0.003649	 0.0122	 0.0	 2481	 2481	 2481	 0.0	 0.0	 1	 -30.0	 30.0;
	8155	 1913	 0.00372	 0.011938	 0.0	 2527	 2527	 2527	 0.0	 0.0	 1	 -30.0	 30.0;
	1913	 7090	 0.005031	 0.028102	 0.0	 1107	 1107	 1107	 0.0	 0.0	 1	 -30.0	 30.0;
	1913	 7090	 0.005129	 0.02752	 0.0	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	1913	 7844	 0.005218	 0.026951	 0.0	 1151	 1151	 1151	 0.0	 0.0	 1	 -30.0	 30.0;
	4413	 3462	 0.00288	 0.01992	 0.0	 1570	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	4413	 3462	 0.003262	 0.01952	 0.0	 1597	 1597	 1597	 0.0	 0.0	 1	 -30.0	 30.0;
	8738	 1106	 0.00956	 0.061022	 0.0	 512	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	8738	 2760	 0.005382	 0.033911	 0.0	 920	 920	 920	 0.0	 0.0	 1	 -30.0	 30.0;
	8738	 2760	 0.005271	 0.034569	 0.0	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	8738	 6218	 0.004102	 0.023018	 0.0	 1352	 1352	 1352	 0.0	 0.0	 1	 -30.0	 30.0;
	1788	 8604	 0.0	 0.00052	 0.0	 757.0	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 2335	 0.0	 0.000222	 0.0	 481.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 3182	 0.011631	 0.094591	 0.0	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	2616	 1020	 0.0012	 0.008769	 0.0	 299.0	 3569	 3569	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 9072	 0.001218	 0.008582	 0.0	 299.0	 3645	 3645	 0.0	 0.0	 1	 -30.0	 30.0;
	7138	 7586	 0.002689	 0.013818	 0.0	 2244	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	2648	 8288	 0.005	 0.008934	 0.0	 3086	 3086	 3086	 0.0	 0.0	 1	 -30.0	 30.0;
	2824	 140	 0.0	 0.000531	 0.0	 59487	 59487	 59487	 0.0	 0.0	 1	 -30.0	 30.0;
	2824	 5311	 0.001281	 0.0158	 0.0	 1993	 1993	 1993	 0.0	 0.0	 1	 -30.0	 30.0;
	140	 3891	 0.00125	 0.016099	 0.0	 1957	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	211	 6526	 0.010058	 0.048	 0.0	 645	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	211	 6526	 0.010248	 0.047	 0.0	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	211	 2804	 0.004314	 0.024537	 0.0	 1268	 1268	 1268	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 3301	 0.010791	 0.042151	 0.0	 299.0	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 1011	 0.0006	 0.040218	 0.0	 786	 786	 786	 0.0	 0.0	 1	 -30.0	 30.0;
	243	 8621	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3210	 5674	 0.0	 0.00053	 0.0	 1711.0	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	3210	 4337	 0.0	 0.00054	 0.0	 1251.0	 58496	 58496	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 8204	 0.00196	 0.010249	 0.0	 3028	 3028	 3028	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 1516	 0.002182	 0.010498	 0.0	 2946	 2946	 2946	 0.0	 0.0	 1	 -30.0	 30.0;
	5949	 6480	 0.000582	 0.040991	 0.0	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	5949	 5655	 0.000569	 0.04176	 0.0	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	1464	 3177	 0.003818	 0.013209	 0.0	 2298	 2298	 2298	 0.0	 0.0	 1	 -30.0	 30.0;
	5949	 6323	 0.00428	 0.023511	 0.0	 1322	 1322	 1322	 0.0	 0.0	 1	 -30.0	 30.0;
	5949	 6323	 0.004182	 0.021769	 0.0	 1425	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	1956	 4858	 0.0	 0.0005	 0.0	 1086.0	 63175	 63175	 0.0	 0.0	 1	 -30.0	 30.0;
	1956	 8264	 0.00114	 0.01661	 0.0	 1481.0	 1898	 1898	 0.0	 0.0	 1	 -30.0	 30.0;
	4320	 4248	 0.0	 0.000539	 0.0	 58604	 58604	 58604	 0.0	 0.0	 1	 -30.0	 30.0;
	4320	 76	 0.00119	 0.014081	 0.0	 2236	 2236	 2236	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 8211	 0.00117	 0.01626	 0.0	 1711.0	 1938	 1938	 0.0	 0.0	 1	 -30.0	 30.0;
	4248	 38	 0.00106	 0.01595	 0.0	 1977	 1977	 1977	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 999	 0.018058	 0.065719	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 1010	 0.012826	 0.025058	 0.0	 1123	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 1010	 0.013331	 0.024	 0.0	 1151	 1151	 1151	 0.0	 0.0	 1	 -30.0	 30.0;
	8204	 1516	 0.001089	 0.003151	 0.0	 9475	 9475	 9475	 0.0	 0.0	 1	 -30.0	 30.0;
	5792	 2428	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 1277	 0.000631	 0.054471	 0.0	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 2117	 0.000622	 0.055489	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 8895	 0.0006	 0.051382	 0.0	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 6526	 0.017702	 0.064331	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 1787	 0.012314	 0.04924	 0.0	 623	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	2331	 8380	 0.001223	 0.001248	 0.0	 18078	 18078	 18078	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 8380	 0.001471	 0.00481	 0.0	 6280	 6280	 6280	 0.0	 0.0	 1	 -30.0	 30.0;
	999	 8380	 0.011521	 0.03138	 0.0	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	9029	 7915	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9029	 6149	 0.000289	 0.00056	 0.0	 50125	 50125	 50125	 0.0	 0.0	 1	 -30.0	 30.0;
	3968	 3370	 0.00034	 0.01805	 0.0	 757.0	 1750	 1750	 0.0	 0.0	 1	 -30.0	 30.0;
	7480	 2720	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 6687	 0.00035	 0.01766	 0.0	 1053.0	 1789	 1789	 0.0	 0.0	 1	 -30.0	 30.0;
	8956	 4209	 0.00035	 0.01728	 0.0	 1053.0	 1828	 1828	 0.0	 0.0	 1	 -30.0	 30.0;
	5065	 8318	 0.00031	 0.01958	 0.0	 1614	 1614	 1614	 0.0	 0.0	 1	 -30.0	 30.0;
	7270	 3370	 0.00031	 0.01997	 0.0	 856.0	 1582	 1582	 0.0	 0.0	 1	 -30.0	 30.0;
	6424	 3370	 0.0003	 0.02035	 0.0	 757.0	 1553	 1553	 0.0	 0.0	 1	 -30.0	 30.0;
	5888	 8223	 0.00016	 0.0025	 0.0	 1020.0	 12610	 12610	 0.0	 0.0	 1	 -30.0	 30.0;
	4776	 3370	 0.00029	 0.02074	 0.0	 1119.0	 1523	 1523	 0.0	 0.0	 1	 -30.0	 30.0;
	1331	 8318	 0.00029	 0.0192	 0.0	 757.0	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	8483	 8318	 0.00033	 0.01882	 0.0	 757.0	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	6687	 4209	 0.0	 0.00049	 0.0	 757.0	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	4733	 6687	 0.0	 0.00048	 0.0	 1283.0	 65807	 65807	 0.0	 0.0	 1	 -30.0	 30.0;
	7856	 4209	 0.0	 0.00047	 0.0	 1382.0	 67208	 67208	 0.0	 0.0	 1	 -30.0	 30.0;
	3370	 5897	 0.0	 0.00046	 0.0	 1349.0	 68669	 68669	 0.0	 0.0	 1	 -30.0	 30.0;
	3370	 420	 0.0	 0.00045	 0.0	 1086.0	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	3370	 8898	 0.0	 0.00051	 0.0	 757.0	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	8318	 7856	 0.0	 0.00052	 0.0	 987.0	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	8318	 4733	 0.0	 0.00053	 0.0	 921.0	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	8318	 8898	 0.0	 0.00054	 0.0	 757.0	 58496	 58496	 0.0	 0.0	 1	 -30.0	 30.0;
	5897	 4087	 0.0	 0.0005	 0.0	 1448.0	 63175	 63175	 0.0	 0.0	 1	 -30.0	 30.0;
	4087	 7856	 0.0	 0.00049	 0.0	 1843.0	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	4087	 4077	 0.00028	 0.00403	 0.0	 1382.0	 7820	 7820	 0.0	 0.0	 1	 -30.0	 30.0;
	6283	 4087	 0.00021	 0.00396	 0.0	 1777.0	 7966	 7966	 0.0	 0.0	 1	 -30.0	 30.0;
	420	 2927	 0.0	 0.00048	 0.0	 1119.0	 65807	 65807	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 4733	 0.0	 0.00047	 0.0	 1251.0	 67208	 67208	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 5888	 0.00029	 0.00394	 0.0	 954.0	 7996	 7996	 0.0	 0.0	 1	 -30.0	 30.0;
	4485	 2927	 0.0002	 0.00404	 0.0	 1744.0	 7810	 7810	 0.0	 0.0	 1	 -30.0	 30.0;
	2720	 243	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	243	 558	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8492	 2748	 0.004471	 0.020791	 0.0	 1486	 1486	 1486	 0.0	 0.0	 1	 -30.0	 30.0;
	8492	 3215	 0.002791	 0.01132	 0.0	 2710	 2710	 2710	 0.0	 0.0	 1	 -30.0	 30.0;
	5760	 8392	 0.000822	 0.001649	 0.0	 17144	 17144	 17144	 0.0	 0.0	 1	 -30.0	 30.0;
	5760	 8392	 0.0008	 0.00168	 0.0	 16976	 16976	 16976	 0.0	 0.0	 1	 -30.0	 30.0;
	5760	 8392	 0.000782	 0.00156	 0.0	 18102	 18102	 18102	 0.0	 0.0	 1	 -30.0	 30.0;
	370	 311	 0.00432	 0.012662	 0.0	 2362	 2362	 2362	 0.0	 0.0	 1	 -30.0	 30.0;
	370	 311	 0.003849	 0.014351	 0.0	 2126	 2126	 2126	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 2552	 0.001418	 0.004618	 0.0	 6539	 6539	 6539	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 7275	 0.001689	 0.011631	 0.0	 2688	 2688	 2688	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 6218	 0.005991	 0.03832	 0.0	 815	 815	 815	 0.0	 0.0	 1	 -30.0	 30.0;
	9206	 1936	 0.001169	 0.007098	 0.0	 403.0	 4392	 4392	 0.0	 0.0	 1	 -30.0	 30.0;
	7476	 1936	 0.0012	 0.00696	 0.0	 299.0	 4473	 4473	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 9146	 0.030066	 0.046289	 0.0	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 9146	 0.026793	 0.052463	 0.0	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	7729	 4415	 0.023413	 0.057397	 0.0	 510	 510	 510	 0.0	 0.0	 1	 -30.0	 30.0;
	5591	 5364	 0.001631	 0.00832	 0.0	 3726	 3726	 3726	 0.0	 0.0	 1	 -30.0	 30.0;
	6047	 4431	 0.012569	 0.04732	 0.0	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	6047	 4431	 0.012311	 0.048231	 0.0	 635	 635	 635	 0.0	 0.0	 1	 -30.0	 30.0;
	8017	 6519	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7018	 8017	 0.000982	 0.004751	 0.0	 6511	 6511	 6511	 0.0	 0.0	 1	 -30.0	 30.0;
	2965	 1260	 0.00144	 0.12	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 5364	 0.001249	 0.0064	 0.0	 4845	 4845	 4845	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 5364	 0.00112	 0.007249	 0.0	 4307	 4307	 4307	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 3891	 0.0	 0.0005	 0.0	 63175	 63175	 63175	 0.0	 0.0	 1	 -30.0	 30.0;
	9205	 8668	 0.022843	 0.098893	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	8668	 6526	 0.034909	 0.072893	 0.0	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	7666	 377	 0.00188	 0.092222	 0.0	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	7666	 1227	 0.00184	 0.093991	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	7666	 4006	 0.0018	 0.09576	 0.0	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	5872	 7666	 0.00132	 0.01088	 0.0	 2883	 2883	 2883	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 1889	 0.01924	 0.056603	 0.0	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 1889	 0.017124	 0.064149	 0.0	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 6747	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 838	 0.006889	 0.03404	 0.0	 910	 910	 910	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 838	 0.007018	 0.033329	 0.0	 928	 928	 928	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 7951	 0.006169	 0.035689	 0.0	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 7951	 0.00628	 0.034929	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 8792	 0.004271	 0.026418	 0.0	 1181	 1181	 1181	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 8792	 0.00436	 0.02588	 0.0	 1204	 1204	 1204	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 8792	 0.00444	 0.025338	 0.0	 1228	 1228	 1228	 0.0	 0.0	 1	 -30.0	 30.0;
	3898	 1330	 0.00852	 0.02444	 0.0	 1221	 1221	 1221	 0.0	 0.0	 1	 -30.0	 30.0;
	8613	 52	 0.002671	 0.018929	 0.0	 1653	 1653	 1653	 0.0	 0.0	 1	 -30.0	 30.0;
	662	 3352	 0.0	 0.00046	 0.0	 1613.0	 68669	 68669	 0.0	 0.0	 1	 -30.0	 30.0;
	662	 6766	 0.0	 0.00045	 0.0	 1481.0	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	6017	 3352	 0.0	 0.00051	 0.0	 1185.0	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	6017	 6766	 0.0	 0.00052	 0.0	 1382.0	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	2552	 7275	 0.000329	 0.000902	 0.0	 32900	 32900	 32900	 0.0	 0.0	 1	 -30.0	 30.0;
	8792	 3712	 0.00068	 0.050351	 0.0	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	3388	 838	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 2523	 0.0	 0.00049	 0.0	 64464	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 1052	 0.00212	 0.022531	 0.0	 553.0	 1396	 1396	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 76	 0.000919	 0.012789	 0.0	 2464	 2464	 2464	 0.0	 0.0	 1	 -30.0	 30.0;
	2523	 3878	 0.002159	 0.02206	 0.0	 438.0	 1426	 1426	 0.0	 0.0	 1	 -30.0	 30.0;
	2523	 38	 0.00094	 0.012531	 0.0	 2514	 2514	 2514	 0.0	 0.0	 1	 -30.0	 30.0;
	194	 7018	 0.00032	 0.014102	 0.0	 299.0	 2240	 2240	 0.0	 0.0	 1	 -30.0	 30.0;
	4846	 7018	 0.000329	 0.0138	 0.0	 299.0	 2289	 2289	 0.0	 0.0	 1	 -30.0	 30.0;
	3691	 7018	 0.000329	 0.013502	 0.0	 299.0	 2339	 2339	 0.0	 0.0	 1	 -30.0	 30.0;
	6323	 539	 0.005818	 0.02396	 0.0	 1282	 1282	 1282	 0.0	 0.0	 1	 -30.0	 30.0;
	6323	 539	 0.005942	 0.023462	 0.0	 1306	 1306	 1306	 0.0	 0.0	 1	 -30.0	 30.0;
	5872	 6707	 0.000671	 0.001871	 0.0	 260.0	 15892	 15892	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 6707	 0.0	 0.001791	 0.0	 17637	 17637	 17637	 0.0	 0.0	 1	 -30.0	 30.0;
	5872	 3509	 0.002249	 0.003471	 0.0	 7638	 7638	 7638	 0.0	 0.0	 1	 -30.0	 30.0;
	5872	 3509	 0.001631	 0.0042	 0.0	 7011	 7011	 7011	 0.0	 0.0	 1	 -30.0	 30.0;
	5872	 3776	 0.00092	 0.002582	 0.0	 11524	 11524	 11524	 0.0	 0.0	 1	 -30.0	 30.0;
	7018	 3509	 0.0	 0.000222	 0.0	 585.0	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7018	 5974	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	8784	 7018	 0.000822	 0.00572	 0.0	 5467	 5467	 5467	 0.0	 0.0	 1	 -30.0	 30.0;
	7018	 4565	 0.001338	 0.013622	 0.0	 2308	 2308	 2308	 0.0	 0.0	 1	 -30.0	 30.0;
	8058	 7018	 0.00136	 0.004649	 0.0	 6522	 6522	 6522	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 4863	 0.0	 0.001751	 0.0	 18040	 18040	 18040	 0.0	 0.0	 1	 -30.0	 30.0;
	3776	 3509	 0.0	 0.001711	 0.0	 18462	 18462	 18462	 0.0	 0.0	 1	 -30.0	 30.0;
	4082	 6442	 0.000662	 0.004529	 0.0	 273.0	 6902	 6902	 0.0	 0.0	 1	 -30.0	 30.0;
	5246	 6442	 0.000649	 0.004618	 0.0	 6774	 6774	 6774	 0.0	 0.0	 1	 -30.0	 30.0;
	6526	 1787	 0.005669	 0.028992	 0.0	 1070	 1070	 1070	 0.0	 0.0	 1	 -30.0	 30.0;
	4616	 7260	 0.001631	 0.1176	 0.0	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	1221	 7996	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 1221	 0.006942	 0.04516	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 1221	 0.0068	 0.04604	 0.0	 679	 679	 679	 0.0	 0.0	 1	 -30.0	 30.0;
	8525	 2698	 0.003289	 0.017909	 0.0	 1735	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	3215	 7407	 0.00056	 0.038671	 0.0	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	4686	 7729	 0.02162	 0.062612	 0.0	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 2494	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 9007	 0.000822	 0.00656	 0.0	 4778	 4778	 4778	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 928	 0.003009	 0.004649	 0.0	 273.0	 5704	 5704	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 928	 0.003071	 0.004551	 0.0	 286.0	 5754	 5754	 0.0	 0.0	 1	 -30.0	 30.0;
	6987	 4509	 0.00464	 0.029431	 0.0	 1061	 1061	 1061	 0.0	 0.0	 1	 -30.0	 30.0;
	6987	 4509	 0.005249	 0.02884	 0.0	 1078	 1078	 1078	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 6047	 0.001902	 0.012702	 0.0	 2460	 2460	 2460	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 6047	 0.001858	 0.012938	 0.0	 2417	 2417	 2417	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 7662	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6149	 5442	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 3819	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 6015	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	9083	 994	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	9206	 3169	 9.8e-05	 0.000222	 0.0	 260.0	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	9206	 838	 0.004738	 0.012529	 0.0	 2359	 2359	 2359	 0.0	 0.0	 1	 -30.0	 30.0;
	9206	 838	 0.004831	 0.012262	 0.0	 2397	 2397	 2397	 0.0	 0.0	 1	 -30.0	 30.0;
	9206	 838	 0.002711	 0.018431	 0.0	 1696	 1696	 1696	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 9223	 0.01205	 0.03281	 0.0	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 838	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	838	 7779	 0.000649	 0.03712	 0.0	 390.0	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	838	 4477	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6320	 838	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 3620	 0.00076	 0.005329	 0.0	 5869	 5869	 5869	 0.0	 0.0	 1	 -30.0	 30.0;
	3182	 297	 0.005769	 0.03528	 0.0	 884	 884	 884	 0.0	 0.0	 1	 -30.0	 30.0;
	7476	 1463	 0.002258	 0.004849	 0.0	 5906	 5906	 5906	 0.0	 0.0	 1	 -30.0	 30.0;
	7476	 1463	 0.002209	 0.004489	 0.0	 260.0	 6314	 6314	 0.0	 0.0	 1	 -30.0	 30.0;
	1052	 3878	 0.0	 0.000479	 0.0	 65945	 65945	 65945	 0.0	 0.0	 1	 -30.0	 30.0;
	1052	 6477	 0.00256	 0.01561	 0.0	 533.0	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	3878	 5295	 0.00269	 0.01451	 0.0	 591.0	 2141	 2141	 0.0	 0.0	 1	 -30.0	 30.0;
	8277	 5887	 0.003372	 0.028231	 0.0	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	8277	 9127	 0.007033	 0.047083	 0.0	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	76	 38	 0.0	 0.000469	 0.0	 67351	 67351	 67351	 0.0	 0.0	 1	 -30.0	 30.0;
	3182	 1984	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	2760	 3182	 0.00392	 0.025191	 0.0	 1240	 1240	 1240	 0.0	 0.0	 1	 -30.0	 30.0;
	2760	 3182	 0.00444	 0.024689	 0.0	 1260	 1260	 1260	 0.0	 0.0	 1	 -30.0	 30.0;
	9127	 5887	 0.003529	 0.021223	 0.0	 1469	 1469	 1469	 0.0	 0.0	 1	 -30.0	 30.0;
	4082	 5246	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4485	 395	 0.00069	 0.00134	 0.0	 1481.0	 20958	 20958	 0.0	 0.0	 1	 -30.0	 30.0;
	5843	 6283	 0.00067	 0.00136	 0.0	 1448.0	 20835	 20835	 0.0	 0.0	 1	 -30.0	 30.0;
	2478	 8480	 0.012992	 0.070207	 0.0	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	395	 5843	 0.0	 0.00053	 0.0	 823.0	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	6477	 5295	 0.0	 0.000461	 0.0	 68520	 68520	 68520	 0.0	 0.0	 1	 -30.0	 30.0;
	8264	 8211	 0.0	 0.00054	 0.0	 790.0	 58496	 58496	 0.0	 0.0	 1	 -30.0	 30.0;
	7011	 4614	 0.002314	 0.005661	 0.0	 5165	 5165	 5165	 0.0	 0.0	 1	 -30.0	 30.0;
	4614	 7011	 0.002512	 0.005909	 0.0	 4920	 4920	 4920	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 7011	 0.006364	 0.018488	 0.0	 1616	 1616	 1616	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 7011	 0.005959	 0.017752	 0.0	 1687	 1687	 1687	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 9223	 0.018397	 0.04176	 0.0	 693	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 9223	 0.018058	 0.042653	 0.0	 682	 682	 682	 0.0	 0.0	 1	 -30.0	 30.0;
	7090	 7844	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2616	 559	 0.0	 0.000529	 0.0	 59712	 59712	 59712	 0.0	 0.0	 1	 -30.0	 30.0;
	9072	 559	 0.0	 0.00052	 0.0	 60745	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	2305	 9072	 0.003369	 0.031329	 0.0	 338.0	 1003	 1003	 0.0	 0.0	 1	 -30.0	 30.0;
	3341	 4259	 0.019671	 0.07004	 0.0	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	3341	 4259	 0.01812	 0.06872	 0.0	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	5805	 4721	 0.001582	 0.00724	 0.0	 4263	 4263	 4263	 0.0	 0.0	 1	 -30.0	 30.0;
	5805	 4721	 0.001551	 0.007231	 0.0	 4272	 4272	 4272	 0.0	 0.0	 1	 -30.0	 30.0;
	5805	 4721	 0.001262	 0.00796	 0.0	 3920	 3920	 3920	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 2734	 0.0264	 0.075129	 0.0	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 5274	 0.00824	 0.044751	 0.0	 695	 695	 695	 0.0	 0.0	 1	 -30.0	 30.0;
	7879	 4721	 0.018271	 0.070191	 0.0	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	7879	 4721	 0.021711	 0.063129	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	7879	 7569	 0.013191	 0.0428	 0.0	 706	 706	 706	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 2734	 0.027631	 0.102502	 0.0	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 7358	 0.005369	 0.052622	 0.0	 598	 598	 598	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 7358	 0.013938	 0.0534	 0.0	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 7358	 0.01364	 0.049449	 0.0	 616	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 1407	 0.007991	 0.037738	 0.0	 819	 819	 819	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 4721	 0.007671	 0.04096	 0.0	 758	 758	 758	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 4721	 0.007511	 0.041769	 0.0	 745	 745	 745	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 3429	 0.004089	 0.010978	 0.0	 2697	 2697	 2697	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 3429	 0.003	 0.014769	 0.0	 2096	 2096	 2096	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 610	 0.001351	 0.00784	 0.0	 3971	 3971	 3971	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 948	 0.003671	 0.022089	 0.0	 1411	 1411	 1411	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 2954	 0.002378	 0.00772	 0.0	 3911	 3911	 3911	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 610	 0.006911	 0.03268	 0.0	 946	 946	 946	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 2140	 0.00944	 0.03284	 0.0	 925	 925	 925	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 6512	 0.009831	 0.02848	 0.0	 1049	 1049	 1049	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 948	 0.003671	 0.02092	 0.0	 1488	 1488	 1488	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 2734	 0.019378	 0.10932	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 2734	 0.021969	 0.107129	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 5274	 0.009151	 0.063249	 0.0	 495	 495	 495	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 4116	 0.029169	 0.088102	 0.0	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 4868	 0.031351	 0.115698	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 7358	 0.04936	 0.182018	 0.0	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 6329	 0.001609	 0.016889	 0.0	 299.0	 1862	 1862	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 2817	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	702	 8927	 0.008698	 0.033591	 0.0	 911	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 1862	 0.01792	 0.070169	 0.0	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 8629	 0.00308	 0.008422	 0.0	 299.0	 3523	 3523	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 552	 0.002031	 0.012102	 0.0	 2575	 2575	 2575	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 552	 0.0068	 0.03452	 0.0	 898	 898	 898	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 3791	 0.01176	 0.055871	 0.0	 554	 554	 554	 0.0	 0.0	 1	 -30.0	 30.0;
	4344	 6512	 0.04856	 0.135111	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	2734	 6188	 0.039289	 0.146129	 0.0	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	2734	 6188	 0.038471	 0.148938	 0.0	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	2734	 3413	 0.010911	 0.04116	 0.0	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	6188	 1407	 0.002898	 0.017409	 0.0	 1790	 1790	 1790	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 1250	 0.00544	 0.051431	 0.0	 611	 611	 611	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 5331	 0.003791	 0.014342	 0.0	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 5927	 0.005969	 0.026302	 0.0	 1172	 1172	 1172	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 4771	 0.00608	 0.02572	 0.0	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 2660	 0.010818	 0.066769	 0.0	 260.0	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	1862	 2407	 0.006649	 0.024138	 0.0	 1262	 1262	 1262	 0.0	 0.0	 1	 -30.0	 30.0;
	1862	 2407	 0.007542	 0.023662	 0.0	 1272	 1272	 1272	 0.0	 0.0	 1	 -30.0	 30.0;
	1862	 2407	 0.007991	 0.036622	 0.0	 843	 843	 843	 0.0	 0.0	 1	 -30.0	 30.0;
	1862	 2407	 0.0116	 0.046018	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	4116	 2140	 0.011631	 0.047049	 0.0	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 7358	 0.018822	 0.064009	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	1250	 5927	 0.008071	 0.049138	 0.0	 635	 635	 635	 0.0	 0.0	 1	 -30.0	 30.0;
	1250	 4771	 0.007889	 0.045502	 0.0	 684	 684	 684	 0.0	 0.0	 1	 -30.0	 30.0;
	1250	 8278	 0.009822	 0.057222	 0.0	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 3711	 0.00656	 0.023831	 0.0	 1278	 1278	 1278	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 3711	 0.007431	 0.023351	 0.0	 1290	 1290	 1290	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 7411	 0.007391	 0.026978	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 4277	 0.001871	 0.012142	 0.0	 2572	 2572	 2572	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 987	 0.003969	 0.026169	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 2206	 0.008151	 0.04664	 0.0	 299.0	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 39	 0.00076	 0.005622	 0.0	 5568	 5568	 5568	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 3711	 0.0094	 0.035791	 0.0	 854	 854	 854	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 7792	 0.00844	 0.031031	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 1685	 0.00028	 0.002062	 0.0	 15180	 15180	 15180	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 2894	 0.004849	 0.030031	 0.0	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 4277	 0.00268	 0.022391	 0.0	 1401	 1401	 1401	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 987	 0.002391	 0.025382	 0.0	 1239	 1239	 1239	 0.0	 0.0	 1	 -30.0	 30.0;
	552	 3711	 0.017551	 0.078191	 0.0	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	6504	 1543	 0.003849	 0.02475	 0.0	 591.0	 1262	 1262	 0.0	 0.0	 1	 -30.0	 30.0;
	6504	 7041	 0.0042	 0.02005	 0.0	 1542	 1542	 1542	 0.0	 0.0	 1	 -30.0	 30.0;
	6504	 3585	 0.00011	 0.000581	 0.0	 53419	 53419	 53419	 0.0	 0.0	 1	 -30.0	 30.0;
	6504	 780	 0.000169	 0.000651	 0.0	 46965	 46965	 46965	 0.0	 0.0	 1	 -30.0	 30.0;
	6504	 3957	 0.000169	 0.000659	 0.0	 46430	 46430	 46430	 0.0	 0.0	 1	 -30.0	 30.0;
	2692	 6254	 0.00219	 0.01125	 0.0	 495.0	 2757	 2757	 0.0	 0.0	 1	 -30.0	 30.0;
	2692	 8957	 0.00018	 0.000599	 0.0	 495.0	 50503	 50503	 0.0	 0.0	 1	 -30.0	 30.0;
	2692	 8861	 0.00018	 0.000591	 0.0	 400.0	 51129	 51129	 0.0	 0.0	 1	 -30.0	 30.0;
	2692	 1734	 0.00019	 0.000581	 0.0	 438.0	 51675	 51675	 0.0	 0.0	 1	 -30.0	 30.0;
	2692	 3266	 0.000169	 0.000651	 0.0	 495.0	 46965	 46965	 0.0	 0.0	 1	 -30.0	 30.0;
	322	 1974	 0.00231	 0.0138	 0.0	 457.0	 2258	 2258	 0.0	 0.0	 1	 -30.0	 30.0;
	322	 1974	 0.00082	 0.003841	 0.0	 8043	 8043	 8043	 0.0	 0.0	 1	 -30.0	 30.0;
	322	 177	 0.00305	 0.01762	 0.0	 495.0	 1767	 1767	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 5333	 0.01101	 0.055469	 0.0	 476.0	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 7901	 0.009169	 0.0462	 0.0	 533.0	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 7041	 0.00201	 0.00905	 0.0	 3408	 3408	 3408	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 2006	 0.005969	 0.038841	 0.0	 553.0	 804	 804	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 7761	 0.00474	 0.02687	 0.0	 438.0	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 5559	 0.005409	 0.03438	 0.0	 476.0	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 3211	 0.005401	 0.03264	 0.0	 572.0	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 8963	 0.00311	 0.015919	 0.0	 610.0	 1948	 1948	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 1770	 0.00462	 0.02613	 0.0	 419.0	 1191	 1191	 0.0	 0.0	 1	 -30.0	 30.0;
	3186	 1109	 0.01044	 0.05187	 0.0	 476.0	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	3186	 1109	 0.01001	 0.05113	 0.0	 476.0	 607	 607	 0.0	 0.0	 1	 -30.0	 30.0;
	3186	 8493	 0.008331	 0.051729	 0.0	 533.0	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	3186	 6280	 0.000169	 0.00089	 0.0	 438.0	 34869	 34869	 0.0	 0.0	 1	 -30.0	 30.0;
	3186	 3987	 0.00214	 0.01099	 0.0	 495.0	 2822	 2822	 0.0	 0.0	 1	 -30.0	 30.0;
	1974	 5825	 0.004669	 0.042349	 0.0	 476.0	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	1974	 7252	 0.00139	 0.008789	 0.0	 419.0	 3550	 3550	 0.0	 0.0	 1	 -30.0	 30.0;
	1974	 7252	 0.000219	 0.001669	 0.0	 495.0	 18766	 18766	 0.0	 0.0	 1	 -30.0	 30.0;
	1974	 177	 0.00119	 0.01063	 0.0	 2954	 2954	 2954	 0.0	 0.0	 1	 -30.0	 30.0;
	2410	 2006	 0.004169	 0.02724	 0.0	 514.0	 1147	 1147	 0.0	 0.0	 1	 -30.0	 30.0;
	2410	 2006	 0.004081	 0.025219	 0.0	 495.0	 1237	 1237	 0.0	 0.0	 1	 -30.0	 30.0;
	2410	 315	 0.00168	 0.01039	 0.0	 533.0	 3002	 3002	 0.0	 0.0	 1	 -30.0	 30.0;
	2410	 1489	 0.0017	 0.01055	 0.0	 495.0	 2956	 2956	 0.0	 0.0	 1	 -30.0	 30.0;
	8926	 5797	 0.00139	 0.008771	 0.0	 495.0	 3557	 3557	 0.0	 0.0	 1	 -30.0	 30.0;
	8926	 6381	 0.000651	 0.00261	 0.0	 476.0	 11743	 11743	 0.0	 0.0	 1	 -30.0	 30.0;
	8926	 6381	 0.000729	 0.00256	 0.0	 476.0	 11868	 11868	 0.0	 0.0	 1	 -30.0	 30.0;
	8926	 1239	 0.0	 0.008169	 0.0	 400.0	 3867	 3867	 0.0	 0.0	 1	 -30.0	 30.0;
	8926	 5643	 5e-05	 0.00025	 0.0	 438.0	 123896	 123896	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 7901	 0.003719	 0.022669	 0.0	 514.0	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 6415	 0.00732	 0.042711	 0.0	 476.0	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 6415	 0.003599	 0.025331	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 8998	 0.00494	 0.027401	 0.0	 533.0	 1135	 1135	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 6795	 0.0062	 0.03519	 0.0	 533.0	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 6795	 0.00739	 0.04574	 0.0	 438.0	 682	 682	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 3211	 0.006781	 0.034289	 0.0	 572.0	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	6795	 3054	 0.003669	 0.03205	 0.0	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	6795	 3054	 0.002789	 0.026289	 0.0	 1195	 1195	 1195	 0.0	 0.0	 1	 -30.0	 30.0;
	6795	 2562	 0.005979	 0.031979	 0.0	 533.0	 971	 971	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 6254	 0.00425	 0.02132	 0.0	 553.0	 1453	 1453	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 1543	 0.002469	 0.015099	 0.0	 2065	 2065	 2065	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 8957	 0.004341	 0.02662	 0.0	 514.0	 1172	 1172	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 3266	 0.005219	 0.02287	 0.0	 610.0	 1347	 1347	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 7615	 0.0095	 0.04693	 0.0	 495.0	 660	 660	 0.0	 0.0	 1	 -30.0	 30.0;
	5825	 177	 0.01099	 0.052909	 0.0	 457.0	 585	 585	 0.0	 0.0	 1	 -30.0	 30.0;
	5825	 6415	 0.004901	 0.02949	 0.0	 533.0	 1057	 1057	 0.0	 0.0	 1	 -30.0	 30.0;
	5825	 4744	 0.00832	 0.038531	 0.0	 457.0	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	5825	 5669	 0.003909	 0.018091	 0.0	 381.0	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	5825	 3416	 0.000331	 0.00189	 0.0	 476.0	 16463	 16463	 0.0	 0.0	 1	 -30.0	 30.0;
	7901	 6415	 0.01101	 0.05514	 0.0	 495.0	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	7901	 7503	 0.00345	 0.01925	 0.0	 457.0	 1616	 1616	 0.0	 0.0	 1	 -30.0	 30.0;
	8459	 177	 0.00162	 0.00889	 0.0	 3496	 3496	 3496	 0.0	 0.0	 1	 -30.0	 30.0;
	8459	 8998	 0.00039	 0.00464	 0.0	 6784	 6784	 6784	 0.0	 0.0	 1	 -30.0	 30.0;
	8459	 5361	 0.00064	 0.010099	 0.0	 3122	 3122	 3122	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 5797	 0.003151	 0.01613	 0.0	 572.0	 1922	 1922	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 5797	 0.002091	 0.012409	 0.0	 629.0	 2511	 2511	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 9136	 0.0	 0.00799	 0.0	 3954	 3954	 3954	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 4650	 0.0	 0.00906	 0.0	 3487	 3487	 3487	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 7037	 0.000909	 0.010401	 0.0	 3026	 3026	 3026	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 2497	 0.003211	 0.016081	 0.0	 591.0	 1927	 1927	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 8861	 0.00314	 0.017711	 0.0	 457.0	 1757	 1757	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 1734	 0.00214	 0.010591	 0.0	 476.0	 2924	 2924	 0.0	 0.0	 1	 -30.0	 30.0;
	3478	 3211	 0.00056	 0.003169	 0.0	 9816	 9816	 9816	 0.0	 0.0	 1	 -30.0	 30.0;
	7252	 7236	 0.001719	 0.0108	 0.0	 514.0	 2889	 2889	 0.0	 0.0	 1	 -30.0	 30.0;
	5797	 3954	 0.0005	 0.00174	 0.0	 514.0	 17448	 17448	 0.0	 0.0	 1	 -30.0	 30.0;
	5797	 5643	 0.00126	 0.00587	 0.0	 419.0	 5262	 5262	 0.0	 0.0	 1	 -30.0	 30.0;
	6960	 2562	 0.007909	 0.03607	 0.0	 533.0	 856	 856	 0.0	 0.0	 1	 -30.0	 30.0;
	6960	 7037	 0.00057	 0.00457	 0.0	 6859	 6859	 6859	 0.0	 0.0	 1	 -30.0	 30.0;
	6960	 5643	 0.00132	 0.008409	 0.0	 400.0	 3711	 3711	 0.0	 0.0	 1	 -30.0	 30.0;
	177	 2460	 0.003581	 0.017289	 0.0	 610.0	 1790	 1790	 0.0	 0.0	 1	 -30.0	 30.0;
	177	 4744	 0.002711	 0.01526	 0.0	 476.0	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	177	 6311	 0.00039	 0.006081	 0.0	 5184	 5184	 5184	 0.0	 0.0	 1	 -30.0	 30.0;
	177	 5361	 0.00037	 0.005409	 0.0	 5827	 5827	 5827	 0.0	 0.0	 1	 -30.0	 30.0;
	177	 7236	 0.00244	 0.013789	 0.0	 476.0	 2256	 2256	 0.0	 0.0	 1	 -30.0	 30.0;
	3954	 2497	 0.000349	 0.00149	 0.0	 533.0	 20641	 20641	 0.0	 0.0	 1	 -30.0	 30.0;
	2460	 6415	 0.00212	 0.010531	 0.0	 591.0	 2941	 2941	 0.0	 0.0	 1	 -30.0	 30.0;
	380	 5339	 0.003039	 0.031151	 0.0	 1010	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	380	 5669	 0.001831	 0.0187	 0.0	 1682	 1682	 1682	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 3932	 0.006599	 0.043169	 0.0	 438.0	 724	 724	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 5094	 0.006729	 0.046599	 0.0	 438.0	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 3623	 0.002159	 0.010789	 0.0	 476.0	 2871	 2871	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 785	 0.0022	 0.01057	 0.0	 476.0	 2926	 2926	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 1036	 0.003461	 0.02049	 0.0	 1521	 1521	 1521	 0.0	 0.0	 1	 -30.0	 30.0;
	8021	 698	 0.00311	 0.019469	 0.0	 495.0	 1603	 1603	 0.0	 0.0	 1	 -30.0	 30.0;
	8021	 628	 0.01064	 0.065969	 0.0	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	1109	 315	 0.003539	 0.020479	 0.0	 495.0	 1520	 1520	 0.0	 0.0	 1	 -30.0	 30.0;
	1109	 1489	 0.00357	 0.020719	 0.0	 495.0	 1503	 1503	 0.0	 0.0	 1	 -30.0	 30.0;
	1109	 3932	 0.00275	 0.013831	 0.0	 457.0	 2240	 2240	 0.0	 0.0	 1	 -30.0	 30.0;
	1109	 5094	 0.0028	 0.013531	 0.0	 457.0	 2287	 2287	 0.0	 0.0	 1	 -30.0	 30.0;
	6415	 5669	 0.005151	 0.04851	 0.0	 648	 648	 648	 0.0	 0.0	 1	 -30.0	 30.0;
	6415	 8493	 0.005401	 0.025281	 0.0	 533.0	 1222	 1222	 0.0	 0.0	 1	 -30.0	 30.0;
	6415	 8493	 0.0055	 0.02475	 0.0	 514.0	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	7503	 5559	 0.00093	 0.00538	 0.0	 438.0	 5786	 5786	 0.0	 0.0	 1	 -30.0	 30.0;
	7041	 2006	 0.010331	 0.061849	 0.0	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	4712	 3623	 0.00686	 0.032771	 0.0	 476.0	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	4712	 785	 0.007	 0.032081	 0.0	 476.0	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	5339	 4170	 0.007729	 0.038099	 0.0	 813	 813	 813	 0.0	 0.0	 1	 -30.0	 30.0;
	4170	 698	 0.006581	 0.035281	 0.0	 572.0	 881	 881	 0.0	 0.0	 1	 -30.0	 30.0;
	4170	 698	 0.003711	 0.02651	 0.0	 533.0	 1181	 1181	 0.0	 0.0	 1	 -30.0	 30.0;
	4170	 4333	 0.00482	 0.021979	 0.0	 572.0	 1404	 1404	 0.0	 0.0	 1	 -30.0	 30.0;
	4170	 4333	 0.003979	 0.026099	 0.0	 533.0	 1197	 1197	 0.0	 0.0	 1	 -30.0	 30.0;
	2006	 8963	 0.0038	 0.017271	 0.0	 553.0	 1787	 1787	 0.0	 0.0	 1	 -30.0	 30.0;
	2006	 7661	 0.00626	 0.03626	 0.0	 629.0	 859	 859	 0.0	 0.0	 1	 -30.0	 30.0;
	8493	 628	 0.00538	 0.02588	 0.0	 572.0	 1195	 1195	 0.0	 0.0	 1	 -30.0	 30.0;
	8493	 628	 0.005479	 0.025341	 0.0	 553.0	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	130	 3080	 0.00134	 0.01235	 0.0	 1218.0	 2543	 2543	 0.0	 0.0	 1	 -30.0	 30.0;
	130	 536	 0.00127	 0.01399	 0.0	 1349.0	 2249	 2249	 0.0	 0.0	 1	 -30.0	 30.0;
	130	 4393	 0.00142	 0.01374	 0.0	 1349.0	 2287	 2287	 0.0	 0.0	 1	 -30.0	 30.0;
	7827	 7969	 0.00039	 0.00365	 0.0	 1218.0	 8606	 8606	 0.0	 0.0	 1	 -30.0	 30.0;
	7827	 6760	 0.00058	 0.00507	 0.0	 1283.0	 6190	 6190	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 6298	 0.00129	 0.01577	 0.0	 1349.0	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 3007	 0.00033	 0.00373	 0.0	 1316.0	 8436	 8436	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 3265	 0.00086	 0.00799	 0.0	 1415.0	 3931	 3931	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 3265	 0.00189	 0.02135	 0.0	 1448.0	 1474	 1474	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 1774	 0.00106	 0.01219	 0.0	 1218.0	 2582	 2582	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 2899	 0.00147	 0.01622	 0.0	 1316.0	 1940	 1940	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 1703	 0.00215	 0.02108	 0.0	 1349.0	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	441	 8088	 0.00063	 0.0052	 0.0	 1382.0	 6031	 6031	 0.0	 0.0	 1	 -30.0	 30.0;
	441	 3265	 0.00159	 0.01792	 0.0	 1119.0	 1756	 1756	 0.0	 0.0	 1	 -30.0	 30.0;
	6298	 1774	 0.00157	 0.01981	 0.0	 1251.0	 1590	 1590	 0.0	 0.0	 1	 -30.0	 30.0;
	6298	 2899	 0.00158	 0.02014	 0.0	 1481.0	 1564	 1564	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 3080	 0.0018	 0.02388	 0.0	 1316.0	 1320	 1320	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 544	 0.00034	 0.00318	 0.0	 1349.0	 9877	 9877	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 7079	 0.00015	 0.00132	 0.0	 757.0	 23777	 23777	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 8601	 0.00014	 0.0015	 0.0	 757.0	 20968	 20968	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 1155	 0.00013	 0.00153	 0.0	 757.0	 20572	 20572	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 3256	 0.00013	 0.00156	 0.0	 757.0	 20179	 20179	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 5815	 0.0004	 0.00449	 0.0	 1283.0	 7008	 7008	 0.0	 0.0	 1	 -30.0	 30.0;
	8088	 5815	 0.00045	 0.0044	 0.0	 1152.0	 7142	 7142	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 1899	 0.0023	 0.01984	 0.0	 1185.0	 1582	 1582	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 9032	 0.0002	 0.00235	 0.0	 757.0	 13394	 13394	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 6004	 0.00019	 0.00239	 0.0	 757.0	 13175	 13175	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 7810	 0.00169	 0.01602	 0.0	 1316.0	 1961	 1961	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 8630	 0.00024	 0.00253	 0.0	 790.0	 12430	 12430	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 8183	 0.00022	 0.00244	 0.0	 757.0	 12894	 12894	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 6390	 0.00025	 0.00239	 0.0	 757.0	 13145	 13145	 0.0	 0.0	 1	 -30.0	 30.0;
	8224	 7969	 0.00066	 0.0061	 0.0	 1316.0	 5149	 5149	 0.0	 0.0	 1	 -30.0	 30.0;
	8224	 7969	 0.00062	 0.00844	 0.0	 1316.0	 3733	 3733	 0.0	 0.0	 1	 -30.0	 30.0;
	8224	 7860	 0.00124	 0.01353	 0.0	 1580.0	 2325	 2325	 0.0	 0.0	 1	 -30.0	 30.0;
	8224	 6187	 0.00046	 0.00452	 0.0	 1283.0	 6953	 6953	 0.0	 0.0	 1	 -30.0	 30.0;
	3007	 3265	 0.00045	 0.00531	 0.0	 1349.0	 5928	 5928	 0.0	 0.0	 1	 -30.0	 30.0;
	3007	 544	 0.00123	 0.01433	 0.0	 1152.0	 2197	 2197	 0.0	 0.0	 1	 -30.0	 30.0;
	3007	 7810	 0.00174	 0.01696	 0.0	 1448.0	 1853	 1853	 0.0	 0.0	 1	 -30.0	 30.0;
	4807	 6187	 0.00086	 0.00877	 0.0	 1382.0	 3585	 3585	 0.0	 0.0	 1	 -30.0	 30.0;
	4807	 6760	 0.00096	 0.00999	 0.0	 1218.0	 3148	 3148	 0.0	 0.0	 1	 -30.0	 30.0;
	4807	 4926	 0.00082	 0.00761	 0.0	 757.0	 4127	 4127	 0.0	 0.0	 1	 -30.0	 30.0;
	7969	 1703	 0.00185	 0.01803	 0.0	 1283.0	 1743	 1743	 0.0	 0.0	 1	 -30.0	 30.0;
	7969	 2031	 0.00138	 0.01246	 0.0	 1481.0	 2520	 2520	 0.0	 0.0	 1	 -30.0	 30.0;
	7969	 7980	 0.00062	 0.00605	 0.0	 1514.0	 5194	 5194	 0.0	 0.0	 1	 -30.0	 30.0;
	7969	 6760	 0.00073	 0.00817	 0.0	 757.0	 3851	 3851	 0.0	 0.0	 1	 -30.0	 30.0;
	536	 7509	 0.00094	 0.00999	 0.0	 1316.0	 3148	 3148	 0.0	 0.0	 1	 -30.0	 30.0;
	536	 3990	 0.00058	 0.00671	 0.0	 1218.0	 4691	 4691	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 1703	 0.00108	 0.01279	 0.0	 1349.0	 2461	 2461	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 7980	 0.00225	 0.02472	 0.0	 1273	 1273	 1273	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 4543	 0.00019	 0.00244	 0.0	 757.0	 12907	 12907	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 6340	 0.00018	 0.00248	 0.0	 757.0	 12704	 12704	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 261	 0.0001	 0.0011	 0.0	 757.0	 28598	 28598	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 2058	 0.00011	 0.00108	 0.0	 757.0	 29098	 29098	 0.0	 0.0	 1	 -30.0	 30.0;
	7860	 6187	 0.00089	 0.00815	 0.0	 1283.0	 3853	 3853	 0.0	 0.0	 1	 -30.0	 30.0;
	6080	 2899	 0.0009	 0.00859	 0.0	 1415.0	 3658	 3658	 0.0	 0.0	 1	 -30.0	 30.0;
	6080	 7509	 0.00167	 0.02239	 0.0	 1407	 1407	 1407	 0.0	 0.0	 1	 -30.0	 30.0;
	2899	 5263	 2e-05	 0.00024	 0.0	 757.0	 131160	 131160	 0.0	 0.0	 1	 -30.0	 30.0;
	1703	 138	 0.00157	 0.01326	 0.0	 1349.0	 2366	 2366	 0.0	 0.0	 1	 -30.0	 30.0;
	1899	 5562	 0.00155	 0.0139	 0.0	 1349.0	 2259	 2259	 0.0	 0.0	 1	 -30.0	 30.0;
	138	 2031	 0.00142	 0.01472	 0.0	 1349.0	 2136	 2136	 0.0	 0.0	 1	 -30.0	 30.0;
	4704	 2031	 0.00187	 0.02232	 0.0	 1411	 1411	 1411	 0.0	 0.0	 1	 -30.0	 30.0;
	4704	 1570	 0.00049	 0.00572	 0.0	 1349.0	 5503	 5503	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 1999	 0.0	 0.00021	 0.0	 757.0	 150416	 150416	 0.0	 0.0	 1	 -30.0	 30.0;
	7509	 3990	 0.00104	 0.00939	 0.0	 1349.0	 3344	 3344	 0.0	 0.0	 1	 -30.0	 30.0;
	7509	 7935	 0.00043	 0.0049	 0.0	 757.0	 6422	 6422	 0.0	 0.0	 1	 -30.0	 30.0;
	7509	 7935	 0.00049	 0.0048	 0.0	 757.0	 6547	 6547	 0.0	 0.0	 1	 -30.0	 30.0;
	39	 1174	 0.002009	 0.01464	 0.0	 2138	 2138	 2138	 0.0	 0.0	 1	 -30.0	 30.0;
	1174	 3711	 0.003302	 0.026	 0.0	 1206	 1206	 1206	 0.0	 0.0	 1	 -30.0	 30.0;
	389	 4259	 0.006222	 0.018089	 0.0	 1652	 1652	 1652	 0.0	 0.0	 1	 -30.0	 30.0;
	3711	 7411	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3711	 2894	 8.9e-05	 0.000911	 0.0	 34509	 34509	 34509	 0.0	 0.0	 1	 -30.0	 30.0;
	8771	 7792	 1.8e-05	 0.000222	 0.0	 141820	 141820	 141820	 0.0	 0.0	 1	 -30.0	 30.0;
	6459	 7411	 0.00388	 0.014289	 0.0	 286.0	 2134	 2134	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 610	 0.001329	 0.007898	 0.0	 3944	 3944	 3944	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 4577	 0.00048	 0.002951	 0.0	 10566	 10566	 10566	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 8007	 8e-05	 0.00032	 0.0	 95764	 95764	 95764	 0.0	 0.0	 1	 -30.0	 30.0;
	2853	 5331	 0.000302	 0.001102	 0.0	 27645	 27645	 27645	 0.0	 0.0	 1	 -30.0	 30.0;
	6512	 304	 0.003742	 0.013098	 0.0	 2319	 2319	 2319	 0.0	 0.0	 1	 -30.0	 30.0;
	7569	 6135	 0.008911	 0.032298	 0.0	 943	 943	 943	 0.0	 0.0	 1	 -30.0	 30.0;
	5927	 6540	 0.00124	 0.005409	 0.0	 5693	 5693	 5693	 0.0	 0.0	 1	 -30.0	 30.0;
	698	 7104	 0.0025	 0.0123	 0.0	 400.0	 2517	 2517	 0.0	 0.0	 1	 -30.0	 30.0;
	698	 7104	 0.001781	 0.013729	 0.0	 400.0	 2282	 2282	 0.0	 0.0	 1	 -30.0	 30.0;
	698	 4333	 0.00324	 0.016039	 0.0	 553.0	 1931	 1931	 0.0	 0.0	 1	 -30.0	 30.0;
	8998	 6311	 0.00037	 0.00474	 0.0	 6644	 6644	 6644	 0.0	 0.0	 1	 -30.0	 30.0;
	7761	 1770	 9.1e-05	 0.000521	 0.0	 419.0	 59725	 59725	 0.0	 0.0	 1	 -30.0	 30.0;
	6311	 5361	 3.1e-05	 0.00043	 0.0	 73269	 73269	 73269	 0.0	 0.0	 1	 -30.0	 30.0;
	1770	 7709	 0.001281	 0.005909	 0.0	 5225	 5225	 5225	 0.0	 0.0	 1	 -30.0	 30.0;
	1489	 5790	 0.000909	 0.00476	 0.0	 6519	 6519	 6519	 0.0	 0.0	 1	 -30.0	 30.0;
	5094	 5266	 0.00011	 0.000599	 0.0	 51867	 51867	 51867	 0.0	 0.0	 1	 -30.0	 30.0;
	3623	 7927	 0.000289	 0.001719	 0.0	 18122	 18122	 18122	 0.0	 0.0	 1	 -30.0	 30.0;
	7236	 4098	 0.00026	 0.001591	 0.0	 514.0	 19594	 19594	 0.0	 0.0	 1	 -30.0	 30.0;
	5815	 3990	 0.00108	 0.01382	 0.0	 1481.0	 2279	 2279	 0.0	 0.0	 1	 -30.0	 30.0;
	7329	 7661	 0.0	 0.0002	 0.0	 572.0	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	9024	 6542	 0.000742	 0.067219	 0.0	 470	 470	 470	 0.994359	 0.0	 1	 -30.0	 30.0;
	9024	 6542	 0.000793	 0.06388	 0.0	 495	 495	 495	 0.998418	 0.0	 1	 -30.0	 30.0;
	6069	 9192	 0.000609	 0.046809	 0.0	 675	 675	 675	 0.933053	 0.0	 1	 -30.0	 30.0;
	6069	 1968	 0.00059	 0.04521	 0.0	 691.0	 699	 699	 0.91223	 0.0	 1	 -30.0	 30.0;
	7829	 1968	 0.519194	 5.108058	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	8574	 2299	 0.000559	 0.039982	 0.0	 790	 790	 790	 0.919523	 0.0	 1	 -30.0	 30.0;
	8574	 5587	 0.000537	 0.045312	 0.0	 698	 698	 698	 0.948262	 0.0	 1	 -30.0	 30.0;
	4929	 1815	 0.000889	 0.061549	 0.0	 514	 514	 514	 0.996867	 0.0	 1	 -30.0	 30.0;
	1815	 792	 1.467822	 7.764888	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	6704	 4586	 0.000586	 0.049031	 0.0	 645	 645	 645	 0.923407	 0.0	 1	 -30.0	 30.0;
	2441	 3506	 0.000417	 0.047801	 0.0	 658.0	 661	 661	 0.952413	 0.0	 1	 -30.0	 30.0;
	1367	 6826	 0.000755	 0.05143	 0.0	 615	 615	 615	 0.924009	 0.0	 1	 -30.0	 30.0;
	1676	 228	 0.000733	 0.052399	 0.0	 603	 603	 603	 0.934986	 0.0	 1	 -30.0	 30.0;
	7829	 6826	 0.00078	 0.064311	 0.0	 492	 492	 492	 1.0	 0.0	 1	 -30.0	 30.0;
	659	 3279	 0.00089	 0.048632	 0.0	 650	 650	 650	 0.987002	 0.0	 1	 -30.0	 30.0;
	5210	 792	 0.00855	 0.08972	 0.0	 351	 351	 351	 1.0	 0.0	 1	 -30.0	 30.0;
	1445	 792	 0.00223	 0.04836	 0.0	 653	 653	 653	 1.0	 0.0	 1	 -30.0	 30.0;
	7180	 2168	 0.000581	 0.043111	 0.0	 658.0	 733	 733	 0.924038	 0.0	 1	 -30.0	 30.0;
	6833	 8964	 0.000579	 0.043272	 0.0	 691.0	 730	 730	 0.901005	 0.0	 1	 -30.0	 30.0;
	3659	 3242	 0.000586	 0.049031	 0.0	 645	 645	 645	 0.923407	 0.0	 1	 -30.0	 30.0;
	8181	 4427	 0.000559	 0.049192	 0.0	 643	 643	 643	 0.924009	 0.0	 1	 -30.0	 30.0;
	9025	 7563	 0.000573	 0.051129	 0.0	 618	 618	 618	 0.934986	 0.0	 1	 -30.0	 30.0;
	2267	 5210	 0.000417	 0.039229	 0.0	 724.0	 806	 806	 0.967059	 0.0	 1	 -30.0	 30.0;
	5210	 7279	 0.230542	 1.197733	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	5210	 8335	 0.02284	 0.2644	 0.0	 120	 120	 120	 1.0	 0.0	 1	 -30.0	 30.0;
	5210	 2449	 0.08537	 0.736798	 0.0	 43	 43	 43	 1.0	 0.0	 1	 -30.0	 30.0;
	5210	 4665	 1.402768	 3.640289	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	5210	 4495	 1.050227	 4.450207	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	8179	 7279	 0.000716	 0.04371	 0.0	 723	 723	 723	 0.934986	 0.0	 1	 -30.0	 30.0;
	1445	 7279	 0.518622	 2.317689	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	5509	 8335	 0.00059	 0.045662	 0.0	 692	 692	 692	 0.955958	 0.0	 1	 -30.0	 30.0;
	5509	 1531	 0.000603	 0.050959	 0.0	 620	 620	 620	 0.968125	 0.0	 1	 -30.0	 30.0;
	1445	 8335	 0.047769	 0.554178	 0.0	 57	 57	 57	 1.0	 0.0	 1	 -30.0	 30.0;
	7762	 5155	 0.000591	 0.045153	 0.0	 700	 700	 700	 0.918868	 0.0	 1	 -30.0	 30.0;
	7762	 271	 0.0006	 0.047778	 0.0	 662	 662	 662	 0.948976	 0.0	 1	 -30.0	 30.0;
	7829	 5776	 0.02436	 0.270151	 0.0	 117	 117	 117	 1.0	 0.0	 1	 -30.0	 30.0;
	8329	 1445	 0.000802	 0.05727	 0.0	 552	 552	 552	 0.967021	 0.0	 1	 -30.0	 30.0;
	8329	 1445	 0.000823	 0.056059	 0.0	 564	 564	 564	 0.967021	 0.0	 1	 -30.0	 30.0;
	1445	 2449	 0.188099	 1.291901	 0.0	 25	 25	 25	 1.0	 0.0	 1	 -30.0	 30.0;
	1445	 4665	 2.466323	 7.26343	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	2268	 2908	 0.000523	 0.050352	 0.0	 628	 628	 628	 0.934622	 0.0	 1	 -30.0	 30.0;
	8847	 5776	 0.000682	 0.049638	 0.0	 637	 637	 637	 0.913034	 0.0	 1	 -30.0	 30.0;
	8847	 8103	 0.00099	 0.04736	 0.0	 667	 667	 667	 1.012146	 0.0	 1	 -30.0	 30.0;
	317	 2449	 0.000616	 0.048759	 0.0	 648	 648	 648	 0.933053	 0.0	 1	 -30.0	 30.0;
	7637	 8581	 9e-05	 0.015499	 0.0	 1678.0	 2038	 2038	 1.0	 -0.428189	 1	 -30.0	 30.0;
	5848	 7526	 9e-05	 0.00963	 0.0	 1678.0	 3280	 3280	 1.0	 0.178581	 1	 -30.0	 30.0;
	89	 4495	 0.000664	 0.045609	 0.0	 693	 693	 693	 0.924009	 0.0	 1	 -30.0	 30.0;
	2520	 4665	 0.000649	 0.044862	 0.0	 691.0	 705	 705	 0.933053	 0.0	 1	 -30.0	 30.0;
	5996	 8420	 0.00067	 0.04326	 0.0	 724.0	 731	 731	 0.923407	 0.0	 1	 -30.0	 30.0;
	2154	 5996	 9e-05	 0.009901	 0.0	 1678.0	 3191	 3191	 1.0	 -0.153178	 1	 -30.0	 30.0;
	4241	 2248	 0.000214	 0.018189	 0.0	 691.0	 1737	 1737	 0.997518	 0.0	 1	 -30.0	 30.0;
	4717	 5787	 0.000545	 0.028951	 0.0	 1091	 1091	 1091	 1.002304	 0.0	 1	 -30.0	 30.0;
	5425	 7431	 0.000433	 0.016641	 0.0	 691.0	 1898	 1898	 1.052632	 0.0	 1	 -30.0	 30.0;
	5425	 7431	 0.000271	 0.019483	 0.0	 691.0	 1622	 1622	 1.046093	 0.0	 1	 -30.0	 30.0;
	6632	 3650	 0.000292	 0.041885	 0.0	 755	 755	 755	 1.035986	 0.0	 1	 -30.0	 30.0;
	6632	 3650	 0.000283	 0.025435	 0.0	 1242	 1242	 1242	 1.035986	 0.0	 1	 -30.0	 30.0;
	6917	 4958	 0.00019	 0.020772	 0.0	 691.0	 1521	 1521	 1.016388	 0.0	 1	 -30.0	 30.0;
	2962	 8888	 0.000567	 0.0487	 0.0	 649	 649	 649	 1.01961	 0.0	 1	 -30.0	 30.0;
	2962	 8888	 0.000292	 0.024683	 0.0	 1280	 1280	 1280	 1.026095	 0.0	 1	 -30.0	 30.0;
	4542	 7510	 0.000238	 0.020505	 0.0	 691.0	 1541	 1541	 1.016388	 0.0	 1	 -30.0	 30.0;
	4542	 7510	 0.000302	 0.024253	 0.0	 1303	 1303	 1303	 1.016399	 0.0	 1	 -30.0	 30.0;
	1549	 3282	 0.000394	 0.025662	 0.0	 1231	 1231	 1231	 0.997518	 0.0	 1	 -30.0	 30.0;
	1549	 3282	 0.000403	 0.026263	 0.0	 1203	 1203	 1203	 0.997518	 0.0	 1	 -30.0	 30.0;
	1549	 3282	 0.000358	 0.02845	 0.0	 1111	 1111	 1111	 0.997518	 0.0	 1	 -30.0	 30.0;
	1200	 3549	 0.000184	 0.020004	 0.0	 691.0	 1579	 1579	 1.016388	 0.0	 1	 -30.0	 30.0;
	6771	 4806	 0.000287	 0.030676	 0.0	 1030	 1030	 1030	 1.026104	 0.0	 1	 -30.0	 30.0;
	1086	 6443	 0.000183	 0.021447	 0.0	 691.0	 1473	 1473	 0.997518	 0.0	 1	 -30.0	 30.0;
	1086	 6443	 0.000183	 0.019858	 0.0	 691.0	 1591	 1591	 0.997518	 0.0	 1	 -30.0	 30.0;
	9159	 6499	 0.000196	 0.019264	 0.0	 691.0	 1640	 1640	 0.997518	 0.0	 1	 -30.0	 30.0;
	9159	 6499	 0.000205	 0.018521	 0.0	 691.0	 1706	 1706	 0.997518	 0.0	 1	 -30.0	 30.0;
	5685	 3378	 0.000205	 0.018131	 0.0	 691.0	 1743	 1743	 0.997518	 0.0	 1	 -30.0	 30.0;
	693	 6994	 0.000224	 0.01875	 0.0	 691.0	 1685	 1685	 1.035986	 0.0	 1	 -30.0	 30.0;
	693	 6994	 0.000685	 0.016451	 0.0	 691.0	 1919	 1919	 1.032682	 0.0	 1	 -30.0	 30.0;
	5332	 3633	 0.00021	 0.024641	 0.0	 691.0	 1282	 1282	 0.961805	 0.0	 1	 -30.0	 30.0;
	5332	 3633	 0.00021	 0.025112	 0.0	 691.0	 1258	 1258	 0.961805	 0.0	 1	 -30.0	 30.0;
	8034	 4020	 0.0	 0.00554	 0.0	 1514.0	 5702	 5702	 0.0	 0.0	 1	 -30.0	 30.0;
	1985	 1023	 0.0	 0.006182	 0.0	 895.0	 5110	 5110	 0.969385	 0.248079	 1	 -30.0	 30.0;
	477	 6769	 0.000205	 0.016639	 0.0	 691.0	 1899	 1899	 0.997518	 0.0	 1	 -30.0	 30.0;
	477	 6769	 0.000214	 0.017035	 0.0	 691.0	 1855	 1855	 0.997518	 0.0	 1	 -30.0	 30.0;
	477	 6769	 0.000214	 0.016674	 0.0	 691.0	 1895	 1895	 0.997518	 0.0	 1	 -30.0	 30.0;
	2188	 5170	 0.000224	 0.018397	 0.0	 691.0	 1717	 1717	 1.016388	 0.0	 1	 -30.0	 30.0;
	3061	 699	 0.000522	 0.027299	 0.0	 1157	 1157	 1157	 1.006865	 0.0	 1	 -30.0	 30.0;
	3061	 699	 0.000646	 0.037462	 0.0	 844	 844	 844	 0.997538	 0.0	 1	 -30.0	 30.0;
	5823	 7110	 0.000244	 0.033945	 0.0	 931	 931	 931	 1.052632	 0.0	 1	 -30.0	 30.0;
	5823	 7110	 0.000196	 0.023262	 0.0	 691.0	 1358	 1358	 1.035986	 0.0	 1	 -30.0	 30.0;
	5280	 7110	 0.00091	 0.001761	 0.0	 457.0	 15936	 15936	 0.99993	 -0.01179	 1	 -30.0	 30.0;
	1947	 4317	 0.000179	 0.016955	 0.0	 691.0	 1863	 1863	 1.056356	 0.0	 1	 -30.0	 30.0;
	7303	 429	 0.000206	 0.01883	 0.0	 691.0	 1678	 1678	 1.016388	 0.0	 1	 -30.0	 30.0;
	6039	 7973	 0.000233	 0.018474	 0.0	 691.0	 1710	 1710	 1.006865	 0.0	 1	 -30.0	 30.0;
	6039	 7973	 0.000421	 0.031827	 0.0	 993	 993	 993	 1.014604	 0.0	 1	 -30.0	 30.0;
	1060	 8981	 0.000219	 0.016973	 0.0	 691.0	 1861	 1861	 1.026095	 0.0	 1	 -30.0	 30.0;
	8034	 1752	 0.000213	 0.020004	 0.0	 691.0	 1579	 1579	 0.997518	 0.0	 1	 -30.0	 30.0;
	739	 1393	 0.000556	 0.033053	 0.0	 956	 956	 956	 0.998185	 0.0	 1	 -30.0	 30.0;
	2235	 8512	 0.000508	 0.028375	 0.0	 1114	 1114	 1114	 0.998185	 0.0	 1	 -30.0	 30.0;
	3428	 1439	 0.000179	 0.022003	 0.0	 691.0	 1436	 1436	 1.006865	 0.0	 1	 -30.0	 30.0;
	2730	 6127	 0.000209	 0.02019	 0.0	 691.0	 1565	 1565	 0.970491	 0.0	 1	 -30.0	 30.0;
	2730	 6127	 0.000214	 0.020311	 0.0	 691.0	 1556	 1556	 0.970491	 0.0	 1	 -30.0	 30.0;
	7395	 5435	 0.000616	 0.030505	 0.0	 1036	 1036	 1036	 0.991996	 0.0	 1	 -30.0	 30.0;
	7395	 5435	 0.000626	 0.029369	 0.0	 1076	 1076	 1076	 0.991996	 0.0	 1	 -30.0	 30.0;
	2437	 3792	 0.000214	 0.019409	 0.0	 691.0	 1628	 1628	 0.988343	 0.0	 1	 -30.0	 30.0;
	2437	 3792	 0.000192	 0.022	 0.0	 691.0	 1436	 1436	 0.979336	 0.0	 1	 -30.0	 30.0;
	5239	 8438	 0.000531	 0.03466	 0.0	 912	 912	 912	 0.991996	 0.0	 1	 -30.0	 30.0;
	5873	 8147	 0.000531	 0.035228	 0.0	 897	 897	 897	 0.99508	 0.0	 1	 -30.0	 30.0;
	5873	 8147	 0.00049	 0.031535	 0.0	 1002	 1002	 1002	 0.995061	 0.0	 1	 -30.0	 30.0;
	5873	 8147	 0.000209	 0.020964	 0.0	 691.0	 1507	 1507	 0.988343	 0.0	 1	 -30.0	 30.0;
	7508	 1240	 0.000393	 0.02663	 0.0	 1187	 1187	 1187	 1.035986	 0.0	 1	 -30.0	 30.0;
	7508	 1240	 0.000402	 0.026088	 0.0	 1211	 1211	 1211	 1.035986	 0.0	 1	 -30.0	 30.0;
	3268	 6397	 0.000201	 0.017787	 0.0	 691.0	 1776	 1776	 1.006865	 0.0	 1	 -30.0	 30.0;
	4290	 797	 0.000289	 0.018121	 0.0	 691.0	 1743	 1743	 1.033257	 0.0	 1	 -30.0	 30.0;
	7929	 4592	 0.000643	 0.024464	 0.0	 1291	 1291	 1291	 1.066843	 0.0	 1	 -30.0	 30.0;
	7929	 4592	 0.000568	 0.027771	 0.0	 1138	 1138	 1138	 1.066843	 0.0	 1	 -30.0	 30.0;
	849	 3840	 0.000506	 0.031833	 0.0	 993	 993	 993	 0.998185	 0.0	 1	 -30.0	 30.0;
	849	 3840	 0.000196	 0.024118	 0.0	 691.0	 1310	 1310	 0.997518	 0.0	 1	 -30.0	 30.0;
	5919	 8871	 0.000205	 0.022593	 0.0	 691.0	 1399	 1399	 0.997518	 0.0	 1	 -30.0	 30.0;
	5919	 8871	 0.000186	 0.01968	 0.0	 691.0	 1605	 1605	 0.997518	 0.0	 1	 -30.0	 30.0;
	5919	 8871	 0.000205	 0.01997	 0.0	 691.0	 1582	 1582	 0.997518	 0.0	 1	 -30.0	 30.0;
	1168	 2686	 0.000215	 0.018787	 0.0	 691.0	 1682	 1682	 1.016388	 0.0	 1	 -30.0	 30.0;
	1168	 2686	 0.000215	 0.018388	 0.0	 691.0	 1718	 1718	 1.016388	 0.0	 1	 -30.0	 30.0;
	3275	 6243	 0.000224	 0.018834	 0.0	 691.0	 1678	 1678	 0.997518	 0.0	 1	 -30.0	 30.0;
	3798	 1121	 0.000433	 0.043546	 0.0	 726	 726	 726	 1.052632	 0.0	 1	 -30.0	 30.0;
	5884	 8207	 0.000234	 0.018757	 0.0	 691.0	 1684	 1684	 0.996896	 0.0	 1	 -30.0	 30.0;
	5884	 8207	 0.000197	 0.019207	 0.0	 691.0	 1645	 1645	 0.991986	 0.0	 1	 -30.0	 30.0;
	5884	 8207	 0.000197	 0.019495	 0.0	 691.0	 1621	 1621	 0.991986	 0.0	 1	 -30.0	 30.0;
	6681	 7819	 0.00018	 0.021226	 0.0	 691.0	 1489	 1489	 1.046093	 0.0	 1	 -30.0	 30.0;
	6681	 7819	 0.000812	 0.03849	 0.0	 821	 821	 821	 1.046093	 0.0	 1	 -30.0	 30.0;
	2261	 4204	 0.000205	 0.02035	 0.0	 691.0	 1553	 1553	 1.056356	 0.0	 1	 -30.0	 30.0;
	731	 3728	 0.000593	 0.031521	 0.0	 1002	 1002	 1002	 1.001309	 0.0	 1	 -30.0	 30.0;
	731	 3728	 0.000612	 0.031123	 0.0	 1015	 1015	 1015	 1.001309	 0.0	 1	 -30.0	 30.0;
	731	 3728	 0.000427	 0.024994	 0.0	 1264	 1264	 1264	 1.006865	 0.0	 1	 -30.0	 30.0;
	2764	 415	 0.000667	 0.027207	 0.0	 1161	 1161	 1161	 1.026095	 0.0	 1	 -30.0	 30.0;
	2764	 415	 0.000621	 0.030836	 0.0	 1025	 1025	 1025	 1.026095	 0.0	 1	 -30.0	 30.0;
	299	 947	 0.000192	 0.020791	 0.0	 691.0	 1520	 1520	 1.066843	 0.0	 1	 -30.0	 30.0;
	299	 947	 0.000192	 0.02119	 0.0	 691.0	 1491	 1491	 1.066843	 0.0	 1	 -30.0	 30.0;
	8806	 32	 0.000686	 0.030987	 0.0	 1020	 1020	 1020	 1.026958	 0.0	 1	 -30.0	 30.0;
	3008	 5670	 0.000194	 0.020764	 0.0	 691.0	 1522	 1522	 0.988343	 0.0	 1	 -30.0	 30.0;
	179	 1850	 0.000717	 0.038087	 0.0	 830	 830	 830	 1.035986	 0.0	 1	 -30.0	 30.0;
	7918	 6660	 0.000206	 0.01883	 0.0	 691.0	 1678	 1678	 1.016388	 0.0	 1	 -30.0	 30.0;
	7918	 77	 0.000206	 0.018439	 0.0	 691.0	 1713	 1713	 1.016388	 0.0	 1	 -30.0	 30.0;
	7029	 33	 0.000219	 0.017019	 0.0	 691.0	 1856	 1856	 1.035986	 0.0	 1	 -30.0	 30.0;
	7029	 33	 0.000224	 0.016641	 0.0	 691.0	 1898	 1898	 1.035986	 0.0	 1	 -30.0	 30.0;
	6607	 9039	 0.000676	 0.047085	 0.0	 671	 671	 671	 1.026095	 0.0	 1	 -30.0	 30.0;
	6607	 9039	 0.000667	 0.048014	 0.0	 658	 658	 658	 1.016388	 0.0	 1	 -30.0	 30.0;
	7343	 8338	 0.000196	 0.019215	 0.0	 691.0	 1644	 1644	 0.997518	 0.0	 1	 -30.0	 30.0;
	3966	 5890	 0.000253	 0.025528	 0.0	 1238	 1238	 1238	 1.011609	 0.0	 1	 -30.0	 30.0;
	8210	 6936	 0.00021	 0.017884	 0.0	 691.0	 1767	 1767	 1.016388	 0.0	 1	 -30.0	 30.0;
	8210	 6936	 0.00021	 0.017518	 0.0	 691.0	 1804	 1804	 1.016388	 0.0	 1	 -30.0	 30.0;
	1716	 6544	 0.000219	 0.017358	 0.0	 691.0	 1820	 1820	 1.006865	 0.0	 1	 -30.0	 30.0;
	1716	 6544	 0.000219	 0.016973	 0.0	 691.0	 1861	 1861	 1.006865	 0.0	 1	 -30.0	 30.0;
	3544	 869	 0.000295	 0.027995	 0.0	 1129	 1129	 1129	 1.021673	 0.0	 1	 -30.0	 30.0;
	3544	 869	 0.000277	 0.027486	 0.0	 1150	 1150	 1150	 1.026115	 0.0	 1	 -30.0	 30.0;
	3662	 8242	 0.000489	 0.032074	 0.0	 985	 985	 985	 0.998185	 0.0	 1	 -30.0	 30.0;
	6092	 3109	 0.00018	 0.02129	 0.0	 691.0	 1484	 1484	 1.020734	 0.0	 1	 -30.0	 30.0;
	1074	 1769	 0.000366	 0.029147	 0.0	 1084	 1084	 1084	 1.000611	 0.0	 1	 -30.0	 30.0;
	1074	 1769	 0.000366	 0.028067	 0.0	 1126	 1126	 1126	 1.002235	 0.0	 1	 -30.0	 30.0;
	1074	 1769	 0.00042	 0.026331	 0.0	 1200	 1200	 1200	 1.000611	 0.0	 1	 -30.0	 30.0;
	4957	 1513	 0.000441	 0.01916	 0.0	 691.0	 1649	 1649	 1.012394	 0.0	 1	 -30.0	 30.0;
	7428	 6134	 0.000391	 0.024766	 0.0	 1276	 1276	 1276	 0.988343	 0.0	 1	 -30.0	 30.0;
	7428	 6134	 0.000401	 0.024225	 0.0	 1304	 1304	 1304	 0.997518	 0.0	 1	 -30.0	 30.0;
	7428	 4651	 0.000408	 0.028237	 0.0	 1119	 1119	 1119	 1.006865	 0.0	 1	 -30.0	 30.0;
	6970	 4632	 0.000199	 0.018609	 0.0	 691.0	 1698	 1698	 0.997518	 0.0	 1	 -30.0	 30.0;
	2700	 8953	 0.000196	 0.021597	 0.0	 691.0	 1463	 1463	 0.997518	 0.0	 1	 -30.0	 30.0;
	2700	 8953	 0.000186	 0.022003	 0.0	 691.0	 1436	 1436	 0.997518	 0.0	 1	 -30.0	 30.0;
	2849	 3291	 0.000186	 0.019718	 0.0	 691.0	 1602	 1602	 1.006865	 0.0	 1	 -30.0	 30.0;
	4446	 1457	 0.000205	 0.022703	 0.0	 691.0	 1392	 1392	 1.016388	 0.0	 1	 -30.0	 30.0;
	814	 7820	 0.000228	 0.021908	 0.0	 691.0	 1442	 1442	 0.988343	 0.0	 1	 -30.0	 30.0;
	7436	 7629	 0.000322	 0.028734	 0.0	 1100	 1100	 1100	 0.996603	 0.0	 1	 -30.0	 30.0;
	7436	 9106	 0.000319	 0.026574	 0.0	 1189	 1189	 1189	 1.042861	 0.0	 1	 -30.0	 30.0;
	3587	 1241	 0.000289	 0.018298	 0.0	 691.0	 1727	 1727	 1.046093	 0.0	 1	 -30.0	 30.0;
	3587	 1241	 0.000199	 0.02111	 0.0	 691.0	 1497	 1497	 1.046093	 0.0	 1	 -30.0	 30.0;
	7688	 8301	 0.000196	 0.02119	 0.0	 691.0	 1491	 1491	 1.016388	 0.0	 1	 -30.0	 30.0;
	7688	 8301	 0.000196	 0.021597	 0.0	 691.0	 1463	 1463	 1.016388	 0.0	 1	 -30.0	 30.0;
	4507	 1503	 0.001097	 0.082091	 0.0	 385	 385	 385	 1.006865	 0.0	 1	 -30.0	 30.0;
	4507	 1503	 0.000406	 0.048834	 0.0	 647	 647	 647	 1.033257	 0.0	 1	 -30.0	 30.0;
	4507	 1503	 7.2e-05	 0.017798	 0.0	 691.0	 1775	 1775	 0.988343	 0.0	 1	 -30.0	 30.0;
	4507	 1503	 0.000424	 0.04684	 0.0	 675	 675	 675	 1.033257	 0.0	 1	 -30.0	 30.0;
	8260	 4081	 0.000224	 0.01875	 0.0	 691.0	 1685	 1685	 1.006865	 0.0	 1	 -30.0	 30.0;
	8260	 4081	 0.000224	 0.018334	 0.0	 691.0	 1723	 1723	 1.006865	 0.0	 1	 -30.0	 30.0;
	1280	 4279	 0.000379	 0.018493	 0.0	 691.0	 1708	 1708	 1.046093	 0.0	 1	 -30.0	 30.0;
	1280	 4279	 0.000253	 0.019711	 0.0	 691.0	 1603	 1603	 1.046093	 0.0	 1	 -30.0	 30.0;
	385	 9028	 0.000196	 0.016483	 0.0	 1053.0	 1917	 1917	 0.997518	 0.0	 1	 -30.0	 30.0;
	385	 9028	 0.000186	 0.022421	 0.0	 691.0	 1409	 1409	 0.997518	 0.0	 1	 -30.0	 30.0;
	6768	 4096	 0.00046	 0.030794	 0.0	 1026	 1026	 1026	 1.002506	 0.0	 1	 -30.0	 30.0;
	9203	 2426	 0.000695	 0.049098	 0.0	 644	 644	 644	 0.982143	 0.0	 1	 -30.0	 30.0;
	9203	 2426	 0.000355	 0.024893	 0.0	 691.0	 1269	 1269	 0.93617	 0.0	 1	 -30.0	 30.0;
	118	 2426	 0.000365	 0.024372	 0.0	 691.0	 1296	 1296	 0.979227	 0.0	 1	 -30.0	 30.0;
	3145	 7770	 0.000411	 0.023652	 0.0	 691.0	 1336	 1336	 0.93617	 0.0	 1	 -30.0	 30.0;
	7267	 4918	 0.000386	 0.025673	 0.0	 691.0	 1231	 1231	 0.93617	 0.0	 1	 -30.0	 30.0;
	7267	 4918	 0.000344	 0.029336	 0.0	 691.0	 1077	 1077	 0.93617	 0.0	 1	 -30.0	 30.0;
	839	 4506	 0.000653	 0.052104	 0.0	 607	 607	 607	 0.982143	 0.0	 1	 -30.0	 30.0;
	839	 4506	 0.000767	 0.043531	 0.0	 726	 726	 726	 0.982143	 0.0	 1	 -30.0	 30.0;
	3445	 6114	 0.000323	 0.028314	 0.0	 691.0	 1116	 1116	 0.93617	 0.0	 1	 -30.0	 30.0;
	3445	 6114	 0.000323	 0.025999	 0.0	 691.0	 1215	 1215	 0.93617	 0.0	 1	 -30.0	 30.0;
	3445	 7264	 0.000365	 0.025478	 0.0	 691.0	 1240	 1240	 0.93617	 0.0	 1	 -30.0	 30.0;
	891	 6306	 0.00086	 0.039291	 0.0	 804	 804	 804	 0.982143	 0.0	 1	 -30.0	 30.0;
	720	 1711	 0.000355	 0.026586	 0.0	 691.0	 1189	 1189	 0.93617	 0.0	 1	 -30.0	 30.0;
	720	 1711	 0.000375	 0.026313	 0.0	 691.0	 1201	 1201	 0.93617	 0.0	 1	 -30.0	 30.0;
	6206	 3240	 0.000344	 0.023329	 0.0	 691.0	 1354	 1354	 0.979227	 0.0	 1	 -30.0	 30.0;
	6206	 3240	 0.000302	 0.026375	 0.0	 691.0	 1198	 1198	 0.979227	 0.0	 1	 -30.0	 30.0;
	9174	 2924	 0.000788	 0.04323	 0.0	 731	 731	 731	 0.982143	 0.0	 1	 -30.0	 30.0;
	9174	 2924	 0.000767	 0.04407	 0.0	 717	 717	 717	 0.982143	 0.0	 1	 -30.0	 30.0;
	1355	 5856	 0.000767	 0.043562	 0.0	 725	 725	 725	 0.982143	 0.0	 1	 -30.0	 30.0;
	1355	 5856	 0.000788	 0.041281	 0.0	 766	 766	 766	 0.982143	 0.0	 1	 -30.0	 30.0;
	1355	 5856	 0.000892	 0.040524	 0.0	 780	 780	 780	 0.982143	 0.0	 1	 -30.0	 30.0;
	3205	 4683	 0.000975	 0.043562	 0.0	 725	 725	 725	 0.982143	 0.0	 1	 -30.0	 30.0;
	3205	 4683	 0.000757	 0.042649	 0.0	 741	 741	 741	 0.982143	 0.0	 1	 -30.0	 30.0;
	5350	 2361	 0.000261	 0.030762	 0.0	 691.0	 1027	 1027	 0.93617	 0.0	 1	 -30.0	 30.0;
	5350	 2361	 0.000261	 0.030088	 0.0	 691.0	 1050	 1050	 0.93617	 0.0	 1	 -30.0	 30.0;
	5016	 6112	 0.000323	 0.026447	 0.0	 691.0	 1195	 1195	 0.979227	 0.0	 1	 -30.0	 30.0;
	5016	 8860	 0.000323	 0.026885	 0.0	 691.0	 1175	 1175	 0.979227	 0.0	 1	 -30.0	 30.0;
	7471	 549	 0.000323	 0.02748	 0.0	 691.0	 1150	 1150	 0.93617	 0.0	 1	 -30.0	 30.0;
	7471	 549	 0.000292	 0.028158	 0.0	 691.0	 1122	 1122	 0.93617	 0.0	 1	 -30.0	 30.0;
	549	 5002	 0.0	 0.009197	 0.0	 667.0	 3435	 3435	 1.0	 0.072386	 1	 -30.0	 30.0;
	5490	 3817	 0.000736	 0.044526	 0.0	 710	 710	 710	 0.982143	 0.0	 1	 -30.0	 30.0;
	2854	 9112	 0.00086	 0.039488	 0.0	 800	 800	 800	 0.982143	 0.0	 1	 -30.0	 30.0;
	2918	 6532	 0.000365	 0.024372	 0.0	 691.0	 1296	 1296	 0.93617	 0.0	 1	 -30.0	 30.0;
	2918	 6532	 0.000375	 0.023986	 0.0	 691.0	 1317	 1317	 0.93617	 0.0	 1	 -30.0	 30.0;
	4494	 7284	 0.000386	 0.025673	 0.0	 691.0	 1231	 1231	 0.93617	 0.0	 1	 -30.0	 30.0;
	2656	 1775	 0.000809	 0.042318	 0.0	 747	 747	 747	 0.982143	 0.0	 1	 -30.0	 30.0;
	3519	 5641	 0.000705	 0.042038	 0.0	 752	 752	 752	 0.982143	 0.0	 1	 -30.0	 30.0;
	3543	 367	 0.000334	 0.028022	 0.0	 691.0	 1128	 1128	 0.93617	 0.0	 1	 -30.0	 30.0;
	3543	 1833	 0.000353	 0.022403	 0.0	 691.0	 1410	 1410	 0.982143	 0.0	 1	 -30.0	 30.0;
	2372	 367	 0.000313	 0.026354	 0.0	 691.0	 1199	 1199	 0.93617	 0.0	 1	 -30.0	 30.0;
	2372	 367	 0.000323	 0.025478	 0.0	 691.0	 1240	 1240	 0.93617	 0.0	 1	 -30.0	 30.0;
	1876	 7752	 0.000344	 0.024622	 0.0	 691.0	 1283	 1283	 0.979227	 0.0	 1	 -30.0	 30.0;
	113	 7752	 0.000355	 0.024038	 0.0	 691.0	 1314	 1314	 0.979227	 0.0	 1	 -30.0	 30.0;
	3499	 7289	 0.000881	 0.038244	 0.0	 826	 826	 826	 0.982143	 0.0	 1	 -30.0	 30.0;
	3499	 7289	 0.000757	 0.040959	 0.0	 772	 772	 772	 0.982143	 0.0	 1	 -30.0	 30.0;
	3082	 2083	 0.000354	 0.028765	 0.0	 691.0	 1099	 1099	 0.93617	 0.0	 1	 -30.0	 30.0;
	6224	 2083	 0.000354	 0.027114	 0.0	 691.0	 1165	 1165	 0.93617	 0.0	 1	 -30.0	 30.0;
	2174	 2083	 0.000695	 0.04748	 0.0	 666	 666	 666	 0.982143	 0.0	 1	 -30.0	 30.0;
	4623	 1609	 0.000323	 0.028314	 0.0	 691.0	 1116	 1116	 0.93617	 0.0	 1	 -30.0	 30.0;
	4623	 1609	 0.000323	 0.026354	 0.0	 691.0	 1199	 1199	 0.93617	 0.0	 1	 -30.0	 30.0;
	4623	 1609	 0.000323	 0.025696	 0.0	 691.0	 1230	 1230	 0.93617	 0.0	 1	 -30.0	 30.0;
	5589	 1001	 0.000355	 0.027305	 0.0	 691.0	 1157	 1157	 0.979227	 0.0	 1	 -30.0	 30.0;
	5589	 1001	 0.000355	 0.026666	 0.0	 691.0	 1185	 1185	 0.979227	 0.0	 1	 -30.0	 30.0;
	5589	 1001	 0.000923	 0.037456	 0.0	 844	 844	 844	 0.982143	 0.0	 1	 -30.0	 30.0;
	5589	 1001	 0.000788	 0.035217	 0.0	 897	 897	 897	 0.982143	 0.0	 1	 -30.0	 30.0;
	1198	 7473	 0.000323	 0.026739	 0.0	 691.0	 1182	 1182	 0.93617	 0.0	 1	 -30.0	 30.0;
	1198	 7473	 0.000323	 0.02749	 0.0	 691.0	 1149	 1149	 0.93617	 0.0	 1	 -30.0	 30.0;
	2479	 5482	 0.000313	 0.027324	 0.0	 691.0	 1156	 1156	 0.93617	 0.0	 1	 -30.0	 30.0;
	2479	 5482	 0.000313	 0.028074	 0.0	 691.0	 1126	 1126	 0.93617	 0.0	 1	 -30.0	 30.0;
	7831	 5525	 0.000601	 0.024984	 0.0	 1264	 1264	 1264	 0.982143	 0.0	 1	 -30.0	 30.0;
	7831	 5525	 0.000715	 0.022797	 0.0	 1385	 1385	 1385	 0.982143	 0.0	 1	 -30.0	 30.0;
	7831	 5525	 0.000344	 0.024893	 0.0	 691.0	 1269	 1269	 0.93617	 0.0	 1	 -30.0	 30.0;
	4970	 7955	 0.000365	 0.024163	 0.0	 691.0	 1308	 1308	 0.979227	 0.0	 1	 -30.0	 30.0;
	4970	 7955	 0.000344	 0.02385	 0.0	 691.0	 1325	 1325	 0.979227	 0.0	 1	 -30.0	 30.0;
	5007	 7367	 0.000757	 0.040182	 0.0	 786	 786	 786	 0.982143	 0.0	 1	 -30.0	 30.0;
	757	 3758	 0.000323	 0.028937	 0.0	 691.0	 1092	 1092	 0.979227	 0.0	 1	 -30.0	 30.0;
	3697	 6952	 0.000354	 0.026958	 0.0	 691.0	 1172	 1172	 0.93617	 0.0	 1	 -30.0	 30.0;
	3697	 6952	 0.000778	 0.045656	 0.0	 692	 692	 692	 0.982143	 0.0	 1	 -30.0	 30.0;
	3697	 6952	 0.000695	 0.048932	 0.0	 646	 646	 646	 0.982143	 0.0	 1	 -30.0	 30.0;
	3697	 6952	 0.000302	 0.025926	 0.0	 691.0	 1219	 1219	 0.93617	 0.0	 1	 -30.0	 30.0;
	6738	 8180	 0.000355	 0.027328	 0.0	 691.0	 1156	 1156	 0.93617	 0.0	 1	 -30.0	 30.0;
	6738	 8180	 0.000365	 0.027156	 0.0	 691.0	 1164	 1164	 0.93617	 0.0	 1	 -30.0	 30.0;
	9222	 5935	 0.000355	 0.024299	 0.0	 691.0	 1300	 1300	 0.979227	 0.0	 1	 -30.0	 30.0;
	7988	 804	 0.000375	 0.026313	 0.0	 691.0	 1201	 1201	 0.93617	 0.0	 1	 -30.0	 30.0;
	7988	 804	 0.000375	 0.025605	 0.0	 691.0	 1234	 1234	 0.93617	 0.0	 1	 -30.0	 30.0;
	3239	 1539	 0.000334	 0.026291	 0.0	 691.0	 1202	 1202	 0.979227	 0.0	 1	 -30.0	 30.0;
	3239	 1539	 0.000705	 0.046735	 0.0	 676	 676	 676	 0.982143	 0.0	 1	 -30.0	 30.0;
	2056	 4084	 0.000313	 0.026875	 0.0	 691.0	 1176	 1176	 0.979227	 0.0	 1	 -30.0	 30.0;
	2056	 4084	 0.000302	 0.027376	 0.0	 691.0	 1154	 1154	 0.979227	 0.0	 1	 -30.0	 30.0;
	4598	 5110	 0.000664	 0.044868	 0.0	 704	 704	 704	 0.982143	 0.0	 1	 -30.0	 30.0;
	2129	 5110	 0.000809	 0.044526	 0.0	 710	 710	 710	 0.982143	 0.0	 1	 -30.0	 30.0;
	5658	 5550	 0.00086	 0.034253	 0.0	 922	 922	 922	 0.982143	 0.0	 1	 -30.0	 30.0;
	5658	 5550	 0.000355	 0.024372	 0.0	 691.0	 1296	 1296	 0.93617	 0.0	 1	 -30.0	 30.0;
	2848	 1526	 0.000365	 0.023788	 0.0	 691.0	 1328	 1328	 0.93617	 0.0	 1	 -30.0	 30.0;
	4541	 7464	 0.000375	 0.023204	 0.0	 691.0	 1362	 1362	 0.979227	 0.0	 1	 -30.0	 30.0;
	4541	 7464	 0.000302	 0.026593	 0.0	 691.0	 1188	 1188	 0.979227	 0.0	 1	 -30.0	 30.0;
	1754	 3857	 0.000323	 0.029256	 0.0	 691.0	 1080	 1080	 0.93617	 0.0	 1	 -30.0	 30.0;
	1754	 3857	 0.000334	 0.029986	 0.0	 691.0	 1054	 1054	 0.93617	 0.0	 1	 -30.0	 30.0;
	1754	 3857	 0.000355	 0.030979	 0.0	 691.0	 1020	 1020	 0.93617	 0.0	 1	 -30.0	 30.0;
	2518	 4544	 0.000302	 0.025707	 0.0	 691.0	 1229	 1229	 0.93617	 0.0	 1	 -30.0	 30.0;
	2518	 4544	 0.000344	 0.025405	 0.0	 691.0	 1244	 1244	 0.93617	 0.0	 1	 -30.0	 30.0;
	3069	 6115	 0.00012	 0.008908	 0.0	 591.0	 3546	 3546	 1.0	 -0.072388	 1	 -30.0	 30.0;
	5067	 7641	 0.000365	 0.023715	 0.0	 691.0	 1332	 1332	 0.93617	 0.0	 1	 -30.0	 30.0;
	6036	 8670	 0.000365	 0.023517	 0.0	 691.0	 1344	 1344	 0.979227	 0.0	 1	 -30.0	 30.0;
	6036	 5522	 0.000334	 0.026812	 0.0	 691.0	 1179	 1179	 0.979227	 0.0	 1	 -30.0	 30.0;
	8486	 8791	 0.000695	 0.047253	 0.0	 669	 669	 669	 0.982143	 0.0	 1	 -30.0	 30.0;
	7530	 8791	 0.000778	 0.043759	 0.0	 722	 722	 722	 0.982143	 0.0	 1	 -30.0	 30.0;
	7522	 7571	 0.000313	 0.030636	 0.0	 691.0	 1031	 1031	 0.93617	 0.0	 1	 -30.0	 30.0;
	7522	 7571	 0.000313	 0.028286	 0.0	 691.0	 1117	 1117	 0.93617	 0.0	 1	 -30.0	 30.0;
	7522	 7571	 0.000344	 0.028115	 0.0	 691.0	 1124	 1124	 0.93617	 0.0	 1	 -30.0	 30.0;
	2526	 1483	 0.000902	 0.039425	 0.0	 801	 801	 801	 0.982143	 0.0	 1	 -30.0	 30.0;
	2365	 8316	 0.000355	 0.024237	 0.0	 691.0	 1304	 1304	 0.93617	 0.0	 1	 -30.0	 30.0;
	8672	 1860	 0.000375	 0.023986	 0.0	 691.0	 1317	 1317	 0.93617	 0.0	 1	 -30.0	 30.0;
	8672	 1860	 0.000375	 0.023861	 0.0	 691.0	 1324	 1324	 0.93617	 0.0	 1	 -30.0	 30.0;
	1494	 583	 0.000819	 0.04153	 0.0	 761	 761	 761	 0.982143	 0.0	 1	 -30.0	 30.0;
	1494	 583	 0.000809	 0.042701	 0.0	 740	 740	 740	 0.982143	 0.0	 1	 -30.0	 30.0;
	1502	 2795	 0.000334	 0.028022	 0.0	 691.0	 1128	 1128	 0.93617	 0.0	 1	 -30.0	 30.0;
	8195	 933	 0.000632	 0.048237	 0.0	 655	 655	 655	 0.982143	 0.0	 1	 -30.0	 30.0;
	8195	 933	 0.000632	 0.045159	 0.0	 700	 700	 700	 0.982143	 0.0	 1	 -30.0	 30.0;
	8195	 933	 0.000715	 0.044039	 0.0	 718	 718	 718	 0.982143	 0.0	 1	 -30.0	 30.0;
	3918	 6802	 0.00074	 0.044479	 0.0	 711	 711	 711	 0.986547	 0.0	 1	 -30.0	 30.0;
	3918	 4025	 0.00074	 0.043811	 0.0	 721	 721	 721	 0.986547	 0.0	 1	 -30.0	 30.0;
	4435	 2079	 0.000375	 0.02385	 0.0	 691.0	 1325	 1325	 0.93617	 0.0	 1	 -30.0	 30.0;
	4435	 2079	 0.000365	 0.023267	 0.0	 691.0	 1358	 1358	 0.93617	 0.0	 1	 -30.0	 30.0;
	4435	 2079	 0.000323	 0.026739	 0.0	 691.0	 1182	 1182	 0.93617	 0.0	 1	 -30.0	 30.0;
	1081	 7361	 0.000684	 0.047025	 0.0	 672	 672	 672	 0.982143	 0.0	 1	 -30.0	 30.0;
	9101	 2177	 0.000313	 0.02748	 0.0	 691.0	 1150	 1150	 0.93617	 0.0	 1	 -30.0	 30.0;
	6555	 8475	 0.000323	 0.028554	 0.0	 691.0	 1107	 1107	 0.93617	 0.0	 1	 -30.0	 30.0;
	6555	 8475	 0.000302	 0.026437	 0.0	 691.0	 1195	 1195	 0.93617	 0.0	 1	 -30.0	 30.0;
	7056	 7577	 0.000365	 0.025551	 0.0	 691.0	 1237	 1237	 0.93617	 0.0	 1	 -30.0	 30.0;
	7056	 7577	 0.000344	 0.024893	 0.0	 691.0	 1269	 1269	 0.93617	 0.0	 1	 -30.0	 30.0;
	7056	 9051	 0.000375	 0.024508	 0.0	 691.0	 1289	 1289	 0.979227	 0.0	 1	 -30.0	 30.0;
	6889	 6785	 0.000778	 0.041157	 0.0	 768	 768	 768	 0.982143	 0.0	 1	 -30.0	 30.0;
	6889	 6785	 0.000923	 0.03702	 0.0	 853	 853	 853	 0.982143	 0.0	 1	 -30.0	 30.0;
	6889	 6785	 0.000302	 0.026593	 0.0	 691.0	 1188	 1188	 0.979227	 0.0	 1	 -30.0	 30.0;
	1027	 7148	 0.000344	 0.029667	 0.0	 691.0	 1065	 1065	 0.93617	 0.0	 1	 -30.0	 30.0;
	1027	 44	 0.000334	 0.02748	 0.0	 691.0	 1150	 1150	 0.93617	 0.0	 1	 -30.0	 30.0;
	5308	 7148	 0.000323	 0.030636	 0.0	 691.0	 1031	 1031	 0.89674	 0.0	 1	 -30.0	 30.0;
	5308	 44	 0.000323	 0.028526	 0.0	 691.0	 1108	 1108	 0.93617	 0.0	 1	 -30.0	 30.0;
	9213	 6231	 0.000344	 0.025332	 0.0	 691.0	 1247	 1247	 0.979227	 0.0	 1	 -30.0	 30.0;
	9213	 8291	 0.000334	 0.024674	 0.0	 691.0	 1281	 1281	 0.979227	 0.0	 1	 -30.0	 30.0;
	9213	 6842	 0.000344	 0.02457	 0.0	 691.0	 1286	 1286	 0.979227	 0.0	 1	 -30.0	 30.0;
	3608	 6664	 0.000365	 0.023788	 0.0	 691.0	 1328	 1328	 0.93617	 0.0	 1	 -30.0	 30.0;
	4339	 6570	 0.000365	 0.023601	 0.0	 691.0	 1339	 1339	 0.93617	 0.0	 1	 -30.0	 30.0;
	4339	 6570	 0.000344	 0.02652	 0.0	 691.0	 1191	 1191	 0.93617	 0.0	 1	 -30.0	 30.0;
	7513	 6570	 0.000344	 0.027272	 0.0	 691.0	 1159	 1159	 0.93617	 0.0	 1	 -30.0	 30.0;
	7513	 6570	 0.000334	 0.027563	 0.0	 691.0	 1146	 1146	 0.93617	 0.0	 1	 -30.0	 30.0;
	8887	 6639	 0.000313	 0.030636	 0.0	 691.0	 1031	 1031	 0.979227	 0.0	 1	 -30.0	 30.0;
	8887	 6639	 0.000313	 0.028286	 0.0	 691.0	 1117	 1117	 0.979227	 0.0	 1	 -30.0	 30.0;
	5461	 4816	 0.000881	 0.036803	 0.0	 859	 859	 859	 0.982143	 0.0	 1	 -30.0	 30.0;
	5461	 4816	 0.000902	 0.036668	 0.0	 862	 862	 862	 0.982143	 0.0	 1	 -30.0	 30.0;
	5461	 4816	 0.000881	 0.034014	 0.0	 929	 929	 929	 0.982143	 0.0	 1	 -30.0	 30.0;
	5460	 3786	 0.000365	 0.026027	 0.0	 691.0	 1214	 1214	 0.93617	 0.0	 1	 -30.0	 30.0;
	5460	 3786	 0.000386	 0.025673	 0.0	 691.0	 1231	 1231	 0.93617	 0.0	 1	 -30.0	 30.0;
	7256	 4491	 0.00012	 0.011186	 0.0	 686.0	 2824	 2824	 1.0	 0.084507	 1	 -30.0	 30.0;
	6153	 58	 0.00017	 0.007091	 0.0	 1316.0	 4454	 4454	 1.0	 -0.09784	 1	 -30.0	 30.0;
	6153	 6807	 0.000664	 0.047107	 0.0	 671	 671	 671	 0.982143	 0.0	 1	 -30.0	 30.0;
	1465	 1262	 0.000313	 0.028314	 0.0	 691.0	 1116	 1116	 0.93617	 0.0	 1	 -30.0	 30.0;
	1465	 1262	 0.000334	 0.025707	 0.0	 691.0	 1229	 1229	 0.93617	 0.0	 1	 -30.0	 30.0;
	1465	 1551	 0.000344	 0.025478	 0.0	 691.0	 1240	 1240	 0.93617	 0.0	 1	 -30.0	 30.0;
	7537	 1551	 0.000344	 0.027236	 0.0	 691.0	 1160	 1160	 0.93617	 0.0	 1	 -30.0	 30.0;
	7537	 1551	 0.000375	 0.026518	 0.0	 691.0	 1192	 1192	 0.93617	 0.0	 1	 -30.0	 30.0;
	6901	 4874	 0.000386	 0.02646	 0.0	 691.0	 1194	 1194	 0.93617	 0.0	 1	 -30.0	 30.0;
	5241	 4	 0.000788	 0.040317	 0.0	 784	 784	 784	 0.982143	 0.0	 1	 -30.0	 30.0;
	7520	 561	 0.000323	 0.025863	 0.0	 691.0	 1222	 1222	 0.979227	 0.0	 1	 -30.0	 30.0;
	749	 4324	 1e-05	 0.022863	 0.0	 1048.0	 1382	 1382	 1.0	 0.04898	 1	 -30.0	 30.0;
	4141	 7124	 0.000334	 0.030306	 0.0	 691.0	 1043	 1043	 0.93617	 0.0	 1	 -30.0	 30.0;
	4141	 7124	 0.000302	 0.030636	 0.0	 691.0	 1032	 1032	 0.93617	 0.0	 1	 -30.0	 30.0;
	7466	 3649	 0.00011	 0.010476	 0.0	 572.0	 3016	 3016	 1.0	 -0.06138	 1	 -30.0	 30.0;
	8222	 6556	 0.000344	 0.024841	 0.0	 691.0	 1272	 1272	 0.979227	 0.0	 1	 -30.0	 30.0;
	8222	 6556	 0.000365	 0.025029	 0.0	 691.0	 1262	 1262	 0.979227	 0.0	 1	 -30.0	 30.0;
	8222	 6556	 0.000355	 0.024101	 0.0	 691.0	 1311	 1311	 0.979227	 0.0	 1	 -30.0	 30.0;
	4125	 163	 0.000344	 0.02385	 0.0	 691.0	 1325	 1325	 0.93617	 0.0	 1	 -30.0	 30.0;
	4125	 163	 0.000411	 0.02313	 0.0	 691.0	 1366	 1366	 0.93617	 0.0	 1	 -30.0	 30.0;
	4125	 163	 0.000829	 0.042764	 0.0	 739	 739	 739	 0.982143	 0.0	 1	 -30.0	 30.0;
	5837	 9217	 0.000705	 0.04748	 0.0	 666	 666	 666	 0.982143	 0.0	 1	 -30.0	 30.0;
	5837	 1448	 0.000323	 0.029986	 0.0	 691.0	 1054	 1054	 0.93617	 0.0	 1	 -30.0	 30.0;
	5837	 1448	 0.000302	 0.029952	 0.0	 691.0	 1055	 1055	 0.93617	 0.0	 1	 -30.0	 30.0;
	8267	 5365	 0.000746	 0.041064	 0.0	 770	 770	 770	 0.982143	 0.0	 1	 -30.0	 30.0;
	8267	 5365	 0.000881	 0.042214	 0.0	 749	 749	 749	 0.982143	 0.0	 1	 -30.0	 30.0;
	2359	 8005	 0.00086	 0.041209	 0.0	 767	 767	 767	 0.982143	 0.0	 1	 -30.0	 30.0;
	2359	 8005	 0.000912	 0.038669	 0.0	 817	 817	 817	 0.982143	 0.0	 1	 -30.0	 30.0;
	8109	 171	 0.000375	 0.026244	 0.0	 691.0	 1204	 1204	 0.979227	 0.0	 1	 -30.0	 30.0;
	8109	 171	 0.000375	 0.025457	 0.0	 691.0	 1241	 1241	 0.979227	 0.0	 1	 -30.0	 30.0;
	3485	 1156	 0.000302	 0.029096	 0.0	 691.0	 1086	 1086	 0.93617	 0.0	 1	 -30.0	 30.0;
	4734	 2229	 0.000302	 0.029667	 0.0	 691.0	 1065	 1065	 0.93617	 0.0	 1	 -30.0	 30.0;
	1709	 7702	 0.000334	 0.027563	 0.0	 691.0	 1146	 1146	 0.979227	 0.0	 1	 -30.0	 30.0;
	1709	 7702	 0.000323	 0.028074	 0.0	 691.0	 1126	 1126	 0.979227	 0.0	 1	 -30.0	 30.0;
	905	 8189	 0.000736	 0.041064	 0.0	 770	 770	 770	 0.982143	 0.0	 1	 -30.0	 30.0;
	8334	 8189	 0.001234	 0.040109	 0.0	 788	 788	 788	 0.982143	 0.0	 1	 -30.0	 30.0;
	8334	 8189	 0.000757	 0.043209	 0.0	 731	 731	 731	 0.982143	 0.0	 1	 -30.0	 30.0;
	7998	 6734	 0.000323	 0.026586	 0.0	 954.0	 1189	 1189	 0.93617	 0.0	 1	 -30.0	 30.0;
	4196	 280	 0.000788	 0.040296	 0.0	 784	 784	 784	 0.982143	 0.0	 1	 -30.0	 30.0;
	4196	 280	 0.000912	 0.040514	 0.0	 780	 780	 780	 0.982143	 0.0	 1	 -30.0	 30.0;
	6475	 3503	 0.000798	 0.042183	 0.0	 749	 749	 749	 0.982143	 0.0	 1	 -30.0	 30.0;
	6475	 3503	 0.000778	 0.043147	 0.0	 732	 732	 732	 0.982143	 0.0	 1	 -30.0	 30.0;
	7328	 4235	 0.000323	 0.027793	 0.0	 691.0	 1137	 1137	 0.93617	 0.0	 1	 -30.0	 30.0;
	7328	 4235	 0.000302	 0.027918	 0.0	 691.0	 1132	 1132	 0.93617	 0.0	 1	 -30.0	 30.0;
	7328	 4235	 0.000302	 0.025926	 0.0	 691.0	 1219	 1219	 0.93617	 0.0	 1	 -30.0	 30.0;
	6921	 2949	 0.000344	 0.024956	 0.0	 691.0	 1266	 1266	 0.979227	 0.0	 1	 -30.0	 30.0;
	6921	 2949	 0.000355	 0.024435	 0.0	 691.0	 1293	 1293	 0.979227	 0.0	 1	 -30.0	 30.0;
	3830	 306	 0.000386	 0.026392	 0.0	 691.0	 1197	 1197	 0.93617	 0.0	 1	 -30.0	 30.0;
	5648	 306	 0.000365	 0.025525	 0.0	 691.0	 1238	 1238	 0.93617	 0.0	 1	 -30.0	 30.0;
	1730	 115	 0.000344	 0.029986	 0.0	 691.0	 1054	 1054	 0.93617	 0.0	 1	 -30.0	 30.0;
	1730	 115	 0.000323	 0.029838	 0.0	 691.0	 1059	 1059	 0.93617	 0.0	 1	 -30.0	 30.0;
	2721	 5720	 0.000323	 0.02748	 0.0	 691.0	 1150	 1150	 0.93617	 0.0	 1	 -30.0	 30.0;
	2721	 5720	 0.000313	 0.028001	 0.0	 691.0	 1129	 1129	 0.93617	 0.0	 1	 -30.0	 30.0;
	432	 3246	 0.000179	 0.012988	 0.0	 1251.0	 2432	 2432	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 8846	 0.000198	 0.012724	 0.0	 1251.0	 2483	 2483	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 2393	 0.000207	 0.012469	 0.0	 1251.0	 2533	 2533	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 1895	 0.000207	 0.012206	 0.0	 1251.0	 2588	 2588	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 3412	 0.000217	 0.012912	 0.0	 1251.0	 2447	 2447	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 5586	 0.000217	 0.012627	 0.0	 1251.0	 2502	 2502	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 3112	 0.000198	 0.014317	 0.0	 1251.0	 2207	 2207	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 3112	 0.000189	 0.014592	 0.0	 1251.0	 2165	 2165	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 7857	 0.000354	 0.02725	 0.0	 691.0	 1160	 1160	 0.979227	 0.0	 1	 -30.0	 30.0;
	960	 8497	 0.000628	 0.042428	 0.0	 745	 745	 745	 1.009174	 0.0	 1	 -30.0	 30.0;
	960	 8497	 0.000726	 0.044039	 0.0	 718	 718	 718	 0.982143	 0.0	 1	 -30.0	 30.0;
	3577	 5907	 0.000365	 0.024893	 0.0	 691.0	 1269	 1269	 0.979227	 0.0	 1	 -30.0	 30.0;
	3577	 5907	 0.000438	 0.02457	 0.0	 691.0	 1286	 1286	 0.979227	 0.0	 1	 -30.0	 30.0;
	3577	 5907	 0.000365	 0.023986	 0.0	 691.0	 1317	 1317	 0.979227	 0.0	 1	 -30.0	 30.0;
	7164	 5918	 0.000375	 0.023267	 0.0	 691.0	 1358	 1358	 0.979227	 0.0	 1	 -30.0	 30.0;
	7164	 5918	 0.000323	 0.026375	 0.0	 691.0	 1198	 1198	 0.93617	 0.0	 1	 -30.0	 30.0;
	1798	 2467	 0.000334	 0.029735	 0.0	 691.0	 1063	 1063	 0.93617	 0.0	 1	 -30.0	 30.0;
	1798	 2467	 0.000313	 0.030237	 0.0	 691.0	 1045	 1045	 0.93617	 0.0	 1	 -30.0	 30.0;
	3346	 2132	 0.000767	 0.044049	 0.0	 717	 717	 717	 0.982143	 0.0	 1	 -30.0	 30.0;
	3346	 2132	 0.000302	 0.026072	 0.0	 691.0	 1212	 1212	 0.93617	 0.0	 1	 -30.0	 30.0;
	3346	 2132	 0.00085	 0.039892	 0.0	 792	 792	 792	 0.982143	 0.0	 1	 -30.0	 30.0;
	3483	 8992	 0.000344	 0.024956	 0.0	 691.0	 1266	 1266	 0.979227	 0.0	 1	 -30.0	 30.0;
	8886	 8992	 0.000334	 0.026666	 0.0	 691.0	 1185	 1185	 0.93617	 0.0	 1	 -30.0	 30.0;
	2093	 805	 0.000365	 0.023788	 0.0	 691.0	 1328	 1328	 0.93617	 0.0	 1	 -30.0	 30.0;
	2093	 805	 0.000365	 0.023465	 0.0	 691.0	 1346	 1346	 0.93617	 0.0	 1	 -30.0	 30.0;
	221	 1541	 0.000334	 0.026447	 0.0	 691.0	 1195	 1195	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 5383	 0.000323	 0.027042	 0.0	 691.0	 1169	 1169	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 5383	 0.000313	 0.02748	 0.0	 691.0	 1150	 1150	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 5383	 0.000302	 0.028314	 0.0	 691.0	 1116	 1116	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 7507	 0.000323	 0.025853	 0.0	 691.0	 1222	 1222	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 7507	 0.000365	 0.026197	 0.0	 691.0	 1206	 1206	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 7507	 0.000365	 0.025165	 0.0	 691.0	 1256	 1256	 0.93617	 0.0	 1	 -30.0	 30.0;
	4000	 4852	 0.000355	 0.024237	 0.0	 691.0	 1304	 1304	 0.979227	 0.0	 1	 -30.0	 30.0;
	4000	 2012	 0.000375	 0.024247	 0.0	 691.0	 1303	 1303	 0.93617	 0.0	 1	 -30.0	 30.0;
	2183	 4852	 0.000365	 0.023267	 0.0	 691.0	 1358	 1358	 0.979227	 0.0	 1	 -30.0	 30.0;
	2183	 2012	 0.000342	 0.023139	 0.0	 691.0	 1365	 1365	 0.982143	 0.0	 1	 -30.0	 30.0;
	1642	 7098	 0.000344	 0.026666	 0.0	 691.0	 1185	 1185	 0.979227	 0.0	 1	 -30.0	 30.0;
	1642	 687	 0.000334	 0.027021	 0.0	 691.0	 1169	 1169	 0.93617	 0.0	 1	 -30.0	 30.0;
	809	 7098	 0.000302	 0.027615	 0.0	 691.0	 1144	 1144	 0.979227	 0.0	 1	 -30.0	 30.0;
	809	 687	 0.000313	 0.026135	 0.0	 691.0	 1209	 1209	 0.93617	 0.0	 1	 -30.0	 30.0;
	4594	 8804	 0.000365	 0.025905	 0.0	 691.0	 1220	 1220	 0.93617	 0.0	 1	 -30.0	 30.0;
	4594	 8804	 0.000355	 0.025238	 0.0	 691.0	 1252	 1252	 0.93617	 0.0	 1	 -30.0	 30.0;
	2919	 4215	 0.000334	 0.026814	 0.0	 691.0	 1178	 1178	 0.93617	 0.0	 1	 -30.0	 30.0;
	1392	 5001	 0.001252	 0.073601	 0.0	 430	 430	 430	 0.94	 0.0	 1	 -30.0	 30.0;
	3538	 5001	 0.001271	 0.072001	 0.0	 439	 439	 439	 0.94	 0.0	 1	 -30.0	 30.0;
	8249	 6139	 0.000442	 0.040802	 0.0	 775	 775	 775	 0.88	 0.0	 1	 -30.0	 30.0;
	806	 91	 0.00048	 0.041601	 0.0	 760	 760	 760	 0.97	 0.0	 1	 -30.0	 30.0;
	1747	 6998	 0.000543	 0.04261	 0.0	 742	 742	 742	 1.0	 0.0	 1	 -30.0	 30.0;
	593	 6998	 0.000534	 0.04342	 0.0	 728	 728	 728	 1.0	 0.0	 1	 -30.0	 30.0;
	8432	 6295	 0.003895	 0.040564	 0.0	 776	 776	 776	 0.97	 0.0	 1	 -30.0	 30.0;
	8432	 6295	 0.004413	 0.039762	 0.0	 790	 790	 790	 0.97	 0.0	 1	 -30.0	 30.0;
	8432	 6295	 0.004498	 0.038954	 0.0	 806	 806	 806	 0.97	 0.0	 1	 -30.0	 30.0;
	3190	 7090	 0.000621	 0.0376	 0.0	 840	 840	 840	 1.0	 0.0	 1	 -30.0	 30.0;
	3484	 7090	 0.00063	 0.0368	 0.0	 859	 859	 859	 1.0	 0.0	 1	 -30.0	 30.0;
	3484	 7844	 0.00064	 0.036	 0.0	 878	 878	 878	 1.0	 0.0	 1	 -30.0	 30.0;
	281	 3960	 0.000555	 0.040801	 0.0	 775	 775	 775	 0.984999	 0.0	 1	 -30.0	 30.0;
	8086	 1477	 0.000546	 0.0416	 0.0	 760	 760	 760	 0.984999	 0.0	 1	 -30.0	 30.0;
	8086	 8037	 0.000527	 0.0424	 0.0	 745	 745	 745	 0.984999	 0.0	 1	 -30.0	 30.0;
	5008	 6354	 0.000456	 0.043201	 0.0	 732	 732	 732	 0.97	 0.0	 1	 -30.0	 30.0;
	5008	 6354	 0.000447	 0.040001	 0.0	 790	 790	 790	 0.97	 0.0	 1	 -30.0	 30.0;
	919	 6354	 0.000505	 0.039202	 0.0	 806	 806	 806	 0.97	 0.0	 1	 -30.0	 30.0;
	919	 6354	 0.000513	 0.038402	 0.0	 823	 823	 823	 0.97	 0.0	 1	 -30.0	 30.0;
	4825	 7884	 0.000513	 0.037602	 0.0	 840	 840	 840	 0.954999	 0.0	 1	 -30.0	 30.0;
	3023	 7884	 0.00052	 0.036802	 0.0	 859	 859	 859	 0.954999	 0.0	 1	 -30.0	 30.0;
	6345	 7884	 0.000529	 0.036002	 0.0	 878	 878	 878	 0.954999	 0.0	 1	 -30.0	 30.0;
	8114	 8738	 0.000473	 0.040802	 0.0	 775	 775	 775	 0.984999	 0.0	 1	 -30.0	 30.0;
	8773	 8738	 0.000465	 0.041601	 0.0	 760	 760	 760	 0.984999	 0.0	 1	 -30.0	 30.0;
	4059	 6282	 7e-05	 0.021201	 0.0	 790.0	 1490	 1490	 1.0	 0.0	 1	 -30.0	 30.0;
	2002	 4340	 7e-05	 0.021599	 0.0	 790.0	 1463	 1463	 1.0	 0.0	 1	 -30.0	 30.0;
	5165	 3363	 0.00054	 0.04	 0.0	 790	 790	 790	 0.98421	 0.0	 1	 -30.0	 30.0;
	5165	 3363	 0.000472	 0.039202	 0.0	 806	 806	 806	 0.984999	 0.0	 1	 -30.0	 30.0;
	2722	 3363	 0.00048	 0.038402	 0.0	 823	 823	 823	 0.984999	 0.0	 1	 -30.0	 30.0;
	2722	 3363	 0.00064	 0.0376	 0.0	 840	 840	 840	 0.98421	 0.0	 1	 -30.0	 30.0;
	1591	 1124	 0.000333	 0.029441	 0.0	 1073	 1073	 1073	 0.925	 0.0	 1	 -30.0	 30.0;
	5558	 8510	 0.000353	 0.028801	 0.0	 1097	 1097	 1097	 0.925	 0.0	 1	 -30.0	 30.0;
	5558	 8510	 0.000312	 0.032641	 0.0	 968	 968	 968	 0.925	 0.0	 1	 -30.0	 30.0;
	1689	 8814	 0.000529	 0.041601	 0.0	 760	 760	 760	 0.94	 0.0	 1	 -30.0	 30.0;
	8230	 8814	 0.000511	 0.042401	 0.0	 745	 745	 745	 0.94	 0.0	 1	 -30.0	 30.0;
	8393	 7565	 0.000633	 0.051521	 0.0	 614	 614	 614	 0.94	 0.0	 1	 -30.0	 30.0;
	8393	 7565	 0.000616	 0.047701	 0.0	 663	 663	 663	 0.94	 0.0	 1	 -30.0	 30.0;
	139	 7565	 0.000701	 0.046752	 0.0	 676	 676	 676	 0.94	 0.0	 1	 -30.0	 30.0;
	3257	 6058	 0.000811	 0.04579	 0.0	 690	 690	 690	 0.98871	 0.0	 1	 -30.0	 30.0;
	369	 6058	 0.000831	 0.04484	 0.0	 705	 705	 705	 0.98871	 0.0	 1	 -30.0	 30.0;
	369	 6058	 0.000841	 0.043881	 0.0	 720	 720	 720	 0.98871	 0.0	 1	 -30.0	 30.0;
	6068	 7450	 0.000621	 0.036001	 0.0	 878	 878	 878	 1.015	 0.0	 1	 -30.0	 30.0;
	6068	 2271	 0.000555	 0.040801	 0.0	 775	 775	 775	 1.015	 0.0	 1	 -30.0	 30.0;
	6263	 3846	 0.000563	 0.0416	 0.0	 760	 760	 760	 1.015	 0.0	 1	 -30.0	 30.0;
	1788	 1020	 0.000543	 0.0424	 0.0	 745	 745	 745	 1.015	 0.0	 1	 -30.0	 30.0;
	2824	 211	 0.001026	 0.086398	 0.0	 366	 366	 366	 0.97	 0.0	 1	 -30.0	 30.0;
	140	 211	 0.001007	 0.080001	 0.0	 395	 395	 395	 0.955	 0.0	 1	 -30.0	 30.0;
	3210	 1670	 0.000522	 0.039201	 0.0	 806	 806	 806	 0.954999	 0.0	 1	 -30.0	 30.0;
	5674	 1670	 0.00053	 0.038401	 0.0	 823	 823	 823	 0.954999	 0.0	 1	 -30.0	 30.0;
	4337	 1670	 0.000548	 0.037601	 0.0	 840	 840	 840	 0.94	 0.0	 1	 -30.0	 30.0;
	4779	 1956	 3e-05	 0.006499	 0.0	 4861	 4861	 4861	 0.0	 0.0	 1	 -30.0	 30.0;
	4320	 4302	 0.000907	 0.042929	 0.0	 736	 736	 736	 0.97	 0.0	 1	 -30.0	 30.0;
	4858	 4248	 7.7e-05	 0.0204	 0.0	 724.0	 1549	 1549	 1.105	 0.0	 1	 -30.0	 30.0;
	7235	 4858	 3e-05	 0.007522	 0.0	 4200	 4200	 4200	 0.995481	 -0.09511	 1	 -30.0	 30.0;
	4248	 4302	 0.000773	 0.05056	 0.0	 625	 625	 625	 0.97	 0.0	 1	 -30.0	 30.0;
	5897	 2720	 0.000728	 0.043197	 0.0	 732	 732	 732	 1.045	 0.0	 1	 -30.0	 30.0;
	420	 243	 0.000447	 0.040001	 0.0	 790	 790	 790	 1.045	 0.0	 1	 -30.0	 30.0;
	8898	 6052	 0.00061	 0.0392	 0.0	 806	 806	 806	 1.03	 0.0	 1	 -30.0	 30.0;
	5311	 8668	 0.001203	 0.076801	 0.0	 412	 412	 412	 1.03	 0.0	 1	 -30.0	 30.0;
	3891	 8668	 0.001223	 0.075201	 0.0	 420	 420	 420	 1.03	 0.0	 1	 -30.0	 30.0;
	662	 7073	 0.004533	 0.037356	 0.0	 840	 840	 840	 0.984999	 0.0	 1	 -30.0	 30.0;
	6017	 349	 0.004615	 0.036549	 0.0	 858	 858	 858	 0.984999	 0.0	 1	 -30.0	 30.0;
	6766	 7156	 0.004113	 0.041392	 0.0	 760	 760	 760	 0.984999	 0.0	 1	 -30.0	 30.0;
	4077	 7442	 0.000627	 0.041599	 0.0	 760	 760	 760	 1.039999	 0.0	 1	 -30.0	 30.0;
	1052	 8277	 0.001048	 0.084802	 0.0	 373	 373	 373	 1.045	 0.0	 1	 -30.0	 30.0;
	3878	 8277	 0.001029	 0.086397	 0.0	 366	 366	 366	 1.045	 0.0	 1	 -30.0	 30.0;
	76	 5346	 0.000808	 0.047709	 0.0	 662	 662	 662	 1.0	 0.0	 1	 -30.0	 30.0;
	4485	 3000	 0.00061	 0.0392	 0.0	 806	 806	 806	 1.015	 0.0	 1	 -30.0	 30.0;
	4485	 3000	 0.00062	 0.0384	 0.0	 823	 823	 823	 1.015	 0.0	 1	 -30.0	 30.0;
	6283	 3000	 0.00064	 0.0376	 0.0	 840	 840	 840	 1.015	 0.0	 1	 -30.0	 30.0;
	395	 4082	 0.00063	 0.0368	 0.0	 859	 859	 859	 0.984999	 0.0	 1	 -30.0	 30.0;
	5843	 5246	 0.00064	 0.036	 0.0	 878	 878	 878	 0.984999	 0.0	 1	 -30.0	 30.0;
	5843	 5246	 0.000573	 0.0408	 0.0	 775	 775	 775	 0.984999	 0.0	 1	 -30.0	 30.0;
	6477	 2478	 0.001067	 0.083199	 0.0	 380	 380	 380	 1.0	 0.0	 1	 -30.0	 30.0;
	5295	 2478	 0.001048	 0.084802	 0.0	 373	 373	 373	 1.0	 0.0	 1	 -30.0	 30.0;
	6504	 3341	 0.001519	 0.050701	 0.0	 623	 623	 623	 1.013513	 0.0	 1	 -30.0	 30.0;
	130	 5452	 0.000821	 0.051524	 0.0	 613	 613	 613	 1.052632	 0.0	 1	 -30.0	 30.0;
	130	 5452	 0.000803	 0.047869	 0.0	 660	 660	 660	 1.052632	 0.0	 1	 -30.0	 30.0;
	441	 2233	 0.000466	 0.029318	 0.0	 1078	 1078	 1078	 1.025291	 0.0	 1	 -30.0	 30.0;
	8088	 4721	 0.000463	 0.028006	 0.0	 1128	 1128	 1128	 1.038781	 0.0	 1	 -30.0	 30.0;
	8088	 4721	 0.000463	 0.026569	 0.0	 1189	 1189	 1189	 1.038781	 0.0	 1	 -30.0	 30.0;
	3080	 8789	 0.000556	 0.030088	 0.0	 1050	 1050	 1050	 1.08147	 0.0	 1	 -30.0	 30.0;
	3080	 8789	 0.000581	 0.029019	 0.0	 1089	 1089	 1089	 1.08147	 0.0	 1	 -30.0	 30.0;
	5825	 702	 0.0017	 0.077979	 0.0	 405	 405	 405	 1.0	 0.0	 1	 -30.0	 30.0;
	8224	 5517	 0.000569	 0.046371	 0.0	 682	 682	 682	 1.052632	 0.0	 1	 -30.0	 30.0;
	8224	 5517	 0.00056	 0.047255	 0.0	 669	 669	 669	 1.052632	 0.0	 1	 -30.0	 30.0;
	536	 4344	 0.0008	 0.050159	 0.0	 630	 630	 630	 1.066857	 0.0	 1	 -30.0	 30.0;
	6080	 5006	 0.000379	 0.039836	 0.0	 793	 793	 793	 1.052632	 0.0	 1	 -30.0	 30.0;
	6080	 5006	 0.000433	 0.039042	 0.0	 810	 810	 810	 1.052632	 0.0	 1	 -30.0	 30.0;
	1899	 7358	 0.000448	 0.032183	 0.0	 982	 982	 982	 1.066857	 0.0	 1	 -30.0	 30.0;
	4712	 1250	 0.000498	 0.034255	 0.0	 923	 923	 923	 1.041667	 0.0	 1	 -30.0	 30.0;
	4712	 1250	 0.000507	 0.033509	 0.0	 943	 943	 943	 1.041667	 0.0	 1	 -30.0	 30.0;
	6187	 2407	 0.000415	 0.040631	 0.0	 778	 778	 778	 1.052632	 0.0	 1	 -30.0	 30.0;
	6187	 2407	 0.000406	 0.041434	 0.0	 763	 763	 763	 1.052632	 0.0	 1	 -30.0	 30.0;
	5562	 1407	 0.000397	 0.037986	 0.0	 832	 832	 832	 1.052632	 0.0	 1	 -30.0	 30.0;
	7827	 1974	 0.000322	 0.035886	 0.0	 881	 881	 881	 1.043149	 0.0	 1	 -30.0	 30.0;
	1025	 8926	 0.000408	 0.039074	 0.0	 809	 809	 809	 0.989653	 0.0	 1	 -30.0	 30.0;
	6298	 6795	 0.000417	 0.026115	 0.0	 1210	 1210	 1210	 1.062288	 0.0	 1	 -30.0	 30.0;
	6298	 6795	 0.000443	 0.02577	 0.0	 1226	 1226	 1226	 1.062288	 0.0	 1	 -30.0	 30.0;
	3007	 6254	 0.000396	 0.033918	 0.0	 932	 932	 932	 1.02924	 0.0	 1	 -30.0	 30.0;
	7969	 177	 0.000406	 0.023438	 0.0	 1348	 1348	 1348	 1.052632	 0.0	 1	 -30.0	 30.0;
	7969	 177	 0.000352	 0.026759	 0.0	 1181	 1181	 1181	 1.052632	 0.0	 1	 -30.0	 30.0;
	1703	 7503	 0.000334	 0.036651	 0.0	 862	 862	 862	 1.052632	 0.0	 1	 -30.0	 30.0;
	1703	 7503	 0.000334	 0.037354	 0.0	 846	 846	 846	 1.052632	 0.0	 1	 -30.0	 30.0;
	4704	 4170	 0.000305	 0.035675	 0.0	 886	 886	 886	 1.087225	 0.0	 1	 -30.0	 30.0;
	4704	 4170	 0.000296	 0.033035	 0.0	 957	 957	 957	 1.087225	 0.0	 1	 -30.0	 30.0;
	4704	 4170	 0.000338	 0.032376	 0.0	 976	 976	 976	 1.087225	 0.0	 1	 -30.0	 30.0;
	2031	 8493	 0.000285	 0.02604	 0.0	 1213	 1213	 1213	 1.199891	 0.0	 1	 -30.0	 30.0;
	1025	 1239	 0.000419	 0.02814	 0.0	 1123	 1123	 1123	 0.989653	 0.0	 1	 -30.0	 30.0;
	3007	 9136	 0.000453	 0.025129	 0.0	 1257	 1257	 1257	 1.02924	 0.0	 1	 -30.0	 30.0;
	3007	 4650	 0.000453	 0.02528	 0.0	 1250	 1250	 1250	 1.02924	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Line Capacity Model:         ub
% INFO    : Gen Active Cost Model:       stat
% INFO    : Setting Flat Start
% INFO    : Line Capacity PAB:           15.0 (deg.)
% INFO    : 
% INFO    : === Generator Classification Notes ===
% INFO    : PEL    25  -     1.45
% INFO    : NUC    18  -    12.55
% INFO    : COW    176 -    71.55
% INFO    : NG     291 -    14.44
% INFO    : 
% INFO    : === Generator Active Cost Stat Model Notes ===
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.5418500499 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7888727393 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.259135179 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2225566307 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.83174645693 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1588807237 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.683605476 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.7316239338 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.0983728188 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.3534388433 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.3181097708 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 7.91818179161 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.1557891003 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1451501052 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5818319464 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0782978558 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.1641308981 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.3987854557 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.315498896 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.1951398767 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5240704906 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.9239694229 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9427964601 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.4757334607 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.1794632716 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9112217582 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6614809108 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.6818197844 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.6903693065 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.564121089 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.8621186547 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.5656172304 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2656578882 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.3259683593 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.0168178298 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5968084543 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2515453705 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 62.738660381 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8605049158 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1560192846 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3676314468 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2854032303 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0556078077 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.760203862 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1330684236 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 5.78425806742 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.55785621761 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2952676636 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1688531088 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5684948282 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.1766072546 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.9090958202 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.0997841643 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.6525204909 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.8858074229 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.2787568897 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.754235417 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.5671376591 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2981399497 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.6377130215 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2927570478 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.809839182 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0548796591 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.867485199 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.8608476577 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.7713014005 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.5720452661 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.349397534 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.3133984545 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.0559474058 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.0690505471 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 129.25936157 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.8960740485 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4447980347 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3681725768 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 8.85852209095 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.312818609 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7045840124 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.9390410743 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.3015267267 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7275925558 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 97.8514040485 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.853594006 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2675182872 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3301720112 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.3898603044 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.3638069355 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4694840071 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.8346570566 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.73312220851 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.9804619084 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.0522799227 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.2360929603 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7319636949 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5194122888 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.7702905614 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.8034374202 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.7216498013 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.609781106 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.0731477273 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.7692853231 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2824844572 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.5465433801 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.4128770816 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.2727207664 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.8096714832 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.4544404116 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.5473516851 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.6518444644 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0649453562 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.8892356035 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9955758859 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.9584698412 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.2080955642 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.5573926773 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.7237952069 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.3846403448 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1888143492 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.5902760844 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.3744455386 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.1123081204 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.809591484 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8891091774 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.7867394305 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5147509236 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.2272067433 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.6763973805 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.5139543165 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.2823413976 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.243992532 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7578174912 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.3029120375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9691437977 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.3334461788 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.6223063055 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.0978538456 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.287736249 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.0945275202 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.174469308 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.7690629994 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.33904571882 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.6073257501 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7215854713 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.668914511 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.75835704 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8252859178 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.6466612175 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.0672319222 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.9706590992 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.9219336936 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.6006528901 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.3763792126 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.029629178 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.3083646767 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.5923842787 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1664457534 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.6318717014 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.318042272 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8236040155 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.595784104 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.8289486287 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9667922984 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7868909522 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.8976761986 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3179953637 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.3883534168 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.7476824676 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.9105334413 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.2914608652 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.6661854705 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.786992414 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1443906396 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.5139076717 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.995910185 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.1302448274 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.0923271425 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.9202291109 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2144108697 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3601291097 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.6058401918 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.601318856 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1621131055 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.9437383955 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8859497012 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5685329297 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.4645308711 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.6991215747 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5892411873 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 61.0103235287 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8631817932 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.3449022864 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.38098741 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.6944970594 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3527383347 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.1574547813 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.9458279363 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.0655500827 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.4602220966 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3470225793 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.2602922276 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.3068774106 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2557209818 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7761513574 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.536935943 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6279180527 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.4521181898 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.7874165248 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7800308876 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2695551221 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.1658252845 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.5933640069 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.9600751418 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.0616550972 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.8704641604 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.473786348 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.2100793345 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.0259755579 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1688278101 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.3489735807 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.528424722 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3985712878 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.2109308081 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6541762325 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.4372604025 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0802981299 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1045401424 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1527123151 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8441462011 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4367559463 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9661777763 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.3837029353 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.8969204041 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0619327039 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.4808801063 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.547715771 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.5154259538 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.362323924 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.2953912839 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3707399971 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.6741611263 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7042981765 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.3279403266 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8019935012 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.283179142 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0030244011 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.8812926842 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0426759562 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.5975388355 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.4447843518 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.2180808285 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.759629602 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 6.2765270205 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.4378655057 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.7862868534 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0046154411 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0404934028 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.957522046 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.7226981916 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0520242656 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.070564505 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7760746627 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.97294055678 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.6231712224 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6882329659 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0216944873 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9724268047 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.48302745923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.6996097597 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.61859431569 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3576733868 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.332990299 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.9508912219 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1539077555 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4448063422 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3199295186 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.0134950561 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.3233415223 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.9606931477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.3838375929 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.6524383296 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 8.29897302992 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9755671998 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4531548244 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2521985647 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.0620489101 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.9828671443 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2847911751 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.911090582 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.753690646 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8320392208 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5858155443 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.4868526032 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.4044416715 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.3838067518 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5550410302 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9699946941 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.3025383674 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.4345534768 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.822682974 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.3664397988 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.0927599619 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.6080847562 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.002638783 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.051878591 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.5527134501 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.16733821821 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1359679577 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1904973483 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7142056535 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.5397914977 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.7814809725 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.5078974783 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9094409066 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.517926095 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9104512652 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8213671893 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8872236946 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4755362742 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4774026713 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3232646879 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.354186177 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3051014444 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.808633069 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.091631305 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.9855213999 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.2466083372 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.2343300246 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8696026553 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.0777107961 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1788232562 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8671267752 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.7307356171 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.0443078787 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9154798518 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.800153759 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 46.6377502964 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9878498835 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.4206857367 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.688001749 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.4595387246 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3082368498 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.0244873792 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3819688637 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.3139452308 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.8203010907 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.8355617611 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4826289235 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7837100816 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.8546268444 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1886623633 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.3889415359 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.301832252 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.8381851078 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.017096889 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.541501903 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 92.2341449145 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6188124064 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.1055096446 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.1339142668 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.0896190003 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.205746629 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.5556395104 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.3964625515 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.6761207722 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.5096986947 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.524708258 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.5265996678 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.9227392166 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.4004851401 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9123164899 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.937052621 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.8142553122 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.075219779 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0533853589 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4875510195 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 5.77204111687 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1783107806 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.9421455102 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1534756053 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.126651255 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.7980022703 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.7320072086 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5136308819 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.88936853 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.3018237659 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.7900394815 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.44233148574 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.2538849328 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.029362828 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.8808190851 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.6426444866 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.7702074515 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5668497375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.2563980916 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.3292799827 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.5512904056 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5815142865 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2283432785 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1957770405 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.06073412525 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.11863998334 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.6913311754 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.8125663309 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2161625342 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.5369248393 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.1764867692 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.4472892819 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.700174915 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3072511271 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.2823301989 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7332357926 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1346244188 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7056718214 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.9653434557 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 92.775989661 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.6827512093 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.9949296996 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.8064732753 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.3127965602 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.7243890497 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.3247334022 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.8898610212 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1271540582 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1291303423 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.36358342622 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0508271799 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.5514622287 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9454467107 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5445074571 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.7372957239 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.0107788347 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.97698160681 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6600982325 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.749093439 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.7973897939 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2898243281 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.50529178959 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.564868144 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.1880467133 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.3947272131 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.6406395993 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.9485440603 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.5664978208 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.9169684174 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.5196904114 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.0104012954 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.5042046265 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.5911813135 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.5124262116 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.49776319 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.347715254 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.0164316565 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6301042584 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9098432884 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.9094676369 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.6039802594 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3359907184 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.796322574 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.1117511839 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.6016156507 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.1810649978 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.8139157701 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.5395119337 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7911571664 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.9208380338 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.21487596 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8830024448 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8865610495 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.2425234283 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.6426338766 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.0782141495 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.8140531774 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.970069736 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.6788419746 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.2863090265 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.1811510458 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.985405356 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.3932507958 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.1102709364 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5882081493 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3774172798 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.5831508588 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.4304025503 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1654086684 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6124685962 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.353390328 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.0114520139 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2530732111 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2400608691 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0050744381 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.6210655566 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.635438453 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.059843605 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.5690682718 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8998426413 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.9793625507 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0594130716 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3690523857 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0730358448 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5976299638 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.6015239493 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.457266683 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.8024020321 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.1921179969 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.1705576076 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.4952898301 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.8662586872 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9721829055 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 61.5044515544 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0512880626 0
% INFO    : 
% INFO    : === Generator Bounds Update Notes ===
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% WARNING : Branch 7829-1968 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1815-792 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7829-6826 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-792 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1445-792 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-7279 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-8335 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-2449 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-4665 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5210-4495 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1445-7279 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1445-8335 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7829-5776 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1445-2449 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1445-4665 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Transformer 7637-8581 has a phase shift of -0.428189, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 5848-7526 has a phase shift of 0.178581, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 2154-5996 has a phase shift of -0.153178, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 549-5002 has a phase shift of 0.072386, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 3069-6115 has a phase shift of -0.072388, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 7256-4491 has a phase shift of 0.084507, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 6153-58 has a phase shift of -0.09784, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 749-4324 has a phase shift of 0.04898, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 7466-3649 has a phase shift of -0.06138, changing tap ratio 0.0 => 1.0
% WARNING : Branch 1747-6998 connects two different voltage levels (380.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 593-6998 connects two different voltage levels (380.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3190-7090 connects two different voltage levels (380.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3484-7090 connects two different voltage levels (380.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3484-7844 connects two different voltage levels (380.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4059-6282 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2002-4340 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 76-5346 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6477-2478 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5295-2478 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5825-702 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% INFO    : 
% INFO    : === Line Capacity UB Model Notes ===
% INFO    : Updated Thermal Rating: on line 5147-3097 : Rate B, Rate C , 0.0, 0.0 -> 5104
% INFO    : Updated Thermal Rating: on line 5147-8763 : Rate B, Rate C , 0.0, 0.0 -> 4259
% INFO    : Updated Thermal Rating: on line 427-5425 : Rate B, Rate C , 0.0, 0.0 -> 55004
% INFO    : Updated Thermal Rating: on line 427-4704 : Rate B, Rate C , 0.0, 0.0 -> 56085
% INFO    : Updated Thermal Rating: on line 5960-7431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1870
% INFO    : Updated Thermal Rating: on line 5960-3186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1907
% INFO    : Updated Thermal Rating: on line 4481-7431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1946
% INFO    : Updated Thermal Rating: on line 4481-3186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1733
% INFO    : Updated Thermal Rating: on line 5205-7833 : Rate B, Rate C , 0.0, 0.0 -> 2198
% INFO    : Updated Thermal Rating: on line 5205-7770 : Rate B, Rate C , 0.0, 0.0 -> 1968
% INFO    : Updated Thermal Rating: on line 5773-6542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26146
% INFO    : Updated Thermal Rating: on line 5773-7840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20335
% INFO    : Updated Thermal Rating: on line 5214-6542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6424
% INFO    : Updated Thermal Rating: on line 5214-7840 : Rate B, Rate C , 0.0, 0.0 -> 20703
% INFO    : Updated Thermal Rating: on line 2971-6069 : Rate B, Rate C , 0.0, 0.0 -> 7699
% INFO    : Updated Thermal Rating: on line 2971-3445 : Rate B, Rate C , 0.0, 0.0 -> 6278
% INFO    : Updated Thermal Rating: on line 7561-6069 : Rate B, Rate C , 0.0, 0.0 -> 4506
% INFO    : Updated Thermal Rating: on line 7561-8825 : Rate B, Rate C , 0.0, 0.0 -> 3909
% INFO    : Updated Thermal Rating: on line 7556-7058 : Rate B, Rate C , 0.0, 0.0 -> 1485
% INFO    : Updated Thermal Rating: on line 7556-4324 : Rate B, Rate C , 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 132-2962 : Rate B, Rate C , 0.0, 0.0 -> 4401
% INFO    : Updated Thermal Rating: on line 132-4393 : Rate B, Rate C , 0.0, 0.0 -> 4403
% INFO    : Updated Thermal Rating: on line 5044-693 : Rate B, Rate C , 0.0, 0.0 -> 5671
% INFO    : Updated Thermal Rating: on line 5044-7860 : Rate B, Rate C , 0.0, 0.0 -> 5562
% INFO    : Updated Thermal Rating: on line 6883-693 : Rate B, Rate C , 0.0, 0.0 -> 6006
% INFO    : Updated Thermal Rating: on line 6883-7860 : Rate B, Rate C , 0.0, 0.0 -> 6115
% INFO    : Updated Thermal Rating: on line 6494-4945 : Rate B, Rate C , 0.0, 0.0 -> 10550
% INFO    : Updated Thermal Rating: on line 6494-6080 : Rate B, Rate C , 0.0, 0.0 -> 10798
% INFO    : Updated Thermal Rating: on line 7146-7388 : Rate B, Rate C , 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on line 4735-5239 : Rate B, Rate C , 0.0, 0.0 -> 5881
% INFO    : Updated Thermal Rating: on line 4735-3145 : Rate B, Rate C , 0.0, 0.0 -> 5341
% INFO    : Updated Thermal Rating: on line 3615-8731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6495
% INFO    : Updated Thermal Rating: on line 3615-6246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7573
% INFO    : Updated Thermal Rating: on line 2549-7829 : Rate B, Rate C , 0.0, 0.0 -> 1280
% INFO    : Updated Thermal Rating: on line 2549-4951 : Rate B, Rate C , 0.0, 0.0 -> 1257
% INFO    : Updated Thermal Rating: on line 7004-3370 : Rate B, Rate C , 0.0, 0.0 -> 68669
% INFO    : Updated Thermal Rating: on line 8381-4795 : Rate B, Rate C , 0.0, 0.0 -> 5360
% INFO    : Updated Thermal Rating: on line 8381-5562 : Rate B, Rate C , 0.0, 0.0 -> 4727
% INFO    : Updated Thermal Rating: on line 3409-1716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5127
% INFO    : Updated Thermal Rating: on line 3409-6246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7737
% INFO    : Updated Thermal Rating: on line 1000-6145 : Rate B, Rate C , 0.0, 0.0 -> 2166
% INFO    : Updated Thermal Rating: on line 1000-3186 : Rate B, Rate C , 0.0, 0.0 -> 2336
% INFO    : Updated Thermal Rating: on line 6060-5289 : Rate B, Rate C , 0.0, 0.0 -> 29729
% INFO    : Updated Thermal Rating: on line 7965-5289 : Rate B, Rate C , 0.0, 0.0 -> 29329
% INFO    : Updated Thermal Rating: on line 4363-4507 : Rate B, Rate C , 0.0, 0.0 -> 4435
% INFO    : Updated Thermal Rating: on line 4363-6246 : Rate B, Rate C , 0.0, 0.0 -> 4517
% INFO    : Updated Thermal Rating: on line 425-7526 : Rate B, Rate C , 0.0, 0.0 -> 26451
% INFO    : Updated Thermal Rating: on line 425-5674 : Rate B, Rate C , 0.0, 0.0 -> 24227
% INFO    : Updated Thermal Rating: on line 4799-8581 : Rate B, Rate C , 0.0, 0.0 -> 26034
% INFO    : Updated Thermal Rating: on line 4799-4337 : Rate B, Rate C , 0.0, 0.0 -> 23508
% INFO    : Updated Thermal Rating: on line 4968-2154 : Rate B, Rate C , 0.0, 0.0 -> 6642
% INFO    : Updated Thermal Rating: on line 4968-1747 : Rate B, Rate C , 0.0, 0.0 -> 6733
% INFO    : Updated Thermal Rating: on line 7699-2154 : Rate B, Rate C , 0.0, 0.0 -> 5548
% INFO    : Updated Thermal Rating: on line 7699-1689 : Rate B, Rate C , 0.0, 0.0 -> 4721
% INFO    : Updated Thermal Rating: on line 3097-659 : Rate B, Rate C , 0.0, 0.0 -> 3480
% INFO    : Updated Thermal Rating: on line 9024-4929 : Rate B, Rate C , 0.0, 0.0 -> 1371
% INFO    : Updated Thermal Rating: on line 1815-6542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 6542-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 6069-6833 : Rate B, Rate C , 0.0, 0.0 -> 6748
% INFO    : Updated Thermal Rating: on line 6069-2268 : Rate B, Rate C , 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 6069-7180 : Rate B, Rate C , 0.0, 0.0 -> 5970
% INFO    : Updated Thermal Rating: on line 6069-6293 : Rate B, Rate C , 0.0, 0.0 -> 3355
% INFO    : Updated Thermal Rating: on line 1968-9192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8992
% INFO    : Updated Thermal Rating: on line 1968-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 1968-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 1968-228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 1968-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 1968-8964 : Rate B, Rate C , 0.0, 0.0 -> 2595
% INFO    : Updated Thermal Rating: on line 1968-5776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 9192-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on line 9192-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 9192-8964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 8574-1616 : Rate B, Rate C , 0.0, 0.0 -> 8142
% INFO    : Updated Thermal Rating: on line 8574-1163 : Rate B, Rate C , 0.0, 0.0 -> 2766
% INFO    : Updated Thermal Rating: on line 8574-9064 : Rate B, Rate C , 0.0, 0.0 -> 9657
% INFO    : Updated Thermal Rating: on line 8574-8921 : Rate B, Rate C , 0.0, 0.0 -> 9284
% INFO    : Updated Thermal Rating: on line 3493-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 2299-4423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6826-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 7563-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 4427-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 8335-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 5155-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 271-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 2449-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 4665-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 4495-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 3493-5587 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4586-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 228-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 6826-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on line 7563-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 4427-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 8335-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 5155-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 271-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 5776-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 2449-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 4665-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on line 4495-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 5587-4586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 4423-4586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1544
% INFO    : Updated Thermal Rating: on line 4929-2870 : Rate B, Rate C , 0.0, 0.0 -> 76679
% INFO    : Updated Thermal Rating: on line 4929-659 : Rate B, Rate C , 0.0, 0.0 -> 2897
% INFO    : Updated Thermal Rating: on line 4929-1037 : Rate B, Rate C , 0.0, 0.0 -> 68410
% INFO    : Updated Thermal Rating: on line 4929-659 : Rate B, Rate C , 0.0, 0.0 -> 3401
% INFO    : Updated Thermal Rating: on line 1815-5210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 1815-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 1616-7762 : Rate B, Rate C , 0.0, 0.0 -> 9780
% INFO    : Updated Thermal Rating: on line 1616-2520 : Rate B, Rate C , 0.0, 0.0 -> 6432
% INFO    : Updated Thermal Rating: on line 9064-7762 : Rate B, Rate C , 0.0, 0.0 -> 8942
% INFO    : Updated Thermal Rating: on line 9064-89 : Rate B, Rate C , 0.0, 0.0 -> 6915
% INFO    : Updated Thermal Rating: on line 1317-659 : Rate B, Rate C , 0.0, 0.0 -> 4217
% INFO    : Updated Thermal Rating: on line 1317-8605 : Rate B, Rate C , 0.0, 0.0 -> 3079
% INFO    : Updated Thermal Rating: on line 8605-1367 : Rate B, Rate C , 0.0, 0.0 -> 78577
% INFO    : Updated Thermal Rating: on line 8605-8921 : Rate B, Rate C , 0.0, 0.0 -> 4498
% INFO    : Updated Thermal Rating: on line 1163-1676 : Rate B, Rate C , 0.0, 0.0 -> 73144
% INFO    : Updated Thermal Rating: on line 1163-7051 : Rate B, Rate C , 0.0, 0.0 -> 10190
% INFO    : Updated Thermal Rating: on line 913-7762 : Rate B, Rate C , 0.0, 0.0 -> 5849
% INFO    : Updated Thermal Rating: on line 2107-7762 : Rate B, Rate C , 0.0, 0.0 -> 5744
% INFO    : Updated Thermal Rating: on line 2107-5996 : Rate B, Rate C , 0.0, 0.0 -> 18181
% INFO    : Updated Thermal Rating: on line 2107-6293 : Rate B, Rate C , 0.0, 0.0 -> 2134
% INFO    : Updated Thermal Rating: on line 913-7762 : Rate B, Rate C , 0.0, 0.0 -> 6140
% INFO    : Updated Thermal Rating: on line 6704-8921 : Rate B, Rate C , 0.0, 0.0 -> 12692
% INFO    : Updated Thermal Rating: on line 228-4586 : Rate B, Rate C , 0.0, 0.0 -> 1428
% INFO    : Updated Thermal Rating: on line 2441-6293 : Rate B, Rate C , 0.0, 0.0 -> 10893
% INFO    : Updated Thermal Rating: on line 955-3506 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 955-8964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 3506-2908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 228-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 228-5776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 8964-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 5776-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2682
% INFO    : Updated Thermal Rating: on line 659-8329 : Rate B, Rate C , 0.0, 0.0 -> 10293
% INFO    : Updated Thermal Rating: on line 659-7051 : Rate B, Rate C , 0.0, 0.0 -> 2505
% INFO    : Updated Thermal Rating: on line 659-9239 : Rate B, Rate C , 0.0, 0.0 -> 48391
% INFO    : Updated Thermal Rating: on line 659-7960 : Rate B, Rate C , 0.0, 0.0 -> 49913
% INFO    : Updated Thermal Rating: on line 659-6233 : Rate B, Rate C , 0.0, 0.0 -> 57093
% INFO    : Updated Thermal Rating: on line 659-5416 : Rate B, Rate C , 0.0, 0.0 -> 3253
% INFO    : Updated Thermal Rating: on line 659-6798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39828
% INFO    : Updated Thermal Rating: on line 792-3279 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7563-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 7279-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 8335-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 2449-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on line 4665-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 4495-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 5416-2267 : Rate B, Rate C , 0.0, 0.0 -> 14737
% INFO    : Updated Thermal Rating: on line 5416-7637 : Rate B, Rate C , 0.0, 0.0 -> 3554
% INFO    : Updated Thermal Rating: on line 8964-2168 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3659-5996 : Rate B, Rate C , 0.0, 0.0 -> 15425
% INFO    : Updated Thermal Rating: on line 5762-5996 : Rate B, Rate C , 0.0, 0.0 -> 15130
% INFO    : Updated Thermal Rating: on line 3242-5097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7563-3242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 4427-3242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 3242-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 271-3242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 3242-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on line 5097-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 8181-8179 : Rate B, Rate C , 0.0, 0.0 -> 9918
% INFO    : Updated Thermal Rating: on line 8181-7762 : Rate B, Rate C , 0.0, 0.0 -> 6320
% INFO    : Updated Thermal Rating: on line 9025-7762 : Rate B, Rate C , 0.0, 0.0 -> 6197
% INFO    : Updated Thermal Rating: on line 7563-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 7563-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 7563-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 7563-5155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 7563-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 2449-7563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 4665-7563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 4495-7563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 7563-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 4427-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 4427-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 4427-5155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 4427-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on line 2449-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 4665-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 4495-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 4427-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 5210-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1817
% INFO    : Updated Thermal Rating: on line 8179-5509 : Rate B, Rate C , 0.0, 0.0 -> 4526
% INFO    : Updated Thermal Rating: on line 8179-7762 : Rate B, Rate C , 0.0, 0.0 -> 3935
% INFO    : Updated Thermal Rating: on line 7279-4014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8335-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1017
% INFO    : Updated Thermal Rating: on line 5155-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 271-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 2449-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 4665-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 4495-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 1611-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5509-1579 : Rate B, Rate C , 0.0, 0.0 -> 3513
% INFO    : Updated Thermal Rating: on line 8335-1531 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5155-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 2449-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 4665-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 4495-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 7762-2268 : Rate B, Rate C , 0.0, 0.0 -> 4051
% INFO    : Updated Thermal Rating: on line 5155-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 5155-2908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 520
% INFO    : Updated Thermal Rating: on line 4665-5155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 4495-5155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 5155-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 271-2908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 4665-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 4495-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 271-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 1579-5848 : Rate B, Rate C , 0.0, 0.0 -> 8673
% INFO    : Updated Thermal Rating: on line 7051-8847 : Rate B, Rate C , 0.0, 0.0 -> 17783
% INFO    : Updated Thermal Rating: on line 5776-8229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 317-6233 : Rate B, Rate C , 0.0, 0.0 -> 142990
% INFO    : Updated Thermal Rating: on line 4665-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 2449-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 4665-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 970
% INFO    : Updated Thermal Rating: on line 1611-8420 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6561-1294 : Rate B, Rate C , 0.0, 0.0 -> 1631
% INFO    : Updated Thermal Rating: on line 6561-1666 : Rate B, Rate C , 0.0, 0.0 -> 1230
% INFO    : Updated Thermal Rating: on line 6561-4096 : Rate B, Rate C , 0.0, 0.0 -> 1300
% INFO    : Updated Thermal Rating: on line 4717-4241 : Rate B, Rate C , 0.0, 0.0 -> 1610
% INFO    : Updated Thermal Rating: on line 4241-7395 : Rate B, Rate C , 0.0, 0.0 -> 8057
% INFO    : Updated Thermal Rating: on line 4241-5873 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on line 1479-4241 : Rate B, Rate C , 0.0, 0.0 -> 4156
% INFO    : Updated Thermal Rating: on line 4241-1475 : Rate B, Rate C , 0.0, 0.0 -> 11190
% INFO    : Updated Thermal Rating: on line 4241-1475 : Rate B, Rate C , 0.0, 0.0 -> 11000
% INFO    : Updated Thermal Rating: on line 2248-264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14703
% INFO    : Updated Thermal Rating: on line 2248-8530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10463
% INFO    : Updated Thermal Rating: on line 3744-4806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3419
% INFO    : Updated Thermal Rating: on line 3744-6239 : Rate B, Rate C , 0.0, 0.0 -> 943
% INFO    : Updated Thermal Rating: on line 5991-8671 : Rate B, Rate C , 0.0, 0.0 -> 5114
% INFO    : Updated Thermal Rating: on line 5991-201 : Rate B, Rate C , 0.0, 0.0 -> 1369
% INFO    : Updated Thermal Rating: on line 5991-3512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on line 5991-1430 : Rate B, Rate C , 0.0, 0.0 -> 1067
% INFO    : Updated Thermal Rating: on line 5991-5592 : Rate B, Rate C , 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 5991-4953 : Rate B, Rate C , 0.0, 0.0 -> 2193
% INFO    : Updated Thermal Rating: on line 5991-2355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2167
% INFO    : Updated Thermal Rating: on line 4510-2957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23296
% INFO    : Updated Thermal Rating: on line 4510-6936 : Rate B, Rate C , 0.0, 0.0 -> 4041
% INFO    : Updated Thermal Rating: on line 5697-5933 : Rate B, Rate C , 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on line 5697-6040 : Rate B, Rate C , 0.0, 0.0 -> 1507
% INFO    : Updated Thermal Rating: on line 5189-2917 : Rate B, Rate C , 0.0, 0.0 -> 26594
% INFO    : Updated Thermal Rating: on line 2917-6654 : Rate B, Rate C , 0.0, 0.0 -> 12676
% INFO    : Updated Thermal Rating: on line 6679-7139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8116
% INFO    : Updated Thermal Rating: on line 6679-6134 : Rate B, Rate C , 0.0, 0.0 -> 3780
% INFO    : Updated Thermal Rating: on line 6679-6134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3861
% INFO    : Updated Thermal Rating: on line 7413-6679 : Rate B, Rate C , 0.0, 0.0 -> 12252
% INFO    : Updated Thermal Rating: on line 5189-6456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31096
% INFO    : Updated Thermal Rating: on line 2358-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41388
% INFO    : Updated Thermal Rating: on line 2358-8571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8026
% INFO    : Updated Thermal Rating: on line 4717-8247 : Rate B, Rate C , 0.0, 0.0 -> 1712
% INFO    : Updated Thermal Rating: on line 5787-1393 : Rate B, Rate C , 0.0, 0.0 -> 533
% INFO    : Updated Thermal Rating: on line 5787-6243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 5787-8338 : Rate B, Rate C , 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 5787-751 : Rate B, Rate C , 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on line 8285-4293 : Rate B, Rate C , 0.0, 0.0 -> 15598
% INFO    : Updated Thermal Rating: on line 7392-4293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17534
% INFO    : Updated Thermal Rating: on line 6632-930 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 1024
% INFO    : Updated Thermal Rating: on line 930-4407 : Rate B, Rate C , 0.0, 0.0 -> 2231
% INFO    : Updated Thermal Rating: on line 7834-6596 : Rate B, Rate C , 0.0, 0.0 -> 624
% INFO    : Updated Thermal Rating: on line 7834-5592 : Rate B, Rate C , 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 1418-3633 : Rate B, Rate C , 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 1418-7820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6356
% INFO    : Updated Thermal Rating: on line 2921-6093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4153
% INFO    : Updated Thermal Rating: on line 2921-3487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3354
% INFO    : Updated Thermal Rating: on line 8353-3633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2211
% INFO    : Updated Thermal Rating: on line 8353-3633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2256
% INFO    : Updated Thermal Rating: on line 8353-6904 : Rate B, Rate C , 0.0, 0.0 -> 6776
% INFO    : Updated Thermal Rating: on line 8353-6625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2952
% INFO    : Updated Thermal Rating: on line 6261-1872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3683
% INFO    : Updated Thermal Rating: on line 1872-7973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4498
% INFO    : Updated Thermal Rating: on line 1872-7973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4587
% INFO    : Updated Thermal Rating: on line 1872-4651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13186
% INFO    : Updated Thermal Rating: on line 710-6499 : Rate B, Rate C , 0.0, 0.0 -> 3316
% INFO    : Updated Thermal Rating: on line 710-3792 : Rate B, Rate C , 0.0, 0.0 -> 841
% INFO    : Updated Thermal Rating: on line 2193-6717 : Rate B, Rate C , 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 2193-4752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1770
% INFO    : Updated Thermal Rating: on line 7644-6499 : Rate B, Rate C , 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 7644-6769 : Rate B, Rate C , 0.0, 0.0 -> 894
% INFO    : Updated Thermal Rating: on line 7644-7075 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 7644-8213 : Rate B, Rate C , 0.0, 0.0 -> 6593
% INFO    : Updated Thermal Rating: on line 7644-8213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6473
% INFO    : Updated Thermal Rating: on line 6632-2507 : Rate B, Rate C , 0.0, 0.0 -> 2883
% INFO    : Updated Thermal Rating: on line 2507-6917 : Rate B, Rate C , 0.0, 0.0 -> 2864
% INFO    : Updated Thermal Rating: on line 3095-2951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8627
% INFO    : Updated Thermal Rating: on line 3095-7820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3865
% INFO    : Updated Thermal Rating: on line 5425-1898 : Rate B, Rate C , 0.0, 0.0 -> 7118
% INFO    : Updated Thermal Rating: on line 5425-1498 : Rate A, Rate B, Rate C , 1711.0, 0.0, 0.0 -> 1223
% INFO    : Updated Thermal Rating: on line 5425-1280 : Rate B, Rate C , 0.0, 0.0 -> 8552
% INFO    : Updated Thermal Rating: on line 7431-4279 : Rate B, Rate C , 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 7431-4279 : Rate B, Rate C , 0.0, 0.0 -> 1868
% INFO    : Updated Thermal Rating: on line 7431-4279 : Rate B, Rate C , 0.0, 0.0 -> 1931
% INFO    : Updated Thermal Rating: on line 7431-4279 : Rate B, Rate C , 0.0, 0.0 -> 2083
% INFO    : Updated Thermal Rating: on line 2343-5946 : Rate B, Rate C , 0.0, 0.0 -> 867
% INFO    : Updated Thermal Rating: on line 2236-5946 : Rate B, Rate C , 0.0, 0.0 -> 3276
% INFO    : Updated Thermal Rating: on line 3821-1173 : Rate B, Rate C , 0.0, 0.0 -> 1044
% INFO    : Updated Thermal Rating: on line 3821-6936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5357
% INFO    : Updated Thermal Rating: on line 3821-6936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4739
% INFO    : Updated Thermal Rating: on line 3821-2946 : Rate A, Rate B, Rate C , 533.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 6261-3065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7988
% INFO    : Updated Thermal Rating: on line 4124-3378 : Rate B, Rate C , 0.0, 0.0 -> 4304
% INFO    : Updated Thermal Rating: on line 4124-3378 : Rate B, Rate C , 0.0, 0.0 -> 5056
% INFO    : Updated Thermal Rating: on line 4124-4809 : Rate B, Rate C , 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on line 4124-4750 : Rate B, Rate C , 0.0, 0.0 -> 1706
% INFO    : Updated Thermal Rating: on line 6663-5217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9272
% INFO    : Updated Thermal Rating: on line 6663-4096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3074
% INFO    : Updated Thermal Rating: on line 6663-4096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3016
% INFO    : Updated Thermal Rating: on line 4855-509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1875
% INFO    : Updated Thermal Rating: on line 9162-509 : Rate B, Rate C , 0.0, 0.0 -> 13059
% INFO    : Updated Thermal Rating: on line 6769-6964 : Rate B, Rate C , 0.0, 0.0 -> 1098
% INFO    : Updated Thermal Rating: on line 6964-7002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 6964-6879 : Rate B, Rate C , 0.0, 0.0 -> 2825
% INFO    : Updated Thermal Rating: on line 6632-6917 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1322
% INFO    : Updated Thermal Rating: on line 6632-8870 : Rate A, Rate B, Rate C , 1218.0, 0.0, 0.0 -> 872
% INFO    : Updated Thermal Rating: on line 6632-8870 : Rate A, Rate B, Rate C , 1283.0, 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 8504-6632 : Rate B, Rate C , 0.0, 0.0 -> 1854
% INFO    : Updated Thermal Rating: on line 6632-2730 : Rate A, Rate B, Rate C , 1251.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 6632-7508 : Rate A, Rate B, Rate C , 1316.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on line 6632-385 : Rate A, Rate B, Rate C , 1711.0, 0.0, 0.0 -> 1013
% INFO    : Updated Thermal Rating: on line 6632-385 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 3650-8858 : Rate B, Rate C , 0.0, 0.0 -> 8387
% INFO    : Updated Thermal Rating: on line 3650-8858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12492
% INFO    : Updated Thermal Rating: on line 3650-8858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12784
% INFO    : Updated Thermal Rating: on line 3650-4856 : Rate B, Rate C , 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on line 1618-1060 : Rate A, Rate B, Rate C , 1382.0, 0.0, 0.0 -> 1039
% INFO    : Updated Thermal Rating: on line 1618-8806 : Rate A, Rate B, Rate C , 757.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 8547-6669 : Rate B, Rate C , 0.0, 0.0 -> 1429
% INFO    : Updated Thermal Rating: on line 8547-7398 : Rate B, Rate C , 0.0, 0.0 -> 1085
% INFO    : Updated Thermal Rating: on line 8124-2496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6637
% INFO    : Updated Thermal Rating: on line 8419-2496 : Rate B, Rate C , 0.0, 0.0 -> 3924
% INFO    : Updated Thermal Rating: on line 5125-2916 : Rate B, Rate C , 0.0, 0.0 -> 9690
% INFO    : Updated Thermal Rating: on line 5125-8973 : Rate B, Rate C , 0.0, 0.0 -> 3594
% INFO    : Updated Thermal Rating: on line 2471-8888 : Rate B, Rate C , 0.0, 0.0 -> 604
% INFO    : Updated Thermal Rating: on line 2471-4906 : Rate B, Rate C , 0.0, 0.0 -> 886
% INFO    : Updated Thermal Rating: on line 3076-2471 : Rate B, Rate C , 0.0, 0.0 -> 2522
% INFO    : Updated Thermal Rating: on line 4182-2235 : Rate B, Rate C , 0.0, 0.0 -> 7026
% INFO    : Updated Thermal Rating: on line 4182-5873 : Rate B, Rate C , 0.0, 0.0 -> 2795
% INFO    : Updated Thermal Rating: on line 42-5919 : Rate B, Rate C , 0.0, 0.0 -> 5067
% INFO    : Updated Thermal Rating: on line 42-2096 : Rate B, Rate C , 0.0, 0.0 -> 2435
% INFO    : Updated Thermal Rating: on line 6292-6127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1668
% INFO    : Updated Thermal Rating: on line 6292-6127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on line 6292-2658 : Rate B, Rate C , 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 6292-5191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 905
% INFO    : Updated Thermal Rating: on line 929-1175 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 929-1344 : Rate B, Rate C , 0.0, 0.0 -> 2112
% INFO    : Updated Thermal Rating: on line 8671-1421 : Rate B, Rate C , 0.0, 0.0 -> 2894
% INFO    : Updated Thermal Rating: on line 709-4652 : Rate A, Rate B, Rate C , 1810.0, 0.0, 0.0 -> 1448
% INFO    : Updated Thermal Rating: on line 709-3587 : Rate B, Rate C , 0.0, 0.0 -> 1976
% INFO    : Updated Thermal Rating: on line 8159-3798 : Rate B, Rate C , 0.0, 0.0 -> 2602
% INFO    : Updated Thermal Rating: on line 8159-2261 : Rate B, Rate C , 0.0, 0.0 -> 1680
% INFO    : Updated Thermal Rating: on line 8159-7755 : Rate B, Rate C , 0.0, 0.0 -> 1931
% INFO    : Updated Thermal Rating: on line 8159-7287 : Rate B, Rate C , 0.0, 0.0 -> 5592
% INFO    : Updated Thermal Rating: on line 8159-7287 : Rate B, Rate C , 0.0, 0.0 -> 5497
% INFO    : Updated Thermal Rating: on line 8159-6496 : Rate B, Rate C , 0.0, 0.0 -> 4783
% INFO    : Updated Thermal Rating: on line 8159-5372 : Rate B, Rate C , 0.0, 0.0 -> 3837
% INFO    : Updated Thermal Rating: on line 8159-807 : Rate B, Rate C , 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 201-8582 : Rate B, Rate C , 0.0, 0.0 -> 2756
% INFO    : Updated Thermal Rating: on line 3193-7053 : Rate B, Rate C , 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 3193-2764 : Rate A, Rate B, Rate C , 1185.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 3193-2764 : Rate A, Rate B, Rate C , 1152.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 3193-1498 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 1483
% INFO    : Updated Thermal Rating: on line 3193-1133 : Rate B, Rate C , 0.0, 0.0 -> 1623
% INFO    : Updated Thermal Rating: on line 3193-1133 : Rate B, Rate C , 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on line 2301-3427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6640
% INFO    : Updated Thermal Rating: on line 2301-8575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5582
% INFO    : Updated Thermal Rating: on line 4644-1086 : Rate B, Rate C , 0.0, 0.0 -> 2374
% INFO    : Updated Thermal Rating: on line 4644-2849 : Rate B, Rate C , 0.0, 0.0 -> 4919
% INFO    : Updated Thermal Rating: on line 1458-2459 : Rate A, Rate B, Rate C , 1810.0, 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on line 1458-477 : Rate B, Rate C , 0.0, 0.0 -> 2414
% INFO    : Updated Thermal Rating: on line 1458-477 : Rate B, Rate C , 0.0, 0.0 -> 2466
% INFO    : Updated Thermal Rating: on line 1458-8210 : Rate B, Rate C , 0.0, 0.0 -> 2419
% INFO    : Updated Thermal Rating: on line 1458-3113 : Rate B, Rate C , 0.0, 0.0 -> 1531
% INFO    : Updated Thermal Rating: on line 1458-8987 : Rate B, Rate C , 0.0, 0.0 -> 1650
% INFO    : Updated Thermal Rating: on line 3065-4450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3617
% INFO    : Updated Thermal Rating: on line 4450-1501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9950
% INFO    : Updated Thermal Rating: on line 1185-706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10265
% INFO    : Updated Thermal Rating: on line 1240-706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 3500-8871 : Rate B, Rate C , 0.0, 0.0 -> 4628
% INFO    : Updated Thermal Rating: on line 3500-8582 : Rate B, Rate C , 0.0, 0.0 -> 2225
% INFO    : Updated Thermal Rating: on line 6359-6783 : Rate B, Rate C , 0.0, 0.0 -> 71587
% INFO    : Updated Thermal Rating: on line 6454-6359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60477
% INFO    : Updated Thermal Rating: on line 7833-8438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3823
% INFO    : Updated Thermal Rating: on line 7833-8438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3655
% INFO    : Updated Thermal Rating: on line 4253-7196 : Rate B, Rate C , 0.0, 0.0 -> 1679
% INFO    : Updated Thermal Rating: on line 4253-4651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13035
% INFO    : Updated Thermal Rating: on line 4230-1912 : Rate B, Rate C , 0.0, 0.0 -> 3747
% INFO    : Updated Thermal Rating: on line 4230-6315 : Rate B, Rate C , 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on line 621-4360 : Rate B, Rate C , 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 621-808 : Rate B, Rate C , 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 2962-6917 : Rate B, Rate C , 0.0, 0.0 -> 2107
% INFO    : Updated Thermal Rating: on line 2962-6917 : Rate B, Rate C , 0.0, 0.0 -> 2067
% INFO    : Updated Thermal Rating: on line 4958-4906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5181
% INFO    : Updated Thermal Rating: on line 4958-4906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5289
% INFO    : Updated Thermal Rating: on line 2642-5823 : Rate B, Rate C , 0.0, 0.0 -> 1826
% INFO    : Updated Thermal Rating: on line 2642-1947 : Rate B, Rate C , 0.0, 0.0 -> 2543
% INFO    : Updated Thermal Rating: on line 2642-3966 : Rate A, Rate B, Rate C , 1349.0, 0.0, 0.0 -> 1095
% INFO    : Updated Thermal Rating: on line 2642-1074 : Rate A, Rate B, Rate C , 1218.0, 0.0, 0.0 -> 947
% INFO    : Updated Thermal Rating: on line 2642-1074 : Rate A, Rate B, Rate C , 1448.0, 0.0, 0.0 -> 1022
% INFO    : Updated Thermal Rating: on line 2642-807 : Rate B, Rate C , 0.0, 0.0 -> 1120
% INFO    : Updated Thermal Rating: on line 4165-6659 : Rate B, Rate C , 0.0, 0.0 -> 1849
% INFO    : Updated Thermal Rating: on line 4165-7303 : Rate B, Rate C , 0.0, 0.0 -> 15031
% INFO    : Updated Thermal Rating: on line 1793-2668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6224
% INFO    : Updated Thermal Rating: on line 1793-8338 : Rate B, Rate C , 0.0, 0.0 -> 7103
% INFO    : Updated Thermal Rating: on line 1793-8338 : Rate B, Rate C , 0.0, 0.0 -> 7261
% INFO    : Updated Thermal Rating: on line 4663-6443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5655
% INFO    : Updated Thermal Rating: on line 4663-519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2044
% INFO    : Updated Thermal Rating: on line 4663-595 : Rate B, Rate C , 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 4663-3291 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 6138-7504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1756
% INFO    : Updated Thermal Rating: on line 6138-2896 : Rate B, Rate C , 0.0, 0.0 -> 1795
% INFO    : Updated Thermal Rating: on line 5280-2343 : Rate A, Rate B, Rate C , 514.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on line 8534-5121 : Rate B, Rate C , 0.0, 0.0 -> 5999
% INFO    : Updated Thermal Rating: on line 5121-9039 : Rate B, Rate C , 0.0, 0.0 -> 3029
% INFO    : Updated Thermal Rating: on line 3961-4238 : Rate B, Rate C , 0.0, 0.0 -> 3610
% INFO    : Updated Thermal Rating: on line 3961-1411 : Rate B, Rate C , 0.0, 0.0 -> 4064
% INFO    : Updated Thermal Rating: on line 3961-5793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24666
% INFO    : Updated Thermal Rating: on line 3961-5793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21853
% INFO    : Updated Thermal Rating: on line 976-1549 : Rate B, Rate C , 0.0, 0.0 -> 2939
% INFO    : Updated Thermal Rating: on line 976-4600 : Rate B, Rate C , 0.0, 0.0 -> 4755
% INFO    : Updated Thermal Rating: on line 976-2800 : Rate B, Rate C , 0.0, 0.0 -> 7380
% INFO    : Updated Thermal Rating: on line 976-2800 : Rate B, Rate C , 0.0, 0.0 -> 4848
% INFO    : Updated Thermal Rating: on line 1600-8186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24216
% INFO    : Updated Thermal Rating: on line 1600-4011 : Rate B, Rate C , 0.0, 0.0 -> 32573
% INFO    : Updated Thermal Rating: on line 5771-2235 : Rate B, Rate C , 0.0, 0.0 -> 2448
% INFO    : Updated Thermal Rating: on line 5771-5239 : Rate B, Rate C , 0.0, 0.0 -> 5444
% INFO    : Updated Thermal Rating: on line 9216-1409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104253
% INFO    : Updated Thermal Rating: on line 9216-1409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110496
% INFO    : Updated Thermal Rating: on line 9216-6597 : Rate B, Rate C , 0.0, 0.0 -> 11548
% INFO    : Updated Thermal Rating: on line 9216-6836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14708
% INFO    : Updated Thermal Rating: on line 9216-15 : Rate B, Rate C , 0.0, 0.0 -> 21494
% INFO    : Updated Thermal Rating: on line 429-6132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1373
% INFO    : Updated Thermal Rating: on line 6660-6132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1567
% INFO    : Updated Thermal Rating: on line 1439-649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55271
% INFO    : Updated Thermal Rating: on line 649-6836 : Rate B, Rate C , 0.0, 0.0 -> 49903
% INFO    : Updated Thermal Rating: on line 8417-5435 : Rate B, Rate C , 0.0, 0.0 -> 3315
% INFO    : Updated Thermal Rating: on line 8417-5435 : Rate B, Rate C , 0.0, 0.0 -> 3470
% INFO    : Updated Thermal Rating: on line 8417-4058 : Rate B, Rate C , 0.0, 0.0 -> 82471
% INFO    : Updated Thermal Rating: on line 5617-9055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1713
% INFO    : Updated Thermal Rating: on line 5617-1471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7996
% INFO    : Updated Thermal Rating: on line 8396-7925 : Rate B, Rate C , 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 8806-7925 : Rate B, Rate C , 0.0, 0.0 -> 3471
% INFO    : Updated Thermal Rating: on line 4542-1947 : Rate B, Rate C , 0.0, 0.0 -> 1999
% INFO    : Updated Thermal Rating: on line 4542-8337 : Rate B, Rate C , 0.0, 0.0 -> 11456
% INFO    : Updated Thermal Rating: on line 4542-3966 : Rate B, Rate C , 0.0, 0.0 -> 5592
% INFO    : Updated Thermal Rating: on line 4542-3544 : Rate B, Rate C , 0.0, 0.0 -> 4363
% INFO    : Updated Thermal Rating: on line 7510-4806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1856
% INFO    : Updated Thermal Rating: on line 7510-2907 : Rate B, Rate C , 0.0, 0.0 -> 2457
% INFO    : Updated Thermal Rating: on line 7510-2907 : Rate B, Rate C , 0.0, 0.0 -> 2414
% INFO    : Updated Thermal Rating: on line 7510-4338 : Rate B, Rate C , 0.0, 0.0 -> 1345
% INFO    : Updated Thermal Rating: on line 7510-1282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3421
% INFO    : Updated Thermal Rating: on line 7510-7795 : Rate B, Rate C , 0.0, 0.0 -> 5450
% INFO    : Updated Thermal Rating: on line 7510-3382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3377
% INFO    : Updated Thermal Rating: on line 7510-6456 : Rate B, Rate C , 0.0, 0.0 -> 2972
% INFO    : Updated Thermal Rating: on line 5409-8352 : Rate B, Rate C , 0.0, 0.0 -> 7394
% INFO    : Updated Thermal Rating: on line 5409-797 : Rate B, Rate C , 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 5409-8207 : Rate B, Rate C , 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 5409-1241 : Rate B, Rate C , 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on line 2416-5042 : Rate B, Rate C , 0.0, 0.0 -> 1052
% INFO    : Updated Thermal Rating: on line 2416-2764 : Rate B, Rate C , 0.0, 0.0 -> 3575
% INFO    : Updated Thermal Rating: on line 2416-2764 : Rate B, Rate C , 0.0, 0.0 -> 3270
% INFO    : Updated Thermal Rating: on line 2416-179 : Rate B, Rate C , 0.0, 0.0 -> 1415
% INFO    : Updated Thermal Rating: on line 9001-5463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4911
% INFO    : Updated Thermal Rating: on line 9001-445 : Rate B, Rate C , 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 4809-2538 : Rate B, Rate C , 0.0, 0.0 -> 1387
% INFO    : Updated Thermal Rating: on line 2538-6397 : Rate B, Rate C , 0.0, 0.0 -> 2303
% INFO    : Updated Thermal Rating: on line 2081-4556 : Rate B, Rate C , 0.0, 0.0 -> 2588
% INFO    : Updated Thermal Rating: on line 2081-4592 : Rate B, Rate C , 0.0, 0.0 -> 10303
% INFO    : Updated Thermal Rating: on line 3592-267 : Rate B, Rate C , 0.0, 0.0 -> 1322
% INFO    : Updated Thermal Rating: on line 3592-4632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2431
% INFO    : Updated Thermal Rating: on line 3592-4632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2388
% INFO    : Updated Thermal Rating: on line 1549-579 : Rate B, Rate C , 0.0, 0.0 -> 4009
% INFO    : Updated Thermal Rating: on line 1549-9117 : Rate B, Rate C , 0.0, 0.0 -> 5144
% INFO    : Updated Thermal Rating: on line 3282-7145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3451
% INFO    : Updated Thermal Rating: on line 3282-4855 : Rate B, Rate C , 0.0, 0.0 -> 1464
% INFO    : Updated Thermal Rating: on line 3282-4855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on line 3282-4095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2782
% INFO    : Updated Thermal Rating: on line 8285-699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3578
% INFO    : Updated Thermal Rating: on line 8285-6882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13271
% INFO    : Updated Thermal Rating: on line 8285-7820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5792
% INFO    : Updated Thermal Rating: on line 267-7349 : Rate B, Rate C , 0.0, 0.0 -> 1299
% INFO    : Updated Thermal Rating: on line 1200-8731 : Rate B, Rate C , 0.0, 0.0 -> 4024
% INFO    : Updated Thermal Rating: on line 1200-1716 : Rate B, Rate C , 0.0, 0.0 -> 7271
% INFO    : Updated Thermal Rating: on line 1200-3067 : Rate B, Rate C , 0.0, 0.0 -> 5104
% INFO    : Updated Thermal Rating: on line 1200-1074 : Rate B, Rate C , 0.0, 0.0 -> 2080
% INFO    : Updated Thermal Rating: on line 3549-6544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1701
% INFO    : Updated Thermal Rating: on line 3549-1503 : Rate B, Rate C , 0.0, 0.0 -> 972
% INFO    : Updated Thermal Rating: on line 1409-3715 : Rate B, Rate C , 0.0, 0.0 -> 22904
% INFO    : Updated Thermal Rating: on line 1409-6836 : Rate B, Rate C , 0.0, 0.0 -> 20247
% INFO    : Updated Thermal Rating: on line 1409-5892 : Rate B, Rate C , 0.0, 0.0 -> 24553
% INFO    : Updated Thermal Rating: on line 1409-5948 : Rate B, Rate C , 0.0, 0.0 -> 14593
% INFO    : Updated Thermal Rating: on line 4407-2962 : Rate B, Rate C , 0.0, 0.0 -> 3376
% INFO    : Updated Thermal Rating: on line 4407-2437 : Rate B, Rate C , 0.0, 0.0 -> 1860
% INFO    : Updated Thermal Rating: on line 7058-5163 : Rate B, Rate C , 0.0, 0.0 -> 2767
% INFO    : Updated Thermal Rating: on line 236-8236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3650
% INFO    : Updated Thermal Rating: on line 236-3427 : Rate B, Rate C , 0.0, 0.0 -> 7127
% INFO    : Updated Thermal Rating: on line 2916-5884 : Rate B, Rate C , 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 2916-4315 : Rate B, Rate C , 0.0, 0.0 -> 1724
% INFO    : Updated Thermal Rating: on line 2916-4315 : Rate B, Rate C , 0.0, 0.0 -> 1692
% INFO    : Updated Thermal Rating: on line 2962-2437 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on line 2962-2437 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1336
% INFO    : Updated Thermal Rating: on line 3747-3427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4036
% INFO    : Updated Thermal Rating: on line 3747-988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4700
% INFO    : Updated Thermal Rating: on line 932-3728 : Rate B, Rate C , 0.0, 0.0 -> 2595
% INFO    : Updated Thermal Rating: on line 932-7463 : Rate B, Rate C , 0.0, 0.0 -> 12430
% INFO    : Updated Thermal Rating: on line 8087-3342 : Rate B, Rate C , 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 8087-7659 : Rate B, Rate C , 0.0, 0.0 -> 1874
% INFO    : Updated Thermal Rating: on line 8087-3334 : Rate B, Rate C , 0.0, 0.0 -> 7317
% INFO    : Updated Thermal Rating: on line 8087-3334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7660
% INFO    : Updated Thermal Rating: on line 1639-3728 : Rate B, Rate C , 0.0, 0.0 -> 6618
% INFO    : Updated Thermal Rating: on line 1639-8936 : Rate B, Rate C , 0.0, 0.0 -> 9291
% INFO    : Updated Thermal Rating: on line 2907-481 : Rate B, Rate C , 0.0, 0.0 -> 3704
% INFO    : Updated Thermal Rating: on line 2907-481 : Rate B, Rate C , 0.0, 0.0 -> 2966
% INFO    : Updated Thermal Rating: on line 481-9057 : Rate B, Rate C , 0.0, 0.0 -> 4432
% INFO    : Updated Thermal Rating: on line 1894-481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 906
% INFO    : Updated Thermal Rating: on line 4890-481 : Rate B, Rate C , 0.0, 0.0 -> 3231
% INFO    : Updated Thermal Rating: on line 5890-481 : Rate B, Rate C , 0.0, 0.0 -> 2595
% INFO    : Updated Thermal Rating: on line 5391-481 : Rate B, Rate C , 0.0, 0.0 -> 5854
% INFO    : Updated Thermal Rating: on line 3544-6771 : Rate B, Rate C , 0.0, 0.0 -> 106663
% INFO    : Updated Thermal Rating: on line 1344-4806 : Rate B, Rate C , 0.0, 0.0 -> 2377
% INFO    : Updated Thermal Rating: on line 869-4806 : Rate B, Rate C , 0.0, 0.0 -> 29067
% INFO    : Updated Thermal Rating: on line 869-4806 : Rate B, Rate C , 0.0, 0.0 -> 28567
% INFO    : Updated Thermal Rating: on line 5685-2459 : Rate B, Rate C , 0.0, 0.0 -> 1837
% INFO    : Updated Thermal Rating: on line 2730-2459 : Rate B, Rate C , 0.0, 0.0 -> 1929
% INFO    : Updated Thermal Rating: on line 2730-2459 : Rate B, Rate C , 0.0, 0.0 -> 2220
% INFO    : Updated Thermal Rating: on line 2730-2459 : Rate B, Rate C , 0.0, 0.0 -> 2267
% INFO    : Updated Thermal Rating: on line 2459-8987 : Rate B, Rate C , 0.0, 0.0 -> 4294
% INFO    : Updated Thermal Rating: on line 1185-1240 : Rate B, Rate C , 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 1185-4016 : Rate B, Rate C , 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 2668-981 : Rate B, Rate C , 0.0, 0.0 -> 5387
% INFO    : Updated Thermal Rating: on line 2668-6344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11091
% INFO    : Updated Thermal Rating: on line 6564-1074 : Rate B, Rate C , 0.0, 0.0 -> 4227
% INFO    : Updated Thermal Rating: on line 6564-4026 : Rate B, Rate C , 0.0, 0.0 -> 2123
% INFO    : Updated Thermal Rating: on line 4336-4249 : Rate B, Rate C , 0.0, 0.0 -> 6083
% INFO    : Updated Thermal Rating: on line 7196-4249 : Rate B, Rate C , 0.0, 0.0 -> 6375
% INFO    : Updated Thermal Rating: on line 4600-642 : Rate B, Rate C , 0.0, 0.0 -> 4078
% INFO    : Updated Thermal Rating: on line 7573-6186 : Rate B, Rate C , 0.0, 0.0 -> 33347
% INFO    : Updated Thermal Rating: on line 7573-8186 : Rate B, Rate C , 0.0, 0.0 -> 26429
% INFO    : Updated Thermal Rating: on line 7413-7573 : Rate B, Rate C , 0.0, 0.0 -> 13292
% INFO    : Updated Thermal Rating: on line 8719-1023 : Rate B, Rate C , 0.0, 0.0 -> 4752
% INFO    : Updated Thermal Rating: on line 8719-3063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3181
% INFO    : Updated Thermal Rating: on line 7508-7053 : Rate B, Rate C , 0.0, 0.0 -> 3697
% INFO    : Updated Thermal Rating: on line 6183-6932 : Rate B, Rate C , 0.0, 0.0 -> 27867
% INFO    : Updated Thermal Rating: on line 6183-6932 : Rate B, Rate C , 0.0, 0.0 -> 25162
% INFO    : Updated Thermal Rating: on line 6183-8068 : Rate B, Rate C , 0.0, 0.0 -> 41215
% INFO    : Updated Thermal Rating: on line 6183-8068 : Rate B, Rate C , 0.0, 0.0 -> 42222
% INFO    : Updated Thermal Rating: on line 1602-4855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3447
% INFO    : Updated Thermal Rating: on line 1602-2551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 7999-1439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18438
% INFO    : Updated Thermal Rating: on line 7999-6597 : Rate B, Rate C , 0.0, 0.0 -> 20508
% INFO    : Updated Thermal Rating: on line 7999-8661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9625
% INFO    : Updated Thermal Rating: on line 1086-7257 : Rate B, Rate C , 0.0, 0.0 -> 1812
% INFO    : Updated Thermal Rating: on line 6443-519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2353
% INFO    : Updated Thermal Rating: on line 6443-519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2309
% INFO    : Updated Thermal Rating: on line 2009-6443 : Rate B, Rate C , 0.0, 0.0 -> 1960
% INFO    : Updated Thermal Rating: on line 6443-6749 : Rate B, Rate C , 0.0, 0.0 -> 1947
% INFO    : Updated Thermal Rating: on line 1121-4947 : Rate B, Rate C , 0.0, 0.0 -> 2818
% INFO    : Updated Thermal Rating: on line 4204-4947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 733
% INFO    : Updated Thermal Rating: on line 2907-7191 : Rate B, Rate C , 0.0, 0.0 -> 49864
% INFO    : Updated Thermal Rating: on line 2907-284 : Rate B, Rate C , 0.0, 0.0 -> 15638
% INFO    : Updated Thermal Rating: on line 477-9159 : Rate B, Rate C , 0.0, 0.0 -> 3072
% INFO    : Updated Thermal Rating: on line 1133-9159 : Rate A, Rate B, Rate C , 1152.0, 0.0, 0.0 -> 640
% INFO    : Updated Thermal Rating: on line 3178-6499 : Rate B, Rate C , 0.0, 0.0 -> 830
% INFO    : Updated Thermal Rating: on line 3792-6499 : Rate B, Rate C , 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on line 6499-6038 : Rate B, Rate C , 0.0, 0.0 -> 1629
% INFO    : Updated Thermal Rating: on line 6499-7398 : Rate B, Rate C , 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 75-2126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10113
% INFO    : Updated Thermal Rating: on line 75-6869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6507
% INFO    : Updated Thermal Rating: on line 7137-6659 : Rate B, Rate C , 0.0, 0.0 -> 2423
% INFO    : Updated Thermal Rating: on line 3673-6745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1635
% INFO    : Updated Thermal Rating: on line 3673-8953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2993
% INFO    : Updated Thermal Rating: on line 3673-8953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2935
% INFO    : Updated Thermal Rating: on line 5685-2849 : Rate B, Rate C , 0.0, 0.0 -> 6989
% INFO    : Updated Thermal Rating: on line 3378-6397 : Rate B, Rate C , 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on line 3378-1520 : Rate B, Rate C , 0.0, 0.0 -> 1311
% INFO    : Updated Thermal Rating: on line 3378-3233 : Rate B, Rate C , 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 3378-3291 : Rate B, Rate C , 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 693-8240 : Rate B, Rate C , 0.0, 0.0 -> 2803
% INFO    : Updated Thermal Rating: on line 693-5884 : Rate B, Rate C , 0.0, 0.0 -> 1345
% INFO    : Updated Thermal Rating: on line 693-3587 : Rate B, Rate C , 0.0, 0.0 -> 2405
% INFO    : Updated Thermal Rating: on line 693-3587 : Rate B, Rate C , 0.0, 0.0 -> 2356
% INFO    : Updated Thermal Rating: on line 6994-5970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5704
% INFO    : Updated Thermal Rating: on line 6994-5970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2606
% INFO    : Updated Thermal Rating: on line 6994-970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2922
% INFO    : Updated Thermal Rating: on line 6994-5348 : Rate B, Rate C , 0.0, 0.0 -> 1945
% INFO    : Updated Thermal Rating: on line 6994-1909 : Rate B, Rate C , 0.0, 0.0 -> 1997
% INFO    : Updated Thermal Rating: on line 3843-8534 : Rate B, Rate C , 0.0, 0.0 -> 4579
% INFO    : Updated Thermal Rating: on line 3843-9039 : Rate B, Rate C , 0.0, 0.0 -> 1842
% INFO    : Updated Thermal Rating: on line 1021-257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 1021-6936 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 1021-2946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2083
% INFO    : Updated Thermal Rating: on line 1021-172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2123
% INFO    : Updated Thermal Rating: on line 8138-3792 : Rate B, Rate C , 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on line 8138-7659 : Rate B, Rate C , 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 6669-5111 : Rate B, Rate C , 0.0, 0.0 -> 1778
% INFO    : Updated Thermal Rating: on line 5511-7145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2217
% INFO    : Updated Thermal Rating: on line 4338-1894 : Rate B, Rate C , 0.0, 0.0 -> 4781
% INFO    : Updated Thermal Rating: on line 4338-1894 : Rate B, Rate C , 0.0, 0.0 -> 4879
% INFO    : Updated Thermal Rating: on line 4338-6456 : Rate B, Rate C , 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 8946-849 : Rate B, Rate C , 0.0, 0.0 -> 20189
% INFO    : Updated Thermal Rating: on line 8946-849 : Rate B, Rate C , 0.0, 0.0 -> 20572
% INFO    : Updated Thermal Rating: on line 8946-6768 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on line 5970-2896 : Rate B, Rate C , 0.0, 0.0 -> 822
% INFO    : Updated Thermal Rating: on line 5970-9049 : Rate B, Rate C , 0.0, 0.0 -> 1320
% INFO    : Updated Thermal Rating: on line 5332-618 : Rate B, Rate C , 0.0, 0.0 -> 4037
% INFO    : Updated Thermal Rating: on line 5332-618 : Rate B, Rate C , 0.0, 0.0 -> 4120
% INFO    : Updated Thermal Rating: on line 5332-579 : Rate B, Rate C , 0.0, 0.0 -> 5216
% INFO    : Updated Thermal Rating: on line 5332-4442 : Rate B, Rate C , 0.0, 0.0 -> 2562
% INFO    : Updated Thermal Rating: on line 5332-814 : Rate B, Rate C , 0.0, 0.0 -> 5398
% INFO    : Updated Thermal Rating: on line 3633-6904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4167
% INFO    : Updated Thermal Rating: on line 3633-7820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1297
% INFO    : Updated Thermal Rating: on line 3633-7632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1994
% INFO    : Updated Thermal Rating: on line 3633-7632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 3629-4112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1511
% INFO    : Updated Thermal Rating: on line 4112-7630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4769
% INFO    : Updated Thermal Rating: on line 1645-3066 : Rate B, Rate C , 0.0, 0.0 -> 26592
% INFO    : Updated Thermal Rating: on line 1645-7973 : Rate B, Rate C , 0.0, 0.0 -> 9073
% INFO    : Updated Thermal Rating: on line 4945-7508 : Rate B, Rate C , 0.0, 0.0 -> 2171
% INFO    : Updated Thermal Rating: on line 1957-5933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 1957-1769 : Rate B, Rate C , 0.0, 0.0 -> 755
% INFO    : Updated Thermal Rating: on line 7417-7600 : Rate B, Rate C , 0.0, 0.0 -> 6843
% INFO    : Updated Thermal Rating: on line 7417-3792 : Rate B, Rate C , 0.0, 0.0 -> 976
% INFO    : Updated Thermal Rating: on line 7417-6879 : Rate B, Rate C , 0.0, 0.0 -> 7276
% INFO    : Updated Thermal Rating: on line 7417-962 : Rate B, Rate C , 0.0, 0.0 -> 9758
% INFO    : Updated Thermal Rating: on line 3489-3813 : Rate B, Rate C , 0.0, 0.0 -> 15658
% INFO    : Updated Thermal Rating: on line 1347-3813 : Rate B, Rate C , 0.0, 0.0 -> 15364
% INFO    : Updated Thermal Rating: on line 3813-5500 : Rate B, Rate C , 0.0, 0.0 -> 54724
% INFO    : Updated Thermal Rating: on line 5366-869 : Rate B, Rate C , 0.0, 0.0 -> 4521
% INFO    : Updated Thermal Rating: on line 5366-3382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4283
% INFO    : Updated Thermal Rating: on line 8352-9049 : Rate B, Rate C , 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on line 1869-473 : Rate B, Rate C , 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 1869-6243 : Rate B, Rate C , 0.0, 0.0 -> 4714
% INFO    : Updated Thermal Rating: on line 5767-9057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4823
% INFO    : Updated Thermal Rating: on line 2800-3061 : Rate B, Rate C , 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on line 2800-618 : Rate B, Rate C , 0.0, 0.0 -> 10720
% INFO    : Updated Thermal Rating: on line 2800-618 : Rate B, Rate C , 0.0, 0.0 -> 10939
% INFO    : Updated Thermal Rating: on line 2800-5042 : Rate B, Rate C , 0.0, 0.0 -> 1666
% INFO    : Updated Thermal Rating: on line 8870-2764 : Rate B, Rate C , 0.0, 0.0 -> 5550
% INFO    : Updated Thermal Rating: on line 8870-2764 : Rate B, Rate C , 0.0, 0.0 -> 5667
% INFO    : Updated Thermal Rating: on line 7096-4290 : Rate B, Rate C , 0.0, 0.0 -> 27343
% INFO    : Updated Thermal Rating: on line 7096-6681 : Rate B, Rate C , 0.0, 0.0 -> 24957
% INFO    : Updated Thermal Rating: on line 7096-8973 : Rate A, Rate B, Rate C , 1382.0, 0.0, 0.0 -> 1076
% INFO    : Updated Thermal Rating: on line 7096-5060 : Rate B, Rate C , 0.0, 0.0 -> 3587
% INFO    : Updated Thermal Rating: on line 5780-6932 : Rate B, Rate C , 0.0, 0.0 -> 5766
% INFO    : Updated Thermal Rating: on line 5780-6869 : Rate B, Rate C , 0.0, 0.0 -> 4430
% INFO    : Updated Thermal Rating: on line 4291-6656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1667
% INFO    : Updated Thermal Rating: on line 4291-8729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 5512-5463 : Rate B, Rate C , 0.0, 0.0 -> 2919
% INFO    : Updated Thermal Rating: on line 7685-5463 : Rate B, Rate C , 0.0, 0.0 -> 2020
% INFO    : Updated Thermal Rating: on line 5463-4967 : Rate B, Rate C , 0.0, 0.0 -> 7002
% INFO    : Updated Thermal Rating: on line 1013-7875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 1741-7875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3468
% INFO    : Updated Thermal Rating: on line 51-5670 : Rate B, Rate C , 0.0, 0.0 -> 1919
% INFO    : Updated Thermal Rating: on line 51-6174 : Rate B, Rate C , 0.0, 0.0 -> 3573
% INFO    : Updated Thermal Rating: on line 51-2517 : Rate B, Rate C , 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 7805-3425 : Rate B, Rate C , 0.0, 0.0 -> 21536
% INFO    : Updated Thermal Rating: on line 7805-8658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 7805-4011 : Rate B, Rate C , 0.0, 0.0 -> 25801
% INFO    : Updated Thermal Rating: on line 7805-9028 : Rate B, Rate C , 0.0, 0.0 -> 2103
% INFO    : Updated Thermal Rating: on line 7805-9028 : Rate B, Rate C , 0.0, 0.0 -> 2143
% INFO    : Updated Thermal Rating: on line 6932-4274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2367
% INFO    : Updated Thermal Rating: on line 6932-8871 : Rate B, Rate C , 0.0, 0.0 -> 2875
% INFO    : Updated Thermal Rating: on line 6932-8871 : Rate B, Rate C , 0.0, 0.0 -> 2932
% INFO    : Updated Thermal Rating: on line 6932-3442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36969
% INFO    : Updated Thermal Rating: on line 6953-2658 : Rate B, Rate C , 0.0, 0.0 -> 2547
% INFO    : Updated Thermal Rating: on line 6953-5592 : Rate B, Rate C , 0.0, 0.0 -> 1030
% INFO    : Updated Thermal Rating: on line 3342-7659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1261
% INFO    : Updated Thermal Rating: on line 6186-8068 : Rate B, Rate C , 0.0, 0.0 -> 23440
% INFO    : Updated Thermal Rating: on line 8504-1898 : Rate B, Rate C , 0.0, 0.0 -> 1641
% INFO    : Updated Thermal Rating: on line 1282-869 : Rate B, Rate C , 0.0, 0.0 -> 8106
% INFO    : Updated Thermal Rating: on line 9043-7819 : Rate B, Rate C , 0.0, 0.0 -> 6878
% INFO    : Updated Thermal Rating: on line 9043-7819 : Rate B, Rate C , 0.0, 0.0 -> 7428
% INFO    : Updated Thermal Rating: on line 9043-32 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 9043-7423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 7139-8186 : Rate B, Rate C , 0.0, 0.0 -> 50961
% INFO    : Updated Thermal Rating: on line 7139-1065 : Rate B, Rate C , 0.0, 0.0 -> 9950
% INFO    : Updated Thermal Rating: on line 7139-6134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3621
% INFO    : Updated Thermal Rating: on line 4336-4651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4968
% INFO    : Updated Thermal Rating: on line 731-4020 : Rate B, Rate C , 0.0, 0.0 -> 3543
% INFO    : Updated Thermal Rating: on line 6769-3178 : Rate B, Rate C , 0.0, 0.0 -> 2965
% INFO    : Updated Thermal Rating: on line 6769-3178 : Rate B, Rate C , 0.0, 0.0 -> 3624
% INFO    : Updated Thermal Rating: on line 3178-2116 : Rate B, Rate C , 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on line 3178-7283 : Rate B, Rate C , 0.0, 0.0 -> 3889
% INFO    : Updated Thermal Rating: on line 3178-7283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3960
% INFO    : Updated Thermal Rating: on line 3157-916 : Rate B, Rate C , 0.0, 0.0 -> 5799
% INFO    : Updated Thermal Rating: on line 3157-1241 : Rate B, Rate C , 0.0, 0.0 -> 1361
% INFO    : Updated Thermal Rating: on line 477-2437 : Rate B, Rate C , 0.0, 0.0 -> 2165
% INFO    : Updated Thermal Rating: on line 6769-257 : Rate B, Rate C , 0.0, 0.0 -> 1470
% INFO    : Updated Thermal Rating: on line 6769-7283 : Rate B, Rate C , 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on line 8858-2403 : Rate B, Rate C , 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 8858-4772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on line 8858-4016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1741
% INFO    : Updated Thermal Rating: on line 2403-6797 : Rate B, Rate C , 0.0, 0.0 -> 647
% INFO    : Updated Thermal Rating: on line 6192-8207 : Rate B, Rate C , 0.0, 0.0 -> 1495
% INFO    : Updated Thermal Rating: on line 6192-3937 : Rate B, Rate C , 0.0, 0.0 -> 4630
% INFO    : Updated Thermal Rating: on line 7669-8867 : Rate B, Rate C , 0.0, 0.0 -> 54080
% INFO    : Updated Thermal Rating: on line 7669-5948 : Rate B, Rate C , 0.0, 0.0 -> 42367
% INFO    : Updated Thermal Rating: on line 7392-8939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17273
% INFO    : Updated Thermal Rating: on line 1114-5096 : Rate B, Rate C , 0.0, 0.0 -> 2712
% INFO    : Updated Thermal Rating: on line 1114-4315 : Rate B, Rate C , 0.0, 0.0 -> 6889
% INFO    : Updated Thermal Rating: on line 3066-7973 : Rate B, Rate C , 0.0, 0.0 -> 7676
% INFO    : Updated Thermal Rating: on line 264-7064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16221
% INFO    : Updated Thermal Rating: on line 2188-4706 : Rate B, Rate C , 0.0, 0.0 -> 3060
% INFO    : Updated Thermal Rating: on line 7428-2188 : Rate B, Rate C , 0.0, 0.0 -> 9483
% INFO    : Updated Thermal Rating: on line 5170-5681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20189
% INFO    : Updated Thermal Rating: on line 5170-5681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20569
% INFO    : Updated Thermal Rating: on line 8756-2060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2188
% INFO    : Updated Thermal Rating: on line 8756-8419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9249
% INFO    : Updated Thermal Rating: on line 6009-1430 : Rate B, Rate C , 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on line 6009-5592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 3150-8147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2437
% INFO    : Updated Thermal Rating: on line 3150-4096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2487
% INFO    : Updated Thermal Rating: on line 1632-3621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21937
% INFO    : Updated Thermal Rating: on line 1632-6869 : Rate B, Rate C , 0.0, 0.0 -> 6105
% INFO    : Updated Thermal Rating: on line 3061-7460 : Rate B, Rate C , 0.0, 0.0 -> 6572
% INFO    : Updated Thermal Rating: on line 3061-7460 : Rate B, Rate C , 0.0, 0.0 -> 6529
% INFO    : Updated Thermal Rating: on line 3061-7929 : Rate B, Rate C , 0.0, 0.0 -> 2198
% INFO    : Updated Thermal Rating: on line 3061-814 : Rate B, Rate C , 0.0, 0.0 -> 5729
% INFO    : Updated Thermal Rating: on line 699-6882 : Rate B, Rate C , 0.0, 0.0 -> 3930
% INFO    : Updated Thermal Rating: on line 699-947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1518
% INFO    : Updated Thermal Rating: on line 699-2951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3332
% INFO    : Updated Thermal Rating: on line 3584-4177 : Rate B, Rate C , 0.0, 0.0 -> 1628
% INFO    : Updated Thermal Rating: on line 3584-5276 : Rate B, Rate C , 0.0, 0.0 -> 1180
% INFO    : Updated Thermal Rating: on line 5034-8301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6843
% INFO    : Updated Thermal Rating: on line 5034-8582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10399
% INFO    : Updated Thermal Rating: on line 1461-3754 : Rate B, Rate C , 0.0, 0.0 -> 41268
% INFO    : Updated Thermal Rating: on line 1461-6179 : Rate B, Rate C , 0.0, 0.0 -> 1829
% INFO    : Updated Thermal Rating: on line 5823-1060 : Rate B, Rate C , 0.0, 0.0 -> 2402
% INFO    : Updated Thermal Rating: on line 5280-4954 : Rate B, Rate C , 0.0, 0.0 -> 1087
% INFO    : Updated Thermal Rating: on line 5280-1121 : Rate B, Rate C , 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 5280-7861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 546
% INFO    : Updated Thermal Rating: on line 5280-7861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 555
% INFO    : Updated Thermal Rating: on line 7303-4690 : Rate B, Rate C , 0.0, 0.0 -> 69919
% INFO    : Updated Thermal Rating: on line 4954-8534 : Rate B, Rate C , 0.0, 0.0 -> 2902
% INFO    : Updated Thermal Rating: on line 4317-72 : Rate B, Rate C , 0.0, 0.0 -> 1791
% INFO    : Updated Thermal Rating: on line 4317-6333 : Rate B, Rate C , 0.0, 0.0 -> 13051
% INFO    : Updated Thermal Rating: on line 8702-4948 : Rate B, Rate C , 0.0, 0.0 -> 1279
% INFO    : Updated Thermal Rating: on line 5163-4948 : Rate B, Rate C , 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 3489-6869 : Rate B, Rate C , 0.0, 0.0 -> 20434
% INFO    : Updated Thermal Rating: on line 1347-6869 : Rate B, Rate C , 0.0, 0.0 -> 20842
% INFO    : Updated Thermal Rating: on line 3687-5877 : Rate B, Rate C , 0.0, 0.0 -> 21883
% INFO    : Updated Thermal Rating: on line 3687-5919 : Rate B, Rate C , 0.0, 0.0 -> 14188
% INFO    : Updated Thermal Rating: on line 1232-4588 : Rate B, Rate C , 0.0, 0.0 -> 22347
% INFO    : Updated Thermal Rating: on line 1232-2764 : Rate B, Rate C , 0.0, 0.0 -> 5758
% INFO    : Updated Thermal Rating: on line 7428-5877 : Rate B, Rate C , 0.0, 0.0 -> 59086
% INFO    : Updated Thermal Rating: on line 4588-7428 : Rate B, Rate C , 0.0, 0.0 -> 52385
% INFO    : Updated Thermal Rating: on line 8939-4371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12770
% INFO    : Updated Thermal Rating: on line 8939-7820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4665
% INFO    : Updated Thermal Rating: on line 6209-7191 : Rate B, Rate C , 0.0, 0.0 -> 18710
% INFO    : Updated Thermal Rating: on line 519-7349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 963
% INFO    : Updated Thermal Rating: on line 429-7877 : Rate B, Rate C , 0.0, 0.0 -> 2302
% INFO    : Updated Thermal Rating: on line 1894-4890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 4062-1599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44749
% INFO    : Updated Thermal Rating: on line 4062-8079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7447
% INFO    : Updated Thermal Rating: on line 6841-8936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11554
% INFO    : Updated Thermal Rating: on line 6841-2564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10244
% INFO    : Updated Thermal Rating: on line 8710-1491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3294
% INFO    : Updated Thermal Rating: on line 8710-7406 : Rate B, Rate C , 0.0, 0.0 -> 2813
% INFO    : Updated Thermal Rating: on line 970-7504 : Rate B, Rate C , 0.0, 0.0 -> 4369
% INFO    : Updated Thermal Rating: on line 6039-8034 : Rate B, Rate C , 0.0, 0.0 -> 3717
% INFO    : Updated Thermal Rating: on line 6039-7428 : Rate B, Rate C , 0.0, 0.0 -> 9681
% INFO    : Updated Thermal Rating: on line 7973-7475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5055
% INFO    : Updated Thermal Rating: on line 7973-2740 : Rate B, Rate C , 0.0, 0.0 -> 16876
% INFO    : Updated Thermal Rating: on line 7973-2297 : Rate B, Rate C , 0.0, 0.0 -> 16532
% INFO    : Updated Thermal Rating: on line 6877-1060 : Rate B, Rate C , 0.0, 0.0 -> 3282
% INFO    : Updated Thermal Rating: on line 6877-1060 : Rate B, Rate C , 0.0, 0.0 -> 3354
% INFO    : Updated Thermal Rating: on line 8981-4428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1547
% INFO    : Updated Thermal Rating: on line 8981-4428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1518
% INFO    : Updated Thermal Rating: on line 1841-3728 : Rate B, Rate C , 0.0, 0.0 -> 4229
% INFO    : Updated Thermal Rating: on line 1841-7463 : Rate B, Rate C , 0.0, 0.0 -> 4410
% INFO    : Updated Thermal Rating: on line 3582-5919 : Rate B, Rate C , 0.0, 0.0 -> 2181
% INFO    : Updated Thermal Rating: on line 3582-2096 : Rate B, Rate C , 0.0, 0.0 -> 2176
% INFO    : Updated Thermal Rating: on line 2009-7349 : Rate B, Rate C , 0.0, 0.0 -> 970
% INFO    : Updated Thermal Rating: on line 8034-1399 : Rate B, Rate C , 0.0, 0.0 -> 3181
% INFO    : Updated Thermal Rating: on line 4652-8034 : Rate A, Rate B, Rate C , 1283.0, 0.0, 0.0 -> 1112
% INFO    : Updated Thermal Rating: on line 1752-7845 : Rate B, Rate C , 0.0, 0.0 -> 2772
% INFO    : Updated Thermal Rating: on line 1752-3427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2393
% INFO    : Updated Thermal Rating: on line 7347-1599 : Rate B, Rate C , 0.0, 0.0 -> 45315
% INFO    : Updated Thermal Rating: on line 7347-8079 : Rate B, Rate C , 0.0, 0.0 -> 46708
% INFO    : Updated Thermal Rating: on line 4896-3736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8172
% INFO    : Updated Thermal Rating: on line 4896-7632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1353
% INFO    : Updated Thermal Rating: on line 3736-6625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2689
% INFO    : Updated Thermal Rating: on line 739-8561 : Rate B, Rate C , 0.0, 0.0 -> 1145
% INFO    : Updated Thermal Rating: on line 739-7395 : Rate B, Rate C , 0.0, 0.0 -> 2352
% INFO    : Updated Thermal Rating: on line 739-5873 : Rate B, Rate C , 0.0, 0.0 -> 1852
% INFO    : Updated Thermal Rating: on line 739-4843 : Rate B, Rate C , 0.0, 0.0 -> 2973
% INFO    : Updated Thermal Rating: on line 6092-739 : Rate B, Rate C , 0.0, 0.0 -> 1520
% INFO    : Updated Thermal Rating: on line 1393-6717 : Rate B, Rate C , 0.0, 0.0 -> 3435
% INFO    : Updated Thermal Rating: on line 1393-6717 : Rate B, Rate C , 0.0, 0.0 -> 3504
% INFO    : Updated Thermal Rating: on line 8337-807 : Rate B, Rate C , 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on line 2235-7395 : Rate B, Rate C , 0.0, 0.0 -> 3548
% INFO    : Updated Thermal Rating: on line 8512-5435 : Rate B, Rate C , 0.0, 0.0 -> 1088
% INFO    : Updated Thermal Rating: on line 8512-4658 : Rate B, Rate C , 0.0, 0.0 -> 4254
% INFO    : Updated Thermal Rating: on line 7929-7460 : Rate B, Rate C , 0.0, 0.0 -> 4011
% INFO    : Updated Thermal Rating: on line 7929-7460 : Rate B, Rate C , 0.0, 0.0 -> 3672
% INFO    : Updated Thermal Rating: on line 299-7460 : Rate B, Rate C , 0.0, 0.0 -> 20061
% INFO    : Updated Thermal Rating: on line 299-7460 : Rate B, Rate C , 0.0, 0.0 -> 20439
% INFO    : Updated Thermal Rating: on line 5117-6456 : Rate B, Rate C , 0.0, 0.0 -> 6509
% INFO    : Updated Thermal Rating: on line 5117-6394 : Rate B, Rate C , 0.0, 0.0 -> 3497
% INFO    : Updated Thermal Rating: on line 6397-7075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 874
% INFO    : Updated Thermal Rating: on line 7075-6936 : Rate B, Rate C , 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on line 7075-2946 : Rate B, Rate C , 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 4274-1969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24058
% INFO    : Updated Thermal Rating: on line 2946-2116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 5096-5464 : Rate B, Rate C , 0.0, 0.0 -> 4440
% INFO    : Updated Thermal Rating: on line 5096-4957 : Rate B, Rate C , 0.0, 0.0 -> 15189
% INFO    : Updated Thermal Rating: on line 5096-4446 : Rate B, Rate C , 0.0, 0.0 -> 9749
% INFO    : Updated Thermal Rating: on line 1115-6090 : Rate B, Rate C , 0.0, 0.0 -> 1991
% INFO    : Updated Thermal Rating: on line 1115-4204 : Rate B, Rate C , 0.0, 0.0 -> 1474
% INFO    : Updated Thermal Rating: on line 3966-3428 : Rate B, Rate C , 0.0, 0.0 -> 3101
% INFO    : Updated Thermal Rating: on line 1439-6836 : Rate B, Rate C , 0.0, 0.0 -> 33506
% INFO    : Updated Thermal Rating: on line 1439-5892 : Rate B, Rate C , 0.0, 0.0 -> 16486
% INFO    : Updated Thermal Rating: on line 9201-3937 : Rate B, Rate C , 0.0, 0.0 -> 21333
% INFO    : Updated Thermal Rating: on line 9201-3692 : Rate B, Rate C , 0.0, 0.0 -> 4118
% INFO    : Updated Thermal Rating: on line 8561-266 : Rate B, Rate C , 0.0, 0.0 -> 2577
% INFO    : Updated Thermal Rating: on line 8561-2566 : Rate A, Rate B, Rate C , 1251.0, 0.0, 0.0 -> 1067
% INFO    : Updated Thermal Rating: on line 8561-8806 : Rate B, Rate C , 0.0, 0.0 -> 2831
% INFO    : Updated Thermal Rating: on line 8561-7428 : Rate A, Rate B, Rate C , 1448.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 8561-1280 : Rate A, Rate B, Rate C , 1086.0, 0.0, 0.0 -> 992
% INFO    : Updated Thermal Rating: on line 2730-1133 : Rate A, Rate B, Rate C , 1251.0, 0.0, 0.0 -> 799
% INFO    : Updated Thermal Rating: on line 2730-1133 : Rate A, Rate B, Rate C , 1152.0, 0.0, 0.0 -> 815
% INFO    : Updated Thermal Rating: on line 6127-5111 : Rate B, Rate C , 0.0, 0.0 -> 584
% INFO    : Updated Thermal Rating: on line 6127-2172 : Rate B, Rate C , 0.0, 0.0 -> 841
% INFO    : Updated Thermal Rating: on line 6127-2658 : Rate A, Rate B, Rate C , 400.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 7600-7283 : Rate B, Rate C , 0.0, 0.0 -> 14981
% INFO    : Updated Thermal Rating: on line 473-7193 : Rate B, Rate C , 0.0, 0.0 -> 824
% INFO    : Updated Thermal Rating: on line 473-5025 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 7395-5873 : Rate A, Rate B, Rate C , 1810.0, 0.0, 0.0 -> 1360
% INFO    : Updated Thermal Rating: on line 7395-3662 : Rate B, Rate C , 0.0, 0.0 -> 11130
% INFO    : Updated Thermal Rating: on line 7395-4931 : Rate B, Rate C , 0.0, 0.0 -> 1958
% INFO    : Updated Thermal Rating: on line 5435-489 : Rate B, Rate C , 0.0, 0.0 -> 4376
% INFO    : Updated Thermal Rating: on line 5435-489 : Rate B, Rate C , 0.0, 0.0 -> 5608
% INFO    : Updated Thermal Rating: on line 5435-8529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6766
% INFO    : Updated Thermal Rating: on line 5435-7064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6907
% INFO    : Updated Thermal Rating: on line 5435-4058 : Rate B, Rate C , 0.0, 0.0 -> 2866
% INFO    : Updated Thermal Rating: on line 5435-4658 : Rate B, Rate C , 0.0, 0.0 -> 1270
% INFO    : Updated Thermal Rating: on line 2437-7029 : Rate A, Rate B, Rate C , 1678.0, 0.0, 0.0 -> 1575
% INFO    : Updated Thermal Rating: on line 2437-7029 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1609
% INFO    : Updated Thermal Rating: on line 2437-4795 : Rate A, Rate B, Rate C , 1744.0, 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on line 2437-4795 : Rate A, Rate B, Rate C , 1843.0, 0.0, 0.0 -> 1221
% INFO    : Updated Thermal Rating: on line 2437-1133 : Rate A, Rate B, Rate C , 1086.0, 0.0, 0.0 -> 759
% INFO    : Updated Thermal Rating: on line 3792-550 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 6299-3792 : Rate B, Rate C , 0.0, 0.0 -> 1856
% INFO    : Updated Thermal Rating: on line 3792-6879 : Rate B, Rate C , 0.0, 0.0 -> 965
% INFO    : Updated Thermal Rating: on line 3792-4181 : Rate B, Rate C , 0.0, 0.0 -> 986
% INFO    : Updated Thermal Rating: on line 8702-5163 : Rate B, Rate C , 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 8702-7861 : Rate B, Rate C , 0.0, 0.0 -> 1254
% INFO    : Updated Thermal Rating: on line 8702-7861 : Rate B, Rate C , 0.0, 0.0 -> 1279
% INFO    : Updated Thermal Rating: on line 957-7446 : Rate B, Rate C , 0.0, 0.0 -> 2411
% INFO    : Updated Thermal Rating: on line 957-4897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3387
% INFO    : Updated Thermal Rating: on line 5239-5873 : Rate B, Rate C , 0.0, 0.0 -> 4090
% INFO    : Updated Thermal Rating: on line 8438-8147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1284
% INFO    : Updated Thermal Rating: on line 8438-8147 : Rate B, Rate C , 0.0, 0.0 -> 1309
% INFO    : Updated Thermal Rating: on line 4290-266 : Rate A, Rate B, Rate C , 1283.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 266-4843 : Rate B, Rate C , 0.0, 0.0 -> 3936
% INFO    : Updated Thermal Rating: on line 3275-266 : Rate B, Rate C , 0.0, 0.0 -> 3274
% INFO    : Updated Thermal Rating: on line 8247-266 : Rate B, Rate C , 0.0, 0.0 -> 3043
% INFO    : Updated Thermal Rating: on line 8374-266 : Rate B, Rate C , 0.0, 0.0 -> 1603
% INFO    : Updated Thermal Rating: on line 7193-5025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 1064-3734 : Rate B, Rate C , 0.0, 0.0 -> 23210
% INFO    : Updated Thermal Rating: on line 1064-6456 : Rate B, Rate C , 0.0, 0.0 -> 5181
% INFO    : Updated Thermal Rating: on line 1064-6456 : Rate B, Rate C , 0.0, 0.0 -> 5291
% INFO    : Updated Thermal Rating: on line 7877-3063 : Rate B, Rate C , 0.0, 0.0 -> 11413
% INFO    : Updated Thermal Rating: on line 986-3367 : Rate B, Rate C , 0.0, 0.0 -> 1607
% INFO    : Updated Thermal Rating: on line 986-4603 : Rate B, Rate C , 0.0, 0.0 -> 1052
% INFO    : Updated Thermal Rating: on line 7257-6970 : Rate B, Rate C , 0.0, 0.0 -> 3126
% INFO    : Updated Thermal Rating: on line 5873-6768 : Rate B, Rate C , 0.0, 0.0 -> 3884
% INFO    : Updated Thermal Rating: on line 8147-6174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 825
% INFO    : Updated Thermal Rating: on line 8147-6174 : Rate B, Rate C , 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 8147-5162 : Rate B, Rate C , 0.0, 0.0 -> 7502
% INFO    : Updated Thermal Rating: on line 6879-6038 : Rate B, Rate C , 0.0, 0.0 -> 2493
% INFO    : Updated Thermal Rating: on line 4556-4592 : Rate B, Rate C , 0.0, 0.0 -> 5863
% INFO    : Updated Thermal Rating: on line 2412-2686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2427
% INFO    : Updated Thermal Rating: on line 2412-2686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1733
% INFO    : Updated Thermal Rating: on line 2412-3644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1245
% INFO    : Updated Thermal Rating: on line 2412-3644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on line 4855-2551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1535
% INFO    : Updated Thermal Rating: on line 4855-6904 : Rate B, Rate C , 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 4855-1897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2304
% INFO    : Updated Thermal Rating: on line 3268-8210 : Rate B, Rate C , 0.0, 0.0 -> 4753
% INFO    : Updated Thermal Rating: on line 3268-2849 : Rate B, Rate C , 0.0, 0.0 -> 1848
% INFO    : Updated Thermal Rating: on line 6397-1173 : Rate B, Rate C , 0.0, 0.0 -> 1661
% INFO    : Updated Thermal Rating: on line 6397-6936 : Rate B, Rate C , 0.0, 0.0 -> 783
% INFO    : Updated Thermal Rating: on line 6397-6936 : Rate B, Rate C , 0.0, 0.0 -> 870
% INFO    : Updated Thermal Rating: on line 6397-4750 : Rate B, Rate C , 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 3665-6544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6815
% INFO    : Updated Thermal Rating: on line 3665-6544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6686
% INFO    : Updated Thermal Rating: on line 3665-6544 : Rate B, Rate C , 0.0, 0.0 -> 9641
% INFO    : Updated Thermal Rating: on line 6436-5217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22084
% INFO    : Updated Thermal Rating: on line 6436-6717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1668
% INFO    : Updated Thermal Rating: on line 72-6093 : Rate B, Rate C , 0.0, 0.0 -> 2383
% INFO    : Updated Thermal Rating: on line 1520-3233 : Rate B, Rate C , 0.0, 0.0 -> 2931
% INFO    : Updated Thermal Rating: on line 6985-854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53332
% INFO    : Updated Thermal Rating: on line 6985-415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on line 6985-1501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4327
% INFO    : Updated Thermal Rating: on line 489-4238 : Rate B, Rate C , 0.0, 0.0 -> 3610
% INFO    : Updated Thermal Rating: on line 489-1411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4672
% INFO    : Updated Thermal Rating: on line 4290-6681 : Rate B, Rate C , 0.0, 0.0 -> 25787
% INFO    : Updated Thermal Rating: on line 4290-3587 : Rate B, Rate C , 0.0, 0.0 -> 2537
% INFO    : Updated Thermal Rating: on line 4290-8374 : Rate B, Rate C , 0.0, 0.0 -> 1664
% INFO    : Updated Thermal Rating: on line 797-7819 : Rate B, Rate C , 0.0, 0.0 -> 3767
% INFO    : Updated Thermal Rating: on line 797-8378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1599
% INFO    : Updated Thermal Rating: on line 797-1241 : Rate B, Rate C , 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 7929-7755 : Rate B, Rate C , 0.0, 0.0 -> 2548
% INFO    : Updated Thermal Rating: on line 7929-7755 : Rate B, Rate C , 0.0, 0.0 -> 2597
% INFO    : Updated Thermal Rating: on line 7929-8625 : Rate B, Rate C , 0.0, 0.0 -> 1757
% INFO    : Updated Thermal Rating: on line 4592-1471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5854
% INFO    : Updated Thermal Rating: on line 4592-1471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5970
% INFO    : Updated Thermal Rating: on line 6040-3111 : Rate B, Rate C , 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 1175-3111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1365
% INFO    : Updated Thermal Rating: on line 3111-6239 : Rate B, Rate C , 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 3111-3689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on line 3111-6179 : Rate B, Rate C , 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 8396-5091 : Rate B, Rate C , 0.0, 0.0 -> 1967
% INFO    : Updated Thermal Rating: on line 8396-8806 : Rate A, Rate B, Rate C , 1251.0, 0.0, 0.0 -> 1217
% INFO    : Updated Thermal Rating: on line 8396-8247 : Rate B, Rate C , 0.0, 0.0 -> 2117
% INFO    : Updated Thermal Rating: on line 8396-5060 : Rate B, Rate C , 0.0, 0.0 -> 3020
% INFO    : Updated Thermal Rating: on line 8396-8012 : Rate B, Rate C , 0.0, 0.0 -> 9367
% INFO    : Updated Thermal Rating: on line 1491-4489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2494
% INFO    : Updated Thermal Rating: on line 1491-1503 : Rate B, Rate C , 0.0, 0.0 -> 791
% INFO    : Updated Thermal Rating: on line 849-1168 : Rate B, Rate C , 0.0, 0.0 -> 1866
% INFO    : Updated Thermal Rating: on line 849-1168 : Rate B, Rate C , 0.0, 0.0 -> 4637
% INFO    : Updated Thermal Rating: on line 849-1168 : Rate B, Rate C , 0.0, 0.0 -> 4545
% INFO    : Updated Thermal Rating: on line 6092-849 : Rate B, Rate C , 0.0, 0.0 -> 2065
% INFO    : Updated Thermal Rating: on line 3840-686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1309
% INFO    : Updated Thermal Rating: on line 3840-5821 : Rate B, Rate C , 0.0, 0.0 -> 981
% INFO    : Updated Thermal Rating: on line 3840-2225 : Rate B, Rate C , 0.0, 0.0 -> 4761
% INFO    : Updated Thermal Rating: on line 3840-2225 : Rate B, Rate C , 0.0, 0.0 -> 5698
% INFO    : Updated Thermal Rating: on line 5091-4390 : Rate B, Rate C , 0.0, 0.0 -> 76837
% INFO    : Updated Thermal Rating: on line 5091-4390 : Rate B, Rate C , 0.0, 0.0 -> 76837
% INFO    : Updated Thermal Rating: on line 5091-4957 : Rate B, Rate C , 0.0, 0.0 -> 9161
% INFO    : Updated Thermal Rating: on line 7446-2504 : Rate B, Rate C , 0.0, 0.0 -> 1776
% INFO    : Updated Thermal Rating: on line 1741-1912 : Rate B, Rate C , 0.0, 0.0 -> 2343
% INFO    : Updated Thermal Rating: on line 483-2658 : Rate B, Rate C , 0.0, 0.0 -> 4224
% INFO    : Updated Thermal Rating: on line 483-5592 : Rate B, Rate C , 0.0, 0.0 -> 898
% INFO    : Updated Thermal Rating: on line 5111-4360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12109
% INFO    : Updated Thermal Rating: on line 6596-3512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 8701-8207 : Rate B, Rate C , 0.0, 0.0 -> 2397
% INFO    : Updated Thermal Rating: on line 8701-1271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1086
% INFO    : Updated Thermal Rating: on line 2236-4967 : Rate B, Rate C , 0.0, 0.0 -> 3120
% INFO    : Updated Thermal Rating: on line 8575-7845 : Rate B, Rate C , 0.0, 0.0 -> 2049
% INFO    : Updated Thermal Rating: on line 8664-1399 : Rate B, Rate C , 0.0, 0.0 -> 2371
% INFO    : Updated Thermal Rating: on line 5202-8936 : Rate B, Rate C , 0.0, 0.0 -> 47279
% INFO    : Updated Thermal Rating: on line 5202-2564 : Rate B, Rate C , 0.0, 0.0 -> 48642
% INFO    : Updated Thermal Rating: on line 5202-3027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27957
% INFO    : Updated Thermal Rating: on line 6836-6209 : Rate B, Rate C , 0.0, 0.0 -> 18221
% INFO    : Updated Thermal Rating: on line 5923-854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37113
% INFO    : Updated Thermal Rating: on line 7137-7310 : Rate B, Rate C , 0.0, 0.0 -> 5272
% INFO    : Updated Thermal Rating: on line 7137-6970 : Rate B, Rate C , 0.0, 0.0 -> 2889
% INFO    : Updated Thermal Rating: on line 5831-7137 : Rate B, Rate C , 0.0, 0.0 -> 1633
% INFO    : Updated Thermal Rating: on line 5919-2764 : Rate B, Rate C , 0.0, 0.0 -> 6753
% INFO    : Updated Thermal Rating: on line 8871-8819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4699
% INFO    : Updated Thermal Rating: on line 2504-5329 : Rate B, Rate C , 0.0, 0.0 -> 1136
% INFO    : Updated Thermal Rating: on line 3233-2844 : Rate B, Rate C , 0.0, 0.0 -> 7885
% INFO    : Updated Thermal Rating: on line 3233-3291 : Rate B, Rate C , 0.0, 0.0 -> 953
% INFO    : Updated Thermal Rating: on line 8149-2896 : Rate B, Rate C , 0.0, 0.0 -> 1384
% INFO    : Updated Thermal Rating: on line 8149-1802 : Rate B, Rate C , 0.0, 0.0 -> 3627
% INFO    : Updated Thermal Rating: on line 5828-440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1670
% INFO    : Updated Thermal Rating: on line 5828-1391 : Rate B, Rate C , 0.0, 0.0 -> 1566
% INFO    : Updated Thermal Rating: on line 8236-3027 : Rate B, Rate C , 0.0, 0.0 -> 3541
% INFO    : Updated Thermal Rating: on line 1168-6607 : Rate B, Rate C , 0.0, 0.0 -> 1691
% INFO    : Updated Thermal Rating: on line 1168-7673 : Rate B, Rate C , 0.0, 0.0 -> 5484
% INFO    : Updated Thermal Rating: on line 1168-754 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1499
% INFO    : Updated Thermal Rating: on line 2686-4773 : Rate B, Rate C , 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 2225-4177 : Rate B, Rate C , 0.0, 0.0 -> 1279
% INFO    : Updated Thermal Rating: on line 3798-2913 : Rate B, Rate C , 0.0, 0.0 -> 6399
% INFO    : Updated Thermal Rating: on line 3544-2913 : Rate A, Rate B, Rate C , 1349.0, 0.0, 0.0 -> 1173
% INFO    : Updated Thermal Rating: on line 4906-550 : Rate B, Rate C , 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 3427-6949 : Rate B, Rate C , 0.0, 0.0 -> 11309
% INFO    : Updated Thermal Rating: on line 3427-9028 : Rate B, Rate C , 0.0, 0.0 -> 2325
% INFO    : Updated Thermal Rating: on line 4890-7406 : Rate B, Rate C , 0.0, 0.0 -> 2818
% INFO    : Updated Thermal Rating: on line 4890-6349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11807
% INFO    : Updated Thermal Rating: on line 8867-15 : Rate B, Rate C , 0.0, 0.0 -> 23815
% INFO    : Updated Thermal Rating: on line 8867-284 : Rate B, Rate C , 0.0, 0.0 -> 18942
% INFO    : Updated Thermal Rating: on line 4428-8534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2449
% INFO    : Updated Thermal Rating: on line 4428-8534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2500
% INFO    : Updated Thermal Rating: on line 4428-5276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3289
% INFO    : Updated Thermal Rating: on line 4428-5276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3347
% INFO    : Updated Thermal Rating: on line 3644-4428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2418
% INFO    : Updated Thermal Rating: on line 3644-4428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2610
% INFO    : Updated Thermal Rating: on line 6936-2957 : Rate B, Rate C , 0.0, 0.0 -> 5859
% INFO    : Updated Thermal Rating: on line 8240-8973 : Rate A, Rate B, Rate C , 1514.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 6543-3715 : Rate B, Rate C , 0.0, 0.0 -> 20595
% INFO    : Updated Thermal Rating: on line 6543-5948 : Rate B, Rate C , 0.0, 0.0 -> 27118
% INFO    : Updated Thermal Rating: on line 3275-4931 : Rate B, Rate C , 0.0, 0.0 -> 3851
% INFO    : Updated Thermal Rating: on line 8163-3425 : Rate B, Rate C , 0.0, 0.0 -> 11591
% INFO    : Updated Thermal Rating: on line 3425-6783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142001
% INFO    : Updated Thermal Rating: on line 2172-595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 8658-1065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23603
% INFO    : Updated Thermal Rating: on line 6090-1175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 792
% INFO    : Updated Thermal Rating: on line 3106-7673 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 3106-2096 : Rate B, Rate C , 0.0, 0.0 -> 2556
% INFO    : Updated Thermal Rating: on line 8163-5500 : Rate B, Rate C , 0.0, 0.0 -> 49392
% INFO    : Updated Thermal Rating: on line 7249-8207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9445
% INFO    : Updated Thermal Rating: on line 7249-3692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2025
% INFO    : Updated Thermal Rating: on line 6783-5923 : Rate B, Rate C , 0.0, 0.0 -> 18543
% INFO    : Updated Thermal Rating: on line 6783-8575 : Rate B, Rate C , 0.0, 0.0 -> 12501
% INFO    : Updated Thermal Rating: on line 1121-4657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on line 3487-1121 : Rate B, Rate C , 0.0, 0.0 -> 1198
% INFO    : Updated Thermal Rating: on line 3442-8819 : Rate B, Rate C , 0.0, 0.0 -> 11260
% INFO    : Updated Thermal Rating: on line 4856-4906 : Rate B, Rate C , 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 3076-4906 : Rate B, Rate C , 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 5884-8973 : Rate B, Rate C , 0.0, 0.0 -> 2472
% INFO    : Updated Thermal Rating: on line 8207-5961 : Rate B, Rate C , 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 8207-3629 : Rate B, Rate C , 0.0, 0.0 -> 794
% INFO    : Updated Thermal Rating: on line 8207-3692 : Rate B, Rate C , 0.0, 0.0 -> 1411
% INFO    : Updated Thermal Rating: on line 8207-7630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 958
% INFO    : Updated Thermal Rating: on line 6877-7755 : Rate B, Rate C , 0.0, 0.0 -> 2337
% INFO    : Updated Thermal Rating: on line 6877-7755 : Rate B, Rate C , 0.0, 0.0 -> 2523
% INFO    : Updated Thermal Rating: on line 5042-179 : Rate B, Rate C , 0.0, 0.0 -> 3600
% INFO    : Updated Thermal Rating: on line 5042-4442 : Rate B, Rate C , 0.0, 0.0 -> 5145
% INFO    : Updated Thermal Rating: on line 2566-6768 : Rate B, Rate C , 0.0, 0.0 -> 5190
% INFO    : Updated Thermal Rating: on line 4897-6717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2792
% INFO    : Updated Thermal Rating: on line 7475-6949 : Rate B, Rate C , 0.0, 0.0 -> 2240
% INFO    : Updated Thermal Rating: on line 1294-5162 : Rate B, Rate C , 0.0, 0.0 -> 4095
% INFO    : Updated Thermal Rating: on line 6681-8806 : Rate A, Rate B, Rate C , 1382.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 6681-8806 : Rate A, Rate B, Rate C , 1316.0, 0.0, 0.0 -> 956
% INFO    : Updated Thermal Rating: on line 6681-8806 : Rate A, Rate B, Rate C , 1185.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 6681-8973 : Rate A, Rate B, Rate C , 1283.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 7819-32 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 6333-5512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1559
% INFO    : Updated Thermal Rating: on line 8534-9039 : Rate B, Rate C , 0.0, 0.0 -> 1744
% INFO    : Updated Thermal Rating: on line 8534-5276 : Rate B, Rate C , 0.0, 0.0 -> 2197
% INFO    : Updated Thermal Rating: on line 4026-2261 : Rate B, Rate C , 0.0, 0.0 -> 2310
% INFO    : Updated Thermal Rating: on line 4204-4657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 731-2764 : Rate B, Rate C , 0.0, 0.0 -> 3338
% INFO    : Updated Thermal Rating: on line 731-597 : Rate A, Rate B, Rate C , 1777.0, 0.0, 0.0 -> 1728
% INFO    : Updated Thermal Rating: on line 731-385 : Rate B, Rate C , 0.0, 0.0 -> 9100
% INFO    : Updated Thermal Rating: on line 3728-2564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3193
% INFO    : Updated Thermal Rating: on line 2764-2622 : Rate B, Rate C , 0.0, 0.0 -> 9837
% INFO    : Updated Thermal Rating: on line 2764-7688 : Rate B, Rate C , 0.0, 0.0 -> 4632
% INFO    : Updated Thermal Rating: on line 2764-8260 : Rate B, Rate C , 0.0, 0.0 -> 7107
% INFO    : Updated Thermal Rating: on line 415-3367 : Rate B, Rate C , 0.0, 0.0 -> 1729
% INFO    : Updated Thermal Rating: on line 415-4081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2046
% INFO    : Updated Thermal Rating: on line 7287-7755 : Rate B, Rate C , 0.0, 0.0 -> 3416
% INFO    : Updated Thermal Rating: on line 7287-7755 : Rate B, Rate C , 0.0, 0.0 -> 3487
% INFO    : Updated Thermal Rating: on line 947-2785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4351
% INFO    : Updated Thermal Rating: on line 3734-6654 : Rate B, Rate C , 0.0, 0.0 -> 9468
% INFO    : Updated Thermal Rating: on line 2551-1897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2007
% INFO    : Updated Thermal Rating: on line 8806-8664 : Rate B, Rate C , 0.0, 0.0 -> 2443
% INFO    : Updated Thermal Rating: on line 8806-7428 : Rate A, Rate B, Rate C , 1514.0, 0.0, 0.0 -> 829
% INFO    : Updated Thermal Rating: on line 8806-4652 : Rate B, Rate C , 0.0, 0.0 -> 4456
% INFO    : Updated Thermal Rating: on line 249-32 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32723
% INFO    : Updated Thermal Rating: on line 1741-249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1095
% INFO    : Updated Thermal Rating: on line 249-5290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 472
% INFO    : Updated Thermal Rating: on line 249-4467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 888
% INFO    : Updated Thermal Rating: on line 249-5290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 1391-32 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 32-2143 : Rate B, Rate C , 0.0, 0.0 -> 1629
% INFO    : Updated Thermal Rating: on line 3008-6768 : Rate B, Rate C , 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 6174-5670 : Rate B, Rate C , 0.0, 0.0 -> 1714
% INFO    : Updated Thermal Rating: on line 8066-5961 : Rate B, Rate C , 0.0, 0.0 -> 4839
% INFO    : Updated Thermal Rating: on line 442-8066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2256
% INFO    : Updated Thermal Rating: on line 1271-5961 : Rate B, Rate C , 0.0, 0.0 -> 3702
% INFO    : Updated Thermal Rating: on line 869-4489 : Rate B, Rate C , 0.0, 0.0 -> 1902
% INFO    : Updated Thermal Rating: on line 869-4489 : Rate B, Rate C , 0.0, 0.0 -> 1940
% INFO    : Updated Thermal Rating: on line 602-4489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2415
% INFO    : Updated Thermal Rating: on line 602-4489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2374
% INFO    : Updated Thermal Rating: on line 6484-7918 : Rate B, Rate C , 0.0, 0.0 -> 2585
% INFO    : Updated Thermal Rating: on line 6484-7436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3311
% INFO    : Updated Thermal Rating: on line 7918-4690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2538
% INFO    : Updated Thermal Rating: on line 5511-1942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3295
% INFO    : Updated Thermal Rating: on line 5511-8419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2267
% INFO    : Updated Thermal Rating: on line 5511-8419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2227
% INFO    : Updated Thermal Rating: on line 7611-3382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36111
% INFO    : Updated Thermal Rating: on line 7611-3382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36526
% INFO    : Updated Thermal Rating: on line 7611-7869 : Rate B, Rate C , 0.0, 0.0 -> 13322
% INFO    : Updated Thermal Rating: on line 686-5171 : Rate B, Rate C , 0.0, 0.0 -> 5534
% INFO    : Updated Thermal Rating: on line 2172-5191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 774
% INFO    : Updated Thermal Rating: on line 1697-179 : Rate B, Rate C , 0.0, 0.0 -> 1960
% INFO    : Updated Thermal Rating: on line 1697-179 : Rate B, Rate C , 0.0, 0.0 -> 1925
% INFO    : Updated Thermal Rating: on line 179-2096 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1323
% INFO    : Updated Thermal Rating: on line 1728-179 : Rate B, Rate C , 0.0, 0.0 -> 3539
% INFO    : Updated Thermal Rating: on line 1850-4603 : Rate B, Rate C , 0.0, 0.0 -> 830
% INFO    : Updated Thermal Rating: on line 1850-4603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 918
% INFO    : Updated Thermal Rating: on line 3109-5726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1134
% INFO    : Updated Thermal Rating: on line 3109-5726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 5726-4773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3716
% INFO    : Updated Thermal Rating: on line 7659-6879 : Rate B, Rate C , 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 6174-5171 : Rate B, Rate C , 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on line 527-8242 : Rate B, Rate C , 0.0, 0.0 -> 14910
% INFO    : Updated Thermal Rating: on line 527-8529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13316
% INFO    : Updated Thermal Rating: on line 527-8530 : Rate B, Rate C , 0.0, 0.0 -> 57786
% INFO    : Updated Thermal Rating: on line 6496-6607 : Rate B, Rate C , 0.0, 0.0 -> 4045
% INFO    : Updated Thermal Rating: on line 4652-4706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8536
% INFO    : Updated Thermal Rating: on line 6656-2091 : Rate B, Rate C , 0.0, 0.0 -> 2435
% INFO    : Updated Thermal Rating: on line 6656-8993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3519
% INFO    : Updated Thermal Rating: on line 6656-1241 : Rate B, Rate C , 0.0, 0.0 -> 6012
% INFO    : Updated Thermal Rating: on line 2658-808 : Rate B, Rate C , 0.0, 0.0 -> 1310
% INFO    : Updated Thermal Rating: on line 3291-6749 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 7406-4397 : Rate B, Rate C , 0.0, 0.0 -> 1361
% INFO    : Updated Thermal Rating: on line 7406-1769 : Rate B, Rate C , 0.0, 0.0 -> 2586
% INFO    : Updated Thermal Rating: on line 7406-1769 : Rate B, Rate C , 0.0, 0.0 -> 2632
% INFO    : Updated Thermal Rating: on line 1013-4467 : Rate B, Rate C , 0.0, 0.0 -> 8366
% INFO    : Updated Thermal Rating: on line 1013-5025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on line 7918-7310 : Rate A, Rate B, Rate C , 1316.0, 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on line 7918-5608 : Rate B, Rate C , 0.0, 0.0 -> 2000
% INFO    : Updated Thermal Rating: on line 5831-7918 : Rate B, Rate C , 0.0, 0.0 -> 2363
% INFO    : Updated Thermal Rating: on line 7918-2202 : Rate B, Rate C , 0.0, 0.0 -> 4179
% INFO    : Updated Thermal Rating: on line 77-6660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84901
% INFO    : Updated Thermal Rating: on line 8124-8419 : Rate B, Rate C , 0.0, 0.0 -> 4622
% INFO    : Updated Thermal Rating: on line 33-3334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18888
% INFO    : Updated Thermal Rating: on line 6490-8301 : Rate B, Rate C , 0.0, 0.0 -> 2625
% INFO    : Updated Thermal Rating: on line 6490-6869 : Rate B, Rate C , 0.0, 0.0 -> 2349
% INFO    : Updated Thermal Rating: on line 4371-7820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3745
% INFO    : Updated Thermal Rating: on line 2896-5348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2100
% INFO    : Updated Thermal Rating: on line 5767-6836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105292
% INFO    : Updated Thermal Rating: on line 2978-6836 : Rate B, Rate C , 0.0, 0.0 -> 105292
% INFO    : Updated Thermal Rating: on line 2978-5391 : Rate B, Rate C , 0.0, 0.0 -> 3954
% INFO    : Updated Thermal Rating: on line 3629-230 : Rate B, Rate C , 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on line 9039-7861 : Rate B, Rate C , 0.0, 0.0 -> 3391
% INFO    : Updated Thermal Rating: on line 1479-7343 : Rate B, Rate C , 0.0, 0.0 -> 12713
% INFO    : Updated Thermal Rating: on line 7343-4957 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 8338-981 : Rate B, Rate C , 0.0, 0.0 -> 6176
% INFO    : Updated Thermal Rating: on line 8338-751 : Rate B, Rate C , 0.0, 0.0 -> 1944
% INFO    : Updated Thermal Rating: on line 4026-5372 : Rate B, Rate C , 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 7821-642 : Rate B, Rate C , 0.0, 0.0 -> 3450
% INFO    : Updated Thermal Rating: on line 7821-5608 : Rate B, Rate C , 0.0, 0.0 -> 3603
% INFO    : Updated Thermal Rating: on line 9097-1513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3502
% INFO    : Updated Thermal Rating: on line 9097-1513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3778
% INFO    : Updated Thermal Rating: on line 9097-3125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3295
% INFO    : Updated Thermal Rating: on line 9097-3125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3236
% INFO    : Updated Thermal Rating: on line 4315-5464 : Rate B, Rate C , 0.0, 0.0 -> 4352
% INFO    : Updated Thermal Rating: on line 1942-4095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2470
% INFO    : Updated Thermal Rating: on line 3966-1074 : Rate B, Rate C , 0.0, 0.0 -> 3291
% INFO    : Updated Thermal Rating: on line 3966-807 : Rate B, Rate C , 0.0, 0.0 -> 1294
% INFO    : Updated Thermal Rating: on line 3966-4507 : Rate B, Rate C , 0.0, 0.0 -> 1852
% INFO    : Updated Thermal Rating: on line 5890-3689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 8210-3113 : Rate B, Rate C , 0.0, 0.0 -> 4598
% INFO    : Updated Thermal Rating: on line 8210-2849 : Rate A, Rate B, Rate C , 1613.0, 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on line 642-5608 : Rate B, Rate C , 0.0, 0.0 -> 1513
% INFO    : Updated Thermal Rating: on line 1697-642 : Rate B, Rate C , 0.0, 0.0 -> 4012
% INFO    : Updated Thermal Rating: on line 1697-642 : Rate B, Rate C , 0.0, 0.0 -> 3937
% INFO    : Updated Thermal Rating: on line 1421-3621 : Rate B, Rate C , 0.0, 0.0 -> 6468
% INFO    : Updated Thermal Rating: on line 2126-1421 : Rate B, Rate C , 0.0, 0.0 -> 7053
% INFO    : Updated Thermal Rating: on line 2844-3291 : Rate B, Rate C , 0.0, 0.0 -> 985
% INFO    : Updated Thermal Rating: on line 1638-8575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36222
% INFO    : Updated Thermal Rating: on line 3163-1411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 3163-5025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1017
% INFO    : Updated Thermal Rating: on line 6454-8571 : Rate B, Rate C , 0.0, 0.0 -> 20925
% INFO    : Updated Thermal Rating: on line 8571-4081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3326
% INFO    : Updated Thermal Rating: on line 8571-4081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3395
% INFO    : Updated Thermal Rating: on line 2091-440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1975
% INFO    : Updated Thermal Rating: on line 4953-1421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5036
% INFO    : Updated Thermal Rating: on line 2667-1969 : Rate B, Rate C , 0.0, 0.0 -> 3501
% INFO    : Updated Thermal Rating: on line 2667-9028 : Rate B, Rate C , 0.0, 0.0 -> 4810
% INFO    : Updated Thermal Rating: on line 8819-6134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3461
% INFO    : Updated Thermal Rating: on line 751-4493 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 751-4493 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 751-6344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20833
% INFO    : Updated Thermal Rating: on line 5289-3113 : Rate B, Rate C , 0.0, 0.0 -> 15802
% INFO    : Updated Thermal Rating: on line 3113-5289 : Rate B, Rate C , 0.0, 0.0 -> 16708
% INFO    : Updated Thermal Rating: on line 172-2946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on line 7685-6394 : Rate B, Rate C , 0.0, 0.0 -> 1631
% INFO    : Updated Thermal Rating: on line 5821-5329 : Rate B, Rate C , 0.0, 0.0 -> 1403
% INFO    : Updated Thermal Rating: on line 7283-8213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6347
% INFO    : Updated Thermal Rating: on line 7283-962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6732
% INFO    : Updated Thermal Rating: on line 3468-8661 : Rate B, Rate C , 0.0, 0.0 -> 9608
% INFO    : Updated Thermal Rating: on line 3468-1769 : Rate B, Rate C , 0.0, 0.0 -> 7669
% INFO    : Updated Thermal Rating: on line 6244-9055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4105
% INFO    : Updated Thermal Rating: on line 6244-1471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4187
% INFO    : Updated Thermal Rating: on line 6544-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on line 7463-1969 : Rate B, Rate C , 0.0, 0.0 -> 80052
% INFO    : Updated Thermal Rating: on line 1030-6022 : Rate B, Rate C , 0.0, 0.0 -> 1733
% INFO    : Updated Thermal Rating: on line 1030-8776 : Rate B, Rate C , 0.0, 0.0 -> 1715
% INFO    : Updated Thermal Rating: on line 1030-5290 : Rate B, Rate C , 0.0, 0.0 -> 3672
% INFO    : Updated Thermal Rating: on line 1030-4279 : Rate B, Rate C , 0.0, 0.0 -> 1404
% INFO    : Updated Thermal Rating: on line 3067-4507 : Rate B, Rate C , 0.0, 0.0 -> 3620
% INFO    : Updated Thermal Rating: on line 5608-9117 : Rate B, Rate C , 0.0, 0.0 -> 2668
% INFO    : Updated Thermal Rating: on line 5608-7436 : Rate B, Rate C , 0.0, 0.0 -> 5324
% INFO    : Updated Thermal Rating: on line 5608-2202 : Rate B, Rate C , 0.0, 0.0 -> 3176
% INFO    : Updated Thermal Rating: on line 7002-3334 : Rate B, Rate C , 0.0, 0.0 -> 915
% INFO    : Updated Thermal Rating: on line 2060-3495 : Rate B, Rate C , 0.0, 0.0 -> 5124
% INFO    : Updated Thermal Rating: on line 3544-807 : Rate A, Rate B, Rate C , 1316.0, 0.0, 0.0 -> 1155
% INFO    : Updated Thermal Rating: on line 869-4910 : Rate B, Rate C , 0.0, 0.0 -> 16962
% INFO    : Updated Thermal Rating: on line 869-6456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1268
% INFO    : Updated Thermal Rating: on line 4397-1503 : Rate B, Rate C , 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 1513-6745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7010
% INFO    : Updated Thermal Rating: on line 916-4224 : Rate B, Rate C , 0.0, 0.0 -> 5932
% INFO    : Updated Thermal Rating: on line 916-1241 : Rate B, Rate C , 0.0, 0.0 -> 1407
% INFO    : Updated Thermal Rating: on line 602-4910 : Rate B, Rate C , 0.0, 0.0 -> 3599
% INFO    : Updated Thermal Rating: on line 6456-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2334
% INFO    : Updated Thermal Rating: on line 4224-1909 : Rate B, Rate C , 0.0, 0.0 -> 2334
% INFO    : Updated Thermal Rating: on line 2297-2740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16272
% INFO    : Updated Thermal Rating: on line 9162-8419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3367
% INFO    : Updated Thermal Rating: on line 5391-6349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8489
% INFO    : Updated Thermal Rating: on line 2517-5163 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 5163-3754 : Rate B, Rate C , 0.0, 0.0 -> 828
% INFO    : Updated Thermal Rating: on line 2785-9055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4224
% INFO    : Updated Thermal Rating: on line 2785-9055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2921
% INFO    : Updated Thermal Rating: on line 4957-5464 : Rate B, Rate C , 0.0, 0.0 -> 2981
% INFO    : Updated Thermal Rating: on line 807-8625 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1522
% INFO    : Updated Thermal Rating: on line 6299-6879 : Rate B, Rate C , 0.0, 0.0 -> 1921
% INFO    : Updated Thermal Rating: on line 8247-4390 : Rate A, Rate B, Rate C , 1711.0, 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on line 8247-4390 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1351
% INFO    : Updated Thermal Rating: on line 7630-442 : Rate B, Rate C , 0.0, 0.0 -> 1463
% INFO    : Updated Thermal Rating: on line 8993-8378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2856
% INFO    : Updated Thermal Rating: on line 6879-4181 : Rate B, Rate C , 0.0, 0.0 -> 7808
% INFO    : Updated Thermal Rating: on line 3662-1475 : Rate B, Rate C , 0.0, 0.0 -> 32126
% INFO    : Updated Thermal Rating: on line 8242-8530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12595
% INFO    : Updated Thermal Rating: on line 5494-5290 : Rate B, Rate C , 0.0, 0.0 -> 981
% INFO    : Updated Thermal Rating: on line 5494-1437 : Rate B, Rate C , 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 6145-4279 : Rate B, Rate C , 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 6145-4279 : Rate B, Rate C , 0.0, 0.0 -> 1164
% INFO    : Updated Thermal Rating: on line 4652-597 : Rate A, Rate B, Rate C , 1678.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 3109-5329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4698
% INFO    : Updated Thermal Rating: on line 3109-5329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4612
% INFO    : Updated Thermal Rating: on line 4026-1074 : Rate B, Rate C , 0.0, 0.0 -> 1633
% INFO    : Updated Thermal Rating: on line 2355-8582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2024
% INFO    : Updated Thermal Rating: on line 1666-4058 : Rate B, Rate C , 0.0, 0.0 -> 21165
% INFO    : Updated Thermal Rating: on line 4493-1513 : Rate B, Rate C , 0.0, 0.0 -> 3317
% INFO    : Updated Thermal Rating: on line 1513-6604 : Rate B, Rate C , 0.0, 0.0 -> 3324
% INFO    : Updated Thermal Rating: on line 6604-1457 : Rate B, Rate C , 0.0, 0.0 -> 2216
% INFO    : Updated Thermal Rating: on line 3495-7629 : Rate B, Rate C , 0.0, 0.0 -> 3179
% INFO    : Updated Thermal Rating: on line 1985-9106 : Rate B, Rate C , 0.0, 0.0 -> 3430
% INFO    : Updated Thermal Rating: on line 4957-8012 : Rate B, Rate C , 0.0, 0.0 -> 2982
% INFO    : Updated Thermal Rating: on line 4651-5681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3182
% INFO    : Updated Thermal Rating: on line 4651-5681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2822
% INFO    : Updated Thermal Rating: on line 7795-445 : Rate B, Rate C , 0.0, 0.0 -> 1334
% INFO    : Updated Thermal Rating: on line 2700-4446 : Rate B, Rate C , 0.0, 0.0 -> 19605
% INFO    : Updated Thermal Rating: on line 4772-8301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 4772-988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 634
% INFO    : Updated Thermal Rating: on line 442-230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 924
% INFO    : Updated Thermal Rating: on line 4238-7312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 7366-3125 : Rate B, Rate C , 0.0, 0.0 -> 2767
% INFO    : Updated Thermal Rating: on line 7366-7423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 754-2096 : Rate B, Rate C , 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on line 1599-4096 : Rate B, Rate C , 0.0, 0.0 -> 7589
% INFO    : Updated Thermal Rating: on line 8079-4096 : Rate B, Rate C , 0.0, 0.0 -> 7754
% INFO    : Updated Thermal Rating: on line 230-1802 : Rate B, Rate C , 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 3027-4081 : Rate B, Rate C , 0.0, 0.0 -> 3458
% INFO    : Updated Thermal Rating: on line 4652-1280 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 1293
% INFO    : Updated Thermal Rating: on line 6315-6022 : Rate B, Rate C , 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 6315-8729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 6315-5631 : Rate B, Rate C , 0.0, 0.0 -> 1307
% INFO    : Updated Thermal Rating: on line 2622-8260 : Rate B, Rate C , 0.0, 0.0 -> 21248
% INFO    : Updated Thermal Rating: on line 6797-8301 : Rate B, Rate C , 0.0, 0.0 -> 927
% INFO    : Updated Thermal Rating: on line 4467-5465 : Rate B, Rate C , 0.0, 0.0 -> 1507
% INFO    : Updated Thermal Rating: on line 1728-2096 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on line 5793-2147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6585
% INFO    : Updated Thermal Rating: on line 5793-2147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6718
% INFO    : Updated Thermal Rating: on line 7688-385 : Rate B, Rate C , 0.0, 0.0 -> 6097
% INFO    : Updated Thermal Rating: on line 8301-6869 : Rate B, Rate C , 0.0, 0.0 -> 2691
% INFO    : Updated Thermal Rating: on line 1501-4081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3398
% INFO    : Updated Thermal Rating: on line 6022-695 : Rate B, Rate C , 0.0, 0.0 -> 137464
% INFO    : Updated Thermal Rating: on line 8776-695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42591
% INFO    : Updated Thermal Rating: on line 8776-5631 : Rate A, Rate B, Rate C , 457.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 2143-5631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4276
% INFO    : Updated Thermal Rating: on line 2143-5631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6853
% INFO    : Updated Thermal Rating: on line 5465-5025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 7632-6625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2111
% INFO    : Updated Thermal Rating: on line 5290-4279 : Rate B, Rate C , 0.0, 0.0 -> 913
% INFO    : Updated Thermal Rating: on line 5290-4279 : Rate B, Rate C , 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 5025-4752 : Rate B, Rate C , 0.0, 0.0 -> 4350
% INFO    : Updated Thermal Rating: on line 5025-7312 : Rate B, Rate C , 0.0, 0.0 -> 4376
% INFO    : Updated Thermal Rating: on line 1437-4279 : Rate A, Rate B, Rate C , 572.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 6654-7869 : Rate B, Rate C , 0.0, 0.0 -> 71510
% INFO    : Updated Thermal Rating: on line 6654-7869 : Rate B, Rate C , 0.0, 0.0 -> 73159
% INFO    : Updated Thermal Rating: on line 7351-5441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39412
% INFO    : Updated Thermal Rating: on line 4314-7571 : Rate B, Rate C , 0.0, 0.0 -> 1864
% INFO    : Updated Thermal Rating: on line 5803-3916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7252
% INFO    : Updated Thermal Rating: on line 6757-6036 : Rate B, Rate C , 0.0, 0.0 -> 12799
% INFO    : Updated Thermal Rating: on line 6757-6921 : Rate B, Rate C , 0.0, 0.0 -> 8353
% INFO    : Updated Thermal Rating: on line 5019-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53817
% INFO    : Updated Thermal Rating: on line 2930-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42657
% INFO    : Updated Thermal Rating: on line 1436-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53244
% INFO    : Updated Thermal Rating: on line 1851-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48642
% INFO    : Updated Thermal Rating: on line 8331-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53416
% INFO    : Updated Thermal Rating: on line 6220-8791 : Rate B, Rate C , 0.0, 0.0 -> 6384
% INFO    : Updated Thermal Rating: on line 9203-7842 : Rate B, Rate C , 0.0, 0.0 -> 41388
% INFO    : Updated Thermal Rating: on line 9203-8997 : Rate B, Rate C , 0.0, 0.0 -> 5051
% INFO    : Updated Thermal Rating: on line 9203-2129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4190
% INFO    : Updated Thermal Rating: on line 9203-29 : Rate B, Rate C , 0.0, 0.0 -> 3577
% INFO    : Updated Thermal Rating: on line 118-8903 : Rate B, Rate C , 0.0, 0.0 -> 34578
% INFO    : Updated Thermal Rating: on line 118-4598 : Rate B, Rate C , 0.0, 0.0 -> 4380
% INFO    : Updated Thermal Rating: on line 2426-5533 : Rate B, Rate C , 0.0, 0.0 -> 14992
% INFO    : Updated Thermal Rating: on line 2426-4831 : Rate B, Rate C , 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 2426-8961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on line 2426-8522 : Rate B, Rate C , 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 2426-6888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 2426-3401 : Rate B, Rate C , 0.0, 0.0 -> 4685
% INFO    : Updated Thermal Rating: on line 2426-641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3433
% INFO    : Updated Thermal Rating: on line 2426-2600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9747
% INFO    : Updated Thermal Rating: on line 2426-5351 : Rate B, Rate C , 0.0, 0.0 -> 1772
% INFO    : Updated Thermal Rating: on line 3051-718 : Rate B, Rate C , 0.0, 0.0 -> 124840
% INFO    : Updated Thermal Rating: on line 3036-2327 : Rate B, Rate C , 0.0, 0.0 -> 42335
% INFO    : Updated Thermal Rating: on line 8651-7473 : Rate B, Rate C , 0.0, 0.0 -> 972
% INFO    : Updated Thermal Rating: on line 8651-7473 : Rate B, Rate C , 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 903-3654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70101
% INFO    : Updated Thermal Rating: on line 8732-7050 : Rate B, Rate C , 0.0, 0.0 -> 21113
% INFO    : Updated Thermal Rating: on line 8732-3912 : Rate B, Rate C , 0.0, 0.0 -> 41734
% INFO    : Updated Thermal Rating: on line 2273-1973 : Rate B, Rate C , 0.0, 0.0 -> 50883
% INFO    : Updated Thermal Rating: on line 5131-2928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35472
% INFO    : Updated Thermal Rating: on line 6629-4918 : Rate B, Rate C , 0.0, 0.0 -> 2273
% INFO    : Updated Thermal Rating: on line 6629-7309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2617
% INFO    : Updated Thermal Rating: on line 413-1102 : Rate B, Rate C , 0.0, 0.0 -> 50969
% INFO    : Updated Thermal Rating: on line 413-1102 : Rate B, Rate C , 0.0, 0.0 -> 49351
% INFO    : Updated Thermal Rating: on line 3248-4918 : Rate B, Rate C , 0.0, 0.0 -> 7265
% INFO    : Updated Thermal Rating: on line 3248-4281 : Rate B, Rate C , 0.0, 0.0 -> 1670
% INFO    : Updated Thermal Rating: on line 3248-7309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9162
% INFO    : Updated Thermal Rating: on line 1146-1187 : Rate B, Rate C , 0.0, 0.0 -> 2399
% INFO    : Updated Thermal Rating: on line 1146-7945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9180
% INFO    : Updated Thermal Rating: on line 8900-2421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25425
% INFO    : Updated Thermal Rating: on line 6071-2972 : Rate B, Rate C , 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 6071-6031 : Rate B, Rate C , 0.0, 0.0 -> 2617
% INFO    : Updated Thermal Rating: on line 3293-7264 : Rate B, Rate C , 0.0, 0.0 -> 2816
% INFO    : Updated Thermal Rating: on line 3293-283 : Rate B, Rate C , 0.0, 0.0 -> 4036
% INFO    : Updated Thermal Rating: on line 3293-3069 : Rate B, Rate C , 0.0, 0.0 -> 939
% INFO    : Updated Thermal Rating: on line 3293-3390 : Rate B, Rate C , 0.0, 0.0 -> 3066
% INFO    : Updated Thermal Rating: on line 4689-4936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9881
% INFO    : Updated Thermal Rating: on line 4689-4936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9744
% INFO    : Updated Thermal Rating: on line 3218-7809 : Rate B, Rate C , 0.0, 0.0 -> 1598
% INFO    : Updated Thermal Rating: on line 3218-5455 : Rate B, Rate C , 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 3218-1857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1996
% INFO    : Updated Thermal Rating: on line 6806-5410 : Rate B, Rate C , 0.0, 0.0 -> 7899
% INFO    : Updated Thermal Rating: on line 6806-5410 : Rate B, Rate C , 0.0, 0.0 -> 8381
% INFO    : Updated Thermal Rating: on line 6806-1609 : Rate B, Rate C , 0.0, 0.0 -> 4018
% INFO    : Updated Thermal Rating: on line 6806-1609 : Rate B, Rate C , 0.0, 0.0 -> 4034
% INFO    : Updated Thermal Rating: on line 6806-1609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4041
% INFO    : Updated Thermal Rating: on line 6806-2438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9636
% INFO    : Updated Thermal Rating: on line 6806-954 : Rate B, Rate C , 0.0, 0.0 -> 11510
% INFO    : Updated Thermal Rating: on line 9140-502 : Rate B, Rate C , 0.0, 0.0 -> 2502
% INFO    : Updated Thermal Rating: on line 9140-3013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4315
% INFO    : Updated Thermal Rating: on line 9140-2949 : Rate B, Rate C , 0.0, 0.0 -> 3575
% INFO    : Updated Thermal Rating: on line 9140-2949 : Rate B, Rate C , 0.0, 0.0 -> 3646
% INFO    : Updated Thermal Rating: on line 9140-2949 : Rate B, Rate C , 0.0, 0.0 -> 3663
% INFO    : Updated Thermal Rating: on line 7070-2208 : Rate B, Rate C , 0.0, 0.0 -> 36421
% INFO    : Updated Thermal Rating: on line 7070-8060 : Rate B, Rate C , 0.0, 0.0 -> 25518
% INFO    : Updated Thermal Rating: on line 7070-4484 : Rate B, Rate C , 0.0, 0.0 -> 23967
% INFO    : Updated Thermal Rating: on line 7070-4239 : Rate B, Rate C , 0.0, 0.0 -> 8717
% INFO    : Updated Thermal Rating: on line 8535-7047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48244
% INFO    : Updated Thermal Rating: on line 5477-3657 : Rate B, Rate C , 0.0, 0.0 -> 25180
% INFO    : Updated Thermal Rating: on line 5477-2928 : Rate B, Rate C , 0.0, 0.0 -> 12337
% INFO    : Updated Thermal Rating: on line 3145-2918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 7770-5317 : Rate B, Rate C , 0.0, 0.0 -> 6584
% INFO    : Updated Thermal Rating: on line 7770-5317 : Rate B, Rate C , 0.0, 0.0 -> 6260
% INFO    : Updated Thermal Rating: on line 3-8676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3514
% INFO    : Updated Thermal Rating: on line 3-8189 : Rate B, Rate C , 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 7267-2938 : Rate B, Rate C , 0.0, 0.0 -> 3928
% INFO    : Updated Thermal Rating: on line 7267-2938 : Rate B, Rate C , 0.0, 0.0 -> 3990
% INFO    : Updated Thermal Rating: on line 7267-3918 : Rate B, Rate C , 0.0, 0.0 -> 1480
% INFO    : Updated Thermal Rating: on line 7267-3918 : Rate B, Rate C , 0.0, 0.0 -> 1511
% INFO    : Updated Thermal Rating: on line 7267-6581 : Rate B, Rate C , 0.0, 0.0 -> 2201
% INFO    : Updated Thermal Rating: on line 7267-6581 : Rate B, Rate C , 0.0, 0.0 -> 2246
% INFO    : Updated Thermal Rating: on line 7267-3830 : Rate B, Rate C , 0.0, 0.0 -> 2175
% INFO    : Updated Thermal Rating: on line 7267-5648 : Rate B, Rate C , 0.0, 0.0 -> 2087
% INFO    : Updated Thermal Rating: on line 7267-5648 : Rate B, Rate C , 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on line 4918-4907 : Rate B, Rate C , 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 4918-5957 : Rate B, Rate C , 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on line 4918-5233 : Rate B, Rate C , 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 6854-7309 : Rate B, Rate C , 0.0, 0.0 -> 148968
% INFO    : Updated Thermal Rating: on line 8311-3680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13251
% INFO    : Updated Thermal Rating: on line 2770-8804 : Rate B, Rate C , 0.0, 0.0 -> 7291
% INFO    : Updated Thermal Rating: on line 9241-8804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7442
% INFO    : Updated Thermal Rating: on line 3083-7124 : Rate B, Rate C , 0.0, 0.0 -> 7227
% INFO    : Updated Thermal Rating: on line 3083-7124 : Rate B, Rate C , 0.0, 0.0 -> 6738
% INFO    : Updated Thermal Rating: on line 3083-8873 : Rate B, Rate C , 0.0, 0.0 -> 6103
% INFO    : Updated Thermal Rating: on line 1566-7582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2393
% INFO    : Updated Thermal Rating: on line 1566-3541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2443
% INFO    : Updated Thermal Rating: on line 8683-3698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32156
% INFO    : Updated Thermal Rating: on line 8683-3698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33953
% INFO    : Updated Thermal Rating: on line 8683-2801 : Rate B, Rate C , 0.0, 0.0 -> 2515
% INFO    : Updated Thermal Rating: on line 8683-8328 : Rate B, Rate C , 0.0, 0.0 -> 14927
% INFO    : Updated Thermal Rating: on line 8683-8511 : Rate B, Rate C , 0.0, 0.0 -> 20990
% INFO    : Updated Thermal Rating: on line 8683-6570 : Rate B, Rate C , 0.0, 0.0 -> 2238
% INFO    : Updated Thermal Rating: on line 8683-6570 : Rate B, Rate C , 0.0, 0.0 -> 2415
% INFO    : Updated Thermal Rating: on line 8683-8975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13028
% INFO    : Updated Thermal Rating: on line 8683-216 : Rate B, Rate C , 0.0, 0.0 -> 6209
% INFO    : Updated Thermal Rating: on line 8683-2961 : Rate B, Rate C , 0.0, 0.0 -> 43067
% INFO    : Updated Thermal Rating: on line 8683-6773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122861
% INFO    : Updated Thermal Rating: on line 8683-5278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134762
% INFO    : Updated Thermal Rating: on line 3768-2751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34015
% INFO    : Updated Thermal Rating: on line 2276-5546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3946
% INFO    : Updated Thermal Rating: on line 2276-6816 : Rate B, Rate C , 0.0, 0.0 -> 2621
% INFO    : Updated Thermal Rating: on line 7766-444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2955
% INFO    : Updated Thermal Rating: on line 7766-5334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3062
% INFO    : Updated Thermal Rating: on line 839-3918 : Rate B, Rate C , 0.0, 0.0 -> 14872
% INFO    : Updated Thermal Rating: on line 839-809 : Rate B, Rate C , 0.0, 0.0 -> 10058
% INFO    : Updated Thermal Rating: on line 4506-2286 : Rate B, Rate C , 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 4506-6802 : Rate B, Rate C , 0.0, 0.0 -> 4050
% INFO    : Updated Thermal Rating: on line 4506-3520 : Rate B, Rate C , 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 7273-6271 : Rate B, Rate C , 0.0, 0.0 -> 947
% INFO    : Updated Thermal Rating: on line 7273-1435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 7273-7148 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 7273-7437 : Rate B, Rate C , 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 6104-871 : Rate B, Rate C , 0.0, 0.0 -> 12175
% INFO    : Updated Thermal Rating: on line 7580-871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13128
% INFO    : Updated Thermal Rating: on line 1188-1539 : Rate B, Rate C , 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 1188-8515 : Rate B, Rate C , 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 3971-4084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18252
% INFO    : Updated Thermal Rating: on line 3971-4084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18682
% INFO    : Updated Thermal Rating: on line 6845-5340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69711
% INFO    : Updated Thermal Rating: on line 8294-5814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6000
% INFO    : Updated Thermal Rating: on line 7115-6807 : Rate B, Rate C , 0.0, 0.0 -> 3309
% INFO    : Updated Thermal Rating: on line 619-6791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45348
% INFO    : Updated Thermal Rating: on line 5418-4908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37527
% INFO    : Updated Thermal Rating: on line 5120-6816 : Rate B, Rate C , 0.0, 0.0 -> 2192
% INFO    : Updated Thermal Rating: on line 6692-9158 : Rate B, Rate C , 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 6692-8035 : Rate B, Rate C , 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 3445-2848 : Rate B, Rate C , 0.0, 0.0 -> 4712
% INFO    : Updated Thermal Rating: on line 3445-7056 : Rate B, Rate C , 0.0, 0.0 -> 4156
% INFO    : Updated Thermal Rating: on line 3445-7056 : Rate B, Rate C , 0.0, 0.0 -> 5194
% INFO    : Updated Thermal Rating: on line 3445-1642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1759
% INFO    : Updated Thermal Rating: on line 3445-4594 : Rate B, Rate C , 0.0, 0.0 -> 6495
% INFO    : Updated Thermal Rating: on line 6114-1692 : Rate B, Rate C , 0.0, 0.0 -> 7400
% INFO    : Updated Thermal Rating: on line 6114-8190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7268
% INFO    : Updated Thermal Rating: on line 6114-5836 : Rate B, Rate C , 0.0, 0.0 -> 1522
% INFO    : Updated Thermal Rating: on line 6114-3191 : Rate B, Rate C , 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on line 6114-5300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2226
% INFO    : Updated Thermal Rating: on line 6114-4889 : Rate B, Rate C , 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on line 7264-444 : Rate B, Rate C , 0.0, 0.0 -> 1912
% INFO    : Updated Thermal Rating: on line 7264-4747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 7982-9011 : Rate B, Rate C , 0.0, 0.0 -> 25490
% INFO    : Updated Thermal Rating: on line 7982-6675 : Rate B, Rate C , 0.0, 0.0 -> 19252
% INFO    : Updated Thermal Rating: on line 7982-6909 : Rate B, Rate C , 0.0, 0.0 -> 27681
% INFO    : Updated Thermal Rating: on line 7982-8835 : Rate B, Rate C , 0.0, 0.0 -> 9714
% INFO    : Updated Thermal Rating: on line 7982-4186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25490
% INFO    : Updated Thermal Rating: on line 1604-502 : Rate B, Rate C , 0.0, 0.0 -> 22423
% INFO    : Updated Thermal Rating: on line 2842-502 : Rate B, Rate C , 0.0, 0.0 -> 20084
% INFO    : Updated Thermal Rating: on line 1354-513 : Rate B, Rate C , 0.0, 0.0 -> 3776
% INFO    : Updated Thermal Rating: on line 1354-502 : Rate B, Rate C , 0.0, 0.0 -> 6259
% INFO    : Updated Thermal Rating: on line 891-3697 : Rate B, Rate C , 0.0, 0.0 -> 6921
% INFO    : Updated Thermal Rating: on line 891-3697 : Rate B, Rate C , 0.0, 0.0 -> 6952
% INFO    : Updated Thermal Rating: on line 8312-7541 : Rate B, Rate C , 0.0, 0.0 -> 3162
% INFO    : Updated Thermal Rating: on line 8312-7541 : Rate B, Rate C , 0.0, 0.0 -> 3103
% INFO    : Updated Thermal Rating: on line 6306-4826 : Rate B, Rate C , 0.0, 0.0 -> 70039
% INFO    : Updated Thermal Rating: on line 4826-4418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66806
% INFO    : Updated Thermal Rating: on line 4826-1605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92032
% INFO    : Updated Thermal Rating: on line 4826-6952 : Rate B, Rate C , 0.0, 0.0 -> 1613
% INFO    : Updated Thermal Rating: on line 4826-7124 : Rate A, Rate B, Rate C , 514.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 9128-217 : Rate B, Rate C , 0.0, 0.0 -> 10923
% INFO    : Updated Thermal Rating: on line 7014-217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7964
% INFO    : Updated Thermal Rating: on line 720-5350 : Rate B, Rate C , 0.0, 0.0 -> 1764
% INFO    : Updated Thermal Rating: on line 720-5350 : Rate B, Rate C , 0.0, 0.0 -> 1730
% INFO    : Updated Thermal Rating: on line 1711-639 : Rate B, Rate C , 0.0, 0.0 -> 2771
% INFO    : Updated Thermal Rating: on line 1711-639 : Rate B, Rate C , 0.0, 0.0 -> 2720
% INFO    : Updated Thermal Rating: on line 1711-9130 : Rate B, Rate C , 0.0, 0.0 -> 3013
% INFO    : Updated Thermal Rating: on line 1711-9130 : Rate B, Rate C , 0.0, 0.0 -> 2595
% INFO    : Updated Thermal Rating: on line 8209-1998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37606
% INFO    : Updated Thermal Rating: on line 8209-7974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21666
% INFO    : Updated Thermal Rating: on line 1035-8180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1958
% INFO    : Updated Thermal Rating: on line 1035-7466 : Rate B, Rate C , 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 1035-305 : Rate B, Rate C , 0.0, 0.0 -> 7089
% INFO    : Updated Thermal Rating: on line 1035-305 : Rate B, Rate C , 0.0, 0.0 -> 6970
% INFO    : Updated Thermal Rating: on line 1035-5106 : Rate B, Rate C , 0.0, 0.0 -> 3531
% INFO    : Updated Thermal Rating: on line 1035-5106 : Rate B, Rate C , 0.0, 0.0 -> 4433
% INFO    : Updated Thermal Rating: on line 2527-8466 : Rate B, Rate C , 0.0, 0.0 -> 5811
% INFO    : Updated Thermal Rating: on line 8669-8893 : Rate B, Rate C , 0.0, 0.0 -> 11214
% INFO    : Updated Thermal Rating: on line 6206-7691 : Rate B, Rate C , 0.0, 0.0 -> 1676
% INFO    : Updated Thermal Rating: on line 6206-6624 : Rate B, Rate C , 0.0, 0.0 -> 2206
% INFO    : Updated Thermal Rating: on line 3240-8158 : Rate B, Rate C , 0.0, 0.0 -> 4292
% INFO    : Updated Thermal Rating: on line 3240-8795 : Rate B, Rate C , 0.0, 0.0 -> 1294
% INFO    : Updated Thermal Rating: on line 3240-4143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7181
% INFO    : Updated Thermal Rating: on line 3240-2797 : Rate B, Rate C , 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 3240-6331 : Rate B, Rate C , 0.0, 0.0 -> 2673
% INFO    : Updated Thermal Rating: on line 3240-6384 : Rate B, Rate C , 0.0, 0.0 -> 2795
% INFO    : Updated Thermal Rating: on line 3240-7523 : Rate B, Rate C , 0.0, 0.0 -> 3327
% INFO    : Updated Thermal Rating: on line 3240-2889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13596
% INFO    : Updated Thermal Rating: on line 3240-6887 : Rate B, Rate C , 0.0, 0.0 -> 1729
% INFO    : Updated Thermal Rating: on line 1249-4541 : Rate B, Rate C , 0.0, 0.0 -> 4424
% INFO    : Updated Thermal Rating: on line 819-7523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9048
% INFO    : Updated Thermal Rating: on line 2304-4353 : Rate B, Rate C , 0.0, 0.0 -> 3847
% INFO    : Updated Thermal Rating: on line 2304-4816 : Rate B, Rate C , 0.0, 0.0 -> 2165
% INFO    : Updated Thermal Rating: on line 9174-6246 : Rate B, Rate C , 0.0, 0.0 -> 3756
% INFO    : Updated Thermal Rating: on line 9174-6246 : Rate B, Rate C , 0.0, 0.0 -> 3682
% INFO    : Updated Thermal Rating: on line 9174-5658 : Rate B, Rate C , 0.0, 0.0 -> 2374
% INFO    : Updated Thermal Rating: on line 9174-5658 : Rate B, Rate C , 0.0, 0.0 -> 1979
% INFO    : Updated Thermal Rating: on line 2924-3645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12101
% INFO    : Updated Thermal Rating: on line 2924-3645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12156
% INFO    : Updated Thermal Rating: on line 59-5764 : Rate B, Rate C , 0.0, 0.0 -> 1583
% INFO    : Updated Thermal Rating: on line 59-2360 : Rate B, Rate C , 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 6510-9033 : Rate B, Rate C , 0.0, 0.0 -> 27118
% INFO    : Updated Thermal Rating: on line 6510-5918 : Rate B, Rate C , 0.0, 0.0 -> 2237
% INFO    : Updated Thermal Rating: on line 6510-5918 : Rate B, Rate C , 0.0, 0.0 -> 2498
% INFO    : Updated Thermal Rating: on line 1275-2850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7597
% INFO    : Updated Thermal Rating: on line 6426-4110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 6426-3558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 1758-2816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5059
% INFO    : Updated Thermal Rating: on line 1758-352 : Rate B, Rate C , 0.0, 0.0 -> 4370
% INFO    : Updated Thermal Rating: on line 1758-6581 : Rate B, Rate C , 0.0, 0.0 -> 4041
% INFO    : Updated Thermal Rating: on line 1758-1923 : Rate B, Rate C , 0.0, 0.0 -> 1823
% INFO    : Updated Thermal Rating: on line 1758-5837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2756
% INFO    : Updated Thermal Rating: on line 1758-3830 : Rate B, Rate C , 0.0, 0.0 -> 1671
% INFO    : Updated Thermal Rating: on line 1758-3577 : Rate B, Rate C , 0.0, 0.0 -> 8198
% INFO    : Updated Thermal Rating: on line 8030-1794 : Rate B, Rate C , 0.0, 0.0 -> 4858
% INFO    : Updated Thermal Rating: on line 8030-7808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4792
% INFO    : Updated Thermal Rating: on line 8030-6581 : Rate B, Rate C , 0.0, 0.0 -> 4130
% INFO    : Updated Thermal Rating: on line 8030-1923 : Rate B, Rate C , 0.0, 0.0 -> 1968
% INFO    : Updated Thermal Rating: on line 8030-5837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2707
% INFO    : Updated Thermal Rating: on line 8030-5648 : Rate B, Rate C , 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 8030-3577 : Rate B, Rate C , 0.0, 0.0 -> 8371
% INFO    : Updated Thermal Rating: on line 4615-171 : Rate B, Rate C , 0.0, 0.0 -> 2578
% INFO    : Updated Thermal Rating: on line 3137-2341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84603
% INFO    : Updated Thermal Rating: on line 6271-8787 : Rate B, Rate C , 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on line 6252-9137 : Rate B, Rate C , 0.0, 0.0 -> 753
% INFO    : Updated Thermal Rating: on line 5533-7133 : Rate B, Rate C , 0.0, 0.0 -> 2183
% INFO    : Updated Thermal Rating: on line 8361-4355 : Rate B, Rate C , 0.0, 0.0 -> 67762
% INFO    : Updated Thermal Rating: on line 8361-2928 : Rate B, Rate C , 0.0, 0.0 -> 30454
% INFO    : Updated Thermal Rating: on line 609-1341 : Rate B, Rate C , 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on line 609-5419 : Rate B, Rate C , 0.0, 0.0 -> 7777
% INFO    : Updated Thermal Rating: on line 609-5419 : Rate B, Rate C , 0.0, 0.0 -> 7651
% INFO    : Updated Thermal Rating: on line 609-2079 : Rate B, Rate C , 0.0, 0.0 -> 1302
% INFO    : Updated Thermal Rating: on line 609-772 : Rate B, Rate C , 0.0, 0.0 -> 1631
% INFO    : Updated Thermal Rating: on line 3654-2928 : Rate B, Rate C , 0.0, 0.0 -> 26642
% INFO    : Updated Thermal Rating: on line 1355-7282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on line 1355-2197 : Rate B, Rate C , 0.0, 0.0 -> 2059
% INFO    : Updated Thermal Rating: on line 1355-7640 : Rate B, Rate C , 0.0, 0.0 -> 2019
% INFO    : Updated Thermal Rating: on line 1355-1081 : Rate A, Rate B, Rate C , 1382.0, 0.0, 0.0 -> 1140
% INFO    : Updated Thermal Rating: on line 1355-1081 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on line 1355-2359 : Rate B, Rate C , 0.0, 0.0 -> 3422
% INFO    : Updated Thermal Rating: on line 1355-4196 : Rate B, Rate C , 0.0, 0.0 -> 1849
% INFO    : Updated Thermal Rating: on line 5856-8546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2811
% INFO    : Updated Thermal Rating: on line 5856-5987 : Rate B, Rate C , 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on line 5856-8005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 5856-3925 : Rate B, Rate C , 0.0, 0.0 -> 958
% INFO    : Updated Thermal Rating: on line 5856-3324 : Rate B, Rate C , 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 5856-4748 : Rate B, Rate C , 0.0, 0.0 -> 2964
% INFO    : Updated Thermal Rating: on line 8265-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11971
% INFO    : Updated Thermal Rating: on line 6151-6313 : Rate B, Rate C , 0.0, 0.0 -> 9442
% INFO    : Updated Thermal Rating: on line 4005-6532 : Rate B, Rate C , 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 4005-2177 : Rate B, Rate C , 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 5723-2079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1579
% INFO    : Updated Thermal Rating: on line 5723-789 : Rate B, Rate C , 0.0, 0.0 -> 1683
% INFO    : Updated Thermal Rating: on line 2327-9189 : Rate B, Rate C , 0.0, 0.0 -> 22821
% INFO    : Updated Thermal Rating: on line 2327-3400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21440
% INFO    : Updated Thermal Rating: on line 207-4747 : Rate B, Rate C , 0.0, 0.0 -> 2328
% INFO    : Updated Thermal Rating: on line 207-7791 : Rate B, Rate C , 0.0, 0.0 -> 5519
% INFO    : Updated Thermal Rating: on line 3205-6735 : Rate B, Rate C , 0.0, 0.0 -> 75017
% INFO    : Updated Thermal Rating: on line 3205-666 : Rate B, Rate C , 0.0, 0.0 -> 3501
% INFO    : Updated Thermal Rating: on line 3205-666 : Rate B, Rate C , 0.0, 0.0 -> 3579
% INFO    : Updated Thermal Rating: on line 3205-4435 : Rate A, Rate B, Rate C , 1382.0, 0.0, 0.0 -> 927
% INFO    : Updated Thermal Rating: on line 3205-1644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3991
% INFO    : Updated Thermal Rating: on line 3205-3483 : Rate B, Rate C , 0.0, 0.0 -> 3742
% INFO    : Updated Thermal Rating: on line 4683-7989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25173
% INFO    : Updated Thermal Rating: on line 4683-6516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28780
% INFO    : Updated Thermal Rating: on line 4683-7697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25191
% INFO    : Updated Thermal Rating: on line 4683-416 : Rate B, Rate C , 0.0, 0.0 -> 1284
% INFO    : Updated Thermal Rating: on line 4683-2847 : Rate B, Rate C , 0.0, 0.0 -> 2810
% INFO    : Updated Thermal Rating: on line 4683-2563 : Rate B, Rate C , 0.0, 0.0 -> 2871
% INFO    : Updated Thermal Rating: on line 4683-2563 : Rate B, Rate C , 0.0, 0.0 -> 2961
% INFO    : Updated Thermal Rating: on line 4683-2995 : Rate B, Rate C , 0.0, 0.0 -> 1609
% INFO    : Updated Thermal Rating: on line 5691-1001 : Rate A, Rate B, Rate C , 610.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5691-4426 : Rate A, Rate B, Rate C , 514.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 5350-2721 : Rate B, Rate C , 0.0, 0.0 -> 4683
% INFO    : Updated Thermal Rating: on line 5350-2721 : Rate B, Rate C , 0.0, 0.0 -> 4773
% INFO    : Updated Thermal Rating: on line 2361-4936 : Rate B, Rate C , 0.0, 0.0 -> 3215
% INFO    : Updated Thermal Rating: on line 2361-5179 : Rate B, Rate C , 0.0, 0.0 -> 2630
% INFO    : Updated Thermal Rating: on line 2044-4748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16743
% INFO    : Updated Thermal Rating: on line 4197-5522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14024
% INFO    : Updated Thermal Rating: on line 5699-8670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12826
% INFO    : Updated Thermal Rating: on line 7809-5110 : Rate B, Rate C , 0.0, 0.0 -> 1823
% INFO    : Updated Thermal Rating: on line 7222-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1003
% INFO    : Updated Thermal Rating: on line 4402-3817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113538
% INFO    : Updated Thermal Rating: on line 6857-2732 : Rate B, Rate C , 0.0, 0.0 -> 4391
% INFO    : Updated Thermal Rating: on line 6857-4550 : Rate B, Rate C , 0.0, 0.0 -> 4740
% INFO    : Updated Thermal Rating: on line 6857-4339 : Rate B, Rate C , 0.0, 0.0 -> 2079
% INFO    : Updated Thermal Rating: on line 6857-7513 : Rate B, Rate C , 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 5016-26 : Rate B, Rate C , 0.0, 0.0 -> 5182
% INFO    : Updated Thermal Rating: on line 5016-9213 : Rate B, Rate C , 0.0, 0.0 -> 6285
% INFO    : Updated Thermal Rating: on line 6112-9002 : Rate B, Rate C , 0.0, 0.0 -> 2344
% INFO    : Updated Thermal Rating: on line 6112-6231 : Rate B, Rate C , 0.0, 0.0 -> 2089
% INFO    : Updated Thermal Rating: on line 6112-883 : Rate B, Rate C , 0.0, 0.0 -> 1654
% INFO    : Updated Thermal Rating: on line 6112-5738 : Rate B, Rate C , 0.0, 0.0 -> 2297
% INFO    : Updated Thermal Rating: on line 8860-7700 : Rate B, Rate C , 0.0, 0.0 -> 3302
% INFO    : Updated Thermal Rating: on line 8860-9002 : Rate B, Rate C , 0.0, 0.0 -> 2693
% INFO    : Updated Thermal Rating: on line 8860-5990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 8860-6450 : Rate B, Rate C , 0.0, 0.0 -> 2234
% INFO    : Updated Thermal Rating: on line 8860-7726 : Rate B, Rate C , 0.0, 0.0 -> 4269
% INFO    : Updated Thermal Rating: on line 2489-4110 : Rate B, Rate C , 0.0, 0.0 -> 7985
% INFO    : Updated Thermal Rating: on line 3985-6376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1596
% INFO    : Updated Thermal Rating: on line 3985-4110 : Rate B, Rate C , 0.0, 0.0 -> 7062
% INFO    : Updated Thermal Rating: on line 3985-4829 : Rate B, Rate C , 0.0, 0.0 -> 875
% INFO    : Updated Thermal Rating: on line 3985-7857 : Rate B, Rate C , 0.0, 0.0 -> 6817
% INFO    : Updated Thermal Rating: on line 2806-7857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6858
% INFO    : Updated Thermal Rating: on line 2489-9012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5335
% INFO    : Updated Thermal Rating: on line 2489-2231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5728
% INFO    : Updated Thermal Rating: on line 658-3793 : Rate B, Rate C , 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 658-8497 : Rate B, Rate C , 0.0, 0.0 -> 1298
% INFO    : Updated Thermal Rating: on line 658-8497 : Rate B, Rate C , 0.0, 0.0 -> 1274
% INFO    : Updated Thermal Rating: on line 3502-9002 : Rate B, Rate C , 0.0, 0.0 -> 34833
% INFO    : Updated Thermal Rating: on line 3502-9002 : Rate B, Rate C , 0.0, 0.0 -> 31811
% INFO    : Updated Thermal Rating: on line 6313-44 : Rate B, Rate C , 0.0, 0.0 -> 1405
% INFO    : Updated Thermal Rating: on line 6313-7582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1387
% INFO    : Updated Thermal Rating: on line 5944-8808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17349
% INFO    : Updated Thermal Rating: on line 3183-8515 : Rate B, Rate C , 0.0, 0.0 -> 2903
% INFO    : Updated Thermal Rating: on line 1005-8515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3155
% INFO    : Updated Thermal Rating: on line 8787-1448 : Rate B, Rate C , 0.0, 0.0 -> 2543
% INFO    : Updated Thermal Rating: on line 6636-9051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41134
% INFO    : Updated Thermal Rating: on line 9109-9051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45856
% INFO    : Updated Thermal Rating: on line 6961-6376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on line 6961-8818 : Rate B, Rate C , 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on line 5077-4353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23256
% INFO    : Updated Thermal Rating: on line 7471-5241 : Rate B, Rate C , 0.0, 0.0 -> 1935
% INFO    : Updated Thermal Rating: on line 7471-8200 : Rate B, Rate C , 0.0, 0.0 -> 50038
% INFO    : Updated Thermal Rating: on line 549-6290 : Rate B, Rate C , 0.0, 0.0 -> 1259
% INFO    : Updated Thermal Rating: on line 549-2291 : Rate B, Rate C , 0.0, 0.0 -> 1410
% INFO    : Updated Thermal Rating: on line 549-3656 : Rate B, Rate C , 0.0, 0.0 -> 2991
% INFO    : Updated Thermal Rating: on line 5002-4144 : Rate B, Rate C , 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 1888-5441 : Rate B, Rate C , 0.0, 0.0 -> 10884
% INFO    : Updated Thermal Rating: on line 1888-5441 : Rate B, Rate C , 0.0, 0.0 -> 10446
% INFO    : Updated Thermal Rating: on line 5490-4970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4899
% INFO    : Updated Thermal Rating: on line 5490-4970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4772
% INFO    : Updated Thermal Rating: on line 5490-4970 : Rate B, Rate C , 0.0, 0.0 -> 4325
% INFO    : Updated Thermal Rating: on line 5490-5461 : Rate B, Rate C , 0.0, 0.0 -> 3631
% INFO    : Updated Thermal Rating: on line 5490-7778 : Rate B, Rate C , 0.0, 0.0 -> 2930
% INFO    : Updated Thermal Rating: on line 5490-6897 : Rate B, Rate C , 0.0, 0.0 -> 2877
% INFO    : Updated Thermal Rating: on line 3075-4562 : Rate B, Rate C , 0.0, 0.0 -> 6077
% INFO    : Updated Thermal Rating: on line 564-8475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1280
% INFO    : Updated Thermal Rating: on line 564-2252 : Rate B, Rate C , 0.0, 0.0 -> 1893
% INFO    : Updated Thermal Rating: on line 564-7903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 4331-1857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142001
% INFO    : Updated Thermal Rating: on line 2877-3674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5705
% INFO    : Updated Thermal Rating: on line 2854-1081 : Rate A, Rate B, Rate C , 1020.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 2854-8267 : Rate B, Rate C , 0.0, 0.0 -> 2146
% INFO    : Updated Thermal Rating: on line 9112-9176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1795
% INFO    : Updated Thermal Rating: on line 9112-1422 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 9112-8515 : Rate B, Rate C , 0.0, 0.0 -> 1775
% INFO    : Updated Thermal Rating: on line 9112-8515 : Rate B, Rate C , 0.0, 0.0 -> 1879
% INFO    : Updated Thermal Rating: on line 9112-5051 : Rate B, Rate C , 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 9112-1051 : Rate B, Rate C , 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on line 9112-1397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2012
% INFO    : Updated Thermal Rating: on line 9112-1584 : Rate B, Rate C , 0.0, 0.0 -> 925
% INFO    : Updated Thermal Rating: on line 6168-6888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1835
% INFO    : Updated Thermal Rating: on line 7653-3019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142001
% INFO    : Updated Thermal Rating: on line 7341-7098 : Rate B, Rate C , 0.0, 0.0 -> 4392
% INFO    : Updated Thermal Rating: on line 4701-8267 : Rate B, Rate C , 0.0, 0.0 -> 31398
% INFO    : Updated Thermal Rating: on line 1672-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30565
% INFO    : Updated Thermal Rating: on line 3880-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29969
% INFO    : Updated Thermal Rating: on line 6648-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30207
% INFO    : Updated Thermal Rating: on line 3609-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31096
% INFO    : Updated Thermal Rating: on line 2782-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28500
% INFO    : Updated Thermal Rating: on line 1844-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29005
% INFO    : Updated Thermal Rating: on line 4353-6053 : Rate B, Rate C , 0.0, 0.0 -> 2550
% INFO    : Updated Thermal Rating: on line 2166-5237 : Rate B, Rate C , 0.0, 0.0 -> 16450
% INFO    : Updated Thermal Rating: on line 2166-2886 : Rate B, Rate C , 0.0, 0.0 -> 2906
% INFO    : Updated Thermal Rating: on line 1043-3513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157740
% INFO    : Updated Thermal Rating: on line 4049-883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98903
% INFO    : Updated Thermal Rating: on line 4520-883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89464
% INFO    : Updated Thermal Rating: on line 1704-5814 : Rate B, Rate C , 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 8107-1486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49257
% INFO    : Updated Thermal Rating: on line 5664-5522 : Rate B, Rate C , 0.0, 0.0 -> 7545
% INFO    : Updated Thermal Rating: on line 4482-8670 : Rate B, Rate C , 0.0, 0.0 -> 7692
% INFO    : Updated Thermal Rating: on line 8795-7523 : Rate B, Rate C , 0.0, 0.0 -> 2355
% INFO    : Updated Thermal Rating: on line 2337-6430 : Rate B, Rate C , 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 455-7775 : Rate B, Rate C , 0.0, 0.0 -> 1155
% INFO    : Updated Thermal Rating: on line 455-3857 : Rate B, Rate C , 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 455-333 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 455-6940 : Rate B, Rate C , 0.0, 0.0 -> 1056
% INFO    : Updated Thermal Rating: on line 8225-3656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5843
% INFO    : Updated Thermal Rating: on line 5413-7752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1699
% INFO    : Updated Thermal Rating: on line 5413-1940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2910
% INFO    : Updated Thermal Rating: on line 5413-4234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 2591-6828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 2591-7571 : Rate B, Rate C , 0.0, 0.0 -> 1233
% INFO    : Updated Thermal Rating: on line 2591-7571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1679
% INFO    : Updated Thermal Rating: on line 2591-7571 : Rate B, Rate C , 0.0, 0.0 -> 1437
% INFO    : Updated Thermal Rating: on line 2591-7994 : Rate B, Rate C , 0.0, 0.0 -> 702
% INFO    : Updated Thermal Rating: on line 2591-7226 : Rate B, Rate C , 0.0, 0.0 -> 1711
% INFO    : Updated Thermal Rating: on line 2591-1554 : Rate B, Rate C , 0.0, 0.0 -> 1125
% INFO    : Updated Thermal Rating: on line 9011-1156 : Rate B, Rate C , 0.0, 0.0 -> 7870
% INFO    : Updated Thermal Rating: on line 8689-5502 : Rate B, Rate C , 0.0, 0.0 -> 3499
% INFO    : Updated Thermal Rating: on line 3085-8873 : Rate B, Rate C , 0.0, 0.0 -> 2346
% INFO    : Updated Thermal Rating: on line 1568-980 : Rate B, Rate C , 0.0, 0.0 -> 50801
% INFO    : Updated Thermal Rating: on line 3204-3331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2659
% INFO    : Updated Thermal Rating: on line 3557-639 : Rate B, Rate C , 0.0, 0.0 -> 4539
% INFO    : Updated Thermal Rating: on line 3557-4936 : Rate B, Rate C , 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 416-3492 : Rate B, Rate C , 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 416-7937 : Rate B, Rate C , 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 3255-1262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1762
% INFO    : Updated Thermal Rating: on line 3255-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49730
% INFO    : Updated Thermal Rating: on line 7373-367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1943
% INFO    : Updated Thermal Rating: on line 4251-2132 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 4251-2132 : Rate B, Rate C , 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 4251-5567 : Rate B, Rate C , 0.0, 0.0 -> 2996
% INFO    : Updated Thermal Rating: on line 6376-1808 : Rate B, Rate C , 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on line 6376-1808 : Rate B, Rate C , 0.0, 0.0 -> 1139
% INFO    : Updated Thermal Rating: on line 6376-7857 : Rate B, Rate C , 0.0, 0.0 -> 1826
% INFO    : Updated Thermal Rating: on line 9185-7289 : Rate B, Rate C , 0.0, 0.0 -> 4058
% INFO    : Updated Thermal Rating: on line 9185-3999 : Rate B, Rate C , 0.0, 0.0 -> 45778
% INFO    : Updated Thermal Rating: on line 8653-2303 : Rate B, Rate C , 0.0, 0.0 -> 4384
% INFO    : Updated Thermal Rating: on line 908-6474 : Rate B, Rate C , 0.0, 0.0 -> 16400
% INFO    : Updated Thermal Rating: on line 7030-6474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14972
% INFO    : Updated Thermal Rating: on line 4205-6556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18862
% INFO    : Updated Thermal Rating: on line 7325-6556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18455
% INFO    : Updated Thermal Rating: on line 5857-3391 : Rate B, Rate C , 0.0, 0.0 -> 3688
% INFO    : Updated Thermal Rating: on line 5857-3760 : Rate B, Rate C , 0.0, 0.0 -> 5049
% INFO    : Updated Thermal Rating: on line 3707-8765 : Rate B, Rate C , 0.0, 0.0 -> 24790
% INFO    : Updated Thermal Rating: on line 900-6619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21835
% INFO    : Updated Thermal Rating: on line 2918-8109 : Rate A, Rate B, Rate C , 1876.0, 0.0, 0.0 -> 1755
% INFO    : Updated Thermal Rating: on line 2918-8109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2081
% INFO    : Updated Thermal Rating: on line 6532-2177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 6532-5317 : Rate A, Rate B, Rate C , 610.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 6532-608 : Rate B, Rate C , 0.0, 0.0 -> 909
% INFO    : Updated Thermal Rating: on line 6532-608 : Rate B, Rate C , 0.0, 0.0 -> 990
% INFO    : Updated Thermal Rating: on line 4494-8763 : Rate B, Rate C , 0.0, 0.0 -> 2279
% INFO    : Updated Thermal Rating: on line 4494-7056 : Rate B, Rate C , 0.0, 0.0 -> 2375
% INFO    : Updated Thermal Rating: on line 6828-5814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1202
% INFO    : Updated Thermal Rating: on line 3670-21 : Rate B, Rate C , 0.0, 0.0 -> 22404
% INFO    : Updated Thermal Rating: on line 5137-7702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5156
% INFO    : Updated Thermal Rating: on line 1334-7702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5264
% INFO    : Updated Thermal Rating: on line 8448-7624 : Rate B, Rate C , 0.0, 0.0 -> 3961
% INFO    : Updated Thermal Rating: on line 8448-1129 : Rate B, Rate C , 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 8448-3070 : Rate B, Rate C , 0.0, 0.0 -> 1457
% INFO    : Updated Thermal Rating: on line 8448-306 : Rate B, Rate C , 0.0, 0.0 -> 3020
% INFO    : Updated Thermal Rating: on line 8448-306 : Rate B, Rate C , 0.0, 0.0 -> 2963
% INFO    : Updated Thermal Rating: on line 8448-7491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1223
% INFO    : Updated Thermal Rating: on line 4685-2089 : Rate B, Rate C , 0.0, 0.0 -> 35750
% INFO    : Updated Thermal Rating: on line 7485-6253 : Rate B, Rate C , 0.0, 0.0 -> 25882
% INFO    : Updated Thermal Rating: on line 7485-1562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38849
% INFO    : Updated Thermal Rating: on line 7776-1644 : Rate B, Rate C , 0.0, 0.0 -> 10592
% INFO    : Updated Thermal Rating: on line 5971-3483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10925
% INFO    : Updated Thermal Rating: on line 2786-1644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9741
% INFO    : Updated Thermal Rating: on line 972-3483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9474
% INFO    : Updated Thermal Rating: on line 8906-923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29496
% INFO    : Updated Thermal Rating: on line 8906-4914 : Rate B, Rate C , 0.0, 0.0 -> 29418
% INFO    : Updated Thermal Rating: on line 2656-9101 : Rate B, Rate C , 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 2656-7164 : Rate A, Rate B, Rate C , 1876.0, 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on line 3519-9101 : Rate B, Rate C , 0.0, 0.0 -> 1430
% INFO    : Updated Thermal Rating: on line 3519-7164 : Rate B, Rate C , 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 1775-9137 : Rate B, Rate C , 0.0, 0.0 -> 2649
% INFO    : Updated Thermal Rating: on line 1775-9137 : Rate B, Rate C , 0.0, 0.0 -> 3236
% INFO    : Updated Thermal Rating: on line 5641-1026 : Rate A, Rate B, Rate C , 419.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 5641-9137 : Rate B, Rate C , 0.0, 0.0 -> 3297
% INFO    : Updated Thermal Rating: on line 1096-2889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17110
% INFO    : Updated Thermal Rating: on line 7380-2732 : Rate B, Rate C , 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on line 7380-4787 : Rate B, Rate C , 0.0, 0.0 -> 29975
% INFO    : Updated Thermal Rating: on line 3543-5308 : Rate B, Rate C , 0.0, 0.0 -> 3899
% INFO    : Updated Thermal Rating: on line 3543-3830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4697
% INFO    : Updated Thermal Rating: on line 2372-1027 : Rate B, Rate C , 0.0, 0.0 -> 4210
% INFO    : Updated Thermal Rating: on line 2372-5648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4991
% INFO    : Updated Thermal Rating: on line 367-1172 : Rate B, Rate C , 0.0, 0.0 -> 3570
% INFO    : Updated Thermal Rating: on line 367-9191 : Rate B, Rate C , 0.0, 0.0 -> 5103
% INFO    : Updated Thermal Rating: on line 367-8722 : Rate B, Rate C , 0.0, 0.0 -> 5087
% INFO    : Updated Thermal Rating: on line 1833-3610 : Rate B, Rate C , 0.0, 0.0 -> 8331
% INFO    : Updated Thermal Rating: on line 1833-3610 : Rate B, Rate C , 0.0, 0.0 -> 9649
% INFO    : Updated Thermal Rating: on line 1833-3962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3558
% INFO    : Updated Thermal Rating: on line 1833-1838 : Rate B, Rate C , 0.0, 0.0 -> 6744
% INFO    : Updated Thermal Rating: on line 1833-2230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6876
% INFO    : Updated Thermal Rating: on line 5388-2467 : Rate B, Rate C , 0.0, 0.0 -> 2041
% INFO    : Updated Thermal Rating: on line 5388-2467 : Rate B, Rate C , 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 6110-8853 : Rate B, Rate C , 0.0, 0.0 -> 5394
% INFO    : Updated Thermal Rating: on line 6110-1001 : Rate B, Rate C , 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 7583-1808 : Rate B, Rate C , 0.0, 0.0 -> 2610
% INFO    : Updated Thermal Rating: on line 7583-2889 : Rate B, Rate C , 0.0, 0.0 -> 995
% INFO    : Updated Thermal Rating: on line 26-6624 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 927
% INFO    : Updated Thermal Rating: on line 26-2479 : Rate B, Rate C , 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 26-4598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2160
% INFO    : Updated Thermal Rating: on line 26-4231 : Rate B, Rate C , 0.0, 0.0 -> 3184
% INFO    : Updated Thermal Rating: on line 26-5144 : Rate B, Rate C , 0.0, 0.0 -> 6520
% INFO    : Updated Thermal Rating: on line 26-5144 : Rate B, Rate C , 0.0, 0.0 -> 7895
% INFO    : Updated Thermal Rating: on line 7691-2479 : Rate B, Rate C , 0.0, 0.0 -> 1827
% INFO    : Updated Thermal Rating: on line 7691-2129 : Rate B, Rate C , 0.0, 0.0 -> 2120
% INFO    : Updated Thermal Rating: on line 7691-9213 : Rate B, Rate C , 0.0, 0.0 -> 9168
% INFO    : Updated Thermal Rating: on line 7691-9213 : Rate B, Rate C , 0.0, 0.0 -> 12700
% INFO    : Updated Thermal Rating: on line 7691-4231 : Rate B, Rate C , 0.0, 0.0 -> 3251
% INFO    : Updated Thermal Rating: on line 7691-3513 : Rate B, Rate C , 0.0, 0.0 -> 6651
% INFO    : Updated Thermal Rating: on line 7691-3513 : Rate B, Rate C , 0.0, 0.0 -> 7915
% INFO    : Updated Thermal Rating: on line 1876-3906 : Rate B, Rate C , 0.0, 0.0 -> 6116
% INFO    : Updated Thermal Rating: on line 113-3906 : Rate B, Rate C , 0.0, 0.0 -> 6246
% INFO    : Updated Thermal Rating: on line 7752-3758 : Rate B, Rate C , 0.0, 0.0 -> 1361
% INFO    : Updated Thermal Rating: on line 7752-3758 : Rate B, Rate C , 0.0, 0.0 -> 1484
% INFO    : Updated Thermal Rating: on line 7752-3758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1538
% INFO    : Updated Thermal Rating: on line 4952-8976 : Rate B, Rate C , 0.0, 0.0 -> 2888
% INFO    : Updated Thermal Rating: on line 4952-8189 : Rate B, Rate C , 0.0, 0.0 -> 1594
% INFO    : Updated Thermal Rating: on line 6119-7886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 6119-4544 : Rate B, Rate C , 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 6119-4544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2080
% INFO    : Updated Thermal Rating: on line 7905-3697 : Rate B, Rate C , 0.0, 0.0 -> 1941
% INFO    : Updated Thermal Rating: on line 7905-7541 : Rate B, Rate C , 0.0, 0.0 -> 7052
% INFO    : Updated Thermal Rating: on line 7905-7541 : Rate B, Rate C , 0.0, 0.0 -> 8133
% INFO    : Updated Thermal Rating: on line 7905-4141 : Rate B, Rate C , 0.0, 0.0 -> 2731
% INFO    : Updated Thermal Rating: on line 7905-4141 : Rate B, Rate C , 0.0, 0.0 -> 2678
% INFO    : Updated Thermal Rating: on line 7905-3022 : Rate B, Rate C , 0.0, 0.0 -> 2102
% INFO    : Updated Thermal Rating: on line 1768-163 : Rate B, Rate C , 0.0, 0.0 -> 2472
% INFO    : Updated Thermal Rating: on line 4245-2425 : Rate B, Rate C , 0.0, 0.0 -> 25068
% INFO    : Updated Thermal Rating: on line 3698-5297 : Rate B, Rate C , 0.0, 0.0 -> 45030
% INFO    : Updated Thermal Rating: on line 750-8328 : Rate B, Rate C , 0.0, 0.0 -> 25940
% INFO    : Updated Thermal Rating: on line 750-870 : Rate B, Rate C , 0.0, 0.0 -> 21222
% INFO    : Updated Thermal Rating: on line 750-2961 : Rate B, Rate C , 0.0, 0.0 -> 45595
% INFO    : Updated Thermal Rating: on line 3499-7988 : Rate B, Rate C , 0.0, 0.0 -> 4620
% INFO    : Updated Thermal Rating: on line 3499-2197 : Rate B, Rate C , 0.0, 0.0 -> 2596
% INFO    : Updated Thermal Rating: on line 3499-7640 : Rate B, Rate C , 0.0, 0.0 -> 2652
% INFO    : Updated Thermal Rating: on line 3499-4231 : Rate B, Rate C , 0.0, 0.0 -> 3251
% INFO    : Updated Thermal Rating: on line 3499-5144 : Rate B, Rate C , 0.0, 0.0 -> 2438
% INFO    : Updated Thermal Rating: on line 3499-3513 : Rate B, Rate C , 0.0, 0.0 -> 2485
% INFO    : Updated Thermal Rating: on line 7289-3999 : Rate B, Rate C , 0.0, 0.0 -> 4537
% INFO    : Updated Thermal Rating: on line 3018-1051 : Rate B, Rate C , 0.0, 0.0 -> 89200
% INFO    : Updated Thermal Rating: on line 2702-3435 : Rate B, Rate C , 0.0, 0.0 -> 43865
% INFO    : Updated Thermal Rating: on line 9131-2020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42767
% INFO    : Updated Thermal Rating: on line 6308-6684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29632
% INFO    : Updated Thermal Rating: on line 4831-3680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 837
% INFO    : Updated Thermal Rating: on line 5410-2751 : Rate B, Rate C , 0.0, 0.0 -> 1363
% INFO    : Updated Thermal Rating: on line 3082-4623 : Rate B, Rate C , 0.0, 0.0 -> 2470
% INFO    : Updated Thermal Rating: on line 3082-4339 : Rate B, Rate C , 0.0, 0.0 -> 3176
% INFO    : Updated Thermal Rating: on line 3082-5288 : Rate B, Rate C , 0.0, 0.0 -> 105881
% INFO    : Updated Thermal Rating: on line 3082-5421 : Rate B, Rate C , 0.0, 0.0 -> 39728
% INFO    : Updated Thermal Rating: on line 3082-6475 : Rate A, Rate B, Rate C , 1613.0, 0.0, 0.0 -> 1535
% INFO    : Updated Thermal Rating: on line 3082-8468 : Rate B, Rate C , 0.0, 0.0 -> 2069
% INFO    : Updated Thermal Rating: on line 6224-2732 : Rate B, Rate C , 0.0, 0.0 -> 1737
% INFO    : Updated Thermal Rating: on line 6224-7513 : Rate B, Rate C , 0.0, 0.0 -> 2808
% INFO    : Updated Thermal Rating: on line 6224-6475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1844
% INFO    : Updated Thermal Rating: on line 2174-4623 : Rate B, Rate C , 0.0, 0.0 -> 2437
% INFO    : Updated Thermal Rating: on line 2174-4550 : Rate B, Rate C , 0.0, 0.0 -> 1809
% INFO    : Updated Thermal Rating: on line 2174-6475 : Rate A, Rate B, Rate C , 1777.0, 0.0, 0.0 -> 1629
% INFO    : Updated Thermal Rating: on line 2083-9231 : Rate B, Rate C , 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 2083-9231 : Rate B, Rate C , 0.0, 0.0 -> 2107
% INFO    : Updated Thermal Rating: on line 2083-9231 : Rate B, Rate C , 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 2083-4054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36840
% INFO    : Updated Thermal Rating: on line 2083-3481 : Rate B, Rate C , 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 2083-3602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3104
% INFO    : Updated Thermal Rating: on line 2083-2794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12197
% INFO    : Updated Thermal Rating: on line 2083-2794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13903
% INFO    : Updated Thermal Rating: on line 2083-8467 : Rate B, Rate C , 0.0, 0.0 -> 785
% INFO    : Updated Thermal Rating: on line 2083-1136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4796
% INFO    : Updated Thermal Rating: on line 2083-22 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4752
% INFO    : Updated Thermal Rating: on line 8853-1001 : Rate B, Rate C , 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 8853-4950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 8853-4410 : Rate B, Rate C , 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 8853-6697 : Rate B, Rate C , 0.0, 0.0 -> 1905
% INFO    : Updated Thermal Rating: on line 8853-1159 : Rate B, Rate C , 0.0, 0.0 -> 2874
% INFO    : Updated Thermal Rating: on line 8853-7165 : Rate B, Rate C , 0.0, 0.0 -> 1170
% INFO    : Updated Thermal Rating: on line 2938-2848 : Rate B, Rate C , 0.0, 0.0 -> 5758
% INFO    : Updated Thermal Rating: on line 2938-2848 : Rate B, Rate C , 0.0, 0.0 -> 5875
% INFO    : Updated Thermal Rating: on line 2938-7522 : Rate B, Rate C , 0.0, 0.0 -> 2288
% INFO    : Updated Thermal Rating: on line 2938-7522 : Rate B, Rate C , 0.0, 0.0 -> 2025
% INFO    : Updated Thermal Rating: on line 2938-1642 : Rate A, Rate B, Rate C , 1810.0, 0.0, 0.0 -> 1418
% INFO    : Updated Thermal Rating: on line 2938-809 : Rate A, Rate B, Rate C , 1810.0, 0.0, 0.0 -> 1448
% INFO    : Updated Thermal Rating: on line 9189-6791 : Rate B, Rate C , 0.0, 0.0 -> 9227
% INFO    : Updated Thermal Rating: on line 9189-3400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37102
% INFO    : Updated Thermal Rating: on line 9189-7092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10077
% INFO    : Updated Thermal Rating: on line 9189-3718 : Rate B, Rate C , 0.0, 0.0 -> 12119
% INFO    : Updated Thermal Rating: on line 9189-3701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13958
% INFO    : Updated Thermal Rating: on line 9189-7507 : Rate B, Rate C , 0.0, 0.0 -> 3272
% INFO    : Updated Thermal Rating: on line 9189-7507 : Rate B, Rate C , 0.0, 0.0 -> 2926
% INFO    : Updated Thermal Rating: on line 9189-7507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3642
% INFO    : Updated Thermal Rating: on line 9189-2406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4517
% INFO    : Updated Thermal Rating: on line 2801-8511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37687
% INFO    : Updated Thermal Rating: on line 2801-216 : Rate B, Rate C , 0.0, 0.0 -> 4920
% INFO    : Updated Thermal Rating: on line 453-2129 : Rate B, Rate C , 0.0, 0.0 -> 11419
% INFO    : Updated Thermal Rating: on line 8691-6952 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 604
% INFO    : Updated Thermal Rating: on line 8691-6952 : Rate A, Rate B, Rate C , 591.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 8691-1183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1500
% INFO    : Updated Thermal Rating: on line 8691-4410 : Rate B, Rate C , 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 8691-8743 : Rate B, Rate C , 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 2446-8763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4461
% INFO    : Updated Thermal Rating: on line 2627-8763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4501
% INFO    : Updated Thermal Rating: on line 4951-6785 : Rate B, Rate C , 0.0, 0.0 -> 1793
% INFO    : Updated Thermal Rating: on line 4951-6785 : Rate B, Rate C , 0.0, 0.0 -> 1627
% INFO    : Updated Thermal Rating: on line 4623-964 : Rate B, Rate C , 0.0, 0.0 -> 3346
% INFO    : Updated Thermal Rating: on line 4623-964 : Rate B, Rate C , 0.0, 0.0 -> 3251
% INFO    : Updated Thermal Rating: on line 4623-8347 : Rate B, Rate C , 0.0, 0.0 -> 5920
% INFO    : Updated Thermal Rating: on line 4623-8347 : Rate B, Rate C , 0.0, 0.0 -> 6655
% INFO    : Updated Thermal Rating: on line 4623-8347 : Rate B, Rate C , 0.0, 0.0 -> 6285
% INFO    : Updated Thermal Rating: on line 1609-6552 : Rate B, Rate C , 0.0, 0.0 -> 4907
% INFO    : Updated Thermal Rating: on line 1609-6552 : Rate B, Rate C , 0.0, 0.0 -> 4995
% INFO    : Updated Thermal Rating: on line 1609-8999 : Rate B, Rate C , 0.0, 0.0 -> 1808
% INFO    : Updated Thermal Rating: on line 4368-4816 : Rate B, Rate C , 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on line 5481-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150246
% INFO    : Updated Thermal Rating: on line 7913-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126249
% INFO    : Updated Thermal Rating: on line 506-960 : Rate B, Rate C , 0.0, 0.0 -> 101684
% INFO    : Updated Thermal Rating: on line 2980-960 : Rate B, Rate C , 0.0, 0.0 -> 78748
% INFO    : Updated Thermal Rating: on line 4554-6382 : Rate B, Rate C , 0.0, 0.0 -> 6562
% INFO    : Updated Thermal Rating: on line 4554-6382 : Rate B, Rate C , 0.0, 0.0 -> 6397
% INFO    : Updated Thermal Rating: on line 6844-1595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2606
% INFO    : Updated Thermal Rating: on line 3672-5334 : Rate B, Rate C , 0.0, 0.0 -> 10281
% INFO    : Updated Thermal Rating: on line 6219-5334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10093
% INFO    : Updated Thermal Rating: on line 8997-6153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2955
% INFO    : Updated Thermal Rating: on line 1852-5935 : Rate B, Rate C , 0.0, 0.0 -> 1359
% INFO    : Updated Thermal Rating: on line 1852-5695 : Rate B, Rate C , 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 2931-5799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1584
% INFO    : Updated Thermal Rating: on line 2931-7124 : Rate B, Rate C , 0.0, 0.0 -> 715
% INFO    : Updated Thermal Rating: on line 2598-3674 : Rate B, Rate C , 0.0, 0.0 -> 2061
% INFO    : Updated Thermal Rating: on line 2598-2132 : Rate B, Rate C , 0.0, 0.0 -> 1039
% INFO    : Updated Thermal Rating: on line 2558-7571 : Rate B, Rate C , 0.0, 0.0 -> 959
% INFO    : Updated Thermal Rating: on line 8834-1129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on line 7377-3324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4788
% INFO    : Updated Thermal Rating: on line 1265-4426 : Rate B, Rate C , 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 1265-1965 : Rate B, Rate C , 0.0, 0.0 -> 1550
% INFO    : Updated Thermal Rating: on line 8060-7162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61700
% INFO    : Updated Thermal Rating: on line 6922-5482 : Rate B, Rate C , 0.0, 0.0 -> 1673
% INFO    : Updated Thermal Rating: on line 6922-1295 : Rate B, Rate C , 0.0, 0.0 -> 21414
% INFO    : Updated Thermal Rating: on line 8369-4710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1705
% INFO    : Updated Thermal Rating: on line 8961-7133 : Rate B, Rate C , 0.0, 0.0 -> 4377
% INFO    : Updated Thermal Rating: on line 8961-6888 : Rate B, Rate C , 0.0, 0.0 -> 1384
% INFO    : Updated Thermal Rating: on line 4185-7019 : Rate B, Rate C , 0.0, 0.0 -> 64904
% INFO    : Updated Thermal Rating: on line 4185-6253 : Rate B, Rate C , 0.0, 0.0 -> 40281
% INFO    : Updated Thermal Rating: on line 7895-3391 : Rate B, Rate C , 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 7895-1448 : Rate B, Rate C , 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 7895-1448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 777
% INFO    : Updated Thermal Rating: on line 7895-115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 949
% INFO    : Updated Thermal Rating: on line 5589-4306 : Rate B, Rate C , 0.0, 0.0 -> 131160
% INFO    : Updated Thermal Rating: on line 5589-1763 : Rate B, Rate C , 0.0, 0.0 -> 150246
% INFO    : Updated Thermal Rating: on line 5589-3697 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 5589-3794 : Rate B, Rate C , 0.0, 0.0 -> 2658
% INFO    : Updated Thermal Rating: on line 5589-3613 : Rate B, Rate C , 0.0, 0.0 -> 2358
% INFO    : Updated Thermal Rating: on line 5589-1502 : Rate B, Rate C , 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on line 5589-6555 : Rate A, Rate B, Rate C , 1777.0, 0.0, 0.0 -> 546
% INFO    : Updated Thermal Rating: on line 5589-3608 : Rate A, Rate B, Rate C , 1613.0, 0.0, 0.0 -> 909
% INFO    : Updated Thermal Rating: on line 1001-4134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26320
% INFO    : Updated Thermal Rating: on line 1001-1979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33184
% INFO    : Updated Thermal Rating: on line 1001-516 : Rate B, Rate C , 0.0, 0.0 -> 48317
% INFO    : Updated Thermal Rating: on line 1001-3580 : Rate B, Rate C , 0.0, 0.0 -> 37387
% INFO    : Updated Thermal Rating: on line 1001-3809 : Rate B, Rate C , 0.0, 0.0 -> 1504
% INFO    : Updated Thermal Rating: on line 1001-5616 : Rate B, Rate C , 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 1001-5616 : Rate B, Rate C , 0.0, 0.0 -> 1496
% INFO    : Updated Thermal Rating: on line 1001-6697 : Rate B, Rate C , 0.0, 0.0 -> 1034
% INFO    : Updated Thermal Rating: on line 1001-7165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4781
% INFO    : Updated Thermal Rating: on line 1001-892 : Rate B, Rate C , 0.0, 0.0 -> 4400
% INFO    : Updated Thermal Rating: on line 7438-5334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2105
% INFO    : Updated Thermal Rating: on line 7438-1526 : Rate B, Rate C , 0.0, 0.0 -> 2539
% INFO    : Updated Thermal Rating: on line 1301-6952 : Rate B, Rate C , 0.0, 0.0 -> 854
% INFO    : Updated Thermal Rating: on line 1301-6952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 828
% INFO    : Updated Thermal Rating: on line 1301-6952 : Rate B, Rate C , 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 1301-7883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10335
% INFO    : Updated Thermal Rating: on line 1301-6430 : Rate B, Rate C , 0.0, 0.0 -> 5140
% INFO    : Updated Thermal Rating: on line 778-7209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 778-1910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4334
% INFO    : Updated Thermal Rating: on line 778-6820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8414
% INFO    : Updated Thermal Rating: on line 778-3071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 5297-6267 : Rate B, Rate C , 0.0, 0.0 -> 45626
% INFO    : Updated Thermal Rating: on line 3657-3855 : Rate B, Rate C , 0.0, 0.0 -> 41622
% INFO    : Updated Thermal Rating: on line 3657-3855 : Rate B, Rate C , 0.0, 0.0 -> 45778
% INFO    : Updated Thermal Rating: on line 3657-2928 : Rate B, Rate C , 0.0, 0.0 -> 12161
% INFO    : Updated Thermal Rating: on line 3657-2928 : Rate B, Rate C , 0.0, 0.0 -> 12717
% INFO    : Updated Thermal Rating: on line 3657-1172 : Rate B, Rate C , 0.0, 0.0 -> 13211
% INFO    : Updated Thermal Rating: on line 3657-9191 : Rate B, Rate C , 0.0, 0.0 -> 4832
% INFO    : Updated Thermal Rating: on line 3657-8722 : Rate B, Rate C , 0.0, 0.0 -> 5211
% INFO    : Updated Thermal Rating: on line 6472-5362 : Rate B, Rate C , 0.0, 0.0 -> 17339
% INFO    : Updated Thermal Rating: on line 6472-3962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13063
% INFO    : Updated Thermal Rating: on line 1198-1343 : Rate B, Rate C , 0.0, 0.0 -> 4076
% INFO    : Updated Thermal Rating: on line 1198-29 : Rate B, Rate C , 0.0, 0.0 -> 1978
% INFO    : Updated Thermal Rating: on line 7473-3680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 971
% INFO    : Updated Thermal Rating: on line 7473-96 : Rate B, Rate C , 0.0, 0.0 -> 1804
% INFO    : Updated Thermal Rating: on line 7473-1868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2508
% INFO    : Updated Thermal Rating: on line 346-3184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6510
% INFO    : Updated Thermal Rating: on line 346-6570 : Rate B, Rate C , 0.0, 0.0 -> 6187
% INFO    : Updated Thermal Rating: on line 3184-4728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2626
% INFO    : Updated Thermal Rating: on line 2654-7886 : Rate B, Rate C , 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 2654-2132 : Rate B, Rate C , 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 4144-8874 : Rate B, Rate C , 0.0, 0.0 -> 2846
% INFO    : Updated Thermal Rating: on line 4144-1625 : Rate B, Rate C , 0.0, 0.0 -> 5227
% INFO    : Updated Thermal Rating: on line 4144-1625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5276
% INFO    : Updated Thermal Rating: on line 4144-3786 : Rate B, Rate C , 0.0, 0.0 -> 2479
% INFO    : Updated Thermal Rating: on line 4144-3786 : Rate B, Rate C , 0.0, 0.0 -> 2204
% INFO    : Updated Thermal Rating: on line 3422-4100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44249
% INFO    : Updated Thermal Rating: on line 6624-4419 : Rate B, Rate C , 0.0, 0.0 -> 58406
% INFO    : Updated Thermal Rating: on line 6624-7159 : Rate B, Rate C , 0.0, 0.0 -> 57347
% INFO    : Updated Thermal Rating: on line 6624-3661 : Rate B, Rate C , 0.0, 0.0 -> 54332
% INFO    : Updated Thermal Rating: on line 6624-5486 : Rate B, Rate C , 0.0, 0.0 -> 58336
% INFO    : Updated Thermal Rating: on line 6624-4231 : Rate B, Rate C , 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 6624-4231 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 6624-6921 : Rate B, Rate C , 0.0, 0.0 -> 1794
% INFO    : Updated Thermal Rating: on line 6624-432 : Rate B, Rate C , 0.0, 0.0 -> 3336
% INFO    : Updated Thermal Rating: on line 6624-432 : Rate B, Rate C , 0.0, 0.0 -> 2840
% INFO    : Updated Thermal Rating: on line 6624-432 : Rate B, Rate C , 0.0, 0.0 -> 2788
% INFO    : Updated Thermal Rating: on line 3353-6887 : Rate B, Rate C , 0.0, 0.0 -> 5371
% INFO    : Updated Thermal Rating: on line 2479-2050 : Rate B, Rate C , 0.0, 0.0 -> 5307
% INFO    : Updated Thermal Rating: on line 2479-2050 : Rate B, Rate C , 0.0, 0.0 -> 4690
% INFO    : Updated Thermal Rating: on line 5482-8704 : Rate B, Rate C , 0.0, 0.0 -> 4888
% INFO    : Updated Thermal Rating: on line 5482-8704 : Rate B, Rate C , 0.0, 0.0 -> 4337
% INFO    : Updated Thermal Rating: on line 5482-4710 : Rate B, Rate C , 0.0, 0.0 -> 1375
% INFO    : Updated Thermal Rating: on line 5482-1295 : Rate B, Rate C , 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on line 5482-1910 : Rate B, Rate C , 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 5482-2985 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 5482-5853 : Rate B, Rate C , 0.0, 0.0 -> 12252
% INFO    : Updated Thermal Rating: on line 5482-7824 : Rate B, Rate C , 0.0, 0.0 -> 1910
% INFO    : Updated Thermal Rating: on line 5482-3071 : Rate B, Rate C , 0.0, 0.0 -> 18399
% INFO    : Updated Thermal Rating: on line 4525-195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 9066-7367 : Rate B, Rate C , 0.0, 0.0 -> 1469
% INFO    : Updated Thermal Rating: on line 9066-9155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 9066-6357 : Rate B, Rate C , 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 7886-3126 : Rate B, Rate C , 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 7886-8564 : Rate B, Rate C , 0.0, 0.0 -> 4738
% INFO    : Updated Thermal Rating: on line 7886-5567 : Rate B, Rate C , 0.0, 0.0 -> 1241
% INFO    : Updated Thermal Rating: on line 6416-3069 : Rate B, Rate C , 0.0, 0.0 -> 1534
% INFO    : Updated Thermal Rating: on line 6416-3876 : Rate B, Rate C , 0.0, 0.0 -> 9976
% INFO    : Updated Thermal Rating: on line 6416-8804 : Rate B, Rate C , 0.0, 0.0 -> 2409
% INFO    : Updated Thermal Rating: on line 6416-8804 : Rate B, Rate C , 0.0, 0.0 -> 2366
% INFO    : Updated Thermal Rating: on line 7831-4550 : Rate B, Rate C , 0.0, 0.0 -> 5610
% INFO    : Updated Thermal Rating: on line 7831-4125 : Rate B, Rate C , 0.0, 0.0 -> 1737
% INFO    : Updated Thermal Rating: on line 7831-3346 : Rate B, Rate C , 0.0, 0.0 -> 1098
% INFO    : Updated Thermal Rating: on line 5525-2377 : Rate B, Rate C , 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 5525-1401 : Rate B, Rate C , 0.0, 0.0 -> 1220
% INFO    : Updated Thermal Rating: on line 5525-2850 : Rate B, Rate C , 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on line 5525-2430 : Rate B, Rate C , 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on line 5525-9164 : Rate B, Rate C , 0.0, 0.0 -> 599
% INFO    : Updated Thermal Rating: on line 8511-1033 : Rate B, Rate C , 0.0, 0.0 -> 25264
% INFO    : Updated Thermal Rating: on line 8511-6178 : Rate B, Rate C , 0.0, 0.0 -> 29393
% INFO    : Updated Thermal Rating: on line 3400-980 : Rate B, Rate C , 0.0, 0.0 -> 24306
% INFO    : Updated Thermal Rating: on line 2101-4598 : Rate B, Rate C , 0.0, 0.0 -> 2637
% INFO    : Updated Thermal Rating: on line 2101-4541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2663
% INFO    : Updated Thermal Rating: on line 2101-5144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7392
% INFO    : Updated Thermal Rating: on line 3919-2129 : Rate B, Rate C , 0.0, 0.0 -> 2695
% INFO    : Updated Thermal Rating: on line 3919-4541 : Rate B, Rate C , 0.0, 0.0 -> 3010
% INFO    : Updated Thermal Rating: on line 3919-3513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7549
% INFO    : Updated Thermal Rating: on line 6675-1486 : Rate B, Rate C , 0.0, 0.0 -> 44610
% INFO    : Updated Thermal Rating: on line 4711-5836 : Rate B, Rate C , 0.0, 0.0 -> 6392
% INFO    : Updated Thermal Rating: on line 4711-575 : Rate B, Rate C , 0.0, 0.0 -> 6111
% INFO    : Updated Thermal Rating: on line 4711-8214 : Rate B, Rate C , 0.0, 0.0 -> 8784
% INFO    : Updated Thermal Rating: on line 4711-8214 : Rate B, Rate C , 0.0, 0.0 -> 8261
% INFO    : Updated Thermal Rating: on line 4711-3021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25671
% INFO    : Updated Thermal Rating: on line 4711-7967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25386
% INFO    : Updated Thermal Rating: on line 4711-5993 : Rate B, Rate C , 0.0, 0.0 -> 3668
% INFO    : Updated Thermal Rating: on line 4711-8804 : Rate B, Rate C , 0.0, 0.0 -> 1588
% INFO    : Updated Thermal Rating: on line 4513-6831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26216
% INFO    : Updated Thermal Rating: on line 2043-1422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48510
% INFO    : Updated Thermal Rating: on line 6714-1808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7088
% INFO    : Updated Thermal Rating: on line 6371-1808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7213
% INFO    : Updated Thermal Rating: on line 513-2866 : Rate B, Rate C , 0.0, 0.0 -> 3766
% INFO    : Updated Thermal Rating: on line 4970-9222 : Rate B, Rate C , 0.0, 0.0 -> 900
% INFO    : Updated Thermal Rating: on line 4970-9222 : Rate B, Rate C , 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 4970-2072 : Rate B, Rate C , 0.0, 0.0 -> 5202
% INFO    : Updated Thermal Rating: on line 4970-5461 : Rate B, Rate C , 0.0, 0.0 -> 11447
% INFO    : Updated Thermal Rating: on line 4970-8109 : Rate B, Rate C , 0.0, 0.0 -> 2341
% INFO    : Updated Thermal Rating: on line 4970-8109 : Rate B, Rate C , 0.0, 0.0 -> 2030
% INFO    : Updated Thermal Rating: on line 7955-707 : Rate B, Rate C , 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 7955-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3937
% INFO    : Updated Thermal Rating: on line 7955-1866 : Rate B, Rate C , 0.0, 0.0 -> 1090
% INFO    : Updated Thermal Rating: on line 7955-5488 : Rate A, Rate B, Rate C , 591.0, 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 5093-2467 : Rate B, Rate C , 0.0, 0.0 -> 1540
% INFO    : Updated Thermal Rating: on line 2328-7178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6241
% INFO    : Updated Thermal Rating: on line 9180-195 : Rate B, Rate C , 0.0, 0.0 -> 2352
% INFO    : Updated Thermal Rating: on line 9180-3133 : Rate B, Rate C , 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on line 292-4544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3334
% INFO    : Updated Thermal Rating: on line 9002-6737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20291
% INFO    : Updated Thermal Rating: on line 8439-3758 : Rate B, Rate C , 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 8439-3758 : Rate B, Rate C , 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 4974-2940 : Rate B, Rate C , 0.0, 0.0 -> 1572
% INFO    : Updated Thermal Rating: on line 4974-163 : Rate B, Rate C , 0.0, 0.0 -> 992
% INFO    : Updated Thermal Rating: on line 747-8507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26055
% INFO    : Updated Thermal Rating: on line 6909-4914 : Rate B, Rate C , 0.0, 0.0 -> 14377
% INFO    : Updated Thermal Rating: on line 444-4747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7334
% INFO    : Updated Thermal Rating: on line 1459-6495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3289
% INFO    : Updated Thermal Rating: on line 1459-2751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1971
% INFO    : Updated Thermal Rating: on line 3601-4728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9924
% INFO    : Updated Thermal Rating: on line 1251-6475 : Rate B, Rate C , 0.0, 0.0 -> 76837
% INFO    : Updated Thermal Rating: on line 1093-6475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73380
% INFO    : Updated Thermal Rating: on line 5709-6475 : Rate B, Rate C , 0.0, 0.0 -> 80755
% INFO    : Updated Thermal Rating: on line 3825-6475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82867
% INFO    : Updated Thermal Rating: on line 1415-3503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7473
% INFO    : Updated Thermal Rating: on line 4549-3503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8069
% INFO    : Updated Thermal Rating: on line 3072-639 : Rate B, Rate C , 0.0, 0.0 -> 7210
% INFO    : Updated Thermal Rating: on line 3072-639 : Rate B, Rate C , 0.0, 0.0 -> 7718
% INFO    : Updated Thermal Rating: on line 5007-4541 : Rate A, Rate B, Rate C , 1152.0, 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on line 5007-8195 : Rate B, Rate C , 0.0, 0.0 -> 1873
% INFO    : Updated Thermal Rating: on line 757-964 : Rate B, Rate C , 0.0, 0.0 -> 3905
% INFO    : Updated Thermal Rating: on line 757-964 : Rate B, Rate C , 0.0, 0.0 -> 3830
% INFO    : Updated Thermal Rating: on line 757-3906 : Rate B, Rate C , 0.0, 0.0 -> 2741
% INFO    : Updated Thermal Rating: on line 757-3906 : Rate B, Rate C , 0.0, 0.0 -> 2425
% INFO    : Updated Thermal Rating: on line 757-8347 : Rate B, Rate C , 0.0, 0.0 -> 1984
% INFO    : Updated Thermal Rating: on line 757-2919 : Rate A, Rate B, Rate C , 1481.0, 0.0, 0.0 -> 1133
% INFO    : Updated Thermal Rating: on line 3758-188 : Rate B, Rate C , 0.0, 0.0 -> 1091
% INFO    : Updated Thermal Rating: on line 3758-2242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 919
% INFO    : Updated Thermal Rating: on line 3903-4114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 5743-6990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 8626-8930 : Rate B, Rate C , 0.0, 0.0 -> 954
% INFO    : Updated Thermal Rating: on line 8626-2467 : Rate B, Rate C , 0.0, 0.0 -> 938
% INFO    : Updated Thermal Rating: on line 2161-5488 : Rate B, Rate C , 0.0, 0.0 -> 846
% INFO    : Updated Thermal Rating: on line 2161-7772 : Rate B, Rate C , 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 5003-6382 : Rate B, Rate C , 0.0, 0.0 -> 13719
% INFO    : Updated Thermal Rating: on line 6474-4084 : Rate B, Rate C , 0.0, 0.0 -> 2878
% INFO    : Updated Thermal Rating: on line 6474-4084 : Rate B, Rate C , 0.0, 0.0 -> 2504
% INFO    : Updated Thermal Rating: on line 6474-53 : Rate B, Rate C , 0.0, 0.0 -> 2198
% INFO    : Updated Thermal Rating: on line 6474-7259 : Rate B, Rate C , 0.0, 0.0 -> 19023
% INFO    : Updated Thermal Rating: on line 6474-2475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18424
% INFO    : Updated Thermal Rating: on line 5334-7577 : Rate B, Rate C , 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 7961-2288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20686
% INFO    : Updated Thermal Rating: on line 1592-7098 : Rate B, Rate C , 0.0, 0.0 -> 5012
% INFO    : Updated Thermal Rating: on line 3187-2079 : Rate B, Rate C , 0.0, 0.0 -> 1997
% INFO    : Updated Thermal Rating: on line 6041-5926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4243
% INFO    : Updated Thermal Rating: on line 3697-8486 : Rate B, Rate C , 0.0, 0.0 -> 3034
% INFO    : Updated Thermal Rating: on line 3697-7530 : Rate B, Rate C , 0.0, 0.0 -> 3094
% INFO    : Updated Thermal Rating: on line 3697-1502 : Rate B, Rate C , 0.0, 0.0 -> 2198
% INFO    : Updated Thermal Rating: on line 3697-1552 : Rate A, Rate B, Rate C , 1678.0, 0.0, 0.0 -> 1555
% INFO    : Updated Thermal Rating: on line 6952-3793 : Rate B, Rate C , 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 6738-2526 : Rate B, Rate C , 0.0, 0.0 -> 2537
% INFO    : Updated Thermal Rating: on line 6738-2526 : Rate B, Rate C , 0.0, 0.0 -> 2252
% INFO    : Updated Thermal Rating: on line 6738-2365 : Rate B, Rate C , 0.0, 0.0 -> 3731
% INFO    : Updated Thermal Rating: on line 6738-2365 : Rate B, Rate C , 0.0, 0.0 -> 3662
% INFO    : Updated Thermal Rating: on line 6738-3794 : Rate B, Rate C , 0.0, 0.0 -> 2974
% INFO    : Updated Thermal Rating: on line 6738-3613 : Rate B, Rate C , 0.0, 0.0 -> 2807
% INFO    : Updated Thermal Rating: on line 6738-6901 : Rate A, Rate B, Rate C , 1777.0, 0.0, 0.0 -> 1218
% INFO    : Updated Thermal Rating: on line 8180-5106 : Rate B, Rate C , 0.0, 0.0 -> 3996
% INFO    : Updated Thermal Rating: on line 8180-5106 : Rate B, Rate C , 0.0, 0.0 -> 3866
% INFO    : Updated Thermal Rating: on line 6240-7165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 9222-8721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95544
% INFO    : Updated Thermal Rating: on line 9222-8872 : Rate B, Rate C , 0.0, 0.0 -> 108858
% INFO    : Updated Thermal Rating: on line 9222-8672 : Rate B, Rate C , 0.0, 0.0 -> 3531
% INFO    : Updated Thermal Rating: on line 9222-7164 : Rate B, Rate C , 0.0, 0.0 -> 2062
% INFO    : Updated Thermal Rating: on line 5935-7772 : Rate B, Rate C , 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 3134-3430 : Rate B, Rate C , 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on line 3134-1051 : Rate B, Rate C , 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 283-800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21921
% INFO    : Updated Thermal Rating: on line 283-1077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20446
% INFO    : Updated Thermal Rating: on line 283-4747 : Rate B, Rate C , 0.0, 0.0 -> 6998
% INFO    : Updated Thermal Rating: on line 3391-5213 : Rate B, Rate C , 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on line 3391-115 : Rate B, Rate C , 0.0, 0.0 -> 3736
% INFO    : Updated Thermal Rating: on line 3391-115 : Rate B, Rate C , 0.0, 0.0 -> 3241
% INFO    : Updated Thermal Rating: on line 4867-5753 : Rate B, Rate C , 0.0, 0.0 -> 5101
% INFO    : Updated Thermal Rating: on line 7539-6556 : Rate B, Rate C , 0.0, 0.0 -> 2477
% INFO    : Updated Thermal Rating: on line 7539-871 : Rate B, Rate C , 0.0, 0.0 -> 3278
% INFO    : Updated Thermal Rating: on line 8893-8874 : Rate B, Rate C , 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 8893-4505 : Rate B, Rate C , 0.0, 0.0 -> 3592
% INFO    : Updated Thermal Rating: on line 8893-3436 : Rate B, Rate C , 0.0, 0.0 -> 2054
% INFO    : Updated Thermal Rating: on line 8893-3436 : Rate B, Rate C , 0.0, 0.0 -> 2016
% INFO    : Updated Thermal Rating: on line 8893-3436 : Rate B, Rate C , 0.0, 0.0 -> 1910
% INFO    : Updated Thermal Rating: on line 8893-6556 : Rate B, Rate C , 0.0, 0.0 -> 1599
% INFO    : Updated Thermal Rating: on line 8893-8765 : Rate B, Rate C , 0.0, 0.0 -> 13522
% INFO    : Updated Thermal Rating: on line 8893-6619 : Rate B, Rate C , 0.0, 0.0 -> 11682
% INFO    : Updated Thermal Rating: on line 8165-6734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53974
% INFO    : Updated Thermal Rating: on line 1078-6734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84816
% INFO    : Updated Thermal Rating: on line 7988-4231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9642
% INFO    : Updated Thermal Rating: on line 804-2142 : Rate B, Rate C , 0.0, 0.0 -> 5557
% INFO    : Updated Thermal Rating: on line 804-2142 : Rate B, Rate C , 0.0, 0.0 -> 5672
% INFO    : Updated Thermal Rating: on line 804-7519 : Rate B, Rate C , 0.0, 0.0 -> 1593
% INFO    : Updated Thermal Rating: on line 804-6744 : Rate B, Rate C , 0.0, 0.0 -> 1628
% INFO    : Updated Thermal Rating: on line 2286-6802 : Rate B, Rate C , 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on line 2286-769 : Rate B, Rate C , 0.0, 0.0 -> 1193
% INFO    : Updated Thermal Rating: on line 3239-1081 : Rate B, Rate C , 0.0, 0.0 -> 1501
% INFO    : Updated Thermal Rating: on line 3239-5983 : Rate B, Rate C , 0.0, 0.0 -> 1467
% INFO    : Updated Thermal Rating: on line 3239-8267 : Rate A, Rate B, Rate C , 1053.0, 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on line 3239-960 : Rate B, Rate C , 0.0, 0.0 -> 2314
% INFO    : Updated Thermal Rating: on line 3239-960 : Rate B, Rate C , 0.0, 0.0 -> 2061
% INFO    : Updated Thermal Rating: on line 3239-3906 : Rate A, Rate B, Rate C , 1481.0, 0.0, 0.0 -> 1040
% INFO    : Updated Thermal Rating: on line 1539-7361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on line 1539-6852 : Rate B, Rate C , 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 1539-8515 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 1539-3166 : Rate B, Rate C , 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 1539-2676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on line 1539-3793 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 1539-4529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 937
% INFO    : Updated Thermal Rating: on line 1539-4234 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 8628-44 : Rate B, Rate C , 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 8628-6630 : Rate B, Rate C , 0.0, 0.0 -> 3902
% INFO    : Updated Thermal Rating: on line 8628-6630 : Rate B, Rate C , 0.0, 0.0 -> 3982
% INFO    : Updated Thermal Rating: on line 8628-1545 : Rate B, Rate C , 0.0, 0.0 -> 10610
% INFO    : Updated Thermal Rating: on line 8628-4215 : Rate B, Rate C , 0.0, 0.0 -> 9305
% INFO    : Updated Thermal Rating: on line 7163-1917 : Rate B, Rate C , 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 7163-5519 : Rate B, Rate C , 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on line 7647-225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25736
% INFO    : Updated Thermal Rating: on line 4864-1397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64786
% INFO    : Updated Thermal Rating: on line 7021-7119 : Rate B, Rate C , 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 7021-3324 : Rate B, Rate C , 0.0, 0.0 -> 2757
% INFO    : Updated Thermal Rating: on line 1248-163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2413
% INFO    : Updated Thermal Rating: on line 9045-2457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78436
% INFO    : Updated Thermal Rating: on line 8874-3786 : Rate B, Rate C , 0.0, 0.0 -> 1991
% INFO    : Updated Thermal Rating: on line 5891-5574 : Rate B, Rate C , 0.0, 0.0 -> 2510
% INFO    : Updated Thermal Rating: on line 5891-7663 : Rate B, Rate C , 0.0, 0.0 -> 1341
% INFO    : Updated Thermal Rating: on line 5891-4889 : Rate B, Rate C , 0.0, 0.0 -> 5190
% INFO    : Updated Thermal Rating: on line 3997-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35710
% INFO    : Updated Thermal Rating: on line 184-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38599
% INFO    : Updated Thermal Rating: on line 2972-2088 : Rate B, Rate C , 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 8676-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 8676-933 : Rate B, Rate C , 0.0, 0.0 -> 4562
% INFO    : Updated Thermal Rating: on line 8676-3643 : Rate B, Rate C , 0.0, 0.0 -> 979
% INFO    : Updated Thermal Rating: on line 8704-6723 : Rate B, Rate C , 0.0, 0.0 -> 2411
% INFO    : Updated Thermal Rating: on line 7047-21 : Rate B, Rate C , 0.0, 0.0 -> 31376
% INFO    : Updated Thermal Rating: on line 7047-21 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21862
% INFO    : Updated Thermal Rating: on line 7047-1551 : Rate B, Rate C , 0.0, 0.0 -> 1996
% INFO    : Updated Thermal Rating: on line 7047-4103 : Rate B, Rate C , 0.0, 0.0 -> 10244
% INFO    : Updated Thermal Rating: on line 7047-7862 : Rate B, Rate C , 0.0, 0.0 -> 3768
% INFO    : Updated Thermal Rating: on line 7047-5458 : Rate B, Rate C , 0.0, 0.0 -> 3966
% INFO    : Updated Thermal Rating: on line 5574-5666 : Rate B, Rate C , 0.0, 0.0 -> 2016
% INFO    : Updated Thermal Rating: on line 6742-5458 : Rate B, Rate C , 0.0, 0.0 -> 24252
% INFO    : Updated Thermal Rating: on line 5270-7862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24653
% INFO    : Updated Thermal Rating: on line 7775-3857 : Rate B, Rate C , 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 6290-3436 : Rate B, Rate C , 0.0, 0.0 -> 3696
% INFO    : Updated Thermal Rating: on line 3430-401 : Rate B, Rate C , 0.0, 0.0 -> 978
% INFO    : Updated Thermal Rating: on line 2967-8976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20925
% INFO    : Updated Thermal Rating: on line 2967-8976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20403
% INFO    : Updated Thermal Rating: on line 8976-2481 : Rate B, Rate C , 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 8976-9108 : Rate B, Rate C , 0.0, 0.0 -> 2458
% INFO    : Updated Thermal Rating: on line 2056-7520 : Rate B, Rate C , 0.0, 0.0 -> 6825
% INFO    : Updated Thermal Rating: on line 2056-7520 : Rate B, Rate C , 0.0, 0.0 -> 6697
% INFO    : Updated Thermal Rating: on line 4084-5340 : Rate B, Rate C , 0.0, 0.0 -> 2230
% INFO    : Updated Thermal Rating: on line 4084-2319 : Rate B, Rate C , 0.0, 0.0 -> 3526
% INFO    : Updated Thermal Rating: on line 4084-2878 : Rate B, Rate C , 0.0, 0.0 -> 1136
% INFO    : Updated Thermal Rating: on line 2597-7422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3993
% INFO    : Updated Thermal Rating: on line 7183-8931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10070
% INFO    : Updated Thermal Rating: on line 5379-8931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9884
% INFO    : Updated Thermal Rating: on line 8128-8931 : Rate B, Rate C , 0.0, 0.0 -> 7250
% INFO    : Updated Thermal Rating: on line 6337-8931 : Rate B, Rate C , 0.0, 0.0 -> 7402
% INFO    : Updated Thermal Rating: on line 1237-8931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10049
% INFO    : Updated Thermal Rating: on line 4127-9173 : Rate B, Rate C , 0.0, 0.0 -> 40572
% INFO    : Updated Thermal Rating: on line 4127-7974 : Rate B, Rate C , 0.0, 0.0 -> 23949
% INFO    : Updated Thermal Rating: on line 2432-4816 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 2432-1866 : Rate B, Rate C , 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 2432-8809 : Rate B, Rate C , 0.0, 0.0 -> 7955
% INFO    : Updated Thermal Rating: on line 2432-5146 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 2432-6940 : Rate B, Rate C , 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 2432-1742 : Rate B, Rate C , 0.0, 0.0 -> 7075
% INFO    : Updated Thermal Rating: on line 5213-8627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 703
% INFO    : Updated Thermal Rating: on line 5213-174 : Rate B, Rate C , 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 5213-7437 : Rate B, Rate C , 0.0, 0.0 -> 758
% INFO    : Updated Thermal Rating: on line 7342-5940 : Rate B, Rate C , 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 7342-7495 : Rate B, Rate C , 0.0, 0.0 -> 900
% INFO    : Updated Thermal Rating: on line 8808-4816 : Rate B, Rate C , 0.0, 0.0 -> 1450
% INFO    : Updated Thermal Rating: on line 8808-4816 : Rate B, Rate C , 0.0, 0.0 -> 1420
% INFO    : Updated Thermal Rating: on line 8808-6053 : Rate B, Rate C , 0.0, 0.0 -> 1834
% INFO    : Updated Thermal Rating: on line 5764-4189 : Rate B, Rate C , 0.0, 0.0 -> 1559
% INFO    : Updated Thermal Rating: on line 8507-1973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33783
% INFO    : Updated Thermal Rating: on line 1394-1973 : Rate B, Rate C , 0.0, 0.0 -> 33061
% INFO    : Updated Thermal Rating: on line 2898-2128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96873
% INFO    : Updated Thermal Rating: on line 4942-8255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on line 4942-4748 : Rate B, Rate C , 0.0, 0.0 -> 5098
% INFO    : Updated Thermal Rating: on line 3486-3594 : Rate B, Rate C , 0.0, 0.0 -> 1482
% INFO    : Updated Thermal Rating: on line 3486-4679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 4656-4235 : Rate B, Rate C , 0.0, 0.0 -> 1552
% INFO    : Updated Thermal Rating: on line 4656-4235 : Rate B, Rate C , 0.0, 0.0 -> 1584
% INFO    : Updated Thermal Rating: on line 7129-5441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13000
% INFO    : Updated Thermal Rating: on line 7129-5441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12810
% INFO    : Updated Thermal Rating: on line 8250-5720 : Rate B, Rate C , 0.0, 0.0 -> 1587
% INFO    : Updated Thermal Rating: on line 8250-5720 : Rate B, Rate C , 0.0, 0.0 -> 1558
% INFO    : Updated Thermal Rating: on line 6831-6723 : Rate B, Rate C , 0.0, 0.0 -> 11064
% INFO    : Updated Thermal Rating: on line 6831-5686 : Rate B, Rate C , 0.0, 0.0 -> 2437
% INFO    : Updated Thermal Rating: on line 2377-805 : Rate A, Rate B, Rate C , 438.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 907-9091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78402
% INFO    : Updated Thermal Rating: on line 4056-9091 : Rate B, Rate C , 0.0, 0.0 -> 71132
% INFO    : Updated Thermal Rating: on line 6837-2142 : Rate B, Rate C , 0.0, 0.0 -> 62725
% INFO    : Updated Thermal Rating: on line 5666-2641 : Rate B, Rate C , 0.0, 0.0 -> 4421
% INFO    : Updated Thermal Rating: on line 5666-7577 : Rate B, Rate C , 0.0, 0.0 -> 9851
% INFO    : Updated Thermal Rating: on line 5666-7577 : Rate B, Rate C , 0.0, 0.0 -> 9225
% INFO    : Updated Thermal Rating: on line 5666-7577 : Rate B, Rate C , 0.0, 0.0 -> 6466
% INFO    : Updated Thermal Rating: on line 5666-1629 : Rate B, Rate C , 0.0, 0.0 -> 2052
% INFO    : Updated Thermal Rating: on line 726-687 : Rate B, Rate C , 0.0, 0.0 -> 7239
% INFO    : Updated Thermal Rating: on line 3526-687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8564
% INFO    : Updated Thermal Rating: on line 6382-2425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4444
% INFO    : Updated Thermal Rating: on line 6382-2425 : Rate B, Rate C , 0.0, 0.0 -> 4533
% INFO    : Updated Thermal Rating: on line 6382-5907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1442
% INFO    : Updated Thermal Rating: on line 6382-5907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1617
% INFO    : Updated Thermal Rating: on line 6382-5907 : Rate B, Rate C , 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 7847-9217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1471
% INFO    : Updated Thermal Rating: on line 2981-1448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1597
% INFO    : Updated Thermal Rating: on line 5110-5686 : Rate B, Rate C , 0.0, 0.0 -> 3769
% INFO    : Updated Thermal Rating: on line 2968-5907 : Rate B, Rate C , 0.0, 0.0 -> 3813
% INFO    : Updated Thermal Rating: on line 5441-2155 : Rate B, Rate C , 0.0, 0.0 -> 2042
% INFO    : Updated Thermal Rating: on line 5441-8112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1956
% INFO    : Updated Thermal Rating: on line 5441-2535 : Rate B, Rate C , 0.0, 0.0 -> 11184
% INFO    : Updated Thermal Rating: on line 5441-7098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2530
% INFO    : Updated Thermal Rating: on line 5441-7098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2683
% INFO    : Updated Thermal Rating: on line 5441-7098 : Rate B, Rate C , 0.0, 0.0 -> 2899
% INFO    : Updated Thermal Rating: on line 5441-3737 : Rate B, Rate C , 0.0, 0.0 -> 5922
% INFO    : Updated Thermal Rating: on line 5441-5529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5818
% INFO    : Updated Thermal Rating: on line 5441-5753 : Rate B, Rate C , 0.0, 0.0 -> 2664
% INFO    : Updated Thermal Rating: on line 9019-6563 : Rate B, Rate C , 0.0, 0.0 -> 52008
% INFO    : Updated Thermal Rating: on line 1341-1101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1090
% INFO    : Updated Thermal Rating: on line 2797-8291 : Rate B, Rate C , 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 2797-8367 : Rate B, Rate C , 0.0, 0.0 -> 1628
% INFO    : Updated Thermal Rating: on line 2797-1100 : Rate B, Rate C , 0.0, 0.0 -> 7022
% INFO    : Updated Thermal Rating: on line 2797-6887 : Rate B, Rate C , 0.0, 0.0 -> 2694
% INFO    : Updated Thermal Rating: on line 4939-6880 : Rate B, Rate C , 0.0, 0.0 -> 9486
% INFO    : Updated Thermal Rating: on line 7738-6982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 6565-3121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 8707-280 : Rate B, Rate C , 0.0, 0.0 -> 3515
% INFO    : Updated Thermal Rating: on line 8707-2510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 1625-766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20318
% INFO    : Updated Thermal Rating: on line 8411-6232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54993
% INFO    : Updated Thermal Rating: on line 3951-1397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2258
% INFO    : Updated Thermal Rating: on line 964-7282 : Rate B, Rate C , 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on line 964-7282 : Rate B, Rate C , 0.0, 0.0 -> 2152
% INFO    : Updated Thermal Rating: on line 964-6475 : Rate B, Rate C , 0.0, 0.0 -> 3837
% INFO    : Updated Thermal Rating: on line 964-6475 : Rate B, Rate C , 0.0, 0.0 -> 3917
% INFO    : Updated Thermal Rating: on line 5658-5420 : Rate B, Rate C , 0.0, 0.0 -> 2472
% INFO    : Updated Thermal Rating: on line 5658-8267 : Rate A, Rate B, Rate C , 1744.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 5658-7328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on line 5658-7328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1445
% INFO    : Updated Thermal Rating: on line 5658-7164 : Rate B, Rate C , 0.0, 0.0 -> 1524
% INFO    : Updated Thermal Rating: on line 5550-410 : Rate B, Rate C , 0.0, 0.0 -> 2976
% INFO    : Updated Thermal Rating: on line 5550-7579 : Rate B, Rate C , 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 5550-7579 : Rate B, Rate C , 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 5550-4189 : Rate B, Rate C , 0.0, 0.0 -> 629
% INFO    : Updated Thermal Rating: on line 7282-4196 : Rate B, Rate C , 0.0, 0.0 -> 2639
% INFO    : Updated Thermal Rating: on line 1526-3916 : Rate B, Rate C , 0.0, 0.0 -> 621
% INFO    : Updated Thermal Rating: on line 1526-4747 : Rate B, Rate C , 0.0, 0.0 -> 2505
% INFO    : Updated Thermal Rating: on line 1526-4747 : Rate B, Rate C , 0.0, 0.0 -> 2051
% INFO    : Updated Thermal Rating: on line 4541-3346 : Rate A, Rate B, Rate C , 1514.0, 0.0, 0.0 -> 959
% INFO    : Updated Thermal Rating: on line 4541-3346 : Rate A, Rate B, Rate C , 1020.0, 0.0, 0.0 -> 789
% INFO    : Updated Thermal Rating: on line 1343-3346 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 3680-2719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44610
% INFO    : Updated Thermal Rating: on line 3680-2719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31417
% INFO    : Updated Thermal Rating: on line 3680-2719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36971
% INFO    : Updated Thermal Rating: on line 3680-795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41087
% INFO    : Updated Thermal Rating: on line 3680-4880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1761
% INFO    : Updated Thermal Rating: on line 3680-1868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1518
% INFO    : Updated Thermal Rating: on line 7464-5564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47512
% INFO    : Updated Thermal Rating: on line 7464-7036 : Rate B, Rate C , 0.0, 0.0 -> 40125
% INFO    : Updated Thermal Rating: on line 7464-5940 : Rate B, Rate C , 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 7464-7495 : Rate B, Rate C , 0.0, 0.0 -> 969
% INFO    : Updated Thermal Rating: on line 4850-2886 : Rate B, Rate C , 0.0, 0.0 -> 2683
% INFO    : Updated Thermal Rating: on line 4850-7049 : Rate B, Rate C , 0.0, 0.0 -> 1660
% INFO    : Updated Thermal Rating: on line 2510-6146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11156
% INFO    : Updated Thermal Rating: on line 90-1860 : Rate B, Rate C , 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on line 90-1860 : Rate B, Rate C , 0.0, 0.0 -> 1500
% INFO    : Updated Thermal Rating: on line 2142-3276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20489
% INFO    : Updated Thermal Rating: on line 2142-3545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2774
% INFO    : Updated Thermal Rating: on line 2142-6842 : Rate B, Rate C , 0.0, 0.0 -> 1734
% INFO    : Updated Thermal Rating: on line 2142-6744 : Rate B, Rate C , 0.0, 0.0 -> 1023
% INFO    : Updated Thermal Rating: on line 2142-7635 : Rate B, Rate C , 0.0, 0.0 -> 24993
% INFO    : Updated Thermal Rating: on line 9091-1040 : Rate B, Rate C , 0.0, 0.0 -> 1752
% INFO    : Updated Thermal Rating: on line 2457-6178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79847
% INFO    : Updated Thermal Rating: on line 1422-1462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5876
% INFO    : Updated Thermal Rating: on line 1422-7772 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 7881-5365 : Rate B, Rate C , 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 7881-6982 : Rate B, Rate C , 0.0, 0.0 -> 468
% INFO    : Updated Thermal Rating: on line 6926-3327 : Rate B, Rate C , 0.0, 0.0 -> 7240
% INFO    : Updated Thermal Rating: on line 1959-615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4685
% INFO    : Updated Thermal Rating: on line 6455-1262 : Rate B, Rate C , 0.0, 0.0 -> 14149
% INFO    : Updated Thermal Rating: on line 803-6982 : Rate B, Rate C , 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 803-5918 : Rate B, Rate C , 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 7624-3070 : Rate B, Rate C , 0.0, 0.0 -> 1926
% INFO    : Updated Thermal Rating: on line 500-1547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5703
% INFO    : Updated Thermal Rating: on line 500-5237 : Rate B, Rate C , 0.0, 0.0 -> 826
% INFO    : Updated Thermal Rating: on line 500-772 : Rate B, Rate C , 0.0, 0.0 -> 1815
% INFO    : Updated Thermal Rating: on line 500-8950 : Rate B, Rate C , 0.0, 0.0 -> 2298
% INFO    : Updated Thermal Rating: on line 2754-2079 : Rate B, Rate C , 0.0, 0.0 -> 2097
% INFO    : Updated Thermal Rating: on line 2754-2229 : Rate B, Rate C , 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on line 2754-7049 : Rate B, Rate C , 0.0, 0.0 -> 3071
% INFO    : Updated Thermal Rating: on line 4118-7873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 772
% INFO    : Updated Thermal Rating: on line 4118-3865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5072
% INFO    : Updated Thermal Rating: on line 1754-8486 : Rate B, Rate C , 0.0, 0.0 -> 1631
% INFO    : Updated Thermal Rating: on line 1754-7530 : Rate B, Rate C , 0.0, 0.0 -> 1601
% INFO    : Updated Thermal Rating: on line 1754-7778 : Rate B, Rate C , 0.0, 0.0 -> 2200
% INFO    : Updated Thermal Rating: on line 1754-6897 : Rate B, Rate C , 0.0, 0.0 -> 2158
% INFO    : Updated Thermal Rating: on line 1754-960 : Rate B, Rate C , 0.0, 0.0 -> 1567
% INFO    : Updated Thermal Rating: on line 1754-960 : Rate B, Rate C , 0.0, 0.0 -> 1537
% INFO    : Updated Thermal Rating: on line 3857-4491 : Rate B, Rate C , 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 3857-6010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6340
% INFO    : Updated Thermal Rating: on line 3857-6940 : Rate B, Rate C , 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on line 858-1642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20980
% INFO    : Updated Thermal Rating: on line 3028-809 : Rate B, Rate C , 0.0, 0.0 -> 21405
% INFO    : Updated Thermal Rating: on line 4819-1642 : Rate B, Rate C , 0.0, 0.0 -> 18328
% INFO    : Updated Thermal Rating: on line 2035-809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18979
% INFO    : Updated Thermal Rating: on line 3869-1642 : Rate B, Rate C , 0.0, 0.0 -> 18755
% INFO    : Updated Thermal Rating: on line 3741-809 : Rate B, Rate C , 0.0, 0.0 -> 18321
% INFO    : Updated Thermal Rating: on line 742-687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5499
% INFO    : Updated Thermal Rating: on line 2910-7098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6113
% INFO    : Updated Thermal Rating: on line 5688-6231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4761
% INFO    : Updated Thermal Rating: on line 5182-5455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10736
% INFO    : Updated Thermal Rating: on line 707-5695 : Rate B, Rate C , 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 3814-954 : Rate B, Rate C , 0.0, 0.0 -> 4656
% INFO    : Updated Thermal Rating: on line 2313-2438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4692
% INFO    : Updated Thermal Rating: on line 195-2985 : Rate B, Rate C , 0.0, 0.0 -> 2259
% INFO    : Updated Thermal Rating: on line 2518-3513 : Rate A, Rate B, Rate C , 1613.0, 0.0, 0.0 -> 1177
% INFO    : Updated Thermal Rating: on line 2518-3346 : Rate B, Rate C , 0.0, 0.0 -> 1641
% INFO    : Updated Thermal Rating: on line 4544-601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 708
% INFO    : Updated Thermal Rating: on line 4544-3241 : Rate B, Rate C , 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 4544-7338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3724
% INFO    : Updated Thermal Rating: on line 3069-1538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16227
% INFO    : Updated Thermal Rating: on line 3069-1538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16547
% INFO    : Updated Thermal Rating: on line 6115-4729 : Rate B, Rate C , 0.0, 0.0 -> 2043
% INFO    : Updated Thermal Rating: on line 3344-6616 : Rate B, Rate C , 0.0, 0.0 -> 1921
% INFO    : Updated Thermal Rating: on line 3809-5616 : Rate B, Rate C , 0.0, 0.0 -> 2898
% INFO    : Updated Thermal Rating: on line 3809-6691 : Rate B, Rate C , 0.0, 0.0 -> 3753
% INFO    : Updated Thermal Rating: on line 3809-6691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3514
% INFO    : Updated Thermal Rating: on line 1326-892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2196
% INFO    : Updated Thermal Rating: on line 601-616 : Rate B, Rate C , 0.0, 0.0 -> 1690
% INFO    : Updated Thermal Rating: on line 3496-1551 : Rate B, Rate C , 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 4925-2230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8460
% INFO    : Updated Thermal Rating: on line 8057-5907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6577
% INFO    : Updated Thermal Rating: on line 5354-5907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6466
% INFO    : Updated Thermal Rating: on line 3674-616 : Rate B, Rate C , 0.0, 0.0 -> 2023
% INFO    : Updated Thermal Rating: on line 3674-7338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2076
% INFO    : Updated Thermal Rating: on line 5836-5083 : Rate B, Rate C , 0.0, 0.0 -> 7834
% INFO    : Updated Thermal Rating: on line 5836-7576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11334
% INFO    : Updated Thermal Rating: on line 5836-3191 : Rate B, Rate C , 0.0, 0.0 -> 10177
% INFO    : Updated Thermal Rating: on line 5836-3488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2635
% INFO    : Updated Thermal Rating: on line 5836-1578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2919
% INFO    : Updated Thermal Rating: on line 575-5300 : Rate B, Rate C , 0.0, 0.0 -> 8927
% INFO    : Updated Thermal Rating: on line 3929-9173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41796
% INFO    : Updated Thermal Rating: on line 2089-3818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39156
% INFO    : Updated Thermal Rating: on line 2089-6232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57521
% INFO    : Updated Thermal Rating: on line 2089-1643 : Rate B, Rate C , 0.0, 0.0 -> 23719
% INFO    : Updated Thermal Rating: on line 2089-6253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106228
% INFO    : Updated Thermal Rating: on line 2089-6684 : Rate B, Rate C , 0.0, 0.0 -> 14289
% INFO    : Updated Thermal Rating: on line 2089-8151 : Rate B, Rate C , 0.0, 0.0 -> 19583
% INFO    : Updated Thermal Rating: on line 5067-449 : Rate B, Rate C , 0.0, 0.0 -> 11368
% INFO    : Updated Thermal Rating: on line 5067-449 : Rate B, Rate C , 0.0, 0.0 -> 11607
% INFO    : Updated Thermal Rating: on line 7641-3037 : Rate B, Rate C , 0.0, 0.0 -> 15052
% INFO    : Updated Thermal Rating: on line 7641-3037 : Rate B, Rate C , 0.0, 0.0 -> 13595
% INFO    : Updated Thermal Rating: on line 3191-2340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9173
% INFO    : Updated Thermal Rating: on line 3191-8711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9061
% INFO    : Updated Thermal Rating: on line 8104-8722 : Rate B, Rate C , 0.0, 0.0 -> 14120
% INFO    : Updated Thermal Rating: on line 2644-9191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13488
% INFO    : Updated Thermal Rating: on line 4128-8522 : Rate B, Rate C , 0.0, 0.0 -> 115370
% INFO    : Updated Thermal Rating: on line 604-7522 : Rate B, Rate C , 0.0, 0.0 -> 3119
% INFO    : Updated Thermal Rating: on line 604-4000 : Rate B, Rate C , 0.0, 0.0 -> 2164
% INFO    : Updated Thermal Rating: on line 2155-9021 : Rate B, Rate C , 0.0, 0.0 -> 3176
% INFO    : Updated Thermal Rating: on line 2155-9021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2817
% INFO    : Updated Thermal Rating: on line 2155-2042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22385
% INFO    : Updated Thermal Rating: on line 2155-687 : Rate B, Rate C , 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 2155-3520 : Rate B, Rate C , 0.0, 0.0 -> 26969
% INFO    : Updated Thermal Rating: on line 2155-4729 : Rate B, Rate C , 0.0, 0.0 -> 2300
% INFO    : Updated Thermal Rating: on line 2641-4889 : Rate B, Rate C , 0.0, 0.0 -> 2295
% INFO    : Updated Thermal Rating: on line 9067-9051 : Rate B, Rate C , 0.0, 0.0 -> 6238
% INFO    : Updated Thermal Rating: on line 6969-5573 : Rate B, Rate C , 0.0, 0.0 -> 5164
% INFO    : Updated Thermal Rating: on line 666-1494 : Rate A, Rate B, Rate C , 1448.0, 0.0, 0.0 -> 1183
% INFO    : Updated Thermal Rating: on line 666-2732 : Rate A, Rate B, Rate C , 1514.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 666-4550 : Rate A, Rate B, Rate C , 1481.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 666-1607 : Rate B, Rate C , 0.0, 0.0 -> 12537
% INFO    : Updated Thermal Rating: on line 666-2093 : Rate B, Rate C , 0.0, 0.0 -> 4833
% INFO    : Updated Thermal Rating: on line 3565-2177 : Rate B, Rate C , 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 3565-2841 : Rate B, Rate C , 0.0, 0.0 -> 5880
% INFO    : Updated Thermal Rating: on line 3611-7972 : Rate B, Rate C , 0.0, 0.0 -> 2237
% INFO    : Updated Thermal Rating: on line 3611-2481 : Rate B, Rate C , 0.0, 0.0 -> 3697
% INFO    : Updated Thermal Rating: on line 5420-7164 : Rate B, Rate C , 0.0, 0.0 -> 3760
% INFO    : Updated Thermal Rating: on line 7119-2078 : Rate B, Rate C , 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on line 7119-7873 : Rate B, Rate C , 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 7422-7519 : Rate B, Rate C , 0.0, 0.0 -> 3892
% INFO    : Updated Thermal Rating: on line 7422-6744 : Rate B, Rate C , 0.0, 0.0 -> 2101
% INFO    : Updated Thermal Rating: on line 1026-1860 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 4765-3327 : Rate B, Rate C , 0.0, 0.0 -> 5873
% INFO    : Updated Thermal Rating: on line 6036-6921 : Rate B, Rate C , 0.0, 0.0 -> 5568
% INFO    : Updated Thermal Rating: on line 8670-7069 : Rate B, Rate C , 0.0, 0.0 -> 1610
% INFO    : Updated Thermal Rating: on line 8670-7069 : Rate B, Rate C , 0.0, 0.0 -> 1635
% INFO    : Updated Thermal Rating: on line 8670-2866 : Rate B, Rate C , 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on line 4032-6450 : Rate B, Rate C , 0.0, 0.0 -> 2086
% INFO    : Updated Thermal Rating: on line 4032-5738 : Rate B, Rate C , 0.0, 0.0 -> 2243
% INFO    : Updated Thermal Rating: on line 7327-2481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2614
% INFO    : Updated Thermal Rating: on line 7327-8189 : Rate B, Rate C , 0.0, 0.0 -> 8692
% INFO    : Updated Thermal Rating: on line 7474-1584 : Rate B, Rate C , 0.0, 0.0 -> 31852
% INFO    : Updated Thermal Rating: on line 8947-3390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57640
% INFO    : Updated Thermal Rating: on line 1808-6384 : Rate B, Rate C , 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on line 4624-6031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15773
% INFO    : Updated Thermal Rating: on line 1721-3558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43532
% INFO    : Updated Thermal Rating: on line 7694-3865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46697
% INFO    : Updated Thermal Rating: on line 9181-6723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29820
% INFO    : Updated Thermal Rating: on line 8373-8748 : Rate B, Rate C , 0.0, 0.0 -> 1506
% INFO    : Updated Thermal Rating: on line 8373-8475 : Rate B, Rate C , 0.0, 0.0 -> 9896
% INFO    : Updated Thermal Rating: on line 8373-8475 : Rate B, Rate C , 0.0, 0.0 -> 9471
% INFO    : Updated Thermal Rating: on line 5630-6639 : Rate B, Rate C , 0.0, 0.0 -> 1792
% INFO    : Updated Thermal Rating: on line 5630-1187 : Rate B, Rate C , 0.0, 0.0 -> 1649
% INFO    : Updated Thermal Rating: on line 5630-7274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 853
% INFO    : Updated Thermal Rating: on line 5630-8992 : Rate B, Rate C , 0.0, 0.0 -> 968
% INFO    : Updated Thermal Rating: on line 5630-7266 : Rate B, Rate C , 0.0, 0.0 -> 1374
% INFO    : Updated Thermal Rating: on line 3492-6734 : Rate B, Rate C , 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 3492-1015 : Rate B, Rate C , 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 3492-8310 : Rate B, Rate C , 0.0, 0.0 -> 17314
% INFO    : Updated Thermal Rating: on line 1980-6570 : Rate B, Rate C , 0.0, 0.0 -> 4294
% INFO    : Updated Thermal Rating: on line 9137-749 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 7522-2183 : Rate A, Rate B, Rate C , 1711.0, 0.0, 0.0 -> 1381
% INFO    : Updated Thermal Rating: on line 7571-3916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2168
% INFO    : Updated Thermal Rating: on line 7571-6891 : Rate B, Rate C , 0.0, 0.0 -> 3673
% INFO    : Updated Thermal Rating: on line 2526-6199 : Rate B, Rate C , 0.0, 0.0 -> 2197
% INFO    : Updated Thermal Rating: on line 2526-6199 : Rate B, Rate C , 0.0, 0.0 -> 2244
% INFO    : Updated Thermal Rating: on line 1483-3649 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 2365-6199 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 2365-6199 : Rate A, Rate B, Rate C , 1218.0, 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on line 2365-4141 : Rate B, Rate C , 0.0, 0.0 -> 1534
% INFO    : Updated Thermal Rating: on line 2365-1311 : Rate B, Rate C , 0.0, 0.0 -> 2802
% INFO    : Updated Thermal Rating: on line 8316-174 : Rate B, Rate C , 0.0, 0.0 -> 3821
% INFO    : Updated Thermal Rating: on line 174-6430 : Rate B, Rate C , 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 5340-7892 : Rate B, Rate C , 0.0, 0.0 -> 4102
% INFO    : Updated Thermal Rating: on line 5340-561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17232
% INFO    : Updated Thermal Rating: on line 5340-8843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155017
% INFO    : Updated Thermal Rating: on line 5340-8843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157839
% INFO    : Updated Thermal Rating: on line 5340-4239 : Rate B, Rate C , 0.0, 0.0 -> 1379
% INFO    : Updated Thermal Rating: on line 3866-1860 : Rate B, Rate C , 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 3866-5395 : Rate B, Rate C , 0.0, 0.0 -> 2178
% INFO    : Updated Thermal Rating: on line 7042-2177 : Rate B, Rate C , 0.0, 0.0 -> 1979
% INFO    : Updated Thermal Rating: on line 8672-7164 : Rate B, Rate C , 0.0, 0.0 -> 4019
% INFO    : Updated Thermal Rating: on line 1860-7772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1694
% INFO    : Updated Thermal Rating: on line 1860-7772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1435
% INFO    : Updated Thermal Rating: on line 4885-2928 : Rate B, Rate C , 0.0, 0.0 -> 111427
% INFO    : Updated Thermal Rating: on line 4157-2928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121741
% INFO    : Updated Thermal Rating: on line 4432-2928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121741
% INFO    : Updated Thermal Rating: on line 2072-5983 : Rate A, Rate B, Rate C , 1481.0, 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on line 3450-6552 : Rate B, Rate C , 0.0, 0.0 -> 3657
% INFO    : Updated Thermal Rating: on line 3956-7507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1961
% INFO    : Updated Thermal Rating: on line 5286-1838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93122
% INFO    : Updated Thermal Rating: on line 5571-2230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91583
% INFO    : Updated Thermal Rating: on line 2078-8005 : Rate B, Rate C , 0.0, 0.0 -> 4017
% INFO    : Updated Thermal Rating: on line 639-6351 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 639-2749 : Rate B, Rate C , 0.0, 0.0 -> 6761
% INFO    : Updated Thermal Rating: on line 639-9130 : Rate B, Rate C , 0.0, 0.0 -> 3197
% INFO    : Updated Thermal Rating: on line 410-4189 : Rate B, Rate C , 0.0, 0.0 -> 1438
% INFO    : Updated Thermal Rating: on line 1494-5781 : Rate B, Rate C , 0.0, 0.0 -> 4206
% INFO    : Updated Thermal Rating: on line 583-6616 : Rate B, Rate C , 0.0, 0.0 -> 3384
% INFO    : Updated Thermal Rating: on line 583-6031 : Rate B, Rate C , 0.0, 0.0 -> 2386
% INFO    : Updated Thermal Rating: on line 1746-7507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2854
% INFO    : Updated Thermal Rating: on line 3276-7635 : Rate B, Rate C , 0.0, 0.0 -> 87233
% INFO    : Updated Thermal Rating: on line 1105-196 : Rate B, Rate C , 0.0, 0.0 -> 66610
% INFO    : Updated Thermal Rating: on line 8522-7132 : Rate B, Rate C , 0.0, 0.0 -> 18651
% INFO    : Updated Thermal Rating: on line 8522-5351 : Rate B, Rate C , 0.0, 0.0 -> 1239
% INFO    : Updated Thermal Rating: on line 8763-7056 : Rate B, Rate C , 0.0, 0.0 -> 1307
% INFO    : Updated Thermal Rating: on line 8763-8825 : Rate B, Rate C , 0.0, 0.0 -> 1283
% INFO    : Updated Thermal Rating: on line 8763-6889 : Rate B, Rate C , 0.0, 0.0 -> 12298
% INFO    : Updated Thermal Rating: on line 8763-6889 : Rate B, Rate C , 0.0, 0.0 -> 12936
% INFO    : Updated Thermal Rating: on line 8763-8887 : Rate A, Rate B, Rate C , 1514.0, 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on line 8763-8887 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1503
% INFO    : Updated Thermal Rating: on line 8763-8487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2932
% INFO    : Updated Thermal Rating: on line 8748-8475 : Rate B, Rate C , 0.0, 0.0 -> 1200
% INFO    : Updated Thermal Rating: on line 217-6785 : Rate B, Rate C , 0.0, 0.0 -> 1505
% INFO    : Updated Thermal Rating: on line 217-6785 : Rate B, Rate C , 0.0, 0.0 -> 1688
% INFO    : Updated Thermal Rating: on line 217-1179 : Rate B, Rate C , 0.0, 0.0 -> 6680
% INFO    : Updated Thermal Rating: on line 217-2575 : Rate B, Rate C , 0.0, 0.0 -> 7921
% INFO    : Updated Thermal Rating: on line 217-7274 : Rate B, Rate C , 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on line 7972-8189 : Rate B, Rate C , 0.0, 0.0 -> 1508
% INFO    : Updated Thermal Rating: on line 7972-8189 : Rate B, Rate C , 0.0, 0.0 -> 1627
% INFO    : Updated Thermal Rating: on line 7972-1039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2361
% INFO    : Updated Thermal Rating: on line 7253-7840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3594
% INFO    : Updated Thermal Rating: on line 4395-8913 : Rate B, Rate C , 0.0, 0.0 -> 7698
% INFO    : Updated Thermal Rating: on line 4395-4852 : Rate B, Rate C , 0.0, 0.0 -> 4149
% INFO    : Updated Thermal Rating: on line 2795-1183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5439
% INFO    : Updated Thermal Rating: on line 2795-1183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4811
% INFO    : Updated Thermal Rating: on line 1305-6291 : Rate B, Rate C , 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on line 1305-6982 : Rate B, Rate C , 0.0, 0.0 -> 1305
% INFO    : Updated Thermal Rating: on line 2732-1798 : Rate B, Rate C , 0.0, 0.0 -> 1580
% INFO    : Updated Thermal Rating: on line 2732-3346 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 4550-3346 : Rate A, Rate B, Rate C , 1580.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 4725-5738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1583
% INFO    : Updated Thermal Rating: on line 1083-8310 : Rate B, Rate C , 0.0, 0.0 -> 59909
% INFO    : Updated Thermal Rating: on line 1398-5567 : Rate B, Rate C , 0.0, 0.0 -> 45315
% INFO    : Updated Thermal Rating: on line 4281-4580 : Rate B, Rate C , 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on line 7050-4908 : Rate B, Rate C , 0.0, 0.0 -> 24666
% INFO    : Updated Thermal Rating: on line 7050-3740 : Rate B, Rate C , 0.0, 0.0 -> 42288
% INFO    : Updated Thermal Rating: on line 6563-870 : Rate B, Rate C , 0.0, 0.0 -> 31635
% INFO    : Updated Thermal Rating: on line 8999-6495 : Rate B, Rate C , 0.0, 0.0 -> 4522
% INFO    : Updated Thermal Rating: on line 6888-5994 : Rate B, Rate C , 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 5400-8005 : Rate B, Rate C , 0.0, 0.0 -> 6871
% INFO    : Updated Thermal Rating: on line 5400-8005 : Rate B, Rate C , 0.0, 0.0 -> 6583
% INFO    : Updated Thermal Rating: on line 5881-4031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3663
% INFO    : Updated Thermal Rating: on line 8195-8334 : Rate B, Rate C , 0.0, 0.0 -> 1905
% INFO    : Updated Thermal Rating: on line 933-6357 : Rate B, Rate C , 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 933-6357 : Rate B, Rate C , 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on line 933-3775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 449
% INFO    : Updated Thermal Rating: on line 933-3975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3918-1642 : Rate B, Rate C , 0.0, 0.0 -> 5902
% INFO    : Updated Thermal Rating: on line 6802-1153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47123
% INFO    : Updated Thermal Rating: on line 6802-7599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50874
% INFO    : Updated Thermal Rating: on line 4025-3994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45791
% INFO    : Updated Thermal Rating: on line 1595-1414 : Rate B, Rate C , 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 3114-3656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3905
% INFO    : Updated Thermal Rating: on line 5237-2229 : Rate B, Rate C , 0.0, 0.0 -> 1508
% INFO    : Updated Thermal Rating: on line 5237-9108 : Rate B, Rate C , 0.0, 0.0 -> 1893
% INFO    : Updated Thermal Rating: on line 5237-1478 : Rate B, Rate C , 0.0, 0.0 -> 1860
% INFO    : Updated Thermal Rating: on line 2799-8515 : Rate B, Rate C , 0.0, 0.0 -> 46722
% INFO    : Updated Thermal Rating: on line 6405-7873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 6405-3894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on line 4435-4734 : Rate B, Rate C , 0.0, 0.0 -> 4819
% INFO    : Updated Thermal Rating: on line 4435-3483 : Rate A, Rate B, Rate C , 1382.0, 0.0, 0.0 -> 1381
% INFO    : Updated Thermal Rating: on line 2079-7052 : Rate B, Rate C , 0.0, 0.0 -> 3255
% INFO    : Updated Thermal Rating: on line 2079-7052 : Rate B, Rate C , 0.0, 0.0 -> 3175
% INFO    : Updated Thermal Rating: on line 2079-772 : Rate B, Rate C , 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 2079-772 : Rate B, Rate C , 0.0, 0.0 -> 1920
% INFO    : Updated Thermal Rating: on line 1081-6475 : Rate B, Rate C , 0.0, 0.0 -> 1478
% INFO    : Updated Thermal Rating: on line 1081-6475 : Rate B, Rate C , 0.0, 0.0 -> 1555
% INFO    : Updated Thermal Rating: on line 7361-3166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 7361-426 : Rate B, Rate C , 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 2863-1857 : Rate B, Rate C , 0.0, 0.0 -> 31275
% INFO    : Updated Thermal Rating: on line 1364-2430 : Rate B, Rate C , 0.0, 0.0 -> 3794
% INFO    : Updated Thermal Rating: on line 2177-749 : Rate A, Rate B, Rate C , 476.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 3594-2850 : Rate B, Rate C , 0.0, 0.0 -> 1966
% INFO    : Updated Thermal Rating: on line 6555-3608 : Rate B, Rate C , 0.0, 0.0 -> 1494
% INFO    : Updated Thermal Rating: on line 8475-1965 : Rate B, Rate C , 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 8475-5926 : Rate B, Rate C , 0.0, 0.0 -> 16954
% INFO    : Updated Thermal Rating: on line 5735-6053 : Rate B, Rate C , 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on line 5735-2341 : Rate B, Rate C , 0.0, 0.0 -> 2596
% INFO    : Updated Thermal Rating: on line 2629-7507 : Rate B, Rate C , 0.0, 0.0 -> 7813
% INFO    : Updated Thermal Rating: on line 1137-2406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60973
% INFO    : Updated Thermal Rating: on line 7577-5814 : Rate B, Rate C , 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 7577-3231 : Rate B, Rate C , 0.0, 0.0 -> 1518
% INFO    : Updated Thermal Rating: on line 7663-5814 : Rate B, Rate C , 0.0, 0.0 -> 5713
% INFO    : Updated Thermal Rating: on line 1183-1159 : Rate B, Rate C , 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 6852-5051 : Rate B, Rate C , 0.0, 0.0 -> 997
% INFO    : Updated Thermal Rating: on line 8307-8807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27156
% INFO    : Updated Thermal Rating: on line 6947-8807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27847
% INFO    : Updated Thermal Rating: on line 4505-4357 : Rate B, Rate C , 0.0, 0.0 -> 34015
% INFO    : Updated Thermal Rating: on line 7144-7791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7404
% INFO    : Updated Thermal Rating: on line 6889-2085 : Rate B, Rate C , 0.0, 0.0 -> 53817
% INFO    : Updated Thermal Rating: on line 6889-4024 : Rate B, Rate C , 0.0, 0.0 -> 52926
% INFO    : Updated Thermal Rating: on line 6889-9065 : Rate B, Rate C , 0.0, 0.0 -> 58932
% INFO    : Updated Thermal Rating: on line 6889-661 : Rate B, Rate C , 0.0, 0.0 -> 60039
% INFO    : Updated Thermal Rating: on line 6612-8864 : Rate B, Rate C , 0.0, 0.0 -> 20590
% INFO    : Updated Thermal Rating: on line 8931-6199 : Rate B, Rate C , 0.0, 0.0 -> 5378
% INFO    : Updated Thermal Rating: on line 8931-6199 : Rate B, Rate C , 0.0, 0.0 -> 4753
% INFO    : Updated Thermal Rating: on line 8931-6199 : Rate B, Rate C , 0.0, 0.0 -> 4662
% INFO    : Updated Thermal Rating: on line 8931-6199 : Rate B, Rate C , 0.0, 0.0 -> 4575
% INFO    : Updated Thermal Rating: on line 8931-8494 : Rate B, Rate C , 0.0, 0.0 -> 9314
% INFO    : Updated Thermal Rating: on line 8931-8494 : Rate B, Rate C , 0.0, 0.0 -> 9859
% INFO    : Updated Thermal Rating: on line 1643-4511 : Rate B, Rate C , 0.0, 0.0 -> 30359
% INFO    : Updated Thermal Rating: on line 196-1973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25834
% INFO    : Updated Thermal Rating: on line 2902-5573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48210
% INFO    : Updated Thermal Rating: on line 4950-4410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1092
% INFO    : Updated Thermal Rating: on line 4950-333 : Rate B, Rate C , 0.0, 0.0 -> 1329
% INFO    : Updated Thermal Rating: on line 4950-6908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 876
% INFO    : Updated Thermal Rating: on line 3377-7726 : Rate B, Rate C , 0.0, 0.0 -> 76413
% INFO    : Updated Thermal Rating: on line 1027-3243 : Rate B, Rate C , 0.0, 0.0 -> 30849
% INFO    : Updated Thermal Rating: on line 1027-2458 : Rate B, Rate C , 0.0, 0.0 -> 1909
% INFO    : Updated Thermal Rating: on line 1027-2919 : Rate B, Rate C , 0.0, 0.0 -> 7375
% INFO    : Updated Thermal Rating: on line 5308-8560 : Rate B, Rate C , 0.0, 0.0 -> 28859
% INFO    : Updated Thermal Rating: on line 5308-6427 : Rate B, Rate C , 0.0, 0.0 -> 1872
% INFO    : Updated Thermal Rating: on line 5308-8347 : Rate B, Rate C , 0.0, 0.0 -> 2490
% INFO    : Updated Thermal Rating: on line 7148-5610 : Rate B, Rate C , 0.0, 0.0 -> 1592
% INFO    : Updated Thermal Rating: on line 7148-2421 : Rate B, Rate C , 0.0, 0.0 -> 5934
% INFO    : Updated Thermal Rating: on line 7148-2421 : Rate B, Rate C , 0.0, 0.0 -> 6053
% INFO    : Updated Thermal Rating: on line 7148-2421 : Rate B, Rate C , 0.0, 0.0 -> 6164
% INFO    : Updated Thermal Rating: on line 7148-6989 : Rate B, Rate C , 0.0, 0.0 -> 2466
% INFO    : Updated Thermal Rating: on line 44-1545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1566
% INFO    : Updated Thermal Rating: on line 44-3541 : Rate B, Rate C , 0.0, 0.0 -> 1338
% INFO    : Updated Thermal Rating: on line 6231-4710 : Rate B, Rate C , 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 6231-8367 : Rate B, Rate C , 0.0, 0.0 -> 1785
% INFO    : Updated Thermal Rating: on line 6231-2288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5477
% INFO    : Updated Thermal Rating: on line 8291-8473 : Rate B, Rate C , 0.0, 0.0 -> 3592
% INFO    : Updated Thermal Rating: on line 8291-5455 : Rate B, Rate C , 0.0, 0.0 -> 6500
% INFO    : Updated Thermal Rating: on line 8291-7635 : Rate B, Rate C , 0.0, 0.0 -> 2493
% INFO    : Updated Thermal Rating: on line 6842-8473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3825
% INFO    : Updated Thermal Rating: on line 6842-883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 6842-2288 : Rate B, Rate C , 0.0, 0.0 -> 5255
% INFO    : Updated Thermal Rating: on line 3969-7726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3635
% INFO    : Updated Thermal Rating: on line 1090-1129 : Rate B, Rate C , 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 1090-3070 : Rate B, Rate C , 0.0, 0.0 -> 3697
% INFO    : Updated Thermal Rating: on line 8515-5365 : Rate B, Rate C , 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 8515-5365 : Rate B, Rate C , 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 8515-4529 : Rate A, Rate B, Rate C , 381.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 8515-3364 : Rate B, Rate C , 0.0, 0.0 -> 41929
% INFO    : Updated Thermal Rating: on line 935-5383 : Rate B, Rate C , 0.0, 0.0 -> 4856
% INFO    : Updated Thermal Rating: on line 920-6570 : Rate B, Rate C , 0.0, 0.0 -> 155017
% INFO    : Updated Thermal Rating: on line 6664-4426 : Rate B, Rate C , 0.0, 0.0 -> 13291
% INFO    : Updated Thermal Rating: on line 4339-2183 : Rate B, Rate C , 0.0, 0.0 -> 9586
% INFO    : Updated Thermal Rating: on line 7513-4000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9693
% INFO    : Updated Thermal Rating: on line 6570-8542 : Rate B, Rate C , 0.0, 0.0 -> 8963
% INFO    : Updated Thermal Rating: on line 6570-8542 : Rate B, Rate C , 0.0, 0.0 -> 9449
% INFO    : Updated Thermal Rating: on line 6570-1662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2322
% INFO    : Updated Thermal Rating: on line 6570-9119 : Rate B, Rate C , 0.0, 0.0 -> 4647
% INFO    : Updated Thermal Rating: on line 6570-1151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7843
% INFO    : Updated Thermal Rating: on line 502-3589 : Rate B, Rate C , 0.0, 0.0 -> 10995
% INFO    : Updated Thermal Rating: on line 8473-1040 : Rate B, Rate C , 0.0, 0.0 -> 12244
% INFO    : Updated Thermal Rating: on line 8473-145 : Rate B, Rate C , 0.0, 0.0 -> 25543
% INFO    : Updated Thermal Rating: on line 8473-4267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23628
% INFO    : Updated Thermal Rating: on line 4936-5179 : Rate B, Rate C , 0.0, 0.0 -> 3164
% INFO    : Updated Thermal Rating: on line 5317-8854 : Rate B, Rate C , 0.0, 0.0 -> 12765
% INFO    : Updated Thermal Rating: on line 9018-4 : Rate B, Rate C , 0.0, 0.0 -> 3374
% INFO    : Updated Thermal Rating: on line 9018-4829 : Rate B, Rate C , 0.0, 0.0 -> 2406
% INFO    : Updated Thermal Rating: on line 6253-5383 : Rate B, Rate C , 0.0, 0.0 -> 2604
% INFO    : Updated Thermal Rating: on line 6253-7507 : Rate B, Rate C , 0.0, 0.0 -> 2881
% INFO    : Updated Thermal Rating: on line 8887-1644 : Rate B, Rate C , 0.0, 0.0 -> 3037
% INFO    : Updated Thermal Rating: on line 8887-3483 : Rate B, Rate C , 0.0, 0.0 -> 2684
% INFO    : Updated Thermal Rating: on line 6639-7840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3311
% INFO    : Updated Thermal Rating: on line 6639-7840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3250
% INFO    : Updated Thermal Rating: on line 5461-8109 : Rate B, Rate C , 0.0, 0.0 -> 2374
% INFO    : Updated Thermal Rating: on line 6291-4189 : Rate B, Rate C , 0.0, 0.0 -> 1258
% INFO    : Updated Thermal Rating: on line 8405-4747 : Rate B, Rate C , 0.0, 0.0 -> 7369
% INFO    : Updated Thermal Rating: on line 8405-4580 : Rate B, Rate C , 0.0, 0.0 -> 1168
% INFO    : Updated Thermal Rating: on line 338-7824 : Rate B, Rate C , 0.0, 0.0 -> 11239
% INFO    : Updated Thermal Rating: on line 2468-7824 : Rate B, Rate C , 0.0, 0.0 -> 11053
% INFO    : Updated Thermal Rating: on line 5257-7824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13399
% INFO    : Updated Thermal Rating: on line 2189-7824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13134
% INFO    : Updated Thermal Rating: on line 8458-8267 : Rate B, Rate C , 0.0, 0.0 -> 16324
% INFO    : Updated Thermal Rating: on line 2676-5987 : Rate B, Rate C , 0.0, 0.0 -> 2085
% INFO    : Updated Thermal Rating: on line 1187-5712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2558
% INFO    : Updated Thermal Rating: on line 1187-6521 : Rate B, Rate C , 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on line 2360-8636 : Rate B, Rate C , 0.0, 0.0 -> 5704
% INFO    : Updated Thermal Rating: on line 2360-8829 : Rate B, Rate C , 0.0, 0.0 -> 25455
% INFO    : Updated Thermal Rating: on line 2360-4235 : Rate B, Rate C , 0.0, 0.0 -> 1801
% INFO    : Updated Thermal Rating: on line 2360-4235 : Rate B, Rate C , 0.0, 0.0 -> 1773
% INFO    : Updated Thermal Rating: on line 2360-4235 : Rate B, Rate C , 0.0, 0.0 -> 1833
% INFO    : Updated Thermal Rating: on line 8818-5099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 5781-4734 : Rate B, Rate C , 0.0, 0.0 -> 2600
% INFO    : Updated Thermal Rating: on line 5781-905 : Rate B, Rate C , 0.0, 0.0 -> 3928
% INFO    : Updated Thermal Rating: on line 5781-8334 : Rate B, Rate C , 0.0, 0.0 -> 4709
% INFO    : Updated Thermal Rating: on line 5781-2093 : Rate A, Rate B, Rate C , 1415.0, 0.0, 0.0 -> 1199
% INFO    : Updated Thermal Rating: on line 6772-6989 : Rate B, Rate C , 0.0, 0.0 -> 10553
% INFO    : Updated Thermal Rating: on line 7885-3912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 6730-3912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67388
% INFO    : Updated Thermal Rating: on line 4301-3912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64510
% INFO    : Updated Thermal Rating: on line 5362-5610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5841
% INFO    : Updated Thermal Rating: on line 5362-350 : Rate B, Rate C , 0.0, 0.0 -> 28553
% INFO    : Updated Thermal Rating: on line 5362-6763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28222
% INFO    : Updated Thermal Rating: on line 3855-1973 : Rate B, Rate C , 0.0, 0.0 -> 37967
% INFO    : Updated Thermal Rating: on line 3855-1973 : Rate B, Rate C , 0.0, 0.0 -> 22051
% INFO    : Updated Thermal Rating: on line 3481-554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1342
% INFO    : Updated Thermal Rating: on line 5460-8222 : Rate B, Rate C , 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 5460-8222 : Rate B, Rate C , 0.0, 0.0 -> 1921
% INFO    : Updated Thermal Rating: on line 5460-2721 : Rate B, Rate C , 0.0, 0.0 -> 2910
% INFO    : Updated Thermal Rating: on line 5460-2721 : Rate B, Rate C , 0.0, 0.0 -> 2858
% INFO    : Updated Thermal Rating: on line 3786-8578 : Rate B, Rate C , 0.0, 0.0 -> 1246
% INFO    : Updated Thermal Rating: on line 490-2653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46468
% INFO    : Updated Thermal Rating: on line 148-7069 : Rate B, Rate C , 0.0, 0.0 -> 25372
% INFO    : Updated Thermal Rating: on line 7256-8743 : Rate B, Rate C , 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on line 7256-1742 : Rate B, Rate C , 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 8930-314 : Rate B, Rate C , 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 6954-7974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93784
% INFO    : Updated Thermal Rating: on line 3325-7974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99888
% INFO    : Updated Thermal Rating: on line 5627-1742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16564
% INFO    : Updated Thermal Rating: on line 5610-6989 : Rate B, Rate C , 0.0, 0.0 -> 4733
% INFO    : Updated Thermal Rating: on line 21-6163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55892
% INFO    : Updated Thermal Rating: on line 3749-5365 : Rate B, Rate C , 0.0, 0.0 -> 779
% INFO    : Updated Thermal Rating: on line 3749-6982 : Rate B, Rate C , 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on line 2291-3133 : Rate B, Rate C , 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 2291-4738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1905
% INFO    : Updated Thermal Rating: on line 2291-3656 : Rate B, Rate C , 0.0, 0.0 -> 1634
% INFO    : Updated Thermal Rating: on line 314-4300 : Rate B, Rate C , 0.0, 0.0 -> 7799
% INFO    : Updated Thermal Rating: on line 314-5789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7797
% INFO    : Updated Thermal Rating: on line 314-2467 : Rate B, Rate C , 0.0, 0.0 -> 1749
% INFO    : Updated Thermal Rating: on line 314-2467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1709
% INFO    : Updated Thermal Rating: on line 314-5256 : Rate B, Rate C , 0.0, 0.0 -> 1693
% INFO    : Updated Thermal Rating: on line 3200-2653 : Rate B, Rate C , 0.0, 0.0 -> 29775
% INFO    : Updated Thermal Rating: on line 4679-4852 : Rate B, Rate C , 0.0, 0.0 -> 2496
% INFO    : Updated Thermal Rating: on line 4679-4852 : Rate B, Rate C , 0.0, 0.0 -> 3923
% INFO    : Updated Thermal Rating: on line 4679-1151 : Rate B, Rate C , 0.0, 0.0 -> 9867
% INFO    : Updated Thermal Rating: on line 8568-5215 : Rate B, Rate C , 0.0, 0.0 -> 13881
% INFO    : Updated Thermal Rating: on line 58-221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8180
% INFO    : Updated Thermal Rating: on line 6807-851 : Rate B, Rate C , 0.0, 0.0 -> 3799
% INFO    : Updated Thermal Rating: on line 150-5099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 150-3558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6482
% INFO    : Updated Thermal Rating: on line 7209-2934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9308
% INFO    : Updated Thermal Rating: on line 1465-4787 : Rate B, Rate C , 0.0, 0.0 -> 4611
% INFO    : Updated Thermal Rating: on line 1465-3830 : Rate B, Rate C , 0.0, 0.0 -> 6274
% INFO    : Updated Thermal Rating: on line 1465-5648 : Rate B, Rate C , 0.0, 0.0 -> 6400
% INFO    : Updated Thermal Rating: on line 1465-4000 : Rate B, Rate C , 0.0, 0.0 -> 5103
% INFO    : Updated Thermal Rating: on line 7537-3485 : Rate B, Rate C , 0.0, 0.0 -> 10015
% INFO    : Updated Thermal Rating: on line 7537-3830 : Rate B, Rate C , 0.0, 0.0 -> 4715
% INFO    : Updated Thermal Rating: on line 7537-5648 : Rate B, Rate C , 0.0, 0.0 -> 4647
% INFO    : Updated Thermal Rating: on line 1262-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1832
% INFO    : Updated Thermal Rating: on line 1262-1156 : Rate B, Rate C , 0.0, 0.0 -> 2737
% INFO    : Updated Thermal Rating: on line 1262-4914 : Rate B, Rate C , 0.0, 0.0 -> 2031
% INFO    : Updated Thermal Rating: on line 1262-4914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2821
% INFO    : Updated Thermal Rating: on line 1262-3834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11729
% INFO    : Updated Thermal Rating: on line 1262-556 : Rate B, Rate C , 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 1262-3019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4048
% INFO    : Updated Thermal Rating: on line 1262-7923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12172
% INFO    : Updated Thermal Rating: on line 1551-4103 : Rate B, Rate C , 0.0, 0.0 -> 2607
% INFO    : Updated Thermal Rating: on line 1551-7862 : Rate B, Rate C , 0.0, 0.0 -> 4274
% INFO    : Updated Thermal Rating: on line 1551-5458 : Rate B, Rate C , 0.0, 0.0 -> 4122
% INFO    : Updated Thermal Rating: on line 1551-1838 : Rate B, Rate C , 0.0, 0.0 -> 1389
% INFO    : Updated Thermal Rating: on line 3070-2888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10884
% INFO    : Updated Thermal Rating: on line 4874-4504 : Rate B, Rate C , 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on line 4874-3579 : Rate B, Rate C , 0.0, 0.0 -> 2469
% INFO    : Updated Thermal Rating: on line 4874-3579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2614
% INFO    : Updated Thermal Rating: on line 4874-7903 : Rate B, Rate C , 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on line 6368-1102 : Rate B, Rate C , 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on line 6368-9217 : Rate B, Rate C , 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 6368-5653 : Rate B, Rate C , 0.0, 0.0 -> 1841
% INFO    : Updated Thermal Rating: on line 8478-5907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 5241-6921 : Rate B, Rate C , 0.0, 0.0 -> 3877
% INFO    : Updated Thermal Rating: on line 4-1813 : Rate B, Rate C , 0.0, 0.0 -> 2021
% INFO    : Updated Thermal Rating: on line 8950-7049 : Rate B, Rate C , 0.0, 0.0 -> 9413
% INFO    : Updated Thermal Rating: on line 6846-8788 : Rate B, Rate C , 0.0, 0.0 -> 1578
% INFO    : Updated Thermal Rating: on line 6846-6734 : Rate B, Rate C , 0.0, 0.0 -> 2398
% INFO    : Updated Thermal Rating: on line 4426-5616 : Rate A, Rate B, Rate C , 553.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 4426-1965 : Rate B, Rate C , 0.0, 0.0 -> 611
% INFO    : Updated Thermal Rating: on line 4426-1767 : Rate B, Rate C , 0.0, 0.0 -> 684
% INFO    : Updated Thermal Rating: on line 3037-1102 : Rate B, Rate C , 0.0, 0.0 -> 7428
% INFO    : Updated Thermal Rating: on line 3037-8485 : Rate B, Rate C , 0.0, 0.0 -> 4197
% INFO    : Updated Thermal Rating: on line 3037-5653 : Rate B, Rate C , 0.0, 0.0 -> 2553
% INFO    : Updated Thermal Rating: on line 5395-4661 : Rate B, Rate C , 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 5395-520 : Rate B, Rate C , 0.0, 0.0 -> 3383
% INFO    : Updated Thermal Rating: on line 5395-6816 : Rate B, Rate C , 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 5395-5918 : Rate B, Rate C , 0.0, 0.0 -> 1300
% INFO    : Updated Thermal Rating: on line 5395-5918 : Rate B, Rate C , 0.0, 0.0 -> 1287
% INFO    : Updated Thermal Rating: on line 8636-1380 : Rate B, Rate C , 0.0, 0.0 -> 2291
% INFO    : Updated Thermal Rating: on line 3436-4239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2547
% INFO    : Updated Thermal Rating: on line 3436-4239 : Rate B, Rate C , 0.0, 0.0 -> 2529
% INFO    : Updated Thermal Rating: on line 3436-3656 : Rate B, Rate C , 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on line 6203-7124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on line 9059-7124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1035
% INFO    : Updated Thermal Rating: on line 5994-96 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1417
% INFO    : Updated Thermal Rating: on line 5049-306 : Rate B, Rate C , 0.0, 0.0 -> 1417
% INFO    : Updated Thermal Rating: on line 718-8397 : Rate B, Rate C , 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 718-6982 : Rate B, Rate C , 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 7202-8807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2632
% INFO    : Updated Thermal Rating: on line 7202-8807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2683
% INFO    : Updated Thermal Rating: on line 8592-2995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5816
% INFO    : Updated Thermal Rating: on line 6581-823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95544
% INFO    : Updated Thermal Rating: on line 6581-1680 : Rate B, Rate C , 0.0, 0.0 -> 92864
% INFO    : Updated Thermal Rating: on line 6199-953 : Rate B, Rate C , 0.0, 0.0 -> 12195
% INFO    : Updated Thermal Rating: on line 6199-1817 : Rate B, Rate C , 0.0, 0.0 -> 12483
% INFO    : Updated Thermal Rating: on line 3231-1504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3602
% INFO    : Updated Thermal Rating: on line 3231-7226 : Rate B, Rate C , 0.0, 0.0 -> 1472
% INFO    : Updated Thermal Rating: on line 2928-7865 : Rate B, Rate C , 0.0, 0.0 -> 37425
% INFO    : Updated Thermal Rating: on line 3916-6891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2768
% INFO    : Updated Thermal Rating: on line 6053-171 : Rate B, Rate C , 0.0, 0.0 -> 1839
% INFO    : Updated Thermal Rating: on line 6053-171 : Rate B, Rate C , 0.0, 0.0 -> 1876
% INFO    : Updated Thermal Rating: on line 8829-3044 : Rate B, Rate C , 0.0, 0.0 -> 26188
% INFO    : Updated Thermal Rating: on line 1552-1194 : Rate B, Rate C , 0.0, 0.0 -> 4405
% INFO    : Updated Thermal Rating: on line 3912-3740 : Rate B, Rate C , 0.0, 0.0 -> 6862
% INFO    : Updated Thermal Rating: on line 3912-2695 : Rate B, Rate C , 0.0, 0.0 -> 18126
% INFO    : Updated Thermal Rating: on line 3912-2695 : Rate B, Rate C , 0.0, 0.0 -> 40050
% INFO    : Updated Thermal Rating: on line 3912-8877 : Rate B, Rate C , 0.0, 0.0 -> 4693
% INFO    : Updated Thermal Rating: on line 7520-8222 : Rate B, Rate C , 0.0, 0.0 -> 3758
% INFO    : Updated Thermal Rating: on line 7520-8222 : Rate B, Rate C , 0.0, 0.0 -> 3689
% INFO    : Updated Thermal Rating: on line 2421-3610 : Rate B, Rate C , 0.0, 0.0 -> 1819
% INFO    : Updated Thermal Rating: on line 2421-1414 : Rate B, Rate C , 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 8879-3610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1615
% INFO    : Updated Thermal Rating: on line 8397-5918 : Rate B, Rate C , 0.0, 0.0 -> 1464
% INFO    : Updated Thermal Rating: on line 1914-6982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11266
% INFO    : Updated Thermal Rating: on line 7873-6638 : Rate B, Rate C , 0.0, 0.0 -> 2308
% INFO    : Updated Thermal Rating: on line 4562-7702 : Rate B, Rate C , 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 4562-7702 : Rate B, Rate C , 0.0, 0.0 -> 2639
% INFO    : Updated Thermal Rating: on line 8835-1156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5127
% INFO    : Updated Thermal Rating: on line 8835-1233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5224
% INFO    : Updated Thermal Rating: on line 3390-408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39117
% INFO    : Updated Thermal Rating: on line 3390-7231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45856
% INFO    : Updated Thermal Rating: on line 3390-5993 : Rate B, Rate C , 0.0, 0.0 -> 3676
% INFO    : Updated Thermal Rating: on line 1910-2550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30131
% INFO    : Updated Thermal Rating: on line 3975-7353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 3126-7495 : Rate B, Rate C , 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on line 2689-5753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8836
% INFO    : Updated Thermal Rating: on line 1201-4235 : Rate B, Rate C , 0.0, 0.0 -> 3507
% INFO    : Updated Thermal Rating: on line 7626-7076 : Rate B, Rate C , 0.0, 0.0 -> 74627
% INFO    : Updated Thermal Rating: on line 4823-4060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5902
% INFO    : Updated Thermal Rating: on line 4141-1311 : Rate B, Rate C , 0.0, 0.0 -> 3816
% INFO    : Updated Thermal Rating: on line 7124-4566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 7124-8873 : Rate B, Rate C , 0.0, 0.0 -> 32351
% INFO    : Updated Thermal Rating: on line 6684-5383 : Rate B, Rate C , 0.0, 0.0 -> 3092
% INFO    : Updated Thermal Rating: on line 8151-5383 : Rate B, Rate C , 0.0, 0.0 -> 3541
% INFO    : Updated Thermal Rating: on line 4357-6619 : Rate B, Rate C , 0.0, 0.0 -> 4605
% INFO    : Updated Thermal Rating: on line 8191-8765 : Rate B, Rate C , 0.0, 0.0 -> 5309
% INFO    : Updated Thermal Rating: on line 7466-5469 : Rate B, Rate C , 0.0, 0.0 -> 938
% INFO    : Updated Thermal Rating: on line 3401-5351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87580
% INFO    : Updated Thermal Rating: on line 3760-225 : Rate B, Rate C , 0.0, 0.0 -> 4182
% INFO    : Updated Thermal Rating: on line 53-4031 : Rate B, Rate C , 0.0, 0.0 -> 1290
% INFO    : Updated Thermal Rating: on line 8222-6921 : Rate A, Rate B, Rate C , 1678.0, 0.0, 0.0 -> 1461
% INFO    : Updated Thermal Rating: on line 8222-6921 : Rate A, Rate B, Rate C , 1777.0, 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on line 6556-4239 : Rate B, Rate C , 0.0, 0.0 -> 5553
% INFO    : Updated Thermal Rating: on line 6556-4239 : Rate B, Rate C , 0.0, 0.0 -> 5069
% INFO    : Updated Thermal Rating: on line 2940-7178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3077
% INFO    : Updated Thermal Rating: on line 3928-2563 : Rate B, Rate C , 0.0, 0.0 -> 15364
% INFO    : Updated Thermal Rating: on line 3928-6521 : Rate B, Rate C , 0.0, 0.0 -> 47279
% INFO    : Updated Thermal Rating: on line 1923-3830 : Rate B, Rate C , 0.0, 0.0 -> 6234
% INFO    : Updated Thermal Rating: on line 1923-5648 : Rate B, Rate C , 0.0, 0.0 -> 6371
% INFO    : Updated Thermal Rating: on line 2815-4914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39182
% INFO    : Updated Thermal Rating: on line 2815-4914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41796
% INFO    : Updated Thermal Rating: on line 4125-1644 : Rate A, Rate B, Rate C , 1843.0, 0.0, 0.0 -> 1018
% INFO    : Updated Thermal Rating: on line 163-3498 : Rate B, Rate C , 0.0, 0.0 -> 1573
% INFO    : Updated Thermal Rating: on line 163-2430 : Rate B, Rate C , 0.0, 0.0 -> 1528
% INFO    : Updated Thermal Rating: on line 7943-9108 : Rate B, Rate C , 0.0, 0.0 -> 8334
% INFO    : Updated Thermal Rating: on line 7943-1478 : Rate B, Rate C , 0.0, 0.0 -> 8174
% INFO    : Updated Thermal Rating: on line 2308-3541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5453
% INFO    : Updated Thermal Rating: on line 3535-7582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5552
% INFO    : Updated Thermal Rating: on line 2019-8542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21943
% INFO    : Updated Thermal Rating: on line 5174-8542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22129
% INFO    : Updated Thermal Rating: on line 7945-5215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9325
% INFO    : Updated Thermal Rating: on line 2057-9130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18132
% INFO    : Updated Thermal Rating: on line 2057-9130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18519
% INFO    : Updated Thermal Rating: on line 4661-6816 : Rate B, Rate C , 0.0, 0.0 -> 996
% INFO    : Updated Thermal Rating: on line 7519-776 : Rate B, Rate C , 0.0, 0.0 -> 1378
% INFO    : Updated Thermal Rating: on line 8989-3435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65948
% INFO    : Updated Thermal Rating: on line 7797-2020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65948
% INFO    : Updated Thermal Rating: on line 871-4031 : Rate B, Rate C , 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 871-2878 : Rate B, Rate C , 0.0, 0.0 -> 2621
% INFO    : Updated Thermal Rating: on line 7353-9164 : Rate B, Rate C , 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on line 7974-2012 : Rate B, Rate C , 0.0, 0.0 -> 2147
% INFO    : Updated Thermal Rating: on line 7974-2012 : Rate B, Rate C , 0.0, 0.0 -> 2132
% INFO    : Updated Thermal Rating: on line 7974-1750 : Rate B, Rate C , 0.0, 0.0 -> 3105
% INFO    : Updated Thermal Rating: on line 1401-2303 : Rate B, Rate C , 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 4504-7903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1009
% INFO    : Updated Thermal Rating: on line 5837-449 : Rate B, Rate C , 0.0, 0.0 -> 3535
% INFO    : Updated Thermal Rating: on line 5837-449 : Rate B, Rate C , 0.0, 0.0 -> 3615
% INFO    : Updated Thermal Rating: on line 5837-1817 : Rate A, Rate B, Rate C , 1678.0, 0.0, 0.0 -> 905
% INFO    : Updated Thermal Rating: on line 5837-2458 : Rate B, Rate C , 0.0, 0.0 -> 3347
% INFO    : Updated Thermal Rating: on line 5837-6427 : Rate B, Rate C , 0.0, 0.0 -> 3557
% INFO    : Updated Thermal Rating: on line 5837-1730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 9217-594 : Rate B, Rate C , 0.0, 0.0 -> 1365
% INFO    : Updated Thermal Rating: on line 6351-5393 : Rate B, Rate C , 0.0, 0.0 -> 7699
% INFO    : Updated Thermal Rating: on line 6194-7702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on line 2503-7491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 4031-2872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7474
% INFO    : Updated Thermal Rating: on line 4031-8043 : Rate B, Rate C , 0.0, 0.0 -> 1667
% INFO    : Updated Thermal Rating: on line 1813-2866 : Rate B, Rate C , 0.0, 0.0 -> 1824
% INFO    : Updated Thermal Rating: on line 5365-5417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 5365-4100 : Rate B, Rate C , 0.0, 0.0 -> 2710
% INFO    : Updated Thermal Rating: on line 5365-1556 : Rate B, Rate C , 0.0, 0.0 -> 55676
% INFO    : Updated Thermal Rating: on line 3894-3865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1228
% INFO    : Updated Thermal Rating: on line 128-1554 : Rate B, Rate C , 0.0, 0.0 -> 19092
% INFO    : Updated Thermal Rating: on line 198-7994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2671
% INFO    : Updated Thermal Rating: on line 198-1554 : Rate B, Rate C , 0.0, 0.0 -> 2016
% INFO    : Updated Thermal Rating: on line 2985-3133 : Rate B, Rate C , 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 7316-3071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23827
% INFO    : Updated Thermal Rating: on line 6486-8992 : Rate B, Rate C , 0.0, 0.0 -> 2371
% INFO    : Updated Thermal Rating: on line 8485-594 : Rate B, Rate C , 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 682-8477 : Rate B, Rate C , 0.0, 0.0 -> 7532
% INFO    : Updated Thermal Rating: on line 5146-5488 : Rate B, Rate C , 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 6638-776 : Rate B, Rate C , 0.0, 0.0 -> 1018
% INFO    : Updated Thermal Rating: on line 8788-789 : Rate B, Rate C , 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 6332-1556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5705
% INFO    : Updated Thermal Rating: on line 6332-1556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5809
% INFO    : Updated Thermal Rating: on line 1883-7702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 961
% INFO    : Updated Thermal Rating: on line 1883-2132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on line 171-2341 : Rate B, Rate C , 0.0, 0.0 -> 2364
% INFO    : Updated Thermal Rating: on line 6630-10 : Rate B, Rate C , 0.0, 0.0 -> 16165
% INFO    : Updated Thermal Rating: on line 4484-4239 : Rate B, Rate C , 0.0, 0.0 -> 19365
% INFO    : Updated Thermal Rating: on line 3044-4235 : Rate B, Rate C , 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 851-4454 : Rate B, Rate C , 0.0, 0.0 -> 3535
% INFO    : Updated Thermal Rating: on line 3485-2183 : Rate B, Rate C , 0.0, 0.0 -> 11041
% INFO    : Updated Thermal Rating: on line 1156-7923 : Rate B, Rate C , 0.0, 0.0 -> 3479
% INFO    : Updated Thermal Rating: on line 1156-1233 : Rate B, Rate C , 0.0, 0.0 -> 80052
% INFO    : Updated Thermal Rating: on line 8913-4852 : Rate B, Rate C , 0.0, 0.0 -> 3446
% INFO    : Updated Thermal Rating: on line 4039-1233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70621
% INFO    : Updated Thermal Rating: on line 4914-2653 : Rate B, Rate C , 0.0, 0.0 -> 59321
% INFO    : Updated Thermal Rating: on line 4914-2653 : Rate B, Rate C , 0.0, 0.0 -> 62899
% INFO    : Updated Thermal Rating: on line 4914-556 : Rate B, Rate C , 0.0, 0.0 -> 8170
% INFO    : Updated Thermal Rating: on line 4914-3019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11052
% INFO    : Updated Thermal Rating: on line 7994-5256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 1709-3346 : Rate B, Rate C , 0.0, 0.0 -> 1571
% INFO    : Updated Thermal Rating: on line 1709-8468 : Rate B, Rate C , 0.0, 0.0 -> 3639
% INFO    : Updated Thermal Rating: on line 7702-1234 : Rate B, Rate C , 0.0, 0.0 -> 1613
% INFO    : Updated Thermal Rating: on line 7702-8035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1905
% INFO    : Updated Thermal Rating: on line 8677-3331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 8189-3643 : Rate B, Rate C , 0.0, 0.0 -> 2226
% INFO    : Updated Thermal Rating: on line 3133-8477 : Rate B, Rate C , 0.0, 0.0 -> 1724
% INFO    : Updated Thermal Rating: on line 6744-6101 : Rate B, Rate C , 0.0, 0.0 -> 2551
% INFO    : Updated Thermal Rating: on line 8542-4313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17353
% INFO    : Updated Thermal Rating: on line 769-5233 : Rate B, Rate C , 0.0, 0.0 -> 1297
% INFO    : Updated Thermal Rating: on line 1965-5926 : Rate B, Rate C , 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 9014-3999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21842
% INFO    : Updated Thermal Rating: on line 1917-8406 : Rate B, Rate C , 0.0, 0.0 -> 11385
% INFO    : Updated Thermal Rating: on line 1917-2021 : Rate B, Rate C , 0.0, 0.0 -> 11989
% INFO    : Updated Thermal Rating: on line 1917-8293 : Rate B, Rate C , 0.0, 0.0 -> 2601
% INFO    : Updated Thermal Rating: on line 4738-3656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 867
% INFO    : Updated Thermal Rating: on line 4738-8477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3636
% INFO    : Updated Thermal Rating: on line 7998-1644 : Rate B, Rate C , 0.0, 0.0 -> 4432
% INFO    : Updated Thermal Rating: on line 6734-1015 : Rate B, Rate C , 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on line 6734-8992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1592
% INFO    : Updated Thermal Rating: on line 6734-789 : Rate B, Rate C , 0.0, 0.0 -> 2512
% INFO    : Updated Thermal Rating: on line 5004-5393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17113
% INFO    : Updated Thermal Rating: on line 1708-3906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73380
% INFO    : Updated Thermal Rating: on line 9150-3906 : Rate B, Rate C , 0.0, 0.0 -> 78748
% INFO    : Updated Thermal Rating: on line 280-9158 : Rate B, Rate C , 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 8043-3656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 5712-8992 : Rate B, Rate C , 0.0, 0.0 -> 2129
% INFO    : Updated Thermal Rating: on line 5712-8466 : Rate B, Rate C , 0.0, 0.0 -> 9920
% INFO    : Updated Thermal Rating: on line 5712-6880 : Rate B, Rate C , 0.0, 0.0 -> 10368
% INFO    : Updated Thermal Rating: on line 5215-7266 : Rate B, Rate C , 0.0, 0.0 -> 5338
% INFO    : Updated Thermal Rating: on line 8807-8992 : Rate B, Rate C , 0.0, 0.0 -> 4978
% INFO    : Updated Thermal Rating: on line 8807-8992 : Rate B, Rate C , 0.0, 0.0 -> 4887
% INFO    : Updated Thermal Rating: on line 8807-8992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6219
% INFO    : Updated Thermal Rating: on line 218-2088 : Rate B, Rate C , 0.0, 0.0 -> 1050
% INFO    : Updated Thermal Rating: on line 520-5918 : Rate B, Rate C , 0.0, 0.0 -> 1999
% INFO    : Updated Thermal Rating: on line 2653-2128 : Rate B, Rate C , 0.0, 0.0 -> 36817
% INFO    : Updated Thermal Rating: on line 1216-5233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55045
% INFO    : Updated Thermal Rating: on line 8980-5993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13915
% INFO    : Updated Thermal Rating: on line 5212-5993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14137
% INFO    : Updated Thermal Rating: on line 3656-4060 : Rate B, Rate C , 0.0, 0.0 -> 1694
% INFO    : Updated Thermal Rating: on line 883-3331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2032
% INFO    : Updated Thermal Rating: on line 5144-3346 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 774
% INFO    : Updated Thermal Rating: on line 3498-2563 : Rate B, Rate C , 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 1896-8200 : Rate B, Rate C , 0.0, 0.0 -> 29948
% INFO    : Updated Thermal Rating: on line 9130-8864 : Rate B, Rate C , 0.0, 0.0 -> 1805
% INFO    : Updated Thermal Rating: on line 3503-2510 : Rate B, Rate C , 0.0, 0.0 -> 2962
% INFO    : Updated Thermal Rating: on line 3503-6146 : Rate B, Rate C , 0.0, 0.0 -> 4121
% INFO    : Updated Thermal Rating: on line 401-1584 : Rate B, Rate C , 0.0, 0.0 -> 102150
% INFO    : Updated Thermal Rating: on line 7328-6921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1780
% INFO    : Updated Thermal Rating: on line 7328-6921 : Rate A, Rate B, Rate C , 1744.0, 0.0, 0.0 -> 1573
% INFO    : Updated Thermal Rating: on line 6816-5573 : Rate B, Rate C , 0.0, 0.0 -> 1074
% INFO    : Updated Thermal Rating: on line 7396-8564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62614
% INFO    : Updated Thermal Rating: on line 7396-8564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63968
% INFO    : Updated Thermal Rating: on line 6921-432 : Rate B, Rate C , 0.0, 0.0 -> 3095
% INFO    : Updated Thermal Rating: on line 6921-432 : Rate B, Rate C , 0.0, 0.0 -> 3633
% INFO    : Updated Thermal Rating: on line 6921-432 : Rate B, Rate C , 0.0, 0.0 -> 2435
% INFO    : Updated Thermal Rating: on line 6921-432 : Rate B, Rate C , 0.0, 0.0 -> 4173
% INFO    : Updated Thermal Rating: on line 6921-432 : Rate B, Rate C , 0.0, 0.0 -> 4092
% INFO    : Updated Thermal Rating: on line 6921-8200 : Rate A, Rate B, Rate C , 1645.0, 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 2949-3121 : Rate B, Rate C , 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on line 2949-3121 : Rate B, Rate C , 0.0, 0.0 -> 807
% INFO    : Updated Thermal Rating: on line 953-1730 : Rate B, Rate C , 0.0, 0.0 -> 2312
% INFO    : Updated Thermal Rating: on line 1767-892 : Rate A, Rate B, Rate C , 629.0, 0.0, 0.0 -> 587
% INFO    : Updated Thermal Rating: on line 4674-4889 : Rate B, Rate C , 0.0, 0.0 -> 6553
% INFO    : Updated Thermal Rating: on line 4674-7076 : Rate B, Rate C , 0.0, 0.0 -> 28567
% INFO    : Updated Thermal Rating: on line 1234-8035 : Rate B, Rate C , 0.0, 0.0 -> 5032
% INFO    : Updated Thermal Rating: on line 115-225 : Rate B, Rate C , 0.0, 0.0 -> 8039
% INFO    : Updated Thermal Rating: on line 5720-8578 : Rate B, Rate C , 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on line 3579-5469 : Rate B, Rate C , 0.0, 0.0 -> 1633
% INFO    : Updated Thermal Rating: on line 3246-124 : Rate B, Rate C , 0.0, 0.0 -> 28416
% INFO    : Updated Thermal Rating: on line 8846-4783 : Rate B, Rate C , 0.0, 0.0 -> 28923
% INFO    : Updated Thermal Rating: on line 2393-3306 : Rate B, Rate C , 0.0, 0.0 -> 35458
% INFO    : Updated Thermal Rating: on line 1895-4480 : Rate B, Rate C , 0.0, 0.0 -> 35026
% INFO    : Updated Thermal Rating: on line 678-4454 : Rate B, Rate C , 0.0, 0.0 -> 28133
% INFO    : Updated Thermal Rating: on line 1002-4852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11613
% INFO    : Updated Thermal Rating: on line 6429-2012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8540
% INFO    : Updated Thermal Rating: on line 4889-7076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11440
% INFO    : Updated Thermal Rating: on line 5341-7491 : Rate B, Rate C , 0.0, 0.0 -> 6226
% INFO    : Updated Thermal Rating: on line 2563-6521 : Rate B, Rate C , 0.0, 0.0 -> 37622
% INFO    : Updated Thermal Rating: on line 1111-594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2494
% INFO    : Updated Thermal Rating: on line 4747-7791 : Rate B, Rate C , 0.0, 0.0 -> 4005
% INFO    : Updated Thermal Rating: on line 3906-3022 : Rate B, Rate C , 0.0, 0.0 -> 5690
% INFO    : Updated Thermal Rating: on line 3906-1194 : Rate B, Rate C , 0.0, 0.0 -> 5036
% INFO    : Updated Thermal Rating: on line 5993-8804 : Rate B, Rate C , 0.0, 0.0 -> 2911
% INFO    : Updated Thermal Rating: on line 1798-8487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5304
% INFO    : Updated Thermal Rating: on line 2467-7178 : Rate B, Rate C , 0.0, 0.0 -> 2142
% INFO    : Updated Thermal Rating: on line 2132-2303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 8992-8466 : Rate B, Rate C , 0.0, 0.0 -> 2819
% INFO    : Updated Thermal Rating: on line 8992-6880 : Rate B, Rate C , 0.0, 0.0 -> 3102
% INFO    : Updated Thermal Rating: on line 8992-2995 : Rate B, Rate C , 0.0, 0.0 -> 2211
% INFO    : Updated Thermal Rating: on line 805-3221 : Rate B, Rate C , 0.0, 0.0 -> 1153
% INFO    : Updated Thermal Rating: on line 805-3327 : Rate B, Rate C , 0.0, 0.0 -> 2203
% INFO    : Updated Thermal Rating: on line 805-8310 : Rate B, Rate C , 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 805-2088 : Rate B, Rate C , 0.0, 0.0 -> 4025
% INFO    : Updated Thermal Rating: on line 5383-2021 : Rate B, Rate C , 0.0, 0.0 -> 4122
% INFO    : Updated Thermal Rating: on line 5383-4114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9353
% INFO    : Updated Thermal Rating: on line 5383-5519 : Rate B, Rate C , 0.0, 0.0 -> 8632
% INFO    : Updated Thermal Rating: on line 5383-8293 : Rate B, Rate C , 0.0, 0.0 -> 7757
% INFO    : Updated Thermal Rating: on line 5383-3435 : Rate B, Rate C , 0.0, 0.0 -> 3571
% INFO    : Updated Thermal Rating: on line 7507-6990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10003
% INFO    : Updated Thermal Rating: on line 7507-2406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7874
% INFO    : Updated Thermal Rating: on line 7507-2020 : Rate B, Rate C , 0.0, 0.0 -> 3199
% INFO    : Updated Thermal Rating: on line 6478-6146 : Rate B, Rate C , 0.0, 0.0 -> 1023
% INFO    : Updated Thermal Rating: on line 4852-2695 : Rate B, Rate C , 0.0, 0.0 -> 3390
% INFO    : Updated Thermal Rating: on line 4852-2695 : Rate B, Rate C , 0.0, 0.0 -> 3259
% INFO    : Updated Thermal Rating: on line 4852-5502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3517
% INFO    : Updated Thermal Rating: on line 4852-8877 : Rate B, Rate C , 0.0, 0.0 -> 6356
% INFO    : Updated Thermal Rating: on line 4852-9119 : Rate B, Rate C , 0.0, 0.0 -> 5658
% INFO    : Updated Thermal Rating: on line 4852-1151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5280
% INFO    : Updated Thermal Rating: on line 2012-1750 : Rate B, Rate C , 0.0, 0.0 -> 7030
% INFO    : Updated Thermal Rating: on line 1478-6616 : Rate B, Rate C , 0.0, 0.0 -> 2394
% INFO    : Updated Thermal Rating: on line 809-4594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2190
% INFO    : Updated Thermal Rating: on line 8656-4729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30397
% INFO    : Updated Thermal Rating: on line 4100-615 : Rate B, Rate C , 0.0, 0.0 -> 11773
% INFO    : Updated Thermal Rating: on line 4060-5393 : Rate B, Rate C , 0.0, 0.0 -> 6861
% INFO    : Updated Thermal Rating: on line 6000-1689 : Rate B, Rate C , 0.0, 0.0 -> 2780
% INFO    : Updated Thermal Rating: on line 4192-8230 : Rate B, Rate C , 0.0, 0.0 -> 1788
% INFO    : Updated Thermal Rating: on line 8814-2030 : Rate B, Rate C , 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on line 8832-2180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12505
% INFO    : Updated Thermal Rating: on line 8832-3771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58713
% INFO    : Updated Thermal Rating: on line 6395-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 6395-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1149
% INFO    : Updated Thermal Rating: on line 5255-6395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3255
% INFO    : Updated Thermal Rating: on line 5255-6395 : Rate B, Rate C , 0.0, 0.0 -> 3323
% INFO    : Updated Thermal Rating: on line 3397-5247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33791
% INFO    : Updated Thermal Rating: on line 1207-5247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2021
% INFO    : Updated Thermal Rating: on line 3397-7958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34103
% INFO    : Updated Thermal Rating: on line 1207-7958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2176
% INFO    : Updated Thermal Rating: on line 8389-5526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 91-722 : Rate B, Rate C , 0.0, 0.0 -> 43072
% INFO    : Updated Thermal Rating: on line 1207-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2347
% INFO    : Updated Thermal Rating: on line 9083-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2288
% INFO    : Updated Thermal Rating: on line 3363-1870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4018
% INFO    : Updated Thermal Rating: on line 6539-1870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3459
% INFO    : Updated Thermal Rating: on line 5792-1870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1468
% INFO    : Updated Thermal Rating: on line 3363-8356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3557
% INFO    : Updated Thermal Rating: on line 6539-8356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3727
% INFO    : Updated Thermal Rating: on line 5792-8356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 8828-5740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 3443-8828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4191
% INFO    : Updated Thermal Rating: on line 7701-8828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20873
% INFO    : Updated Thermal Rating: on line 2619-8167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on line 244-2619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3749
% INFO    : Updated Thermal Rating: on line 7701-2619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21259
% INFO    : Updated Thermal Rating: on line 1810-4740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 5279-7525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 2180-7374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2102
% INFO    : Updated Thermal Rating: on line 164-8490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2144
% INFO    : Updated Thermal Rating: on line 164-2180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27021
% INFO    : Updated Thermal Rating: on line 164-7596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9098
% INFO    : Updated Thermal Rating: on line 164-2708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9741
% INFO    : Updated Thermal Rating: on line 3119-7059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8989
% INFO    : Updated Thermal Rating: on line 3119-7059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9155
% INFO    : Updated Thermal Rating: on line 7596-2708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5690
% INFO    : Updated Thermal Rating: on line 7596-2305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1366
% INFO    : Updated Thermal Rating: on line 7596-2305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on line 7394-7575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1484
% INFO    : Updated Thermal Rating: on line 7394-7575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on line 7394-4415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 779
% INFO    : Updated Thermal Rating: on line 7394-4686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 5783-7575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 5783-7575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on line 6823-6202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7834
% INFO    : Updated Thermal Rating: on line 6823-6202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7911
% INFO    : Updated Thermal Rating: on line 2330-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 712-4272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 606
% INFO    : Updated Thermal Rating: on line 712-4272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 617
% INFO    : Updated Thermal Rating: on line 878-3206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on line 7090-3206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1895
% INFO    : Updated Thermal Rating: on line 7844-3206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on line 3497-6202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 3497-6202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 796
% INFO    : Updated Thermal Rating: on line 3497-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2636
% INFO    : Updated Thermal Rating: on line 3497-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2843
% INFO    : Updated Thermal Rating: on line 5426-9120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6611
% INFO    : Updated Thermal Rating: on line 133-9120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7317
% INFO    : Updated Thermal Rating: on line 6323-9120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on line 5426-3047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6492
% INFO    : Updated Thermal Rating: on line 275-3047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2123
% INFO    : Updated Thermal Rating: on line 133-3047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7404
% INFO    : Updated Thermal Rating: on line 4188-1880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2808
% INFO    : Updated Thermal Rating: on line 3898-4188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 486-5740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21658
% INFO    : Updated Thermal Rating: on line 5740-539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1793
% INFO    : Updated Thermal Rating: on line 486-8167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22108
% INFO    : Updated Thermal Rating: on line 8167-539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1932
% INFO    : Updated Thermal Rating: on line 9094-8463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5484
% INFO    : Updated Thermal Rating: on line 9094-8994 : Rate B, Rate C , 0.0, 0.0 -> 4279
% INFO    : Updated Thermal Rating: on line 6354-9094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2322
% INFO    : Updated Thermal Rating: on line 9094-1936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5449
% INFO    : Updated Thermal Rating: on line 3280-6423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1089
% INFO    : Updated Thermal Rating: on line 2055-6423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34727
% INFO    : Updated Thermal Rating: on line 6275-6423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2342
% INFO    : Updated Thermal Rating: on line 7138-5618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1583
% INFO    : Updated Thermal Rating: on line 2055-5618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31394
% INFO    : Updated Thermal Rating: on line 6275-5618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2133
% INFO    : Updated Thermal Rating: on line 6288-3456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3218
% INFO    : Updated Thermal Rating: on line 2745-3456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26113
% INFO    : Updated Thermal Rating: on line 3301-3456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4795
% INFO    : Updated Thermal Rating: on line 2745-3280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23441
% INFO    : Updated Thermal Rating: on line 3301-3280 : Rate B, Rate C , 0.0, 0.0 -> 4881
% INFO    : Updated Thermal Rating: on line 790-6600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26368
% INFO    : Updated Thermal Rating: on line 472-8889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2157
% INFO    : Updated Thermal Rating: on line 472-775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6356-3443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4737
% INFO    : Updated Thermal Rating: on line 8164-3443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22534
% INFO    : Updated Thermal Rating: on line 6356-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4654
% INFO    : Updated Thermal Rating: on line 8164-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20195
% INFO    : Updated Thermal Rating: on line 8814-5320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1685
% INFO    : Updated Thermal Rating: on line 8814-5320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on line 1255-143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 1255-3974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1569
% INFO    : Updated Thermal Rating: on line 8016-1255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1482
% INFO    : Updated Thermal Rating: on line 8016-1255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1496
% INFO    : Updated Thermal Rating: on line 1255-4362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 950-5792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1554
% INFO    : Updated Thermal Rating: on line 950-5792 : Rate B, Rate C , 0.0, 0.0 -> 1673
% INFO    : Updated Thermal Rating: on line 3397-6045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6288-7138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 707
% INFO    : Updated Thermal Rating: on line 6057-1352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 6057-6559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1829
% INFO    : Updated Thermal Rating: on line 656-1392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1145
% INFO    : Updated Thermal Rating: on line 6835-3538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 351-3538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on line 1392-3538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68520
% INFO    : Updated Thermal Rating: on line 1392-2824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5635
% INFO    : Updated Thermal Rating: on line 1052-1392 : Rate B, Rate C , 0.0, 0.0 -> 1387
% INFO    : Updated Thermal Rating: on line 3538-140 : Rate B, Rate C , 0.0, 0.0 -> 5757
% INFO    : Updated Thermal Rating: on line 3878-3538 : Rate B, Rate C , 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on line 5001-8862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 5001-8862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 1810-6342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3361
% INFO    : Updated Thermal Rating: on line 1777-1810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1142
% INFO    : Updated Thermal Rating: on line 1352-6559 : Rate B, Rate C , 0.0, 0.0 -> 743
% INFO    : Updated Thermal Rating: on line 1352-643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1349
% INFO    : Updated Thermal Rating: on line 1352-1836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3672
% INFO    : Updated Thermal Rating: on line 1352-1836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3746
% INFO    : Updated Thermal Rating: on line 1670-1352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2550
% INFO    : Updated Thermal Rating: on line 1670-1352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2257
% INFO    : Updated Thermal Rating: on line 1352-7628 : Rate B, Rate C , 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 1352-311 : Rate B, Rate C , 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 6998-2482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5008-8249 : Rate B, Rate C , 0.0, 0.0 -> 10075
% INFO    : Updated Thermal Rating: on line 6068-8249 : Rate B, Rate C , 0.0, 0.0 -> 4092
% INFO    : Updated Thermal Rating: on line 6139-5450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1016
% INFO    : Updated Thermal Rating: on line 6139-5450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1033
% INFO    : Updated Thermal Rating: on line 344-6139 : Rate B, Rate C , 0.0, 0.0 -> 1389
% INFO    : Updated Thermal Rating: on line 344-6139 : Rate B, Rate C , 0.0, 0.0 -> 1400
% INFO    : Updated Thermal Rating: on line 8881-7751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 8881-6559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8986
% INFO    : Updated Thermal Rating: on line 8881-5342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1565
% INFO    : Updated Thermal Rating: on line 8881-6399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2878
% INFO    : Updated Thermal Rating: on line 1670-8881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 8881-9083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 5279-2350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 5279-1123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 5279-1633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42268
% INFO    : Updated Thermal Rating: on line 5279-1633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43011
% INFO    : Updated Thermal Rating: on line 5279-2812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36580
% INFO    : Updated Thermal Rating: on line 5279-9029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11925
% INFO    : Updated Thermal Rating: on line 5279-6149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13827
% INFO    : Updated Thermal Rating: on line 5279-6149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12858
% INFO    : Updated Thermal Rating: on line 5279-4616 : Rate B, Rate C , 0.0, 0.0 -> 9709
% INFO    : Updated Thermal Rating: on line 1777-5893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 5296-5893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 2478-5893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 2478-5893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 773
% INFO    : Updated Thermal Rating: on line 2350-1260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2479
% INFO    : Updated Thermal Rating: on line 6354-8463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3615
% INFO    : Updated Thermal Rating: on line 6354-8994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5455
% INFO    : Updated Thermal Rating: on line 8994-7476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6446
% INFO    : Updated Thermal Rating: on line 8994-7476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6362
% INFO    : Updated Thermal Rating: on line 3023-806 : Rate B, Rate C , 0.0, 0.0 -> 4207
% INFO    : Updated Thermal Rating: on line 5674-806 : Rate B, Rate C , 0.0, 0.0 -> 2964
% INFO    : Updated Thermal Rating: on line 2240-8991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2244
% INFO    : Updated Thermal Rating: on line 539-2240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7313
% INFO    : Updated Thermal Rating: on line 539-2240 : Rate B, Rate C , 0.0, 0.0 -> 7397
% INFO    : Updated Thermal Rating: on line 8814-5426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2464
% INFO    : Updated Thermal Rating: on line 8814-5426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2418
% INFO    : Updated Thermal Rating: on line 5748-1046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59281
% INFO    : Updated Thermal Rating: on line 5748-1046 : Rate B, Rate C , 0.0, 0.0 -> 60257
% INFO    : Updated Thermal Rating: on line 5748-1836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 5748-1836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 5748-6824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3320
% INFO    : Updated Thermal Rating: on line 5748-6824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3271
% INFO    : Updated Thermal Rating: on line 5748-6275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3544
% INFO    : Updated Thermal Rating: on line 5748-6275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3614
% INFO    : Updated Thermal Rating: on line 2974-3301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1962
% INFO    : Updated Thermal Rating: on line 1670-2974 : Rate B, Rate C , 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on line 6998-8875 : Rate B, Rate C , 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 1747-593 : Rate B, Rate C , 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 593-8230 : Rate A, Rate B, Rate C , 1613.0, 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on line 6998-8772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 6998-6356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2059
% INFO    : Updated Thermal Rating: on line 6998-6356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2099
% INFO    : Updated Thermal Rating: on line 6998-5031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5478
% INFO    : Updated Thermal Rating: on line 6998-5031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5390
% INFO    : Updated Thermal Rating: on line 6998-3299 : Rate B, Rate C , 0.0, 0.0 -> 4046
% INFO    : Updated Thermal Rating: on line 6998-3299 : Rate B, Rate C , 0.0, 0.0 -> 4133
% INFO    : Updated Thermal Rating: on line 6998-3119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on line 6998-3119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on line 6998-1464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on line 6998-1464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1098
% INFO    : Updated Thermal Rating: on line 1221-1350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2732
% INFO    : Updated Thermal Rating: on line 1221-1350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2791
% INFO    : Updated Thermal Rating: on line 2305-1350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2159
% INFO    : Updated Thermal Rating: on line 2305-1350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2205
% INFO    : Updated Thermal Rating: on line 199-7195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6757
% INFO    : Updated Thermal Rating: on line 52-199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 4964-8432 : Rate B, Rate C , 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 8432-3190 : Rate B, Rate C , 0.0, 0.0 -> 2650
% INFO    : Updated Thermal Rating: on line 8432-3352 : Rate B, Rate C , 0.0, 0.0 -> 9965
% INFO    : Updated Thermal Rating: on line 4964-3484 : Rate B, Rate C , 0.0, 0.0 -> 2708
% INFO    : Updated Thermal Rating: on line 4964-6766 : Rate B, Rate C , 0.0, 0.0 -> 9781
% INFO    : Updated Thermal Rating: on line 838-6295 : Rate B, Rate C , 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on line 3190-3484 : Rate B, Rate C , 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 3190-6263 : Rate B, Rate C , 0.0, 0.0 -> 9621
% INFO    : Updated Thermal Rating: on line 395-3190 : Rate B, Rate C , 0.0, 0.0 -> 10047
% INFO    : Updated Thermal Rating: on line 3484-6068 : Rate B, Rate C , 0.0, 0.0 -> 9827
% INFO    : Updated Thermal Rating: on line 5843-3484 : Rate B, Rate C , 0.0, 0.0 -> 10239
% INFO    : Updated Thermal Rating: on line 3210-4021 : Rate B, Rate C , 0.0, 0.0 -> 1622
% INFO    : Updated Thermal Rating: on line 1670-7425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 2381-5772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2037
% INFO    : Updated Thermal Rating: on line 281-8086 : Rate B, Rate C , 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 281-6068 : Rate B, Rate C , 0.0, 0.0 -> 11190
% INFO    : Updated Thermal Rating: on line 4077-281 : Rate B, Rate C , 0.0, 0.0 -> 4456
% INFO    : Updated Thermal Rating: on line 8086-6263 : Rate B, Rate C , 0.0, 0.0 -> 12088
% INFO    : Updated Thermal Rating: on line 5888-8086 : Rate B, Rate C , 0.0, 0.0 -> 4369
% INFO    : Updated Thermal Rating: on line 1477-5255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11389
% INFO    : Updated Thermal Rating: on line 3960-5255 : Rate B, Rate C , 0.0, 0.0 -> 11593
% INFO    : Updated Thermal Rating: on line 8037-5255 : Rate B, Rate C , 0.0, 0.0 -> 11845
% INFO    : Updated Thermal Rating: on line 1989-1597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 6923-1597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 676-8706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 8706-205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1259
% INFO    : Updated Thermal Rating: on line 8706-4362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2136
% INFO    : Updated Thermal Rating: on line 8706-4362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2177
% INFO    : Updated Thermal Rating: on line 7584-7736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 7584-5591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on line 7584-5364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1158
% INFO    : Updated Thermal Rating: on line 4774-7584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 865
% INFO    : Updated Thermal Rating: on line 4774-7584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 882
% INFO    : Updated Thermal Rating: on line 5255-2796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17383
% INFO    : Updated Thermal Rating: on line 5255-2796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17554
% INFO    : Updated Thermal Rating: on line 8642-5255 : Rate B, Rate C , 0.0, 0.0 -> 6295
% INFO    : Updated Thermal Rating: on line 5255-2703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 650-4104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 1989-650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 491
% INFO    : Updated Thermal Rating: on line 4130-1635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6167-4130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6167-5872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2058
% INFO    : Updated Thermal Rating: on line 4130-496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1580
% INFO    : Updated Thermal Rating: on line 4130-5872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1831
% INFO    : Updated Thermal Rating: on line 6582-3462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2507
% INFO    : Updated Thermal Rating: on line 6582-4082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4046
% INFO    : Updated Thermal Rating: on line 6582-5246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3601
% INFO    : Updated Thermal Rating: on line 496-5872 : Rate B, Rate C , 0.0, 0.0 -> 2822
% INFO    : Updated Thermal Rating: on line 6047-3664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2077-9063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3224-8044 : Rate B, Rate C , 0.0, 0.0 -> 19555
% INFO    : Updated Thermal Rating: on line 76-5742 : Rate B, Rate C , 0.0, 0.0 -> 32401
% INFO    : Updated Thermal Rating: on line 38-5742 : Rate B, Rate C , 0.0, 0.0 -> 34833
% INFO    : Updated Thermal Rating: on line 8814-9118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2000
% INFO    : Updated Thermal Rating: on line 5008-919 : Rate B, Rate C , 0.0, 0.0 -> 58496
% INFO    : Updated Thermal Rating: on line 1788-5008 : Rate B, Rate C , 0.0, 0.0 -> 3038
% INFO    : Updated Thermal Rating: on line 662-5008 : Rate B, Rate C , 0.0, 0.0 -> 10643
% INFO    : Updated Thermal Rating: on line 8604-919 : Rate B, Rate C , 0.0, 0.0 -> 2984
% INFO    : Updated Thermal Rating: on line 6354-4295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 6354-5203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1627
% INFO    : Updated Thermal Rating: on line 6354-5203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1659
% INFO    : Updated Thermal Rating: on line 6354-472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 6354-7476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4603
% INFO    : Updated Thermal Rating: on line 6354-7476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4686
% INFO    : Updated Thermal Rating: on line 6354-8792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 801
% INFO    : Updated Thermal Rating: on line 6354-8792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on line 6354-8792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 848
% INFO    : Updated Thermal Rating: on line 1020-1094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1925
% INFO    : Updated Thermal Rating: on line 3182-1094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 4825-3023 : Rate B, Rate C , 0.0, 0.0 -> 63175
% INFO    : Updated Thermal Rating: on line 4825-6345 : Rate B, Rate C , 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 4825-8114 : Rate B, Rate C , 0.0, 0.0 -> 3709
% INFO    : Updated Thermal Rating: on line 4825-3210 : Rate B, Rate C , 0.0, 0.0 -> 1806
% INFO    : Updated Thermal Rating: on line 3023-6345 : Rate B, Rate C , 0.0, 0.0 -> 65807
% INFO    : Updated Thermal Rating: on line 3023-8773 : Rate B, Rate C , 0.0, 0.0 -> 3789
% INFO    : Updated Thermal Rating: on line 7884-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1293
% INFO    : Updated Thermal Rating: on line 7884-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1318
% INFO    : Updated Thermal Rating: on line 7884-6202 : Rate B, Rate C , 0.0, 0.0 -> 2119
% INFO    : Updated Thermal Rating: on line 7884-1106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1030
% INFO    : Updated Thermal Rating: on line 7884-1106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1111
% INFO    : Updated Thermal Rating: on line 7884-7305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7352
% INFO    : Updated Thermal Rating: on line 7884-7305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6881
% INFO    : Updated Thermal Rating: on line 7884-6987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 7884-6987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1036
% INFO    : Updated Thermal Rating: on line 7884-4774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1349
% INFO    : Updated Thermal Rating: on line 7884-3620 : Rate B, Rate C , 0.0, 0.0 -> 1509
% INFO    : Updated Thermal Rating: on line 3119-1722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1964
% INFO    : Updated Thermal Rating: on line 585-3148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 1106-585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 861
% INFO    : Updated Thermal Rating: on line 6987-585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1966
% INFO    : Updated Thermal Rating: on line 7275-585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 8114-8773 : Rate B, Rate C , 0.0, 0.0 -> 67208
% INFO    : Updated Thermal Rating: on line 8393-8114 : Rate B, Rate C , 0.0, 0.0 -> 2658
% INFO    : Updated Thermal Rating: on line 139-8773 : Rate B, Rate C , 0.0, 0.0 -> 2610
% INFO    : Updated Thermal Rating: on line 676-6439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 8738-676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9887
% INFO    : Updated Thermal Rating: on line 8738-676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9717
% INFO    : Updated Thermal Rating: on line 676-205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1514
% INFO    : Updated Thermal Rating: on line 8862-6915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 8862-9205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 6393-4057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 6028-6393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 583
% INFO    : Updated Thermal Rating: on line 4872-6393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 6393-7136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 2769-6118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 76-2769 : Rate B, Rate C , 0.0, 0.0 -> 21010
% INFO    : Updated Thermal Rating: on line 38-6118 : Rate B, Rate C , 0.0, 0.0 -> 29290
% INFO    : Updated Thermal Rating: on line 3224-7117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1763
% INFO    : Updated Thermal Rating: on line 3224-8525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1622
% INFO    : Updated Thermal Rating: on line 3224-5346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19813
% INFO    : Updated Thermal Rating: on line 4993-3335 : Rate B, Rate C , 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on line 6832-4797 : Rate B, Rate C , 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on line 6489-4797 : Rate B, Rate C , 0.0, 0.0 -> 1264
% INFO    : Updated Thermal Rating: on line 8284-4797 : Rate B, Rate C , 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on line 577-1362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1982
% INFO    : Updated Thermal Rating: on line 268-1057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on line 2728-5979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on line 8662-8298 : Rate B, Rate C , 0.0, 0.0 -> 1094
% INFO    : Updated Thermal Rating: on line 6884-4059 : Rate B, Rate C , 0.0, 0.0 -> 1073
% INFO    : Updated Thermal Rating: on line 3723-3335 : Rate A, Rate B, Rate C , 1876.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 1890-3335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1138
% INFO    : Updated Thermal Rating: on line 71-8141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 7295-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1515
% INFO    : Updated Thermal Rating: on line 71-7297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on line 4797-8298 : Rate B, Rate C , 0.0, 0.0 -> 68669
% INFO    : Updated Thermal Rating: on line 4797-4059 : Rate B, Rate C , 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 4797-7388 : Rate B, Rate C , 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 4797-2002 : Rate B, Rate C , 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 2448-5979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 2448-1057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60629
% INFO    : Updated Thermal Rating: on line 2448-6282 : Rate B, Rate C , 0.0, 0.0 -> 59487
% INFO    : Updated Thermal Rating: on line 2448-4340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58604
% INFO    : Updated Thermal Rating: on line 3335-8298 : Rate B, Rate C , 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 3335-4059 : Rate B, Rate C , 0.0, 0.0 -> 58496
% INFO    : Updated Thermal Rating: on line 3335-7388 : Rate B, Rate C , 0.0, 0.0 -> 63175
% INFO    : Updated Thermal Rating: on line 3335-2002 : Rate B, Rate C , 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 326-5979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63175
% INFO    : Updated Thermal Rating: on line 326-1057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 326-6282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65945
% INFO    : Updated Thermal Rating: on line 326-4340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67351
% INFO    : Updated Thermal Rating: on line 4858-8298 : Rate B, Rate C , 0.0, 0.0 -> 5789
% INFO    : Updated Thermal Rating: on line 2523-5979 : Rate B, Rate C , 0.0, 0.0 -> 68520
% INFO    : Updated Thermal Rating: on line 1057-1362 : Rate B, Rate C , 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 1956-7388 : Rate B, Rate C , 0.0, 0.0 -> 5119
% INFO    : Updated Thermal Rating: on line 5299-2002 : Rate B, Rate C , 0.0, 0.0 -> 1161
% INFO    : Updated Thermal Rating: on line 4340-1052 : Rate B, Rate C , 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 6662-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5165-2722 : Rate B, Rate C , 0.0, 0.0 -> 65807
% INFO    : Updated Thermal Rating: on line 5165-1689 : Rate B, Rate C , 0.0, 0.0 -> 2646
% INFO    : Updated Thermal Rating: on line 5165-3210 : Rate B, Rate C , 0.0, 0.0 -> 3472
% INFO    : Updated Thermal Rating: on line 2722-1689 : Rate B, Rate C , 0.0, 0.0 -> 2699
% INFO    : Updated Thermal Rating: on line 2722-8230 : Rate B, Rate C , 0.0, 0.0 -> 2757
% INFO    : Updated Thermal Rating: on line 2722-5674 : Rate B, Rate C , 0.0, 0.0 -> 3545
% INFO    : Updated Thermal Rating: on line 3363-7195 : Rate B, Rate C , 0.0, 0.0 -> 3436
% INFO    : Updated Thermal Rating: on line 3363-7195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3373
% INFO    : Updated Thermal Rating: on line 7195-8977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6201
% INFO    : Updated Thermal Rating: on line 52-7195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on line 7195-3868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1929
% INFO    : Updated Thermal Rating: on line 3363-392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 961
% INFO    : Updated Thermal Rating: on line 3363-3530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2359
% INFO    : Updated Thermal Rating: on line 3363-3530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2401
% INFO    : Updated Thermal Rating: on line 3363-5829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 8977-6539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7117
% INFO    : Updated Thermal Rating: on line 7675-6539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 981
% INFO    : Updated Thermal Rating: on line 7675-6539 : Rate B, Rate C , 0.0, 0.0 -> 966
% INFO    : Updated Thermal Rating: on line 1702-2900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 6202-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2101
% INFO    : Updated Thermal Rating: on line 6202-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2145
% INFO    : Updated Thermal Rating: on line 1106-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 1106-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1812
% INFO    : Updated Thermal Rating: on line 5916-6342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5590
% INFO    : Updated Thermal Rating: on line 4302-6342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 733-8917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 5423-8917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 1777-548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2836
% INFO    : Updated Thermal Rating: on line 548-6923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 9029-8508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 1591-5558 : Rate B, Rate C , 0.0, 0.0 -> 67208
% INFO    : Updated Thermal Rating: on line 1591-8604 : Rate B, Rate C , 0.0, 0.0 -> 8585
% INFO    : Updated Thermal Rating: on line 1591-8264 : Rate B, Rate C , 0.0, 0.0 -> 4974
% INFO    : Updated Thermal Rating: on line 1124-8510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 1124-3257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2015
% INFO    : Updated Thermal Rating: on line 5311-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1408
% INFO    : Updated Thermal Rating: on line 5558-1788 : Rate B, Rate C , 0.0, 0.0 -> 7586
% INFO    : Updated Thermal Rating: on line 8211-5558 : Rate B, Rate C , 0.0, 0.0 -> 4875
% INFO    : Updated Thermal Rating: on line 8510-369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2057
% INFO    : Updated Thermal Rating: on line 3891-8510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 5952-784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2081
% INFO    : Updated Thermal Rating: on line 5952-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4099
% INFO    : Updated Thermal Rating: on line 5952-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4134
% INFO    : Updated Thermal Rating: on line 6923-5108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4417
% INFO    : Updated Thermal Rating: on line 5829-392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 949
% INFO    : Updated Thermal Rating: on line 1633-8389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1439
% INFO    : Updated Thermal Rating: on line 1633-8389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1415
% INFO    : Updated Thermal Rating: on line 8389-2720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2980
% INFO    : Updated Thermal Rating: on line 8389-243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2552
% INFO    : Updated Thermal Rating: on line 8389-4409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 3119-2572 : Rate B, Rate C , 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 4318-7404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3405
% INFO    : Updated Thermal Rating: on line 4318-1338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7613
% INFO    : Updated Thermal Rating: on line 4318-8288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 7404-8882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25816
% INFO    : Updated Thermal Rating: on line 7404-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on line 1338-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4001
% INFO    : Updated Thermal Rating: on line 360-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 275-6323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1652
% INFO    : Updated Thermal Rating: on line 5872-7230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 8194-5872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 1020-6514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1630
% INFO    : Updated Thermal Rating: on line 1020-387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1106-6838 : Rate B, Rate C , 0.0, 0.0 -> 16802
% INFO    : Updated Thermal Rating: on line 8480-6025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24710
% INFO    : Updated Thermal Rating: on line 9029-5835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16377
% INFO    : Updated Thermal Rating: on line 3374-878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 7450-3374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1407
% INFO    : Updated Thermal Rating: on line 7450-3374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 6383-231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 2228-6383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 2228-6383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 1010-6383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on line 2228-8878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on line 2228-8878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on line 2228-7117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 2228-2698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on line 8277-2228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 8277-2228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 4057-5783 : Rate B, Rate C , 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 7136-4057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 609
% INFO    : Updated Thermal Rating: on line 5549-1207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2582
% INFO    : Updated Thermal Rating: on line 5549-9083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 2745-7138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 929
% INFO    : Updated Thermal Rating: on line 2745-7138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 947
% INFO    : Updated Thermal Rating: on line 1670-2745 : Rate B, Rate C , 0.0, 0.0 -> 1223
% INFO    : Updated Thermal Rating: on line 1670-2745 : Rate B, Rate C , 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on line 2745-8492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1728
% INFO    : Updated Thermal Rating: on line 2745-2748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3983
% INFO    : Updated Thermal Rating: on line 2745-3215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3288
% INFO    : Updated Thermal Rating: on line 6915-8668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 544
% INFO    : Updated Thermal Rating: on line 3177-6356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 1464-6356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on line 1689-8230 : Rate B, Rate C , 0.0, 0.0 -> 68669
% INFO    : Updated Thermal Rating: on line 6068-1689 : Rate B, Rate C , 0.0, 0.0 -> 4597
% INFO    : Updated Thermal Rating: on line 6263-8230 : Rate B, Rate C , 0.0, 0.0 -> 4506
% INFO    : Updated Thermal Rating: on line 8814-69 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on line 8814-5949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1297
% INFO    : Updated Thermal Rating: on line 8814-5949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on line 8814-8613 : Rate B, Rate C , 0.0, 0.0 -> 2633
% INFO    : Updated Thermal Rating: on line 8814-9007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on line 8814-5188 : Rate B, Rate C , 0.0, 0.0 -> 1100
% INFO    : Updated Thermal Rating: on line 2077-6442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7019
% INFO    : Updated Thermal Rating: on line 2077-3462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6477
% INFO    : Updated Thermal Rating: on line 2812-1778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2812-1633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142169
% INFO    : Updated Thermal Rating: on line 3983-1633 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7442-1633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7297
% INFO    : Updated Thermal Rating: on line 6047-5271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12650
% INFO    : Updated Thermal Rating: on line 6047-5271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11902
% INFO    : Updated Thermal Rating: on line 211-2832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 4132-2832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 715
% INFO    : Updated Thermal Rating: on line 4132-2832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 727
% INFO    : Updated Thermal Rating: on line 2804-2832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 4216-6028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20172
% INFO    : Updated Thermal Rating: on line 6028-4872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 6028-9146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 6028-9146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 6058-6028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 6058-6028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 796
% INFO    : Updated Thermal Rating: on line 6028-7011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1419
% INFO    : Updated Thermal Rating: on line 6028-7011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 7295-5595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 800
% INFO    : Updated Thermal Rating: on line 5595-7297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 5595-1020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 2616-5595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1187
% INFO    : Updated Thermal Rating: on line 5595-2305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 1989-4104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 1889-4104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2006
% INFO    : Updated Thermal Rating: on line 312-5783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26367
% INFO    : Updated Thermal Rating: on line 8393-139 : Rate B, Rate C , 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 8393-8264 : Rate B, Rate C , 0.0, 0.0 -> 2693
% INFO    : Updated Thermal Rating: on line 139-8211 : Rate B, Rate C , 0.0, 0.0 -> 2642
% INFO    : Updated Thermal Rating: on line 6600-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4752
% INFO    : Updated Thermal Rating: on line 6600-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4829
% INFO    : Updated Thermal Rating: on line 2555-6600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24150
% INFO    : Updated Thermal Rating: on line 5783-7565 : Rate B, Rate C , 0.0, 0.0 -> 3935
% INFO    : Updated Thermal Rating: on line 5783-7565 : Rate B, Rate C , 0.0, 0.0 -> 4244
% INFO    : Updated Thermal Rating: on line 5783-2648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 5783-2648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 1989-6923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 1989-8480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2028
% INFO    : Updated Thermal Rating: on line 2478-1989 : Rate B, Rate C , 0.0, 0.0 -> 4258
% INFO    : Updated Thermal Rating: on line 523-5760 : Rate B, Rate C , 0.0, 0.0 -> 7426
% INFO    : Updated Thermal Rating: on line 523-5760 : Rate B, Rate C , 0.0, 0.0 -> 7495
% INFO    : Updated Thermal Rating: on line 523-5760 : Rate B, Rate C , 0.0, 0.0 -> 7045
% INFO    : Updated Thermal Rating: on line 523-7476 : Rate B, Rate C , 0.0, 0.0 -> 7409
% INFO    : Updated Thermal Rating: on line 69-7852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2115
% INFO    : Updated Thermal Rating: on line 1670-5342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1297
% INFO    : Updated Thermal Rating: on line 9206-4757 : Rate B, Rate C , 0.0, 0.0 -> 1988
% INFO    : Updated Thermal Rating: on line 9206-4757 : Rate B, Rate C , 0.0, 0.0 -> 2141
% INFO    : Updated Thermal Rating: on line 1880-4380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2157
% INFO    : Updated Thermal Rating: on line 3530-1880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9749
% INFO    : Updated Thermal Rating: on line 3530-4687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 3530-1330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on line 7295-8442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12376
% INFO    : Updated Thermal Rating: on line 7297-8442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12458
% INFO    : Updated Thermal Rating: on line 6399-9083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1796
% INFO    : Updated Thermal Rating: on line 898-8668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2525
% INFO    : Updated Thermal Rating: on line 898-6526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 3257-369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60629
% INFO    : Updated Thermal Rating: on line 2381-1020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 2381-297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 2381-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 5829-4692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 5829-69 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7004
% INFO    : Updated Thermal Rating: on line 5829-3898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 702
% INFO    : Updated Thermal Rating: on line 5829-3898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 756
% INFO    : Updated Thermal Rating: on line 5188-5829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1234
% INFO    : Updated Thermal Rating: on line 4272-1205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2199
% INFO    : Updated Thermal Rating: on line 472-6131 : Rate B, Rate C , 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on line 8565-472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 472-5760 : Rate B, Rate C , 0.0, 0.0 -> 9746
% INFO    : Updated Thermal Rating: on line 472-5760 : Rate B, Rate C , 0.0, 0.0 -> 9916
% INFO    : Updated Thermal Rating: on line 472-5760 : Rate B, Rate C , 0.0, 0.0 -> 8979
% INFO    : Updated Thermal Rating: on line 472-7073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2042
% INFO    : Updated Thermal Rating: on line 472-349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 472-7156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1966
% INFO    : Updated Thermal Rating: on line 6202-7305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3263
% INFO    : Updated Thermal Rating: on line 6202-7305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3222
% INFO    : Updated Thermal Rating: on line 643-311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2416
% INFO    : Updated Thermal Rating: on line 6068-6263 : Rate B, Rate C , 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 6017-6263 : Rate B, Rate C , 0.0, 0.0 -> 2382
% INFO    : Updated Thermal Rating: on line 7450-2271 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7450-7666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2799
% INFO    : Updated Thermal Rating: on line 7450-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1041
% INFO    : Updated Thermal Rating: on line 8784-7450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3018
% INFO    : Updated Thermal Rating: on line 2271-3846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142169
% INFO    : Updated Thermal Rating: on line 2271-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1022
% INFO    : Updated Thermal Rating: on line 3846-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1004
% INFO    : Updated Thermal Rating: on line 733-5423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on line 4614-733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 8492-3216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3326
% INFO    : Updated Thermal Rating: on line 2748-3216 : Rate B, Rate C , 0.0, 0.0 -> 2982
% INFO    : Updated Thermal Rating: on line 3215-3216 : Rate B, Rate C , 0.0, 0.0 -> 4156
% INFO    : Updated Thermal Rating: on line 8878-4302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on line 8878-4302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 2760-8016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2582
% INFO    : Updated Thermal Rating: on line 2760-8016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2626
% INFO    : Updated Thermal Rating: on line 1913-2120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8155-1913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2481
% INFO    : Updated Thermal Rating: on line 8155-1913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2527
% INFO    : Updated Thermal Rating: on line 1913-7090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on line 1913-7090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 1913-7844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1151
% INFO    : Updated Thermal Rating: on line 4413-3462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 4413-3462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1597
% INFO    : Updated Thermal Rating: on line 8738-1106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 8738-2760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 920
% INFO    : Updated Thermal Rating: on line 8738-2760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 8738-6218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1352
% INFO    : Updated Thermal Rating: on line 1788-8604 : Rate B, Rate C , 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 1020-2335 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1020-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 2616-1020 : Rate B, Rate C , 0.0, 0.0 -> 3569
% INFO    : Updated Thermal Rating: on line 1020-9072 : Rate B, Rate C , 0.0, 0.0 -> 3645
% INFO    : Updated Thermal Rating: on line 7138-7586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2244
% INFO    : Updated Thermal Rating: on line 2648-8288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3086
% INFO    : Updated Thermal Rating: on line 2824-140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59487
% INFO    : Updated Thermal Rating: on line 2824-5311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1993
% INFO    : Updated Thermal Rating: on line 140-3891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 211-6526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 211-6526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 211-2804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1268
% INFO    : Updated Thermal Rating: on line 1670-3301 : Rate B, Rate C , 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 344-1011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on line 243-8621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3210-5674 : Rate B, Rate C , 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 3210-4337 : Rate B, Rate C , 0.0, 0.0 -> 58496
% INFO    : Updated Thermal Rating: on line 1670-8204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3028
% INFO    : Updated Thermal Rating: on line 1670-1516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2946
% INFO    : Updated Thermal Rating: on line 5949-6480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 5949-5655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 1464-3177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2298
% INFO    : Updated Thermal Rating: on line 5949-6323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1322
% INFO    : Updated Thermal Rating: on line 5949-6323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 1956-4858 : Rate B, Rate C , 0.0, 0.0 -> 63175
% INFO    : Updated Thermal Rating: on line 1956-8264 : Rate B, Rate C , 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on line 4320-4248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58604
% INFO    : Updated Thermal Rating: on line 4320-76 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2236
% INFO    : Updated Thermal Rating: on line 4858-8211 : Rate B, Rate C , 0.0, 0.0 -> 1938
% INFO    : Updated Thermal Rating: on line 4248-38 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1977
% INFO    : Updated Thermal Rating: on line 4302-999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 4302-1010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 4302-1010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1151
% INFO    : Updated Thermal Rating: on line 8204-1516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9475
% INFO    : Updated Thermal Rating: on line 5792-2428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 344-1277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 344-2117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 344-8895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 4132-6526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 4132-1787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 2331-8380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18078
% INFO    : Updated Thermal Rating: on line 5296-8380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6280
% INFO    : Updated Thermal Rating: on line 999-8380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 9029-7915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9029-6149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50125
% INFO    : Updated Thermal Rating: on line 3968-3370 : Rate B, Rate C , 0.0, 0.0 -> 1750
% INFO    : Updated Thermal Rating: on line 7480-2720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2150-6687 : Rate B, Rate C , 0.0, 0.0 -> 1789
% INFO    : Updated Thermal Rating: on line 8956-4209 : Rate B, Rate C , 0.0, 0.0 -> 1828
% INFO    : Updated Thermal Rating: on line 5065-8318 : Rate A, Rate B, Rate C , 1876.0, 0.0, 0.0 -> 1614
% INFO    : Updated Thermal Rating: on line 7270-3370 : Rate B, Rate C , 0.0, 0.0 -> 1582
% INFO    : Updated Thermal Rating: on line 6424-3370 : Rate B, Rate C , 0.0, 0.0 -> 1553
% INFO    : Updated Thermal Rating: on line 5888-8223 : Rate B, Rate C , 0.0, 0.0 -> 12610
% INFO    : Updated Thermal Rating: on line 4776-3370 : Rate B, Rate C , 0.0, 0.0 -> 1523
% INFO    : Updated Thermal Rating: on line 1331-8318 : Rate B, Rate C , 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 8483-8318 : Rate B, Rate C , 0.0, 0.0 -> 1679
% INFO    : Updated Thermal Rating: on line 6687-4209 : Rate B, Rate C , 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 4733-6687 : Rate B, Rate C , 0.0, 0.0 -> 65807
% INFO    : Updated Thermal Rating: on line 7856-4209 : Rate B, Rate C , 0.0, 0.0 -> 67208
% INFO    : Updated Thermal Rating: on line 3370-5897 : Rate B, Rate C , 0.0, 0.0 -> 68669
% INFO    : Updated Thermal Rating: on line 3370-420 : Rate B, Rate C , 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 3370-8898 : Rate B, Rate C , 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 8318-7856 : Rate B, Rate C , 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 8318-4733 : Rate B, Rate C , 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 8318-8898 : Rate B, Rate C , 0.0, 0.0 -> 58496
% INFO    : Updated Thermal Rating: on line 5897-4087 : Rate B, Rate C , 0.0, 0.0 -> 63175
% INFO    : Updated Thermal Rating: on line 4087-7856 : Rate B, Rate C , 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 4087-4077 : Rate B, Rate C , 0.0, 0.0 -> 7820
% INFO    : Updated Thermal Rating: on line 6283-4087 : Rate B, Rate C , 0.0, 0.0 -> 7966
% INFO    : Updated Thermal Rating: on line 420-2927 : Rate B, Rate C , 0.0, 0.0 -> 65807
% INFO    : Updated Thermal Rating: on line 2927-4733 : Rate B, Rate C , 0.0, 0.0 -> 67208
% INFO    : Updated Thermal Rating: on line 2927-5888 : Rate B, Rate C , 0.0, 0.0 -> 7996
% INFO    : Updated Thermal Rating: on line 4485-2927 : Rate B, Rate C , 0.0, 0.0 -> 7810
% INFO    : Updated Thermal Rating: on line 2720-243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 243-558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8492-2748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1486
% INFO    : Updated Thermal Rating: on line 8492-3215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2710
% INFO    : Updated Thermal Rating: on line 5760-8392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17144
% INFO    : Updated Thermal Rating: on line 5760-8392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16976
% INFO    : Updated Thermal Rating: on line 5760-8392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18102
% INFO    : Updated Thermal Rating: on line 370-311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2362
% INFO    : Updated Thermal Rating: on line 370-311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2126
% INFO    : Updated Thermal Rating: on line 1106-2552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6539
% INFO    : Updated Thermal Rating: on line 1106-7275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2688
% INFO    : Updated Thermal Rating: on line 1106-6218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 815
% INFO    : Updated Thermal Rating: on line 9206-1936 : Rate B, Rate C , 0.0, 0.0 -> 4392
% INFO    : Updated Thermal Rating: on line 7476-1936 : Rate B, Rate C , 0.0, 0.0 -> 4473
% INFO    : Updated Thermal Rating: on line 4415-9146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 4415-9146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 7729-4415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on line 5591-5364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3726
% INFO    : Updated Thermal Rating: on line 6047-4431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 6047-4431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on line 8017-6519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7018-8017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6511
% INFO    : Updated Thermal Rating: on line 2965-1260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 344-5364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4845
% INFO    : Updated Thermal Rating: on line 344-5364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4307
% INFO    : Updated Thermal Rating: on line 5311-3891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63175
% INFO    : Updated Thermal Rating: on line 9205-8668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 8668-6526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 7666-377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 7666-1227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 7666-4006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 5872-7666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2883
% INFO    : Updated Thermal Rating: on line 6058-1889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 6058-1889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 4272-6747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 4272-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 910
% INFO    : Updated Thermal Rating: on line 4272-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 928
% INFO    : Updated Thermal Rating: on line 4272-7951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 873
% INFO    : Updated Thermal Rating: on line 4272-7951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 4272-8792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1181
% INFO    : Updated Thermal Rating: on line 4272-8792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1204
% INFO    : Updated Thermal Rating: on line 4272-8792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1228
% INFO    : Updated Thermal Rating: on line 3898-1330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1221
% INFO    : Updated Thermal Rating: on line 8613-52 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1653
% INFO    : Updated Thermal Rating: on line 662-3352 : Rate B, Rate C , 0.0, 0.0 -> 68669
% INFO    : Updated Thermal Rating: on line 662-6766 : Rate B, Rate C , 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 6017-3352 : Rate B, Rate C , 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 6017-6766 : Rate B, Rate C , 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 2552-7275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32900
% INFO    : Updated Thermal Rating: on line 8792-3712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 3388-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1362-2523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 1362-1052 : Rate B, Rate C , 0.0, 0.0 -> 1396
% INFO    : Updated Thermal Rating: on line 1362-76 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2464
% INFO    : Updated Thermal Rating: on line 2523-3878 : Rate B, Rate C , 0.0, 0.0 -> 1426
% INFO    : Updated Thermal Rating: on line 2523-38 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2514
% INFO    : Updated Thermal Rating: on line 194-7018 : Rate B, Rate C , 0.0, 0.0 -> 2240
% INFO    : Updated Thermal Rating: on line 4846-7018 : Rate B, Rate C , 0.0, 0.0 -> 2289
% INFO    : Updated Thermal Rating: on line 3691-7018 : Rate B, Rate C , 0.0, 0.0 -> 2339
% INFO    : Updated Thermal Rating: on line 6323-539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on line 6323-539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1306
% INFO    : Updated Thermal Rating: on line 5872-6707 : Rate B, Rate C , 0.0, 0.0 -> 15892
% INFO    : Updated Thermal Rating: on line 4863-6707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17637
% INFO    : Updated Thermal Rating: on line 5872-3509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7638
% INFO    : Updated Thermal Rating: on line 5872-3509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7011
% INFO    : Updated Thermal Rating: on line 5872-3776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11524
% INFO    : Updated Thermal Rating: on line 7018-3509 : Rate B, Rate C , 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7018-5974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 8784-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5467
% INFO    : Updated Thermal Rating: on line 7018-4565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2308
% INFO    : Updated Thermal Rating: on line 8058-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6522
% INFO    : Updated Thermal Rating: on line 3509-4863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18040
% INFO    : Updated Thermal Rating: on line 3776-3509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18462
% INFO    : Updated Thermal Rating: on line 4082-6442 : Rate B, Rate C , 0.0, 0.0 -> 6902
% INFO    : Updated Thermal Rating: on line 5246-6442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6774
% INFO    : Updated Thermal Rating: on line 6526-1787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1070
% INFO    : Updated Thermal Rating: on line 4616-7260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 1221-7996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 344-1221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 344-1221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on line 8525-2698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on line 3215-7407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 4686-7729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 52-2494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 52-9007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4778
% INFO    : Updated Thermal Rating: on line 52-928 : Rate B, Rate C , 0.0, 0.0 -> 5704
% INFO    : Updated Thermal Rating: on line 52-928 : Rate B, Rate C , 0.0, 0.0 -> 5754
% INFO    : Updated Thermal Rating: on line 6987-4509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1061
% INFO    : Updated Thermal Rating: on line 6987-4509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on line 3119-6047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2460
% INFO    : Updated Thermal Rating: on line 3119-6047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2417
% INFO    : Updated Thermal Rating: on line 3119-7662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6149-5442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6275-3819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 344-6015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 9083-994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 9206-3169 : Rate B, Rate C , 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 9206-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2359
% INFO    : Updated Thermal Rating: on line 9206-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2397
% INFO    : Updated Thermal Rating: on line 9206-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1696
% INFO    : Updated Thermal Rating: on line 5423-9223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 3314-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 838-7779 : Rate B, Rate C , 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 838-4477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6320-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4774-3620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5869
% INFO    : Updated Thermal Rating: on line 3182-297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 884
% INFO    : Updated Thermal Rating: on line 7476-1463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5906
% INFO    : Updated Thermal Rating: on line 7476-1463 : Rate B, Rate C , 0.0, 0.0 -> 6314
% INFO    : Updated Thermal Rating: on line 1052-3878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65945
% INFO    : Updated Thermal Rating: on line 1052-6477 : Rate B, Rate C , 0.0, 0.0 -> 1997
% INFO    : Updated Thermal Rating: on line 3878-5295 : Rate B, Rate C , 0.0, 0.0 -> 2141
% INFO    : Updated Thermal Rating: on line 8277-5887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1111
% INFO    : Updated Thermal Rating: on line 8277-9127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 76-38 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67351
% INFO    : Updated Thermal Rating: on line 3182-1984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 2760-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on line 2760-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1260
% INFO    : Updated Thermal Rating: on line 9127-5887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1469
% INFO    : Updated Thermal Rating: on line 4082-5246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4485-395 : Rate B, Rate C , 0.0, 0.0 -> 20958
% INFO    : Updated Thermal Rating: on line 5843-6283 : Rate B, Rate C , 0.0, 0.0 -> 20835
% INFO    : Updated Thermal Rating: on line 2478-8480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 395-5843 : Rate B, Rate C , 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 6477-5295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68520
% INFO    : Updated Thermal Rating: on line 8264-8211 : Rate B, Rate C , 0.0, 0.0 -> 58496
% INFO    : Updated Thermal Rating: on line 7011-4614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5165
% INFO    : Updated Thermal Rating: on line 4614-7011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4920
% INFO    : Updated Thermal Rating: on line 6058-7011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1616
% INFO    : Updated Thermal Rating: on line 6058-7011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1687
% INFO    : Updated Thermal Rating: on line 6058-9223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 6058-9223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on line 7090-7844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2616-559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59712
% INFO    : Updated Thermal Rating: on line 9072-559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 2305-9072 : Rate B, Rate C , 0.0, 0.0 -> 1003
% INFO    : Updated Thermal Rating: on line 3341-4259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 3341-4259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 5805-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4263
% INFO    : Updated Thermal Rating: on line 5805-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4272
% INFO    : Updated Thermal Rating: on line 5805-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3920
% INFO    : Updated Thermal Rating: on line 5452-2734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 5452-5274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on line 7879-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 7879-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 7879-7569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 706
% INFO    : Updated Thermal Rating: on line 8098-2734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 8098-7358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 598
% INFO    : Updated Thermal Rating: on line 8098-7358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 8098-7358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 8098-1407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 819
% INFO    : Updated Thermal Rating: on line 2233-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 758
% INFO    : Updated Thermal Rating: on line 2233-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on line 2233-3429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2697
% INFO    : Updated Thermal Rating: on line 2233-3429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2096
% INFO    : Updated Thermal Rating: on line 2233-610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3971
% INFO    : Updated Thermal Rating: on line 2233-948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1411
% INFO    : Updated Thermal Rating: on line 2233-2954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3911
% INFO    : Updated Thermal Rating: on line 4721-610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 946
% INFO    : Updated Thermal Rating: on line 4721-2140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 925
% INFO    : Updated Thermal Rating: on line 4721-6512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1049
% INFO    : Updated Thermal Rating: on line 4721-948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on line 8789-2734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 8789-2734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 8789-5274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on line 8789-4116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 8789-4868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 8789-7358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 8789-6329 : Rate B, Rate C , 0.0, 0.0 -> 1862
% INFO    : Updated Thermal Rating: on line 8789-2817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 702-8927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 5517-1862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 5517-8629 : Rate B, Rate C , 0.0, 0.0 -> 3523
% INFO    : Updated Thermal Rating: on line 5517-552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2575
% INFO    : Updated Thermal Rating: on line 5517-552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 898
% INFO    : Updated Thermal Rating: on line 5517-3791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 554
% INFO    : Updated Thermal Rating: on line 4344-6512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 2734-6188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 2734-6188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 2734-3413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 6188-1407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1790
% INFO    : Updated Thermal Rating: on line 5006-1250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 611
% INFO    : Updated Thermal Rating: on line 5006-5331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2130
% INFO    : Updated Thermal Rating: on line 5006-5927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1172
% INFO    : Updated Thermal Rating: on line 5006-4771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 5006-2660 : Rate B, Rate C , 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 1862-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1262
% INFO    : Updated Thermal Rating: on line 1862-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on line 1862-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 843
% INFO    : Updated Thermal Rating: on line 1862-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 4116-2140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 4868-7358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 1250-5927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on line 1250-4771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 684
% INFO    : Updated Thermal Rating: on line 1250-8278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 2407-3711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1278
% INFO    : Updated Thermal Rating: on line 2407-3711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1290
% INFO    : Updated Thermal Rating: on line 2407-7411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 2407-4277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2572
% INFO    : Updated Thermal Rating: on line 2407-987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 2407-2206 : Rate B, Rate C , 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 8197-39 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5568
% INFO    : Updated Thermal Rating: on line 8197-3711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 854
% INFO    : Updated Thermal Rating: on line 8197-7792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 8197-1685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15180
% INFO    : Updated Thermal Rating: on line 8197-2894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1039
% INFO    : Updated Thermal Rating: on line 8197-4277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1401
% INFO    : Updated Thermal Rating: on line 8197-987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1239
% INFO    : Updated Thermal Rating: on line 552-3711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 6504-1543 : Rate B, Rate C , 0.0, 0.0 -> 1262
% INFO    : Updated Thermal Rating: on line 6504-7041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1542
% INFO    : Updated Thermal Rating: on line 6504-3585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53419
% INFO    : Updated Thermal Rating: on line 6504-780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46965
% INFO    : Updated Thermal Rating: on line 6504-3957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46430
% INFO    : Updated Thermal Rating: on line 2692-6254 : Rate B, Rate C , 0.0, 0.0 -> 2757
% INFO    : Updated Thermal Rating: on line 2692-8957 : Rate B, Rate C , 0.0, 0.0 -> 50503
% INFO    : Updated Thermal Rating: on line 2692-8861 : Rate B, Rate C , 0.0, 0.0 -> 51129
% INFO    : Updated Thermal Rating: on line 2692-1734 : Rate B, Rate C , 0.0, 0.0 -> 51675
% INFO    : Updated Thermal Rating: on line 2692-3266 : Rate B, Rate C , 0.0, 0.0 -> 46965
% INFO    : Updated Thermal Rating: on line 322-1974 : Rate B, Rate C , 0.0, 0.0 -> 2258
% INFO    : Updated Thermal Rating: on line 322-1974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8043
% INFO    : Updated Thermal Rating: on line 322-177 : Rate B, Rate C , 0.0, 0.0 -> 1767
% INFO    : Updated Thermal Rating: on line 5662-5333 : Rate B, Rate C , 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 5662-7901 : Rate B, Rate C , 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 5662-7041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3408
% INFO    : Updated Thermal Rating: on line 5662-2006 : Rate B, Rate C , 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on line 5662-7761 : Rate B, Rate C , 0.0, 0.0 -> 1158
% INFO    : Updated Thermal Rating: on line 5662-5559 : Rate B, Rate C , 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 5662-3211 : Rate B, Rate C , 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 5662-8963 : Rate B, Rate C , 0.0, 0.0 -> 1948
% INFO    : Updated Thermal Rating: on line 5662-1770 : Rate B, Rate C , 0.0, 0.0 -> 1191
% INFO    : Updated Thermal Rating: on line 3186-1109 : Rate B, Rate C , 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 3186-1109 : Rate B, Rate C , 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on line 3186-8493 : Rate B, Rate C , 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 3186-6280 : Rate B, Rate C , 0.0, 0.0 -> 34869
% INFO    : Updated Thermal Rating: on line 3186-3987 : Rate B, Rate C , 0.0, 0.0 -> 2822
% INFO    : Updated Thermal Rating: on line 1974-5825 : Rate B, Rate C , 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 1974-7252 : Rate B, Rate C , 0.0, 0.0 -> 3550
% INFO    : Updated Thermal Rating: on line 1974-7252 : Rate B, Rate C , 0.0, 0.0 -> 18766
% INFO    : Updated Thermal Rating: on line 1974-177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2954
% INFO    : Updated Thermal Rating: on line 2410-2006 : Rate B, Rate C , 0.0, 0.0 -> 1147
% INFO    : Updated Thermal Rating: on line 2410-2006 : Rate B, Rate C , 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on line 2410-315 : Rate B, Rate C , 0.0, 0.0 -> 3002
% INFO    : Updated Thermal Rating: on line 2410-1489 : Rate B, Rate C , 0.0, 0.0 -> 2956
% INFO    : Updated Thermal Rating: on line 8926-5797 : Rate B, Rate C , 0.0, 0.0 -> 3557
% INFO    : Updated Thermal Rating: on line 8926-6381 : Rate B, Rate C , 0.0, 0.0 -> 11743
% INFO    : Updated Thermal Rating: on line 8926-6381 : Rate B, Rate C , 0.0, 0.0 -> 11868
% INFO    : Updated Thermal Rating: on line 8926-1239 : Rate B, Rate C , 0.0, 0.0 -> 3867
% INFO    : Updated Thermal Rating: on line 8926-5643 : Rate B, Rate C , 0.0, 0.0 -> 123896
% INFO    : Updated Thermal Rating: on line 5672-7901 : Rate B, Rate C , 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 5672-6415 : Rate B, Rate C , 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 5672-6415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 5672-8998 : Rate B, Rate C , 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on line 5333-6795 : Rate B, Rate C , 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 5333-6795 : Rate B, Rate C , 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on line 5333-3211 : Rate B, Rate C , 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 6795-3054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 6795-3054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on line 6795-2562 : Rate B, Rate C , 0.0, 0.0 -> 971
% INFO    : Updated Thermal Rating: on line 3054-6254 : Rate B, Rate C , 0.0, 0.0 -> 1453
% INFO    : Updated Thermal Rating: on line 3054-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2065
% INFO    : Updated Thermal Rating: on line 3054-8957 : Rate B, Rate C , 0.0, 0.0 -> 1172
% INFO    : Updated Thermal Rating: on line 3054-3266 : Rate B, Rate C , 0.0, 0.0 -> 1347
% INFO    : Updated Thermal Rating: on line 3054-7615 : Rate B, Rate C , 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on line 5825-177 : Rate B, Rate C , 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on line 5825-6415 : Rate B, Rate C , 0.0, 0.0 -> 1057
% INFO    : Updated Thermal Rating: on line 5825-4744 : Rate B, Rate C , 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 5825-5669 : Rate B, Rate C , 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 5825-3416 : Rate B, Rate C , 0.0, 0.0 -> 16463
% INFO    : Updated Thermal Rating: on line 7901-6415 : Rate B, Rate C , 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 7901-7503 : Rate B, Rate C , 0.0, 0.0 -> 1616
% INFO    : Updated Thermal Rating: on line 8459-177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3496
% INFO    : Updated Thermal Rating: on line 8459-8998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6784
% INFO    : Updated Thermal Rating: on line 8459-5361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3122
% INFO    : Updated Thermal Rating: on line 6254-5797 : Rate B, Rate C , 0.0, 0.0 -> 1922
% INFO    : Updated Thermal Rating: on line 6254-5797 : Rate B, Rate C , 0.0, 0.0 -> 2511
% INFO    : Updated Thermal Rating: on line 6254-9136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3954
% INFO    : Updated Thermal Rating: on line 6254-4650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3487
% INFO    : Updated Thermal Rating: on line 6254-7037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3026
% INFO    : Updated Thermal Rating: on line 6254-2497 : Rate B, Rate C , 0.0, 0.0 -> 1927
% INFO    : Updated Thermal Rating: on line 6254-8861 : Rate B, Rate C , 0.0, 0.0 -> 1757
% INFO    : Updated Thermal Rating: on line 6254-1734 : Rate B, Rate C , 0.0, 0.0 -> 2924
% INFO    : Updated Thermal Rating: on line 3478-3211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9816
% INFO    : Updated Thermal Rating: on line 7252-7236 : Rate B, Rate C , 0.0, 0.0 -> 2889
% INFO    : Updated Thermal Rating: on line 5797-3954 : Rate B, Rate C , 0.0, 0.0 -> 17448
% INFO    : Updated Thermal Rating: on line 5797-5643 : Rate B, Rate C , 0.0, 0.0 -> 5262
% INFO    : Updated Thermal Rating: on line 6960-2562 : Rate B, Rate C , 0.0, 0.0 -> 856
% INFO    : Updated Thermal Rating: on line 6960-7037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6859
% INFO    : Updated Thermal Rating: on line 6960-5643 : Rate B, Rate C , 0.0, 0.0 -> 3711
% INFO    : Updated Thermal Rating: on line 177-2460 : Rate B, Rate C , 0.0, 0.0 -> 1790
% INFO    : Updated Thermal Rating: on line 177-4744 : Rate B, Rate C , 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 177-6311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5184
% INFO    : Updated Thermal Rating: on line 177-5361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5827
% INFO    : Updated Thermal Rating: on line 177-7236 : Rate B, Rate C , 0.0, 0.0 -> 2256
% INFO    : Updated Thermal Rating: on line 3954-2497 : Rate B, Rate C , 0.0, 0.0 -> 20641
% INFO    : Updated Thermal Rating: on line 2460-6415 : Rate B, Rate C , 0.0, 0.0 -> 2941
% INFO    : Updated Thermal Rating: on line 380-5339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 380-5669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1682
% INFO    : Updated Thermal Rating: on line 1848-3932 : Rate B, Rate C , 0.0, 0.0 -> 724
% INFO    : Updated Thermal Rating: on line 1848-5094 : Rate B, Rate C , 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 1848-3623 : Rate B, Rate C , 0.0, 0.0 -> 2871
% INFO    : Updated Thermal Rating: on line 1848-785 : Rate B, Rate C , 0.0, 0.0 -> 2926
% INFO    : Updated Thermal Rating: on line 1848-1036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1521
% INFO    : Updated Thermal Rating: on line 8021-698 : Rate B, Rate C , 0.0, 0.0 -> 1603
% INFO    : Updated Thermal Rating: on line 8021-628 : Rate A, Rate B, Rate C , 495.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 1109-315 : Rate B, Rate C , 0.0, 0.0 -> 1520
% INFO    : Updated Thermal Rating: on line 1109-1489 : Rate B, Rate C , 0.0, 0.0 -> 1503
% INFO    : Updated Thermal Rating: on line 1109-3932 : Rate B, Rate C , 0.0, 0.0 -> 2240
% INFO    : Updated Thermal Rating: on line 1109-5094 : Rate B, Rate C , 0.0, 0.0 -> 2287
% INFO    : Updated Thermal Rating: on line 6415-5669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on line 6415-8493 : Rate B, Rate C , 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on line 6415-8493 : Rate B, Rate C , 0.0, 0.0 -> 1246
% INFO    : Updated Thermal Rating: on line 7503-5559 : Rate B, Rate C , 0.0, 0.0 -> 5786
% INFO    : Updated Thermal Rating: on line 7041-2006 : Rate A, Rate B, Rate C , 553.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 4712-3623 : Rate B, Rate C , 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 4712-785 : Rate B, Rate C , 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 5339-4170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 813
% INFO    : Updated Thermal Rating: on line 4170-698 : Rate B, Rate C , 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on line 4170-698 : Rate B, Rate C , 0.0, 0.0 -> 1181
% INFO    : Updated Thermal Rating: on line 4170-4333 : Rate B, Rate C , 0.0, 0.0 -> 1404
% INFO    : Updated Thermal Rating: on line 4170-4333 : Rate B, Rate C , 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on line 2006-8963 : Rate B, Rate C , 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on line 2006-7661 : Rate B, Rate C , 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on line 8493-628 : Rate B, Rate C , 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on line 8493-628 : Rate B, Rate C , 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 130-3080 : Rate B, Rate C , 0.0, 0.0 -> 2543
% INFO    : Updated Thermal Rating: on line 130-536 : Rate B, Rate C , 0.0, 0.0 -> 2249
% INFO    : Updated Thermal Rating: on line 130-4393 : Rate B, Rate C , 0.0, 0.0 -> 2287
% INFO    : Updated Thermal Rating: on line 7827-7969 : Rate B, Rate C , 0.0, 0.0 -> 8606
% INFO    : Updated Thermal Rating: on line 7827-6760 : Rate B, Rate C , 0.0, 0.0 -> 6190
% INFO    : Updated Thermal Rating: on line 1025-6298 : Rate B, Rate C , 0.0, 0.0 -> 1997
% INFO    : Updated Thermal Rating: on line 1025-3007 : Rate B, Rate C , 0.0, 0.0 -> 8436
% INFO    : Updated Thermal Rating: on line 1025-3265 : Rate B, Rate C , 0.0, 0.0 -> 3931
% INFO    : Updated Thermal Rating: on line 1339-3265 : Rate B, Rate C , 0.0, 0.0 -> 1474
% INFO    : Updated Thermal Rating: on line 1339-1774 : Rate B, Rate C , 0.0, 0.0 -> 2582
% INFO    : Updated Thermal Rating: on line 1339-2899 : Rate B, Rate C , 0.0, 0.0 -> 1940
% INFO    : Updated Thermal Rating: on line 1339-1703 : Rate B, Rate C , 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 441-8088 : Rate B, Rate C , 0.0, 0.0 -> 6031
% INFO    : Updated Thermal Rating: on line 441-3265 : Rate B, Rate C , 0.0, 0.0 -> 1756
% INFO    : Updated Thermal Rating: on line 6298-1774 : Rate B, Rate C , 0.0, 0.0 -> 1590
% INFO    : Updated Thermal Rating: on line 6298-2899 : Rate B, Rate C , 0.0, 0.0 -> 1564
% INFO    : Updated Thermal Rating: on line 8088-3080 : Rate B, Rate C , 0.0, 0.0 -> 1320
% INFO    : Updated Thermal Rating: on line 8088-544 : Rate B, Rate C , 0.0, 0.0 -> 9877
% INFO    : Updated Thermal Rating: on line 8088-7079 : Rate B, Rate C , 0.0, 0.0 -> 23777
% INFO    : Updated Thermal Rating: on line 8088-8601 : Rate B, Rate C , 0.0, 0.0 -> 20968
% INFO    : Updated Thermal Rating: on line 8088-1155 : Rate B, Rate C , 0.0, 0.0 -> 20572
% INFO    : Updated Thermal Rating: on line 8088-3256 : Rate B, Rate C , 0.0, 0.0 -> 20179
% INFO    : Updated Thermal Rating: on line 8088-5815 : Rate B, Rate C , 0.0, 0.0 -> 7008
% INFO    : Updated Thermal Rating: on line 8088-5815 : Rate B, Rate C , 0.0, 0.0 -> 7142
% INFO    : Updated Thermal Rating: on line 3080-1899 : Rate B, Rate C , 0.0, 0.0 -> 1582
% INFO    : Updated Thermal Rating: on line 3080-9032 : Rate B, Rate C , 0.0, 0.0 -> 13394
% INFO    : Updated Thermal Rating: on line 3080-6004 : Rate B, Rate C , 0.0, 0.0 -> 13175
% INFO    : Updated Thermal Rating: on line 3080-7810 : Rate B, Rate C , 0.0, 0.0 -> 1961
% INFO    : Updated Thermal Rating: on line 3080-8630 : Rate B, Rate C , 0.0, 0.0 -> 12430
% INFO    : Updated Thermal Rating: on line 3080-8183 : Rate B, Rate C , 0.0, 0.0 -> 12894
% INFO    : Updated Thermal Rating: on line 3080-6390 : Rate B, Rate C , 0.0, 0.0 -> 13145
% INFO    : Updated Thermal Rating: on line 8224-7969 : Rate B, Rate C , 0.0, 0.0 -> 5149
% INFO    : Updated Thermal Rating: on line 8224-7969 : Rate B, Rate C , 0.0, 0.0 -> 3733
% INFO    : Updated Thermal Rating: on line 8224-7860 : Rate B, Rate C , 0.0, 0.0 -> 2325
% INFO    : Updated Thermal Rating: on line 8224-6187 : Rate B, Rate C , 0.0, 0.0 -> 6953
% INFO    : Updated Thermal Rating: on line 3007-3265 : Rate B, Rate C , 0.0, 0.0 -> 5928
% INFO    : Updated Thermal Rating: on line 3007-544 : Rate B, Rate C , 0.0, 0.0 -> 2197
% INFO    : Updated Thermal Rating: on line 3007-7810 : Rate B, Rate C , 0.0, 0.0 -> 1853
% INFO    : Updated Thermal Rating: on line 4807-6187 : Rate B, Rate C , 0.0, 0.0 -> 3585
% INFO    : Updated Thermal Rating: on line 4807-6760 : Rate B, Rate C , 0.0, 0.0 -> 3148
% INFO    : Updated Thermal Rating: on line 4807-4926 : Rate B, Rate C , 0.0, 0.0 -> 4127
% INFO    : Updated Thermal Rating: on line 7969-1703 : Rate B, Rate C , 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on line 7969-2031 : Rate B, Rate C , 0.0, 0.0 -> 2520
% INFO    : Updated Thermal Rating: on line 7969-7980 : Rate B, Rate C , 0.0, 0.0 -> 5194
% INFO    : Updated Thermal Rating: on line 7969-6760 : Rate B, Rate C , 0.0, 0.0 -> 3851
% INFO    : Updated Thermal Rating: on line 536-7509 : Rate B, Rate C , 0.0, 0.0 -> 3148
% INFO    : Updated Thermal Rating: on line 536-3990 : Rate B, Rate C , 0.0, 0.0 -> 4691
% INFO    : Updated Thermal Rating: on line 1774-1703 : Rate B, Rate C , 0.0, 0.0 -> 2461
% INFO    : Updated Thermal Rating: on line 1774-7980 : Rate A, Rate B, Rate C , 1382.0, 0.0, 0.0 -> 1273
% INFO    : Updated Thermal Rating: on line 1774-4543 : Rate B, Rate C , 0.0, 0.0 -> 12907
% INFO    : Updated Thermal Rating: on line 1774-6340 : Rate B, Rate C , 0.0, 0.0 -> 12704
% INFO    : Updated Thermal Rating: on line 1774-261 : Rate B, Rate C , 0.0, 0.0 -> 28598
% INFO    : Updated Thermal Rating: on line 1774-2058 : Rate B, Rate C , 0.0, 0.0 -> 29098
% INFO    : Updated Thermal Rating: on line 7860-6187 : Rate B, Rate C , 0.0, 0.0 -> 3853
% INFO    : Updated Thermal Rating: on line 6080-2899 : Rate B, Rate C , 0.0, 0.0 -> 3658
% INFO    : Updated Thermal Rating: on line 6080-7509 : Rate A, Rate B, Rate C , 1547.0, 0.0, 0.0 -> 1407
% INFO    : Updated Thermal Rating: on line 2899-5263 : Rate B, Rate C , 0.0, 0.0 -> 131160
% INFO    : Updated Thermal Rating: on line 1703-138 : Rate B, Rate C , 0.0, 0.0 -> 2366
% INFO    : Updated Thermal Rating: on line 1899-5562 : Rate B, Rate C , 0.0, 0.0 -> 2259
% INFO    : Updated Thermal Rating: on line 138-2031 : Rate B, Rate C , 0.0, 0.0 -> 2136
% INFO    : Updated Thermal Rating: on line 4704-2031 : Rate A, Rate B, Rate C , 1514.0, 0.0, 0.0 -> 1411
% INFO    : Updated Thermal Rating: on line 4704-1570 : Rate B, Rate C , 0.0, 0.0 -> 5503
% INFO    : Updated Thermal Rating: on line 2031-1999 : Rate B, Rate C , 0.0, 0.0 -> 150416
% INFO    : Updated Thermal Rating: on line 7509-3990 : Rate B, Rate C , 0.0, 0.0 -> 3344
% INFO    : Updated Thermal Rating: on line 7509-7935 : Rate B, Rate C , 0.0, 0.0 -> 6422
% INFO    : Updated Thermal Rating: on line 7509-7935 : Rate B, Rate C , 0.0, 0.0 -> 6547
% INFO    : Updated Thermal Rating: on line 39-1174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2138
% INFO    : Updated Thermal Rating: on line 1174-3711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1206
% INFO    : Updated Thermal Rating: on line 389-4259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1652
% INFO    : Updated Thermal Rating: on line 3711-7411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3711-2894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34509
% INFO    : Updated Thermal Rating: on line 8771-7792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141820
% INFO    : Updated Thermal Rating: on line 6459-7411 : Rate B, Rate C , 0.0, 0.0 -> 2134
% INFO    : Updated Thermal Rating: on line 4013-610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3944
% INFO    : Updated Thermal Rating: on line 4013-4577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10566
% INFO    : Updated Thermal Rating: on line 4013-8007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95764
% INFO    : Updated Thermal Rating: on line 2853-5331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27645
% INFO    : Updated Thermal Rating: on line 6512-304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2319
% INFO    : Updated Thermal Rating: on line 7569-6135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 943
% INFO    : Updated Thermal Rating: on line 5927-6540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5693
% INFO    : Updated Thermal Rating: on line 698-7104 : Rate B, Rate C , 0.0, 0.0 -> 2517
% INFO    : Updated Thermal Rating: on line 698-7104 : Rate B, Rate C , 0.0, 0.0 -> 2282
% INFO    : Updated Thermal Rating: on line 698-4333 : Rate B, Rate C , 0.0, 0.0 -> 1931
% INFO    : Updated Thermal Rating: on line 8998-6311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6644
% INFO    : Updated Thermal Rating: on line 7761-1770 : Rate B, Rate C , 0.0, 0.0 -> 59725
% INFO    : Updated Thermal Rating: on line 6311-5361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73269
% INFO    : Updated Thermal Rating: on line 1770-7709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5225
% INFO    : Updated Thermal Rating: on line 1489-5790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6519
% INFO    : Updated Thermal Rating: on line 5094-5266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51867
% INFO    : Updated Thermal Rating: on line 3623-7927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18122
% INFO    : Updated Thermal Rating: on line 7236-4098 : Rate B, Rate C , 0.0, 0.0 -> 19594
% INFO    : Updated Thermal Rating: on line 5815-3990 : Rate B, Rate C , 0.0, 0.0 -> 2279
% INFO    : Updated Thermal Rating: on line 7329-7661 : Rate B, Rate C , 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on transformer 9024-6542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on transformer 9024-6542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on transformer 6069-9192 : Rate A, Rate B, Rate C , 691.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on transformer 6069-1968 : Rate B, Rate C , 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on transformer 7829-1968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 8574-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 8574-5587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on transformer 4929-1815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on transformer 1815-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 6704-4586 : Rate A, Rate B, Rate C , 658.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on transformer 2441-3506 : Rate B, Rate C , 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on transformer 1367-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on transformer 1676-228 : Rate A, Rate B, Rate C , 658.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on transformer 7829-6826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on transformer 659-3279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 650
% INFO    : Updated Thermal Rating: on transformer 5210-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on transformer 1445-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 653
% INFO    : Updated Thermal Rating: on transformer 7180-2168 : Rate B, Rate C , 0.0, 0.0 -> 733
% INFO    : Updated Thermal Rating: on transformer 6833-8964 : Rate B, Rate C , 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on transformer 3659-3242 : Rate A, Rate B, Rate C , 691.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on transformer 8181-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 643
% INFO    : Updated Thermal Rating: on transformer 9025-7563 : Rate A, Rate B, Rate C , 658.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on transformer 2267-5210 : Rate B, Rate C , 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 5210-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 5210-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on transformer 5210-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on transformer 5210-4665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 5210-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 8179-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on transformer 1445-7279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 5509-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on transformer 5509-1531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on transformer 1445-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on transformer 7762-5155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on transformer 7762-271 : Rate A, Rate B, Rate C , 691.0, 0.0, 0.0 -> 662
% INFO    : Updated Thermal Rating: on transformer 7829-5776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on transformer 8329-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on transformer 8329-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on transformer 1445-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 1445-4665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 2268-2908 : Rate A, Rate B, Rate C , 724.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on transformer 8847-5776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on transformer 8847-8103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on transformer 317-2449 : Rate A, Rate B, Rate C , 658.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on transformer 7637-8581 : Rate B, Rate C , 0.0, 0.0 -> 2038
% INFO    : Updated Thermal Rating: on transformer 5848-7526 : Rate B, Rate C , 0.0, 0.0 -> 3280
% INFO    : Updated Thermal Rating: on transformer 89-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on transformer 2520-4665 : Rate B, Rate C , 0.0, 0.0 -> 705
% INFO    : Updated Thermal Rating: on transformer 5996-8420 : Rate B, Rate C , 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on transformer 2154-5996 : Rate B, Rate C , 0.0, 0.0 -> 3191
% INFO    : Updated Thermal Rating: on transformer 4241-2248 : Rate B, Rate C , 0.0, 0.0 -> 1737
% INFO    : Updated Thermal Rating: on transformer 4717-5787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1091
% INFO    : Updated Thermal Rating: on transformer 5425-7431 : Rate B, Rate C , 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on transformer 5425-7431 : Rate B, Rate C , 0.0, 0.0 -> 1622
% INFO    : Updated Thermal Rating: on transformer 6632-3650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 755
% INFO    : Updated Thermal Rating: on transformer 6632-3650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1242
% INFO    : Updated Thermal Rating: on transformer 6917-4958 : Rate B, Rate C , 0.0, 0.0 -> 1521
% INFO    : Updated Thermal Rating: on transformer 2962-8888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on transformer 2962-8888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1280
% INFO    : Updated Thermal Rating: on transformer 4542-7510 : Rate B, Rate C , 0.0, 0.0 -> 1541
% INFO    : Updated Thermal Rating: on transformer 4542-7510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 1549-3282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 1549-3282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on transformer 1549-3282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1111
% INFO    : Updated Thermal Rating: on transformer 1200-3549 : Rate B, Rate C , 0.0, 0.0 -> 1579
% INFO    : Updated Thermal Rating: on transformer 6771-4806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1030
% INFO    : Updated Thermal Rating: on transformer 1086-6443 : Rate B, Rate C , 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on transformer 1086-6443 : Rate B, Rate C , 0.0, 0.0 -> 1591
% INFO    : Updated Thermal Rating: on transformer 9159-6499 : Rate B, Rate C , 0.0, 0.0 -> 1640
% INFO    : Updated Thermal Rating: on transformer 9159-6499 : Rate B, Rate C , 0.0, 0.0 -> 1706
% INFO    : Updated Thermal Rating: on transformer 5685-3378 : Rate B, Rate C , 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on transformer 693-6994 : Rate B, Rate C , 0.0, 0.0 -> 1685
% INFO    : Updated Thermal Rating: on transformer 693-6994 : Rate B, Rate C , 0.0, 0.0 -> 1919
% INFO    : Updated Thermal Rating: on transformer 5332-3633 : Rate B, Rate C , 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on transformer 5332-3633 : Rate B, Rate C , 0.0, 0.0 -> 1258
% INFO    : Updated Thermal Rating: on line 8034-4020 : Rate B, Rate C , 0.0, 0.0 -> 5702
% INFO    : Updated Thermal Rating: on transformer 1985-1023 : Rate B, Rate C , 0.0, 0.0 -> 5110
% INFO    : Updated Thermal Rating: on transformer 477-6769 : Rate B, Rate C , 0.0, 0.0 -> 1899
% INFO    : Updated Thermal Rating: on transformer 477-6769 : Rate B, Rate C , 0.0, 0.0 -> 1855
% INFO    : Updated Thermal Rating: on transformer 477-6769 : Rate B, Rate C , 0.0, 0.0 -> 1895
% INFO    : Updated Thermal Rating: on transformer 2188-5170 : Rate B, Rate C , 0.0, 0.0 -> 1717
% INFO    : Updated Thermal Rating: on transformer 3061-699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1157
% INFO    : Updated Thermal Rating: on transformer 3061-699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on transformer 5823-7110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on transformer 5823-7110 : Rate B, Rate C , 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on transformer 5280-7110 : Rate B, Rate C , 0.0, 0.0 -> 15936
% INFO    : Updated Thermal Rating: on transformer 1947-4317 : Rate B, Rate C , 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on transformer 7303-429 : Rate B, Rate C , 0.0, 0.0 -> 1678
% INFO    : Updated Thermal Rating: on transformer 6039-7973 : Rate B, Rate C , 0.0, 0.0 -> 1710
% INFO    : Updated Thermal Rating: on transformer 6039-7973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on transformer 1060-8981 : Rate B, Rate C , 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on transformer 8034-1752 : Rate B, Rate C , 0.0, 0.0 -> 1579
% INFO    : Updated Thermal Rating: on transformer 739-1393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 956
% INFO    : Updated Thermal Rating: on transformer 2235-8512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on transformer 3428-1439 : Rate B, Rate C , 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on transformer 2730-6127 : Rate B, Rate C , 0.0, 0.0 -> 1565
% INFO    : Updated Thermal Rating: on transformer 2730-6127 : Rate B, Rate C , 0.0, 0.0 -> 1556
% INFO    : Updated Thermal Rating: on transformer 7395-5435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1036
% INFO    : Updated Thermal Rating: on transformer 7395-5435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1076
% INFO    : Updated Thermal Rating: on transformer 2437-3792 : Rate B, Rate C , 0.0, 0.0 -> 1628
% INFO    : Updated Thermal Rating: on transformer 2437-3792 : Rate B, Rate C , 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on transformer 5239-8438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 912
% INFO    : Updated Thermal Rating: on transformer 5873-8147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on transformer 5873-8147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on transformer 5873-8147 : Rate B, Rate C , 0.0, 0.0 -> 1507
% INFO    : Updated Thermal Rating: on transformer 7508-1240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1187
% INFO    : Updated Thermal Rating: on transformer 7508-1240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on transformer 3268-6397 : Rate B, Rate C , 0.0, 0.0 -> 1776
% INFO    : Updated Thermal Rating: on transformer 4290-797 : Rate B, Rate C , 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on transformer 7929-4592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1291
% INFO    : Updated Thermal Rating: on transformer 7929-4592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1138
% INFO    : Updated Thermal Rating: on transformer 849-3840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on transformer 849-3840 : Rate B, Rate C , 0.0, 0.0 -> 1310
% INFO    : Updated Thermal Rating: on transformer 5919-8871 : Rate B, Rate C , 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on transformer 5919-8871 : Rate B, Rate C , 0.0, 0.0 -> 1605
% INFO    : Updated Thermal Rating: on transformer 5919-8871 : Rate B, Rate C , 0.0, 0.0 -> 1582
% INFO    : Updated Thermal Rating: on transformer 1168-2686 : Rate B, Rate C , 0.0, 0.0 -> 1682
% INFO    : Updated Thermal Rating: on transformer 1168-2686 : Rate B, Rate C , 0.0, 0.0 -> 1718
% INFO    : Updated Thermal Rating: on transformer 3275-6243 : Rate B, Rate C , 0.0, 0.0 -> 1678
% INFO    : Updated Thermal Rating: on transformer 3798-1121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on transformer 5884-8207 : Rate B, Rate C , 0.0, 0.0 -> 1684
% INFO    : Updated Thermal Rating: on transformer 5884-8207 : Rate B, Rate C , 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on transformer 5884-8207 : Rate B, Rate C , 0.0, 0.0 -> 1621
% INFO    : Updated Thermal Rating: on transformer 6681-7819 : Rate B, Rate C , 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on transformer 6681-7819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 821
% INFO    : Updated Thermal Rating: on transformer 2261-4204 : Rate B, Rate C , 0.0, 0.0 -> 1553
% INFO    : Updated Thermal Rating: on transformer 731-3728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on transformer 731-3728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1015
% INFO    : Updated Thermal Rating: on transformer 731-3728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1264
% INFO    : Updated Thermal Rating: on transformer 2764-415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1161
% INFO    : Updated Thermal Rating: on transformer 2764-415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on transformer 299-947 : Rate B, Rate C , 0.0, 0.0 -> 1520
% INFO    : Updated Thermal Rating: on transformer 299-947 : Rate B, Rate C , 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on transformer 8806-32 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on transformer 3008-5670 : Rate B, Rate C , 0.0, 0.0 -> 1522
% INFO    : Updated Thermal Rating: on transformer 179-1850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 830
% INFO    : Updated Thermal Rating: on transformer 7918-6660 : Rate B, Rate C , 0.0, 0.0 -> 1678
% INFO    : Updated Thermal Rating: on transformer 7918-77 : Rate B, Rate C , 0.0, 0.0 -> 1713
% INFO    : Updated Thermal Rating: on transformer 7029-33 : Rate B, Rate C , 0.0, 0.0 -> 1856
% INFO    : Updated Thermal Rating: on transformer 7029-33 : Rate B, Rate C , 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on transformer 6607-9039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on transformer 6607-9039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on transformer 7343-8338 : Rate B, Rate C , 0.0, 0.0 -> 1644
% INFO    : Updated Thermal Rating: on transformer 3966-5890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on transformer 8210-6936 : Rate B, Rate C , 0.0, 0.0 -> 1767
% INFO    : Updated Thermal Rating: on transformer 8210-6936 : Rate B, Rate C , 0.0, 0.0 -> 1804
% INFO    : Updated Thermal Rating: on transformer 1716-6544 : Rate B, Rate C , 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on transformer 1716-6544 : Rate B, Rate C , 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on transformer 3544-869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on transformer 3544-869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 3662-8242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 985
% INFO    : Updated Thermal Rating: on transformer 6092-3109 : Rate B, Rate C , 0.0, 0.0 -> 1484
% INFO    : Updated Thermal Rating: on transformer 1074-1769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1084
% INFO    : Updated Thermal Rating: on transformer 1074-1769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on transformer 1074-1769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1200
% INFO    : Updated Thermal Rating: on transformer 4957-1513 : Rate B, Rate C , 0.0, 0.0 -> 1649
% INFO    : Updated Thermal Rating: on transformer 7428-6134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on transformer 7428-6134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on transformer 7428-4651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on transformer 6970-4632 : Rate B, Rate C , 0.0, 0.0 -> 1698
% INFO    : Updated Thermal Rating: on transformer 2700-8953 : Rate B, Rate C , 0.0, 0.0 -> 1463
% INFO    : Updated Thermal Rating: on transformer 2700-8953 : Rate B, Rate C , 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on transformer 2849-3291 : Rate B, Rate C , 0.0, 0.0 -> 1602
% INFO    : Updated Thermal Rating: on transformer 4446-1457 : Rate B, Rate C , 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on transformer 814-7820 : Rate B, Rate C , 0.0, 0.0 -> 1442
% INFO    : Updated Thermal Rating: on transformer 7436-7629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1100
% INFO    : Updated Thermal Rating: on transformer 7436-9106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on transformer 3587-1241 : Rate B, Rate C , 0.0, 0.0 -> 1727
% INFO    : Updated Thermal Rating: on transformer 3587-1241 : Rate B, Rate C , 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on transformer 7688-8301 : Rate B, Rate C , 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on transformer 7688-8301 : Rate B, Rate C , 0.0, 0.0 -> 1463
% INFO    : Updated Thermal Rating: on transformer 4507-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on transformer 4507-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 647
% INFO    : Updated Thermal Rating: on transformer 4507-1503 : Rate B, Rate C , 0.0, 0.0 -> 1775
% INFO    : Updated Thermal Rating: on transformer 4507-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on transformer 8260-4081 : Rate B, Rate C , 0.0, 0.0 -> 1685
% INFO    : Updated Thermal Rating: on transformer 8260-4081 : Rate B, Rate C , 0.0, 0.0 -> 1723
% INFO    : Updated Thermal Rating: on transformer 1280-4279 : Rate B, Rate C , 0.0, 0.0 -> 1708
% INFO    : Updated Thermal Rating: on transformer 1280-4279 : Rate B, Rate C , 0.0, 0.0 -> 1603
% INFO    : Updated Thermal Rating: on transformer 385-9028 : Rate B, Rate C , 0.0, 0.0 -> 1917
% INFO    : Updated Thermal Rating: on transformer 385-9028 : Rate B, Rate C , 0.0, 0.0 -> 1409
% INFO    : Updated Thermal Rating: on transformer 6768-4096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on transformer 9203-2426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 644
% INFO    : Updated Thermal Rating: on transformer 9203-2426 : Rate B, Rate C , 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on transformer 118-2426 : Rate B, Rate C , 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on transformer 3145-7770 : Rate B, Rate C , 0.0, 0.0 -> 1336
% INFO    : Updated Thermal Rating: on transformer 7267-4918 : Rate B, Rate C , 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 7267-4918 : Rate B, Rate C , 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on transformer 839-4506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on transformer 839-4506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on transformer 3445-6114 : Rate B, Rate C , 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 3445-6114 : Rate B, Rate C , 0.0, 0.0 -> 1215
% INFO    : Updated Thermal Rating: on transformer 3445-7264 : Rate B, Rate C , 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on transformer 891-6306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on transformer 720-1711 : Rate B, Rate C , 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on transformer 720-1711 : Rate B, Rate C , 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on transformer 6206-3240 : Rate B, Rate C , 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on transformer 6206-3240 : Rate B, Rate C , 0.0, 0.0 -> 1198
% INFO    : Updated Thermal Rating: on transformer 9174-2924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on transformer 9174-2924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 1355-5856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on transformer 1355-5856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on transformer 1355-5856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on transformer 3205-4683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on transformer 3205-4683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on transformer 5350-2361 : Rate B, Rate C , 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on transformer 5350-2361 : Rate B, Rate C , 0.0, 0.0 -> 1050
% INFO    : Updated Thermal Rating: on transformer 5016-6112 : Rate B, Rate C , 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on transformer 5016-8860 : Rate B, Rate C , 0.0, 0.0 -> 1175
% INFO    : Updated Thermal Rating: on transformer 7471-549 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 7471-549 : Rate B, Rate C , 0.0, 0.0 -> 1122
% INFO    : Updated Thermal Rating: on transformer 549-5002 : Rate B, Rate C , 0.0, 0.0 -> 3435
% INFO    : Updated Thermal Rating: on transformer 5490-3817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on transformer 2854-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 800
% INFO    : Updated Thermal Rating: on transformer 2918-6532 : Rate B, Rate C , 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on transformer 2918-6532 : Rate B, Rate C , 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on transformer 4494-7284 : Rate B, Rate C , 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 2656-1775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on transformer 3519-5641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 752
% INFO    : Updated Thermal Rating: on transformer 3543-367 : Rate B, Rate C , 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on transformer 3543-1833 : Rate B, Rate C , 0.0, 0.0 -> 1410
% INFO    : Updated Thermal Rating: on transformer 2372-367 : Rate B, Rate C , 0.0, 0.0 -> 1199
% INFO    : Updated Thermal Rating: on transformer 2372-367 : Rate B, Rate C , 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on transformer 1876-7752 : Rate B, Rate C , 0.0, 0.0 -> 1283
% INFO    : Updated Thermal Rating: on transformer 113-7752 : Rate B, Rate C , 0.0, 0.0 -> 1314
% INFO    : Updated Thermal Rating: on transformer 3499-7289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 826
% INFO    : Updated Thermal Rating: on transformer 3499-7289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 772
% INFO    : Updated Thermal Rating: on transformer 3082-2083 : Rate B, Rate C , 0.0, 0.0 -> 1099
% INFO    : Updated Thermal Rating: on transformer 6224-2083 : Rate B, Rate C , 0.0, 0.0 -> 1165
% INFO    : Updated Thermal Rating: on transformer 2174-2083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on transformer 4623-1609 : Rate B, Rate C , 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 4623-1609 : Rate B, Rate C , 0.0, 0.0 -> 1199
% INFO    : Updated Thermal Rating: on transformer 4623-1609 : Rate B, Rate C , 0.0, 0.0 -> 1230
% INFO    : Updated Thermal Rating: on transformer 5589-1001 : Rate B, Rate C , 0.0, 0.0 -> 1157
% INFO    : Updated Thermal Rating: on transformer 5589-1001 : Rate B, Rate C , 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on transformer 5589-1001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on transformer 5589-1001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on transformer 1198-7473 : Rate B, Rate C , 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on transformer 1198-7473 : Rate B, Rate C , 0.0, 0.0 -> 1149
% INFO    : Updated Thermal Rating: on transformer 2479-5482 : Rate B, Rate C , 0.0, 0.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 2479-5482 : Rate B, Rate C , 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on transformer 7831-5525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1264
% INFO    : Updated Thermal Rating: on transformer 7831-5525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1385
% INFO    : Updated Thermal Rating: on transformer 7831-5525 : Rate B, Rate C , 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on transformer 4970-7955 : Rate B, Rate C , 0.0, 0.0 -> 1308
% INFO    : Updated Thermal Rating: on transformer 4970-7955 : Rate B, Rate C , 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on transformer 5007-7367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on transformer 757-3758 : Rate B, Rate C , 0.0, 0.0 -> 1092
% INFO    : Updated Thermal Rating: on transformer 3697-6952 : Rate B, Rate C , 0.0, 0.0 -> 1172
% INFO    : Updated Thermal Rating: on transformer 3697-6952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on transformer 3697-6952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on transformer 3697-6952 : Rate B, Rate C , 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on transformer 6738-8180 : Rate B, Rate C , 0.0, 0.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 6738-8180 : Rate B, Rate C , 0.0, 0.0 -> 1164
% INFO    : Updated Thermal Rating: on transformer 9222-5935 : Rate B, Rate C , 0.0, 0.0 -> 1300
% INFO    : Updated Thermal Rating: on transformer 7988-804 : Rate B, Rate C , 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on transformer 7988-804 : Rate B, Rate C , 0.0, 0.0 -> 1234
% INFO    : Updated Thermal Rating: on transformer 3239-1539 : Rate B, Rate C , 0.0, 0.0 -> 1202
% INFO    : Updated Thermal Rating: on transformer 3239-1539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 676
% INFO    : Updated Thermal Rating: on transformer 2056-4084 : Rate B, Rate C , 0.0, 0.0 -> 1176
% INFO    : Updated Thermal Rating: on transformer 2056-4084 : Rate B, Rate C , 0.0, 0.0 -> 1154
% INFO    : Updated Thermal Rating: on transformer 4598-5110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on transformer 2129-5110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on transformer 5658-5550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 922
% INFO    : Updated Thermal Rating: on transformer 5658-5550 : Rate B, Rate C , 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on transformer 2848-1526 : Rate B, Rate C , 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on transformer 4541-7464 : Rate B, Rate C , 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on transformer 4541-7464 : Rate B, Rate C , 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on transformer 1754-3857 : Rate B, Rate C , 0.0, 0.0 -> 1080
% INFO    : Updated Thermal Rating: on transformer 1754-3857 : Rate B, Rate C , 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on transformer 1754-3857 : Rate B, Rate C , 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on transformer 2518-4544 : Rate B, Rate C , 0.0, 0.0 -> 1229
% INFO    : Updated Thermal Rating: on transformer 2518-4544 : Rate B, Rate C , 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on transformer 3069-6115 : Rate B, Rate C , 0.0, 0.0 -> 3546
% INFO    : Updated Thermal Rating: on transformer 5067-7641 : Rate B, Rate C , 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on transformer 6036-8670 : Rate B, Rate C , 0.0, 0.0 -> 1344
% INFO    : Updated Thermal Rating: on transformer 6036-5522 : Rate B, Rate C , 0.0, 0.0 -> 1179
% INFO    : Updated Thermal Rating: on transformer 8486-8791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on transformer 7530-8791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 722
% INFO    : Updated Thermal Rating: on transformer 7522-7571 : Rate B, Rate C , 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on transformer 7522-7571 : Rate B, Rate C , 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on transformer 7522-7571 : Rate B, Rate C , 0.0, 0.0 -> 1124
% INFO    : Updated Thermal Rating: on transformer 2526-1483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 801
% INFO    : Updated Thermal Rating: on transformer 2365-8316 : Rate B, Rate C , 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on transformer 8672-1860 : Rate B, Rate C , 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on transformer 8672-1860 : Rate B, Rate C , 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on transformer 1494-583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 761
% INFO    : Updated Thermal Rating: on transformer 1494-583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on transformer 1502-2795 : Rate B, Rate C , 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on transformer 8195-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on transformer 8195-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on transformer 8195-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on transformer 3918-6802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 3918-4025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 721
% INFO    : Updated Thermal Rating: on transformer 4435-2079 : Rate B, Rate C , 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on transformer 4435-2079 : Rate B, Rate C , 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on transformer 4435-2079 : Rate B, Rate C , 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on transformer 1081-7361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on transformer 9101-2177 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 6555-8475 : Rate B, Rate C , 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on transformer 6555-8475 : Rate B, Rate C , 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on transformer 7056-7577 : Rate B, Rate C , 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on transformer 7056-7577 : Rate B, Rate C , 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on transformer 7056-9051 : Rate B, Rate C , 0.0, 0.0 -> 1289
% INFO    : Updated Thermal Rating: on transformer 6889-6785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on transformer 6889-6785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 853
% INFO    : Updated Thermal Rating: on transformer 6889-6785 : Rate B, Rate C , 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on transformer 1027-7148 : Rate B, Rate C , 0.0, 0.0 -> 1065
% INFO    : Updated Thermal Rating: on transformer 1027-44 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 5308-7148 : Rate B, Rate C , 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on transformer 5308-44 : Rate B, Rate C , 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on transformer 9213-6231 : Rate B, Rate C , 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on transformer 9213-8291 : Rate B, Rate C , 0.0, 0.0 -> 1281
% INFO    : Updated Thermal Rating: on transformer 9213-6842 : Rate B, Rate C , 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on transformer 3608-6664 : Rate B, Rate C , 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on transformer 4339-6570 : Rate B, Rate C , 0.0, 0.0 -> 1339
% INFO    : Updated Thermal Rating: on transformer 4339-6570 : Rate B, Rate C , 0.0, 0.0 -> 1191
% INFO    : Updated Thermal Rating: on transformer 7513-6570 : Rate B, Rate C , 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on transformer 7513-6570 : Rate B, Rate C , 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on transformer 8887-6639 : Rate B, Rate C , 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on transformer 8887-6639 : Rate B, Rate C , 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on transformer 5461-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on transformer 5461-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on transformer 5461-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 929
% INFO    : Updated Thermal Rating: on transformer 5460-3786 : Rate B, Rate C , 0.0, 0.0 -> 1214
% INFO    : Updated Thermal Rating: on transformer 5460-3786 : Rate B, Rate C , 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 7256-4491 : Rate B, Rate C , 0.0, 0.0 -> 2824
% INFO    : Updated Thermal Rating: on transformer 6153-58 : Rate B, Rate C , 0.0, 0.0 -> 4454
% INFO    : Updated Thermal Rating: on transformer 6153-6807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on transformer 1465-1262 : Rate B, Rate C , 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1465-1262 : Rate B, Rate C , 0.0, 0.0 -> 1229
% INFO    : Updated Thermal Rating: on transformer 1465-1551 : Rate B, Rate C , 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on transformer 7537-1551 : Rate B, Rate C , 0.0, 0.0 -> 1160
% INFO    : Updated Thermal Rating: on transformer 7537-1551 : Rate B, Rate C , 0.0, 0.0 -> 1192
% INFO    : Updated Thermal Rating: on transformer 6901-4874 : Rate B, Rate C , 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on transformer 5241-4 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 784
% INFO    : Updated Thermal Rating: on transformer 7520-561 : Rate B, Rate C , 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on transformer 749-4324 : Rate B, Rate C , 0.0, 0.0 -> 1382
% INFO    : Updated Thermal Rating: on transformer 4141-7124 : Rate B, Rate C , 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on transformer 4141-7124 : Rate B, Rate C , 0.0, 0.0 -> 1032
% INFO    : Updated Thermal Rating: on transformer 7466-3649 : Rate B, Rate C , 0.0, 0.0 -> 3016
% INFO    : Updated Thermal Rating: on transformer 8222-6556 : Rate B, Rate C , 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on transformer 8222-6556 : Rate B, Rate C , 0.0, 0.0 -> 1262
% INFO    : Updated Thermal Rating: on transformer 8222-6556 : Rate B, Rate C , 0.0, 0.0 -> 1311
% INFO    : Updated Thermal Rating: on transformer 4125-163 : Rate B, Rate C , 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on transformer 4125-163 : Rate B, Rate C , 0.0, 0.0 -> 1366
% INFO    : Updated Thermal Rating: on transformer 4125-163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 739
% INFO    : Updated Thermal Rating: on transformer 5837-9217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on transformer 5837-1448 : Rate B, Rate C , 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on transformer 5837-1448 : Rate B, Rate C , 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on transformer 8267-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on transformer 8267-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on transformer 2359-8005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on transformer 2359-8005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on transformer 8109-171 : Rate B, Rate C , 0.0, 0.0 -> 1204
% INFO    : Updated Thermal Rating: on transformer 8109-171 : Rate B, Rate C , 0.0, 0.0 -> 1241
% INFO    : Updated Thermal Rating: on transformer 3485-1156 : Rate B, Rate C , 0.0, 0.0 -> 1086
% INFO    : Updated Thermal Rating: on transformer 4734-2229 : Rate B, Rate C , 0.0, 0.0 -> 1065
% INFO    : Updated Thermal Rating: on transformer 1709-7702 : Rate B, Rate C , 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on transformer 1709-7702 : Rate B, Rate C , 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on transformer 905-8189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on transformer 8334-8189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on transformer 8334-8189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on transformer 7998-6734 : Rate B, Rate C , 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on transformer 4196-280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 784
% INFO    : Updated Thermal Rating: on transformer 4196-280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on transformer 6475-3503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on transformer 6475-3503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on transformer 7328-4235 : Rate B, Rate C , 0.0, 0.0 -> 1137
% INFO    : Updated Thermal Rating: on transformer 7328-4235 : Rate B, Rate C , 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on transformer 7328-4235 : Rate B, Rate C , 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on transformer 6921-2949 : Rate B, Rate C , 0.0, 0.0 -> 1266
% INFO    : Updated Thermal Rating: on transformer 6921-2949 : Rate B, Rate C , 0.0, 0.0 -> 1293
% INFO    : Updated Thermal Rating: on transformer 3830-306 : Rate B, Rate C , 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on transformer 5648-306 : Rate B, Rate C , 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on transformer 1730-115 : Rate B, Rate C , 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on transformer 1730-115 : Rate B, Rate C , 0.0, 0.0 -> 1059
% INFO    : Updated Thermal Rating: on transformer 2721-5720 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 2721-5720 : Rate B, Rate C , 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on transformer 432-3246 : Rate B, Rate C , 0.0, 0.0 -> 2432
% INFO    : Updated Thermal Rating: on transformer 432-8846 : Rate B, Rate C , 0.0, 0.0 -> 2483
% INFO    : Updated Thermal Rating: on transformer 432-2393 : Rate B, Rate C , 0.0, 0.0 -> 2533
% INFO    : Updated Thermal Rating: on transformer 432-1895 : Rate B, Rate C , 0.0, 0.0 -> 2588
% INFO    : Updated Thermal Rating: on transformer 432-3412 : Rate B, Rate C , 0.0, 0.0 -> 2447
% INFO    : Updated Thermal Rating: on transformer 432-5586 : Rate B, Rate C , 0.0, 0.0 -> 2502
% INFO    : Updated Thermal Rating: on transformer 432-3112 : Rate B, Rate C , 0.0, 0.0 -> 2207
% INFO    : Updated Thermal Rating: on transformer 432-3112 : Rate B, Rate C , 0.0, 0.0 -> 2165
% INFO    : Updated Thermal Rating: on transformer 432-7857 : Rate B, Rate C , 0.0, 0.0 -> 1160
% INFO    : Updated Thermal Rating: on transformer 960-8497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on transformer 960-8497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on transformer 3577-5907 : Rate B, Rate C , 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on transformer 3577-5907 : Rate B, Rate C , 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on transformer 3577-5907 : Rate B, Rate C , 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on transformer 7164-5918 : Rate B, Rate C , 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on transformer 7164-5918 : Rate B, Rate C , 0.0, 0.0 -> 1198
% INFO    : Updated Thermal Rating: on transformer 1798-2467 : Rate B, Rate C , 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on transformer 1798-2467 : Rate B, Rate C , 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on transformer 3346-2132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 3346-2132 : Rate B, Rate C , 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on transformer 3346-2132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 792
% INFO    : Updated Thermal Rating: on transformer 3483-8992 : Rate B, Rate C , 0.0, 0.0 -> 1266
% INFO    : Updated Thermal Rating: on transformer 8886-8992 : Rate B, Rate C , 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on transformer 2093-805 : Rate B, Rate C , 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on transformer 2093-805 : Rate B, Rate C , 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on transformer 221-1541 : Rate B, Rate C , 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on transformer 8347-5383 : Rate B, Rate C , 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on transformer 8347-5383 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 8347-5383 : Rate B, Rate C , 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8347-7507 : Rate B, Rate C , 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on transformer 8347-7507 : Rate B, Rate C , 0.0, 0.0 -> 1206
% INFO    : Updated Thermal Rating: on transformer 8347-7507 : Rate B, Rate C , 0.0, 0.0 -> 1256
% INFO    : Updated Thermal Rating: on transformer 4000-4852 : Rate B, Rate C , 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on transformer 4000-2012 : Rate B, Rate C , 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 2183-4852 : Rate B, Rate C , 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on transformer 2183-2012 : Rate B, Rate C , 0.0, 0.0 -> 1365
% INFO    : Updated Thermal Rating: on transformer 1642-7098 : Rate B, Rate C , 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on transformer 1642-687 : Rate B, Rate C , 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on transformer 809-7098 : Rate B, Rate C , 0.0, 0.0 -> 1144
% INFO    : Updated Thermal Rating: on transformer 809-687 : Rate B, Rate C , 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on transformer 4594-8804 : Rate B, Rate C , 0.0, 0.0 -> 1220
% INFO    : Updated Thermal Rating: on transformer 4594-8804 : Rate B, Rate C , 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on transformer 2919-4215 : Rate B, Rate C , 0.0, 0.0 -> 1178
% INFO    : Updated Thermal Rating: on transformer 1392-5001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on transformer 3538-5001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on transformer 8249-6139 : Rate A, Rate B, Rate C , 921.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on transformer 806-91 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 1747-6998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on transformer 593-6998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on transformer 8432-6295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on transformer 8432-6295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 8432-6295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 3190-7090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on transformer 3484-7090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on transformer 3484-7844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on transformer 281-3960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on transformer 8086-1477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 8086-8037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on transformer 5008-6354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on transformer 5008-6354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 919-6354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 919-6354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on transformer 4825-7884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on transformer 3023-7884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on transformer 6345-7884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on transformer 8114-8738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on transformer 8773-8738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 4059-6282 : Rate B, Rate C , 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on transformer 2002-4340 : Rate B, Rate C , 0.0, 0.0 -> 1463
% INFO    : Updated Thermal Rating: on transformer 5165-3363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 5165-3363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 2722-3363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on transformer 2722-3363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on transformer 1591-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1073
% INFO    : Updated Thermal Rating: on transformer 5558-8510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1097
% INFO    : Updated Thermal Rating: on transformer 5558-8510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 968
% INFO    : Updated Thermal Rating: on transformer 1689-8814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 8230-8814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on transformer 8393-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on transformer 8393-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 663
% INFO    : Updated Thermal Rating: on transformer 139-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 676
% INFO    : Updated Thermal Rating: on transformer 3257-6058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on transformer 369-6058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 705
% INFO    : Updated Thermal Rating: on transformer 369-6058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on transformer 6068-7450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on transformer 6068-2271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on transformer 6263-3846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 1788-1020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on transformer 2824-211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on transformer 140-211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on transformer 3210-1670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 5674-1670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on transformer 4337-1670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on line 4779-1956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4861
% INFO    : Updated Thermal Rating: on transformer 4320-4302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 736
% INFO    : Updated Thermal Rating: on transformer 4858-4248 : Rate B, Rate C , 0.0, 0.0 -> 1549
% INFO    : Updated Thermal Rating: on transformer 7235-4858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4200
% INFO    : Updated Thermal Rating: on transformer 4248-4302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on transformer 5897-2720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on transformer 420-243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 8898-6052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 5311-8668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on transformer 3891-8668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on transformer 662-7073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on transformer 6017-349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 858
% INFO    : Updated Thermal Rating: on transformer 6766-7156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 4077-7442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 1052-8277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3878-8277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on transformer 76-5346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 662
% INFO    : Updated Thermal Rating: on transformer 4485-3000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 4485-3000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on transformer 6283-3000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on transformer 395-4082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on transformer 5843-5246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on transformer 5843-5246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on transformer 6477-2478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on transformer 5295-2478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6504-3341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on transformer 130-5452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 613
% INFO    : Updated Thermal Rating: on transformer 130-5452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on transformer 441-2233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on transformer 8088-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on transformer 8088-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on transformer 3080-8789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1050
% INFO    : Updated Thermal Rating: on transformer 3080-8789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1089
% INFO    : Updated Thermal Rating: on transformer 5825-702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on transformer 8224-5517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on transformer 8224-5517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on transformer 536-4344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on transformer 6080-5006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 793
% INFO    : Updated Thermal Rating: on transformer 6080-5006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on transformer 1899-7358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on transformer 4712-1250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 923
% INFO    : Updated Thermal Rating: on transformer 4712-1250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 943
% INFO    : Updated Thermal Rating: on transformer 6187-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on transformer 6187-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on transformer 5562-1407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 832
% INFO    : Updated Thermal Rating: on transformer 7827-1974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on transformer 1025-8926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on transformer 6298-6795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1210
% INFO    : Updated Thermal Rating: on transformer 6298-6795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1226
% INFO    : Updated Thermal Rating: on transformer 3007-6254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on transformer 7969-177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1348
% INFO    : Updated Thermal Rating: on transformer 7969-177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1181
% INFO    : Updated Thermal Rating: on transformer 1703-7503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on transformer 1703-7503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 846
% INFO    : Updated Thermal Rating: on transformer 4704-4170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 886
% INFO    : Updated Thermal Rating: on transformer 4704-4170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on transformer 4704-4170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 976
% INFO    : Updated Thermal Rating: on transformer 2031-8493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1213
% INFO    : Updated Thermal Rating: on transformer 1025-1239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on transformer 3007-9136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1257
% INFO    : Updated Thermal Rating: on transformer 3007-4650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1250
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 3	: V=1.015975, theta=-21.797826 -> V=1.0, theta=0.0
% INFO    : Bus 4	: V=1.025797, theta=-7.009176 -> V=1.0, theta=0.0
% INFO    : Bus 10	: V=1.037973, theta=-24.31171 -> V=1.0, theta=0.0
% INFO    : Bus 15	: V=1.024279, theta=-48.286579 -> V=1.0, theta=0.0
% INFO    : Bus 21	: V=1.035642, theta=-21.986561 -> V=1.0, theta=0.0
% INFO    : Bus 22	: V=1.032862, theta=-18.51179 -> V=1.0, theta=0.0
% INFO    : Bus 26	: V=1.032832, theta=-3.303479 -> V=1.0, theta=0.0
% INFO    : Bus 29	: V=0.997905, theta=-13.742779 -> V=1.0, theta=0.0
% INFO    : Bus 32	: V=1.006206, theta=-42.36182 -> V=1.0, theta=0.0
% INFO    : Bus 33	: V=1.031909, theta=-37.946488 -> V=1.0, theta=0.0
% INFO    : Bus 38	: V=1.028477, theta=26.320254 -> V=1.0, theta=0.0
% INFO    : Bus 39	: V=1.005551, theta=-37.656299 -> V=1.0, theta=0.0
% INFO    : Bus 42	: V=1.047415, theta=-48.480512 -> V=1.0, theta=0.0
% INFO    : Bus 44	: V=1.045273, theta=-22.20917 -> V=1.0, theta=0.0
% INFO    : Bus 51	: V=1.01198, theta=-47.438988 -> V=1.0, theta=0.0
% INFO    : Bus 52	: V=1.013245, theta=0.963784 -> V=1.0, theta=0.0
% INFO    : Bus 53	: V=1.060523, theta=-9.105713 -> V=1.0, theta=0.0
% INFO    : Bus 58	: V=0.995373, theta=-21.587045 -> V=1.0, theta=0.0
% INFO    : Bus 59	: V=1.031574, theta=-23.793559 -> V=1.0, theta=0.0
% INFO    : Bus 69	: V=1.011798, theta=-0.30934 -> V=1.0, theta=0.0
% INFO    : Bus 71	: V=1.037783, theta=3.197998 -> V=1.0, theta=0.0
% INFO    : Bus 72	: V=1.009626, theta=-40.551667 -> V=1.0, theta=0.0
% INFO    : Bus 75	: V=1.024422, theta=-52.498016 -> V=1.0, theta=0.0
% INFO    : Bus 76	: V=1.028539, theta=26.329875 -> V=1.0, theta=0.0
% INFO    : Bus 77	: V=1.013066, theta=-48.881785 -> V=1.0, theta=0.0
% INFO    : Bus 89	: V=0.996001, theta=-4.601142 -> V=1.0, theta=0.0
% INFO    : Bus 90	: V=1.04293, theta=-27.629609 -> V=1.0, theta=0.0
% INFO    : Bus 91	: V=1.011563, theta=0.577525 -> V=1.0, theta=0.0
% INFO    : Bus 96	: V=1.034803, theta=-15.625024 -> V=1.0, theta=0.0
% INFO    : Bus 113	: V=1.030544, theta=-14.260449 -> V=1.0, theta=0.0
% INFO    : Bus 115	: V=1.065676, theta=-19.810351 -> V=1.0, theta=0.0
% INFO    : Bus 118	: V=1.021915, theta=-11.391408 -> V=1.0, theta=0.0
% INFO    : Bus 124	: V=1.079291, theta=8.367367 -> V=1.0, theta=0.0
% INFO    : Bus 128	: V=1.020115, theta=-16.088574 -> V=1.0, theta=0.0
% INFO    : Bus 130	: V=1.062972, theta=-46.623005 -> V=1.0, theta=0.0
% INFO    : Bus 132	: V=1.067846, theta=-43.278308 -> V=1.0, theta=0.0
% INFO    : Bus 133	: V=1.01895, theta=2.823528 -> V=1.0, theta=0.0
% INFO    : Bus 138	: V=1.071168, theta=-41.33849 -> V=1.0, theta=0.0
% INFO    : Bus 139	: V=1.002952, theta=17.568852 -> V=1.0, theta=0.0
% INFO    : Bus 140	: V=1.029191, theta=17.813411 -> V=1.0, theta=0.0
% INFO    : Bus 143	: V=1.013822, theta=4.4155 -> V=1.0, theta=0.0
% INFO    : Bus 145	: V=1.042169, theta=-8.880162 -> V=1.0, theta=0.0
% INFO    : Bus 148	: V=1.041686, theta=-7.998665 -> V=1.0, theta=0.0
% INFO    : Bus 150	: V=1.062067, theta=2.553662 -> V=1.0, theta=0.0
% INFO    : Bus 163	: V=1.042505, theta=-10.668912 -> V=1.0, theta=0.0
% INFO    : Bus 164	: V=1.015861, theta=-0.666839 -> V=1.0, theta=0.0
% INFO    : Bus 171	: V=1.063782, theta=-25.157599 -> V=1.0, theta=0.0
% INFO    : Bus 172	: V=1.017044, theta=-46.443671 -> V=1.0, theta=0.0
% INFO    : Bus 174	: V=1.073491, theta=-27.987179 -> V=1.0, theta=0.0
% INFO    : Bus 177	: V=0.973375, theta=-42.693578 -> V=1.0, theta=0.0
% INFO    : Bus 179	: V=1.048817, theta=-49.34001 -> V=1.0, theta=0.0
% INFO    : Bus 184	: V=1.043679, theta=-11.957994 -> V=1.0, theta=0.0
% INFO    : Bus 188	: V=1.018271, theta=-19.570046 -> V=1.0, theta=0.0
% INFO    : Bus 194	: V=1.029584, theta=13.78786 -> V=1.0, theta=0.0
% INFO    : Bus 195	: V=1.053191, theta=-8.795989 -> V=1.0, theta=0.0
% INFO    : Bus 196	: V=1.074427, theta=-26.348559 -> V=1.0, theta=0.0
% INFO    : Bus 198	: V=1.01582, theta=-16.334436 -> V=1.0, theta=0.0
% INFO    : Bus 199	: V=1.011196, theta=0.998875 -> V=1.0, theta=0.0
% INFO    : Bus 201	: V=1.024675, theta=-50.722374 -> V=1.0, theta=0.0
% INFO    : Bus 205	: V=1.00871, theta=4.996181 -> V=1.0, theta=0.0
% INFO    : Bus 207	: V=1.027593, theta=-13.46248 -> V=1.0, theta=0.0
% INFO    : Bus 211	: V=1.032527, theta=13.596519 -> V=1.0, theta=0.0
% INFO    : Bus 216	: V=1.038563, theta=-24.634597 -> V=1.0, theta=0.0
% INFO    : Bus 217	: V=1.034707, theta=-2.558504 -> V=1.0, theta=0.0
% INFO    : Bus 218	: V=1.042445, theta=-13.132419 -> V=1.0, theta=0.0
% INFO    : Bus 221	: V=0.996091, theta=-22.219166 -> V=1.0, theta=0.0
% INFO    : Bus 225	: V=1.062639, theta=-20.201534 -> V=1.0, theta=0.0
% INFO    : Bus 228	: V=1.043885, theta=-8.143399 -> V=1.0, theta=0.0
% INFO    : Bus 230	: V=1.007001, theta=-46.343334 -> V=1.0, theta=0.0
% INFO    : Bus 231	: V=1.019763, theta=23.115587 -> V=1.0, theta=0.0
% INFO    : Bus 236	: V=1.02885, theta=-53.54777 -> V=1.0, theta=0.0
% INFO    : Bus 243	: V=1.01715, theta=17.760873 -> V=1.0, theta=0.0
% INFO    : Bus 244	: V=1.018463, theta=6.917494 -> V=1.0, theta=0.0
% INFO    : Bus 249	: V=1.005395, theta=-42.359771 -> V=1.0, theta=0.0
% INFO    : Bus 257	: V=1.034093, theta=-45.514467 -> V=1.0, theta=0.0
% INFO    : Bus 261	: V=1.056876, theta=-45.124465 -> V=1.0, theta=0.0
% INFO    : Bus 264	: V=1.01505, theta=-46.406008 -> V=1.0, theta=0.0
% INFO    : Bus 266	: V=1.059749, theta=-41.880587 -> V=1.0, theta=0.0
% INFO    : Bus 267	: V=1.016267, theta=-50.549724 -> V=1.0, theta=0.0
% INFO    : Bus 268	: V=1.046663, theta=26.481396 -> V=1.0, theta=0.0
% INFO    : Bus 271	: V=1.03996, theta=-9.671728 -> V=1.0, theta=0.0
% INFO    : Bus 275	: V=1.012638, theta=2.38281 -> V=1.0, theta=0.0
% INFO    : Bus 280	: V=1.033127, theta=-11.186618 -> V=1.0, theta=0.0
% INFO    : Bus 281	: V=1.035067, theta=14.007344 -> V=1.0, theta=0.0
% INFO    : Bus 283	: V=1.036291, theta=-12.101832 -> V=1.0, theta=0.0
% INFO    : Bus 284	: V=1.023939, theta=-48.338029 -> V=1.0, theta=0.0
% INFO    : Bus 292	: V=1.04757, theta=-14.756324 -> V=1.0, theta=0.0
% INFO    : Bus 297	: V=1.025769, theta=4.498938 -> V=1.0, theta=0.0
% INFO    : Bus 299	: V=1.046197, theta=-45.832236 -> V=1.0, theta=0.0
% INFO    : Bus 304	: V=0.994426, theta=-53.724872 -> V=1.0, theta=0.0
% INFO    : Bus 305	: V=1.066061, theta=-32.494764 -> V=1.0, theta=0.0
% INFO    : Bus 306	: V=1.029806, theta=-18.845783 -> V=1.0, theta=0.0
% INFO    : Bus 311	: V=1.003155, theta=-2.003262 -> V=1.0, theta=0.0
% INFO    : Bus 312	: V=1.054916, theta=11.672353 -> V=1.0, theta=0.0
% INFO    : Bus 314	: V=1.000695, theta=-16.068608 -> V=1.0, theta=0.0
% INFO    : Bus 315	: V=1.026865, theta=-35.887691 -> V=1.0, theta=0.0
% INFO    : Bus 317	: V=1.017677, theta=6.394344 -> V=1.0, theta=0.0
% INFO    : Bus 322	: V=0.963932, theta=-44.221789 -> V=1.0, theta=0.0
% INFO    : Bus 326	: V=1.046796, theta=26.528223 -> V=1.0, theta=0.0
% INFO    : Bus 333	: V=1.012818, theta=-42.225824 -> V=1.0, theta=0.0
% INFO    : Bus 338	: V=1.049578, theta=-6.144398 -> V=1.0, theta=0.0
% INFO    : Bus 344	: V=1.022517, theta=-1.388364 -> V=1.0, theta=0.0
% INFO    : Bus 346	: V=1.039389, theta=-21.333666 -> V=1.0, theta=0.0
% INFO    : Bus 349	: V=1.047326, theta=9.079132 -> V=1.0, theta=0.0
% INFO    : Bus 350	: V=1.042975, theta=-24.324408 -> V=1.0, theta=0.0
% INFO    : Bus 351	: V=1.028054, theta=18.540762 -> V=1.0, theta=0.0
% INFO    : Bus 352	: V=1.054691, theta=0.247829 -> V=1.0, theta=0.0
% INFO    : Bus 360	: V=1.047637, theta=11.384137 -> V=1.0, theta=0.0
% INFO    : Bus 367	: V=1.071258, theta=-23.626071 -> V=1.0, theta=0.0
% INFO    : Bus 369	: V=1.045084, theta=13.593865 -> V=1.0, theta=0.0
% INFO    : Bus 370	: V=1.00045, theta=-2.194776 -> V=1.0, theta=0.0
% INFO    : Bus 377	: V=1.021633, theta=11.131046 -> V=1.0, theta=0.0
% INFO    : Bus 380	: V=1.004315, theta=-32.70603 -> V=1.0, theta=0.0
% INFO    : Bus 385	: V=1.045045, theta=-49.151666 -> V=1.0, theta=0.0
% INFO    : Bus 387	: V=1.040472, theta=6.605475 -> V=1.0, theta=0.0
% INFO    : Bus 389	: V=1.020856, theta=-40.645901 -> V=1.0, theta=0.0
% INFO    : Bus 392	: V=1.005558, theta=-0.515044 -> V=1.0, theta=0.0
% INFO    : Bus 395	: V=1.034154, theta=15.282226 -> V=1.0, theta=0.0
% INFO    : Bus 401	: V=1.028209, theta=-14.323194 -> V=1.0, theta=0.0
% INFO    : Bus 408	: V=1.041485, theta=-11.562819 -> V=1.0, theta=0.0
% INFO    : Bus 410	: V=1.035431, theta=-26.631809 -> V=1.0, theta=0.0
% INFO    : Bus 413	: V=1.052152, theta=-6.629634 -> V=1.0, theta=0.0
% INFO    : Bus 415	: V=1.029407, theta=-51.548505 -> V=1.0, theta=0.0
% INFO    : Bus 416	: V=1.041782, theta=-6.713309 -> V=1.0, theta=0.0
% INFO    : Bus 420	: V=1.049813, theta=18.568379 -> V=1.0, theta=0.0
% INFO    : Bus 425	: V=1.008682, theta=6.877656 -> V=1.0, theta=0.0
% INFO    : Bus 426	: V=1.040559, theta=-18.404022 -> V=1.0, theta=0.0
% INFO    : Bus 427	: V=1.077855, theta=-35.447133 -> V=1.0, theta=0.0
% INFO    : Bus 429	: V=1.018028, theta=-45.166294 -> V=1.0, theta=0.0
% INFO    : Bus 432	: V=1.04617, theta=2.418195 -> V=1.0, theta=0.0
% INFO    : Bus 440	: V=1.029422, theta=-36.073637 -> V=1.0, theta=0.0
% INFO    : Bus 441	: V=1.037169, theta=-51.706225 -> V=1.0, theta=0.0
% INFO    : Bus 442	: V=1.013689, theta=-46.010399 -> V=1.0, theta=0.0
% INFO    : Bus 444	: V=1.037192, theta=-12.208318 -> V=1.0, theta=0.0
% INFO    : Bus 445	: V=1.022265, theta=-44.379049 -> V=1.0, theta=0.0
% INFO    : Bus 449	: V=1.02121, theta=-8.505204 -> V=1.0, theta=0.0
% INFO    : Bus 453	: V=1.021096, theta=-7.822572 -> V=1.0, theta=0.0
% INFO    : Bus 455	: V=1.043545, theta=-30.648087 -> V=1.0, theta=0.0
% INFO    : Bus 472	: V=1.049863, theta=7.888585 -> V=1.0, theta=0.0
% INFO    : Bus 473	: V=1.027789, theta=-45.658214 -> V=1.0, theta=0.0
% INFO    : Bus 477	: V=1.049487, theta=-41.702128 -> V=1.0, theta=0.0
% INFO    : Bus 481	: V=1.024242, theta=-47.836389 -> V=1.0, theta=0.0
% INFO    : Bus 483	: V=1.022965, theta=-49.351603 -> V=1.0, theta=0.0
% INFO    : Bus 486	: V=1.014633, theta=4.966833 -> V=1.0, theta=0.0
% INFO    : Bus 489	: V=1.012805, theta=-47.213053 -> V=1.0, theta=0.0
% INFO    : Bus 490	: V=1.036343, theta=-23.043793 -> V=1.0, theta=0.0
% INFO    : Bus 496	: V=1.018474, theta=11.259593 -> V=1.0, theta=0.0
% INFO    : Bus 500	: V=1.037969, theta=-15.06839 -> V=1.0, theta=0.0
% INFO    : Bus 502	: V=1.04397, theta=-6.689582 -> V=1.0, theta=0.0
% INFO    : Bus 506	: V=1.062897, theta=-9.075959 -> V=1.0, theta=0.0
% INFO    : Bus 509	: V=1.015368, theta=-60.258851 -> V=1.0, theta=0.0
% INFO    : Bus 513	: V=1.038862, theta=-7.455688 -> V=1.0, theta=0.0
% INFO    : Bus 516	: V=1.074804, theta=-33.515516 -> V=1.0, theta=0.0
% INFO    : Bus 519	: V=1.026737, theta=-49.849135 -> V=1.0, theta=0.0
% INFO    : Bus 520	: V=1.048877, theta=-27.213193 -> V=1.0, theta=0.0
% INFO    : Bus 523	: V=1.043256, theta=7.231269 -> V=1.0, theta=0.0
% INFO    : Bus 527	: V=1.014388, theta=-46.235817 -> V=1.0, theta=0.0
% INFO    : Bus 536	: V=1.059638, theta=-47.971384 -> V=1.0, theta=0.0
% INFO    : Bus 539	: V=1.013211, theta=3.762537 -> V=1.0, theta=0.0
% INFO    : Bus 544	: V=1.039051, theta=-51.441574 -> V=1.0, theta=0.0
% INFO    : Bus 548	: V=1.03326, theta=16.142358 -> V=1.0, theta=0.0
% INFO    : Bus 549	: V=1.070777, theta=-10.99741 -> V=1.0, theta=0.0
% INFO    : Bus 550	: V=1.040041, theta=-45.192187 -> V=1.0, theta=0.0
% INFO    : Bus 552	: V=0.969255, theta=-42.920126 -> V=1.0, theta=0.0
% INFO    : Bus 554	: V=1.021838, theta=-20.831434 -> V=1.0, theta=0.0
% INFO    : Bus 556	: V=1.036788, theta=-22.791951 -> V=1.0, theta=0.0
% INFO    : Bus 558	: V=1.017158, theta=17.760895 -> V=1.0, theta=0.0
% INFO    : Bus 559	: V=1.03524, theta=5.466244 -> V=1.0, theta=0.0
% INFO    : Bus 561	: V=1.051908, theta=-11.066228 -> V=1.0, theta=0.0
% INFO    : Bus 564	: V=1.069692, theta=-47.162859 -> V=1.0, theta=0.0
% INFO    : Bus 575	: V=1.045123, theta=-11.170776 -> V=1.0, theta=0.0
% INFO    : Bus 577	: V=1.045911, theta=26.397998 -> V=1.0, theta=0.0
% INFO    : Bus 579	: V=1.021347, theta=-51.682309 -> V=1.0, theta=0.0
% INFO    : Bus 583	: V=1.043394, theta=-15.595495 -> V=1.0, theta=0.0
% INFO    : Bus 585	: V=1.032522, theta=3.857451 -> V=1.0, theta=0.0
% INFO    : Bus 593	: V=1.054621, theta=12.781834 -> V=1.0, theta=0.0
% INFO    : Bus 594	: V=1.038322, theta=-8.883436 -> V=1.0, theta=0.0
% INFO    : Bus 595	: V=1.028698, theta=-49.910829 -> V=1.0, theta=0.0
% INFO    : Bus 597	: V=1.059114, theta=-47.539487 -> V=1.0, theta=0.0
% INFO    : Bus 601	: V=1.041109, theta=-14.413923 -> V=1.0, theta=0.0
% INFO    : Bus 602	: V=1.023809, theta=-46.846316 -> V=1.0, theta=0.0
% INFO    : Bus 604	: V=0.996802, theta=-12.954482 -> V=1.0, theta=0.0
% INFO    : Bus 608	: V=1.067834, theta=-32.673267 -> V=1.0, theta=0.0
% INFO    : Bus 609	: V=1.022581, theta=-14.805449 -> V=1.0, theta=0.0
% INFO    : Bus 610	: V=0.990242, theta=-55.420594 -> V=1.0, theta=0.0
% INFO    : Bus 615	: V=1.06611, theta=-10.707846 -> V=1.0, theta=0.0
% INFO    : Bus 616	: V=1.049295, theta=-12.996312 -> V=1.0, theta=0.0
% INFO    : Bus 618	: V=1.028233, theta=-48.626653 -> V=1.0, theta=0.0
% INFO    : Bus 619	: V=1.045204, theta=-25.296091 -> V=1.0, theta=0.0
% INFO    : Bus 621	: V=1.019534, theta=-51.372282 -> V=1.0, theta=0.0
% INFO    : Bus 628	: V=0.98494, theta=-34.539287 -> V=1.0, theta=0.0
% INFO    : Bus 639	: V=1.046182, theta=-30.213914 -> V=1.0, theta=0.0
% INFO    : Bus 641	: V=1.0383, theta=-13.886781 -> V=1.0, theta=0.0
% INFO    : Bus 642	: V=1.036757, theta=-50.092904 -> V=1.0, theta=0.0
% INFO    : Bus 643	: V=1.007039, theta=-1.733141 -> V=1.0, theta=0.0
% INFO    : Bus 649	: V=1.025052, theta=-48.149342 -> V=1.0, theta=0.0
% INFO    : Bus 650	: V=1.020577, theta=12.404841 -> V=1.0, theta=0.0
% INFO    : Bus 656	: V=1.028027, theta=18.542452 -> V=1.0, theta=0.0
% INFO    : Bus 658	: V=1.033358, theta=-17.451459 -> V=1.0, theta=0.0
% INFO    : Bus 659	: V=1.017121, theta=6.345431 -> V=1.0, theta=0.0
% INFO    : Bus 661	: V=1.032374, theta=2.535923 -> V=1.0, theta=0.0
% INFO    : Bus 662	: V=1.024189, theta=11.926507 -> V=1.0, theta=0.0
% INFO    : Bus 666	: V=1.026843, theta=-5.376314 -> V=1.0, theta=0.0
% INFO    : Bus 676	: V=1.014417, theta=5.816488 -> V=1.0, theta=0.0
% INFO    : Bus 678	: V=0.992478, theta=-18.417537 -> V=1.0, theta=0.0
% INFO    : Bus 682	: V=1.065269, theta=-10.065918 -> V=1.0, theta=0.0
% INFO    : Bus 686	: V=1.018064, theta=-46.344294 -> V=1.0, theta=0.0
% INFO    : Bus 687	: V=1.061145, theta=-4.109826 -> V=1.0, theta=0.0
% INFO    : Bus 693	: V=1.061013, theta=-39.903628 -> V=1.0, theta=0.0
% INFO    : Bus 695	: V=1.001534, theta=-37.751201 -> V=1.0, theta=0.0
% INFO    : Bus 698	: V=1.001541, theta=-29.340894 -> V=1.0, theta=0.0
% INFO    : Bus 699	: V=1.015897, theta=-52.533022 -> V=1.0, theta=0.0
% INFO    : Bus 702	: V=1.007203, theta=-35.192471 -> V=1.0, theta=0.0
% INFO    : Bus 706	: V=1.01376, theta=-43.810675 -> V=1.0, theta=0.0
% INFO    : Bus 707	: V=1.052025, theta=-25.653481 -> V=1.0, theta=0.0
% INFO    : Bus 709	: V=1.072146, theta=-41.838466 -> V=1.0, theta=0.0
% INFO    : Bus 710	: V=1.050704, theta=-44.810504 -> V=1.0, theta=0.0
% INFO    : Bus 712	: V=1.009788, theta=1.2558 -> V=1.0, theta=0.0
% INFO    : Bus 718	: V=1.032503, theta=-24.998397 -> V=1.0, theta=0.0
% INFO    : Bus 720	: V=0.976999, theta=-26.946044 -> V=1.0, theta=0.0
% INFO    : Bus 722	: V=1.011148, theta=0.459046 -> V=1.0, theta=0.0
% INFO    : Bus 726	: V=1.051828, theta=-4.968545 -> V=1.0, theta=0.0
% INFO    : Bus 731	: V=1.046464, theta=-49.570359 -> V=1.0, theta=0.0
% INFO    : Bus 733	: V=1.004624, theta=6.681343 -> V=1.0, theta=0.0
% INFO    : Bus 739	: V=1.040583, theta=-42.166433 -> V=1.0, theta=0.0
% INFO    : Bus 742	: V=1.061315, theta=-4.111335 -> V=1.0, theta=0.0
% INFO    : Bus 747	: V=1.073525, theta=-26.409302 -> V=1.0, theta=0.0
% INFO    : Bus 749	: V=1.0548, theta=-29.025797 -> V=1.0, theta=0.0
% INFO    : Bus 750	: V=1.040344, theta=-24.488621 -> V=1.0, theta=0.0
% INFO    : Bus 751	: V=1.023645, theta=-43.542115 -> V=1.0, theta=0.0
% INFO    : Bus 754	: V=1.049392, theta=-44.640438 -> V=1.0, theta=0.0
% INFO    : Bus 757	: V=1.016623, theta=-13.779113 -> V=1.0, theta=0.0
% INFO    : Bus 766	: V=1.043257, theta=-19.971137 -> V=1.0, theta=0.0
% INFO    : Bus 769	: V=1.02737, theta=-10.890652 -> V=1.0, theta=0.0
% INFO    : Bus 772	: V=1.03156, theta=-14.189114 -> V=1.0, theta=0.0
% INFO    : Bus 775	: V=1.049935, theta=7.89661 -> V=1.0, theta=0.0
% INFO    : Bus 776	: V=1.029038, theta=-13.297102 -> V=1.0, theta=0.0
% INFO    : Bus 778	: V=1.051035, theta=-6.663814 -> V=1.0, theta=0.0
% INFO    : Bus 780	: V=1.006139, theta=-44.460594 -> V=1.0, theta=0.0
% INFO    : Bus 784	: V=1.026671, theta=4.566419 -> V=1.0, theta=0.0
% INFO    : Bus 785	: V=1.032974, theta=-33.396061 -> V=1.0, theta=0.0
% INFO    : Bus 789	: V=1.047988, theta=-5.931607 -> V=1.0, theta=0.0
% INFO    : Bus 790	: V=1.056626, theta=12.502239 -> V=1.0, theta=0.0
% INFO    : Bus 792	: V=1.004879, theta=-2.745379 -> V=1.0, theta=0.0
% INFO    : Bus 795	: V=1.039638, theta=-15.418252 -> V=1.0, theta=0.0
% INFO    : Bus 797	: V=1.01981, theta=-39.437643 -> V=1.0, theta=0.0
% INFO    : Bus 800	: V=1.035866, theta=-12.135713 -> V=1.0, theta=0.0
% INFO    : Bus 803	: V=1.04396, theta=-24.894279 -> V=1.0, theta=0.0
% INFO    : Bus 804	: V=1.0581, theta=-7.541712 -> V=1.0, theta=0.0
% INFO    : Bus 805	: V=1.053184, theta=-11.133211 -> V=1.0, theta=0.0
% INFO    : Bus 806	: V=0.999621, theta=7.284283 -> V=1.0, theta=0.0
% INFO    : Bus 807	: V=1.057043, theta=-37.929845 -> V=1.0, theta=0.0
% INFO    : Bus 808	: V=1.022909, theta=-49.791145 -> V=1.0, theta=0.0
% INFO    : Bus 809	: V=1.031022, theta=-0.130758 -> V=1.0, theta=0.0
% INFO    : Bus 814	: V=1.024011, theta=-50.140745 -> V=1.0, theta=0.0
% INFO    : Bus 819	: V=1.05327, theta=-0.714338 -> V=1.0, theta=0.0
% INFO    : Bus 823	: V=1.044347, theta=-2.253517 -> V=1.0, theta=0.0
% INFO    : Bus 838	: V=1.031933, theta=4.198236 -> V=1.0, theta=0.0
% INFO    : Bus 839	: V=1.027702, theta=-1.443829 -> V=1.0, theta=0.0
% INFO    : Bus 849	: V=1.041392, theta=-41.391834 -> V=1.0, theta=0.0
% INFO    : Bus 851	: V=1.006263, theta=-17.209235 -> V=1.0, theta=0.0
% INFO    : Bus 854	: V=1.029065, theta=-53.698786 -> V=1.0, theta=0.0
% INFO    : Bus 858	: V=1.035299, theta=1.038476 -> V=1.0, theta=0.0
% INFO    : Bus 869	: V=1.024451, theta=-46.452848 -> V=1.0, theta=0.0
% INFO    : Bus 870	: V=1.039963, theta=-24.646112 -> V=1.0, theta=0.0
% INFO    : Bus 871	: V=1.053384, theta=-12.006609 -> V=1.0, theta=0.0
% INFO    : Bus 878	: V=1.032326, theta=10.347716 -> V=1.0, theta=0.0
% INFO    : Bus 883	: V=1.019167, theta=-10.099494 -> V=1.0, theta=0.0
% INFO    : Bus 891	: V=1.063198, theta=-18.995307 -> V=1.0, theta=0.0
% INFO    : Bus 892	: V=1.06845, theta=-35.058808 -> V=1.0, theta=0.0
% INFO    : Bus 898	: V=1.017379, theta=13.778356 -> V=1.0, theta=0.0
% INFO    : Bus 900	: V=1.045753, theta=-15.459465 -> V=1.0, theta=0.0
% INFO    : Bus 903	: V=1.073487, theta=-26.434473 -> V=1.0, theta=0.0
% INFO    : Bus 905	: V=1.034156, theta=-15.096405 -> V=1.0, theta=0.0
% INFO    : Bus 907	: V=1.042523, theta=-9.744132 -> V=1.0, theta=0.0
% INFO    : Bus 908	: V=1.062521, theta=-7.960383 -> V=1.0, theta=0.0
% INFO    : Bus 913	: V=1.032774, theta=-1.888859 -> V=1.0, theta=0.0
% INFO    : Bus 916	: V=1.024009, theta=-37.476261 -> V=1.0, theta=0.0
% INFO    : Bus 919	: V=1.015897, theta=12.146494 -> V=1.0, theta=0.0
% INFO    : Bus 920	: V=1.044238, theta=-20.80386 -> V=1.0, theta=0.0
% INFO    : Bus 923	: V=1.035473, theta=-23.119527 -> V=1.0, theta=0.0
% INFO    : Bus 928	: V=1.01151, theta=0.819942 -> V=1.0, theta=0.0
% INFO    : Bus 929	: V=1.024627, theta=-45.597223 -> V=1.0, theta=0.0
% INFO    : Bus 930	: V=1.063763, theta=-37.235712 -> V=1.0, theta=0.0
% INFO    : Bus 932	: V=1.031096, theta=-53.231343 -> V=1.0, theta=0.0
% INFO    : Bus 933	: V=1.019207, theta=-21.558165 -> V=1.0, theta=0.0
% INFO    : Bus 935	: V=1.047658, theta=-24.511894 -> V=1.0, theta=0.0
% INFO    : Bus 947	: V=0.989542, theta=-49.087121 -> V=1.0, theta=0.0
% INFO    : Bus 948	: V=0.990808, theta=-55.02646 -> V=1.0, theta=0.0
% INFO    : Bus 950	: V=1.014233, theta=0.231638 -> V=1.0, theta=0.0
% INFO    : Bus 953	: V=1.064103, theta=-13.019958 -> V=1.0, theta=0.0
% INFO    : Bus 954	: V=1.043381, theta=-21.557176 -> V=1.0, theta=0.0
% INFO    : Bus 955	: V=1.010468, theta=-11.004951 -> V=1.0, theta=0.0
% INFO    : Bus 957	: V=1.014721, theta=-45.935916 -> V=1.0, theta=0.0
% INFO    : Bus 960	: V=1.062896, theta=-9.075954 -> V=1.0, theta=0.0
% INFO    : Bus 962	: V=1.040501, theta=-45.427736 -> V=1.0, theta=0.0
% INFO    : Bus 964	: V=1.013923, theta=-11.664656 -> V=1.0, theta=0.0
% INFO    : Bus 970	: V=1.019331, theta=-42.032228 -> V=1.0, theta=0.0
% INFO    : Bus 972	: V=1.068998, theta=5.469581 -> V=1.0, theta=0.0
% INFO    : Bus 976	: V=1.029847, theta=-49.344807 -> V=1.0, theta=0.0
% INFO    : Bus 980	: V=1.045627, theta=-25.181981 -> V=1.0, theta=0.0
% INFO    : Bus 981	: V=1.023028, theta=-43.883268 -> V=1.0, theta=0.0
% INFO    : Bus 986	: V=1.022036, theta=-52.113357 -> V=1.0, theta=0.0
% INFO    : Bus 987	: V=1.000938, theta=-38.474493 -> V=1.0, theta=0.0
% INFO    : Bus 988	: V=1.028293, theta=-52.276231 -> V=1.0, theta=0.0
% INFO    : Bus 994	: V=1.00959, theta=-0.823416 -> V=1.0, theta=0.0
% INFO    : Bus 999	: V=1.018279, theta=20.643565 -> V=1.0, theta=0.0
% INFO    : Bus 1000	: V=1.020326, theta=-32.938159 -> V=1.0, theta=0.0
% INFO    : Bus 1001	: V=1.073365, theta=-33.684292 -> V=1.0, theta=0.0
% INFO    : Bus 1002	: V=1.040649, theta=-20.121516 -> V=1.0, theta=0.0
% INFO    : Bus 1005	: V=1.055459, theta=-12.444399 -> V=1.0, theta=0.0
% INFO    : Bus 1010	: V=1.025244, theta=23.360989 -> V=1.0, theta=0.0
% INFO    : Bus 1011	: V=1.022912, theta=-1.384287 -> V=1.0, theta=0.0
% INFO    : Bus 1013	: V=0.995803, theta=-46.382009 -> V=1.0, theta=0.0
% INFO    : Bus 1015	: V=1.052586, theta=-5.374132 -> V=1.0, theta=0.0
% INFO    : Bus 1020	: V=1.040463, theta=6.605453 -> V=1.0, theta=0.0
% INFO    : Bus 1021	: V=1.019135, theta=-46.034292 -> V=1.0, theta=0.0
% INFO    : Bus 1023	: V=1.019064, theta=-43.846601 -> V=1.0, theta=0.0
% INFO    : Bus 1025	: V=1.02861, theta=-51.715097 -> V=1.0, theta=0.0
% INFO    : Bus 1026	: V=1.028099, theta=-29.440609 -> V=1.0, theta=0.0
% INFO    : Bus 1027	: V=0.990137, theta=-18.20472 -> V=1.0, theta=0.0
% INFO    : Bus 1030	: V=1.00979, theta=-35.817545 -> V=1.0, theta=0.0
% INFO    : Bus 1033	: V=1.040136, theta=-24.565838 -> V=1.0, theta=0.0
% INFO    : Bus 1035	: V=1.066688, theta=-32.38237 -> V=1.0, theta=0.0
% INFO    : Bus 1036	: V=1.038657, theta=-30.920325 -> V=1.0, theta=0.0
% INFO    : Bus 1037	: V=1.019244, theta=5.129195 -> V=1.0, theta=0.0
% INFO    : Bus 1039	: V=1.033489, theta=-19.577193 -> V=1.0, theta=0.0
% INFO    : Bus 1040	: V=1.042099, theta=-9.004028 -> V=1.0, theta=0.0
% INFO    : Bus 1043	: V=1.029789, theta=-3.679585 -> V=1.0, theta=0.0
% INFO    : Bus 1046	: V=0.996689, theta=-4.648049 -> V=1.0, theta=0.0
% INFO    : Bus 1051	: V=1.043295, theta=-12.895086 -> V=1.0, theta=0.0
% INFO    : Bus 1052	: V=1.037394, theta=22.543259 -> V=1.0, theta=0.0
% INFO    : Bus 1057	: V=1.046413, theta=26.479841 -> V=1.0, theta=0.0
% INFO    : Bus 1060	: V=1.066748, theta=-41.463394 -> V=1.0, theta=0.0
% INFO    : Bus 1064	: V=1.023328, theta=-46.764421 -> V=1.0, theta=0.0
% INFO    : Bus 1065	: V=1.03126, theta=-53.682126 -> V=1.0, theta=0.0
% INFO    : Bus 1074	: V=1.04431, theta=-42.949688 -> V=1.0, theta=0.0
% INFO    : Bus 1077	: V=1.036293, theta=-12.101853 -> V=1.0, theta=0.0
% INFO    : Bus 1078	: V=1.057667, theta=-3.433753 -> V=1.0, theta=0.0
% INFO    : Bus 1081	: V=1.038361, theta=-10.516057 -> V=1.0, theta=0.0
% INFO    : Bus 1083	: V=1.046149, theta=-8.612778 -> V=1.0, theta=0.0
% INFO    : Bus 1086	: V=1.030324, theta=-46.704132 -> V=1.0, theta=0.0
% INFO    : Bus 1090	: V=1.009868, theta=-21.716046 -> V=1.0, theta=0.0
% INFO    : Bus 1093	: V=1.026457, theta=-8.509476 -> V=1.0, theta=0.0
% INFO    : Bus 1094	: V=1.035847, theta=6.036454 -> V=1.0, theta=0.0
% INFO    : Bus 1096	: V=1.051471, theta=-1.112508 -> V=1.0, theta=0.0
% INFO    : Bus 1100	: V=1.045212, theta=-4.342005 -> V=1.0, theta=0.0
% INFO    : Bus 1101	: V=1.031004, theta=-14.234122 -> V=1.0, theta=0.0
% INFO    : Bus 1102	: V=1.051902, theta=-6.664986 -> V=1.0, theta=0.0
% INFO    : Bus 1105	: V=1.074362, theta=-26.354638 -> V=1.0, theta=0.0
% INFO    : Bus 1106	: V=1.039063, theta=4.797809 -> V=1.0, theta=0.0
% INFO    : Bus 1109	: V=1.026975, theta=-34.564954 -> V=1.0, theta=0.0
% INFO    : Bus 1111	: V=1.038462, theta=-8.885347 -> V=1.0, theta=0.0
% INFO    : Bus 1114	: V=1.049971, theta=-38.366222 -> V=1.0, theta=0.0
% INFO    : Bus 1115	: V=1.026059, theta=-38.808007 -> V=1.0, theta=0.0
% INFO    : Bus 1121	: V=1.019674, theta=-38.721714 -> V=1.0, theta=0.0
% INFO    : Bus 1123	: V=1.023952, theta=17.512847 -> V=1.0, theta=0.0
% INFO    : Bus 1124	: V=1.061545, theta=15.555095 -> V=1.0, theta=0.0
% INFO    : Bus 1129	: V=1.003091, theta=-22.556815 -> V=1.0, theta=0.0
% INFO    : Bus 1133	: V=1.060996, theta=-43.314848 -> V=1.0, theta=0.0
% INFO    : Bus 1136	: V=1.032589, theta=-18.567697 -> V=1.0, theta=0.0
% INFO    : Bus 1137	: V=1.047141, theta=-24.469687 -> V=1.0, theta=0.0
% INFO    : Bus 1146	: V=1.027082, theta=-5.621485 -> V=1.0, theta=0.0
% INFO    : Bus 1151	: V=1.042198, theta=-20.641446 -> V=1.0, theta=0.0
% INFO    : Bus 1153	: V=1.038665, theta=-6.090842 -> V=1.0, theta=0.0
% INFO    : Bus 1155	: V=1.041573, theta=-51.256265 -> V=1.0, theta=0.0
% INFO    : Bus 1156	: V=1.037806, theta=-22.529879 -> V=1.0, theta=0.0
% INFO    : Bus 1159	: V=1.05154, theta=-36.310129 -> V=1.0, theta=0.0
% INFO    : Bus 1163	: V=0.994226, theta=-1.33508 -> V=1.0, theta=0.0
% INFO    : Bus 1168	: V=1.044876, theta=-42.073382 -> V=1.0, theta=0.0
% INFO    : Bus 1172	: V=1.074074, theta=-25.585411 -> V=1.0, theta=0.0
% INFO    : Bus 1173	: V=1.026125, theta=-41.202223 -> V=1.0, theta=0.0
% INFO    : Bus 1174	: V=1.004865, theta=-37.841731 -> V=1.0, theta=0.0
% INFO    : Bus 1175	: V=1.040018, theta=-39.23186 -> V=1.0, theta=0.0
% INFO    : Bus 1179	: V=1.032826, theta=-2.760554 -> V=1.0, theta=0.0
% INFO    : Bus 1183	: V=1.065333, theta=-33.138248 -> V=1.0, theta=0.0
% INFO    : Bus 1185	: V=1.014073, theta=-43.85169 -> V=1.0, theta=0.0
% INFO    : Bus 1187	: V=1.034555, theta=-4.939632 -> V=1.0, theta=0.0
% INFO    : Bus 1188	: V=1.055512, theta=-14.263576 -> V=1.0, theta=0.0
% INFO    : Bus 1194	: V=1.038615, theta=-15.144566 -> V=1.0, theta=0.0
% INFO    : Bus 1198	: V=0.990911, theta=-14.574593 -> V=1.0, theta=0.0
% INFO    : Bus 1200	: V=1.029044, theta=-41.25002 -> V=1.0, theta=0.0
% INFO    : Bus 1201	: V=1.044872, theta=-19.749595 -> V=1.0, theta=0.0
% INFO    : Bus 1205	: V=1.024412, theta=2.729649 -> V=1.0, theta=0.0
% INFO    : Bus 1207	: V=1.002426, theta=-0.400479 -> V=1.0, theta=0.0
% INFO    : Bus 1216	: V=1.0433, theta=-10.974434 -> V=1.0, theta=0.0
% INFO    : Bus 1221	: V=1.021136, theta=-1.469658 -> V=1.0, theta=0.0
% INFO    : Bus 1227	: V=1.02165, theta=11.131243 -> V=1.0, theta=0.0
% INFO    : Bus 1232	: V=1.050627, theta=-49.560634 -> V=1.0, theta=0.0
% INFO    : Bus 1233	: V=1.037734, theta=-22.55474 -> V=1.0, theta=0.0
% INFO    : Bus 1234	: V=1.021063, theta=-16.53158 -> V=1.0, theta=0.0
% INFO    : Bus 1237	: V=1.105045, theta=-6.257773 -> V=1.0, theta=0.0
% INFO    : Bus 1239	: V=1.00029, theta=-54.869777 -> V=1.0, theta=0.0
% INFO    : Bus 1240	: V=1.023595, theta=-41.324095 -> V=1.0, theta=0.0
% INFO    : Bus 1241	: V=1.021438, theta=-37.891799 -> V=1.0, theta=0.0
% INFO    : Bus 1248	: V=1.042662, theta=-10.670454 -> V=1.0, theta=0.0
% INFO    : Bus 1249	: V=1.019757, theta=-11.249323 -> V=1.0, theta=0.0
% INFO    : Bus 1250	: V=0.992765, theta=-35.003016 -> V=1.0, theta=0.0
% INFO    : Bus 1251	: V=1.0265, theta=-8.519028 -> V=1.0, theta=0.0
% INFO    : Bus 1255	: V=1.013822, theta=4.4155 -> V=1.0, theta=0.0
% INFO    : Bus 1260	: V=1.006152, theta=16.289799 -> V=1.0, theta=0.0
% INFO    : Bus 1262	: V=1.038366, theta=-22.062584 -> V=1.0, theta=0.0
% INFO    : Bus 1265	: V=1.066038, theta=-50.142036 -> V=1.0, theta=0.0
% INFO    : Bus 1271	: V=1.015573, theta=-46.050489 -> V=1.0, theta=0.0
% INFO    : Bus 1275	: V=1.029911, theta=-18.88645 -> V=1.0, theta=0.0
% INFO    : Bus 1277	: V=1.023051, theta=-1.382743 -> V=1.0, theta=0.0
% INFO    : Bus 1280	: V=1.074452, theta=-36.539156 -> V=1.0, theta=0.0
% INFO    : Bus 1282	: V=1.022795, theta=-46.751133 -> V=1.0, theta=0.0
% INFO    : Bus 1294	: V=1.014068, theta=-48.160177 -> V=1.0, theta=0.0
% INFO    : Bus 1295	: V=1.038943, theta=-8.62346 -> V=1.0, theta=0.0
% INFO    : Bus 1301	: V=1.050333, theta=-28.761692 -> V=1.0, theta=0.0
% INFO    : Bus 1305	: V=1.03884, theta=-22.413139 -> V=1.0, theta=0.0
% INFO    : Bus 1311	: V=1.032916, theta=-21.685441 -> V=1.0, theta=0.0
% INFO    : Bus 1317	: V=1.012625, theta=3.260404 -> V=1.0, theta=0.0
% INFO    : Bus 1326	: V=1.0686, theta=-35.059803 -> V=1.0, theta=0.0
% INFO    : Bus 1330	: V=0.993108, theta=-1.662148 -> V=1.0, theta=0.0
% INFO    : Bus 1331	: V=1.050091, theta=18.748368 -> V=1.0, theta=0.0
% INFO    : Bus 1334	: V=1.023695, theta=-16.319863 -> V=1.0, theta=0.0
% INFO    : Bus 1338	: V=1.046601, theta=11.309824 -> V=1.0, theta=0.0
% INFO    : Bus 1339	: V=1.054799, theta=-46.022749 -> V=1.0, theta=0.0
% INFO    : Bus 1341	: V=1.030396, theta=-14.229973 -> V=1.0, theta=0.0
% INFO    : Bus 1343	: V=0.998625, theta=-14.148042 -> V=1.0, theta=0.0
% INFO    : Bus 1344	: V=1.024638, theta=-46.046982 -> V=1.0, theta=0.0
% INFO    : Bus 1347	: V=1.027222, theta=-52.983085 -> V=1.0, theta=0.0
% INFO    : Bus 1350	: V=1.021086, theta=-0.760994 -> V=1.0, theta=0.0
% INFO    : Bus 1352	: V=1.016527, theta=-1.088293 -> V=1.0, theta=0.0
% INFO    : Bus 1354	: V=1.04168, theta=-7.390066 -> V=1.0, theta=0.0
% INFO    : Bus 1355	: V=1.032403, theta=-8.543964 -> V=1.0, theta=0.0
% INFO    : Bus 1362	: V=1.045758, theta=26.397012 -> V=1.0, theta=0.0
% INFO    : Bus 1364	: V=1.035537, theta=-12.095863 -> V=1.0, theta=0.0
% INFO    : Bus 1367	: V=1.008895, theta=-0.195912 -> V=1.0, theta=0.0
% INFO    : Bus 1380	: V=1.028172, theta=-22.726688 -> V=1.0, theta=0.0
% INFO    : Bus 1391	: V=1.028915, theta=-37.143274 -> V=1.0, theta=0.0
% INFO    : Bus 1392	: V=1.027508, theta=18.540668 -> V=1.0, theta=0.0
% INFO    : Bus 1393	: V=1.026572, theta=-45.348551 -> V=1.0, theta=0.0
% INFO    : Bus 1394	: V=1.074262, theta=-26.342945 -> V=1.0, theta=0.0
% INFO    : Bus 1397	: V=1.039499, theta=-12.885891 -> V=1.0, theta=0.0
% INFO    : Bus 1398	: V=1.016914, theta=-19.000915 -> V=1.0, theta=0.0
% INFO    : Bus 1399	: V=1.052722, theta=-48.692525 -> V=1.0, theta=0.0
% INFO    : Bus 1401	: V=1.035517, theta=-14.762042 -> V=1.0, theta=0.0
% INFO    : Bus 1407	: V=0.996889, theta=-49.175373 -> V=1.0, theta=0.0
% INFO    : Bus 1409	: V=1.024907, theta=-48.140766 -> V=1.0, theta=0.0
% INFO    : Bus 1411	: V=1.01205, theta=-47.31797 -> V=1.0, theta=0.0
% INFO    : Bus 1414	: V=1.022618, theta=-27.926817 -> V=1.0, theta=0.0
% INFO    : Bus 1415	: V=1.031083, theta=-11.51315 -> V=1.0, theta=0.0
% INFO    : Bus 1418	: V=1.021924, theta=-54.400148 -> V=1.0, theta=0.0
% INFO    : Bus 1421	: V=1.021629, theta=-51.698681 -> V=1.0, theta=0.0
% INFO    : Bus 1422	: V=1.045292, theta=-21.037138 -> V=1.0, theta=0.0
% INFO    : Bus 1430	: V=1.015624, theta=-50.375421 -> V=1.0, theta=0.0
% INFO    : Bus 1435	: V=1.044029, theta=-24.378621 -> V=1.0, theta=0.0
% INFO    : Bus 1436	: V=1.049261, theta=-12.98242 -> V=1.0, theta=0.0
% INFO    : Bus 1437	: V=0.9896, theta=-37.927533 -> V=1.0, theta=0.0
% INFO    : Bus 1439	: V=1.025342, theta=-48.121825 -> V=1.0, theta=0.0
% INFO    : Bus 1445	: V=1.001732, theta=-0.206284 -> V=1.0, theta=0.0
% INFO    : Bus 1448	: V=1.074407, theta=-15.342169 -> V=1.0, theta=0.0
% INFO    : Bus 1457	: V=1.016731, theta=-39.321312 -> V=1.0, theta=0.0
% INFO    : Bus 1458	: V=1.05352, theta=-38.031423 -> V=1.0, theta=0.0
% INFO    : Bus 1459	: V=1.041987, theta=-21.849566 -> V=1.0, theta=0.0
% INFO    : Bus 1461	: V=1.038081, theta=-38.816129 -> V=1.0, theta=0.0
% INFO    : Bus 1462	: V=1.045314, theta=-21.037648 -> V=1.0, theta=0.0
% INFO    : Bus 1463	: V=1.03605, theta=6.423553 -> V=1.0, theta=0.0
% INFO    : Bus 1464	: V=1.020741, theta=7.919173 -> V=1.0, theta=0.0
% INFO    : Bus 1465	: V=0.987783, theta=-15.361156 -> V=1.0, theta=0.0
% INFO    : Bus 1471	: V=0.981221, theta=-48.994904 -> V=1.0, theta=0.0
% INFO    : Bus 1475	: V=1.025403, theta=-43.044459 -> V=1.0, theta=0.0
% INFO    : Bus 1477	: V=1.034673, theta=9.5982 -> V=1.0, theta=0.0
% INFO    : Bus 1478	: V=1.046165, theta=-15.856607 -> V=1.0, theta=0.0
% INFO    : Bus 1479	: V=1.029701, theta=-43.025361 -> V=1.0, theta=0.0
% INFO    : Bus 1483	: V=1.063082, theta=-26.916487 -> V=1.0, theta=0.0
% INFO    : Bus 1486	: V=1.034765, theta=-23.371441 -> V=1.0, theta=0.0
% INFO    : Bus 1489	: V=1.0268, theta=-35.902682 -> V=1.0, theta=0.0
% INFO    : Bus 1491	: V=1.023943, theta=-47.089173 -> V=1.0, theta=0.0
% INFO    : Bus 1494	: V=1.032178, theta=-11.529751 -> V=1.0, theta=0.0
% INFO    : Bus 1498	: V=1.078389, theta=-39.66401 -> V=1.0, theta=0.0
% INFO    : Bus 1501	: V=1.030006, theta=-53.597487 -> V=1.0, theta=0.0
% INFO    : Bus 1502	: V=1.026558, theta=-26.733601 -> V=1.0, theta=0.0
% INFO    : Bus 1503	: V=1.023199, theta=-43.578655 -> V=1.0, theta=0.0
% INFO    : Bus 1504	: V=1.026035, theta=-14.299045 -> V=1.0, theta=0.0
% INFO    : Bus 1513	: V=1.019243, theta=-39.521783 -> V=1.0, theta=0.0
% INFO    : Bus 1516	: V=1.020964, theta=-0.403438 -> V=1.0, theta=0.0
% INFO    : Bus 1520	: V=1.008347, theta=-46.11215 -> V=1.0, theta=0.0
% INFO    : Bus 1526	: V=1.043661, theta=-11.957383 -> V=1.0, theta=0.0
% INFO    : Bus 1531	: V=1.00982, theta=-11.496865 -> V=1.0, theta=0.0
% INFO    : Bus 1538	: V=1.035514, theta=-8.768446 -> V=1.0, theta=0.0
% INFO    : Bus 1539	: V=1.059767, theta=-15.313651 -> V=1.0, theta=0.0
% INFO    : Bus 1541	: V=1.051628, theta=-23.909822 -> V=1.0, theta=0.0
% INFO    : Bus 1543	: V=0.993828, theta=-49.272761 -> V=1.0, theta=0.0
% INFO    : Bus 1545	: V=1.041665, theta=-23.501941 -> V=1.0, theta=0.0
% INFO    : Bus 1547	: V=1.038027, theta=-15.068933 -> V=1.0, theta=0.0
% INFO    : Bus 1549	: V=1.021156, theta=-52.883236 -> V=1.0, theta=0.0
% INFO    : Bus 1551	: V=1.042613, theta=-20.44489 -> V=1.0, theta=0.0
% INFO    : Bus 1552	: V=1.042022, theta=-16.638586 -> V=1.0, theta=0.0
% INFO    : Bus 1554	: V=1.020362, theta=-16.068621 -> V=1.0, theta=0.0
% INFO    : Bus 1556	: V=1.063865, theta=-11.487753 -> V=1.0, theta=0.0
% INFO    : Bus 1562	: V=1.040689, theta=-25.900148 -> V=1.0, theta=0.0
% INFO    : Bus 1564	: V=1.017809, theta=7.583606 -> V=1.0, theta=0.0
% INFO    : Bus 1566	: V=1.035654, theta=-24.787616 -> V=1.0, theta=0.0
% INFO    : Bus 1568	: V=1.045321, theta=-25.198298 -> V=1.0, theta=0.0
% INFO    : Bus 1570	: V=1.079057, theta=-35.031052 -> V=1.0, theta=0.0
% INFO    : Bus 1578	: V=1.041117, theta=-12.03536 -> V=1.0, theta=0.0
% INFO    : Bus 1579	: V=1.001361, theta=-5.002873 -> V=1.0, theta=0.0
% INFO    : Bus 1584	: V=1.028531, theta=-14.301081 -> V=1.0, theta=0.0
% INFO    : Bus 1591	: V=1.01399, theta=17.300476 -> V=1.0, theta=0.0
% INFO    : Bus 1592	: V=1.041196, theta=-2.388101 -> V=1.0, theta=0.0
% INFO    : Bus 1595	: V=1.015775, theta=-29.314866 -> V=1.0, theta=0.0
% INFO    : Bus 1597	: V=1.022686, theta=14.250036 -> V=1.0, theta=0.0
% INFO    : Bus 1599	: V=1.014966, theta=-48.210953 -> V=1.0, theta=0.0
% INFO    : Bus 1600	: V=1.030988, theta=-53.564846 -> V=1.0, theta=0.0
% INFO    : Bus 1602	: V=1.015546, theta=-59.838921 -> V=1.0, theta=0.0
% INFO    : Bus 1604	: V=1.044277, theta=-6.654391 -> V=1.0, theta=0.0
% INFO    : Bus 1605	: V=1.075745, theta=-24.387924 -> V=1.0, theta=0.0
% INFO    : Bus 1607	: V=1.026752, theta=-5.477294 -> V=1.0, theta=0.0
% INFO    : Bus 1609	: V=1.049223, theta=-20.706157 -> V=1.0, theta=0.0
% INFO    : Bus 1611	: V=1.050807, theta=-9.150756 -> V=1.0, theta=0.0
% INFO    : Bus 1616	: V=1.003428, theta=-3.942054 -> V=1.0, theta=0.0
% INFO    : Bus 1618	: V=1.079319, theta=-43.562064 -> V=1.0, theta=0.0
% INFO    : Bus 1625	: V=1.043133, theta=-19.969473 -> V=1.0, theta=0.0
% INFO    : Bus 1629	: V=1.044497, theta=-11.070857 -> V=1.0, theta=0.0
% INFO    : Bus 1632	: V=1.024746, theta=-52.071172 -> V=1.0, theta=0.0
% INFO    : Bus 1633	: V=1.012918, theta=16.991789 -> V=1.0, theta=0.0
% INFO    : Bus 1635	: V=1.015425, theta=10.923415 -> V=1.0, theta=0.0
% INFO    : Bus 1638	: V=1.029115, theta=-53.706686 -> V=1.0, theta=0.0
% INFO    : Bus 1639	: V=1.032136, theta=-52.870728 -> V=1.0, theta=0.0
% INFO    : Bus 1642	: V=1.031925, theta=0.361584 -> V=1.0, theta=0.0
% INFO    : Bus 1643	: V=1.040729, theta=-25.9337 -> V=1.0, theta=0.0
% INFO    : Bus 1644	: V=1.049584, theta=3.538596 -> V=1.0, theta=0.0
% INFO    : Bus 1645	: V=1.028996, theta=-53.918767 -> V=1.0, theta=0.0
% INFO    : Bus 1662	: V=1.044929, theta=-20.83595 -> V=1.0, theta=0.0
% INFO    : Bus 1666	: V=1.010007, theta=-47.695122 -> V=1.0, theta=0.0
% INFO    : Bus 1670	: V=1.021732, theta=-0.338232 -> V=1.0, theta=0.0
% INFO    : Bus 1672	: V=1.063888, theta=-11.501012 -> V=1.0, theta=0.0
% INFO    : Bus 1676	: V=0.993902, theta=-1.396138 -> V=1.0, theta=0.0
% INFO    : Bus 1680	: V=1.044209, theta=-2.249484 -> V=1.0, theta=0.0
% INFO    : Bus 1685	: V=1.005778, theta=-37.621541 -> V=1.0, theta=0.0
% INFO    : Bus 1689	: V=1.033205, theta=11.513144 -> V=1.0, theta=0.0
% INFO    : Bus 1692	: V=1.047517, theta=-10.481325 -> V=1.0, theta=0.0
% INFO    : Bus 1697	: V=1.041486, theta=-50.115438 -> V=1.0, theta=0.0
% INFO    : Bus 1702	: V=1.035777, theta=4.260134 -> V=1.0, theta=0.0
% INFO    : Bus 1703	: V=1.05922, theta=-43.51259 -> V=1.0, theta=0.0
% INFO    : Bus 1704	: V=1.043162, theta=-13.087499 -> V=1.0, theta=0.0
% INFO    : Bus 1708	: V=1.037844, theta=-13.203761 -> V=1.0, theta=0.0
% INFO    : Bus 1709	: V=1.006049, theta=-14.735655 -> V=1.0, theta=0.0
% INFO    : Bus 1711	: V=1.047493, theta=-29.9792 -> V=1.0, theta=0.0
% INFO    : Bus 1716	: V=1.025999, theta=-40.615588 -> V=1.0, theta=0.0
% INFO    : Bus 1721	: V=1.061536, theta=2.487523 -> V=1.0, theta=0.0
% INFO    : Bus 1722	: V=1.024592, theta=9.445328 -> V=1.0, theta=0.0
% INFO    : Bus 1728	: V=1.051238, theta=-48.488813 -> V=1.0, theta=0.0
% INFO    : Bus 1730	: V=1.024629, theta=-14.526553 -> V=1.0, theta=0.0
% INFO    : Bus 1734	: V=0.989566, theta=-54.079919 -> V=1.0, theta=0.0
% INFO    : Bus 1741	: V=0.986128, theta=-45.182156 -> V=1.0, theta=0.0
% INFO    : Bus 1742	: V=1.027401, theta=-32.553844 -> V=1.0, theta=0.0
% INFO    : Bus 1746	: V=1.047833, theta=-24.129867 -> V=1.0, theta=0.0
% INFO    : Bus 1747	: V=1.055274, theta=12.851962 -> V=1.0, theta=0.0
% INFO    : Bus 1750	: V=1.035938, theta=-19.217986 -> V=1.0, theta=0.0
% INFO    : Bus 1752	: V=1.035715, theta=-52.712594 -> V=1.0, theta=0.0
% INFO    : Bus 1754	: V=1.040804, theta=-17.145993 -> V=1.0, theta=0.0
% INFO    : Bus 1758	: V=1.034693, theta=-4.444343 -> V=1.0, theta=0.0
% INFO    : Bus 1763	: V=1.033831, theta=-30.862865 -> V=1.0, theta=0.0
% INFO    : Bus 1767	: V=1.048826, theta=-45.648551 -> V=1.0, theta=0.0
% INFO    : Bus 1768	: V=1.038366, theta=-11.138188 -> V=1.0, theta=0.0
% INFO    : Bus 1769	: V=1.03194, theta=-46.566188 -> V=1.0, theta=0.0
% INFO    : Bus 1770	: V=1.015596, theta=-41.191024 -> V=1.0, theta=0.0
% INFO    : Bus 1774	: V=1.056861, theta=-45.124391 -> V=1.0, theta=0.0
% INFO    : Bus 1775	: V=1.049957, theta=-26.065865 -> V=1.0, theta=0.0
% INFO    : Bus 1777	: V=1.033981, theta=16.473721 -> V=1.0, theta=0.0
% INFO    : Bus 1778	: V=1.012854, theta=16.97545 -> V=1.0, theta=0.0
% INFO    : Bus 1787	: V=1.017619, theta=12.619151 -> V=1.0, theta=0.0
% INFO    : Bus 1788	: V=1.018729, theta=15.891067 -> V=1.0, theta=0.0
% INFO    : Bus 1793	: V=1.023406, theta=-43.929454 -> V=1.0, theta=0.0
% INFO    : Bus 1794	: V=1.052726, theta=-0.25556 -> V=1.0, theta=0.0
% INFO    : Bus 1798	: V=0.981441, theta=-7.400061 -> V=1.0, theta=0.0
% INFO    : Bus 1802	: V=1.004678, theta=-46.035316 -> V=1.0, theta=0.0
% INFO    : Bus 1803	: V=1.038641, theta=-22.064619 -> V=1.0, theta=0.0
% INFO    : Bus 1808	: V=1.047818, theta=-0.83857 -> V=1.0, theta=0.0
% INFO    : Bus 1810	: V=1.037208, theta=17.408937 -> V=1.0, theta=0.0
% INFO    : Bus 1813	: V=1.028777, theta=-7.526931 -> V=1.0, theta=0.0
% INFO    : Bus 1815	: V=1.025638, theta=0.196834 -> V=1.0, theta=0.0
% INFO    : Bus 1817	: V=1.067642, theta=-12.571734 -> V=1.0, theta=0.0
% INFO    : Bus 1833	: V=1.036099, theta=-22.50831 -> V=1.0, theta=0.0
% INFO    : Bus 1836	: V=1.012194, theta=-1.655599 -> V=1.0, theta=0.0
% INFO    : Bus 1838	: V=1.037099, theta=-22.190305 -> V=1.0, theta=0.0
% INFO    : Bus 1841	: V=1.032038, theta=-53.00315 -> V=1.0, theta=0.0
% INFO    : Bus 1844	: V=1.063907, theta=-11.500461 -> V=1.0, theta=0.0
% INFO    : Bus 1848	: V=1.032678, theta=-33.137265 -> V=1.0, theta=0.0
% INFO    : Bus 1850	: V=1.020156, theta=-51.03363 -> V=1.0, theta=0.0
% INFO    : Bus 1851	: V=1.0492, theta=-12.99194 -> V=1.0, theta=0.0
% INFO    : Bus 1852	: V=1.056131, theta=-25.812508 -> V=1.0, theta=0.0
% INFO    : Bus 1857	: V=1.032169, theta=-11.026395 -> V=1.0, theta=0.0
% INFO    : Bus 1860	: V=1.061586, theta=-25.618695 -> V=1.0, theta=0.0
% INFO    : Bus 1862	: V=0.987495, theta=-40.251221 -> V=1.0, theta=0.0
% INFO    : Bus 1866	: V=1.04107, theta=-28.326716 -> V=1.0, theta=0.0
% INFO    : Bus 1868	: V=1.039214, theta=-15.807769 -> V=1.0, theta=0.0
% INFO    : Bus 1869	: V=1.035924, theta=-44.095788 -> V=1.0, theta=0.0
% INFO    : Bus 1870	: V=1.015094, theta=1.339807 -> V=1.0, theta=0.0
% INFO    : Bus 1872	: V=1.029381, theta=-53.816205 -> V=1.0, theta=0.0
% INFO    : Bus 1876	: V=1.030623, theta=-14.259772 -> V=1.0, theta=0.0
% INFO    : Bus 1880	: V=1.009514, theta=0.69841 -> V=1.0, theta=0.0
% INFO    : Bus 1883	: V=1.028511, theta=-16.427961 -> V=1.0, theta=0.0
% INFO    : Bus 1888	: V=1.043102, theta=-2.430762 -> V=1.0, theta=0.0
% INFO    : Bus 1889	: V=1.024264, theta=10.369446 -> V=1.0, theta=0.0
% INFO    : Bus 1890	: V=1.050852, theta=54.166807 -> V=1.0, theta=0.0
% INFO    : Bus 1894	: V=1.02411, theta=-47.579361 -> V=1.0, theta=0.0
% INFO    : Bus 1895	: V=1.067859, theta=7.62397 -> V=1.0, theta=0.0
% INFO    : Bus 1896	: V=1.018399, theta=-6.164969 -> V=1.0, theta=0.0
% INFO    : Bus 1897	: V=1.014095, theta=-60.102849 -> V=1.0, theta=0.0
% INFO    : Bus 1898	: V=1.077705, theta=-35.592551 -> V=1.0, theta=0.0
% INFO    : Bus 1899	: V=1.070541, theta=-46.625448 -> V=1.0, theta=0.0
% INFO    : Bus 1909	: V=1.021788, theta=-39.436854 -> V=1.0, theta=0.0
% INFO    : Bus 1910	: V=1.050804, theta=-6.677369 -> V=1.0, theta=0.0
% INFO    : Bus 1912	: V=0.983155, theta=-44.95221 -> V=1.0, theta=0.0
% INFO    : Bus 1913	: V=1.023641, theta=9.891407 -> V=1.0, theta=0.0
% INFO    : Bus 1914	: V=1.038338, theta=-20.75929 -> V=1.0, theta=0.0
% INFO    : Bus 1917	: V=1.048959, theta=-25.176511 -> V=1.0, theta=0.0
% INFO    : Bus 1923	: V=1.002269, theta=-11.665771 -> V=1.0, theta=0.0
% INFO    : Bus 1936	: V=1.035973, theta=5.613493 -> V=1.0, theta=0.0
% INFO    : Bus 1940	: V=1.035883, theta=-18.056411 -> V=1.0, theta=0.0
% INFO    : Bus 1942	: V=1.016842, theta=-58.849363 -> V=1.0, theta=0.0
% INFO    : Bus 1947	: V=1.056511, theta=-39.920881 -> V=1.0, theta=0.0
% INFO    : Bus 1956	: V=1.064864, theta=30.768271 -> V=1.0, theta=0.0
% INFO    : Bus 1957	: V=1.019244, theta=-48.276935 -> V=1.0, theta=0.0
% INFO    : Bus 1959	: V=1.066953, theta=-10.612706 -> V=1.0, theta=0.0
% INFO    : Bus 1965	: V=1.065913, theta=-49.787032 -> V=1.0, theta=0.0
% INFO    : Bus 1968	: V=1.031762, theta=-10.964931 -> V=1.0, theta=0.0
% INFO    : Bus 1969	: V=1.03098, theta=-53.267997 -> V=1.0, theta=0.0
% INFO    : Bus 1973	: V=1.074344, theta=-26.328901 -> V=1.0, theta=0.0
% INFO    : Bus 1974	: V=0.966737, theta=-43.95225 -> V=1.0, theta=0.0
% INFO    : Bus 1979	: V=1.073367, theta=-33.684297 -> V=1.0, theta=0.0
% INFO    : Bus 1980	: V=1.039678, theta=-21.457316 -> V=1.0, theta=0.0
% INFO    : Bus 1984	: V=1.024246, theta=4.396981 -> V=1.0, theta=0.0
% INFO    : Bus 1985	: V=0.988129, theta=-57.352119 -> V=1.0, theta=0.0
% INFO    : Bus 1989	: V=1.029228, theta=14.956885 -> V=1.0, theta=0.0
% INFO    : Bus 1998	: V=1.032648, theta=-20.169174 -> V=1.0, theta=0.0
% INFO    : Bus 1999	: V=1.080207, theta=-39.478229 -> V=1.0, theta=0.0
% INFO    : Bus 2002	: V=1.087207, theta=32.342614 -> V=1.0, theta=0.0
% INFO    : Bus 2006	: V=1.022687, theta=-38.139249 -> V=1.0, theta=0.0
% INFO    : Bus 2009	: V=1.029527, theta=-50.600329 -> V=1.0, theta=0.0
% INFO    : Bus 2012	: V=1.037869, theta=-18.701859 -> V=1.0, theta=0.0
% INFO    : Bus 2019	: V=1.043225, theta=-21.113594 -> V=1.0, theta=0.0
% INFO    : Bus 2020	: V=1.04955, theta=-24.137238 -> V=1.0, theta=0.0
% INFO    : Bus 2021	: V=1.048571, theta=-25.008749 -> V=1.0, theta=0.0
% INFO    : Bus 2030	: V=1.072679, theta=15.936755 -> V=1.0, theta=0.0
% INFO    : Bus 2031	: V=1.080195, theta=-39.49283 -> V=1.0, theta=0.0
% INFO    : Bus 2035	: V=1.034553, theta=0.621632 -> V=1.0, theta=0.0
% INFO    : Bus 2042	: V=1.041161, theta=-5.936709 -> V=1.0, theta=0.0
% INFO    : Bus 2043	: V=1.045278, theta=-21.03811 -> V=1.0, theta=0.0
% INFO    : Bus 2044	: V=1.033509, theta=-12.417674 -> V=1.0, theta=0.0
% INFO    : Bus 2050	: V=1.008592, theta=-1.119799 -> V=1.0, theta=0.0
% INFO    : Bus 2055	: V=0.99757, theta=-4.666491 -> V=1.0, theta=0.0
% INFO    : Bus 2056	: V=1.034337, theta=-9.107467 -> V=1.0, theta=0.0
% INFO    : Bus 2057	: V=1.04448, theta=-30.995545 -> V=1.0, theta=0.0
% INFO    : Bus 2058	: V=1.056876, theta=-45.124474 -> V=1.0, theta=0.0
% INFO    : Bus 2060	: V=1.01599, theta=-58.09796 -> V=1.0, theta=0.0
% INFO    : Bus 2072	: V=1.061875, theta=-17.377654 -> V=1.0, theta=0.0
% INFO    : Bus 2077	: V=1.026664, theta=11.93662 -> V=1.0, theta=0.0
% INFO    : Bus 2078	: V=1.021844, theta=-14.701929 -> V=1.0, theta=0.0
% INFO    : Bus 2079	: V=1.047339, theta=-12.138161 -> V=1.0, theta=0.0
% INFO    : Bus 2081	: V=0.981221, theta=-48.708598 -> V=1.0, theta=0.0
% INFO    : Bus 2083	: V=1.032804, theta=-18.511366 -> V=1.0, theta=0.0
% INFO    : Bus 2085	: V=1.03273, theta=2.589028 -> V=1.0, theta=0.0
% INFO    : Bus 2088	: V=1.048725, theta=-12.063245 -> V=1.0, theta=0.0
% INFO    : Bus 2089	: V=1.041575, theta=-25.815937 -> V=1.0, theta=0.0
% INFO    : Bus 2091	: V=1.026543, theta=-36.391911 -> V=1.0, theta=0.0
% INFO    : Bus 2093	: V=1.013241, theta=-8.07029 -> V=1.0, theta=0.0
% INFO    : Bus 2096	: V=1.050714, theta=-45.901726 -> V=1.0, theta=0.0
% INFO    : Bus 2101	: V=1.030385, theta=-5.532 -> V=1.0, theta=0.0
% INFO    : Bus 2107	: V=1.048234, theta=-0.02966 -> V=1.0, theta=0.0
% INFO    : Bus 2116	: V=1.027792, theta=-45.963304 -> V=1.0, theta=0.0
% INFO    : Bus 2117	: V=1.023061, theta=-1.382627 -> V=1.0, theta=0.0
% INFO    : Bus 2120	: V=1.023649, theta=9.89143 -> V=1.0, theta=0.0
% INFO    : Bus 2126	: V=1.022588, theta=-52.26225 -> V=1.0, theta=0.0
% INFO    : Bus 2128	: V=1.035853, theta=-23.092097 -> V=1.0, theta=0.0
% INFO    : Bus 2129	: V=1.018774, theta=-8.206837 -> V=1.0, theta=0.0
% INFO    : Bus 2132	: V=1.038784, theta=-15.777605 -> V=1.0, theta=0.0
% INFO    : Bus 2140	: V=0.991354, theta=-52.688498 -> V=1.0, theta=0.0
% INFO    : Bus 2142	: V=1.052708, theta=-7.87962 -> V=1.0, theta=0.0
% INFO    : Bus 2143	: V=0.989853, theta=-43.142584 -> V=1.0, theta=0.0
% INFO    : Bus 2147	: V=1.01158, theta=-47.47921 -> V=1.0, theta=0.0
% INFO    : Bus 2150	: V=1.064827, theta=23.234609 -> V=1.0, theta=0.0
% INFO    : Bus 2154	: V=1.048188, theta=11.193021 -> V=1.0, theta=0.0
% INFO    : Bus 2155	: V=1.04127, theta=-5.926904 -> V=1.0, theta=0.0
% INFO    : Bus 2161	: V=1.048473, theta=-28.734289 -> V=1.0, theta=0.0
% INFO    : Bus 2166	: V=1.050718, theta=-14.695738 -> V=1.0, theta=0.0
% INFO    : Bus 2168	: V=1.026021, theta=-12.839247 -> V=1.0, theta=0.0
% INFO    : Bus 2172	: V=1.034538, theta=-49.361418 -> V=1.0, theta=0.0
% INFO    : Bus 2174	: V=1.009806, theta=-13.208287 -> V=1.0, theta=0.0
% INFO    : Bus 2177	: V=1.070558, theta=-28.465666 -> V=1.0, theta=0.0
% INFO    : Bus 2180	: V=1.015768, theta=-0.688874 -> V=1.0, theta=0.0
% INFO    : Bus 2183	: V=0.994736, theta=-16.202074 -> V=1.0, theta=0.0
% INFO    : Bus 2188	: V=1.049958, theta=-49.355234 -> V=1.0, theta=0.0
% INFO    : Bus 2189	: V=1.049117, theta=-6.264179 -> V=1.0, theta=0.0
% INFO    : Bus 2193	: V=1.014181, theta=-46.990737 -> V=1.0, theta=0.0
% INFO    : Bus 2197	: V=1.036195, theta=-6.001598 -> V=1.0, theta=0.0
% INFO    : Bus 2202	: V=1.027976, theta=-49.093244 -> V=1.0, theta=0.0
% INFO    : Bus 2206	: V=1.020141, theta=-34.018711 -> V=1.0, theta=0.0
% INFO    : Bus 2208	: V=1.046913, theta=-13.479325 -> V=1.0, theta=0.0
% INFO    : Bus 2225	: V=1.02967, theta=-44.119861 -> V=1.0, theta=0.0
% INFO    : Bus 2228	: V=1.018483, theta=23.24717 -> V=1.0, theta=0.0
% INFO    : Bus 2229	: V=1.060553, theta=-13.095765 -> V=1.0, theta=0.0
% INFO    : Bus 2230	: V=1.036241, theta=-22.50954 -> V=1.0, theta=0.0
% INFO    : Bus 2231	: V=1.049238, theta=1.176377 -> V=1.0, theta=0.0
% INFO    : Bus 2233	: V=0.990149, theta=-55.658191 -> V=1.0, theta=0.0
% INFO    : Bus 2235	: V=1.014556, theta=-44.573367 -> V=1.0, theta=0.0
% INFO    : Bus 2236	: V=1.023164, theta=-42.172116 -> V=1.0, theta=0.0
% INFO    : Bus 2240	: V=1.01274, theta=3.69707 -> V=1.0, theta=0.0
% INFO    : Bus 2242	: V=1.024412, theta=-19.040124 -> V=1.0, theta=0.0
% INFO    : Bus 2248	: V=1.015625, theta=-46.19205 -> V=1.0, theta=0.0
% INFO    : Bus 2252	: V=1.067898, theta=-48.0026 -> V=1.0, theta=0.0
% INFO    : Bus 2261	: V=1.066297, theta=-40.410185 -> V=1.0, theta=0.0
% INFO    : Bus 2267	: V=1.000857, theta=11.93009 -> V=1.0, theta=0.0
% INFO    : Bus 2268	: V=0.997933, theta=-5.134076 -> V=1.0, theta=0.0
% INFO    : Bus 2271	: V=1.021363, theta=11.424715 -> V=1.0, theta=0.0
% INFO    : Bus 2273	: V=1.073962, theta=-26.368106 -> V=1.0, theta=0.0
% INFO    : Bus 2276	: V=1.055141, theta=-23.885692 -> V=1.0, theta=0.0
% INFO    : Bus 2286	: V=1.027113, theta=-8.732478 -> V=1.0, theta=0.0
% INFO    : Bus 2288	: V=1.036625, theta=-8.550708 -> V=1.0, theta=0.0
% INFO    : Bus 2291	: V=1.068687, theta=-10.641009 -> V=1.0, theta=0.0
% INFO    : Bus 2297	: V=1.029726, theta=-53.825044 -> V=1.0, theta=0.0
% INFO    : Bus 2299	: V=1.036701, theta=-11.109317 -> V=1.0, theta=0.0
% INFO    : Bus 2301	: V=1.029153, theta=-53.664396 -> V=1.0, theta=0.0
% INFO    : Bus 2303	: V=1.035356, theta=-15.857907 -> V=1.0, theta=0.0
% INFO    : Bus 2304	: V=1.053621, theta=-25.856227 -> V=1.0, theta=0.0
% INFO    : Bus 2305	: V=1.022377, theta=0.249057 -> V=1.0, theta=0.0
% INFO    : Bus 2308	: V=1.038049, theta=-24.108761 -> V=1.0, theta=0.0
% INFO    : Bus 2313	: V=1.045713, theta=-21.296439 -> V=1.0, theta=0.0
% INFO    : Bus 2319	: V=1.058042, theta=-8.99633 -> V=1.0, theta=0.0
% INFO    : Bus 2327	: V=1.045658, theta=-25.17735 -> V=1.0, theta=0.0
% INFO    : Bus 2328	: V=1.012206, theta=-14.284271 -> V=1.0, theta=0.0
% INFO    : Bus 2330	: V=1.009792, theta=1.255832 -> V=1.0, theta=0.0
% INFO    : Bus 2331	: V=1.015977, theta=19.537852 -> V=1.0, theta=0.0
% INFO    : Bus 2335	: V=1.040978, theta=6.656092 -> V=1.0, theta=0.0
% INFO    : Bus 2337	: V=1.044141, theta=-29.826668 -> V=1.0, theta=0.0
% INFO    : Bus 2340	: V=1.040211, theta=-12.241008 -> V=1.0, theta=0.0
% INFO    : Bus 2341	: V=1.059334, theta=-26.086007 -> V=1.0, theta=0.0
% INFO    : Bus 2343	: V=1.023455, theta=-42.321013 -> V=1.0, theta=0.0
% INFO    : Bus 2350	: V=1.008285, theta=16.440309 -> V=1.0, theta=0.0
% INFO    : Bus 2355	: V=1.020865, theta=-50.666226 -> V=1.0, theta=0.0
% INFO    : Bus 2358	: V=1.029163, theta=-53.685458 -> V=1.0, theta=0.0
% INFO    : Bus 2359	: V=1.025004, theta=-9.912428 -> V=1.0, theta=0.0
% INFO    : Bus 2360	: V=1.039139, theta=-21.221662 -> V=1.0, theta=0.0
% INFO    : Bus 2361	: V=1.047053, theta=-29.210131 -> V=1.0, theta=0.0
% INFO    : Bus 2365	: V=1.03234, theta=-22.207428 -> V=1.0, theta=0.0
% INFO    : Bus 2372	: V=0.990983, theta=-17.504299 -> V=1.0, theta=0.0
% INFO    : Bus 2377	: V=1.032965, theta=-14.916596 -> V=1.0, theta=0.0
% INFO    : Bus 2381	: V=1.032264, theta=5.112304 -> V=1.0, theta=0.0
% INFO    : Bus 2393	: V=1.067851, theta=7.737226 -> V=1.0, theta=0.0
% INFO    : Bus 2403	: V=1.027657, theta=-47.417397 -> V=1.0, theta=0.0
% INFO    : Bus 2406	: V=1.04714, theta=-24.469684 -> V=1.0, theta=0.0
% INFO    : Bus 2407	: V=0.995534, theta=-39.27632 -> V=1.0, theta=0.0
% INFO    : Bus 2410	: V=1.026919, theta=-36.555421 -> V=1.0, theta=0.0
% INFO    : Bus 2412	: V=1.016849, theta=-42.518502 -> V=1.0, theta=0.0
% INFO    : Bus 2416	: V=1.05268, theta=-49.057941 -> V=1.0, theta=0.0
% INFO    : Bus 2421	: V=1.047704, theta=-23.732507 -> V=1.0, theta=0.0
% INFO    : Bus 2424	: V=1.034737, theta=-22.444225 -> V=1.0, theta=0.0
% INFO    : Bus 2425	: V=1.043025, theta=-9.904307 -> V=1.0, theta=0.0
% INFO    : Bus 2426	: V=1.040828, theta=-13.694298 -> V=1.0, theta=0.0
% INFO    : Bus 2428	: V=1.018049, theta=0.563741 -> V=1.0, theta=0.0
% INFO    : Bus 2430	: V=1.037062, theta=-11.923631 -> V=1.0, theta=0.0
% INFO    : Bus 2432	: V=1.027519, theta=-32.362347 -> V=1.0, theta=0.0
% INFO    : Bus 2437	: V=1.063879, theta=-41.501682 -> V=1.0, theta=0.0
% INFO    : Bus 2438	: V=1.045685, theta=-21.296138 -> V=1.0, theta=0.0
% INFO    : Bus 2441	: V=1.001003, theta=-4.783502 -> V=1.0, theta=0.0
% INFO    : Bus 2446	: V=1.053565, theta=7.758341 -> V=1.0, theta=0.0
% INFO    : Bus 2448	: V=1.04676, theta=26.524166 -> V=1.0, theta=0.0
% INFO    : Bus 2449	: V=1.064595, theta=-5.855251 -> V=1.0, theta=0.0
% INFO    : Bus 2457	: V=1.03926, theta=-24.663306 -> V=1.0, theta=0.0
% INFO    : Bus 2458	: V=1.00611, theta=-13.480214 -> V=1.0, theta=0.0
% INFO    : Bus 2459	: V=1.05033, theta=-42.244541 -> V=1.0, theta=0.0
% INFO    : Bus 2460	: V=0.983266, theta=-39.656055 -> V=1.0, theta=0.0
% INFO    : Bus 2467	: V=1.01269, theta=-14.132965 -> V=1.0, theta=0.0
% INFO    : Bus 2468	: V=1.049474, theta=-6.197025 -> V=1.0, theta=0.0
% INFO    : Bus 2471	: V=1.017576, theta=-47.068239 -> V=1.0, theta=0.0
% INFO    : Bus 2475	: V=1.062881, theta=-7.838877 -> V=1.0, theta=0.0
% INFO    : Bus 2478	: V=1.029979, theta=15.795765 -> V=1.0, theta=0.0
% INFO    : Bus 2479	: V=1.007738, theta=-2.60887 -> V=1.0, theta=0.0
% INFO    : Bus 2481	: V=1.041748, theta=-18.217854 -> V=1.0, theta=0.0
% INFO    : Bus 2482	: V=1.023631, theta=8.63119 -> V=1.0, theta=0.0
% INFO    : Bus 2489	: V=1.049212, theta=1.176689 -> V=1.0, theta=0.0
% INFO    : Bus 2494	: V=1.013245, theta=0.963784 -> V=1.0, theta=0.0
% INFO    : Bus 2496	: V=1.016225, theta=-60.163857 -> V=1.0, theta=0.0
% INFO    : Bus 2497	: V=0.981207, theta=-55.903537 -> V=1.0, theta=0.0
% INFO    : Bus 2503	: V=1.012625, theta=-21.505114 -> V=1.0, theta=0.0
% INFO    : Bus 2504	: V=1.009312, theta=-45.199119 -> V=1.0, theta=0.0
% INFO    : Bus 2507	: V=1.066743, theta=-41.368798 -> V=1.0, theta=0.0
% INFO    : Bus 2510	: V=1.02733, theta=-12.091763 -> V=1.0, theta=0.0
% INFO    : Bus 2517	: V=1.017237, theta=-44.572173 -> V=1.0, theta=0.0
% INFO    : Bus 2518	: V=0.998925, theta=-11.524637 -> V=1.0, theta=0.0
% INFO    : Bus 2520	: V=0.997433, theta=-4.735085 -> V=1.0, theta=0.0
% INFO    : Bus 2523	: V=1.045749, theta=26.39537 -> V=1.0, theta=0.0
% INFO    : Bus 2526	: V=1.042721, theta=-19.883704 -> V=1.0, theta=0.0
% INFO    : Bus 2527	: V=1.039168, theta=-4.615105 -> V=1.0, theta=0.0
% INFO    : Bus 2535	: V=1.041259, theta=-2.946934 -> V=1.0, theta=0.0
% INFO    : Bus 2538	: V=1.017121, theta=-43.487032 -> V=1.0, theta=0.0
% INFO    : Bus 2549	: V=1.049693, theta=-3.110388 -> V=1.0, theta=0.0
% INFO    : Bus 2550	: V=1.050935, theta=-6.648649 -> V=1.0, theta=0.0
% INFO    : Bus 2551	: V=1.011995, theta=-60.510986 -> V=1.0, theta=0.0
% INFO    : Bus 2552	: V=1.036643, theta=4.553272 -> V=1.0, theta=0.0
% INFO    : Bus 2555	: V=1.056627, theta=12.502131 -> V=1.0, theta=0.0
% INFO    : Bus 2558	: V=1.024168, theta=-16.655732 -> V=1.0, theta=0.0
% INFO    : Bus 2562	: V=1.003073, theta=-51.388077 -> V=1.0, theta=0.0
% INFO    : Bus 2563	: V=1.042342, theta=-4.677762 -> V=1.0, theta=0.0
% INFO    : Bus 2564	: V=1.031089, theta=-53.04439 -> V=1.0, theta=0.0
% INFO    : Bus 2566	: V=1.040492, theta=-44.635228 -> V=1.0, theta=0.0
% INFO    : Bus 2572	: V=1.044905, theta=17.443246 -> V=1.0, theta=0.0
% INFO    : Bus 2575	: V=1.033526, theta=-2.681692 -> V=1.0, theta=0.0
% INFO    : Bus 2591	: V=1.031532, theta=-15.253656 -> V=1.0, theta=0.0
% INFO    : Bus 2597	: V=1.035529, theta=-10.83031 -> V=1.0, theta=0.0
% INFO    : Bus 2598	: V=1.040309, theta=-15.280276 -> V=1.0, theta=0.0
% INFO    : Bus 2600	: V=1.041924, theta=-13.574935 -> V=1.0, theta=0.0
% INFO    : Bus 2616	: V=1.035313, theta=5.493092 -> V=1.0, theta=0.0
% INFO    : Bus 2619	: V=1.016786, theta=6.309895 -> V=1.0, theta=0.0
% INFO    : Bus 2622	: V=1.04898, theta=-49.357142 -> V=1.0, theta=0.0
% INFO    : Bus 2627	: V=1.052984, theta=7.725147 -> V=1.0, theta=0.0
% INFO    : Bus 2629	: V=1.043972, theta=-24.533846 -> V=1.0, theta=0.0
% INFO    : Bus 2641	: V=1.043147, theta=-11.261777 -> V=1.0, theta=0.0
% INFO    : Bus 2642	: V=1.054923, theta=-36.938161 -> V=1.0, theta=0.0
% INFO    : Bus 2644	: V=1.073301, theta=-24.836211 -> V=1.0, theta=0.0
% INFO    : Bus 2648	: V=1.048915, theta=11.107878 -> V=1.0, theta=0.0
% INFO    : Bus 2653	: V=1.036409, theta=-23.037279 -> V=1.0, theta=0.0
% INFO    : Bus 2654	: V=1.01876, theta=-18.768622 -> V=1.0, theta=0.0
% INFO    : Bus 2656	: V=1.032684, theta=-22.83602 -> V=1.0, theta=0.0
% INFO    : Bus 2658	: V=1.026597, theta=-48.776737 -> V=1.0, theta=0.0
% INFO    : Bus 2660	: V=1.013897, theta=-31.381581 -> V=1.0, theta=0.0
% INFO    : Bus 2667	: V=1.033098, theta=-52.916082 -> V=1.0, theta=0.0
% INFO    : Bus 2668	: V=1.021145, theta=-43.98353 -> V=1.0, theta=0.0
% INFO    : Bus 2676	: V=1.0367, theta=-14.939386 -> V=1.0, theta=0.0
% INFO    : Bus 2686	: V=1.020441, theta=-42.467961 -> V=1.0, theta=0.0
% INFO    : Bus 2689	: V=1.03773, theta=-3.261785 -> V=1.0, theta=0.0
% INFO    : Bus 2692	: V=0.989518, theta=-54.065312 -> V=1.0, theta=0.0
% INFO    : Bus 2695	: V=1.037346, theta=-21.040609 -> V=1.0, theta=0.0
% INFO    : Bus 2698	: V=1.03424, theta=25.891078 -> V=1.0, theta=0.0
% INFO    : Bus 2700	: V=1.035125, theta=-38.951268 -> V=1.0, theta=0.0
% INFO    : Bus 2702	: V=1.041685, theta=-25.654435 -> V=1.0, theta=0.0
% INFO    : Bus 2703	: V=1.033424, theta=9.303066 -> V=1.0, theta=0.0
% INFO    : Bus 2708	: V=1.015434, theta=-0.677624 -> V=1.0, theta=0.0
% INFO    : Bus 2719	: V=1.039499, theta=-15.429073 -> V=1.0, theta=0.0
% INFO    : Bus 2720	: V=1.017103, theta=17.754983 -> V=1.0, theta=0.0
% INFO    : Bus 2721	: V=0.978984, theta=-22.513554 -> V=1.0, theta=0.0
% INFO    : Bus 2722	: V=1.016299, theta=8.152212 -> V=1.0, theta=0.0
% INFO    : Bus 2728	: V=1.04666, theta=26.481466 -> V=1.0, theta=0.0
% INFO    : Bus 2730	: V=1.045043, theta=-43.518515 -> V=1.0, theta=0.0
% INFO    : Bus 2732	: V=1.008534, theta=-10.041961 -> V=1.0, theta=0.0
% INFO    : Bus 2734	: V=0.995157, theta=-47.721211 -> V=1.0, theta=0.0
% INFO    : Bus 2740	: V=1.029789, theta=-53.804959 -> V=1.0, theta=0.0
% INFO    : Bus 2745	: V=1.007399, theta=-3.385125 -> V=1.0, theta=0.0
% INFO    : Bus 2748	: V=1.003257, theta=-3.866665 -> V=1.0, theta=0.0
% INFO    : Bus 2749	: V=1.044722, theta=-30.340412 -> V=1.0, theta=0.0
% INFO    : Bus 2751	: V=1.041213, theta=-21.928696 -> V=1.0, theta=0.0
% INFO    : Bus 2754	: V=1.049456, theta=-13.383761 -> V=1.0, theta=0.0
% INFO    : Bus 2760	: V=1.017866, theta=4.65043 -> V=1.0, theta=0.0
% INFO    : Bus 2764	: V=1.05096, theta=-48.880173 -> V=1.0, theta=0.0
% INFO    : Bus 2769	: V=1.027942, theta=26.266559 -> V=1.0, theta=0.0
% INFO    : Bus 2770	: V=1.049338, theta=-9.678721 -> V=1.0, theta=0.0
% INFO    : Bus 2782	: V=1.063907, theta=-11.500188 -> V=1.0, theta=0.0
% INFO    : Bus 2785	: V=0.983777, theta=-49.755212 -> V=1.0, theta=0.0
% INFO    : Bus 2786	: V=1.069288, theta=6.564216 -> V=1.0, theta=0.0
% INFO    : Bus 2794	: V=1.032808, theta=-18.511406 -> V=1.0, theta=0.0
% INFO    : Bus 2795	: V=1.068855, theta=-32.501298 -> V=1.0, theta=0.0
% INFO    : Bus 2796	: V=1.032852, theta=9.264863 -> V=1.0, theta=0.0
% INFO    : Bus 2797	: V=1.044662, theta=-4.476602 -> V=1.0, theta=0.0
% INFO    : Bus 2799	: V=1.055463, theta=-12.420614 -> V=1.0, theta=0.0
% INFO    : Bus 2800	: V=1.030206, theta=-48.37868 -> V=1.0, theta=0.0
% INFO    : Bus 2801	: V=1.040225, theta=-24.54678 -> V=1.0, theta=0.0
% INFO    : Bus 2804	: V=1.026472, theta=12.978183 -> V=1.0, theta=0.0
% INFO    : Bus 2806	: V=1.050487, theta=0.178503 -> V=1.0, theta=0.0
% INFO    : Bus 2812	: V=1.012846, theta=16.975428 -> V=1.0, theta=0.0
% INFO    : Bus 2815	: V=1.036427, theta=-23.013761 -> V=1.0, theta=0.0
% INFO    : Bus 2816	: V=1.054536, theta=-0.415457 -> V=1.0, theta=0.0
% INFO    : Bus 2817	: V=0.991705, theta=-46.059108 -> V=1.0, theta=0.0
% INFO    : Bus 2824	: V=1.029264, theta=17.813781 -> V=1.0, theta=0.0
% INFO    : Bus 2832	: V=1.019303, theta=12.490936 -> V=1.0, theta=0.0
% INFO    : Bus 2841	: V=1.079986, theta=-26.265078 -> V=1.0, theta=0.0
% INFO    : Bus 2842	: V=1.044122, theta=-6.664319 -> V=1.0, theta=0.0
% INFO    : Bus 2844	: V=1.011346, theta=-45.900522 -> V=1.0, theta=0.0
% INFO    : Bus 2847	: V=1.046169, theta=-3.919284 -> V=1.0, theta=0.0
% INFO    : Bus 2848	: V=0.998548, theta=-7.849319 -> V=1.0, theta=0.0
% INFO    : Bus 2849	: V=1.040792, theta=-42.513227 -> V=1.0, theta=0.0
% INFO    : Bus 2850	: V=1.030335, theta=-18.770897 -> V=1.0, theta=0.0
% INFO    : Bus 2853	: V=1.000604, theta=-35.710618 -> V=1.0, theta=0.0
% INFO    : Bus 2854	: V=1.046183, theta=-10.741328 -> V=1.0, theta=0.0
% INFO    : Bus 2863	: V=1.031964, theta=-11.04501 -> V=1.0, theta=0.0
% INFO    : Bus 2866	: V=1.038006, theta=-7.282246 -> V=1.0, theta=0.0
% INFO    : Bus 2870	: V=1.019244, theta=5.129193 -> V=1.0, theta=0.0
% INFO    : Bus 2872	: V=1.060615, theta=-10.673863 -> V=1.0, theta=0.0
% INFO    : Bus 2877	: V=1.041957, theta=-14.91571 -> V=1.0, theta=0.0
% INFO    : Bus 2878	: V=1.05418, theta=-10.996458 -> V=1.0, theta=0.0
% INFO    : Bus 2886	: V=1.052878, theta=-14.148238 -> V=1.0, theta=0.0
% INFO    : Bus 2888	: V=1.013491, theta=-21.281344 -> V=1.0, theta=0.0
% INFO    : Bus 2889	: V=1.051468, theta=-1.112479 -> V=1.0, theta=0.0
% INFO    : Bus 2894	: V=1.001352, theta=-38.531811 -> V=1.0, theta=0.0
% INFO    : Bus 2896	: V=1.011629, theta=-44.09682 -> V=1.0, theta=0.0
% INFO    : Bus 2898	: V=1.035736, theta=-23.099879 -> V=1.0, theta=0.0
% INFO    : Bus 2899	: V=1.055839, theta=-44.433529 -> V=1.0, theta=0.0
% INFO    : Bus 2900	: V=1.035777, theta=4.260134 -> V=1.0, theta=0.0
% INFO    : Bus 2902	: V=1.061022, theta=-23.402903 -> V=1.0, theta=0.0
% INFO    : Bus 2907	: V=1.023741, theta=-48.101415 -> V=1.0, theta=0.0
% INFO    : Bus 2908	: V=1.026635, theta=-10.516686 -> V=1.0, theta=0.0
% INFO    : Bus 2910	: V=1.044227, theta=-2.315624 -> V=1.0, theta=0.0
% INFO    : Bus 2913	: V=1.065675, theta=-41.45215 -> V=1.0, theta=0.0
% INFO    : Bus 2916	: V=1.049753, theta=-37.87224 -> V=1.0, theta=0.0
% INFO    : Bus 2917	: V=1.023967, theta=-46.506929 -> V=1.0, theta=0.0
% INFO    : Bus 2918	: V=1.019273, theta=-28.176889 -> V=1.0, theta=0.0
% INFO    : Bus 2919	: V=0.991102, theta=-18.332113 -> V=1.0, theta=0.0
% INFO    : Bus 2921	: V=1.008526, theta=-40.282483 -> V=1.0, theta=0.0
% INFO    : Bus 2924	: V=1.040977, theta=-33.52648 -> V=1.0, theta=0.0
% INFO    : Bus 2927	: V=1.049719, theta=18.392275 -> V=1.0, theta=0.0
% INFO    : Bus 2928	: V=1.07417, theta=-26.364596 -> V=1.0, theta=0.0
% INFO    : Bus 2930	: V=1.049271, theta=-12.977156 -> V=1.0, theta=0.0
% INFO    : Bus 2931	: V=1.042827, theta=-32.310096 -> V=1.0, theta=0.0
% INFO    : Bus 2934	: V=1.052968, theta=-6.51468 -> V=1.0, theta=0.0
% INFO    : Bus 2938	: V=1.006614, theta=-7.445421 -> V=1.0, theta=0.0
% INFO    : Bus 2940	: V=1.011513, theta=-14.38638 -> V=1.0, theta=0.0
% INFO    : Bus 2946	: V=1.020023, theta=-45.610776 -> V=1.0, theta=0.0
% INFO    : Bus 2949	: V=1.049798, theta=-4.843132 -> V=1.0, theta=0.0
% INFO    : Bus 2951	: V=1.015286, theta=-53.686825 -> V=1.0, theta=0.0
% INFO    : Bus 2954	: V=0.98995, theta=-55.678384 -> V=1.0, theta=0.0
% INFO    : Bus 2957	: V=1.027698, theta=-38.781315 -> V=1.0, theta=0.0
% INFO    : Bus 2961	: V=1.040418, theta=-24.431519 -> V=1.0, theta=0.0
% INFO    : Bus 2962	: V=1.067192, theta=-42.399748 -> V=1.0, theta=0.0
% INFO    : Bus 2965	: V=1.030784, theta=18.259396 -> V=1.0, theta=0.0
% INFO    : Bus 2967	: V=1.045595, theta=-17.104 -> V=1.0, theta=0.0
% INFO    : Bus 2968	: V=1.045486, theta=-8.969477 -> V=1.0, theta=0.0
% INFO    : Bus 2971	: V=0.993315, theta=-6.019917 -> V=1.0, theta=0.0
% INFO    : Bus 2972	: V=1.035382, theta=-15.090981 -> V=1.0, theta=0.0
% INFO    : Bus 2974	: V=1.008087, theta=-2.426628 -> V=1.0, theta=0.0
% INFO    : Bus 2978	: V=1.024856, theta=-48.16715 -> V=1.0, theta=0.0
% INFO    : Bus 2980	: V=1.062898, theta=-9.075961 -> V=1.0, theta=0.0
% INFO    : Bus 2981	: V=1.07476, theta=-15.345009 -> V=1.0, theta=0.0
% INFO    : Bus 2985	: V=1.05077, theta=-8.481817 -> V=1.0, theta=0.0
% INFO    : Bus 2995	: V=1.047304, theta=-3.731029 -> V=1.0, theta=0.0
% INFO    : Bus 3000	: V=1.017706, theta=15.028535 -> V=1.0, theta=0.0
% INFO    : Bus 3007	: V=1.031803, theta=-51.698634 -> V=1.0, theta=0.0
% INFO    : Bus 3008	: V=1.021743, theta=-45.9053 -> V=1.0, theta=0.0
% INFO    : Bus 3013	: V=1.04929, theta=-5.249851 -> V=1.0, theta=0.0
% INFO    : Bus 3018	: V=1.043371, theta=-12.865081 -> V=1.0, theta=0.0
% INFO    : Bus 3019	: V=1.036683, theta=-22.79236 -> V=1.0, theta=0.0
% INFO    : Bus 3021	: V=1.043451, theta=-11.465032 -> V=1.0, theta=0.0
% INFO    : Bus 3022	: V=1.038179, theta=-14.947144 -> V=1.0, theta=0.0
% INFO    : Bus 3023	: V=0.997435, theta=8.718509 -> V=1.0, theta=0.0
% INFO    : Bus 3027	: V=1.030907, theta=-53.059141 -> V=1.0, theta=0.0
% INFO    : Bus 3028	: V=1.034318, theta=0.53384 -> V=1.0, theta=0.0
% INFO    : Bus 3036	: V=1.045271, theta=-25.21954 -> V=1.0, theta=0.0
% INFO    : Bus 3037	: V=1.050303, theta=-6.606462 -> V=1.0, theta=0.0
% INFO    : Bus 3044	: V=1.039563, theta=-21.150198 -> V=1.0, theta=0.0
% INFO    : Bus 3047	: V=1.01916, theta=2.829744 -> V=1.0, theta=0.0
% INFO    : Bus 3051	: V=1.032503, theta=-24.998397 -> V=1.0, theta=0.0
% INFO    : Bus 3054	: V=0.999852, theta=-51.274579 -> V=1.0, theta=0.0
% INFO    : Bus 3061	: V=1.035223, theta=-47.778687 -> V=1.0, theta=0.0
% INFO    : Bus 3063	: V=1.015747, theta=-45.233586 -> V=1.0, theta=0.0
% INFO    : Bus 3065	: V=1.027992, theta=-54.17571 -> V=1.0, theta=0.0
% INFO    : Bus 3066	: V=1.028937, theta=-53.939129 -> V=1.0, theta=0.0
% INFO    : Bus 3067	: V=1.027656, theta=-41.914357 -> V=1.0, theta=0.0
% INFO    : Bus 3069	: V=1.035723, theta=-8.751882 -> V=1.0, theta=0.0
% INFO    : Bus 3070	: V=1.013485, theta=-21.281298 -> V=1.0, theta=0.0
% INFO    : Bus 3071	: V=1.04631, theta=-7.264593 -> V=1.0, theta=0.0
% INFO    : Bus 3072	: V=1.045476, theta=-30.312476 -> V=1.0, theta=0.0
% INFO    : Bus 3075	: V=1.019161, theta=-16.90632 -> V=1.0, theta=0.0
% INFO    : Bus 3076	: V=1.014367, theta=-47.584034 -> V=1.0, theta=0.0
% INFO    : Bus 3080	: V=1.064383, theta=-47.252271 -> V=1.0, theta=0.0
% INFO    : Bus 3082	: V=0.997398, theta=-15.135632 -> V=1.0, theta=0.0
% INFO    : Bus 3083	: V=1.067624, theta=-27.680721 -> V=1.0, theta=0.0
% INFO    : Bus 3085	: V=1.066452, theta=-27.737369 -> V=1.0, theta=0.0
% INFO    : Bus 3095	: V=1.013045, theta=-53.928694 -> V=1.0, theta=0.0
% INFO    : Bus 3097	: V=1.0203, theta=4.509568 -> V=1.0, theta=0.0
% INFO    : Bus 3106	: V=1.053068, theta=-45.074265 -> V=1.0, theta=0.0
% INFO    : Bus 3109	: V=1.0195, theta=-42.362846 -> V=1.0, theta=0.0
% INFO    : Bus 3111	: V=1.033059, theta=-42.130088 -> V=1.0, theta=0.0
% INFO    : Bus 3112	: V=1.05568, theta=2.418195 -> V=1.0, theta=0.0
% INFO    : Bus 3113	: V=1.072644, theta=-37.775694 -> V=1.0, theta=0.0
% INFO    : Bus 3114	: V=1.0681, theta=-11.639685 -> V=1.0, theta=0.0
% INFO    : Bus 3119	: V=1.024432, theta=9.444867 -> V=1.0, theta=0.0
% INFO    : Bus 3121	: V=1.030975, theta=-7.223321 -> V=1.0, theta=0.0
% INFO    : Bus 3125	: V=1.01835, theta=-39.759339 -> V=1.0, theta=0.0
% INFO    : Bus 3126	: V=1.022207, theta=-17.916791 -> V=1.0, theta=0.0
% INFO    : Bus 3133	: V=1.061763, theta=-9.179778 -> V=1.0, theta=0.0
% INFO    : Bus 3134	: V=1.02503, theta=-15.762659 -> V=1.0, theta=0.0
% INFO    : Bus 3137	: V=1.059334, theta=-26.086008 -> V=1.0, theta=0.0
% INFO    : Bus 3145	: V=0.990925, theta=-41.332117 -> V=1.0, theta=0.0
% INFO    : Bus 3148	: V=1.032522, theta=3.857451 -> V=1.0, theta=0.0
% INFO    : Bus 3150	: V=1.017094, theta=-47.936998 -> V=1.0, theta=0.0
% INFO    : Bus 3157	: V=1.023658, theta=-37.534265 -> V=1.0, theta=0.0
% INFO    : Bus 3163	: V=1.006379, theta=-47.142629 -> V=1.0, theta=0.0
% INFO    : Bus 3166	: V=1.039311, theta=-17.540223 -> V=1.0, theta=0.0
% INFO    : Bus 3169	: V=1.033678, theta=4.168232 -> V=1.0, theta=0.0
% INFO    : Bus 3177	: V=1.018336, theta=7.592426 -> V=1.0, theta=0.0
% INFO    : Bus 3178	: V=1.041131, theta=-45.048845 -> V=1.0, theta=0.0
% INFO    : Bus 3182	: V=1.024246, theta=4.396981 -> V=1.0, theta=0.0
% INFO    : Bus 3183	: V=1.056991, theta=-11.898771 -> V=1.0, theta=0.0
% INFO    : Bus 3184	: V=1.038993, theta=-21.374036 -> V=1.0, theta=0.0
% INFO    : Bus 3186	: V=1.019225, theta=-33.185258 -> V=1.0, theta=0.0
% INFO    : Bus 3187	: V=1.039446, theta=-12.967806 -> V=1.0, theta=0.0
% INFO    : Bus 3190	: V=1.03268, theta=13.864056 -> V=1.0, theta=0.0
% INFO    : Bus 3191	: V=1.041406, theta=-12.076173 -> V=1.0, theta=0.0
% INFO    : Bus 3193	: V=1.070508, theta=-43.086559 -> V=1.0, theta=0.0
% INFO    : Bus 3200	: V=1.03606, theta=-23.08282 -> V=1.0, theta=0.0
% INFO    : Bus 3204	: V=1.01902, theta=-10.232717 -> V=1.0, theta=0.0
% INFO    : Bus 3205	: V=1.03763, theta=-1.224853 -> V=1.0, theta=0.0
% INFO    : Bus 3206	: V=1.034144, theta=10.259726 -> V=1.0, theta=0.0
% INFO    : Bus 3210	: V=1.009835, theta=6.952975 -> V=1.0, theta=0.0
% INFO    : Bus 3211	: V=1.007781, theta=-44.247841 -> V=1.0, theta=0.0
% INFO    : Bus 3215	: V=1.002866, theta=-3.944884 -> V=1.0, theta=0.0
% INFO    : Bus 3216	: V=1.001722, theta=-4.072981 -> V=1.0, theta=0.0
% INFO    : Bus 3218	: V=1.032146, theta=-11.223745 -> V=1.0, theta=0.0
% INFO    : Bus 3221	: V=1.044182, theta=-12.158598 -> V=1.0, theta=0.0
% INFO    : Bus 3224	: V=1.049779, theta=28.300405 -> V=1.0, theta=0.0
% INFO    : Bus 3231	: V=1.025874, theta=-14.296903 -> V=1.0, theta=0.0
% INFO    : Bus 3233	: V=1.012423, theta=-45.745678 -> V=1.0, theta=0.0
% INFO    : Bus 3239	: V=1.055998, theta=-11.619498 -> V=1.0, theta=0.0
% INFO    : Bus 3240	: V=1.051571, theta=-1.124291 -> V=1.0, theta=0.0
% INFO    : Bus 3241	: V=1.03022, theta=-17.948598 -> V=1.0, theta=0.0
% INFO    : Bus 3242	: V=1.059624, theta=-9.310952 -> V=1.0, theta=0.0
% INFO    : Bus 3243	: V=0.990149, theta=-18.204781 -> V=1.0, theta=0.0
% INFO    : Bus 3246	: V=1.078316, theta=7.898222 -> V=1.0, theta=0.0
% INFO    : Bus 3248	: V=1.05675, theta=-11.335696 -> V=1.0, theta=0.0
% INFO    : Bus 3255	: V=1.038641, theta=-22.064617 -> V=1.0, theta=0.0
% INFO    : Bus 3256	: V=1.041573, theta=-51.256261 -> V=1.0, theta=0.0
% INFO    : Bus 3257	: V=1.045223, theta=13.616401 -> V=1.0, theta=0.0
% INFO    : Bus 3265	: V=1.035215, theta=-51.062654 -> V=1.0, theta=0.0
% INFO    : Bus 3266	: V=0.989841, theta=-53.987659 -> V=1.0, theta=0.0
% INFO    : Bus 3268	: V=1.046344, theta=-39.42253 -> V=1.0, theta=0.0
% INFO    : Bus 3275	: V=1.046626, theta=-42.734675 -> V=1.0, theta=0.0
% INFO    : Bus 3276	: V=1.052405, theta=-7.871112 -> V=1.0, theta=0.0
% INFO    : Bus 3279	: V=1.004923, theta=-2.703149 -> V=1.0, theta=0.0
% INFO    : Bus 3280	: V=1.006907, theta=-3.391392 -> V=1.0, theta=0.0
% INFO    : Bus 3282	: V=1.021422, theta=-56.880436 -> V=1.0, theta=0.0
% INFO    : Bus 3291	: V=1.027251, theta=-44.134036 -> V=1.0, theta=0.0
% INFO    : Bus 3293	: V=1.039346, theta=-11.406773 -> V=1.0, theta=0.0
% INFO    : Bus 3299	: V=1.018099, theta=7.959711 -> V=1.0, theta=0.0
% INFO    : Bus 3301	: V=1.006897, theta=-3.141399 -> V=1.0, theta=0.0
% INFO    : Bus 3306	: V=1.069265, theta=8.119243 -> V=1.0, theta=0.0
% INFO    : Bus 3314	: V=1.031936, theta=4.19826 -> V=1.0, theta=0.0
% INFO    : Bus 3324	: V=1.016523, theta=-16.112897 -> V=1.0, theta=0.0
% INFO    : Bus 3325	: V=1.033352, theta=-20.083581 -> V=1.0, theta=0.0
% INFO    : Bus 3327	: V=1.034449, theta=-12.168575 -> V=1.0, theta=0.0
% INFO    : Bus 3331	: V=1.019496, theta=-10.181699 -> V=1.0, theta=0.0
% INFO    : Bus 3334	: V=1.03247, theta=-38.167816 -> V=1.0, theta=0.0
% INFO    : Bus 3335	: V=1.08873, theta=32.451722 -> V=1.0, theta=0.0
% INFO    : Bus 3341	: V=0.996579, theta=-43.046702 -> V=1.0, theta=0.0
% INFO    : Bus 3342	: V=1.030961, theta=-39.881222 -> V=1.0, theta=0.0
% INFO    : Bus 3344	: V=1.037547, theta=-16.626086 -> V=1.0, theta=0.0
% INFO    : Bus 3346	: V=1.014746, theta=-12.050881 -> V=1.0, theta=0.0
% INFO    : Bus 3352	: V=1.02469, theta=11.939007 -> V=1.0, theta=0.0
% INFO    : Bus 3353	: V=1.047796, theta=-3.038965 -> V=1.0, theta=0.0
% INFO    : Bus 3363	: V=1.015585, theta=1.898178 -> V=1.0, theta=0.0
% INFO    : Bus 3364	: V=1.055303, theta=-12.424509 -> V=1.0, theta=0.0
% INFO    : Bus 3367	: V=1.023439, theta=-52.090148 -> V=1.0, theta=0.0
% INFO    : Bus 3370	: V=1.049776, theta=18.741809 -> V=1.0, theta=0.0
% INFO    : Bus 3374	: V=1.019323, theta=10.42872 -> V=1.0, theta=0.0
% INFO    : Bus 3377	: V=1.019707, theta=-10.476462 -> V=1.0, theta=0.0
% INFO    : Bus 3378	: V=1.023847, theta=-44.818138 -> V=1.0, theta=0.0
% INFO    : Bus 3382	: V=1.024501, theta=-46.594868 -> V=1.0, theta=0.0
% INFO    : Bus 3388	: V=1.031936, theta=4.19826 -> V=1.0, theta=0.0
% INFO    : Bus 3390	: V=1.041678, theta=-11.508701 -> V=1.0, theta=0.0
% INFO    : Bus 3391	: V=1.058582, theta=-20.966447 -> V=1.0, theta=0.0
% INFO    : Bus 3397	: V=1.001327, theta=-0.497618 -> V=1.0, theta=0.0
% INFO    : Bus 3400	: V=1.046036, theta=-25.128412 -> V=1.0, theta=0.0
% INFO    : Bus 3401	: V=1.037884, theta=-14.052358 -> V=1.0, theta=0.0
% INFO    : Bus 3409	: V=1.02461, theta=-38.44707 -> V=1.0, theta=0.0
% INFO    : Bus 3412	: V=1.05568, theta=2.418195 -> V=1.0, theta=0.0
% INFO    : Bus 3413	: V=0.990325, theta=-48.145285 -> V=1.0, theta=0.0
% INFO    : Bus 3416	: V=0.997085, theta=-36.650296 -> V=1.0, theta=0.0
% INFO    : Bus 3422	: V=1.065868, theta=-10.780991 -> V=1.0, theta=0.0
% INFO    : Bus 3425	: V=1.029115, theta=-53.61758 -> V=1.0, theta=0.0
% INFO    : Bus 3427	: V=1.029707, theta=-53.426186 -> V=1.0, theta=0.0
% INFO    : Bus 3428	: V=1.039945, theta=-44.378925 -> V=1.0, theta=0.0
% INFO    : Bus 3429	: V=0.985017, theta=-56.281675 -> V=1.0, theta=0.0
% INFO    : Bus 3430	: V=1.01706, theta=-16.096952 -> V=1.0, theta=0.0
% INFO    : Bus 3435	: V=1.04207, theta=-25.600219 -> V=1.0, theta=0.0
% INFO    : Bus 3436	: V=1.056276, theta=-13.341208 -> V=1.0, theta=0.0
% INFO    : Bus 3442	: V=1.033756, theta=-53.058588 -> V=1.0, theta=0.0
% INFO    : Bus 3443	: V=1.018501, theta=6.910518 -> V=1.0, theta=0.0
% INFO    : Bus 3445	: V=0.998626, theta=-5.886772 -> V=1.0, theta=0.0
% INFO    : Bus 3450	: V=1.045917, theta=-21.516053 -> V=1.0, theta=0.0
% INFO    : Bus 3456	: V=1.007014, theta=-3.377444 -> V=1.0, theta=0.0
% INFO    : Bus 3462	: V=1.024888, theta=11.675038 -> V=1.0, theta=0.0
% INFO    : Bus 3468	: V=1.029162, theta=-47.376681 -> V=1.0, theta=0.0
% INFO    : Bus 3478	: V=1.007823, theta=-44.241987 -> V=1.0, theta=0.0
% INFO    : Bus 3481	: V=1.021369, theta=-20.827525 -> V=1.0, theta=0.0
% INFO    : Bus 3483	: V=1.047991, theta=2.353608 -> V=1.0, theta=0.0
% INFO    : Bus 3484	: V=1.032637, theta=13.843519 -> V=1.0, theta=0.0
% INFO    : Bus 3485	: V=0.990338, theta=-16.290207 -> V=1.0, theta=0.0
% INFO    : Bus 3486	: V=1.035245, theta=-20.908358 -> V=1.0, theta=0.0
% INFO    : Bus 3487	: V=1.01071, theta=-39.922801 -> V=1.0, theta=0.0
% INFO    : Bus 3488	: V=1.039592, theta=-12.379315 -> V=1.0, theta=0.0
% INFO    : Bus 3489	: V=1.027242, theta=-52.988086 -> V=1.0, theta=0.0
% INFO    : Bus 3492	: V=1.04519, theta=-8.569839 -> V=1.0, theta=0.0
% INFO    : Bus 3493	: V=1.035682, theta=-10.395331 -> V=1.0, theta=0.0
% INFO    : Bus 3495	: V=1.018242, theta=-57.061111 -> V=1.0, theta=0.0
% INFO    : Bus 3496	: V=1.03547, theta=-21.365036 -> V=1.0, theta=0.0
% INFO    : Bus 3497	: V=1.024686, theta=4.074269 -> V=1.0, theta=0.0
% INFO    : Bus 3498	: V=1.035615, theta=-10.18023 -> V=1.0, theta=0.0
% INFO    : Bus 3499	: V=1.036881, theta=-3.624207 -> V=1.0, theta=0.0
% INFO    : Bus 3500	: V=1.032595, theta=-52.148697 -> V=1.0, theta=0.0
% INFO    : Bus 3502	: V=1.022468, theta=-10.518494 -> V=1.0, theta=0.0
% INFO    : Bus 3503	: V=1.03107, theta=-11.513013 -> V=1.0, theta=0.0
% INFO    : Bus 3506	: V=1.010703, theta=-10.97175 -> V=1.0, theta=0.0
% INFO    : Bus 3509	: V=1.023232, theta=11.672068 -> V=1.0, theta=0.0
% INFO    : Bus 3512	: V=1.011233, theta=-52.616595 -> V=1.0, theta=0.0
% INFO    : Bus 3513	: V=1.029628, theta=-3.769006 -> V=1.0, theta=0.0
% INFO    : Bus 3519	: V=1.032358, theta=-22.871014 -> V=1.0, theta=0.0
% INFO    : Bus 3520	: V=1.04126, theta=-5.929212 -> V=1.0, theta=0.0
% INFO    : Bus 3526	: V=1.060598, theta=-4.169707 -> V=1.0, theta=0.0
% INFO    : Bus 3530	: V=1.01013, theta=0.854718 -> V=1.0, theta=0.0
% INFO    : Bus 3535	: V=1.035222, theta=-24.481534 -> V=1.0, theta=0.0
% INFO    : Bus 3538	: V=1.027519, theta=18.538871 -> V=1.0, theta=0.0
% INFO    : Bus 3541	: V=1.038631, theta=-24.013582 -> V=1.0, theta=0.0
% INFO    : Bus 3543	: V=0.991231, theta=-17.577149 -> V=1.0, theta=0.0
% INFO    : Bus 3544	: V=1.051823, theta=-43.291508 -> V=1.0, theta=0.0
% INFO    : Bus 3545	: V=1.051526, theta=-7.986739 -> V=1.0, theta=0.0
% INFO    : Bus 3549	: V=1.017723, theta=-42.242961 -> V=1.0, theta=0.0
% INFO    : Bus 3557	: V=1.043736, theta=-30.66359 -> V=1.0, theta=0.0
% INFO    : Bus 3558	: V=1.061451, theta=2.478205 -> V=1.0, theta=0.0
% INFO    : Bus 3565	: V=1.079121, theta=-26.473248 -> V=1.0, theta=0.0
% INFO    : Bus 3577	: V=1.032186, theta=-5.20661 -> V=1.0, theta=0.0
% INFO    : Bus 3579	: V=1.071503, theta=-39.941643 -> V=1.0, theta=0.0
% INFO    : Bus 3580	: V=1.075232, theta=-33.466802 -> V=1.0, theta=0.0
% INFO    : Bus 3582	: V=1.045127, theta=-48.989672 -> V=1.0, theta=0.0
% INFO    : Bus 3584	: V=1.019651, theta=-44.933373 -> V=1.0, theta=0.0
% INFO    : Bus 3585	: V=1.006097, theta=-44.462006 -> V=1.0, theta=0.0
% INFO    : Bus 3587	: V=1.069089, theta=-39.84538 -> V=1.0, theta=0.0
% INFO    : Bus 3589	: V=1.043343, theta=-6.742329 -> V=1.0, theta=0.0
% INFO    : Bus 3592	: V=1.01555, theta=-48.994509 -> V=1.0, theta=0.0
% INFO    : Bus 3594	: V=1.031857, theta=-19.837353 -> V=1.0, theta=0.0
% INFO    : Bus 3601	: V=1.039102, theta=-21.39569 -> V=1.0, theta=0.0
% INFO    : Bus 3602	: V=1.029873, theta=-18.964113 -> V=1.0, theta=0.0
% INFO    : Bus 3608	: V=1.00864, theta=-41.723719 -> V=1.0, theta=0.0
% INFO    : Bus 3609	: V=1.063902, theta=-11.501477 -> V=1.0, theta=0.0
% INFO    : Bus 3610	: V=1.036366, theta=-22.773158 -> V=1.0, theta=0.0
% INFO    : Bus 3611	: V=1.03827, theta=-18.990532 -> V=1.0, theta=0.0
% INFO    : Bus 3613	: V=1.029169, theta=-28.094604 -> V=1.0, theta=0.0
% INFO    : Bus 3615	: V=1.02479, theta=-38.25963 -> V=1.0, theta=0.0
% INFO    : Bus 3620	: V=1.028924, theta=2.181053 -> V=1.0, theta=0.0
% INFO    : Bus 3621	: V=1.023915, theta=-51.863704 -> V=1.0, theta=0.0
% INFO    : Bus 3623	: V=1.032919, theta=-33.405215 -> V=1.0, theta=0.0
% INFO    : Bus 3629	: V=1.020807, theta=-43.909237 -> V=1.0, theta=0.0
% INFO    : Bus 3633	: V=1.034754, theta=-54.841716 -> V=1.0, theta=0.0
% INFO    : Bus 3643	: V=1.032306, theta=-19.396739 -> V=1.0, theta=0.0
% INFO    : Bus 3644	: V=1.018948, theta=-43.146574 -> V=1.0, theta=0.0
% INFO    : Bus 3645	: V=1.040651, theta=-33.549688 -> V=1.0, theta=0.0
% INFO    : Bus 3649	: V=1.0491, theta=-36.643877 -> V=1.0, theta=0.0
% INFO    : Bus 3650	: V=1.027803, theta=-43.004237 -> V=1.0, theta=0.0
% INFO    : Bus 3654	: V=1.073757, theta=-26.422172 -> V=1.0, theta=0.0
% INFO    : Bus 3656	: V=1.067132, theta=-11.788937 -> V=1.0, theta=0.0
% INFO    : Bus 3657	: V=1.075197, theta=-26.111324 -> V=1.0, theta=0.0
% INFO    : Bus 3659	: V=1.065964, theta=1.067647 -> V=1.0, theta=0.0
% INFO    : Bus 3661	: V=1.059844, theta=4.519815 -> V=1.0, theta=0.0
% INFO    : Bus 3662	: V=1.025068, theta=-43.262157 -> V=1.0, theta=0.0
% INFO    : Bus 3664	: V=1.021032, theta=8.869635 -> V=1.0, theta=0.0
% INFO    : Bus 3665	: V=1.015517, theta=-42.634054 -> V=1.0, theta=0.0
% INFO    : Bus 3670	: V=1.035567, theta=-22.00727 -> V=1.0, theta=0.0
% INFO    : Bus 3672	: V=1.033523, theta=-12.87972 -> V=1.0, theta=0.0
% INFO    : Bus 3673	: V=1.013624, theta=-38.75114 -> V=1.0, theta=0.0
% INFO    : Bus 3674	: V=1.042309, theta=-14.830405 -> V=1.0, theta=0.0
% INFO    : Bus 3680	: V=1.039486, theta=-15.440764 -> V=1.0, theta=0.0
% INFO    : Bus 3687	: V=1.048351, theta=-49.738272 -> V=1.0, theta=0.0
% INFO    : Bus 3689	: V=1.032178, theta=-44.964327 -> V=1.0, theta=0.0
% INFO    : Bus 3691	: V=1.030169, theta=13.484958 -> V=1.0, theta=0.0
% INFO    : Bus 3692	: V=1.025431, theta=-42.014259 -> V=1.0, theta=0.0
% INFO    : Bus 3697	: V=1.047634, theta=-20.602675 -> V=1.0, theta=0.0
% INFO    : Bus 3698	: V=1.041028, theta=-24.356749 -> V=1.0, theta=0.0
% INFO    : Bus 3701	: V=1.046495, theta=-25.065923 -> V=1.0, theta=0.0
% INFO    : Bus 3707	: V=1.046289, theta=-15.379565 -> V=1.0, theta=0.0
% INFO    : Bus 3711	: V=1.00126, theta=-38.557504 -> V=1.0, theta=0.0
% INFO    : Bus 3712	: V=1.027985, theta=4.101781 -> V=1.0, theta=0.0
% INFO    : Bus 3715	: V=1.024475, theta=-48.261603 -> V=1.0, theta=0.0
% INFO    : Bus 3718	: V=1.044223, theta=-25.291795 -> V=1.0, theta=0.0
% INFO    : Bus 3723	: V=1.062798, theta=49.722231 -> V=1.0, theta=0.0
% INFO    : Bus 3728	: V=1.034117, theta=-52.492502 -> V=1.0, theta=0.0
% INFO    : Bus 3734	: V=1.023655, theta=-46.639617 -> V=1.0, theta=0.0
% INFO    : Bus 3736	: V=1.017883, theta=-57.812403 -> V=1.0, theta=0.0
% INFO    : Bus 3737	: V=1.040625, theta=-2.984485 -> V=1.0, theta=0.0
% INFO    : Bus 3740	: V=1.036979, theta=-21.255139 -> V=1.0, theta=0.0
% INFO    : Bus 3741	: V=1.035379, theta=0.644884 -> V=1.0, theta=0.0
% INFO    : Bus 3744	: V=1.024137, theta=-46.425744 -> V=1.0, theta=0.0
% INFO    : Bus 3747	: V=1.02865, theta=-52.883204 -> V=1.0, theta=0.0
% INFO    : Bus 3749	: V=1.043452, theta=-17.34385 -> V=1.0, theta=0.0
% INFO    : Bus 3754	: V=1.038012, theta=-38.799743 -> V=1.0, theta=0.0
% INFO    : Bus 3758	: V=1.02345, theta=-19.032004 -> V=1.0, theta=0.0
% INFO    : Bus 3760	: V=1.056951, theta=-20.961308 -> V=1.0, theta=0.0
% INFO    : Bus 3768	: V=1.041082, theta=-21.937131 -> V=1.0, theta=0.0
% INFO    : Bus 3771	: V=1.015175, theta=-0.740046 -> V=1.0, theta=0.0
% INFO    : Bus 3775	: V=1.000587, theta=-23.540244 -> V=1.0, theta=0.0
% INFO    : Bus 3776	: V=1.022691, theta=11.561481 -> V=1.0, theta=0.0
% INFO    : Bus 3786	: V=1.047822, theta=-19.769094 -> V=1.0, theta=0.0
% INFO    : Bus 3791	: V=0.997709, theta=-39.697243 -> V=1.0, theta=0.0
% INFO    : Bus 3792	: V=1.058708, theta=-43.684835 -> V=1.0, theta=0.0
% INFO    : Bus 3793	: V=1.033718, theta=-20.651557 -> V=1.0, theta=0.0
% INFO    : Bus 3794	: V=1.029653, theta=-28.186986 -> V=1.0, theta=0.0
% INFO    : Bus 3798	: V=1.066587, theta=-40.979103 -> V=1.0, theta=0.0
% INFO    : Bus 3809	: V=1.084761, theta=-34.048929 -> V=1.0, theta=0.0
% INFO    : Bus 3813	: V=1.02677, theta=-53.275089 -> V=1.0, theta=0.0
% INFO    : Bus 3814	: V=1.040225, theta=-22.000602 -> V=1.0, theta=0.0
% INFO    : Bus 3817	: V=1.084376, theta=-15.14948 -> V=1.0, theta=0.0
% INFO    : Bus 3818	: V=1.041346, theta=-25.830576 -> V=1.0, theta=0.0
% INFO    : Bus 3819	: V=0.997429, theta=-4.848161 -> V=1.0, theta=0.0
% INFO    : Bus 3821	: V=1.029497, theta=-38.598952 -> V=1.0, theta=0.0
% INFO    : Bus 3825	: V=1.026381, theta=-8.532195 -> V=1.0, theta=0.0
% INFO    : Bus 3830	: V=0.994231, theta=-13.785717 -> V=1.0, theta=0.0
% INFO    : Bus 3834	: V=1.036025, theta=-22.276797 -> V=1.0, theta=0.0
% INFO    : Bus 3840	: V=1.030834, theta=-43.916162 -> V=1.0, theta=0.0
% INFO    : Bus 3843	: V=1.015649, theta=-43.936354 -> V=1.0, theta=0.0
% INFO    : Bus 3846	: V=1.021369, theta=11.436684 -> V=1.0, theta=0.0
% INFO    : Bus 3855	: V=1.075113, theta=-26.199377 -> V=1.0, theta=0.0
% INFO    : Bus 3857	: V=1.078948, theta=-23.148876 -> V=1.0, theta=0.0
% INFO    : Bus 3865	: V=1.028906, theta=-14.828465 -> V=1.0, theta=0.0
% INFO    : Bus 3866	: V=1.048854, theta=-27.64579 -> V=1.0, theta=0.0
% INFO    : Bus 3868	: V=1.013932, theta=1.288488 -> V=1.0, theta=0.0
% INFO    : Bus 3869	: V=1.035477, theta=1.121843 -> V=1.0, theta=0.0
% INFO    : Bus 3876	: V=1.046886, theta=-9.603363 -> V=1.0, theta=0.0
% INFO    : Bus 3878	: V=1.037445, theta=22.511429 -> V=1.0, theta=0.0
% INFO    : Bus 3880	: V=1.063888, theta=-11.500711 -> V=1.0, theta=0.0
% INFO    : Bus 3891	: V=1.04365, theta=16.562241 -> V=1.0, theta=0.0
% INFO    : Bus 3894	: V=1.025966, theta=-15.280447 -> V=1.0, theta=0.0
% INFO    : Bus 3898	: V=0.997386, theta=-1.503423 -> V=1.0, theta=0.0
% INFO    : Bus 3903	: V=1.04983, theta=-24.556874 -> V=1.0, theta=0.0
% INFO    : Bus 3906	: V=1.037134, theta=-13.399373 -> V=1.0, theta=0.0
% INFO    : Bus 3912	: V=1.037244, theta=-21.114751 -> V=1.0, theta=0.0
% INFO    : Bus 3916	: V=1.044945, theta=-14.025037 -> V=1.0, theta=0.0
% INFO    : Bus 3918	: V=1.027043, theta=-1.921362 -> V=1.0, theta=0.0
% INFO    : Bus 3919	: V=1.025931, theta=-6.057599 -> V=1.0, theta=0.0
% INFO    : Bus 3925	: V=1.02786, theta=-13.10527 -> V=1.0, theta=0.0
% INFO    : Bus 3928	: V=1.041886, theta=-4.72794 -> V=1.0, theta=0.0
% INFO    : Bus 3929	: V=1.032023, theta=-20.245503 -> V=1.0, theta=0.0
% INFO    : Bus 3932	: V=1.029043, theta=-34.223167 -> V=1.0, theta=0.0
% INFO    : Bus 3937	: V=1.023016, theta=-42.84661 -> V=1.0, theta=0.0
% INFO    : Bus 3951	: V=1.029014, theta=-12.973188 -> V=1.0, theta=0.0
% INFO    : Bus 3954	: V=0.980151, theta=-56.048746 -> V=1.0, theta=0.0
% INFO    : Bus 3956	: V=1.047817, theta=-24.129675 -> V=1.0, theta=0.0
% INFO    : Bus 3957	: V=1.005937, theta=-44.477596 -> V=1.0, theta=0.0
% INFO    : Bus 3960	: V=1.034669, theta=9.599065 -> V=1.0, theta=0.0
% INFO    : Bus 3961	: V=1.011587, theta=-47.466292 -> V=1.0, theta=0.0
% INFO    : Bus 3962	: V=1.040806, theta=-23.72917 -> V=1.0, theta=0.0
% INFO    : Bus 3966	: V=1.045921, theta=-42.713529 -> V=1.0, theta=0.0
% INFO    : Bus 3968	: V=1.050166, theta=18.743096 -> V=1.0, theta=0.0
% INFO    : Bus 3969	: V=1.019911, theta=-10.460405 -> V=1.0, theta=0.0
% INFO    : Bus 3971	: V=1.060173, theta=-8.888833 -> V=1.0, theta=0.0
% INFO    : Bus 3974	: V=1.014106, theta=4.41456 -> V=1.0, theta=0.0
% INFO    : Bus 3975	: V=0.98457, theta=-24.821972 -> V=1.0, theta=0.0
% INFO    : Bus 3983	: V=1.012943, theta=17.02029 -> V=1.0, theta=0.0
% INFO    : Bus 3985	: V=1.047185, theta=-0.054112 -> V=1.0, theta=0.0
% INFO    : Bus 3987	: V=1.021034, theta=-32.925081 -> V=1.0, theta=0.0
% INFO    : Bus 3990	: V=1.056447, theta=-48.400884 -> V=1.0, theta=0.0
% INFO    : Bus 3994	: V=1.038572, theta=-2.774266 -> V=1.0, theta=0.0
% INFO    : Bus 3997	: V=1.043493, theta=-11.965937 -> V=1.0, theta=0.0
% INFO    : Bus 3999	: V=1.052755, theta=-6.623039 -> V=1.0, theta=0.0
% INFO    : Bus 4000	: V=0.990281, theta=-15.541038 -> V=1.0, theta=0.0
% INFO    : Bus 4005	: V=1.064294, theta=-31.637164 -> V=1.0, theta=0.0
% INFO    : Bus 4006	: V=1.021667, theta=11.13144 -> V=1.0, theta=0.0
% INFO    : Bus 4011	: V=1.030482, theta=-53.578355 -> V=1.0, theta=0.0
% INFO    : Bus 4013	: V=0.98986, theta=-55.464877 -> V=1.0, theta=0.0
% INFO    : Bus 4014	: V=1.030612, theta=-13.14884 -> V=1.0, theta=0.0
% INFO    : Bus 4016	: V=1.026951, theta=-42.526395 -> V=1.0, theta=0.0
% INFO    : Bus 4020	: V=1.047428, theta=-49.661223 -> V=1.0, theta=0.0
% INFO    : Bus 4021	: V=1.010028, theta=6.95481 -> V=1.0, theta=0.0
% INFO    : Bus 4024	: V=1.032708, theta=2.56213 -> V=1.0, theta=0.0
% INFO    : Bus 4025	: V=1.038716, theta=-2.763229 -> V=1.0, theta=0.0
% INFO    : Bus 4026	: V=1.05962, theta=-40.932766 -> V=1.0, theta=0.0
% INFO    : Bus 4031	: V=1.060541, theta=-10.682858 -> V=1.0, theta=0.0
% INFO    : Bus 4032	: V=1.001235, theta=-11.661775 -> V=1.0, theta=0.0
% INFO    : Bus 4039	: V=1.037738, theta=-22.554888 -> V=1.0, theta=0.0
% INFO    : Bus 4049	: V=1.01917, theta=-10.099581 -> V=1.0, theta=0.0
% INFO    : Bus 4054	: V=1.032827, theta=-18.511552 -> V=1.0, theta=0.0
% INFO    : Bus 4056	: V=1.042513, theta=-9.76223 -> V=1.0, theta=0.0
% INFO    : Bus 4057	: V=1.03204, theta=8.696458 -> V=1.0, theta=0.0
% INFO    : Bus 4058	: V=1.010205, theta=-47.598126 -> V=1.0, theta=0.0
% INFO    : Bus 4059	: V=1.087376, theta=32.317567 -> V=1.0, theta=0.0
% INFO    : Bus 4060	: V=1.06252, theta=-14.73886 -> V=1.0, theta=0.0
% INFO    : Bus 4062	: V=1.014964, theta=-48.212922 -> V=1.0, theta=0.0
% INFO    : Bus 4077	: V=1.044199, theta=16.785926 -> V=1.0, theta=0.0
% INFO    : Bus 4081	: V=1.033152, theta=-52.522928 -> V=1.0, theta=0.0
% INFO    : Bus 4082	: V=1.032369, theta=12.590309 -> V=1.0, theta=0.0
% INFO    : Bus 4084	: V=1.060214, theta=-8.829817 -> V=1.0, theta=0.0
% INFO    : Bus 4087	: V=1.049045, theta=18.331888 -> V=1.0, theta=0.0
% INFO    : Bus 4095	: V=1.018058, theta=-58.014896 -> V=1.0, theta=0.0
% INFO    : Bus 4096	: V=1.015565, theta=-48.090558 -> V=1.0, theta=0.0
% INFO    : Bus 4098	: V=0.965808, theta=-43.736662 -> V=1.0, theta=0.0
% INFO    : Bus 4100	: V=1.065816, theta=-10.800151 -> V=1.0, theta=0.0
% INFO    : Bus 4103	: V=1.036557, theta=-21.727519 -> V=1.0, theta=0.0
% INFO    : Bus 4104	: V=1.021346, theta=11.229093 -> V=1.0, theta=0.0
% INFO    : Bus 4110	: V=1.04854, theta=0.638802 -> V=1.0, theta=0.0
% INFO    : Bus 4112	: V=1.018938, theta=-44.367979 -> V=1.0, theta=0.0
% INFO    : Bus 4114	: V=1.047098, theta=-24.523765 -> V=1.0, theta=0.0
% INFO    : Bus 4116	: V=0.988341, theta=-50.469464 -> V=1.0, theta=0.0
% INFO    : Bus 4118	: V=1.029072, theta=-14.764759 -> V=1.0, theta=0.0
% INFO    : Bus 4124	: V=1.02101, theta=-45.251292 -> V=1.0, theta=0.0
% INFO    : Bus 4125	: V=0.999283, theta=-8.393702 -> V=1.0, theta=0.0
% INFO    : Bus 4127	: V=1.032589, theta=-20.184781 -> V=1.0, theta=0.0
% INFO    : Bus 4128	: V=1.023094, theta=-15.634361 -> V=1.0, theta=0.0
% INFO    : Bus 4130	: V=1.015422, theta=10.923387 -> V=1.0, theta=0.0
% INFO    : Bus 4132	: V=1.017781, theta=12.498081 -> V=1.0, theta=0.0
% INFO    : Bus 4134	: V=1.073366, theta=-33.684303 -> V=1.0, theta=0.0
% INFO    : Bus 4141	: V=1.031921, theta=-21.125525 -> V=1.0, theta=0.0
% INFO    : Bus 4143	: V=1.051356, theta=-1.147948 -> V=1.0, theta=0.0
% INFO    : Bus 4144	: V=1.043667, theta=-19.857161 -> V=1.0, theta=0.0
% INFO    : Bus 4157	: V=1.074173, theta=-26.3647 -> V=1.0, theta=0.0
% INFO    : Bus 4165	: V=1.031761, theta=-43.289414 -> V=1.0, theta=0.0
% INFO    : Bus 4170	: V=0.993515, theta=-31.913491 -> V=1.0, theta=0.0
% INFO    : Bus 4177	: V=1.023308, theta=-44.686399 -> V=1.0, theta=0.0
% INFO    : Bus 4181	: V=1.043781, theta=-45.342434 -> V=1.0, theta=0.0
% INFO    : Bus 4182	: V=1.016453, theta=-43.470268 -> V=1.0, theta=0.0
% INFO    : Bus 4185	: V=1.041162, theta=-25.851702 -> V=1.0, theta=0.0
% INFO    : Bus 4186	: V=1.035985, theta=-23.161266 -> V=1.0, theta=0.0
% INFO    : Bus 4188	: V=1.004131, theta=0.103214 -> V=1.0, theta=0.0
% INFO    : Bus 4189	: V=1.032545, theta=-26.186137 -> V=1.0, theta=0.0
% INFO    : Bus 4192	: V=1.077662, theta=18.579115 -> V=1.0, theta=0.0
% INFO    : Bus 4196	: V=1.026572, theta=-7.529013 -> V=1.0, theta=0.0
% INFO    : Bus 4197	: V=1.066931, theta=0.703575 -> V=1.0, theta=0.0
% INFO    : Bus 4204	: V=1.017661, theta=-39.608142 -> V=1.0, theta=0.0
% INFO    : Bus 4205	: V=1.047904, theta=-12.739022 -> V=1.0, theta=0.0
% INFO    : Bus 4209	: V=1.049923, theta=18.730401 -> V=1.0, theta=0.0
% INFO    : Bus 4215	: V=1.04574, theta=-23.060958 -> V=1.0, theta=0.0
% INFO    : Bus 4216	: V=1.0244, theta=8.593062 -> V=1.0, theta=0.0
% INFO    : Bus 4224	: V=1.023033, theta=-37.986866 -> V=1.0, theta=0.0
% INFO    : Bus 4230	: V=0.983046, theta=-44.558409 -> V=1.0, theta=0.0
% INFO    : Bus 4231	: V=1.050918, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 4234	: V=1.046144, theta=-17.178168 -> V=1.0, theta=0.0
% INFO    : Bus 4235	: V=1.048409, theta=-19.236107 -> V=1.0, theta=0.0
% INFO    : Bus 4238	: V=1.012199, theta=-47.372938 -> V=1.0, theta=0.0
% INFO    : Bus 4239	: V=1.048509, theta=-13.243223 -> V=1.0, theta=0.0
% INFO    : Bus 4241	: V=1.026348, theta=-43.342141 -> V=1.0, theta=0.0
% INFO    : Bus 4245	: V=1.042873, theta=-9.919925 -> V=1.0, theta=0.0
% INFO    : Bus 4248	: V=1.006959, theta=26.630788 -> V=1.0, theta=0.0
% INFO    : Bus 4249	: V=1.027416, theta=-54.308862 -> V=1.0, theta=0.0
% INFO    : Bus 4251	: V=1.026117, theta=-17.723087 -> V=1.0, theta=0.0
% INFO    : Bus 4253	: V=1.02913, theta=-53.844323 -> V=1.0, theta=0.0
% INFO    : Bus 4259	: V=1.013671, theta=-41.277855 -> V=1.0, theta=0.0
% INFO    : Bus 4267	: V=1.041691, theta=-8.894803 -> V=1.0, theta=0.0
% INFO    : Bus 4272	: V=1.024269, theta=2.729626 -> V=1.0, theta=0.0
% INFO    : Bus 4274	: V=1.030993, theta=-53.273986 -> V=1.0, theta=0.0
% INFO    : Bus 4277	: V=0.999219, theta=-38.719503 -> V=1.0, theta=0.0
% INFO    : Bus 4279	: V=1.01711, theta=-33.903407 -> V=1.0, theta=0.0
% INFO    : Bus 4281	: V=1.052621, theta=-11.701312 -> V=1.0, theta=0.0
% INFO    : Bus 4290	: V=1.070175, theta=-40.369777 -> V=1.0, theta=0.0
% INFO    : Bus 4291	: V=1.02141, theta=-35.159361 -> V=1.0, theta=0.0
% INFO    : Bus 4293	: V=1.015968, theta=-54.317746 -> V=1.0, theta=0.0
% INFO    : Bus 4295	: V=1.038977, theta=6.823537 -> V=1.0, theta=0.0
% INFO    : Bus 4300	: V=0.998948, theta=-16.239304 -> V=1.0, theta=0.0
% INFO    : Bus 4301	: V=1.037254, theta=-21.115116 -> V=1.0, theta=0.0
% INFO    : Bus 4302	: V=1.028974, theta=23.542154 -> V=1.0, theta=0.0
% INFO    : Bus 4306	: V=1.033831, theta=-30.862867 -> V=1.0, theta=0.0
% INFO    : Bus 4313	: V=1.04225, theta=-21.167095 -> V=1.0, theta=0.0
% INFO    : Bus 4314	: V=1.044902, theta=-14.232728 -> V=1.0, theta=0.0
% INFO    : Bus 4315	: V=1.050551, theta=-38.14331 -> V=1.0, theta=0.0
% INFO    : Bus 4317	: V=1.00999, theta=-40.622522 -> V=1.0, theta=0.0
% INFO    : Bus 4318	: V=1.046831, theta=11.317068 -> V=1.0, theta=0.0
% INFO    : Bus 4320	: V=1.007531, theta=26.5698 -> V=1.0, theta=0.0
% INFO    : Bus 4324	: V=1.056635, theta=-29.843383 -> V=1.0, theta=0.0
% INFO    : Bus 4331	: V=1.032206, theta=-11.019439 -> V=1.0, theta=0.0
% INFO    : Bus 4333	: V=0.999193, theta=-30.217701 -> V=1.0, theta=0.0
% INFO    : Bus 4336	: V=1.02824, theta=-54.093567 -> V=1.0, theta=0.0
% INFO    : Bus 4337	: V=1.010847, theta=6.866672 -> V=1.0, theta=0.0
% INFO    : Bus 4338	: V=1.024208, theta=-47.464582 -> V=1.0, theta=0.0
% INFO    : Bus 4339	: V=0.993094, theta=-15.822682 -> V=1.0, theta=0.0
% INFO    : Bus 4340	: V=1.047125, theta=26.552517 -> V=1.0, theta=0.0
% INFO    : Bus 4344	: V=1.000951, theta=-50.927954 -> V=1.0, theta=0.0
% INFO    : Bus 4353	: V=1.050036, theta=-26.643732 -> V=1.0, theta=0.0
% INFO    : Bus 4355	: V=1.073092, theta=-26.464431 -> V=1.0, theta=0.0
% INFO    : Bus 4357	: V=1.042363, theta=-16.022891 -> V=1.0, theta=0.0
% INFO    : Bus 4360	: V=1.019445, theta=-52.008231 -> V=1.0, theta=0.0
% INFO    : Bus 4362	: V=1.008262, theta=4.432902 -> V=1.0, theta=0.0
% INFO    : Bus 4363	: V=1.027315, theta=-39.283356 -> V=1.0, theta=0.0
% INFO    : Bus 4368	: V=1.056502, theta=-25.103292 -> V=1.0, theta=0.0
% INFO    : Bus 4371	: V=1.016476, theta=-54.57476 -> V=1.0, theta=0.0
% INFO    : Bus 4380	: V=1.017434, theta=1.176125 -> V=1.0, theta=0.0
% INFO    : Bus 4390	: V=1.054595, theta=-38.856296 -> V=1.0, theta=0.0
% INFO    : Bus 4393	: V=1.066547, theta=-44.147015 -> V=1.0, theta=0.0
% INFO    : Bus 4395	: V=1.039119, theta=-20.695167 -> V=1.0, theta=0.0
% INFO    : Bus 4397	: V=1.017881, theta=-47.055799 -> V=1.0, theta=0.0
% INFO    : Bus 4402	: V=1.084379, theta=-15.149537 -> V=1.0, theta=0.0
% INFO    : Bus 4407	: V=1.067036, theta=-40.648917 -> V=1.0, theta=0.0
% INFO    : Bus 4409	: V=1.035676, theta=17.690796 -> V=1.0, theta=0.0
% INFO    : Bus 4410	: V=1.045437, theta=-36.944821 -> V=1.0, theta=0.0
% INFO    : Bus 4413	: V=1.026248, theta=11.663183 -> V=1.0, theta=0.0
% INFO    : Bus 4415	: V=1.023057, theta=8.653225 -> V=1.0, theta=0.0
% INFO    : Bus 4418	: V=1.075746, theta=-24.387925 -> V=1.0, theta=0.0
% INFO    : Bus 4419	: V=1.059728, theta=4.502903 -> V=1.0, theta=0.0
% INFO    : Bus 4423	: V=1.036754, theta=-11.106241 -> V=1.0, theta=0.0
% INFO    : Bus 4426	: V=1.067346, theta=-46.835811 -> V=1.0, theta=0.0
% INFO    : Bus 4427	: V=1.035314, theta=-10.898975 -> V=1.0, theta=0.0
% INFO    : Bus 4428	: V=1.019796, theta=-43.510535 -> V=1.0, theta=0.0
% INFO    : Bus 4431	: V=1.01887, theta=8.62678 -> V=1.0, theta=0.0
% INFO    : Bus 4432	: V=1.074172, theta=-26.364665 -> V=1.0, theta=0.0
% INFO    : Bus 4435	: V=1.003844, theta=-8.586482 -> V=1.0, theta=0.0
% INFO    : Bus 4442	: V=1.036687, theta=-49.906013 -> V=1.0, theta=0.0
% INFO    : Bus 4446	: V=1.038692, theta=-38.842526 -> V=1.0, theta=0.0
% INFO    : Bus 4450	: V=1.02892, theta=-53.925388 -> V=1.0, theta=0.0
% INFO    : Bus 4454	: V=0.993879, theta=-18.276696 -> V=1.0, theta=0.0
% INFO    : Bus 4467	: V=0.997475, theta=-46.089189 -> V=1.0, theta=0.0
% INFO    : Bus 4477	: V=1.031936, theta=4.19826 -> V=1.0, theta=0.0
% INFO    : Bus 4480	: V=1.069297, theta=8.010702 -> V=1.0, theta=0.0
% INFO    : Bus 4481	: V=1.019184, theta=-33.230536 -> V=1.0, theta=0.0
% INFO    : Bus 4482	: V=1.05005, theta=-6.463671 -> V=1.0, theta=0.0
% INFO    : Bus 4484	: V=1.047688, theta=-13.383588 -> V=1.0, theta=0.0
% INFO    : Bus 4485	: V=1.042138, theta=15.995386 -> V=1.0, theta=0.0
% INFO    : Bus 4489	: V=1.02429, theta=-46.767263 -> V=1.0, theta=0.0
% INFO    : Bus 4491	: V=1.029682, theta=-28.956093 -> V=1.0, theta=0.0
% INFO    : Bus 4493	: V=1.021108, theta=-40.326904 -> V=1.0, theta=0.0
% INFO    : Bus 4494	: V=1.020394, theta=-0.81866 -> V=1.0, theta=0.0
% INFO    : Bus 4495	: V=1.033348, theta=-10.869733 -> V=1.0, theta=0.0
% INFO    : Bus 4504	: V=1.071798, theta=-42.595944 -> V=1.0, theta=0.0
% INFO    : Bus 4505	: V=1.042633, theta=-15.989429 -> V=1.0, theta=0.0
% INFO    : Bus 4506	: V=1.040247, theta=-5.976296 -> V=1.0, theta=0.0
% INFO    : Bus 4507	: V=1.030641, theta=-41.584691 -> V=1.0, theta=0.0
% INFO    : Bus 4509	: V=1.022044, theta=2.668853 -> V=1.0, theta=0.0
% INFO    : Bus 4510	: V=1.027661, theta=-38.789178 -> V=1.0, theta=0.0
% INFO    : Bus 4511	: V=1.040393, theta=-25.975564 -> V=1.0, theta=0.0
% INFO    : Bus 4513	: V=1.033259, theta=-9.803992 -> V=1.0, theta=0.0
% INFO    : Bus 4520	: V=1.01917, theta=-10.099585 -> V=1.0, theta=0.0
% INFO    : Bus 4525	: V=1.057452, theta=-8.831755 -> V=1.0, theta=0.0
% INFO    : Bus 4529	: V=1.056301, theta=-15.154075 -> V=1.0, theta=0.0
% INFO    : Bus 4541	: V=1.023808, theta=-9.896599 -> V=1.0, theta=0.0
% INFO    : Bus 4542	: V=1.048495, theta=-42.936839 -> V=1.0, theta=0.0
% INFO    : Bus 4543	: V=1.056921, theta=-45.124643 -> V=1.0, theta=0.0
% INFO    : Bus 4544	: V=1.047795, theta=-14.689027 -> V=1.0, theta=0.0
% INFO    : Bus 4549	: V=1.031082, theta=-11.513168 -> V=1.0, theta=0.0
% INFO    : Bus 4550	: V=1.014914, theta=-10.363845 -> V=1.0, theta=0.0
% INFO    : Bus 4554	: V=1.042589, theta=-9.819337 -> V=1.0, theta=0.0
% INFO    : Bus 4556	: V=0.979907, theta=-48.927394 -> V=1.0, theta=0.0
% INFO    : Bus 4562	: V=1.019971, theta=-16.826723 -> V=1.0, theta=0.0
% INFO    : Bus 4565	: V=1.023469, theta=11.73541 -> V=1.0, theta=0.0
% INFO    : Bus 4566	: V=1.073131, theta=-27.720699 -> V=1.0, theta=0.0
% INFO    : Bus 4577	: V=0.989833, theta=-55.46852 -> V=1.0, theta=0.0
% INFO    : Bus 4580	: V=1.047068, theta=-12.008433 -> V=1.0, theta=0.0
% INFO    : Bus 4586	: V=1.042233, theta=-10.864402 -> V=1.0, theta=0.0
% INFO    : Bus 4588	: V=1.049447, theta=-49.731549 -> V=1.0, theta=0.0
% INFO    : Bus 4592	: V=0.981713, theta=-48.59799 -> V=1.0, theta=0.0
% INFO    : Bus 4594	: V=0.999168, theta=-5.608971 -> V=1.0, theta=0.0
% INFO    : Bus 4598	: V=1.025937, theta=-7.972316 -> V=1.0, theta=0.0
% INFO    : Bus 4600	: V=1.033446, theta=-49.732578 -> V=1.0, theta=0.0
% INFO    : Bus 4603	: V=1.019644, theta=-51.869124 -> V=1.0, theta=0.0
% INFO    : Bus 4614	: V=1.021383, theta=8.264351 -> V=1.0, theta=0.0
% INFO    : Bus 4615	: V=1.061074, theta=-25.400791 -> V=1.0, theta=0.0
% INFO    : Bus 4616	: V=1.012324, theta=16.969427 -> V=1.0, theta=0.0
% INFO    : Bus 4623	: V=0.992881, theta=-16.886734 -> V=1.0, theta=0.0
% INFO    : Bus 4624	: V=1.039942, theta=-15.714328 -> V=1.0, theta=0.0
% INFO    : Bus 4632	: V=1.020645, theta=-48.236226 -> V=1.0, theta=0.0
% INFO    : Bus 4644	: V=1.037671, theta=-43.914953 -> V=1.0, theta=0.0
% INFO    : Bus 4650	: V=0.99335, theta=-53.62447 -> V=1.0, theta=0.0
% INFO    : Bus 4651	: V=1.030087, theta=-53.644773 -> V=1.0, theta=0.0
% INFO    : Bus 4652	: V=1.064983, theta=-44.679234 -> V=1.0, theta=0.0
% INFO    : Bus 4656	: V=1.04736, theta=-19.72727 -> V=1.0, theta=0.0
% INFO    : Bus 4657	: V=1.022686, theta=-38.113595 -> V=1.0, theta=0.0
% INFO    : Bus 4658	: V=1.012281, theta=-47.208522 -> V=1.0, theta=0.0
% INFO    : Bus 4661	: V=1.051599, theta=-26.284671 -> V=1.0, theta=0.0
% INFO    : Bus 4663	: V=1.028053, theta=-49.391084 -> V=1.0, theta=0.0
% INFO    : Bus 4665	: V=1.033888, theta=-11.508364 -> V=1.0, theta=0.0
% INFO    : Bus 4674	: V=1.033798, theta=-12.437269 -> V=1.0, theta=0.0
% INFO    : Bus 4679	: V=1.041212, theta=-20.6513 -> V=1.0, theta=0.0
% INFO    : Bus 4683	: V=1.047572, theta=-3.6912 -> V=1.0, theta=0.0
% INFO    : Bus 4685	: V=1.041453, theta=-25.836412 -> V=1.0, theta=0.0
% INFO    : Bus 4686	: V=1.026397, theta=8.915462 -> V=1.0, theta=0.0
% INFO    : Bus 4687	: V=1.01013, theta=0.854718 -> V=1.0, theta=0.0
% INFO    : Bus 4689	: V=1.043624, theta=-31.015452 -> V=1.0, theta=0.0
% INFO    : Bus 4690	: V=1.033192, theta=-42.772431 -> V=1.0, theta=0.0
% INFO    : Bus 4692	: V=1.011635, theta=-0.528165 -> V=1.0, theta=0.0
% INFO    : Bus 4701	: V=1.044876, theta=-9.959333 -> V=1.0, theta=0.0
% INFO    : Bus 4704	: V=1.078317, theta=-35.372047 -> V=1.0, theta=0.0
% INFO    : Bus 4706	: V=1.060566, theta=-45.898804 -> V=1.0, theta=0.0
% INFO    : Bus 4710	: V=1.028445, theta=-9.15033 -> V=1.0, theta=0.0
% INFO    : Bus 4711	: V=1.043852, theta=-11.422203 -> V=1.0, theta=0.0
% INFO    : Bus 4712	: V=1.032528, theta=-34.167571 -> V=1.0, theta=0.0
% INFO    : Bus 4717	: V=1.043846, theta=-42.202108 -> V=1.0, theta=0.0
% INFO    : Bus 4721	: V=0.992962, theta=-54.243678 -> V=1.0, theta=0.0
% INFO    : Bus 4725	: V=1.015888, theta=-10.567762 -> V=1.0, theta=0.0
% INFO    : Bus 4728	: V=1.039095, theta=-21.395607 -> V=1.0, theta=0.0
% INFO    : Bus 4729	: V=1.035146, theta=-8.455601 -> V=1.0, theta=0.0
% INFO    : Bus 4733	: V=1.049825, theta=18.61991 -> V=1.0, theta=0.0
% INFO    : Bus 4734	: V=1.012079, theta=-10.191896 -> V=1.0, theta=0.0
% INFO    : Bus 4735	: V=0.998166, theta=-44.27649 -> V=1.0, theta=0.0
% INFO    : Bus 4738	: V=1.064836, theta=-10.744894 -> V=1.0, theta=0.0
% INFO    : Bus 4740	: V=1.037211, theta=17.40897 -> V=1.0, theta=0.0
% INFO    : Bus 4744	: V=0.978365, theta=-41.024043 -> V=1.0, theta=0.0
% INFO    : Bus 4747	: V=1.036623, theta=-12.332394 -> V=1.0, theta=0.0
% INFO    : Bus 4748	: V=1.033506, theta=-12.417653 -> V=1.0, theta=0.0
% INFO    : Bus 4750	: V=1.015137, theta=-45.276024 -> V=1.0, theta=0.0
% INFO    : Bus 4752	: V=1.007473, theta=-47.741639 -> V=1.0, theta=0.0
% INFO    : Bus 4757	: V=1.02687, theta=3.635488 -> V=1.0, theta=0.0
% INFO    : Bus 4765	: V=1.03372, theta=-12.259227 -> V=1.0, theta=0.0
% INFO    : Bus 4771	: V=0.994103, theta=-36.152678 -> V=1.0, theta=0.0
% INFO    : Bus 4772	: V=1.027623, theta=-47.726342 -> V=1.0, theta=0.0
% INFO    : Bus 4773	: V=1.020563, theta=-42.19142 -> V=1.0, theta=0.0
% INFO    : Bus 4774	: V=1.027956, theta=1.772495 -> V=1.0, theta=0.0
% INFO    : Bus 4776	: V=1.068296, theta=27.287199 -> V=1.0, theta=0.0
% INFO    : Bus 4779	: V=1.061631, theta=33.330378 -> V=1.0, theta=0.0
% INFO    : Bus 4783	: V=1.069324, theta=8.316401 -> V=1.0, theta=0.0
% INFO    : Bus 4787	: V=0.98971, theta=-14.726367 -> V=1.0, theta=0.0
% INFO    : Bus 4795	: V=1.072329, theta=-43.593004 -> V=1.0, theta=0.0
% INFO    : Bus 4797	: V=1.087201, theta=32.32252 -> V=1.0, theta=0.0
% INFO    : Bus 4799	: V=1.0073, theta=5.93443 -> V=1.0, theta=0.0
% INFO    : Bus 4806	: V=1.024462, theta=-46.444223 -> V=1.0, theta=0.0
% INFO    : Bus 4807	: V=1.054594, theta=-41.633661 -> V=1.0, theta=0.0
% INFO    : Bus 4809	: V=1.013804, theta=-45.319191 -> V=1.0, theta=0.0
% INFO    : Bus 4816	: V=1.062911, theta=-23.822779 -> V=1.0, theta=0.0
% INFO    : Bus 4819	: V=1.035474, theta=1.140999 -> V=1.0, theta=0.0
% INFO    : Bus 4823	: V=1.06272, theta=-14.712789 -> V=1.0, theta=0.0
% INFO    : Bus 4825	: V=0.997516, theta=8.732686 -> V=1.0, theta=0.0
% INFO    : Bus 4826	: V=1.075745, theta=-24.387923 -> V=1.0, theta=0.0
% INFO    : Bus 4829	: V=1.020465, theta=-5.667752 -> V=1.0, theta=0.0
% INFO    : Bus 4831	: V=1.027345, theta=-15.792134 -> V=1.0, theta=0.0
% INFO    : Bus 4843	: V=1.053038, theta=-42.000594 -> V=1.0, theta=0.0
% INFO    : Bus 4846	: V=1.030285, theta=13.52358 -> V=1.0, theta=0.0
% INFO    : Bus 4850	: V=1.052648, theta=-13.908759 -> V=1.0, theta=0.0
% INFO    : Bus 4852	: V=1.039682, theta=-20.363097 -> V=1.0, theta=0.0
% INFO    : Bus 4855	: V=1.017659, theta=-59.350334 -> V=1.0, theta=0.0
% INFO    : Bus 4856	: V=1.02638, theta=-44.841603 -> V=1.0, theta=0.0
% INFO    : Bus 4858	: V=1.064819, theta=30.746864 -> V=1.0, theta=0.0
% INFO    : Bus 4863	: V=1.022186, theta=11.546445 -> V=1.0, theta=0.0
% INFO    : Bus 4864	: V=1.039552, theta=-12.879018 -> V=1.0, theta=0.0
% INFO    : Bus 4867	: V=1.035276, theta=-3.453915 -> V=1.0, theta=0.0
% INFO    : Bus 4868	: V=0.998971, theta=-47.459828 -> V=1.0, theta=0.0
% INFO    : Bus 4872	: V=1.016056, theta=7.721617 -> V=1.0, theta=0.0
% INFO    : Bus 4874	: V=1.075519, theta=-39.452902 -> V=1.0, theta=0.0
% INFO    : Bus 4880	: V=1.03955, theta=-15.833489 -> V=1.0, theta=0.0
% INFO    : Bus 4885	: V=1.073792, theta=-26.378319 -> V=1.0, theta=0.0
% INFO    : Bus 4889	: V=1.035733, theta=-12.245951 -> V=1.0, theta=0.0
% INFO    : Bus 4890	: V=1.022368, theta=-48.115238 -> V=1.0, theta=0.0
% INFO    : Bus 4896	: V=1.016398, theta=-58.139663 -> V=1.0, theta=0.0
% INFO    : Bus 4897	: V=1.018589, theta=-45.870257 -> V=1.0, theta=0.0
% INFO    : Bus 4906	: V=1.029168, theta=-45.727716 -> V=1.0, theta=0.0
% INFO    : Bus 4907	: V=1.043664, theta=-13.305602 -> V=1.0, theta=0.0
% INFO    : Bus 4908	: V=1.036682, theta=-21.309654 -> V=1.0, theta=0.0
% INFO    : Bus 4910	: V=1.024356, theta=-46.521838 -> V=1.0, theta=0.0
% INFO    : Bus 4914	: V=1.036506, theta=-23.010125 -> V=1.0, theta=0.0
% INFO    : Bus 4918	: V=1.059135, theta=-11.057428 -> V=1.0, theta=0.0
% INFO    : Bus 4925	: V=1.036252, theta=-22.509638 -> V=1.0, theta=0.0
% INFO    : Bus 4926	: V=1.055343, theta=-41.653126 -> V=1.0, theta=0.0
% INFO    : Bus 4929	: V=1.019242, theta=5.129207 -> V=1.0, theta=0.0
% INFO    : Bus 4931	: V=1.040167, theta=-42.992365 -> V=1.0, theta=0.0
% INFO    : Bus 4936	: V=1.04373, theta=-30.921402 -> V=1.0, theta=0.0
% INFO    : Bus 4939	: V=1.039171, theta=-4.5288 -> V=1.0, theta=0.0
% INFO    : Bus 4942	: V=1.029688, theta=-12.887815 -> V=1.0, theta=0.0
% INFO    : Bus 4945	: V=1.059702, theta=-40.549906 -> V=1.0, theta=0.0
% INFO    : Bus 4947	: V=1.018243, theta=-39.334796 -> V=1.0, theta=0.0
% INFO    : Bus 4948	: V=1.033168, theta=-39.709053 -> V=1.0, theta=0.0
% INFO    : Bus 4950	: V=1.035276, theta=-40.182771 -> V=1.0, theta=0.0
% INFO    : Bus 4951	: V=1.044873, theta=-1.598447 -> V=1.0, theta=0.0
% INFO    : Bus 4952	: V=1.044318, theta=-17.534802 -> V=1.0, theta=0.0
% INFO    : Bus 4953	: V=1.01977, theta=-51.235898 -> V=1.0, theta=0.0
% INFO    : Bus 4954	: V=1.019681, theta=-42.948639 -> V=1.0, theta=0.0
% INFO    : Bus 4957	: V=1.048836, theta=-38.451969 -> V=1.0, theta=0.0
% INFO    : Bus 4958	: V=1.032637, theta=-45.30464 -> V=1.0, theta=0.0
% INFO    : Bus 4964	: V=1.026451, theta=12.070739 -> V=1.0, theta=0.0
% INFO    : Bus 4967	: V=1.023151, theta=-41.92128 -> V=1.0, theta=0.0
% INFO    : Bus 4968	: V=1.051948, theta=12.030292 -> V=1.0, theta=0.0
% INFO    : Bus 4970	: V=1.05987, theta=-17.639843 -> V=1.0, theta=0.0
% INFO    : Bus 4974	: V=1.018908, theta=-13.502004 -> V=1.0, theta=0.0
% INFO    : Bus 4993	: V=1.089148, theta=32.452882 -> V=1.0, theta=0.0
% INFO    : Bus 5001	: V=1.066984, theta=15.48781 -> V=1.0, theta=0.0
% INFO    : Bus 5002	: V=1.067682, theta=-8.723226 -> V=1.0, theta=0.0
% INFO    : Bus 5003	: V=1.043674, theta=-9.696477 -> V=1.0, theta=0.0
% INFO    : Bus 5004	: V=1.061776, theta=-15.444827 -> V=1.0, theta=0.0
% INFO    : Bus 5006	: V=0.994019, theta=-36.807025 -> V=1.0, theta=0.0
% INFO    : Bus 5007	: V=1.021403, theta=-15.311577 -> V=1.0, theta=0.0
% INFO    : Bus 5008	: V=1.016418, theta=12.111698 -> V=1.0, theta=0.0
% INFO    : Bus 5016	: V=1.022451, theta=-5.00254 -> V=1.0, theta=0.0
% INFO    : Bus 5019	: V=1.04927, theta=-12.982732 -> V=1.0, theta=0.0
% INFO    : Bus 5025	: V=1.006979, theta=-47.649522 -> V=1.0, theta=0.0
% INFO    : Bus 5031	: V=1.022015, theta=8.362718 -> V=1.0, theta=0.0
% INFO    : Bus 5034	: V=1.027075, theta=-51.319318 -> V=1.0, theta=0.0
% INFO    : Bus 5042	: V=1.043173, theta=-49.476619 -> V=1.0, theta=0.0
% INFO    : Bus 5044	: V=1.060018, theta=-39.975233 -> V=1.0, theta=0.0
% INFO    : Bus 5049	: V=1.019742, theta=-20.452658 -> V=1.0, theta=0.0
% INFO    : Bus 5051	: V=1.039098, theta=-16.500428 -> V=1.0, theta=0.0
% INFO    : Bus 5060	: V=1.067508, theta=-40.432615 -> V=1.0, theta=0.0
% INFO    : Bus 5065	: V=1.072972, theta=28.809735 -> V=1.0, theta=0.0
% INFO    : Bus 5067	: V=1.021364, theta=-7.986964 -> V=1.0, theta=0.0
% INFO    : Bus 5077	: V=1.049884, theta=-26.663944 -> V=1.0, theta=0.0
% INFO    : Bus 5083	: V=1.040014, theta=-12.198345 -> V=1.0, theta=0.0
% INFO    : Bus 5091	: V=1.054352, theta=-38.828724 -> V=1.0, theta=0.0
% INFO    : Bus 5093	: V=1.005327, theta=-14.902286 -> V=1.0, theta=0.0
% INFO    : Bus 5094	: V=1.02894, theta=-34.261029 -> V=1.0, theta=0.0
% INFO    : Bus 5096	: V=1.046399, theta=-38.560768 -> V=1.0, theta=0.0
% INFO    : Bus 5097	: V=1.059554, theta=-9.307901 -> V=1.0, theta=0.0
% INFO    : Bus 5099	: V=1.058069, theta=1.551956 -> V=1.0, theta=0.0
% INFO    : Bus 5106	: V=1.070098, theta=-31.647923 -> V=1.0, theta=0.0
% INFO    : Bus 5108	: V=1.040894, theta=15.511042 -> V=1.0, theta=0.0
% INFO    : Bus 5110	: V=1.034874, theta=-10.249956 -> V=1.0, theta=0.0
% INFO    : Bus 5111	: V=1.019649, theta=-52.027452 -> V=1.0, theta=0.0
% INFO    : Bus 5117	: V=1.021991, theta=-46.476868 -> V=1.0, theta=0.0
% INFO    : Bus 5120	: V=1.057395, theta=-23.724008 -> V=1.0, theta=0.0
% INFO    : Bus 5121	: V=1.017828, theta=-43.625753 -> V=1.0, theta=0.0
% INFO    : Bus 5125	: V=1.050162, theta=-37.34517 -> V=1.0, theta=0.0
% INFO    : Bus 5131	: V=1.074244, theta=-26.36545 -> V=1.0, theta=0.0
% INFO    : Bus 5137	: V=1.023524, theta=-16.375719 -> V=1.0, theta=0.0
% INFO    : Bus 5144	: V=1.035348, theta=-3.111199 -> V=1.0, theta=0.0
% INFO    : Bus 5146	: V=1.01171, theta=-34.157872 -> V=1.0, theta=0.0
% INFO    : Bus 5147	: V=1.026032, theta=3.684117 -> V=1.0, theta=0.0
% INFO    : Bus 5155	: V=1.031615, theta=-10.83047 -> V=1.0, theta=0.0
% INFO    : Bus 5162	: V=1.016868, theta=-47.850863 -> V=1.0, theta=0.0
% INFO    : Bus 5163	: V=1.03701, theta=-38.496557 -> V=1.0, theta=0.0
% INFO    : Bus 5165	: V=1.016094, theta=8.082006 -> V=1.0, theta=0.0
% INFO    : Bus 5170	: V=1.031754, theta=-53.011941 -> V=1.0, theta=0.0
% INFO    : Bus 5171	: V=1.01545, theta=-46.857001 -> V=1.0, theta=0.0
% INFO    : Bus 5174	: V=1.043752, theta=-21.06468 -> V=1.0, theta=0.0
% INFO    : Bus 5179	: V=1.044243, theta=-30.656519 -> V=1.0, theta=0.0
% INFO    : Bus 5182	: V=1.045136, theta=-7.970779 -> V=1.0, theta=0.0
% INFO    : Bus 5188	: V=1.015017, theta=0.78079 -> V=1.0, theta=0.0
% INFO    : Bus 5189	: V=1.023618, theta=-46.612109 -> V=1.0, theta=0.0
% INFO    : Bus 5191	: V=1.036462, theta=-49.446584 -> V=1.0, theta=0.0
% INFO    : Bus 5202	: V=1.030983, theta=-53.060445 -> V=1.0, theta=0.0
% INFO    : Bus 5203	: V=1.027094, theta=5.766989 -> V=1.0, theta=0.0
% INFO    : Bus 5205	: V=1.026251, theta=-45.579804 -> V=1.0, theta=0.0
% INFO    : Bus 5210	: V=0.999596, theta=0.054117 -> V=1.0, theta=0.0
% INFO    : Bus 5212	: V=1.044864, theta=-11.010494 -> V=1.0, theta=0.0
% INFO    : Bus 5213	: V=1.045448, theta=-26.411208 -> V=1.0, theta=0.0
% INFO    : Bus 5214	: V=1.041, theta=-2.410275 -> V=1.0, theta=0.0
% INFO    : Bus 5215	: V=1.024179, theta=-5.83903 -> V=1.0, theta=0.0
% INFO    : Bus 5217	: V=1.016177, theta=-47.894882 -> V=1.0, theta=0.0
% INFO    : Bus 5233	: V=1.04328, theta=-10.973219 -> V=1.0, theta=0.0
% INFO    : Bus 5237	: V=1.050569, theta=-14.773477 -> V=1.0, theta=0.0
% INFO    : Bus 5239	: V=1.005494, theta=-46.913998 -> V=1.0, theta=0.0
% INFO    : Bus 5241	: V=1.028186, theta=-3.618432 -> V=1.0, theta=0.0
% INFO    : Bus 5246	: V=1.032411, theta=12.598115 -> V=1.0, theta=0.0
% INFO    : Bus 5247	: V=1.001398, theta=-0.49248 -> V=1.0, theta=0.0
% INFO    : Bus 5255	: V=1.03341, theta=9.303036 -> V=1.0, theta=0.0
% INFO    : Bus 5256	: V=1.000884, theta=-16.700858 -> V=1.0, theta=0.0
% INFO    : Bus 5257	: V=1.049117, theta=-6.26418 -> V=1.0, theta=0.0
% INFO    : Bus 5263	: V=1.055839, theta=-44.433532 -> V=1.0, theta=0.0
% INFO    : Bus 5266	: V=1.028935, theta=-34.261717 -> V=1.0, theta=0.0
% INFO    : Bus 5270	: V=1.04013, theta=-21.145434 -> V=1.0, theta=0.0
% INFO    : Bus 5271	: V=1.020246, theta=8.846019 -> V=1.0, theta=0.0
% INFO    : Bus 5274	: V=0.995551, theta=-46.965426 -> V=1.0, theta=0.0
% INFO    : Bus 5276	: V=1.018539, theta=-43.988903 -> V=1.0, theta=0.0
% INFO    : Bus 5278	: V=1.041244, theta=-24.302931 -> V=1.0, theta=0.0
% INFO    : Bus 5279	: V=1.012625, theta=16.961421 -> V=1.0, theta=0.0
% INFO    : Bus 5280	: V=1.021983, theta=-41.283482 -> V=1.0, theta=0.0
% INFO    : Bus 5286	: V=1.037057, theta=-22.192474 -> V=1.0, theta=0.0
% INFO    : Bus 5288	: V=0.997407, theta=-15.135755 -> V=1.0, theta=0.0
% INFO    : Bus 5289	: V=1.076031, theta=-37.794005 -> V=1.0, theta=0.0
% INFO    : Bus 5290	: V=1.011274, theta=-35.534778 -> V=1.0, theta=0.0
% INFO    : Bus 5295	: V=1.033108, theta=21.51946 -> V=1.0, theta=0.0
% INFO    : Bus 5296	: V=1.015725, theta=19.372243 -> V=1.0, theta=0.0
% INFO    : Bus 5297	: V=1.040618, theta=-24.406654 -> V=1.0, theta=0.0
% INFO    : Bus 5299	: V=1.061166, theta=34.421693 -> V=1.0, theta=0.0
% INFO    : Bus 5300	: V=1.045905, theta=-10.997713 -> V=1.0, theta=0.0
% INFO    : Bus 5308	: V=0.98387, theta=-18.21545 -> V=1.0, theta=0.0
% INFO    : Bus 5311	: V=1.043637, theta=16.562698 -> V=1.0, theta=0.0
% INFO    : Bus 5317	: V=1.028, theta=-44.254256 -> V=1.0, theta=0.0
% INFO    : Bus 5320	: V=1.02841, theta=3.793243 -> V=1.0, theta=0.0
% INFO    : Bus 5329	: V=1.018401, theta=-42.886221 -> V=1.0, theta=0.0
% INFO    : Bus 5331	: V=1.000112, theta=-35.788348 -> V=1.0, theta=0.0
% INFO    : Bus 5332	: V=1.021425, theta=-50.698742 -> V=1.0, theta=0.0
% INFO    : Bus 5333	: V=1.002717, theta=-46.751822 -> V=1.0, theta=0.0
% INFO    : Bus 5334	: V=1.034725, theta=-12.75309 -> V=1.0, theta=0.0
% INFO    : Bus 5339	: V=0.999355, theta=-32.205213 -> V=1.0, theta=0.0
% INFO    : Bus 5340	: V=1.051438, theta=-11.200258 -> V=1.0, theta=0.0
% INFO    : Bus 5341	: V=1.01091, theta=-21.676826 -> V=1.0, theta=0.0
% INFO    : Bus 5342	: V=1.012688, theta=-1.048625 -> V=1.0, theta=0.0
% INFO    : Bus 5346	: V=1.048768, theta=28.252436 -> V=1.0, theta=0.0
% INFO    : Bus 5348	: V=1.015924, theta=-42.487214 -> V=1.0, theta=0.0
% INFO    : Bus 5350	: V=0.976782, theta=-24.559425 -> V=1.0, theta=0.0
% INFO    : Bus 5351	: V=1.037736, theta=-14.066675 -> V=1.0, theta=0.0
% INFO    : Bus 5354	: V=1.046455, theta=-8.661275 -> V=1.0, theta=0.0
% INFO    : Bus 5361	: V=0.972326, theta=-42.828749 -> V=1.0, theta=0.0
% INFO    : Bus 5362	: V=1.043479, theta=-24.26519 -> V=1.0, theta=0.0
% INFO    : Bus 5364	: V=1.020499, theta=-1.54351 -> V=1.0, theta=0.0
% INFO    : Bus 5365	: V=1.063822, theta=-11.51529 -> V=1.0, theta=0.0
% INFO    : Bus 5366	: V=1.02359, theta=-46.644005 -> V=1.0, theta=0.0
% INFO    : Bus 5372	: V=1.063524, theta=-40.57254 -> V=1.0, theta=0.0
% INFO    : Bus 5379	: V=1.105689, theta=-6.79391 -> V=1.0, theta=0.0
% INFO    : Bus 5383	: V=1.047026, theta=-24.505001 -> V=1.0, theta=0.0
% INFO    : Bus 5388	: V=1.007959, theta=-14.803624 -> V=1.0, theta=0.0
% INFO    : Bus 5391	: V=1.023168, theta=-48.106837 -> V=1.0, theta=0.0
% INFO    : Bus 5393	: V=1.061367, theta=-15.492076 -> V=1.0, theta=0.0
% INFO    : Bus 5395	: V=1.049, theta=-27.436125 -> V=1.0, theta=0.0
% INFO    : Bus 5400	: V=1.026563, theta=-13.995618 -> V=1.0, theta=0.0
% INFO    : Bus 5409	: V=1.023182, theta=-38.682073 -> V=1.0, theta=0.0
% INFO    : Bus 5410	: V=1.044777, theta=-21.406419 -> V=1.0, theta=0.0
% INFO    : Bus 5413	: V=1.03575, theta=-18.055374 -> V=1.0, theta=0.0
% INFO    : Bus 5416	: V=1.001202, theta=12.152799 -> V=1.0, theta=0.0
% INFO    : Bus 5417	: V=1.059856, theta=-12.1436 -> V=1.0, theta=0.0
% INFO    : Bus 5418	: V=1.036715, theta=-21.310085 -> V=1.0, theta=0.0
% INFO    : Bus 5419	: V=1.018426, theta=-15.162316 -> V=1.0, theta=0.0
% INFO    : Bus 5420	: V=1.02044, theta=-22.990881 -> V=1.0, theta=0.0
% INFO    : Bus 5421	: V=0.997405, theta=-15.13568 -> V=1.0, theta=0.0
% INFO    : Bus 5423	: V=1.002482, theta=6.650403 -> V=1.0, theta=0.0
% INFO    : Bus 5425	: V=1.077356, theta=-35.523318 -> V=1.0, theta=0.0
% INFO    : Bus 5426	: V=1.021179, theta=2.993375 -> V=1.0, theta=0.0
% INFO    : Bus 5435	: V=1.013845, theta=-46.918495 -> V=1.0, theta=0.0
% INFO    : Bus 5441	: V=1.041494, theta=-2.871036 -> V=1.0, theta=0.0
% INFO    : Bus 5442	: V=1.012513, theta=16.946551 -> V=1.0, theta=0.0
% INFO    : Bus 5450	: V=1.053632, theta=1.072582 -> V=1.0, theta=0.0
% INFO    : Bus 5452	: V=0.997595, theta=-47.54296 -> V=1.0, theta=0.0
% INFO    : Bus 5455	: V=1.04513, theta=-7.970741 -> V=1.0, theta=0.0
% INFO    : Bus 5458	: V=1.038363, theta=-21.451874 -> V=1.0, theta=0.0
% INFO    : Bus 5460	: V=0.988594, theta=-18.027515 -> V=1.0, theta=0.0
% INFO    : Bus 5461	: V=1.05743, theta=-18.381726 -> V=1.0, theta=0.0
% INFO    : Bus 5463	: V=1.02307, theta=-42.018425 -> V=1.0, theta=0.0
% INFO    : Bus 5464	: V=1.04942, theta=-38.419571 -> V=1.0, theta=0.0
% INFO    : Bus 5465	: V=1.001327, theta=-46.65705 -> V=1.0, theta=0.0
% INFO    : Bus 5469	: V=1.067045, theta=-38.802465 -> V=1.0, theta=0.0
% INFO    : Bus 5477	: V=1.074995, theta=-26.195531 -> V=1.0, theta=0.0
% INFO    : Bus 5481	: V=1.063327, theta=-8.931038 -> V=1.0, theta=0.0
% INFO    : Bus 5482	: V=1.046078, theta=-7.297941 -> V=1.0, theta=0.0
% INFO    : Bus 5486	: V=1.0598, theta=4.502248 -> V=1.0, theta=0.0
% INFO    : Bus 5488	: V=1.041439, theta=-29.952888 -> V=1.0, theta=0.0
% INFO    : Bus 5490	: V=1.064044, theta=-15.148619 -> V=1.0, theta=0.0
% INFO    : Bus 5494	: V=0.999098, theta=-36.908159 -> V=1.0, theta=0.0
% INFO    : Bus 5500	: V=1.026927, theta=-53.371077 -> V=1.0, theta=0.0
% INFO    : Bus 5502	: V=1.037491, theta=-20.54784 -> V=1.0, theta=0.0
% INFO    : Bus 5509	: V=0.994728, theta=-6.017725 -> V=1.0, theta=0.0
% INFO    : Bus 5511	: V=1.016789, theta=-59.240772 -> V=1.0, theta=0.0
% INFO    : Bus 5512	: V=1.020123, theta=-41.318107 -> V=1.0, theta=0.0
% INFO    : Bus 5517	: V=0.9775, theta=-42.539832 -> V=1.0, theta=0.0
% INFO    : Bus 5519	: V=1.047274, theta=-24.565625 -> V=1.0, theta=0.0
% INFO    : Bus 5522	: V=1.067053, theta=0.712699 -> V=1.0, theta=0.0
% INFO    : Bus 5525	: V=1.035462, theta=-14.021081 -> V=1.0, theta=0.0
% INFO    : Bus 5526	: V=1.040627, theta=17.945588 -> V=1.0, theta=0.0
% INFO    : Bus 5529	: V=1.041514, theta=-2.871216 -> V=1.0, theta=0.0
% INFO    : Bus 5533	: V=1.041341, theta=-13.595487 -> V=1.0, theta=0.0
% INFO    : Bus 5546	: V=1.055712, theta=-23.801872 -> V=1.0, theta=0.0
% INFO    : Bus 5549	: V=1.00229, theta=-0.631077 -> V=1.0, theta=0.0
% INFO    : Bus 5550	: V=1.044355, theta=-25.941561 -> V=1.0, theta=0.0
% INFO    : Bus 5558	: V=1.013694, theta=17.294351 -> V=1.0, theta=0.0
% INFO    : Bus 5559	: V=1.002365, theta=-42.648238 -> V=1.0, theta=0.0
% INFO    : Bus 5562	: V=1.069676, theta=-45.57785 -> V=1.0, theta=0.0
% INFO    : Bus 5564	: V=1.042161, theta=-12.585697 -> V=1.0, theta=0.0
% INFO    : Bus 5567	: V=1.017406, theta=-18.92817 -> V=1.0, theta=0.0
% INFO    : Bus 5571	: V=1.036243, theta=-22.509656 -> V=1.0, theta=0.0
% INFO    : Bus 5573	: V=1.060977, theta=-23.409461 -> V=1.0, theta=0.0
% INFO    : Bus 5574	: V=1.040549, theta=-11.86988 -> V=1.0, theta=0.0
% INFO    : Bus 5586	: V=1.05568, theta=2.418195 -> V=1.0, theta=0.0
% INFO    : Bus 5587	: V=1.035808, theta=-10.367302 -> V=1.0, theta=0.0
% INFO    : Bus 5589	: V=1.03383, theta=-30.862864 -> V=1.0, theta=0.0
% INFO    : Bus 5591	: V=1.018603, theta=-1.652419 -> V=1.0, theta=0.0
% INFO    : Bus 5592	: V=1.014536, theta=-51.043193 -> V=1.0, theta=0.0
% INFO    : Bus 5595	: V=1.027836, theta=3.426519 -> V=1.0, theta=0.0
% INFO    : Bus 5608	: V=1.028672, theta=-50.35437 -> V=1.0, theta=0.0
% INFO    : Bus 5610	: V=1.045642, theta=-24.197425 -> V=1.0, theta=0.0
% INFO    : Bus 5616	: V=1.075879, theta=-35.292592 -> V=1.0, theta=0.0
% INFO    : Bus 5617	: V=0.98127, theta=-49.187417 -> V=1.0, theta=0.0
% INFO    : Bus 5618	: V=0.997607, theta=-4.667747 -> V=1.0, theta=0.0
% INFO    : Bus 5627	: V=1.027411, theta=-32.553941 -> V=1.0, theta=0.0
% INFO    : Bus 5630	: V=1.037555, theta=-4.070289 -> V=1.0, theta=0.0
% INFO    : Bus 5631	: V=0.989076, theta=-43.054381 -> V=1.0, theta=0.0
% INFO    : Bus 5641	: V=1.048787, theta=-26.137467 -> V=1.0, theta=0.0
% INFO    : Bus 5643	: V=0.989577, theta=-55.845538 -> V=1.0, theta=0.0
% INFO    : Bus 5648	: V=0.995084, theta=-13.471533 -> V=1.0, theta=0.0
% INFO    : Bus 5653	: V=1.047534, theta=-7.680116 -> V=1.0, theta=0.0
% INFO    : Bus 5655	: V=1.016772, theta=2.827447 -> V=1.0, theta=0.0
% INFO    : Bus 5658	: V=1.009808, theta=-23.836753 -> V=1.0, theta=0.0
% INFO    : Bus 5662	: V=1.010873, theta=-41.932245 -> V=1.0, theta=0.0
% INFO    : Bus 5664	: V=1.068735, theta=0.968479 -> V=1.0, theta=0.0
% INFO    : Bus 5666	: V=1.046893, theta=-10.752987 -> V=1.0, theta=0.0
% INFO    : Bus 5669	: V=1.003946, theta=-34.011961 -> V=1.0, theta=0.0
% INFO    : Bus 5670	: V=1.018899, theta=-47.108978 -> V=1.0, theta=0.0
% INFO    : Bus 5672	: V=0.982808, theta=-41.150035 -> V=1.0, theta=0.0
% INFO    : Bus 5674	: V=1.009419, theta=7.023959 -> V=1.0, theta=0.0
% INFO    : Bus 5681	: V=1.031456, theta=-53.165229 -> V=1.0, theta=0.0
% INFO    : Bus 5685	: V=1.039032, theta=-42.883507 -> V=1.0, theta=0.0
% INFO    : Bus 5686	: V=1.033278, theta=-10.192796 -> V=1.0, theta=0.0
% INFO    : Bus 5688	: V=1.035841, theta=-8.055175 -> V=1.0, theta=0.0
% INFO    : Bus 5691	: V=1.060611, theta=-45.305556 -> V=1.0, theta=0.0
% INFO    : Bus 5695	: V=1.047163, theta=-27.187915 -> V=1.0, theta=0.0
% INFO    : Bus 5697	: V=1.010447, theta=-47.112562 -> V=1.0, theta=0.0
% INFO    : Bus 5699	: V=1.049198, theta=-6.529972 -> V=1.0, theta=0.0
% INFO    : Bus 5709	: V=1.026473, theta=-8.528086 -> V=1.0, theta=0.0
% INFO    : Bus 5712	: V=1.039647, theta=-4.558258 -> V=1.0, theta=0.0
% INFO    : Bus 5720	: V=1.040698, theta=-25.156245 -> V=1.0, theta=0.0
% INFO    : Bus 5723	: V=1.041768, theta=-9.639222 -> V=1.0, theta=0.0
% INFO    : Bus 5726	: V=1.020165, theta=-42.201068 -> V=1.0, theta=0.0
% INFO    : Bus 5735	: V=1.054644, theta=-26.928091 -> V=1.0, theta=0.0
% INFO    : Bus 5738	: V=1.015478, theta=-10.510275 -> V=1.0, theta=0.0
% INFO    : Bus 5740	: V=1.014654, theta=4.973889 -> V=1.0, theta=0.0
% INFO    : Bus 5742	: V=1.028692, theta=26.344515 -> V=1.0, theta=0.0
% INFO    : Bus 5743	: V=1.05064, theta=-24.164058 -> V=1.0, theta=0.0
% INFO    : Bus 5748	: V=0.996773, theta=-4.642016 -> V=1.0, theta=0.0
% INFO    : Bus 5753	: V=1.037714, theta=-3.26164 -> V=1.0, theta=0.0
% INFO    : Bus 5760	: V=1.047432, theta=7.554087 -> V=1.0, theta=0.0
% INFO    : Bus 5762	: V=1.053432, theta=0.451774 -> V=1.0, theta=0.0
% INFO    : Bus 5764	: V=1.030004, theta=-25.513064 -> V=1.0, theta=0.0
% INFO    : Bus 5767	: V=1.024855, theta=-48.167766 -> V=1.0, theta=0.0
% INFO    : Bus 5771	: V=1.005505, theta=-46.602459 -> V=1.0, theta=0.0
% INFO    : Bus 5772	: V=1.036506, theta=5.394435 -> V=1.0, theta=0.0
% INFO    : Bus 5773	: V=1.040729, theta=-2.404677 -> V=1.0, theta=0.0
% INFO    : Bus 5776	: V=1.063217, theta=-7.210075 -> V=1.0, theta=0.0
% INFO    : Bus 5780	: V=1.030855, theta=-52.958818 -> V=1.0, theta=0.0
% INFO    : Bus 5781	: V=1.038035, theta=-11.764738 -> V=1.0, theta=0.0
% INFO    : Bus 5783	: V=1.054882, theta=11.673246 -> V=1.0, theta=0.0
% INFO    : Bus 5787	: V=1.031918, theta=-43.4138 -> V=1.0, theta=0.0
% INFO    : Bus 5789	: V=1.000709, theta=-16.068788 -> V=1.0, theta=0.0
% INFO    : Bus 5790	: V=1.02673, theta=-35.913747 -> V=1.0, theta=0.0
% INFO    : Bus 5792	: V=1.017936, theta=0.566548 -> V=1.0, theta=0.0
% INFO    : Bus 5793	: V=1.011587, theta=-47.471007 -> V=1.0, theta=0.0
% INFO    : Bus 5797	: V=0.982903, theta=-55.937579 -> V=1.0, theta=0.0
% INFO    : Bus 5799	: V=1.043112, theta=-32.312018 -> V=1.0, theta=0.0
% INFO    : Bus 5803	: V=1.044961, theta=-14.02515 -> V=1.0, theta=0.0
% INFO    : Bus 5805	: V=0.992355, theta=-54.488935 -> V=1.0, theta=0.0
% INFO    : Bus 5814	: V=1.048258, theta=-11.867086 -> V=1.0, theta=0.0
% INFO    : Bus 5815	: V=1.044027, theta=-50.864596 -> V=1.0, theta=0.0
% INFO    : Bus 5821	: V=1.019461, theta=-43.826963 -> V=1.0, theta=0.0
% INFO    : Bus 5823	: V=1.063184, theta=-39.213955 -> V=1.0, theta=0.0
% INFO    : Bus 5825	: V=0.995795, theta=-36.829799 -> V=1.0, theta=0.0
% INFO    : Bus 5828	: V=1.029274, theta=-36.522798 -> V=1.0, theta=0.0
% INFO    : Bus 5829	: V=1.011522, theta=-0.525357 -> V=1.0, theta=0.0
% INFO    : Bus 5831	: V=1.032948, theta=-46.95059 -> V=1.0, theta=0.0
% INFO    : Bus 5835	: V=1.012728, theta=16.946231 -> V=1.0, theta=0.0
% INFO    : Bus 5836	: V=1.040966, theta=-12.033407 -> V=1.0, theta=0.0
% INFO    : Bus 5837	: V=1.019384, theta=-10.165641 -> V=1.0, theta=0.0
% INFO    : Bus 5843	: V=1.034072, theta=15.26583 -> V=1.0, theta=0.0
% INFO    : Bus 5848	: V=1.003622, theta=-4.593673 -> V=1.0, theta=0.0
% INFO    : Bus 5853	: V=1.044384, theta=-7.444582 -> V=1.0, theta=0.0
% INFO    : Bus 5856	: V=1.039775, theta=-11.608229 -> V=1.0, theta=0.0
% INFO    : Bus 5857	: V=1.056548, theta=-21.100497 -> V=1.0, theta=0.0
% INFO    : Bus 5872	: V=1.020681, theta=11.413214 -> V=1.0, theta=0.0
% INFO    : Bus 5873	: V=1.020973, theta=-45.161164 -> V=1.0, theta=0.0
% INFO    : Bus 5877	: V=1.048701, theta=-49.785885 -> V=1.0, theta=0.0
% INFO    : Bus 5881	: V=1.062314, theta=-10.435974 -> V=1.0, theta=0.0
% INFO    : Bus 5884	: V=1.039018, theta=-39.486484 -> V=1.0, theta=0.0
% INFO    : Bus 5887	: V=1.007987, theta=21.860203 -> V=1.0, theta=0.0
% INFO    : Bus 5888	: V=1.052038, theta=17.362903 -> V=1.0, theta=0.0
% INFO    : Bus 5890	: V=1.030272, theta=-45.767937 -> V=1.0, theta=0.0
% INFO    : Bus 5891	: V=1.038346, theta=-12.124908 -> V=1.0, theta=0.0
% INFO    : Bus 5892	: V=1.024992, theta=-48.153536 -> V=1.0, theta=0.0
% INFO    : Bus 5893	: V=1.026601, theta=16.102265 -> V=1.0, theta=0.0
% INFO    : Bus 5897	: V=1.049488, theta=18.541477 -> V=1.0, theta=0.0
% INFO    : Bus 5907	: V=1.047873, theta=-8.494871 -> V=1.0, theta=0.0
% INFO    : Bus 5916	: V=1.043019, theta=18.096338 -> V=1.0, theta=0.0
% INFO    : Bus 5918	: V=1.053618, theta=-25.89283 -> V=1.0, theta=0.0
% INFO    : Bus 5919	: V=1.046245, theta=-49.652257 -> V=1.0, theta=0.0
% INFO    : Bus 5923	: V=1.029055, theta=-53.701552 -> V=1.0, theta=0.0
% INFO    : Bus 5926	: V=1.071514, theta=-48.003062 -> V=1.0, theta=0.0
% INFO    : Bus 5927	: V=0.994079, theta=-36.184356 -> V=1.0, theta=0.0
% INFO    : Bus 5933	: V=1.008443, theta=-48.246125 -> V=1.0, theta=0.0
% INFO    : Bus 5935	: V=1.066928, theta=-22.224726 -> V=1.0, theta=0.0
% INFO    : Bus 5940	: V=1.031482, theta=-14.571065 -> V=1.0, theta=0.0
% INFO    : Bus 5944	: V=1.054767, theta=-25.897507 -> V=1.0, theta=0.0
% INFO    : Bus 5946	: V=1.023681, theta=-42.208451 -> V=1.0, theta=0.0
% INFO    : Bus 5948	: V=1.024134, theta=-48.323145 -> V=1.0, theta=0.0
% INFO    : Bus 5949	: V=1.016343, theta=2.822912 -> V=1.0, theta=0.0
% INFO    : Bus 5952	: V=1.023957, theta=4.371578 -> V=1.0, theta=0.0
% INFO    : Bus 5957	: V=1.027417, theta=-16.202424 -> V=1.0, theta=0.0
% INFO    : Bus 5960	: V=1.019184, theta=-33.227537 -> V=1.0, theta=0.0
% INFO    : Bus 5961	: V=1.015278, theta=-46.320257 -> V=1.0, theta=0.0
% INFO    : Bus 5970	: V=1.019864, theta=-40.809127 -> V=1.0, theta=0.0
% INFO    : Bus 5971	: V=1.067028, theta=5.04202 -> V=1.0, theta=0.0
% INFO    : Bus 5974	: V=1.023469, theta=11.73541 -> V=1.0, theta=0.0
% INFO    : Bus 5979	: V=1.046415, theta=26.479954 -> V=1.0, theta=0.0
% INFO    : Bus 5983	: V=1.064637, theta=-14.879564 -> V=1.0, theta=0.0
% INFO    : Bus 5987	: V=1.03795, theta=-13.934441 -> V=1.0, theta=0.0
% INFO    : Bus 5990	: V=1.024622, theta=-10.185671 -> V=1.0, theta=0.0
% INFO    : Bus 5991	: V=1.018313, theta=-49.651632 -> V=1.0, theta=0.0
% INFO    : Bus 5993	: V=1.044859, theta=-11.010438 -> V=1.0, theta=0.0
% INFO    : Bus 5994	: V=1.034164, theta=-15.365343 -> V=1.0, theta=0.0
% INFO    : Bus 5996	: V=1.053383, theta=0.452005 -> V=1.0, theta=0.0
% INFO    : Bus 6000	: V=1.085651, theta=16.9619 -> V=1.0, theta=0.0
% INFO    : Bus 6004	: V=1.064444, theta=-47.252529 -> V=1.0, theta=0.0
% INFO    : Bus 6009	: V=1.014176, theta=-50.975888 -> V=1.0, theta=0.0
% INFO    : Bus 6010	: V=1.07902, theta=-23.14938 -> V=1.0, theta=0.0
% INFO    : Bus 6015	: V=1.022574, theta=-1.389768 -> V=1.0, theta=0.0
% INFO    : Bus 6017	: V=1.024964, theta=11.939308 -> V=1.0, theta=0.0
% INFO    : Bus 6022	: V=1.001596, theta=-37.747037 -> V=1.0, theta=0.0
% INFO    : Bus 6025	: V=1.029944, theta=15.101784 -> V=1.0, theta=0.0
% INFO    : Bus 6028	: V=1.02427, theta=8.595544 -> V=1.0, theta=0.0
% INFO    : Bus 6031	: V=1.039374, theta=-15.780003 -> V=1.0, theta=0.0
% INFO    : Bus 6036	: V=1.041753, theta=-0.893841 -> V=1.0, theta=0.0
% INFO    : Bus 6038	: V=1.047079, theta=-45.177751 -> V=1.0, theta=0.0
% INFO    : Bus 6039	: V=1.042753, theta=-50.581128 -> V=1.0, theta=0.0
% INFO    : Bus 6040	: V=1.026365, theta=-44.846715 -> V=1.0, theta=0.0
% INFO    : Bus 6041	: V=1.071556, theta=-48.003338 -> V=1.0, theta=0.0
% INFO    : Bus 6045	: V=1.001329, theta=-0.497586 -> V=1.0, theta=0.0
% INFO    : Bus 6047	: V=1.021029, theta=8.869605 -> V=1.0, theta=0.0
% INFO    : Bus 6052	: V=1.019191, theta=18.744304 -> V=1.0, theta=0.0
% INFO    : Bus 6053	: V=1.052661, theta=-26.616993 -> V=1.0, theta=0.0
% INFO    : Bus 6057	: V=1.006588, theta=-1.618004 -> V=1.0, theta=0.0
% INFO    : Bus 6058	: V=1.034129, theta=9.64509 -> V=1.0, theta=0.0
% INFO    : Bus 6060	: V=1.076909, theta=-37.809268 -> V=1.0, theta=0.0
% INFO    : Bus 6068	: V=1.032486, theta=13.237978 -> V=1.0, theta=0.0
% INFO    : Bus 6069	: V=0.988415, theta=-6.111052 -> V=1.0, theta=0.0
% INFO    : Bus 6071	: V=1.033326, theta=-16.372144 -> V=1.0, theta=0.0
% INFO    : Bus 6080	: V=1.057151, theta=-42.098594 -> V=1.0, theta=0.0
% INFO    : Bus 6090	: V=1.032192, theta=-38.570202 -> V=1.0, theta=0.0
% INFO    : Bus 6092	: V=1.03946, theta=-39.302053 -> V=1.0, theta=0.0
% INFO    : Bus 6093	: V=1.008226, theta=-40.430643 -> V=1.0, theta=0.0
% INFO    : Bus 6101	: V=1.029178, theta=-10.823669 -> V=1.0, theta=0.0
% INFO    : Bus 6104	: V=1.052842, theta=-12.128098 -> V=1.0, theta=0.0
% INFO    : Bus 6110	: V=1.055925, theta=-36.011444 -> V=1.0, theta=0.0
% INFO    : Bus 6112	: V=1.025898, theta=-9.276213 -> V=1.0, theta=0.0
% INFO    : Bus 6114	: V=1.04901, theta=-10.305588 -> V=1.0, theta=0.0
% INFO    : Bus 6115	: V=1.031059, theta=-11.285664 -> V=1.0, theta=0.0
% INFO    : Bus 6118	: V=1.027942, theta=26.269973 -> V=1.0, theta=0.0
% INFO    : Bus 6119	: V=1.039138, theta=-15.987796 -> V=1.0, theta=0.0
% INFO    : Bus 6127	: V=1.053195, theta=-46.799005 -> V=1.0, theta=0.0
% INFO    : Bus 6131	: V=1.141159, theta=19.233339 -> V=1.0, theta=0.0
% INFO    : Bus 6132	: V=1.013934, theta=-47.518736 -> V=1.0, theta=0.0
% INFO    : Bus 6134	: V=1.037631, theta=-52.750478 -> V=1.0, theta=0.0
% INFO    : Bus 6135	: V=0.969407, theta=-55.585275 -> V=1.0, theta=0.0
% INFO    : Bus 6138	: V=1.013527, theta=-43.940748 -> V=1.0, theta=0.0
% INFO    : Bus 6139	: V=1.053454, theta=1.076127 -> V=1.0, theta=0.0
% INFO    : Bus 6145	: V=1.021227, theta=-32.669285 -> V=1.0, theta=0.0
% INFO    : Bus 6146	: V=1.027242, theta=-12.087947 -> V=1.0, theta=0.0
% INFO    : Bus 6149	: V=1.012511, theta=16.94653 -> V=1.0, theta=0.0
% INFO    : Bus 6151	: V=1.031952, theta=-24.043559 -> V=1.0, theta=0.0
% INFO    : Bus 6153	: V=0.996786, theta=-14.746886 -> V=1.0, theta=0.0
% INFO    : Bus 6163	: V=1.03567, theta=-21.986931 -> V=1.0, theta=0.0
% INFO    : Bus 6167	: V=1.015341, theta=10.912565 -> V=1.0, theta=0.0
% INFO    : Bus 6168	: V=1.043938, theta=-13.377168 -> V=1.0, theta=0.0
% INFO    : Bus 6174	: V=1.010663, theta=-47.870802 -> V=1.0, theta=0.0
% INFO    : Bus 6178	: V=1.039445, theta=-24.646301 -> V=1.0, theta=0.0
% INFO    : Bus 6179	: V=1.038661, theta=-39.189548 -> V=1.0, theta=0.0
% INFO    : Bus 6183	: V=1.032969, theta=-53.197394 -> V=1.0, theta=0.0
% INFO    : Bus 6186	: V=1.032387, theta=-53.394752 -> V=1.0, theta=0.0
% INFO    : Bus 6187	: V=1.054472, theta=-41.006336 -> V=1.0, theta=0.0
% INFO    : Bus 6188	: V=0.985483, theta=-50.582871 -> V=1.0, theta=0.0
% INFO    : Bus 6192	: V=1.02478, theta=-42.750534 -> V=1.0, theta=0.0
% INFO    : Bus 6194	: V=1.024716, theta=-16.334779 -> V=1.0, theta=0.0
% INFO    : Bus 6199	: V=1.070633, theta=-12.60189 -> V=1.0, theta=0.0
% INFO    : Bus 6202	: V=1.034847, theta=3.977497 -> V=1.0, theta=0.0
% INFO    : Bus 6203	: V=1.069499, theta=-27.392683 -> V=1.0, theta=0.0
% INFO    : Bus 6206	: V=1.038423, theta=0.045008 -> V=1.0, theta=0.0
% INFO    : Bus 6209	: V=1.024252, theta=-48.184075 -> V=1.0, theta=0.0
% INFO    : Bus 6218	: V=1.01746, theta=4.88991 -> V=1.0, theta=0.0
% INFO    : Bus 6219	: V=1.034732, theta=-12.753159 -> V=1.0, theta=0.0
% INFO    : Bus 6220	: V=1.053799, theta=-22.955261 -> V=1.0, theta=0.0
% INFO    : Bus 6224	: V=0.998228, theta=-12.912978 -> V=1.0, theta=0.0
% INFO    : Bus 6231	: V=1.036226, theta=-8.008108 -> V=1.0, theta=0.0
% INFO    : Bus 6232	: V=1.041395, theta=-25.840003 -> V=1.0, theta=0.0
% INFO    : Bus 6233	: V=1.018011, theta=6.454792 -> V=1.0, theta=0.0
% INFO    : Bus 6239	: V=1.029262, theta=-44.679169 -> V=1.0, theta=0.0
% INFO    : Bus 6240	: V=1.07487, theta=-34.305726 -> V=1.0, theta=0.0
% INFO    : Bus 6243	: V=1.037026, theta=-43.881058 -> V=1.0, theta=0.0
% INFO    : Bus 6244	: V=0.981933, theta=-49.334169 -> V=1.0, theta=0.0
% INFO    : Bus 6246	: V=1.024401, theta=-37.00382 -> V=1.0, theta=0.0
% INFO    : Bus 6252	: V=1.01931, theta=-29.984607 -> V=1.0, theta=0.0
% INFO    : Bus 6253	: V=1.041636, theta=-25.798971 -> V=1.0, theta=0.0
% INFO    : Bus 6254	: V=0.990568, theta=-54.325821 -> V=1.0, theta=0.0
% INFO    : Bus 6261	: V=1.028006, theta=-54.171426 -> V=1.0, theta=0.0
% INFO    : Bus 6263	: V=1.032886, theta=13.276399 -> V=1.0, theta=0.0
% INFO    : Bus 6267	: V=1.040407, theta=-24.438492 -> V=1.0, theta=0.0
% INFO    : Bus 6271	: V=1.053813, theta=-20.132206 -> V=1.0, theta=0.0
% INFO    : Bus 6275	: V=0.997352, theta=-4.846195 -> V=1.0, theta=0.0
% INFO    : Bus 6280	: V=1.019445, theta=-33.127661 -> V=1.0, theta=0.0
% INFO    : Bus 6282	: V=1.0472, theta=26.596881 -> V=1.0, theta=0.0
% INFO    : Bus 6283	: V=1.042145, theta=16.009807 -> V=1.0, theta=0.0
% INFO    : Bus 6288	: V=1.004251, theta=-3.669685 -> V=1.0, theta=0.0
% INFO    : Bus 6290	: V=1.058239, theta=-12.880479 -> V=1.0, theta=0.0
% INFO    : Bus 6291	: V=1.039201, theta=-23.999248 -> V=1.0, theta=0.0
% INFO    : Bus 6292	: V=1.042112, theta=-48.273587 -> V=1.0, theta=0.0
% INFO    : Bus 6293	: V=1.004441, theta=-4.400608 -> V=1.0, theta=0.0
% INFO    : Bus 6295	: V=1.048295, theta=9.044501 -> V=1.0, theta=0.0
% INFO    : Bus 6298	: V=1.051189, theta=-47.906417 -> V=1.0, theta=0.0
% INFO    : Bus 6299	: V=1.050975, theta=-44.42578 -> V=1.0, theta=0.0
% INFO    : Bus 6306	: V=1.076004, theta=-24.327992 -> V=1.0, theta=0.0
% INFO    : Bus 6308	: V=1.043125, theta=-25.590237 -> V=1.0, theta=0.0
% INFO    : Bus 6311	: V=0.97235, theta=-42.823481 -> V=1.0, theta=0.0
% INFO    : Bus 6313	: V=1.033328, theta=-23.945702 -> V=1.0, theta=0.0
% INFO    : Bus 6315	: V=0.988448, theta=-42.71208 -> V=1.0, theta=0.0
% INFO    : Bus 6320	: V=1.031936, theta=4.19826 -> V=1.0, theta=0.0
% INFO    : Bus 6323	: V=1.012964, theta=2.806367 -> V=1.0, theta=0.0
% INFO    : Bus 6329	: V=0.994824, theta=-43.877964 -> V=1.0, theta=0.0
% INFO    : Bus 6331	: V=1.053365, theta=-0.840778 -> V=1.0, theta=0.0
% INFO    : Bus 6332	: V=1.064292, theta=-11.355997 -> V=1.0, theta=0.0
% INFO    : Bus 6333	: V=1.010821, theta=-40.748261 -> V=1.0, theta=0.0
% INFO    : Bus 6337	: V=1.088467, theta=-9.653232 -> V=1.0, theta=0.0
% INFO    : Bus 6340	: V=1.056921, theta=-45.124625 -> V=1.0, theta=0.0
% INFO    : Bus 6342	: V=1.040221, theta=17.9716 -> V=1.0, theta=0.0
% INFO    : Bus 6344	: V=1.022768, theta=-43.695178 -> V=1.0, theta=0.0
% INFO    : Bus 6345	: V=0.99741, theta=8.692009 -> V=1.0, theta=0.0
% INFO    : Bus 6349	: V=1.022378, theta=-48.156496 -> V=1.0, theta=0.0
% INFO    : Bus 6351	: V=1.059908, theta=-16.273161 -> V=1.0, theta=0.0
% INFO    : Bus 6354	: V=1.038618, theta=6.820334 -> V=1.0, theta=0.0
% INFO    : Bus 6356	: V=1.019694, theta=7.425328 -> V=1.0, theta=0.0
% INFO    : Bus 6357	: V=0.98572, theta=-24.821725 -> V=1.0, theta=0.0
% INFO    : Bus 6359	: V=1.029132, theta=-53.622036 -> V=1.0, theta=0.0
% INFO    : Bus 6368	: V=1.046268, theta=-8.318057 -> V=1.0, theta=0.0
% INFO    : Bus 6371	: V=1.047834, theta=-0.838701 -> V=1.0, theta=0.0
% INFO    : Bus 6376	: V=1.047648, theta=-0.304942 -> V=1.0, theta=0.0
% INFO    : Bus 6381	: V=0.987777, theta=-56.008855 -> V=1.0, theta=0.0
% INFO    : Bus 6382	: V=1.043547, theta=-9.673367 -> V=1.0, theta=0.0
% INFO    : Bus 6383	: V=1.019759, theta=23.115557 -> V=1.0, theta=0.0
% INFO    : Bus 6384	: V=1.044325, theta=-1.646281 -> V=1.0, theta=0.0
% INFO    : Bus 6390	: V=1.064469, theta=-47.252752 -> V=1.0, theta=0.0
% INFO    : Bus 6393	: V=1.013488, theta=7.50085 -> V=1.0, theta=0.0
% INFO    : Bus 6394	: V=1.021951, theta=-45.870021 -> V=1.0, theta=0.0
% INFO    : Bus 6395	: V=1.027632, theta=8.567013 -> V=1.0, theta=0.0
% INFO    : Bus 6397	: V=1.027573, theta=-41.568957 -> V=1.0, theta=0.0
% INFO    : Bus 6399	: V=1.00669, theta=-1.272997 -> V=1.0, theta=0.0
% INFO    : Bus 6405	: V=1.018638, theta=-16.011287 -> V=1.0, theta=0.0
% INFO    : Bus 6415	: V=0.987105, theta=-38.038845 -> V=1.0, theta=0.0
% INFO    : Bus 6416	: V=1.046481, theta=-9.558553 -> V=1.0, theta=0.0
% INFO    : Bus 6423	: V=0.997882, theta=-4.642958 -> V=1.0, theta=0.0
% INFO    : Bus 6424	: V=1.050218, theta=18.743357 -> V=1.0, theta=0.0
% INFO    : Bus 6426	: V=1.054575, theta=1.539515 -> V=1.0, theta=0.0
% INFO    : Bus 6427	: V=1.004268, theta=-13.142695 -> V=1.0, theta=0.0
% INFO    : Bus 6429	: V=1.03915, theta=-18.370028 -> V=1.0, theta=0.0
% INFO    : Bus 6430	: V=1.05085, theta=-28.971431 -> V=1.0, theta=0.0
% INFO    : Bus 6436	: V=1.01651, theta=-47.818377 -> V=1.0, theta=0.0
% INFO    : Bus 6439	: V=1.014417, theta=5.816488 -> V=1.0, theta=0.0
% INFO    : Bus 6442	: V=1.029153, theta=12.245807 -> V=1.0, theta=0.0
% INFO    : Bus 6443	: V=1.029433, theta=-49.112793 -> V=1.0, theta=0.0
% INFO    : Bus 6450	: V=1.01178, theta=-10.898649 -> V=1.0, theta=0.0
% INFO    : Bus 6454	: V=1.029382, theta=-53.582851 -> V=1.0, theta=0.0
% INFO    : Bus 6455	: V=1.038025, theta=-22.084544 -> V=1.0, theta=0.0
% INFO    : Bus 6456	: V=1.023228, theta=-46.686932 -> V=1.0, theta=0.0
% INFO    : Bus 6459	: V=1.006942, theta=-37.967795 -> V=1.0, theta=0.0
% INFO    : Bus 6472	: V=1.042588, theta=-24.033565 -> V=1.0, theta=0.0
% INFO    : Bus 6474	: V=1.062877, theta=-7.838842 -> V=1.0, theta=0.0
% INFO    : Bus 6475	: V=1.0259, theta=-8.704262 -> V=1.0, theta=0.0
% INFO    : Bus 6477	: V=1.03311, theta=21.518539 -> V=1.0, theta=0.0
% INFO    : Bus 6478	: V=1.010975, theta=-14.403642 -> V=1.0, theta=0.0
% INFO    : Bus 6480	: V=1.016764, theta=2.82735 -> V=1.0, theta=0.0
% INFO    : Bus 6484	: V=1.030805, theta=-45.317162 -> V=1.0, theta=0.0
% INFO    : Bus 6486	: V=1.043874, theta=-3.962885 -> V=1.0, theta=0.0
% INFO    : Bus 6489	: V=1.087601, theta=32.323601 -> V=1.0, theta=0.0
% INFO    : Bus 6490	: V=1.026525, theta=-52.273036 -> V=1.0, theta=0.0
% INFO    : Bus 6494	: V=1.058484, theta=-41.333189 -> V=1.0, theta=0.0
% INFO    : Bus 6495	: V=1.042112, theta=-21.799784 -> V=1.0, theta=0.0
% INFO    : Bus 6496	: V=1.061179, theta=-40.943297 -> V=1.0, theta=0.0
% INFO    : Bus 6499	: V=1.050329, theta=-44.72942 -> V=1.0, theta=0.0
% INFO    : Bus 6504	: V=1.005937, theta=-44.477592 -> V=1.0, theta=0.0
% INFO    : Bus 6510	: V=1.050373, theta=-26.443611 -> V=1.0, theta=0.0
% INFO    : Bus 6512	: V=0.994548, theta=-53.708793 -> V=1.0, theta=0.0
% INFO    : Bus 6514	: V=1.04065, theta=6.607097 -> V=1.0, theta=0.0
% INFO    : Bus 6516	: V=1.047972, theta=-3.562112 -> V=1.0, theta=0.0
% INFO    : Bus 6519	: V=1.024002, theta=11.729825 -> V=1.0, theta=0.0
% INFO    : Bus 6521	: V=1.041998, theta=-4.708978 -> V=1.0, theta=0.0
% INFO    : Bus 6526	: V=1.022102, theta=13.184764 -> V=1.0, theta=0.0
% INFO    : Bus 6532	: V=1.071832, theta=-31.431415 -> V=1.0, theta=0.0
% INFO    : Bus 6539	: V=1.011836, theta=1.010536 -> V=1.0, theta=0.0
% INFO    : Bus 6540	: V=0.994058, theta=-36.187051 -> V=1.0, theta=0.0
% INFO    : Bus 6542	: V=1.040374, theta=-2.397063 -> V=1.0, theta=0.0
% INFO    : Bus 6543	: V=1.024139, theta=-48.338822 -> V=1.0, theta=0.0
% INFO    : Bus 6544	: V=1.016797, theta=-42.419225 -> V=1.0, theta=0.0
% INFO    : Bus 6552	: V=1.048072, theta=-21.173134 -> V=1.0, theta=0.0
% INFO    : Bus 6555	: V=1.008204, theta=-43.770916 -> V=1.0, theta=0.0
% INFO    : Bus 6556	: V=1.047939, theta=-12.734202 -> V=1.0, theta=0.0
% INFO    : Bus 6559	: V=1.006915, theta=-1.481119 -> V=1.0, theta=0.0
% INFO    : Bus 6561	: V=1.006793, theta=-48.872369 -> V=1.0, theta=0.0
% INFO    : Bus 6563	: V=1.039818, theta=-24.693842 -> V=1.0, theta=0.0
% INFO    : Bus 6564	: V=1.049439, theta=-43.12438 -> V=1.0, theta=0.0
% INFO    : Bus 6565	: V=1.032962, theta=-7.256428 -> V=1.0, theta=0.0
% INFO    : Bus 6570	: V=1.044265, theta=-20.80039 -> V=1.0, theta=0.0
% INFO    : Bus 6581	: V=1.043213, theta=-2.471665 -> V=1.0, theta=0.0
% INFO    : Bus 6582	: V=1.030597, theta=12.371566 -> V=1.0, theta=0.0
% INFO    : Bus 6596	: V=1.004701, theta=-54.051001 -> V=1.0, theta=0.0
% INFO    : Bus 6597	: V=1.025543, theta=-48.149429 -> V=1.0, theta=0.0
% INFO    : Bus 6600	: V=1.05661, theta=12.502407 -> V=1.0, theta=0.0
% INFO    : Bus 6604	: V=1.017766, theta=-39.480036 -> V=1.0, theta=0.0
% INFO    : Bus 6607	: V=1.055138, theta=-41.609574 -> V=1.0, theta=0.0
% INFO    : Bus 6612	: V=1.042708, theta=-31.932488 -> V=1.0, theta=0.0
% INFO    : Bus 6616	: V=1.042889, theta=-15.932041 -> V=1.0, theta=0.0
% INFO    : Bus 6619	: V=1.045751, theta=-15.459446 -> V=1.0, theta=0.0
% INFO    : Bus 6624	: V=1.058817, theta=4.267441 -> V=1.0, theta=0.0
% INFO    : Bus 6625	: V=1.025446, theta=-56.568733 -> V=1.0, theta=0.0
% INFO    : Bus 6629	: V=1.056213, theta=-11.409726 -> V=1.0, theta=0.0
% INFO    : Bus 6630	: V=1.038952, theta=-24.182883 -> V=1.0, theta=0.0
% INFO    : Bus 6632	: V=1.062949, theta=-40.452596 -> V=1.0, theta=0.0
% INFO    : Bus 6636	: V=1.039939, theta=0.565316 -> V=1.0, theta=0.0
% INFO    : Bus 6638	: V=1.022691, theta=-14.912865 -> V=1.0, theta=0.0
% INFO    : Bus 6639	: V=1.04321, theta=-2.440722 -> V=1.0, theta=0.0
% INFO    : Bus 6648	: V=1.063897, theta=-11.502112 -> V=1.0, theta=0.0
% INFO    : Bus 6654	: V=1.02462, theta=-46.240582 -> V=1.0, theta=0.0
% INFO    : Bus 6656	: V=1.022999, theta=-36.884898 -> V=1.0, theta=0.0
% INFO    : Bus 6659	: V=1.030902, theta=-44.811571 -> V=1.0, theta=0.0
% INFO    : Bus 6660	: V=1.012984, theta=-48.913886 -> V=1.0, theta=0.0
% INFO    : Bus 6662	: V=1.031936, theta=4.19826 -> V=1.0, theta=0.0
% INFO    : Bus 6663	: V=1.015493, theta=-48.055478 -> V=1.0, theta=0.0
% INFO    : Bus 6664	: V=1.068966, theta=-46.374278 -> V=1.0, theta=0.0
% INFO    : Bus 6669	: V=1.014034, theta=-52.545603 -> V=1.0, theta=0.0
% INFO    : Bus 6675	: V=1.035153, theta=-23.318949 -> V=1.0, theta=0.0
% INFO    : Bus 6679	: V=1.033934, theta=-53.241623 -> V=1.0, theta=0.0
% INFO    : Bus 6681	: V=1.07064, theta=-40.401559 -> V=1.0, theta=0.0
% INFO    : Bus 6684	: V=1.043124, theta=-25.590229 -> V=1.0, theta=0.0
% INFO    : Bus 6687	: V=1.050008, theta=18.737299 -> V=1.0, theta=0.0
% INFO    : Bus 6691	: V=1.083964, theta=-34.13205 -> V=1.0, theta=0.0
% INFO    : Bus 6692	: V=1.022548, theta=-15.5869 -> V=1.0, theta=0.0
% INFO    : Bus 6697	: V=1.045362, theta=-37.168777 -> V=1.0, theta=0.0
% INFO    : Bus 6704	: V=0.995487, theta=-3.368831 -> V=1.0, theta=0.0
% INFO    : Bus 6707	: V=1.02112, theta=11.417687 -> V=1.0, theta=0.0
% INFO    : Bus 6714	: V=1.047832, theta=-0.838669 -> V=1.0, theta=0.0
% INFO    : Bus 6717	: V=1.022189, theta=-45.90348 -> V=1.0, theta=0.0
% INFO    : Bus 6723	: V=1.035057, theta=-9.440724 -> V=1.0, theta=0.0
% INFO    : Bus 6730	: V=1.037253, theta=-21.115037 -> V=1.0, theta=0.0
% INFO    : Bus 6734	: V=1.05765, theta=-3.4334 -> V=1.0, theta=0.0
% INFO    : Bus 6735	: V=1.037632, theta=-1.22486 -> V=1.0, theta=0.0
% INFO    : Bus 6737	: V=1.022754, theta=-10.499118 -> V=1.0, theta=0.0
% INFO    : Bus 6738	: V=1.028082, theta=-24.822962 -> V=1.0, theta=0.0
% INFO    : Bus 6742	: V=1.037351, theta=-21.529801 -> V=1.0, theta=0.0
% INFO    : Bus 6744	: V=1.035884, theta=-10.189404 -> V=1.0, theta=0.0
% INFO    : Bus 6745	: V=1.016392, theta=-39.412948 -> V=1.0, theta=0.0
% INFO    : Bus 6747	: V=1.024439, theta=2.725414 -> V=1.0, theta=0.0
% INFO    : Bus 6749	: V=1.029371, theta=-48.409878 -> V=1.0, theta=0.0
% INFO    : Bus 6757	: V=1.038766, theta=-1.17374 -> V=1.0, theta=0.0
% INFO    : Bus 6760	: V=1.051203, theta=-42.103673 -> V=1.0, theta=0.0
% INFO    : Bus 6763	: V=1.043541, theta=-24.265972 -> V=1.0, theta=0.0
% INFO    : Bus 6766	: V=1.024741, theta=11.926408 -> V=1.0, theta=0.0
% INFO    : Bus 6768	: V=1.031252, theta=-45.003965 -> V=1.0, theta=0.0
% INFO    : Bus 6769	: V=1.045659, theta=-44.124314 -> V=1.0, theta=0.0
% INFO    : Bus 6771	: V=1.051704, theta=-43.319399 -> V=1.0, theta=0.0
% INFO    : Bus 6772	: V=1.045221, theta=-24.126683 -> V=1.0, theta=0.0
% INFO    : Bus 6773	: V=1.041185, theta=-24.317372 -> V=1.0, theta=0.0
% INFO    : Bus 6783	: V=1.029053, theta=-53.638737 -> V=1.0, theta=0.0
% INFO    : Bus 6785	: V=1.045887, theta=-0.709285 -> V=1.0, theta=0.0
% INFO    : Bus 6791	: V=1.045382, theta=-25.270988 -> V=1.0, theta=0.0
% INFO    : Bus 6795	: V=0.999791, theta=-48.960893 -> V=1.0, theta=0.0
% INFO    : Bus 6797	: V=1.027612, theta=-50.167833 -> V=1.0, theta=0.0
% INFO    : Bus 6798	: V=1.019012, theta=6.75387 -> V=1.0, theta=0.0
% INFO    : Bus 6802	: V=1.038702, theta=-6.086871 -> V=1.0, theta=0.0
% INFO    : Bus 6806	: V=1.045649, theta=-21.295765 -> V=1.0, theta=0.0
% INFO    : Bus 6807	: V=1.012126, theta=-16.436745 -> V=1.0, theta=0.0
% INFO    : Bus 6816	: V=1.055666, theta=-24.275709 -> V=1.0, theta=0.0
% INFO    : Bus 6820	: V=1.051187, theta=-6.633991 -> V=1.0, theta=0.0
% INFO    : Bus 6823	: V=1.034323, theta=3.948895 -> V=1.0, theta=0.0
% INFO    : Bus 6824	: V=0.994435, theta=-4.797866 -> V=1.0, theta=0.0
% INFO    : Bus 6826	: V=1.067413, theta=-7.63246 -> V=1.0, theta=0.0
% INFO    : Bus 6828	: V=1.040297, theta=-13.431461 -> V=1.0, theta=0.0
% INFO    : Bus 6831	: V=1.034052, theta=-9.760419 -> V=1.0, theta=0.0
% INFO    : Bus 6832	: V=1.08761, theta=32.323642 -> V=1.0, theta=0.0
% INFO    : Bus 6833	: V=0.979265, theta=-6.81498 -> V=1.0, theta=0.0
% INFO    : Bus 6835	: V=1.028044, theta=18.540709 -> V=1.0, theta=0.0
% INFO    : Bus 6836	: V=1.024919, theta=-48.168635 -> V=1.0, theta=0.0
% INFO    : Bus 6837	: V=1.052628, theta=-7.891626 -> V=1.0, theta=0.0
% INFO    : Bus 6838	: V=1.043313, theta=5.369918 -> V=1.0, theta=0.0
% INFO    : Bus 6841	: V=1.030565, theta=-53.139202 -> V=1.0, theta=0.0
% INFO    : Bus 6842	: V=1.040109, theta=-8.421644 -> V=1.0, theta=0.0
% INFO    : Bus 6844	: V=1.015901, theta=-29.315974 -> V=1.0, theta=0.0
% INFO    : Bus 6845	: V=1.051715, theta=-11.1809 -> V=1.0, theta=0.0
% INFO    : Bus 6846	: V=1.049248, theta=-4.58634 -> V=1.0, theta=0.0
% INFO    : Bus 6852	: V=1.032911, theta=-19.833765 -> V=1.0, theta=0.0
% INFO    : Bus 6854	: V=1.056677, theta=-11.352791 -> V=1.0, theta=0.0
% INFO    : Bus 6857	: V=1.014858, theta=-8.546516 -> V=1.0, theta=0.0
% INFO    : Bus 6869	: V=1.027632, theta=-52.767366 -> V=1.0, theta=0.0
% INFO    : Bus 6877	: V=1.066537, theta=-41.619855 -> V=1.0, theta=0.0
% INFO    : Bus 6879	: V=1.043211, theta=-45.146735 -> V=1.0, theta=0.0
% INFO    : Bus 6880	: V=1.040453, theta=-4.439381 -> V=1.0, theta=0.0
% INFO    : Bus 6882	: V=1.016215, theta=-53.732109 -> V=1.0, theta=0.0
% INFO    : Bus 6883	: V=1.059988, theta=-39.977279 -> V=1.0, theta=0.0
% INFO    : Bus 6884	: V=1.087731, theta=32.319037 -> V=1.0, theta=0.0
% INFO    : Bus 6887	: V=1.04725, theta=-3.093328 -> V=1.0, theta=0.0
% INFO    : Bus 6888	: V=1.042814, theta=-13.607804 -> V=1.0, theta=0.0
% INFO    : Bus 6889	: V=1.032371, theta=2.535951 -> V=1.0, theta=0.0
% INFO    : Bus 6891	: V=1.043146, theta=-14.346931 -> V=1.0, theta=0.0
% INFO    : Bus 6897	: V=1.052772, theta=-16.564834 -> V=1.0, theta=0.0
% INFO    : Bus 6901	: V=1.010023, theta=-32.207211 -> V=1.0, theta=0.0
% INFO    : Bus 6904	: V=1.030983, theta=-55.55932 -> V=1.0, theta=0.0
% INFO    : Bus 6908	: V=1.03639, theta=-40.192059 -> V=1.0, theta=0.0
% INFO    : Bus 6909	: V=1.035956, theta=-23.157555 -> V=1.0, theta=0.0
% INFO    : Bus 6915	: V=1.02472, theta=14.046055 -> V=1.0, theta=0.0
% INFO    : Bus 6917	: V=1.06608, theta=-42.268714 -> V=1.0, theta=0.0
% INFO    : Bus 6921	: V=1.033994, theta=-1.605149 -> V=1.0, theta=0.0
% INFO    : Bus 6922	: V=1.038591, theta=-8.601875 -> V=1.0, theta=0.0
% INFO    : Bus 6923	: V=1.037346, theta=15.355591 -> V=1.0, theta=0.0
% INFO    : Bus 6926	: V=1.029554, theta=-12.429854 -> V=1.0, theta=0.0
% INFO    : Bus 6932	: V=1.033352, theta=-53.101088 -> V=1.0, theta=0.0
% INFO    : Bus 6936	: V=1.030076, theta=-38.53627 -> V=1.0, theta=0.0
% INFO    : Bus 6940	: V=1.054737, theta=-27.625806 -> V=1.0, theta=0.0
% INFO    : Bus 6947	: V=1.046726, theta=-3.720941 -> V=1.0, theta=0.0
% INFO    : Bus 6949	: V=1.029331, theta=-53.544619 -> V=1.0, theta=0.0
% INFO    : Bus 6952	: V=1.073657, theta=-25.19061 -> V=1.0, theta=0.0
% INFO    : Bus 6953	: V=1.021083, theta=-49.70633 -> V=1.0, theta=0.0
% INFO    : Bus 6954	: V=1.033292, theta=-20.085167 -> V=1.0, theta=0.0
% INFO    : Bus 6960	: V=0.991637, theta=-55.881273 -> V=1.0, theta=0.0
% INFO    : Bus 6961	: V=1.047236, theta=-0.037249 -> V=1.0, theta=0.0
% INFO    : Bus 6964	: V=1.040388, theta=-44.750394 -> V=1.0, theta=0.0
% INFO    : Bus 6969	: V=1.061428, theta=-23.28797 -> V=1.0, theta=0.0
% INFO    : Bus 6970	: V=1.028216, theta=-46.031374 -> V=1.0, theta=0.0
% INFO    : Bus 6982	: V=1.038963, theta=-20.935757 -> V=1.0, theta=0.0
% INFO    : Bus 6985	: V=1.029081, theta=-53.680846 -> V=1.0, theta=0.0
% INFO    : Bus 6987	: V=1.028017, theta=3.250246 -> V=1.0, theta=0.0
% INFO    : Bus 6989	: V=1.046097, theta=-24.035778 -> V=1.0, theta=0.0
% INFO    : Bus 6990	: V=1.047903, theta=-24.132172 -> V=1.0, theta=0.0
% INFO    : Bus 6994	: V=1.020708, theta=-40.858026 -> V=1.0, theta=0.0
% INFO    : Bus 6998	: V=1.023626, theta=8.631158 -> V=1.0, theta=0.0
% INFO    : Bus 7002	: V=1.033942, theta=-41.747854 -> V=1.0, theta=0.0
% INFO    : Bus 7004	: V=1.049776, theta=18.741809 -> V=1.0, theta=0.0
% INFO    : Bus 7011	: V=1.023859, theta=8.520642 -> V=1.0, theta=0.0
% INFO    : Bus 7014	: V=1.034719, theta=-2.558654 -> V=1.0, theta=0.0
% INFO    : Bus 7018	: V=1.023469, theta=11.73541 -> V=1.0, theta=0.0
% INFO    : Bus 7019	: V=1.041053, theta=-25.864067 -> V=1.0, theta=0.0
% INFO    : Bus 7021	: V=1.008138, theta=-17.163471 -> V=1.0, theta=0.0
% INFO    : Bus 7029	: V=1.063951, theta=-36.875689 -> V=1.0, theta=0.0
% INFO    : Bus 7030	: V=1.062881, theta=-7.838873 -> V=1.0, theta=0.0
% INFO    : Bus 7036	: V=1.042173, theta=-12.578177 -> V=1.0, theta=0.0
% INFO    : Bus 7037	: V=0.99153, theta=-55.40565 -> V=1.0, theta=0.0
% INFO    : Bus 7041	: V=1.014317, theta=-41.763015 -> V=1.0, theta=0.0
% INFO    : Bus 7042	: V=1.052154, theta=-30.14741 -> V=1.0, theta=0.0
% INFO    : Bus 7047	: V=1.035936, theta=-21.928794 -> V=1.0, theta=0.0
% INFO    : Bus 7049	: V=1.04735, theta=-14.367804 -> V=1.0, theta=0.0
% INFO    : Bus 7050	: V=1.036775, theta=-21.275559 -> V=1.0, theta=0.0
% INFO    : Bus 7051	: V=0.995283, theta=-0.23205 -> V=1.0, theta=0.0
% INFO    : Bus 7052	: V=1.044853, theta=-12.404558 -> V=1.0, theta=0.0
% INFO    : Bus 7053	: V=1.067028, theta=-40.860634 -> V=1.0, theta=0.0
% INFO    : Bus 7056	: V=1.005566, theta=-4.277241 -> V=1.0, theta=0.0
% INFO    : Bus 7058	: V=1.043279, theta=-36.396436 -> V=1.0, theta=0.0
% INFO    : Bus 7059	: V=1.024187, theta=9.419858 -> V=1.0, theta=0.0
% INFO    : Bus 7064	: V=1.014688, theta=-46.559002 -> V=1.0, theta=0.0
% INFO    : Bus 7069	: V=1.041839, theta=-7.978812 -> V=1.0, theta=0.0
% INFO    : Bus 7070	: V=1.047318, theta=-13.451419 -> V=1.0, theta=0.0
% INFO    : Bus 7073	: V=1.047344, theta=9.041554 -> V=1.0, theta=0.0
% INFO    : Bus 7075	: V=1.026663, theta=-42.497913 -> V=1.0, theta=0.0
% INFO    : Bus 7076	: V=1.033945, theta=-12.41346 -> V=1.0, theta=0.0
% INFO    : Bus 7079	: V=1.041573, theta=-51.256311 -> V=1.0, theta=0.0
% INFO    : Bus 7090	: V=1.031888, theta=10.922009 -> V=1.0, theta=0.0
% INFO    : Bus 7092	: V=1.046583, theta=-25.141996 -> V=1.0, theta=0.0
% INFO    : Bus 7096	: V=1.070091, theta=-40.307397 -> V=1.0, theta=0.0
% INFO    : Bus 7098	: V=1.044076, theta=-2.313897 -> V=1.0, theta=0.0
% INFO    : Bus 7104	: V=1.004388, theta=-28.478299 -> V=1.0, theta=0.0
% INFO    : Bus 7110	: V=1.024139, theta=-41.630598 -> V=1.0, theta=0.0
% INFO    : Bus 7115	: V=1.014496, theta=-16.107551 -> V=1.0, theta=0.0
% INFO    : Bus 7117	: V=1.041082, theta=27.11571 -> V=1.0, theta=0.0
% INFO    : Bus 7119	: V=1.013198, theta=-16.311742 -> V=1.0, theta=0.0
% INFO    : Bus 7124	: V=1.07108, theta=-27.224252 -> V=1.0, theta=0.0
% INFO    : Bus 7129	: V=1.041363, theta=-2.891577 -> V=1.0, theta=0.0
% INFO    : Bus 7132	: V=1.020788, theta=-15.829017 -> V=1.0, theta=0.0
% INFO    : Bus 7133	: V=1.038192, theta=-14.196483 -> V=1.0, theta=0.0
% INFO    : Bus 7136	: V=1.01997, theta=7.817073 -> V=1.0, theta=0.0
% INFO    : Bus 7137	: V=1.031779, theta=-44.572118 -> V=1.0, theta=0.0
% INFO    : Bus 7138	: V=0.998265, theta=-4.445181 -> V=1.0, theta=0.0
% INFO    : Bus 7139	: V=1.032109, theta=-53.496089 -> V=1.0, theta=0.0
% INFO    : Bus 7144	: V=1.031135, theta=-13.014295 -> V=1.0, theta=0.0
% INFO    : Bus 7145	: V=1.017901, theta=-57.933705 -> V=1.0, theta=0.0
% INFO    : Bus 7146	: V=1.087153, theta=32.322685 -> V=1.0, theta=0.0
% INFO    : Bus 7148	: V=1.05068, theta=-23.342154 -> V=1.0, theta=0.0
% INFO    : Bus 7156	: V=1.047935, theta=8.994444 -> V=1.0, theta=0.0
% INFO    : Bus 7159	: V=1.059739, theta=4.507306 -> V=1.0, theta=0.0
% INFO    : Bus 7162	: V=1.047481, theta=-13.453924 -> V=1.0, theta=0.0
% INFO    : Bus 7163	: V=1.048464, theta=-24.909243 -> V=1.0, theta=0.0
% INFO    : Bus 7164	: V=1.025988, theta=-22.171787 -> V=1.0, theta=0.0
% INFO    : Bus 7165	: V=1.070226, theta=-34.26549 -> V=1.0, theta=0.0
% INFO    : Bus 7178	: V=1.012186, theta=-14.284091 -> V=1.0, theta=0.0
% INFO    : Bus 7180	: V=0.981876, theta=-6.902546 -> V=1.0, theta=0.0
% INFO    : Bus 7183	: V=1.105479, theta=-6.84714 -> V=1.0, theta=0.0
% INFO    : Bus 7191	: V=1.02383, theta=-48.137341 -> V=1.0, theta=0.0
% INFO    : Bus 7193	: V=1.019967, theta=-46.478159 -> V=1.0, theta=0.0
% INFO    : Bus 7195	: V=1.012466, theta=1.222377 -> V=1.0, theta=0.0
% INFO    : Bus 7196	: V=1.027609, theta=-54.367035 -> V=1.0, theta=0.0
% INFO    : Bus 7202	: V=1.046075, theta=-3.910533 -> V=1.0, theta=0.0
% INFO    : Bus 7209	: V=1.052921, theta=-6.520132 -> V=1.0, theta=0.0
% INFO    : Bus 7222	: V=1.064563, theta=-23.838621 -> V=1.0, theta=0.0
% INFO    : Bus 7226	: V=1.022853, theta=-15.545301 -> V=1.0, theta=0.0
% INFO    : Bus 7230	: V=1.02127, theta=11.418714 -> V=1.0, theta=0.0
% INFO    : Bus 7231	: V=1.041678, theta=-11.508705 -> V=1.0, theta=0.0
% INFO    : Bus 7235	: V=1.039631, theta=39.664851 -> V=1.0, theta=0.0
% INFO    : Bus 7236	: V=0.966439, theta=-43.680938 -> V=1.0, theta=0.0
% INFO    : Bus 7249	: V=1.029557, theta=-41.944299 -> V=1.0, theta=0.0
% INFO    : Bus 7252	: V=0.965436, theta=-44.082482 -> V=1.0, theta=0.0
% INFO    : Bus 7253	: V=1.040821, theta=-2.447252 -> V=1.0, theta=0.0
% INFO    : Bus 7256	: V=1.020196, theta=-35.458798 -> V=1.0, theta=0.0
% INFO    : Bus 7257	: V=1.030375, theta=-46.213157 -> V=1.0, theta=0.0
% INFO    : Bus 7259	: V=1.062678, theta=-7.907408 -> V=1.0, theta=0.0
% INFO    : Bus 7260	: V=1.016183, theta=19.062716 -> V=1.0, theta=0.0
% INFO    : Bus 7264	: V=1.043585, theta=-10.98095 -> V=1.0, theta=0.0
% INFO    : Bus 7266	: V=1.0272, theta=-5.480785 -> V=1.0, theta=0.0
% INFO    : Bus 7267	: V=1.012113, theta=-7.716675 -> V=1.0, theta=0.0
% INFO    : Bus 7270	: V=1.06851, theta=26.565652 -> V=1.0, theta=0.0
% INFO    : Bus 7273	: V=1.042242, theta=-24.355287 -> V=1.0, theta=0.0
% INFO    : Bus 7274	: V=1.033096, theta=-3.876706 -> V=1.0, theta=0.0
% INFO    : Bus 7275	: V=1.036244, theta=4.519004 -> V=1.0, theta=0.0
% INFO    : Bus 7279	: V=1.030612, theta=-13.14884 -> V=1.0, theta=0.0
% INFO    : Bus 7282	: V=1.029503, theta=-4.625888 -> V=1.0, theta=0.0
% INFO    : Bus 7283	: V=1.040242, theta=-45.426953 -> V=1.0, theta=0.0
% INFO    : Bus 7284	: V=1.089967, theta=-0.81866 -> V=1.0, theta=0.0
% INFO    : Bus 7287	: V=1.064698, theta=-40.954869 -> V=1.0, theta=0.0
% INFO    : Bus 7289	: V=1.055132, theta=-6.159267 -> V=1.0, theta=0.0
% INFO    : Bus 7295	: V=1.033606, theta=3.161377 -> V=1.0, theta=0.0
% INFO    : Bus 7297	: V=1.033594, theta=3.16114 -> V=1.0, theta=0.0
% INFO    : Bus 7303	: V=1.033047, theta=-42.739399 -> V=1.0, theta=0.0
% INFO    : Bus 7305	: V=1.036138, theta=4.015909 -> V=1.0, theta=0.0
% INFO    : Bus 7309	: V=1.056677, theta=-11.352791 -> V=1.0, theta=0.0
% INFO    : Bus 7310	: V=1.029455, theta=-45.744562 -> V=1.0, theta=0.0
% INFO    : Bus 7312	: V=1.00645, theta=-47.823793 -> V=1.0, theta=0.0
% INFO    : Bus 7316	: V=1.046311, theta=-7.264606 -> V=1.0, theta=0.0
% INFO    : Bus 7325	: V=1.047946, theta=-12.734265 -> V=1.0, theta=0.0
% INFO    : Bus 7327	: V=1.042085, theta=-18.10373 -> V=1.0, theta=0.0
% INFO    : Bus 7328	: V=0.994679, theta=-14.546471 -> V=1.0, theta=0.0
% INFO    : Bus 7329	: V=1.039675, theta=-33.666038 -> V=1.0, theta=0.0
% INFO    : Bus 7338	: V=1.045961, theta=-14.736111 -> V=1.0, theta=0.0
% INFO    : Bus 7341	: V=1.04381, theta=-2.454778 -> V=1.0, theta=0.0
% INFO    : Bus 7342	: V=1.019689, theta=-16.094292 -> V=1.0, theta=0.0
% INFO    : Bus 7343	: V=1.03114, theta=-42.813676 -> V=1.0, theta=0.0
% INFO    : Bus 7347	: V=1.014859, theta=-48.229058 -> V=1.0, theta=0.0
% INFO    : Bus 7349	: V=1.021855, theta=-50.750103 -> V=1.0, theta=0.0
% INFO    : Bus 7351	: V=1.041265, theta=-2.894937 -> V=1.0, theta=0.0
% INFO    : Bus 7353	: V=0.983185, theta=-22.469243 -> V=1.0, theta=0.0
% INFO    : Bus 7358	: V=1.001857, theta=-48.125059 -> V=1.0, theta=0.0
% INFO    : Bus 7361	: V=1.053884, theta=-15.280698 -> V=1.0, theta=0.0
% INFO    : Bus 7366	: V=1.015027, theta=-40.142163 -> V=1.0, theta=0.0
% INFO    : Bus 7367	: V=1.028096, theta=-18.923022 -> V=1.0, theta=0.0
% INFO    : Bus 7373	: V=1.071572, theta=-23.62773 -> V=1.0, theta=0.0
% INFO    : Bus 7374	: V=1.015892, theta=-0.687464 -> V=1.0, theta=0.0
% INFO    : Bus 7377	: V=1.016564, theta=-16.113305 -> V=1.0, theta=0.0
% INFO    : Bus 7380	: V=0.990366, theta=-14.587362 -> V=1.0, theta=0.0
% INFO    : Bus 7388	: V=1.087153, theta=32.322685 -> V=1.0, theta=0.0
% INFO    : Bus 7392	: V=1.015493, theta=-54.520223 -> V=1.0, theta=0.0
% INFO    : Bus 7394	: V=1.0354, theta=9.686825 -> V=1.0, theta=0.0
% INFO    : Bus 7395	: V=1.025209, theta=-43.665105 -> V=1.0, theta=0.0
% INFO    : Bus 7396	: V=1.02001, theta=-19.556579 -> V=1.0, theta=0.0
% INFO    : Bus 7398	: V=1.020787, theta=-50.110773 -> V=1.0, theta=0.0
% INFO    : Bus 7404	: V=1.048858, theta=11.613006 -> V=1.0, theta=0.0
% INFO    : Bus 7406	: V=1.027008, theta=-47.350098 -> V=1.0, theta=0.0
% INFO    : Bus 7407	: V=1.003253, theta=-3.940799 -> V=1.0, theta=0.0
% INFO    : Bus 7411	: V=1.001284, theta=-38.553912 -> V=1.0, theta=0.0
% INFO    : Bus 7413	: V=1.032769, theta=-53.379462 -> V=1.0, theta=0.0
% INFO    : Bus 7417	: V=1.041351, theta=-45.36001 -> V=1.0, theta=0.0
% INFO    : Bus 7422	: V=1.036095, theta=-10.773128 -> V=1.0, theta=0.0
% INFO    : Bus 7423	: V=1.020318, theta=-40.092191 -> V=1.0, theta=0.0
% INFO    : Bus 7425	: V=1.022104, theta=-0.334418 -> V=1.0, theta=0.0
% INFO    : Bus 7428	: V=1.048433, theta=-49.801196 -> V=1.0, theta=0.0
% INFO    : Bus 7431	: V=1.01868, theta=-33.26536 -> V=1.0, theta=0.0
% INFO    : Bus 7436	: V=1.025488, theta=-49.807558 -> V=1.0, theta=0.0
% INFO    : Bus 7437	: V=1.042931, theta=-25.681594 -> V=1.0, theta=0.0
% INFO    : Bus 7438	: V=1.036829, theta=-12.73494 -> V=1.0, theta=0.0
% INFO    : Bus 7442	: V=1.013545, theta=16.971644 -> V=1.0, theta=0.0
% INFO    : Bus 7446	: V=1.012514, theta=-45.574723 -> V=1.0, theta=0.0
% INFO    : Bus 7450	: V=1.021372, theta=11.400623 -> V=1.0, theta=0.0
% INFO    : Bus 7460	: V=1.044406, theta=-46.009583 -> V=1.0, theta=0.0
% INFO    : Bus 7463	: V=1.030888, theta=-53.281727 -> V=1.0, theta=0.0
% INFO    : Bus 7464	: V=1.041982, theta=-12.603915 -> V=1.0, theta=0.0
% INFO    : Bus 7466	: V=1.057274, theta=-34.947755 -> V=1.0, theta=0.0
% INFO    : Bus 7471	: V=1.017806, theta=-6.291292 -> V=1.0, theta=0.0
% INFO    : Bus 7473	: V=1.03919, theta=-15.952793 -> V=1.0, theta=0.0
% INFO    : Bus 7474	: V=1.028765, theta=-14.261886 -> V=1.0, theta=0.0
% INFO    : Bus 7475	: V=1.028694, theta=-53.88004 -> V=1.0, theta=0.0
% INFO    : Bus 7476	: V=1.037734, theta=6.54651 -> V=1.0, theta=0.0
% INFO    : Bus 7480	: V=1.017111, theta=17.755005 -> V=1.0, theta=0.0
% INFO    : Bus 7485	: V=1.041059, theta=-25.872286 -> V=1.0, theta=0.0
% INFO    : Bus 7491	: V=1.012011, theta=-21.498322 -> V=1.0, theta=0.0
% INFO    : Bus 7495	: V=1.036344, theta=-15.186951 -> V=1.0, theta=0.0
% INFO    : Bus 7503	: V=1.000871, theta=-42.759103 -> V=1.0, theta=0.0
% INFO    : Bus 7504	: V=1.017989, theta=-42.565789 -> V=1.0, theta=0.0
% INFO    : Bus 7507	: V=1.04762, theta=-24.128215 -> V=1.0, theta=0.0
% INFO    : Bus 7508	: V=1.062735, theta=-39.605713 -> V=1.0, theta=0.0
% INFO    : Bus 7509	: V=1.058758, theta=-47.305611 -> V=1.0, theta=0.0
% INFO    : Bus 7510	: V=1.025667, theta=-46.498034 -> V=1.0, theta=0.0
% INFO    : Bus 7513	: V=0.99089, theta=-15.045436 -> V=1.0, theta=0.0
% INFO    : Bus 7519	: V=1.039225, theta=-10.766503 -> V=1.0, theta=0.0
% INFO    : Bus 7520	: V=1.033404, theta=-9.153694 -> V=1.0, theta=0.0
% INFO    : Bus 7522	: V=1.000638, theta=-10.975301 -> V=1.0, theta=0.0
% INFO    : Bus 7523	: V=1.053262, theta=-0.714256 -> V=1.0, theta=0.0
% INFO    : Bus 7525	: V=1.020325, theta=17.578915 -> V=1.0, theta=0.0
% INFO    : Bus 7526	: V=1.007963, theta=6.743891 -> V=1.0, theta=0.0
% INFO    : Bus 7530	: V=1.045347, theta=-19.834673 -> V=1.0, theta=0.0
% INFO    : Bus 7537	: V=0.989467, theta=-15.645872 -> V=1.0, theta=0.0
% INFO    : Bus 7539	: V=1.04992, theta=-12.426239 -> V=1.0, theta=0.0
% INFO    : Bus 7541	: V=1.053626, theta=-16.488105 -> V=1.0, theta=0.0
% INFO    : Bus 7556	: V=1.046355, theta=-32.996066 -> V=1.0, theta=0.0
% INFO    : Bus 7561	: V=0.998171, theta=-4.519251 -> V=1.0, theta=0.0
% INFO    : Bus 7563	: V=1.039801, theta=-13.004235 -> V=1.0, theta=0.0
% INFO    : Bus 7565	: V=1.056993, theta=12.540707 -> V=1.0, theta=0.0
% INFO    : Bus 7569	: V=0.96962, theta=-55.542078 -> V=1.0, theta=0.0
% INFO    : Bus 7571	: V=1.045785, theta=-14.005381 -> V=1.0, theta=0.0
% INFO    : Bus 7573	: V=1.032069, theta=-53.465727 -> V=1.0, theta=0.0
% INFO    : Bus 7575	: V=1.042025, theta=10.4044 -> V=1.0, theta=0.0
% INFO    : Bus 7576	: V=1.04098, theta=-12.033553 -> V=1.0, theta=0.0
% INFO    : Bus 7577	: V=1.048853, theta=-10.476048 -> V=1.0, theta=0.0
% INFO    : Bus 7579	: V=1.041199, theta=-26.697479 -> V=1.0, theta=0.0
% INFO    : Bus 7580	: V=1.053388, theta=-12.006654 -> V=1.0, theta=0.0
% INFO    : Bus 7582	: V=1.035193, theta=-24.481285 -> V=1.0, theta=0.0
% INFO    : Bus 7583	: V=1.048949, theta=-0.937766 -> V=1.0, theta=0.0
% INFO    : Bus 7584	: V=1.025154, theta=-0.871196 -> V=1.0, theta=0.0
% INFO    : Bus 7586	: V=1.000547, theta=-4.320401 -> V=1.0, theta=0.0
% INFO    : Bus 7596	: V=1.016631, theta=-0.587949 -> V=1.0, theta=0.0
% INFO    : Bus 7599	: V=1.038714, theta=-6.087138 -> V=1.0, theta=0.0
% INFO    : Bus 7600	: V=1.039856, theta=-45.491051 -> V=1.0, theta=0.0
% INFO    : Bus 7611	: V=1.024474, theta=-46.568986 -> V=1.0, theta=0.0
% INFO    : Bus 7615	: V=0.985979, theta=-53.121078 -> V=1.0, theta=0.0
% INFO    : Bus 7624	: V=1.01569, theta=-20.927054 -> V=1.0, theta=0.0
% INFO    : Bus 7626	: V=1.033715, theta=-12.429714 -> V=1.0, theta=0.0
% INFO    : Bus 7628	: V=1.057002, theta=4.195982 -> V=1.0, theta=0.0
% INFO    : Bus 7629	: V=1.022311, theta=-55.19756 -> V=1.0, theta=0.0
% INFO    : Bus 7630	: V=1.019127, theta=-44.28077 -> V=1.0, theta=0.0
% INFO    : Bus 7632	: V=1.028912, theta=-56.022654 -> V=1.0, theta=0.0
% INFO    : Bus 7635	: V=1.052335, theta=-7.868924 -> V=1.0, theta=0.0
% INFO    : Bus 7637	: V=0.998893, theta=18.51968 -> V=1.0, theta=0.0
% INFO    : Bus 7640	: V=1.033497, theta=-5.993491 -> V=1.0, theta=0.0
% INFO    : Bus 7641	: V=1.053056, theta=-6.264318 -> V=1.0, theta=0.0
% INFO    : Bus 7644	: V=1.041528, theta=-45.624972 -> V=1.0, theta=0.0
% INFO    : Bus 7647	: V=1.062641, theta=-20.201545 -> V=1.0, theta=0.0
% INFO    : Bus 7653	: V=1.036646, theta=-22.796085 -> V=1.0, theta=0.0
% INFO    : Bus 7659	: V=1.035071, theta=-40.258623 -> V=1.0, theta=0.0
% INFO    : Bus 7661	: V=1.039659, theta=-33.672696 -> V=1.0, theta=0.0
% INFO    : Bus 7662	: V=1.024437, theta=9.444892 -> V=1.0, theta=0.0
% INFO    : Bus 7663	: V=1.04595, theta=-11.99307 -> V=1.0, theta=0.0
% INFO    : Bus 7666	: V=1.020727, theta=11.122959 -> V=1.0, theta=0.0
% INFO    : Bus 7669	: V=1.023999, theta=-48.354165 -> V=1.0, theta=0.0
% INFO    : Bus 7673	: V=1.047863, theta=-42.64115 -> V=1.0, theta=0.0
% INFO    : Bus 7675	: V=1.005518, theta=0.486497 -> V=1.0, theta=0.0
% INFO    : Bus 7685	: V=1.021717, theta=-43.96567 -> V=1.0, theta=0.0
% INFO    : Bus 7688	: V=1.046502, theta=-49.522132 -> V=1.0, theta=0.0
% INFO    : Bus 7691	: V=1.027974, theta=-3.930565 -> V=1.0, theta=0.0
% INFO    : Bus 7694	: V=1.028968, theta=-14.823846 -> V=1.0, theta=0.0
% INFO    : Bus 7697	: V=1.047945, theta=-3.543018 -> V=1.0, theta=0.0
% INFO    : Bus 7699	: V=1.041938, theta=11.338235 -> V=1.0, theta=0.0
% INFO    : Bus 7700	: V=1.01995, theta=-10.494298 -> V=1.0, theta=0.0
% INFO    : Bus 7701	: V=1.016719, theta=6.309825 -> V=1.0, theta=0.0
% INFO    : Bus 7702	: V=1.023659, theta=-16.319508 -> V=1.0, theta=0.0
% INFO    : Bus 7709	: V=1.015574, theta=-41.198324 -> V=1.0, theta=0.0
% INFO    : Bus 7726	: V=1.019838, theta=-10.459707 -> V=1.0, theta=0.0
% INFO    : Bus 7729	: V=1.021134, theta=8.462881 -> V=1.0, theta=0.0
% INFO    : Bus 7736	: V=1.025312, theta=-0.874285 -> V=1.0, theta=0.0
% INFO    : Bus 7738	: V=1.030225, theta=-21.980925 -> V=1.0, theta=0.0
% INFO    : Bus 7751	: V=1.008501, theta=-1.308496 -> V=1.0, theta=0.0
% INFO    : Bus 7752	: V=1.030082, theta=-18.432528 -> V=1.0, theta=0.0
% INFO    : Bus 7755	: V=1.06304, theta=-41.883921 -> V=1.0, theta=0.0
% INFO    : Bus 7761	: V=1.015679, theta=-41.175535 -> V=1.0, theta=0.0
% INFO    : Bus 7762	: V=1.011652, theta=-3.587995 -> V=1.0, theta=0.0
% INFO    : Bus 7766	: V=1.034191, theta=-12.695906 -> V=1.0, theta=0.0
% INFO    : Bus 7770	: V=1.030464, theta=-44.236875 -> V=1.0, theta=0.0
% INFO    : Bus 7772	: V=1.054801, theta=-25.696499 -> V=1.0, theta=0.0
% INFO    : Bus 7775	: V=1.052625, theta=-28.722171 -> V=1.0, theta=0.0
% INFO    : Bus 7776	: V=1.068185, theta=6.31233 -> V=1.0, theta=0.0
% INFO    : Bus 7778	: V=1.053947, theta=-16.482217 -> V=1.0, theta=0.0
% INFO    : Bus 7779	: V=1.083645, theta=10.723074 -> V=1.0, theta=0.0
% INFO    : Bus 7791	: V=1.031135, theta=-12.994154 -> V=1.0, theta=0.0
% INFO    : Bus 7792	: V=1.008979, theta=-37.341537 -> V=1.0, theta=0.0
% INFO    : Bus 7795	: V=1.024664, theta=-46.191032 -> V=1.0, theta=0.0
% INFO    : Bus 7797	: V=1.04956, theta=-24.137393 -> V=1.0, theta=0.0
% INFO    : Bus 7805	: V=1.030402, theta=-53.502885 -> V=1.0, theta=0.0
% INFO    : Bus 7808	: V=1.055, theta=-0.211716 -> V=1.0, theta=0.0
% INFO    : Bus 7809	: V=1.028173, theta=-11.501218 -> V=1.0, theta=0.0
% INFO    : Bus 7810	: V=1.051434, theta=-49.397778 -> V=1.0, theta=0.0
% INFO    : Bus 7819	: V=1.020992, theta=-39.959663 -> V=1.0, theta=0.0
% INFO    : Bus 7820	: V=1.01943, theta=-54.187383 -> V=1.0, theta=0.0
% INFO    : Bus 7821	: V=1.031901, theta=-50.655816 -> V=1.0, theta=0.0
% INFO    : Bus 7824	: V=1.049112, theta=-6.264138 -> V=1.0, theta=0.0
% INFO    : Bus 7827	: V=1.047944, theta=-42.323354 -> V=1.0, theta=0.0
% INFO    : Bus 7829	: V=1.053991, theta=-4.575479 -> V=1.0, theta=0.0
% INFO    : Bus 7831	: V=1.007389, theta=-11.404525 -> V=1.0, theta=0.0
% INFO    : Bus 7833	: V=1.02191, theta=-46.781983 -> V=1.0, theta=0.0
% INFO    : Bus 7834	: V=1.008157, theta=-52.641682 -> V=1.0, theta=0.0
% INFO    : Bus 7840	: V=1.041176, theta=-2.414918 -> V=1.0, theta=0.0
% INFO    : Bus 7842	: V=1.005674, theta=-12.461135 -> V=1.0, theta=0.0
% INFO    : Bus 7844	: V=1.031944, theta=10.92267 -> V=1.0, theta=0.0
% INFO    : Bus 7845	: V=1.032324, theta=-53.26234 -> V=1.0, theta=0.0
% INFO    : Bus 7847	: V=1.042074, theta=-8.892363 -> V=1.0, theta=0.0
% INFO    : Bus 7852	: V=1.012558, theta=-0.286848 -> V=1.0, theta=0.0
% INFO    : Bus 7856	: V=1.049571, theta=18.602181 -> V=1.0, theta=0.0
% INFO    : Bus 7857	: V=1.050468, theta=0.178649 -> V=1.0, theta=0.0
% INFO    : Bus 7860	: V=1.058289, theta=-40.045371 -> V=1.0, theta=0.0
% INFO    : Bus 7861	: V=1.022328, theta=-42.36437 -> V=1.0, theta=0.0
% INFO    : Bus 7862	: V=1.040044, theta=-21.14272 -> V=1.0, theta=0.0
% INFO    : Bus 7865	: V=1.0739, theta=-26.397762 -> V=1.0, theta=0.0
% INFO    : Bus 7869	: V=1.024599, theta=-46.279386 -> V=1.0, theta=0.0
% INFO    : Bus 7873	: V=1.023316, theta=-15.192522 -> V=1.0, theta=0.0
% INFO    : Bus 7875	: V=0.988393, theta=-45.410783 -> V=1.0, theta=0.0
% INFO    : Bus 7877	: V=1.01583, theta=-45.303092 -> V=1.0, theta=0.0
% INFO    : Bus 7879	: V=0.969444, theta=-55.475945 -> V=1.0, theta=0.0
% INFO    : Bus 7881	: V=1.057819, theta=-15.067961 -> V=1.0, theta=0.0
% INFO    : Bus 7883	: V=1.049592, theta=-28.831267 -> V=1.0, theta=0.0
% INFO    : Bus 7884	: V=1.037333, theta=4.124709 -> V=1.0, theta=0.0
% INFO    : Bus 7885	: V=1.036839, theta=-21.146665 -> V=1.0, theta=0.0
% INFO    : Bus 7886	: V=1.01825, theta=-19.302256 -> V=1.0, theta=0.0
% INFO    : Bus 7892	: V=1.050308, theta=-11.340814 -> V=1.0, theta=0.0
% INFO    : Bus 7895	: V=1.058928, theta=-19.588442 -> V=1.0, theta=0.0
% INFO    : Bus 7901	: V=0.991976, theta=-42.303992 -> V=1.0, theta=0.0
% INFO    : Bus 7903	: V=1.072292, theta=-42.076237 -> V=1.0, theta=0.0
% INFO    : Bus 7905	: V=1.046063, theta=-17.916487 -> V=1.0, theta=0.0
% INFO    : Bus 7913	: V=1.063382, theta=-8.903291 -> V=1.0, theta=0.0
% INFO    : Bus 7915	: V=1.012672, theta=16.947793 -> V=1.0, theta=0.0
% INFO    : Bus 7918	: V=1.03136, theta=-47.278708 -> V=1.0, theta=0.0
% INFO    : Bus 7923	: V=1.038389, theta=-22.166903 -> V=1.0, theta=0.0
% INFO    : Bus 7925	: V=1.068086, theta=-42.655468 -> V=1.0, theta=0.0
% INFO    : Bus 7927	: V=1.032907, theta=-33.407192 -> V=1.0, theta=0.0
% INFO    : Bus 7929	: V=1.050833, theta=-43.956471 -> V=1.0, theta=0.0
% INFO    : Bus 7935	: V=1.059045, theta=-47.312721 -> V=1.0, theta=0.0
% INFO    : Bus 7937	: V=1.036123, theta=-7.391945 -> V=1.0, theta=0.0
% INFO    : Bus 7943	: V=1.04536, theta=-16.204311 -> V=1.0, theta=0.0
% INFO    : Bus 7945	: V=1.025468, theta=-5.745797 -> V=1.0, theta=0.0
% INFO    : Bus 7951	: V=1.008787, theta=1.304576 -> V=1.0, theta=0.0
% INFO    : Bus 7955	: V=1.064403, theta=-23.358794 -> V=1.0, theta=0.0
% INFO    : Bus 7958	: V=1.001402, theta=-0.492115 -> V=1.0, theta=0.0
% INFO    : Bus 7960	: V=1.018041, theta=6.487865 -> V=1.0, theta=0.0
% INFO    : Bus 7961	: V=1.036447, theta=-8.590687 -> V=1.0, theta=0.0
% INFO    : Bus 7965	: V=1.076922, theta=-37.80677 -> V=1.0, theta=0.0
% INFO    : Bus 7967	: V=1.043923, theta=-11.423985 -> V=1.0, theta=0.0
% INFO    : Bus 7969	: V=1.051096, theta=-42.100911 -> V=1.0, theta=0.0
% INFO    : Bus 7972	: V=1.034223, theta=-19.331892 -> V=1.0, theta=0.0
% INFO    : Bus 7973	: V=1.029695, theta=-53.74855 -> V=1.0, theta=0.0
% INFO    : Bus 7974	: V=1.03335, theta=-20.083487 -> V=1.0, theta=0.0
% INFO    : Bus 7980	: V=1.045534, theta=-43.261604 -> V=1.0, theta=0.0
% INFO    : Bus 7982	: V=1.03592, theta=-23.160805 -> V=1.0, theta=0.0
% INFO    : Bus 7988	: V=1.03551, theta=-2.130971 -> V=1.0, theta=0.0
% INFO    : Bus 7989	: V=1.047576, theta=-3.691217 -> V=1.0, theta=0.0
% INFO    : Bus 7994	: V=1.014446, theta=-16.292763 -> V=1.0, theta=0.0
% INFO    : Bus 7996	: V=1.021261, theta=-1.472747 -> V=1.0, theta=0.0
% INFO    : Bus 7998	: V=1.042456, theta=4.346992 -> V=1.0, theta=0.0
% INFO    : Bus 7999	: V=1.025718, theta=-48.097149 -> V=1.0, theta=0.0
% INFO    : Bus 8005	: V=1.02865, theta=-13.702695 -> V=1.0, theta=0.0
% INFO    : Bus 8007	: V=0.989845, theta=-55.466231 -> V=1.0, theta=0.0
% INFO    : Bus 8012	: V=1.058815, theta=-40.172861 -> V=1.0, theta=0.0
% INFO    : Bus 8016	: V=1.016288, theta=4.516916 -> V=1.0, theta=0.0
% INFO    : Bus 8017	: V=1.023998, theta=11.729802 -> V=1.0, theta=0.0
% INFO    : Bus 8021	: V=0.996849, theta=-30.633993 -> V=1.0, theta=0.0
% INFO    : Bus 8030	: V=1.034462, theta=-4.472294 -> V=1.0, theta=0.0
% INFO    : Bus 8034	: V=1.047311, theta=-49.713598 -> V=1.0, theta=0.0
% INFO    : Bus 8035	: V=1.02206, theta=-16.365944 -> V=1.0, theta=0.0
% INFO    : Bus 8037	: V=1.034628, theta=9.582266 -> V=1.0, theta=0.0
% INFO    : Bus 8043	: V=1.063893, theta=-11.286543 -> V=1.0, theta=0.0
% INFO    : Bus 8044	: V=1.052835, theta=28.542058 -> V=1.0, theta=0.0
% INFO    : Bus 8057	: V=1.04691, theta=-8.660865 -> V=1.0, theta=0.0
% INFO    : Bus 8058	: V=1.023025, theta=11.713091 -> V=1.0, theta=0.0
% INFO    : Bus 8060	: V=1.047468, theta=-13.453767 -> V=1.0, theta=0.0
% INFO    : Bus 8066	: V=1.01361, theta=-46.688841 -> V=1.0, theta=0.0
% INFO    : Bus 8068	: V=1.03287, theta=-53.247599 -> V=1.0, theta=0.0
% INFO    : Bus 8079	: V=1.014968, theta=-48.209864 -> V=1.0, theta=0.0
% INFO    : Bus 8086	: V=1.035202, theta=13.999882 -> V=1.0, theta=0.0
% INFO    : Bus 8087	: V=1.03306, theta=-38.178126 -> V=1.0, theta=0.0
% INFO    : Bus 8088	: V=1.041542, theta=-51.256123 -> V=1.0, theta=0.0
% INFO    : Bus 8098	: V=0.993253, theta=-49.633965 -> V=1.0, theta=0.0
% INFO    : Bus 8103	: V=0.986395, theta=-1.654563 -> V=1.0, theta=0.0
% INFO    : Bus 8104	: V=1.070556, theta=-25.20678 -> V=1.0, theta=0.0
% INFO    : Bus 8107	: V=1.034541, theta=-23.391765 -> V=1.0, theta=0.0
% INFO    : Bus 8109	: V=1.06101, theta=-21.072941 -> V=1.0, theta=0.0
% INFO    : Bus 8112	: V=1.035282, theta=-3.58729 -> V=1.0, theta=0.0
% INFO    : Bus 8114	: V=0.997751, theta=11.674608 -> V=1.0, theta=0.0
% INFO    : Bus 8124	: V=1.016097, theta=-60.182064 -> V=1.0, theta=0.0
% INFO    : Bus 8128	: V=1.088468, theta=-9.653161 -> V=1.0, theta=0.0
% INFO    : Bus 8138	: V=1.053106, theta=-42.708847 -> V=1.0, theta=0.0
% INFO    : Bus 8141	: V=1.037929, theta=3.19519 -> V=1.0, theta=0.0
% INFO    : Bus 8147	: V=1.018621, theta=-47.552935 -> V=1.0, theta=0.0
% INFO    : Bus 8149	: V=1.003847, theta=-45.877241 -> V=1.0, theta=0.0
% INFO    : Bus 8151	: V=1.042949, theta=-25.622195 -> V=1.0, theta=0.0
% INFO    : Bus 8155	: V=1.019574, theta=9.50676 -> V=1.0, theta=0.0
% INFO    : Bus 8158	: V=1.05367, theta=-0.553541 -> V=1.0, theta=0.0
% INFO    : Bus 8159	: V=1.064422, theta=-40.369631 -> V=1.0, theta=0.0
% INFO    : Bus 8163	: V=1.027285, theta=-53.440227 -> V=1.0, theta=0.0
% INFO    : Bus 8164	: V=1.01848, theta=6.913157 -> V=1.0, theta=0.0
% INFO    : Bus 8165	: V=1.057662, theta=-3.433844 -> V=1.0, theta=0.0
% INFO    : Bus 8167	: V=1.014661, theta=4.964915 -> V=1.0, theta=0.0
% INFO    : Bus 8179	: V=1.000011, theta=-5.181422 -> V=1.0, theta=0.0
% INFO    : Bus 8180	: V=1.074171, theta=-30.830541 -> V=1.0, theta=0.0
% INFO    : Bus 8181	: V=1.001921, theta=-4.815597 -> V=1.0, theta=0.0
% INFO    : Bus 8183	: V=1.064461, theta=-47.252646 -> V=1.0, theta=0.0
% INFO    : Bus 8186	: V=1.031758, theta=-53.520592 -> V=1.0, theta=0.0
% INFO    : Bus 8189	: V=1.041138, theta=-18.173764 -> V=1.0, theta=0.0
% INFO    : Bus 8190	: V=1.049024, theta=-10.305691 -> V=1.0, theta=0.0
% INFO    : Bus 8191	: V=1.047336, theta=-15.336918 -> V=1.0, theta=0.0
% INFO    : Bus 8194	: V=1.021281, theta=11.418838 -> V=1.0, theta=0.0
% INFO    : Bus 8195	: V=1.022946, theta=-17.065718 -> V=1.0, theta=0.0
% INFO    : Bus 8197	: V=1.005264, theta=-37.692173 -> V=1.0, theta=0.0
% INFO    : Bus 8200	: V=1.018387, theta=-6.164902 -> V=1.0, theta=0.0
% INFO    : Bus 8204	: V=1.021186, theta=-0.388948 -> V=1.0, theta=0.0
% INFO    : Bus 8207	: V=1.030795, theta=-41.862698 -> V=1.0, theta=0.0
% INFO    : Bus 8209	: V=1.03284, theta=-20.164145 -> V=1.0, theta=0.0
% INFO    : Bus 8210	: V=1.053137, theta=-37.468708 -> V=1.0, theta=0.0
% INFO    : Bus 8211	: V=1.019117, theta=20.177021 -> V=1.0, theta=0.0
% INFO    : Bus 8213	: V=1.040329, theta=-45.735133 -> V=1.0, theta=0.0
% INFO    : Bus 8214	: V=1.043506, theta=-11.477321 -> V=1.0, theta=0.0
% INFO    : Bus 8222	: V=1.019521, theta=-10.479346 -> V=1.0, theta=0.0
% INFO    : Bus 8223	: V=1.058011, theta=17.860107 -> V=1.0, theta=0.0
% INFO    : Bus 8224	: V=1.052137, theta=-41.560675 -> V=1.0, theta=0.0
% INFO    : Bus 8225	: V=1.067644, theta=-11.747659 -> V=1.0, theta=0.0
% INFO    : Bus 8229	: V=1.063217, theta=-7.210075 -> V=1.0, theta=0.0
% INFO    : Bus 8230	: V=1.033248, theta=11.611667 -> V=1.0, theta=0.0
% INFO    : Bus 8236	: V=1.028257, theta=-53.577025 -> V=1.0, theta=0.0
% INFO    : Bus 8240	: V=1.059307, theta=-38.737835 -> V=1.0, theta=0.0
% INFO    : Bus 8242	: V=1.01497, theta=-45.885146 -> V=1.0, theta=0.0
% INFO    : Bus 8247	: V=1.059416, theta=-40.401531 -> V=1.0, theta=0.0
% INFO    : Bus 8249	: V=1.013163, theta=11.791202 -> V=1.0, theta=0.0
% INFO    : Bus 8250	: V=1.035371, theta=-26.17535 -> V=1.0, theta=0.0
% INFO    : Bus 8255	: V=1.023269, theta=-13.783725 -> V=1.0, theta=0.0
% INFO    : Bus 8260	: V=1.047941, theta=-49.577511 -> V=1.0, theta=0.0
% INFO    : Bus 8264	: V=1.019133, theta=20.170123 -> V=1.0, theta=0.0
% INFO    : Bus 8265	: V=1.062244, theta=-23.870999 -> V=1.0, theta=0.0
% INFO    : Bus 8267	: V=1.045102, theta=-10.010182 -> V=1.0, theta=0.0
% INFO    : Bus 8277	: V=1.007724, theta=22.24887 -> V=1.0, theta=0.0
% INFO    : Bus 8278	: V=1.006884, theta=-31.874004 -> V=1.0, theta=0.0
% INFO    : Bus 8284	: V=1.087542, theta=32.323919 -> V=1.0, theta=0.0
% INFO    : Bus 8285	: V=1.016702, theta=-53.999369 -> V=1.0, theta=0.0
% INFO    : Bus 8288	: V=1.048417, theta=11.066634 -> V=1.0, theta=0.0
% INFO    : Bus 8291	: V=1.045972, theta=-7.676921 -> V=1.0, theta=0.0
% INFO    : Bus 8293	: V=1.046708, theta=-24.849013 -> V=1.0, theta=0.0
% INFO    : Bus 8294	: V=1.047825, theta=-11.902121 -> V=1.0, theta=0.0
% INFO    : Bus 8298	: V=1.087038, theta=32.309575 -> V=1.0, theta=0.0
% INFO    : Bus 8301	: V=1.028051, theta=-51.292216 -> V=1.0, theta=0.0
% INFO    : Bus 8307	: V=1.046458, theta=-3.855147 -> V=1.0, theta=0.0
% INFO    : Bus 8310	: V=1.046024, theta=-8.637363 -> V=1.0, theta=0.0
% INFO    : Bus 8311	: V=1.039615, theta=-15.453389 -> V=1.0, theta=0.0
% INFO    : Bus 8312	: V=1.078014, theta=-12.24119 -> V=1.0, theta=0.0
% INFO    : Bus 8316	: V=1.082642, theta=-26.528331 -> V=1.0, theta=0.0
% INFO    : Bus 8318	: V=1.049758, theta=18.746946 -> V=1.0, theta=0.0
% INFO    : Bus 8328	: V=1.040546, theta=-24.459456 -> V=1.0, theta=0.0
% INFO    : Bus 8329	: V=1.010579, theta=5.724362 -> V=1.0, theta=0.0
% INFO    : Bus 8331	: V=1.049189, theta=-12.997183 -> V=1.0, theta=0.0
% INFO    : Bus 8334	: V=1.032843, theta=-14.767853 -> V=1.0, theta=0.0
% INFO    : Bus 8335	: V=1.009769, theta=-11.521151 -> V=1.0, theta=0.0
% INFO    : Bus 8337	: V=1.0496, theta=-42.597986 -> V=1.0, theta=0.0
% INFO    : Bus 8338	: V=1.02467, theta=-43.798324 -> V=1.0, theta=0.0
% INFO    : Bus 8347	: V=0.987155, theta=-18.667915 -> V=1.0, theta=0.0
% INFO    : Bus 8352	: V=1.021243, theta=-39.022936 -> V=1.0, theta=0.0
% INFO    : Bus 8353	: V=1.029816, theta=-55.720331 -> V=1.0, theta=0.0
% INFO    : Bus 8356	: V=1.015127, theta=1.297374 -> V=1.0, theta=0.0
% INFO    : Bus 8361	: V=1.073255, theta=-26.451713 -> V=1.0, theta=0.0
% INFO    : Bus 8367	: V=1.036984, theta=-6.681744 -> V=1.0, theta=0.0
% INFO    : Bus 8369	: V=1.028676, theta=-9.152628 -> V=1.0, theta=0.0
% INFO    : Bus 8373	: V=1.070996, theta=-48.215066 -> V=1.0, theta=0.0
% INFO    : Bus 8374	: V=1.061288, theta=-41.845858 -> V=1.0, theta=0.0
% INFO    : Bus 8378	: V=1.022564, theta=-38.108897 -> V=1.0, theta=0.0
% INFO    : Bus 8380	: V=1.015958, theta=19.538705 -> V=1.0, theta=0.0
% INFO    : Bus 8381	: V=1.071454, theta=-44.524455 -> V=1.0, theta=0.0
% INFO    : Bus 8389	: V=1.016669, theta=17.36147 -> V=1.0, theta=0.0
% INFO    : Bus 8392	: V=1.047048, theta=7.528918 -> V=1.0, theta=0.0
% INFO    : Bus 8393	: V=1.002909, theta=17.544011 -> V=1.0, theta=0.0
% INFO    : Bus 8396	: V=1.062328, theta=-40.645356 -> V=1.0, theta=0.0
% INFO    : Bus 8397	: V=1.043616, theta=-25.457032 -> V=1.0, theta=0.0
% INFO    : Bus 8405	: V=1.037511, theta=-12.364331 -> V=1.0, theta=0.0
% INFO    : Bus 8406	: V=1.049365, theta=-25.182116 -> V=1.0, theta=0.0
% INFO    : Bus 8411	: V=1.041273, theta=-25.850241 -> V=1.0, theta=0.0
% INFO    : Bus 8417	: V=1.01013, theta=-47.59632 -> V=1.0, theta=0.0
% INFO    : Bus 8419	: V=1.017228, theta=-59.911374 -> V=1.0, theta=0.0
% INFO    : Bus 8420	: V=1.05117, theta=-9.097494 -> V=1.0, theta=0.0
% INFO    : Bus 8432	: V=1.02638, theta=12.015884 -> V=1.0, theta=0.0
% INFO    : Bus 8438	: V=1.019637, theta=-47.16442 -> V=1.0, theta=0.0
% INFO    : Bus 8439	: V=0.997692, theta=-23.484518 -> V=1.0, theta=0.0
% INFO    : Bus 8442	: V=1.033294, theta=3.146647 -> V=1.0, theta=0.0
% INFO    : Bus 8448	: V=1.017839, theta=-20.618009 -> V=1.0, theta=0.0
% INFO    : Bus 8458	: V=1.045078, theta=-9.483962 -> V=1.0, theta=0.0
% INFO    : Bus 8459	: V=0.969593, theta=-43.205859 -> V=1.0, theta=0.0
% INFO    : Bus 8463	: V=1.037105, theta=6.294399 -> V=1.0, theta=0.0
% INFO    : Bus 8466	: V=1.040487, theta=-4.452236 -> V=1.0, theta=0.0
% INFO    : Bus 8467	: V=0.983889, theta=-23.029689 -> V=1.0, theta=0.0
% INFO    : Bus 8468	: V=1.003777, theta=-14.954113 -> V=1.0, theta=0.0
% INFO    : Bus 8473	: V=1.042275, theta=-8.85577 -> V=1.0, theta=0.0
% INFO    : Bus 8475	: V=1.071679, theta=-47.923897 -> V=1.0, theta=0.0
% INFO    : Bus 8477	: V=1.064533, theta=-10.136664 -> V=1.0, theta=0.0
% INFO    : Bus 8478	: V=1.048947, theta=-8.507678 -> V=1.0, theta=0.0
% INFO    : Bus 8480	: V=1.029915, theta=15.10216 -> V=1.0, theta=0.0
% INFO    : Bus 8483	: V=1.050084, theta=18.748297 -> V=1.0, theta=0.0
% INFO    : Bus 8485	: V=1.04146, theta=-7.387137 -> V=1.0, theta=0.0
% INFO    : Bus 8486	: V=1.046146, theta=-19.545285 -> V=1.0, theta=0.0
% INFO    : Bus 8487	: V=0.996752, theta=-3.789756 -> V=1.0, theta=0.0
% INFO    : Bus 8490	: V=1.016007, theta=-0.665636 -> V=1.0, theta=0.0
% INFO    : Bus 8492	: V=1.002793, theta=-4.061923 -> V=1.0, theta=0.0
% INFO    : Bus 8493	: V=0.972187, theta=-36.402896 -> V=1.0, theta=0.0
% INFO    : Bus 8494	: V=1.087369, theta=-9.837706 -> V=1.0, theta=0.0
% INFO    : Bus 8497	: V=1.046167, theta=-14.558369 -> V=1.0, theta=0.0
% INFO    : Bus 8504	: V=1.074291, theta=-38.217186 -> V=1.0, theta=0.0
% INFO    : Bus 8507	: V=1.074019, theta=-26.375849 -> V=1.0, theta=0.0
% INFO    : Bus 8508	: V=1.028669, theta=17.409525 -> V=1.0, theta=0.0
% INFO    : Bus 8510	: V=1.061792, theta=15.567985 -> V=1.0, theta=0.0
% INFO    : Bus 8511	: V=1.040262, theta=-24.549837 -> V=1.0, theta=0.0
% INFO    : Bus 8512	: V=1.012675, theta=-47.088026 -> V=1.0, theta=0.0
% INFO    : Bus 8515	: V=1.055375, theta=-12.443359 -> V=1.0, theta=0.0
% INFO    : Bus 8522	: V=1.023003, theta=-15.643844 -> V=1.0, theta=0.0
% INFO    : Bus 8525	: V=1.042349, theta=27.051491 -> V=1.0, theta=0.0
% INFO    : Bus 8529	: V=1.014093, theta=-46.532827 -> V=1.0, theta=0.0
% INFO    : Bus 8530	: V=1.01471, theta=-46.176096 -> V=1.0, theta=0.0
% INFO    : Bus 8534	: V=1.016996, theta=-43.798173 -> V=1.0, theta=0.0
% INFO    : Bus 8535	: V=1.035755, theta=-21.953277 -> V=1.0, theta=0.0
% INFO    : Bus 8542	: V=1.043635, theta=-21.062798 -> V=1.0, theta=0.0
% INFO    : Bus 8546	: V=1.039564, theta=-11.636283 -> V=1.0, theta=0.0
% INFO    : Bus 8547	: V=1.015341, theta=-51.627331 -> V=1.0, theta=0.0
% INFO    : Bus 8560	: V=0.983882, theta=-18.215513 -> V=1.0, theta=0.0
% INFO    : Bus 8561	: V=1.065428, theta=-42.770872 -> V=1.0, theta=0.0
% INFO    : Bus 8564	: V=1.019996, theta=-19.556384 -> V=1.0, theta=0.0
% INFO    : Bus 8565	: V=1.049865, theta=7.888607 -> V=1.0, theta=0.0
% INFO    : Bus 8568	: V=1.022255, theta=-6.042108 -> V=1.0, theta=0.0
% INFO    : Bus 8571	: V=1.029852, theta=-53.46566 -> V=1.0, theta=0.0
% INFO    : Bus 8574	: V=0.99818, theta=-3.765849 -> V=1.0, theta=0.0
% INFO    : Bus 8575	: V=1.029116, theta=-53.698048 -> V=1.0, theta=0.0
% INFO    : Bus 8578	: V=1.044202, theta=-22.07106 -> V=1.0, theta=0.0
% INFO    : Bus 8581	: V=1.0043, theta=5.087257 -> V=1.0, theta=0.0
% INFO    : Bus 8582	: V=1.026673, theta=-51.284917 -> V=1.0, theta=0.0
% INFO    : Bus 8592	: V=1.047329, theta=-3.731214 -> V=1.0, theta=0.0
% INFO    : Bus 8601	: V=1.041573, theta=-51.25628 -> V=1.0, theta=0.0
% INFO    : Bus 8604	: V=1.017915, theta=15.899545 -> V=1.0, theta=0.0
% INFO    : Bus 8605	: V=1.009283, theta=-0.131172 -> V=1.0, theta=0.0
% INFO    : Bus 8613	: V=1.020302, theta=2.367885 -> V=1.0, theta=0.0
% INFO    : Bus 8621	: V=1.017227, theta=17.769534 -> V=1.0, theta=0.0
% INFO    : Bus 8625	: V=1.055846, theta=-41.065047 -> V=1.0, theta=0.0
% INFO    : Bus 8626	: V=0.98923, theta=-17.630415 -> V=1.0, theta=0.0
% INFO    : Bus 8627	: V=1.047406, theta=-26.434879 -> V=1.0, theta=0.0
% INFO    : Bus 8628	: V=1.041444, theta=-23.628029 -> V=1.0, theta=0.0
% INFO    : Bus 8629	: V=0.969991, theta=-42.948363 -> V=1.0, theta=0.0
% INFO    : Bus 8630	: V=1.064508, theta=-46.868087 -> V=1.0, theta=0.0
% INFO    : Bus 8636	: V=1.035848, theta=-21.721595 -> V=1.0, theta=0.0
% INFO    : Bus 8642	: V=1.031267, theta=8.872582 -> V=1.0, theta=0.0
% INFO    : Bus 8651	: V=1.028711, theta=-17.231975 -> V=1.0, theta=0.0
% INFO    : Bus 8653	: V=1.034402, theta=-16.023528 -> V=1.0, theta=0.0
% INFO    : Bus 8656	: V=1.035127, theta=-8.458553 -> V=1.0, theta=0.0
% INFO    : Bus 8658	: V=1.031202, theta=-53.697921 -> V=1.0, theta=0.0
% INFO    : Bus 8661	: V=1.02646, theta=-47.934753 -> V=1.0, theta=0.0
% INFO    : Bus 8662	: V=1.087501, theta=32.310934 -> V=1.0, theta=0.0
% INFO    : Bus 8664	: V=1.061218, theta=-46.141427 -> V=1.0, theta=0.0
% INFO    : Bus 8668	: V=1.018394, theta=14.026518 -> V=1.0, theta=0.0
% INFO    : Bus 8669	: V=1.046423, theta=-15.344297 -> V=1.0, theta=0.0
% INFO    : Bus 8670	: V=1.049183, theta=-6.529837 -> V=1.0, theta=0.0
% INFO    : Bus 8671	: V=1.018922, theta=-50.527242 -> V=1.0, theta=0.0
% INFO    : Bus 8672	: V=1.023937, theta=-21.027655 -> V=1.0, theta=0.0
% INFO    : Bus 8676	: V=1.018144, theta=-21.878056 -> V=1.0, theta=0.0
% INFO    : Bus 8677	: V=1.020081, theta=-10.192806 -> V=1.0, theta=0.0
% INFO    : Bus 8683	: V=1.041179, theta=-24.317296 -> V=1.0, theta=0.0
% INFO    : Bus 8689	: V=1.03523, theta=-20.733231 -> V=1.0, theta=0.0
% INFO    : Bus 8691	: V=1.045574, theta=-33.643601 -> V=1.0, theta=0.0
% INFO    : Bus 8701	: V=1.023588, theta=-43.556409 -> V=1.0, theta=0.0
% INFO    : Bus 8702	: V=1.029789, theta=-40.586324 -> V=1.0, theta=0.0
% INFO    : Bus 8704	: V=1.041183, theta=-7.97841 -> V=1.0, theta=0.0
% INFO    : Bus 8706	: V=1.008191, theta=4.606463 -> V=1.0, theta=0.0
% INFO    : Bus 8707	: V=1.029902, theta=-11.704441 -> V=1.0, theta=0.0
% INFO    : Bus 8710	: V=1.024755, theta=-47.559445 -> V=1.0, theta=0.0
% INFO    : Bus 8711	: V=1.041543, theta=-12.078252 -> V=1.0, theta=0.0
% INFO    : Bus 8719	: V=1.017108, theta=-44.601504 -> V=1.0, theta=0.0
% INFO    : Bus 8721	: V=1.056768, theta=-15.959174 -> V=1.0, theta=0.0
% INFO    : Bus 8722	: V=1.071802, theta=-25.073253 -> V=1.0, theta=0.0
% INFO    : Bus 8729	: V=1.009953, theta=-37.874633 -> V=1.0, theta=0.0
% INFO    : Bus 8731	: V=1.025891, theta=-39.717321 -> V=1.0, theta=0.0
% INFO    : Bus 8732	: V=1.03704, theta=-21.186119 -> V=1.0, theta=0.0
% INFO    : Bus 8738	: V=1.015889, theta=6.018492 -> V=1.0, theta=0.0
% INFO    : Bus 8743	: V=1.033764, theta=-34.537661 -> V=1.0, theta=0.0
% INFO    : Bus 8748	: V=1.06653, theta=-49.707057 -> V=1.0, theta=0.0
% INFO    : Bus 8756	: V=1.016103, theta=-59.644677 -> V=1.0, theta=0.0
% INFO    : Bus 8763	: V=1.032339, theta=2.72345 -> V=1.0, theta=0.0
% INFO    : Bus 8765	: V=1.046637, theta=-15.330191 -> V=1.0, theta=0.0
% INFO    : Bus 8771	: V=1.008996, theta=-37.338884 -> V=1.0, theta=0.0
% INFO    : Bus 8772	: V=1.023626, theta=8.631158 -> V=1.0, theta=0.0
% INFO    : Bus 8773	: V=0.997763, theta=11.671711 -> V=1.0, theta=0.0
% INFO    : Bus 8776	: V=1.001752, theta=-37.729943 -> V=1.0, theta=0.0
% INFO    : Bus 8784	: V=1.022002, theta=11.415331 -> V=1.0, theta=0.0
% INFO    : Bus 8787	: V=1.066321, theta=-17.009493 -> V=1.0, theta=0.0
% INFO    : Bus 8788	: V=1.042393, theta=-5.95552 -> V=1.0, theta=0.0
% INFO    : Bus 8789	: V=0.991696, theta=-46.068395 -> V=1.0, theta=0.0
% INFO    : Bus 8791	: V=1.056484, theta=-22.378068 -> V=1.0, theta=0.0
% INFO    : Bus 8792	: V=1.027558, theta=4.096913 -> V=1.0, theta=0.0
% INFO    : Bus 8795	: V=1.055026, theta=-0.12855 -> V=1.0, theta=0.0
% INFO    : Bus 8804	: V=1.050456, theta=-9.493537 -> V=1.0, theta=0.0
% INFO    : Bus 8806	: V=1.069256, theta=-43.457093 -> V=1.0, theta=0.0
% INFO    : Bus 8807	: V=1.046456, theta=-3.855139 -> V=1.0, theta=0.0
% INFO    : Bus 8808	: V=1.055503, theta=-25.842277 -> V=1.0, theta=0.0
% INFO    : Bus 8809	: V=1.027013, theta=-32.578876 -> V=1.0, theta=0.0
% INFO    : Bus 8814	: V=1.029202, theta=3.877715 -> V=1.0, theta=0.0
% INFO    : Bus 8818	: V=1.051013, theta=0.642803 -> V=1.0, theta=0.0
% INFO    : Bus 8819	: V=1.035296, theta=-52.835216 -> V=1.0, theta=0.0
% INFO    : Bus 8825	: V=1.008085, theta=-2.700245 -> V=1.0, theta=0.0
% INFO    : Bus 8828	: V=1.016741, theta=6.318703 -> V=1.0, theta=0.0
% INFO    : Bus 8829	: V=1.039155, theta=-21.21347 -> V=1.0, theta=0.0
% INFO    : Bus 8832	: V=1.015247, theta=-0.729836 -> V=1.0, theta=0.0
% INFO    : Bus 8834	: V=1.003348, theta=-22.560352 -> V=1.0, theta=0.0
% INFO    : Bus 8835	: V=1.036477, theta=-22.934857 -> V=1.0, theta=0.0
% INFO    : Bus 8843	: V=1.05134, theta=-11.210293 -> V=1.0, theta=0.0
% INFO    : Bus 8846	: V=1.067593, theta=7.848137 -> V=1.0, theta=0.0
% INFO    : Bus 8847	: V=0.993761, theta=-0.54588 -> V=1.0, theta=0.0
% INFO    : Bus 8853	: V=1.051311, theta=-36.586636 -> V=1.0, theta=0.0
% INFO    : Bus 8854	: V=1.027085, theta=-44.337295 -> V=1.0, theta=0.0
% INFO    : Bus 8858	: V=1.027559, theta=-43.116605 -> V=1.0, theta=0.0
% INFO    : Bus 8860	: V=1.021941, theta=-10.157615 -> V=1.0, theta=0.0
% INFO    : Bus 8861	: V=0.989557, theta=-54.074535 -> V=1.0, theta=0.0
% INFO    : Bus 8862	: V=1.042169, theta=14.438159 -> V=1.0, theta=0.0
% INFO    : Bus 8864	: V=1.042974, theta=-31.901323 -> V=1.0, theta=0.0
% INFO    : Bus 8867	: V=1.024036, theta=-48.357834 -> V=1.0, theta=0.0
% INFO    : Bus 8870	: V=1.054624, theta=-47.749596 -> V=1.0, theta=0.0
% INFO    : Bus 8871	: V=1.037687, theta=-52.222994 -> V=1.0, theta=0.0
% INFO    : Bus 8872	: V=1.056528, theta=-15.983313 -> V=1.0, theta=0.0
% INFO    : Bus 8873	: V=1.070378, theta=-27.323305 -> V=1.0, theta=0.0
% INFO    : Bus 8874	: V=1.041431, theta=-20.131936 -> V=1.0, theta=0.0
% INFO    : Bus 8875	: V=1.047011, theta=17.817721 -> V=1.0, theta=0.0
% INFO    : Bus 8877	: V=1.038573, theta=-20.681367 -> V=1.0, theta=0.0
% INFO    : Bus 8878	: V=1.020394, theta=23.076892 -> V=1.0, theta=0.0
% INFO    : Bus 8879	: V=1.036661, theta=-22.775474 -> V=1.0, theta=0.0
% INFO    : Bus 8881	: V=1.008501, theta=-1.308496 -> V=1.0, theta=0.0
% INFO    : Bus 8882	: V=1.048879, theta=11.612548 -> V=1.0, theta=0.0
% INFO    : Bus 8886	: V=0.979342, theta=-3.75641 -> V=1.0, theta=0.0
% INFO    : Bus 8887	: V=1.040073, theta=1.821607 -> V=1.0, theta=0.0
% INFO    : Bus 8888	: V=1.037601, theta=-44.205902 -> V=1.0, theta=0.0
% INFO    : Bus 8889	: V=1.050781, theta=7.942576 -> V=1.0, theta=0.0
% INFO    : Bus 8893	: V=1.046765, theta=-15.235259 -> V=1.0, theta=0.0
% INFO    : Bus 8895	: V=1.023021, theta=-1.383064 -> V=1.0, theta=0.0
% INFO    : Bus 8898	: V=1.049767, theta=18.744304 -> V=1.0, theta=0.0
% INFO    : Bus 8900	: V=1.047679, theta=-23.734294 -> V=1.0, theta=0.0
% INFO    : Bus 8903	: V=1.021928, theta=-11.382923 -> V=1.0, theta=0.0
% INFO    : Bus 8906	: V=1.035877, theta=-23.091391 -> V=1.0, theta=0.0
% INFO    : Bus 8913	: V=1.039275, theta=-20.592607 -> V=1.0, theta=0.0
% INFO    : Bus 8917	: V=0.992842, theta=5.915957 -> V=1.0, theta=0.0
% INFO    : Bus 8921	: V=0.998492, theta=-2.950962 -> V=1.0, theta=0.0
% INFO    : Bus 8926	: V=0.989796, theta=-55.840175 -> V=1.0, theta=0.0
% INFO    : Bus 8927	: V=1.015122, theta=-34.562812 -> V=1.0, theta=0.0
% INFO    : Bus 8930	: V=0.986412, theta=-18.654346 -> V=1.0, theta=0.0
% INFO    : Bus 8931	: V=1.088084, theta=-9.652001 -> V=1.0, theta=0.0
% INFO    : Bus 8936	: V=1.031095, theta=-53.048263 -> V=1.0, theta=0.0
% INFO    : Bus 8939	: V=1.015956, theta=-54.590796 -> V=1.0, theta=0.0
% INFO    : Bus 8946	: V=1.041085, theta=-41.176169 -> V=1.0, theta=0.0
% INFO    : Bus 8947	: V=1.041674, theta=-11.509748 -> V=1.0, theta=0.0
% INFO    : Bus 8950	: V=1.045004, theta=-14.86535 -> V=1.0, theta=0.0
% INFO    : Bus 8953	: V=1.015018, theta=-39.845825 -> V=1.0, theta=0.0
% INFO    : Bus 8956	: V=1.064772, theta=23.13068 -> V=1.0, theta=0.0
% INFO    : Bus 8957	: V=0.989889, theta=-54.003917 -> V=1.0, theta=0.0
% INFO    : Bus 8961	: V=1.038824, theta=-14.118012 -> V=1.0, theta=0.0
% INFO    : Bus 8963	: V=1.015806, theta=-40.105518 -> V=1.0, theta=0.0
% INFO    : Bus 8964	: V=1.025866, theta=-12.86993 -> V=1.0, theta=0.0
% INFO    : Bus 8973	: V=1.050147, theta=-35.915457 -> V=1.0, theta=0.0
% INFO    : Bus 8975	: V=1.041454, theta=-24.319884 -> V=1.0, theta=0.0
% INFO    : Bus 8976	: V=1.045593, theta=-17.103981 -> V=1.0, theta=0.0
% INFO    : Bus 8977	: V=1.011449, theta=1.005067 -> V=1.0, theta=0.0
% INFO    : Bus 8980	: V=1.044325, theta=-11.082462 -> V=1.0, theta=0.0
% INFO    : Bus 8981	: V=1.027038, theta=-42.675433 -> V=1.0, theta=0.0
% INFO    : Bus 8987	: V=1.052269, theta=-41.141403 -> V=1.0, theta=0.0
% INFO    : Bus 8989	: V=1.041862, theta=-25.620235 -> V=1.0, theta=0.0
% INFO    : Bus 8991	: V=1.015291, theta=3.736834 -> V=1.0, theta=0.0
% INFO    : Bus 8992	: V=1.046455, theta=-3.756643 -> V=1.0, theta=0.0
% INFO    : Bus 8993	: V=1.022201, theta=-37.558452 -> V=1.0, theta=0.0
% INFO    : Bus 8994	: V=1.037094, theta=6.46761 -> V=1.0, theta=0.0
% INFO    : Bus 8997	: V=1.002676, theta=-13.17164 -> V=1.0, theta=0.0
% INFO    : Bus 8998	: V=0.971706, theta=-42.865881 -> V=1.0, theta=0.0
% INFO    : Bus 8999	: V=1.043446, theta=-21.589649 -> V=1.0, theta=0.0
% INFO    : Bus 9001	: V=1.025721, theta=-41.459434 -> V=1.0, theta=0.0
% INFO    : Bus 9002	: V=1.022623, theta=-10.494423 -> V=1.0, theta=0.0
% INFO    : Bus 9007	: V=1.014412, theta=1.30218 -> V=1.0, theta=0.0
% INFO    : Bus 9011	: V=1.03607, theta=-23.054646 -> V=1.0, theta=0.0
% INFO    : Bus 9012	: V=1.048604, theta=1.102665 -> V=1.0, theta=0.0
% INFO    : Bus 9014	: V=1.052162, theta=-6.665777 -> V=1.0, theta=0.0
% INFO    : Bus 9018	: V=1.022149, theta=-6.603112 -> V=1.0, theta=0.0
% INFO    : Bus 9019	: V=1.039622, theta=-24.721521 -> V=1.0, theta=0.0
% INFO    : Bus 9021	: V=1.039071, theta=-6.338232 -> V=1.0, theta=0.0
% INFO    : Bus 9024	: V=1.025444, theta=1.951824 -> V=1.0, theta=0.0
% INFO    : Bus 9025	: V=1.005508, theta=-4.49576 -> V=1.0, theta=0.0
% INFO    : Bus 9028	: V=1.036092, theta=-52.422827 -> V=1.0, theta=0.0
% INFO    : Bus 9029	: V=1.01267, theta=16.94777 -> V=1.0, theta=0.0
% INFO    : Bus 9032	: V=1.064444, theta=-47.252548 -> V=1.0, theta=0.0
% INFO    : Bus 9033	: V=1.050041, theta=-26.48683 -> V=1.0, theta=0.0
% INFO    : Bus 9039	: V=1.02063, theta=-43.159076 -> V=1.0, theta=0.0
% INFO    : Bus 9043	: V=1.02106, theta=-40.012553 -> V=1.0, theta=0.0
% INFO    : Bus 9045	: V=1.039106, theta=-24.673735 -> V=1.0, theta=0.0
% INFO    : Bus 9049	: V=1.018489, theta=-40.152369 -> V=1.0, theta=0.0
% INFO    : Bus 9051	: V=1.039937, theta=0.565336 -> V=1.0, theta=0.0
% INFO    : Bus 9055	: V=0.982562, theta=-49.677102 -> V=1.0, theta=0.0
% INFO    : Bus 9057	: V=1.02341, theta=-48.135629 -> V=1.0, theta=0.0
% INFO    : Bus 9059	: V=1.071723, theta=-27.23087 -> V=1.0, theta=0.0
% INFO    : Bus 9063	: V=1.026728, theta=11.942947 -> V=1.0, theta=0.0
% INFO    : Bus 9064	: V=1.002528, theta=-3.934171 -> V=1.0, theta=0.0
% INFO    : Bus 9065	: V=1.032374, theta=2.535924 -> V=1.0, theta=0.0
% INFO    : Bus 9066	: V=1.019399, theta=-20.82846 -> V=1.0, theta=0.0
% INFO    : Bus 9067	: V=1.045155, theta=1.524541 -> V=1.0, theta=0.0
% INFO    : Bus 9072	: V=1.035251, theta=5.451595 -> V=1.0, theta=0.0
% INFO    : Bus 9083	: V=1.009534, theta=-0.822012 -> V=1.0, theta=0.0
% INFO    : Bus 9091	: V=1.042523, theta=-9.744131 -> V=1.0, theta=0.0
% INFO    : Bus 9094	: V=1.035929, theta=6.023351 -> V=1.0, theta=0.0
% INFO    : Bus 9097	: V=1.01907, theta=-39.584889 -> V=1.0, theta=0.0
% INFO    : Bus 9101	: V=1.026751, theta=-21.689348 -> V=1.0, theta=0.0
% INFO    : Bus 9106	: V=0.988316, theta=-55.413025 -> V=1.0, theta=0.0
% INFO    : Bus 9108	: V=1.04489, theta=-16.471181 -> V=1.0, theta=0.0
% INFO    : Bus 9109	: V=1.039939, theta=0.565316 -> V=1.0, theta=0.0
% INFO    : Bus 9112	: V=1.049188, theta=-12.997177 -> V=1.0, theta=0.0
% INFO    : Bus 9117	: V=1.023525, theta=-52.097135 -> V=1.0, theta=0.0
% INFO    : Bus 9118	: V=1.029714, theta=3.875256 -> V=1.0, theta=0.0
% INFO    : Bus 9119	: V=1.041761, theta=-20.561727 -> V=1.0, theta=0.0
% INFO    : Bus 9120	: V=1.019729, theta=2.890205 -> V=1.0, theta=0.0
% INFO    : Bus 9127	: V=1.005733, theta=21.671612 -> V=1.0, theta=0.0
% INFO    : Bus 9128	: V=1.034185, theta=-2.632449 -> V=1.0, theta=0.0
% INFO    : Bus 9130	: V=1.044738, theta=-30.943014 -> V=1.0, theta=0.0
% INFO    : Bus 9131	: V=1.0496, theta=-24.137879 -> V=1.0, theta=0.0
% INFO    : Bus 9136	: V=0.9931, theta=-53.684274 -> V=1.0, theta=0.0
% INFO    : Bus 9137	: V=1.048734, theta=-26.47055 -> V=1.0, theta=0.0
% INFO    : Bus 9140	: V=1.049339, theta=-5.241785 -> V=1.0, theta=0.0
% INFO    : Bus 9146	: V=1.019746, theta=8.415269 -> V=1.0, theta=0.0
% INFO    : Bus 9150	: V=1.037874, theta=-13.218156 -> V=1.0, theta=0.0
% INFO    : Bus 9155	: V=1.023228, theta=-20.882747 -> V=1.0, theta=0.0
% INFO    : Bus 9158	: V=1.023649, theta=-14.568689 -> V=1.0, theta=0.0
% INFO    : Bus 9159	: V=1.05214, theta=-43.291737 -> V=1.0, theta=0.0
% INFO    : Bus 9162	: V=1.01511, theta=-60.285572 -> V=1.0, theta=0.0
% INFO    : Bus 9164	: V=0.998782, theta=-19.437343 -> V=1.0, theta=0.0
% INFO    : Bus 9173	: V=1.032259, theta=-20.230037 -> V=1.0, theta=0.0
% INFO    : Bus 9174	: V=1.020141, theta=-32.801345 -> V=1.0, theta=0.0
% INFO    : Bus 9176	: V=1.04942, theta=-12.999767 -> V=1.0, theta=0.0
% INFO    : Bus 9180	: V=1.057766, theta=-8.606877 -> V=1.0, theta=0.0
% INFO    : Bus 9181	: V=1.035041, theta=-9.441995 -> V=1.0, theta=0.0
% INFO    : Bus 9185	: V=1.052903, theta=-6.607366 -> V=1.0, theta=0.0
% INFO    : Bus 9189	: V=1.046485, theta=-25.065792 -> V=1.0, theta=0.0
% INFO    : Bus 9191	: V=1.073296, theta=-24.836176 -> V=1.0, theta=0.0
% INFO    : Bus 9192	: V=1.033027, theta=-10.73637 -> V=1.0, theta=0.0
% INFO    : Bus 9201	: V=1.022891, theta=-42.801498 -> V=1.0, theta=0.0
% INFO    : Bus 9203	: V=1.005382, theta=-12.53126 -> V=1.0, theta=0.0
% INFO    : Bus 9205	: V=1.025558, theta=13.881084 -> V=1.0, theta=0.0
% INFO    : Bus 9206	: V=1.033506, theta=4.172445 -> V=1.0, theta=0.0
% INFO    : Bus 9213	: V=1.024999, theta=-4.638587 -> V=1.0, theta=0.0
% INFO    : Bus 9216	: V=1.024848, theta=-48.161418 -> V=1.0, theta=0.0
% INFO    : Bus 9217	: V=1.041729, theta=-8.889947 -> V=1.0, theta=0.0
% INFO    : Bus 9222	: V=1.055906, theta=-16.165943 -> V=1.0, theta=0.0
% INFO    : Bus 9223	: V=1.010836, theta=7.611553 -> V=1.0, theta=0.0
% INFO    : Bus 9231	: V=1.027624, theta=-19.18143 -> V=1.0, theta=0.0
% INFO    : Bus 9239	: V=1.018061, theta=6.492507 -> V=1.0, theta=0.0
% INFO    : Bus 9241	: V=1.050472, theta=-9.493678 -> V=1.0, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 32	: Pg=8.0, Qg=0.06 -> Pg=8.1, Qg=0.675
% INFO    : Gen at bus 32	: Vg=1.006206 -> Vg=1.0
% INFO    : Gen at bus 33	: Pg=5.3, Qg=0.41 -> Pg=2.69, Qg=0.595
% INFO    : Gen at bus 33	: Vg=1.031909 -> Vg=1.0
% INFO    : Gen at bus 39	: Pg=34.3, Qg=4.84 -> Pg=20.0, Qg=5.31
% INFO    : Gen at bus 39	: Vg=1.005551 -> Vg=1.0
% INFO    : Gen at bus 51	: Pg=-144.5, Qg=0.55 -> Pg=-46.335, Qg=0.645
% INFO    : Gen at bus 51	: Vg=1.01198 -> Vg=1.0
% INFO    : Gen at bus 124	: Pg=861.3, Qg=51.52 -> Pg=666.665, Qg=133.865
% INFO    : Gen at bus 124	: Vg=1.079291 -> Vg=1.0
% INFO    : Gen at bus 150	: Pg=67.29, Qg=-9.79 -> Pg=80.0, Qg=27.275
% INFO    : Gen at bus 150	: Vg=1.062067 -> Vg=1.0
% INFO    : Gen at bus 179	: Pg=-179.2, Qg=-33.84 -> Pg=-69.465, Qg=0.46
% INFO    : Gen at bus 179	: Vg=1.048817 -> Vg=1.0
% INFO    : Gen at bus 194	: Pg=268.6, Qg=43.34 -> Pg=200.0, Qg=38.33
% INFO    : Gen at bus 194	: Vg=1.029584 -> Vg=1.0
% INFO    : Gen at bus 201	: Pg=5.2, Qg=0.39 -> Pg=2.685, Qg=0.6
% INFO    : Gen at bus 201	: Vg=1.024675 -> Vg=1.0
% INFO    : Gen at bus 221	: Pg=-155.39, Qg=91.05 -> Pg=-53.59, Qg=59.31
% INFO    : Gen at bus 221	: Vg=0.996091 -> Vg=1.0
% INFO    : Gen at bus 299	: Pg=975.9, Qg=127.2 -> Pg=1066.665, Qg=231.27
% INFO    : Gen at bus 299	: Vg=1.046197 -> Vg=1.0
% INFO    : Gen at bus 338	: Pg=83.7, Qg=1.48 -> Pg=60.0, Qg=18.19
% INFO    : Gen at bus 338	: Vg=1.049578 -> Vg=1.0
% INFO    : Gen at bus 352	: Pg=1250.4, Qg=268.17 -> Pg=1333.335, Qg=314.335
% INFO    : Gen at bus 352	: Vg=1.054691 -> Vg=1.0
% INFO    : Gen at bus 389	: Pg=69.0, Qg=16.81 -> Pg=60.0, Qg=19.445
% INFO    : Gen at bus 389	: Vg=1.020856 -> Vg=1.0
% INFO    : Gen at bus 413	: Pg=231.0, Qg=19.25 -> Pg=140.0, Qg=37.14
% INFO    : Gen at bus 413	: Vg=1.052152 -> Vg=1.0
% INFO    : Gen at bus 440	: Pg=83.1, Qg=-4.05 -> Pg=60.0, Qg=18.36
% INFO    : Gen at bus 440	: Vg=1.029422 -> Vg=1.0
% INFO    : Gen at bus 442	: Pg=-40.35, Qg=0.43 -> Pg=23.1, Qg=0.51
% INFO    : Gen at bus 442	: Vg=1.013689 -> Vg=1.0
% INFO    : Gen at bus 453	: Pg=260.1, Qg=54.54 -> Pg=270.0, Qg=91.415
% INFO    : Gen at bus 453	: Vg=1.021096 -> Vg=1.0
% INFO    : Gen at bus 489	: Pg=-107.4, Qg=0.51 -> Pg=-21.6, Qg=0.73
% INFO    : Gen at bus 489	: Vg=1.012805 -> Vg=1.0
% INFO    : Gen at bus 516	: Pg=539.4, Qg=188.57 -> Pg=400.0, Qg=77.56
% INFO    : Gen at bus 516	: Vg=1.074804 -> Vg=1.0
% INFO    : Gen at bus 564	: Pg=-51.67, Qg=-0.63 -> Pg=15.555, Qg=-0.44
% INFO    : Gen at bus 564	: Vg=1.069692 -> Vg=1.0
% INFO    : Gen at bus 583	: Pg=-270.0, Qg=5.38 -> Pg=-130.0, Qg=5.425
% INFO    : Gen at bus 583	: Vg=1.043394 -> Vg=1.0
% INFO    : Gen at bus 615	: Pg=38.2, Qg=0.1 -> Pg=20.0, Qg=4.65
% INFO    : Gen at bus 615	: Vg=1.06611 -> Vg=1.0
% INFO    : Gen at bus 616	: Pg=379.2, Qg=41.62 -> Pg=320.0, Qg=68.37
% INFO    : Gen at bus 616	: Vg=1.049295 -> Vg=1.0
% INFO    : Gen at bus 618	: Pg=670.3, Qg=-35.39 -> Pg=533.335, Qg=106.035
% INFO    : Gen at bus 618	: Vg=1.028233 -> Vg=1.0
% INFO    : Gen at bus 628	: Pg=152.4, Qg=41.51 -> Pg=90.0, Qg=23.55
% INFO    : Gen at bus 628	: Vg=0.98494 -> Vg=1.0
% INFO    : Gen at bus 639	: Pg=-46.2, Qg=113.22 -> Pg=19.2, Qg=48.31
% INFO    : Gen at bus 639	: Vg=1.046182 -> Vg=1.0
% INFO    : Gen at bus 642	: Pg=63.33, Qg=-61.52 -> Pg=138.045, Qg=-1.45
% INFO    : Gen at bus 642	: Vg=1.036757 -> Vg=1.0
% INFO    : Gen at bus 682	: Pg=37.4, Qg=7.68 -> Pg=40.0, Qg=13.855
% INFO    : Gen at bus 682	: Vg=1.065269 -> Vg=1.0
% INFO    : Gen at bus 686	: Pg=-21.65, Qg=-10.17 -> Pg=35.57, Qg=0.245
% INFO    : Gen at bus 686	: Vg=1.018064 -> Vg=1.0
% INFO    : Gen at bus 698	: Pg=274.8, Qg=1.65 -> Pg=200.0, Qg=38.015
% INFO    : Gen at bus 698	: Vg=1.001541 -> Vg=1.0
% INFO    : Gen at bus 709	: Pg=16.0, Qg=-10.2 -> Pg=32.65, Qg=0.7
% INFO    : Gen at bus 709	: Vg=1.072146 -> Vg=1.0
% INFO    : Gen at bus 739	: Pg=465.7, Qg=-64.04 -> Pg=333.335, Qg=59.76
% INFO    : Gen at bus 739	: Vg=1.040583 -> Vg=1.0
% INFO    : Gen at bus 749	: Pg=198.88, Qg=4.46 -> Pg=120.0, Qg=30.925
% INFO    : Gen at bus 749	: Vg=1.0548 -> Vg=1.0
% INFO    : Gen at bus 751	: Pg=65.9, Qg=-25.62 -> Pg=150.0, Qg=44.85
% INFO    : Gen at bus 751	: Vg=1.023645 -> Vg=1.0
% INFO    : Gen at bus 757	: Pg=116.7, Qg=16.76 -> Pg=60.0, Qg=13.945
% INFO    : Gen at bus 757	: Vg=1.016623 -> Vg=1.0
% INFO    : Gen at bus 776	: Pg=-111.4, Qg=5.74 -> Pg=-24.265, Qg=5.715
% INFO    : Gen at bus 776	: Vg=1.029038 -> Vg=1.0
% INFO    : Gen at bus 778	: Pg=16.5, Qg=-0.5 -> Pg=16.79, Qg=1.505
% INFO    : Gen at bus 778	: Vg=1.051035 -> Vg=1.0
% INFO    : Gen at bus 780	: Pg=50.8, Qg=17.97 -> Pg=40.0, Qg=12.555
% INFO    : Gen at bus 780	: Vg=1.006139 -> Vg=1.0
% INFO    : Gen at bus 795	: Pg=58.4, Qg=7.49 -> Pg=40.0, Qg=11.855
% INFO    : Gen at bus 795	: Vg=1.039638 -> Vg=1.0
% INFO    : Gen at bus 803	: Pg=-89.2, Qg=2.65 -> Pg=-9.465, Qg=24.245
% INFO    : Gen at bus 803	: Vg=1.04396 -> Vg=1.0
% INFO    : Gen at bus 807	: Pg=1597.5, Qg=-194.05 -> Pg=1333.335, Qg=251.75
% INFO    : Gen at bus 807	: Vg=1.057043 -> Vg=1.0
% INFO    : Gen at bus 823	: Pg=1274.2, Qg=283.53 -> Pg=1333.335, Qg=314.185
% INFO    : Gen at bus 823	: Vg=1.044347 -> Vg=1.0
% INFO    : Gen at bus 849	: Pg=8.7, Qg=-0.02 -> Pg=8.785, Qg=0.77
% INFO    : Gen at bus 849	: Vg=1.041392 -> Vg=1.0
% INFO    : Gen at bus 851	: Pg=59.56, Qg=49.36 -> Pg=100.0, Qg=34.415
% INFO    : Gen at bus 851	: Vg=1.006263 -> Vg=1.0
% INFO    : Gen at bus 858	: Pg=855.6, Qg=161.18 -> Pg=666.665, Qg=134.26
% INFO    : Gen at bus 858	: Vg=1.035299 -> Vg=1.0
% INFO    : Gen at bus 891	: Pg=1702.8, Qg=646.56 -> Pg=1600.0, Qg=361.75
% INFO    : Gen at bus 891	: Vg=1.063198 -> Vg=1.0
% INFO    : Gen at bus 913	: Pg=1249.4, Qg=719.82 -> Pg=1133.335, Qg=251.085
% INFO    : Gen at bus 913	: Vg=1.032774 -> Vg=1.0
% INFO    : Gen at bus 916	: Pg=230.2, Qg=-26.12 -> Pg=150.0, Qg=42.345
% INFO    : Gen at bus 916	: Vg=1.024009 -> Vg=1.0
% INFO    : Gen at bus 930	: Pg=679.6, Qg=-118.4 -> Pg=600.0, Qg=130.955
% INFO    : Gen at bus 930	: Vg=1.063763 -> Vg=1.0
% INFO    : Gen at bus 972	: Pg=1221.2, Qg=397.48 -> Pg=1333.335, Qg=321.605
% INFO    : Gen at bus 972	: Vg=1.068998 -> Vg=1.0
% INFO    : Gen at bus 976	: Pg=21.3, Qg=-5.88 -> Pg=53.915, Qg=0.335
% INFO    : Gen at bus 976	: Vg=1.029847 -> Vg=1.0
% INFO    : Gen at bus 1001	: Pg=92.1, Qg=29.32 -> Pg=60.0, Qg=17.605
% INFO    : Gen at bus 1001	: Vg=1.073365 -> Vg=1.0
% INFO    : Gen at bus 1002	: Pg=171.0, Qg=15.98 -> Pg=100.0, Qg=27.2
% INFO    : Gen at bus 1002	: Vg=1.040649 -> Vg=1.0
% INFO    : Gen at bus 1021	: Pg=-179.3, Qg=3.66 -> Pg=-69.535, Qg=21.055
% INFO    : Gen at bus 1021	: Vg=1.019135 -> Vg=1.0
% INFO    : Gen at bus 1030	: Pg=164.94, Qg=7.29 -> Pg=250.0, Qg=21.885
% INFO    : Gen at bus 1030	: Vg=1.00979 -> Vg=1.0
% INFO    : Gen at bus 1036	: Pg=202.5, Qg=-1.53 -> Pg=200.0, Qg=45.47
% INFO    : Gen at bus 1036	: Vg=1.038657 -> Vg=1.0
% INFO    : Gen at bus 1043	: Pg=829.5, Qg=41.74 -> Pg=600.0, Qg=112.24
% INFO    : Gen at bus 1043	: Vg=1.029789 -> Vg=1.0
% INFO    : Gen at bus 1083	: Pg=91.8, Qg=10.7 -> Pg=60.0, Qg=17.515
% INFO    : Gen at bus 1083	: Vg=1.046149 -> Vg=1.0
% INFO    : Gen at bus 1093	: Pg=837.0, Qg=95.08 -> Pg=800.0, Qg=182.77
% INFO    : Gen at bus 1093	: Vg=1.026457 -> Vg=1.0
% INFO    : Gen at bus 1100	: Pg=58.2, Qg=5.03 -> Pg=40.0, Qg=11.895
% INFO    : Gen at bus 1100	: Vg=1.045212 -> Vg=1.0
% INFO    : Gen at bus 1102	: Pg=-124.15, Qg=12.77 -> Pg=-32.77, Qg=13.23
% INFO    : Gen at bus 1102	: Vg=1.051902 -> Vg=1.0
% INFO    : Gen at bus 1121	: Pg=289.79, Qg=-18.85 -> Pg=180.0, Qg=47.695
% INFO    : Gen at bus 1121	: Vg=1.019674 -> Vg=1.0
% INFO    : Gen at bus 1173	: Pg=-124.7, Qg=0.31 -> Pg=-33.135, Qg=0.485
% INFO    : Gen at bus 1173	: Vg=1.026125 -> Vg=1.0
% INFO    : Gen at bus 1174	: Pg=26.8, Qg=5.72 -> Pg=20.0, Qg=6.165
% INFO    : Gen at bus 1174	: Vg=1.004865 -> Vg=1.0
% INFO    : Gen at bus 1175	: Pg=309.54, Qg=-1.37 -> Pg=450.0, Qg=34.615
% INFO    : Gen at bus 1175	: Vg=1.040018 -> Vg=1.0
% INFO    : Gen at bus 1237	: Pg=1504.8, Qg=347.49 -> Pg=1333.335, Qg=293.585
% INFO    : Gen at bus 1237	: Vg=1.105045 -> Vg=1.0
% INFO    : Gen at bus 1241	: Pg=46.13, Qg=-14.82 -> Pg=32.815, Qg=0.655
% INFO    : Gen at bus 1241	: Vg=1.021438 -> Vg=1.0
% INFO    : Gen at bus 1251	: Pg=837.0, Qg=89.88 -> Pg=800.0, Qg=182.77
% INFO    : Gen at bus 1251	: Vg=1.0265 -> Vg=1.0
% INFO    : Gen at bus 1271	: Pg=-100.5, Qg=-12.52 -> Pg=-17.0, Qg=0.215
% INFO    : Gen at bus 1271	: Vg=1.015573 -> Vg=1.0
% INFO    : Gen at bus 1295	: Pg=-124.1, Qg=9.31 -> Pg=-32.735, Qg=12.02
% INFO    : Gen at bus 1295	: Vg=1.038943 -> Vg=1.0
% INFO    : Gen at bus 1341	: Pg=67.2, Qg=31.22 -> Pg=60.0, Qg=19.705
% INFO    : Gen at bus 1341	: Vg=1.030396 -> Vg=1.0
% INFO    : Gen at bus 1354	: Pg=-246.5, Qg=21.44 -> Pg=-114.335, Qg=13.175
% INFO    : Gen at bus 1354	: Vg=1.04168 -> Vg=1.0
% INFO    : Gen at bus 1391	: Pg=26.2, Qg=2.19 -> Pg=20.0, Qg=6.285
% INFO    : Gen at bus 1391	: Vg=1.028915 -> Vg=1.0
% INFO    : Gen at bus 1399	: Pg=-174.6, Qg=-2.47 -> Pg=-66.4, Qg=0.72
% INFO    : Gen at bus 1399	: Vg=1.052722 -> Vg=1.0
% INFO    : Gen at bus 1409	: Pg=628.19, Qg=-89.19 -> Pg=533.335, Qg=93.45
% INFO    : Gen at bus 1409	: Vg=1.024907 -> Vg=1.0
% INFO    : Gen at bus 1422	: Pg=-101.0, Qg=3.68 -> Pg=-17.335, Qg=5.65
% INFO    : Gen at bus 1422	: Vg=1.045292 -> Vg=1.0
% INFO    : Gen at bus 1436	: Pg=49.4, Qg=2.83 -> Pg=40.0, Qg=12.815
% INFO    : Gen at bus 1436	: Vg=1.049261 -> Vg=1.0
% INFO    : Gen at bus 1458	: Pg=1588.0, Qg=-288.24 -> Pg=1333.335, Qg=282.225
% INFO    : Gen at bus 1458	: Vg=1.05352 -> Vg=1.0
% INFO    : Gen at bus 1475	: Pg=783.9, Qg=-108.21 -> Pg=600.0, Qg=118.725
% INFO    : Gen at bus 1475	: Vg=1.025403 -> Vg=1.0
% INFO    : Gen at bus 1478	: Pg=62.6, Qg=7.21 -> Pg=40.0, Qg=11.48
% INFO    : Gen at bus 1478	: Vg=1.046165 -> Vg=1.0
% INFO    : Gen at bus 1498	: Pg=5.2, Qg=0.36 -> Pg=2.655, Qg=0.595
% INFO    : Gen at bus 1498	: Vg=1.078389 -> Vg=1.0
% INFO    : Gen at bus 1570	: Pg=121.4, Qg=-4.09 -> Pg=133.335, Qg=31.835
% INFO    : Gen at bus 1570	: Vg=1.079057 -> Vg=1.0
% INFO    : Gen at bus 1604	: Pg=50.6, Qg=14.56 -> Pg=40.0, Qg=12.745
% INFO    : Gen at bus 1604	: Vg=1.044277 -> Vg=1.0
% INFO    : Gen at bus 1618	: Pg=-136.6, Qg=-10.11 -> Pg=-41.065, Qg=0.6
% INFO    : Gen at bus 1618	: Vg=1.079319 -> Vg=1.0
% INFO    : Gen at bus 1642	: Pg=50.4, Qg=13.34 -> Pg=40.0, Qg=12.815
% INFO    : Gen at bus 1642	: Vg=1.031925 -> Vg=1.0
% INFO    : Gen at bus 1680	: Pg=1250.4, Qg=271.17 -> Pg=1333.335, Qg=316.395
% INFO    : Gen at bus 1680	: Vg=1.044209 -> Vg=1.0
% INFO    : Gen at bus 1685	: Pg=62.7, Qg=16.57 -> Pg=60.0, Qg=20.095
% INFO    : Gen at bus 1685	: Vg=1.005778 -> Vg=1.0
% INFO    : Gen at bus 1697	: Pg=-189.0, Qg=-12.59 -> Pg=-76.0, Qg=0.35
% INFO    : Gen at bus 1697	: Vg=1.041486 -> Vg=1.0
% INFO    : Gen at bus 1708	: Pg=860.8, Qg=132.37 -> Pg=666.665, Qg=133.035
% INFO    : Gen at bus 1708	: Vg=1.037844 -> Vg=1.0
% INFO    : Gen at bus 1721	: Pg=28.1, Qg=1.63 -> Pg=20.0, Qg=6.065
% INFO    : Gen at bus 1721	: Vg=1.061536 -> Vg=1.0
% INFO    : Gen at bus 1747	: Pg=835.5, Qg=271.39 -> Pg=600.0, Qg=111.97
% INFO    : Gen at bus 1747	: Vg=1.055274 -> Vg=1.0
% INFO    : Gen at bus 1754	: Pg=40.0, Qg=5.45 -> Pg=20.53, Qg=4.535
% INFO    : Gen at bus 1754	: Vg=1.040804 -> Vg=1.0
% INFO    : Gen at bus 1788	: Pg=430.2, Qg=252.54 -> Pg=400.0, Qg=88.665
% INFO    : Gen at bus 1788	: Vg=1.018729 -> Vg=1.0
% INFO    : Gen at bus 1793	: Pg=-90.3, Qg=-0.67 -> Pg=-10.2, Qg=9.72
% INFO    : Gen at bus 1793	: Vg=1.023406 -> Vg=1.0
% INFO    : Gen at bus 1794	: Pg=1250.4, Qg=248.88 -> Pg=1333.335, Qg=314.335
% INFO    : Gen at bus 1794	: Vg=1.052726 -> Vg=1.0
% INFO    : Gen at bus 1808	: Pg=-0.6, Qg=-6.42 -> Pg=49.6, Qg=36.535
% INFO    : Gen at bus 1808	: Vg=1.047818 -> Vg=1.0
% INFO    : Gen at bus 1850	: Pg=2.89, Qg=-1.45 -> Pg=16.485, Qg=0.715
% INFO    : Gen at bus 1850	: Vg=1.020156 -> Vg=1.0
% INFO    : Gen at bus 1851	: Pg=15.6, Qg=-0.75 -> Pg=15.96, Qg=1.435
% INFO    : Gen at bus 1851	: Vg=1.0492 -> Vg=1.0
% INFO    : Gen at bus 1852	: Pg=-241.8, Qg=15.7 -> Pg=-111.2, Qg=20.82
% INFO    : Gen at bus 1852	: Vg=1.056131 -> Vg=1.0
% INFO    : Gen at bus 1888	: Pg=573.68, Qg=43.66 -> Pg=612.78, Qg=120.095
% INFO    : Gen at bus 1888	: Vg=1.043102 -> Vg=1.0
% INFO    : Gen at bus 1890	: Pg=1526.0, Qg=129.25 -> Pg=1066.665, Qg=196.055
% INFO    : Gen at bus 1890	: Vg=1.050852 -> Vg=1.0
% INFO    : Gen at bus 1898	: Pg=246.0, Qg=-24.92 -> Pg=150.0, Qg=40.93
% INFO    : Gen at bus 1898	: Vg=1.077705 -> Vg=1.0
% INFO    : Gen at bus 1909	: Pg=-31.18, Qg=3.61 -> Pg=29.215, Qg=13.785
% INFO    : Gen at bus 1909	: Vg=1.021788 -> Vg=1.0
% INFO    : Gen at bus 1914	: Pg=115.5, Qg=-35.25 -> Pg=255.755, Qg=4.705
% INFO    : Gen at bus 1914	: Vg=1.038338 -> Vg=1.0
% INFO    : Gen at bus 1947	: Pg=-17.02, Qg=0.43 -> Pg=38.65, Qg=0.54
% INFO    : Gen at bus 1947	: Vg=1.056511 -> Vg=1.0
% INFO    : Gen at bus 1959	: Pg=31.0, Qg=1.06 -> Pg=20.0, Qg=5.695
% INFO    : Gen at bus 1959	: Vg=1.066953 -> Vg=1.0
% INFO    : Gen at bus 1999	: Pg=141.6, Qg=5.8 -> Pg=90.0, Qg=25.22
% INFO    : Gen at bus 1999	: Vg=1.080207 -> Vg=1.0
% INFO    : Gen at bus 2030	: Pg=576.0, Qg=167.94 -> Pg=400.0, Qg=73.075
% INFO    : Gen at bus 2030	: Vg=1.072679 -> Vg=1.0
% INFO    : Gen at bus 2035	: Pg=855.6, Qg=161.48 -> Pg=666.665, Qg=135.29
% INFO    : Gen at bus 2035	: Vg=1.034553 -> Vg=1.0
% INFO    : Gen at bus 2050	: Pg=836.2, Qg=-45.26 -> Pg=1333.335, Qg=349.275
% INFO    : Gen at bus 2050	: Vg=1.008592 -> Vg=1.0
% INFO    : Gen at bus 2085	: Pg=176.0, Qg=36.2 -> Pg=100.0, Qg=26.1
% INFO    : Gen at bus 2085	: Vg=1.03273 -> Vg=1.0
% INFO    : Gen at bus 2091	: Pg=33.9, Qg=1.74 -> Pg=20.0, Qg=5.42
% INFO    : Gen at bus 2091	: Vg=1.026543 -> Vg=1.0
% INFO    : Gen at bus 2096	: Pg=1063.5, Qg=-194.12 -> Pg=800.0, Qg=155.185
% INFO    : Gen at bus 2096	: Vg=1.050714 -> Vg=1.0
% INFO    : Gen at bus 2107	: Pg=1269.4, Qg=611.1 -> Pg=1000.0, Qg=202.14
% INFO    : Gen at bus 2107	: Vg=1.048234 -> Vg=1.0
% INFO    : Gen at bus 2150	: Pg=498.4, Qg=98.97 -> Pg=400.0, Qg=82.335
% INFO    : Gen at bus 2150	: Vg=1.064827 -> Vg=1.0
% INFO    : Gen at bus 2177	: Pg=-121.3, Qg=15.21 -> Pg=-30.865, Qg=21.045
% INFO    : Gen at bus 2177	: Vg=1.070558 -> Vg=1.0
% INFO    : Gen at bus 2193	: Pg=7.9, Qg=1.86 -> Pg=8.06, Qg=2.455
% INFO    : Gen at bus 2193	: Vg=1.014181 -> Vg=1.0
% INFO    : Gen at bus 2197	: Pg=-53.29, Qg=2.68 -> Pg=14.475, Qg=2.385
% INFO    : Gen at bus 2197	: Vg=1.036195 -> Vg=1.0
% INFO    : Gen at bus 2206	: Pg=204.3, Qg=24.03 -> Pg=200.0, Qg=45.355
% INFO    : Gen at bus 2206	: Vg=1.020141 -> Vg=1.0
% INFO    : Gen at bus 2225	: Pg=-83.5, Qg=0.41 -> Pg=-5.665, Qg=0.615
% INFO    : Gen at bus 2225	: Vg=1.02967 -> Vg=1.0
% INFO    : Gen at bus 2236	: Pg=-38.45, Qg=0.44 -> Pg=24.37, Qg=0.58
% INFO    : Gen at bus 2236	: Vg=1.023164 -> Vg=1.0
% INFO    : Gen at bus 2267	: Pg=362.0, Qg=147.75 -> Pg=333.335, Qg=74.665
% INFO    : Gen at bus 2267	: Vg=1.000857 -> Vg=1.0
% INFO    : Gen at bus 2276	: Pg=38.9, Qg=-22.76 -> Pg=59.65, Qg=2.585
% INFO    : Gen at bus 2276	: Vg=1.055141 -> Vg=1.0
% INFO    : Gen at bus 2291	: Pg=110.5, Qg=12.61 -> Pg=100.0, Qg=33.38
% INFO    : Gen at bus 2291	: Vg=1.068687 -> Vg=1.0
% INFO    : Gen at bus 2335	: Pg=431.2, Qg=242.01 -> Pg=400.0, Qg=89.695
% INFO    : Gen at bus 2335	: Vg=1.040978 -> Vg=1.0
% INFO    : Gen at bus 2359	: Pg=78.2, Qg=8.56 -> Pg=40.0, Qg=9.425
% INFO    : Gen at bus 2359	: Vg=1.025004 -> Vg=1.0
% INFO    : Gen at bus 2412	: Pg=67.3, Qg=-92.42 -> Pg=204.545, Qg=-0.875
% INFO    : Gen at bus 2412	: Vg=1.016849 -> Vg=1.0
% INFO    : Gen at bus 2421	: Pg=-320.4, Qg=10.06 -> Pg=-163.6, Qg=12.47
% INFO    : Gen at bus 2421	: Vg=1.047704 -> Vg=1.0
% INFO    : Gen at bus 2425	: Pg=-100.5, Qg=14.28 -> Pg=-17.0, Qg=16.905
% INFO    : Gen at bus 2425	: Vg=1.043025 -> Vg=1.0
% INFO    : Gen at bus 2426	: Pg=-43.2, Qg=-33.04 -> Pg=21.2, Qg=3.16
% INFO    : Gen at bus 2426	: Vg=1.040828 -> Vg=1.0
% INFO    : Gen at bus 2446	: Pg=1367.0, Qg=280.85 -> Pg=1333.335, Qg=308.445
% INFO    : Gen at bus 2446	: Vg=1.053565 -> Vg=1.0
% INFO    : Gen at bus 2460	: Pg=37.79, Qg=20.28 -> Pg=40.0, Qg=13.135
% INFO    : Gen at bus 2460	: Vg=0.983266 -> Vg=1.0
% INFO    : Gen at bus 2468	: Pg=46.8, Qg=4.68 -> Pg=40.0, Qg=13.105
% INFO    : Gen at bus 2468	: Vg=1.049474 -> Vg=1.0
% INFO    : Gen at bus 2481	: Pg=31.8, Qg=11.07 -> Pg=40.0, Qg=14.205
% INFO    : Gen at bus 2481	: Vg=1.041748 -> Vg=1.0
% INFO    : Gen at bus 2489	: Pg=286.5, Qg=-17.67 -> Pg=180.0, Qg=50.305
% INFO    : Gen at bus 2489	: Vg=1.049212 -> Vg=1.0
% INFO    : Gen at bus 2517	: Pg=3.85, Qg=-14.82 -> Pg=117.26, Qg=0.53
% INFO    : Gen at bus 2517	: Vg=1.017237 -> Vg=1.0
% INFO    : Gen at bus 2550	: Pg=54.3, Qg=3.25 -> Pg=60.0, Qg=20.87
% INFO    : Gen at bus 2550	: Vg=1.050935 -> Vg=1.0
% INFO    : Gen at bus 2572	: Pg=411.2, Qg=80.01 -> Pg=400.0, Qg=92.28
% INFO    : Gen at bus 2572	: Vg=1.044905 -> Vg=1.0
% INFO    : Gen at bus 2600	: Pg=76.48, Qg=15.74 -> Pg=80.0, Qg=26.245
% INFO    : Gen at bus 2600	: Vg=1.041924 -> Vg=1.0
% INFO    : Gen at bus 2627	: Pg=1367.0, Qg=289.47 -> Pg=1333.335, Qg=308.365
% INFO    : Gen at bus 2627	: Vg=1.052984 -> Vg=1.0
% INFO    : Gen at bus 2642	: Pg=1897.0, Qg=-254.15 -> Pg=1333.335, Qg=235.545
% INFO    : Gen at bus 2642	: Vg=1.054923 -> Vg=1.0
% INFO    : Gen at bus 2653	: Pg=41.92, Qg=10.03 -> Pg=60.0, Qg=14.57
% INFO    : Gen at bus 2653	: Vg=1.036409 -> Vg=1.0
% INFO    : Gen at bus 2658	: Pg=308.31, Qg=-21.53 -> Pg=450.0, Qg=32.645
% INFO    : Gen at bus 2658	: Vg=1.026597 -> Vg=1.0
% INFO    : Gen at bus 2660	: Pg=144.9, Qg=12.3 -> Pg=90.0, Qg=24.46
% INFO    : Gen at bus 2660	: Vg=1.013897 -> Vg=1.0
% INFO    : Gen at bus 2686	: Pg=-72.9, Qg=-46.07 -> Pg=1.4, Qg=-0.445
% INFO    : Gen at bus 2686	: Vg=1.020441 -> Vg=1.0
% INFO    : Gen at bus 2719	: Pg=77.6, Qg=-16.82 -> Pg=98.36, Qg=6.025
% INFO    : Gen at bus 2719	: Vg=1.039499 -> Vg=1.0
% INFO    : Gen at bus 2764	: Pg=575.4, Qg=-114.34 -> Pg=600.0, Qg=141.1
% INFO    : Gen at bus 2764	: Vg=1.05096 -> Vg=1.0
% INFO    : Gen at bus 2786	: Pg=1221.2, Qg=379.25 -> Pg=1333.335, Qg=321.67
% INFO    : Gen at bus 2786	: Vg=1.069288 -> Vg=1.0
% INFO    : Gen at bus 2797	: Pg=-95.1, Qg=-2.82 -> Pg=-13.4, Qg=26.0
% INFO    : Gen at bus 2797	: Vg=1.044662 -> Vg=1.0
% INFO    : Gen at bus 2799	: Pg=66.8, Qg=-1.37 -> Pg=80.0, Qg=28.125
% INFO    : Gen at bus 2799	: Vg=1.055463 -> Vg=1.0
% INFO    : Gen at bus 2800	: Pg=1048.2, Qg=-98.17 -> Pg=800.0, Qg=157.75
% INFO    : Gen at bus 2800	: Vg=1.030206 -> Vg=1.0
% INFO    : Gen at bus 2816	: Pg=1250.4, Qg=280.3 -> Pg=1333.335, Qg=314.26
% INFO    : Gen at bus 2816	: Vg=1.054536 -> Vg=1.0
% INFO    : Gen at bus 2817	: Pg=71.8, Qg=4.24 -> Pg=40.0, Qg=9.93
% INFO    : Gen at bus 2817	: Vg=0.991705 -> Vg=1.0
% INFO    : Gen at bus 2841	: Pg=80.7, Qg=-3.32 -> Pg=60.0, Qg=18.61
% INFO    : Gen at bus 2841	: Vg=1.079986 -> Vg=1.0
% INFO    : Gen at bus 2842	: Pg=31.6, Qg=6.06 -> Pg=20.0, Qg=5.725
% INFO    : Gen at bus 2842	: Vg=1.044122 -> Vg=1.0
% INFO    : Gen at bus 2853	: Pg=126.0, Qg=10.21 -> Pg=80.0, Qg=22.275
% INFO    : Gen at bus 2853	: Vg=1.000604 -> Vg=1.0
% INFO    : Gen at bus 2872	: Pg=4.5, Qg=0.35 -> Pg=4.525, Qg=0.385
% INFO    : Gen at bus 2872	: Vg=1.060615 -> Vg=1.0
% INFO    : Gen at bus 2878	: Pg=8.95, Qg=-12.23 -> Pg=107.43, Qg=2.12
% INFO    : Gen at bus 2878	: Vg=1.05418 -> Vg=1.0
% INFO    : Gen at bus 2886	: Pg=60.9, Qg=10.13 -> Pg=60.0, Qg=20.335
% INFO    : Gen at bus 2886	: Vg=1.052878 -> Vg=1.0
% INFO    : Gen at bus 2896	: Pg=-223.4, Qg=0.31 -> Pg=-98.935, Qg=0.395
% INFO    : Gen at bus 2896	: Vg=1.011629 -> Vg=1.0
% INFO    : Gen at bus 2902	: Pg=20.9, Qg=1.52 -> Pg=20.0, Qg=6.735
% INFO    : Gen at bus 2902	: Vg=1.061022 -> Vg=1.0
% INFO    : Gen at bus 2930	: Pg=53.2, Qg=2.38 -> Pg=40.0, Qg=12.35
% INFO    : Gen at bus 2930	: Vg=1.049271 -> Vg=1.0
% INFO    : Gen at bus 2934	: Pg=3.4, Qg=0.17 -> Pg=3.415, Qg=0.3
% INFO    : Gen at bus 2934	: Vg=1.052968 -> Vg=1.0
% INFO    : Gen at bus 2946	: Pg=-222.1, Qg=0.29 -> Pg=-98.065, Qg=0.48
% INFO    : Gen at bus 2946	: Vg=1.020023 -> Vg=1.0
% INFO    : Gen at bus 2985	: Pg=46.6, Qg=-70.17 -> Pg=246.675, Qg=25.895
% INFO    : Gen at bus 2985	: Vg=1.05077 -> Vg=1.0
% INFO    : Gen at bus 3018	: Pg=162.5, Qg=-4.96 -> Pg=100.0, Qg=27.395
% INFO    : Gen at bus 3018	: Vg=1.043371 -> Vg=1.0
% INFO    : Gen at bus 3028	: Pg=855.7, Qg=158.53 -> Pg=666.665, Qg=135.29
% INFO    : Gen at bus 3028	: Vg=1.034318 -> Vg=1.0
% INFO    : Gen at bus 3054	: Pg=210.4, Qg=123.54 -> Pg=266.665, Qg=45.305
% INFO    : Gen at bus 3054	: Vg=0.999852 -> Vg=1.0
% INFO    : Gen at bus 3113	: Pg=-20.3, Qg=-10.92 -> Pg=36.465, Qg=0.7
% INFO    : Gen at bus 3113	: Vg=1.072644 -> Vg=1.0
% INFO    : Gen at bus 3114	: Pg=38.6, Qg=3.91 -> Pg=20.0, Qg=4.86
% INFO    : Gen at bus 3114	: Vg=1.0681 -> Vg=1.0
% INFO    : Gen at bus 3133	: Pg=85.54, Qg=-1.1 -> Pg=120.0, Qg=39.205
% INFO    : Gen at bus 3133	: Vg=1.061763 -> Vg=1.0
% INFO    : Gen at bus 3134	: Pg=-136.3, Qg=-10.75 -> Pg=-40.865, Qg=20.46
% INFO    : Gen at bus 3134	: Vg=1.02503 -> Vg=1.0
% INFO    : Gen at bus 3150	: Pg=-31.34, Qg=0.57 -> Pg=29.105, Qg=0.78
% INFO    : Gen at bus 3150	: Vg=1.017094 -> Vg=1.0
% INFO    : Gen at bus 3157	: Pg=9.0, Qg=-0.09 -> Pg=9.205, Qg=0.825
% INFO    : Gen at bus 3157	: Vg=1.023658 -> Vg=1.0
% INFO    : Gen at bus 3163	: Pg=33.9, Qg=-29.77 -> Pg=103.43, Qg=-0.55
% INFO    : Gen at bus 3163	: Vg=1.006379 -> Vg=1.0
% INFO    : Gen at bus 3183	: Pg=98.7, Qg=-3.82 -> Pg=60.0, Qg=16.36
% INFO    : Gen at bus 3183	: Vg=1.056991 -> Vg=1.0
% INFO    : Gen at bus 3205	: Pg=416.7, Qg=108.62 -> Pg=270.0, Qg=77.575
% INFO    : Gen at bus 3205	: Vg=1.03763 -> Vg=1.0
% INFO    : Gen at bus 3218	: Pg=-107.4, Qg=9.03 -> Pg=-21.6, Qg=11.895
% INFO    : Gen at bus 3218	: Vg=1.032146 -> Vg=1.0
% INFO    : Gen at bus 3233	: Pg=13.0, Qg=-7.58 -> Pg=210.0, Qg=49.68
% INFO    : Gen at bus 3233	: Vg=1.012423 -> Vg=1.0
% INFO    : Gen at bus 3240	: Pg=-42.3, Qg=-24.84 -> Pg=21.8, Qg=5.43
% INFO    : Gen at bus 3240	: Vg=1.051571 -> Vg=1.0
% INFO    : Gen at bus 3291	: Pg=326.4, Qg=-17.26 -> Pg=333.335, Qg=75.99
% INFO    : Gen at bus 3291	: Vg=1.027251 -> Vg=1.0
% INFO    : Gen at bus 3306	: Pg=861.3, Qg=134.8 -> Pg=666.665, Qg=132.885
% INFO    : Gen at bus 3306	: Vg=1.069265 -> Vg=1.0
% INFO    : Gen at bus 3324	: Pg=-26.48, Qg=16.92 -> Pg=32.35, Qg=13.245
% INFO    : Gen at bus 3324	: Vg=1.016523 -> Vg=1.0
% INFO    : Gen at bus 3334	: Pg=-45.5, Qg=3.24 -> Pg=19.665, Qg=9.535
% INFO    : Gen at bus 3334	: Vg=1.03247 -> Vg=1.0
% INFO    : Gen at bus 3335	: Pg=-600.0, Qg=2045.7 -> Pg=0.0, Qg=0.0
% INFO    : Gen at bus 3335	: Vg=1.08873 -> Vg=1.0
% INFO    : Gen at bus 3346	: Pg=56.8, Qg=12.86 -> Pg=40.0, Qg=12.17
% INFO    : Gen at bus 3346	: Vg=1.014746 -> Vg=1.0
% INFO    : Gen at bus 3353	: Pg=19.07, Qg=6.07 -> Pg=40.0, Qg=13.295
% INFO    : Gen at bus 3353	: Vg=1.047796 -> Vg=1.0
% INFO    : Gen at bus 3364	: Pg=44.5, Qg=-22.17 -> Pg=67.635, Qg=2.875
% INFO    : Gen at bus 3364	: Vg=1.055303 -> Vg=1.0
% INFO    : Gen at bus 3390	: Pg=2.4, Qg=21.5 -> Pg=60.0, Qg=17.2
% INFO    : Gen at bus 3390	: Vg=1.041678 -> Vg=1.0
% INFO    : Gen at bus 3416	: Pg=171.3, Qg=38.2 -> Pg=90.0, Qg=21.155
% INFO    : Gen at bus 3416	: Vg=0.997085 -> Vg=1.0
% INFO    : Gen at bus 3422	: Pg=53.7, Qg=-2.9 -> Pg=60.0, Qg=20.845
% INFO    : Gen at bus 3422	: Vg=1.065868 -> Vg=1.0
% INFO    : Gen at bus 3436	: Pg=521.0, Qg=207.76 -> Pg=800.0, Qg=183.04
% INFO    : Gen at bus 3436	: Vg=1.056276 -> Vg=1.0
% INFO    : Gen at bus 3492	: Pg=-370.8, Qg=6.56 -> Pg=-197.2, Qg=16.335
% INFO    : Gen at bus 3492	: Vg=1.04519 -> Vg=1.0
% INFO    : Gen at bus 3513	: Pg=829.8, Qg=43.52 -> Pg=600.0, Qg=112.24
% INFO    : Gen at bus 3513	: Vg=1.029628 -> Vg=1.0
% INFO    : Gen at bus 3565	: Pg=15.88, Qg=2.99 -> Pg=40.0, Qg=13.93
% INFO    : Gen at bus 3565	: Vg=1.079121 -> Vg=1.0
% INFO    : Gen at bus 3580	: Pg=539.0, Qg=187.63 -> Pg=300.0, Qg=77.17
% INFO    : Gen at bus 3580	: Vg=1.075232 -> Vg=1.0
% INFO    : Gen at bus 3582	: Pg=-321.8, Qg=-36.63 -> Pg=-164.535, Qg=0.395
% INFO    : Gen at bus 3582	: Vg=1.045127 -> Vg=1.0
% INFO    : Gen at bus 3584	: Pg=-88.4, Qg=-1.9 -> Pg=-8.935, Qg=2.34
% INFO    : Gen at bus 3584	: Vg=1.019651 -> Vg=1.0
% INFO    : Gen at bus 3585	: Pg=50.8, Qg=17.99 -> Pg=40.0, Qg=12.555
% INFO    : Gen at bus 3585	: Vg=1.006097 -> Vg=1.0
% INFO    : Gen at bus 3611	: Pg=-125.4, Qg=7.89 -> Pg=-33.6, Qg=17.235
% INFO    : Gen at bus 3611	: Vg=1.03827 -> Vg=1.0
% INFO    : Gen at bus 3621	: Pg=202.03, Qg=-32.82 -> Pg=150.0, Qg=37.985
% INFO    : Gen at bus 3621	: Vg=1.023915 -> Vg=1.0
% INFO    : Gen at bus 3629	: Pg=54.97, Qg=1.75 -> Pg=80.0, Qg=27.105
% INFO    : Gen at bus 3629	: Vg=1.020807 -> Vg=1.0
% INFO    : Gen at bus 3644	: Pg=16.4, Qg=-6.77 -> Pg=33.045, Qg=0.565
% INFO    : Gen at bus 3644	: Vg=1.018948 -> Vg=1.0
% INFO    : Gen at bus 3656	: Pg=-26.2, Qg=13.18 -> Pg=32.535, Qg=41.375
% INFO    : Gen at bus 3656	: Vg=1.067132 -> Vg=1.0
% INFO    : Gen at bus 3659	: Pg=1097.4, Qg=862.06 -> Pg=1333.335, Qg=330.815
% INFO    : Gen at bus 3659	: Vg=1.065964 -> Vg=1.0
% INFO    : Gen at bus 3661	: Pg=861.2, Qg=129.38 -> Pg=666.665, Qg=134.495
% INFO    : Gen at bus 3661	: Vg=1.059844 -> Vg=1.0
% INFO    : Gen at bus 3673	: Pg=424.5, Qg=-84.67 -> Pg=400.0, Qg=73.59
% INFO    : Gen at bus 3673	: Vg=1.013624 -> Vg=1.0
% INFO    : Gen at bus 3689	: Pg=5.2, Qg=0.41 -> Pg=3.1, Qg=0.565
% INFO    : Gen at bus 3689	: Vg=1.032178 -> Vg=1.0
% INFO    : Gen at bus 3691	: Pg=239.6, Qg=48.92 -> Pg=200.0, Qg=41.975
% INFO    : Gen at bus 3691	: Vg=1.030169 -> Vg=1.0
% INFO    : Gen at bus 3692	: Pg=164.4, Qg=-53.69 -> Pg=210.0, Qg=51.135
% INFO    : Gen at bus 3692	: Vg=1.025431 -> Vg=1.0
% INFO    : Gen at bus 3698	: Pg=-12.58, Qg=5.71 -> Pg=41.61, Qg=11.435
% INFO    : Gen at bus 3698	: Vg=1.041028 -> Vg=1.0
% INFO    : Gen at bus 3711	: Pg=40.4, Qg=12.69 -> Pg=40.0, Qg=13.49
% INFO    : Gen at bus 3711	: Vg=1.00126 -> Vg=1.0
% INFO    : Gen at bus 3723	: Pg=1146.3, Qg=67.92 -> Pg=800.0, Qg=146.21
% INFO    : Gen at bus 3723	: Vg=1.062798 -> Vg=1.0
% INFO    : Gen at bus 3741	: Pg=854.7, Qg=206.11 -> Pg=800.0, Qg=180.705
% INFO    : Gen at bus 3741	: Vg=1.035379 -> Vg=1.0
% INFO    : Gen at bus 3791	: Pg=90.6, Qg=18.06 -> Pg=60.0, Qg=17.365
% INFO    : Gen at bus 3791	: Vg=0.997709 -> Vg=1.0
% INFO    : Gen at bus 3792	: Pg=85.4, Qg=-26.48 -> Pg=120.0, Qg=33.405
% INFO    : Gen at bus 3792	: Vg=1.058708 -> Vg=1.0
% INFO    : Gen at bus 3809	: Pg=257.0, Qg=129.92 -> Pg=466.665, Qg=98.14
% INFO    : Gen at bus 3809	: Vg=1.084761 -> Vg=1.0
% INFO    : Gen at bus 3821	: Pg=292.0, Qg=-39.5 -> Pg=266.665, Qg=43.295
% INFO    : Gen at bus 3821	: Vg=1.029497 -> Vg=1.0
% INFO    : Gen at bus 3825	: Pg=837.3, Qg=64.59 -> Pg=600.0, Qg=112.385
% INFO    : Gen at bus 3825	: Vg=1.026381 -> Vg=1.0
% INFO    : Gen at bus 3840	: Pg=-22.95, Qg=-16.27 -> Pg=34.7, Qg=0.435
% INFO    : Gen at bus 3840	: Vg=1.030834 -> Vg=1.0
% INFO    : Gen at bus 3869	: Pg=855.6, Qg=161.13 -> Pg=666.665, Qg=134.275
% INFO    : Gen at bus 3869	: Vg=1.035477 -> Vg=1.0
% INFO    : Gen at bus 3876	: Pg=-25.1, Qg=16.55 -> Pg=33.265, Qg=9.375
% INFO    : Gen at bus 3876	: Vg=1.046886 -> Vg=1.0
% INFO    : Gen at bus 3916	: Pg=-21.27, Qg=16.17 -> Pg=35.815, Qg=13.125
% INFO    : Gen at bus 3916	: Vg=1.044945 -> Vg=1.0
% INFO    : Gen at bus 3951	: Pg=-27.1, Qg=-74.17 -> Pg=31.935, Qg=-0.7
% INFO    : Gen at bus 3951	: Vg=1.029014 -> Vg=1.0
% INFO    : Gen at bus 3971	: Pg=-134.5, Qg=15.75 -> Pg=-39.665, Qg=18.29
% INFO    : Gen at bus 3971	: Vg=1.060173 -> Vg=1.0
% INFO    : Gen at bus 3983	: Pg=229.9, Qg=11.5 -> Pg=200.0, Qg=43.115
% INFO    : Gen at bus 3983	: Vg=1.012943 -> Vg=1.0
% INFO    : Gen at bus 3987	: Pg=44.6, Qg=7.31 -> Pg=40.0, Qg=13.165
% INFO    : Gen at bus 3987	: Vg=1.021034 -> Vg=1.0
% INFO    : Gen at bus 4016	: Pg=109.2, Qg=-3.77 -> Pg=60.0, Qg=14.905
% INFO    : Gen at bus 4016	: Vg=1.026951 -> Vg=1.0
% INFO    : Gen at bus 4024	: Pg=89.5, Qg=44.88 -> Pg=100.0, Qg=34.815
% INFO    : Gen at bus 4024	: Vg=1.032708 -> Vg=1.0
% INFO    : Gen at bus 4026	: Pg=399.3, Qg=-17.62 -> Pg=333.335, Qg=69.685
% INFO    : Gen at bus 4026	: Vg=1.05962 -> Vg=1.0
% INFO    : Gen at bus 4056	: Pg=-76.9, Qg=8.25 -> Pg=-1.265, Qg=13.14
% INFO    : Gen at bus 4056	: Vg=1.042513 -> Vg=1.0
% INFO    : Gen at bus 4084	: Pg=366.1, Qg=46.85 -> Pg=300.0, Qg=80.6
% INFO    : Gen at bus 4084	: Vg=1.060214 -> Vg=1.0
% INFO    : Gen at bus 4118	: Pg=41.0, Qg=4.36 -> Pg=40.0, Qg=13.485
% INFO    : Gen at bus 4118	: Vg=1.029072 -> Vg=1.0
% INFO    : Gen at bus 4125	: Pg=59.6, Qg=18.23 -> Pg=40.0, Qg=11.945
% INFO    : Gen at bus 4125	: Vg=0.999283 -> Vg=1.0
% INFO    : Gen at bus 4128	: Pg=67.5, Qg=24.85 -> Pg=60.0, Qg=19.7
% INFO    : Gen at bus 4128	: Vg=1.023094 -> Vg=1.0
% INFO    : Gen at bus 4182	: Pg=710.7, Qg=-68.75 -> Pg=533.335, Qg=99.42
% INFO    : Gen at bus 4182	: Vg=1.016453 -> Vg=1.0
% INFO    : Gen at bus 4192	: Pg=767.4, Qg=310.02 -> Pg=600.0, Qg=120.695
% INFO    : Gen at bus 4192	: Vg=1.077662 -> Vg=1.0
% INFO    : Gen at bus 4204	: Pg=-48.16, Qg=0.36 -> Pg=17.895, Qg=0.49
% INFO    : Gen at bus 4204	: Vg=1.017661 -> Vg=1.0
% INFO    : Gen at bus 4231	: Pg=2641.24, Qg=819.49 -> Pg=2761.14, Qg=0.0
% INFO    : Gen at bus 4231	: Vg=1.050918 -> Vg=1.0
% INFO    : Gen at bus 4259	: Pg=28.0, Qg=6.24 -> Pg=20.0, Qg=5.98
% INFO    : Gen at bus 4259	: Vg=1.013671 -> Vg=1.0
% INFO    : Gen at bus 4279	: Pg=515.39, Qg=-71.15 -> Pg=400.0, Qg=77.605
% INFO    : Gen at bus 4279	: Vg=1.01711 -> Vg=1.0
% INFO    : Gen at bus 4291	: Pg=251.0, Qg=-30.61 -> Pg=210.0, Qg=67.1
% INFO    : Gen at bus 4291	: Vg=1.02141 -> Vg=1.0
% INFO    : Gen at bus 4331	: Pg=60.2, Qg=6.39 -> Pg=40.0, Qg=11.805
% INFO    : Gen at bus 4331	: Vg=1.032206 -> Vg=1.0
% INFO    : Gen at bus 4333	: Pg=152.4, Qg=4.96 -> Pg=90.0, Qg=23.82
% INFO    : Gen at bus 4333	: Vg=0.999193 -> Vg=1.0
% INFO    : Gen at bus 4337	: Pg=1334.3, Qg=544.16 -> Pg=1750.0, Qg=209.295
% INFO    : Gen at bus 4337	: Vg=1.010847 -> Vg=1.0
% INFO    : Gen at bus 4338	: Pg=-52.5, Qg=4.46 -> Pg=15.0, Qg=4.48
% INFO    : Gen at bus 4338	: Vg=1.024208 -> Vg=1.0
% INFO    : Gen at bus 4393	: Pg=115.36, Qg=-20.0 -> Pg=200.0, Qg=50.065
% INFO    : Gen at bus 4393	: Vg=1.066547 -> Vg=1.0
% INFO    : Gen at bus 4395	: Pg=-129.1, Qg=12.79 -> Pg=-36.065, Qg=13.575
% INFO    : Gen at bus 4395	: Vg=1.039119 -> Vg=1.0
% INFO    : Gen at bus 4419	: Pg=861.3, Qg=131.97 -> Pg=666.665, Qg=134.495
% INFO    : Gen at bus 4419	: Vg=1.059728 -> Vg=1.0
% INFO    : Gen at bus 4428	: Pg=14.7, Qg=-5.61 -> Pg=30.12, Qg=0.625
% INFO    : Gen at bus 4428	: Vg=1.019796 -> Vg=1.0
% INFO    : Gen at bus 4442	: Pg=-11.23, Qg=-12.54 -> Pg=42.51, Qg=0.345
% INFO    : Gen at bus 4442	: Vg=1.036687 -> Vg=1.0
% INFO    : Gen at bus 4480	: Pg=861.3, Qg=136.04 -> Pg=666.665, Qg=132.885
% INFO    : Gen at bus 4480	: Vg=1.069297 -> Vg=1.0
% INFO    : Gen at bus 4482	: Pg=35.2, Qg=14.05 -> Pg=40.0, Qg=13.95
% INFO    : Gen at bus 4482	: Vg=1.05005 -> Vg=1.0
% INFO    : Gen at bus 4506	: Pg=-171.8, Qg=22.11 -> Pg=-64.535, Qg=12.955
% INFO    : Gen at bus 4506	: Vg=1.040247 -> Vg=1.0
% INFO    : Gen at bus 4566	: Pg=-30.39, Qg=8.95 -> Pg=29.745, Qg=13.035
% INFO    : Gen at bus 4566	: Vg=1.073131 -> Vg=1.0
% INFO    : Gen at bus 4586	: Pg=-545.7, Qg=56.41 -> Pg=-313.8, Qg=31.575
% INFO    : Gen at bus 4586	: Vg=1.042233 -> Vg=1.0
% INFO    : Gen at bus 4624	: Pg=68.0, Qg=8.43 -> Pg=40.0, Qg=10.715
% INFO    : Gen at bus 4624	: Vg=1.039942 -> Vg=1.0
% INFO    : Gen at bus 4657	: Pg=101.62, Qg=2.77 -> Pg=150.0, Qg=48.835
% INFO    : Gen at bus 4657	: Vg=1.022686 -> Vg=1.0
% INFO    : Gen at bus 4661	: Pg=-78.9, Qg=3.81 -> Pg=-2.6, Qg=6.685
% INFO    : Gen at bus 4661	: Vg=1.051599 -> Vg=1.0
% INFO    : Gen at bus 4663	: Pg=-116.0, Qg=0.12 -> Pg=-27.335, Qg=17.72
% INFO    : Gen at bus 4663	: Vg=1.028053 -> Vg=1.0
% INFO    : Gen at bus 4690	: Pg=541.0, Qg=15.43 -> Pg=600.0, Qg=142.755
% INFO    : Gen at bus 4690	: Vg=1.033192 -> Vg=1.0
% INFO    : Gen at bus 4701	: Pg=93.2, Qg=-37.45 -> Pg=140.925, Qg=6.055
% INFO    : Gen at bus 4701	: Vg=1.044876 -> Vg=1.0
% INFO    : Gen at bus 4772	: Pg=78.0, Qg=-17.24 -> Pg=100.0, Qg=27.28
% INFO    : Gen at bus 4772	: Vg=1.027623 -> Vg=1.0
% INFO    : Gen at bus 4773	: Pg=16.0, Qg=-5.4 -> Pg=32.65, Qg=0.625
% INFO    : Gen at bus 4773	: Vg=1.020563 -> Vg=1.0
% INFO    : Gen at bus 4776	: Pg=805.5, Qg=144.16 -> Pg=600.0, Qg=114.335
% INFO    : Gen at bus 4776	: Vg=1.068296 -> Vg=1.0
% INFO    : Gen at bus 4783	: Pg=861.3, Qg=133.49 -> Pg=666.665, Qg=132.885
% INFO    : Gen at bus 4783	: Vg=1.069324 -> Vg=1.0
% INFO    : Gen at bus 4816	: Pg=-26.08, Qg=13.8 -> Pg=32.615, Qg=13.465
% INFO    : Gen at bus 4816	: Vg=1.062911 -> Vg=1.0
% INFO    : Gen at bus 4819	: Pg=855.6, Qg=162.5 -> Pg=666.665, Qg=134.275
% INFO    : Gen at bus 4819	: Vg=1.035474 -> Vg=1.0
% INFO    : Gen at bus 4823	: Pg=10.3, Qg=1.34 -> Pg=5.23, Qg=1.185
% INFO    : Gen at bus 4823	: Vg=1.06272 -> Vg=1.0
% INFO    : Gen at bus 4843	: Pg=6.8, Qg=-0.2 -> Pg=6.815, Qg=0.595
% INFO    : Gen at bus 4843	: Vg=1.053038 -> Vg=1.0
% INFO    : Gen at bus 4846	: Pg=239.6, Qg=48.9 -> Pg=200.0, Qg=41.975
% INFO    : Gen at bus 4846	: Vg=1.030285 -> Vg=1.0
% INFO    : Gen at bus 4850	: Pg=88.8, Qg=11.28 -> Pg=80.0, Qg=26.665
% INFO    : Gen at bus 4850	: Vg=1.052648 -> Vg=1.0
% INFO    : Gen at bus 4880	: Pg=-40.3, Qg=7.65 -> Pg=23.135, Qg=25.83
% INFO    : Gen at bus 4880	: Vg=1.03955 -> Vg=1.0
% INFO    : Gen at bus 4897	: Pg=18.56, Qg=4.81 -> Pg=40.0, Qg=12.675
% INFO    : Gen at bus 4897	: Vg=1.018589 -> Vg=1.0
% INFO    : Gen at bus 4918	: Pg=41.69, Qg=10.15 -> Pg=40.0, Qg=12.35
% INFO    : Gen at bus 4918	: Vg=1.059135 -> Vg=1.0
% INFO    : Gen at bus 4931	: Pg=20.2, Qg=-17.48 -> Pg=51.395, Qg=0.375
% INFO    : Gen at bus 4931	: Vg=1.040167 -> Vg=1.0
% INFO    : Gen at bus 4945	: Pg=385.4, Qg=-33.86 -> Pg=333.335, Qg=71.09
% INFO    : Gen at bus 4945	: Vg=1.059702 -> Vg=1.0
% INFO    : Gen at bus 4952	: Pg=-12.57, Qg=7.48 -> Pg=41.615, Qg=12.31
% INFO    : Gen at bus 4952	: Vg=1.044318 -> Vg=1.0
% INFO    : Gen at bus 4954	: Pg=40.84, Qg=0.35 -> Pg=60.0, Qg=17.1
% INFO    : Gen at bus 4954	: Vg=1.019681 -> Vg=1.0
% INFO    : Gen at bus 4957	: Pg=961.0, Qg=-177.26 -> Pg=800.0, Qg=166.135
% INFO    : Gen at bus 4957	: Vg=1.048836 -> Vg=1.0
% INFO    : Gen at bus 4967	: Pg=83.2, Qg=-17.25 -> Pg=210.0, Qg=53.185
% INFO    : Gen at bus 4967	: Vg=1.023151 -> Vg=1.0
% INFO    : Gen at bus 5004	: Pg=54.3, Qg=3.31 -> Pg=110.06, Qg=2.16
% INFO    : Gen at bus 5004	: Vg=1.061776 -> Vg=1.0
% INFO    : Gen at bus 5019	: Pg=49.4, Qg=2.83 -> Pg=40.0, Qg=12.815
% INFO    : Gen at bus 5019	: Vg=1.04927 -> Vg=1.0
% INFO    : Gen at bus 5025	: Pg=-155.1, Qg=0.45 -> Pg=-53.4, Qg=0.675
% INFO    : Gen at bus 5025	: Vg=1.006979 -> Vg=1.0
% INFO    : Gen at bus 5051	: Pg=83.48, Qg=-0.85 -> Pg=80.0, Qg=24.79
% INFO    : Gen at bus 5051	: Vg=1.039098 -> Vg=1.0
% INFO    : Gen at bus 5060	: Pg=13.3, Qg=-4.4 -> Pg=20.34, Qg=0.895
% INFO    : Gen at bus 5060	: Vg=1.067508 -> Vg=1.0
% INFO    : Gen at bus 5065	: Pg=1008.3, Qg=199.74 -> Pg=800.0, Qg=164.885
% INFO    : Gen at bus 5065	: Vg=1.072972 -> Vg=1.0
% INFO    : Gen at bus 5067	: Pg=542.0, Qg=129.85 -> Pg=300.0, Qg=74.665
% INFO    : Gen at bus 5067	: Vg=1.021364 -> Vg=1.0
% INFO    : Gen at bus 5091	: Pg=276.42, Qg=-51.56 -> Pg=180.0, Qg=41.28
% INFO    : Gen at bus 5091	: Vg=1.054352 -> Vg=1.0
% INFO    : Gen at bus 5097	: Pg=21.1, Qg=2.24 -> Pg=14.155, Qg=2.4
% INFO    : Gen at bus 5097	: Vg=1.059554 -> Vg=1.0
% INFO    : Gen at bus 5110	: Pg=-52.51, Qg=11.13 -> Pg=14.995, Qg=13.39
% INFO    : Gen at bus 5110	: Vg=1.034874 -> Vg=1.0
% INFO    : Gen at bus 5120	: Pg=75.6, Qg=-5.08 -> Pg=60.0, Qg=18.965
% INFO    : Gen at bus 5120	: Vg=1.057395 -> Vg=1.0
% INFO    : Gen at bus 5144	: Pg=1713.6, Qg=109.47 -> Pg=1333.335, Qg=269.81
% INFO    : Gen at bus 5144	: Vg=1.035348 -> Vg=1.0
% INFO    : Gen at bus 5171	: Pg=-87.6, Qg=-8.56 -> Pg=-8.4, Qg=0.3
% INFO    : Gen at bus 5171	: Vg=1.01545 -> Vg=1.0
% INFO    : Gen at bus 5237	: Pg=106.8, Qg=9.87 -> Pg=80.0, Qg=25.14
% INFO    : Gen at bus 5237	: Vg=1.050569 -> Vg=1.0
% INFO    : Gen at bus 5239	: Pg=-1344.4, Qg=66.73 -> Pg=-846.265, Qg=0.0
% INFO    : Gen at bus 5239	: Vg=1.005494 -> Vg=1.0
% INFO    : Gen at bus 5278	: Pg=119.4, Qg=1.07 -> Pg=60.0, Qg=13.905
% INFO    : Gen at bus 5278	: Vg=1.041244 -> Vg=1.0
% INFO    : Gen at bus 5280	: Pg=-193.9, Qg=0.41 -> Pg=-79.265, Qg=0.615
% INFO    : Gen at bus 5280	: Vg=1.021983 -> Vg=1.0
% INFO    : Gen at bus 5290	: Pg=332.54, Qg=-12.08 -> Pg=180.0, Qg=49.125
% INFO    : Gen at bus 5290	: Vg=1.011274 -> Vg=1.0
% INFO    : Gen at bus 5299	: Pg=152.3, Qg=-101.06 -> Pg=870.165, Qg=-19.975
% INFO    : Gen at bus 5299	: Vg=1.061166 -> Vg=1.0
% INFO    : Gen at bus 5329	: Pg=-54.78, Qg=-11.3 -> Pg=13.475, Qg=0.325
% INFO    : Gen at bus 5329	: Vg=1.018401 -> Vg=1.0
% INFO    : Gen at bus 5340	: Pg=-159.0, Qg=13.31 -> Pg=-56.0, Qg=11.47
% INFO    : Gen at bus 5340	: Vg=1.051438 -> Vg=1.0
% INFO    : Gen at bus 5348	: Pg=10.8, Qg=-1.39 -> Pg=16.37, Qg=0.64
% INFO    : Gen at bus 5348	: Vg=1.015924 -> Vg=1.0
% INFO    : Gen at bus 5365	: Pg=19.59, Qg=1.74 -> Pg=20.0, Qg=5.695
% INFO    : Gen at bus 5365	: Vg=1.063822 -> Vg=1.0
% INFO    : Gen at bus 5379	: Pg=1250.6, Qg=357.14 -> Pg=1333.335, Qg=314.42
% INFO    : Gen at bus 5379	: Vg=1.105689 -> Vg=1.0
% INFO    : Gen at bus 5395	: Pg=-395.8, Qg=7.69 -> Pg=-213.865, Qg=20.7
% INFO    : Gen at bus 5395	: Vg=1.049 -> Vg=1.0
% INFO    : Gen at bus 5409	: Pg=219.5, Qg=-21.59 -> Pg=120.0, Qg=28.955
% INFO    : Gen at bus 5409	: Vg=1.023182 -> Vg=1.0
% INFO    : Gen at bus 5425	: Pg=181.1, Qg=-12.46 -> Pg=120.0, Qg=34.535
% INFO    : Gen at bus 5425	: Vg=1.077356 -> Vg=1.0
% INFO    : Gen at bus 5461	: Pg=43.4, Qg=12.92 -> Pg=40.0, Qg=13.355
% INFO    : Gen at bus 5461	: Vg=1.05743 -> Vg=1.0
% INFO    : Gen at bus 5465	: Pg=18.5, Qg=-9.16 -> Pg=46.735, Qg=0.165
% INFO    : Gen at bus 5465	: Vg=1.001327 -> Vg=1.0
% INFO    : Gen at bus 5481	: Pg=1368.6, Qg=154.37 -> Pg=1333.335, Qg=307.335
% INFO    : Gen at bus 5481	: Vg=1.063327 -> Vg=1.0
% INFO    : Gen at bus 5482	: Pg=56.8, Qg=-11.92 -> Pg=124.53, Qg=26.6
% INFO    : Gen at bus 5482	: Vg=1.046078 -> Vg=1.0
% INFO    : Gen at bus 5486	: Pg=861.3, Qg=130.17 -> Pg=666.665, Qg=134.495
% INFO    : Gen at bus 5486	: Vg=1.0598 -> Vg=1.0
% INFO    : Gen at bus 5488	: Pg=-96.4, Qg=21.75 -> Pg=-14.265, Qg=12.58
% INFO    : Gen at bus 5488	: Vg=1.041439 -> Vg=1.0
% INFO    : Gen at bus 5490	: Pg=3424.8, Qg=253.92 -> Pg=2666.665, Qg=539.345
% INFO    : Gen at bus 5490	: Vg=1.064044 -> Vg=1.0
% INFO    : Gen at bus 5512	: Pg=75.62, Qg=6.26 -> Pg=80.0, Qg=19.835
% INFO    : Gen at bus 5512	: Vg=1.020123 -> Vg=1.0
% INFO    : Gen at bus 5533	: Pg=173.0, Qg=12.93 -> Pg=100.0, Qg=26.58
% INFO    : Gen at bus 5533	: Vg=1.041341 -> Vg=1.0
% INFO    : Gen at bus 5546	: Pg=21.5, Qg=2.41 -> Pg=20.0, Qg=6.705
% INFO    : Gen at bus 5546	: Vg=1.055712 -> Vg=1.0
% INFO    : Gen at bus 5564	: Pg=57.6, Qg=12.64 -> Pg=40.0, Qg=11.905
% INFO    : Gen at bus 5564	: Vg=1.042161 -> Vg=1.0
% INFO    : Gen at bus 5658	: Pg=229.8, Qg=83.69 -> Pg=120.0, Qg=28.465
% INFO    : Gen at bus 5658	: Vg=1.009808 -> Vg=1.0
% INFO    : Gen at bus 5664	: Pg=128.0, Qg=15.73 -> Pg=80.0, Qg=22.83
% INFO    : Gen at bus 5664	: Vg=1.068735 -> Vg=1.0
% INFO    : Gen at bus 5669	: Pg=294.54, Qg=12.08 -> Pg=350.0, Qg=9.565
% INFO    : Gen at bus 5669	: Vg=1.003946 -> Vg=1.0
% INFO    : Gen at bus 5670	: Pg=16.6, Qg=-4.52 -> Pg=33.88, Qg=0.635
% INFO    : Gen at bus 5670	: Vg=1.018899 -> Vg=1.0
% INFO    : Gen at bus 5709	: Pg=837.0, Qg=87.17 -> Pg=800.0, Qg=182.77
% INFO    : Gen at bus 5709	: Vg=1.026473 -> Vg=1.0
% INFO    : Gen at bus 5726	: Pg=18.5, Qg=-10.63 -> Pg=47.99, Qg=0.22
% INFO    : Gen at bus 5726	: Vg=1.020165 -> Vg=1.0
% INFO    : Gen at bus 5742	: Pg=84.5, Qg=15.08 -> Pg=56.76, Qg=9.63
% INFO    : Gen at bus 5742	: Vg=1.028692 -> Vg=1.0
% INFO    : Gen at bus 5781	: Pg=1102.83, Qg=412.72 -> Pg=1200.0, Qg=227.25
% INFO    : Gen at bus 5781	: Vg=1.038035 -> Vg=1.0
% INFO    : Gen at bus 5787	: Pg=63.55, Qg=-12.77 -> Pg=120.0, Qg=41.055
% INFO    : Gen at bus 5787	: Vg=1.031918 -> Vg=1.0
% INFO    : Gen at bus 5814	: Pg=181.2, Qg=64.23 -> Pg=293.335, Qg=59.905
% INFO    : Gen at bus 5814	: Vg=1.048258 -> Vg=1.0
% INFO    : Gen at bus 5821	: Pg=-74.21, Qg=-20.45 -> Pg=0.53, Qg=-0.235
% INFO    : Gen at bus 5821	: Vg=1.019461 -> Vg=1.0
% INFO    : Gen at bus 5823	: Pg=404.6, Qg=-38.48 -> Pg=333.335, Qg=67.605
% INFO    : Gen at bus 5823	: Vg=1.063184 -> Vg=1.0
% INFO    : Gen at bus 5825	: Pg=262.6, Qg=40.41 -> Pg=350.0, Qg=21.225
% INFO    : Gen at bus 5825	: Vg=0.995795 -> Vg=1.0
% INFO    : Gen at bus 5828	: Pg=13.2, Qg=-3.55 -> Pg=19.99, Qg=0.83
% INFO    : Gen at bus 5828	: Vg=1.029274 -> Vg=1.0
% INFO    : Gen at bus 5831	: Pg=-179.4, Qg=0.25 -> Pg=-69.6, Qg=0.42
% INFO    : Gen at bus 5831	: Vg=1.032948 -> Vg=1.0
% INFO    : Gen at bus 5856	: Pg=305.7, Qg=32.63 -> Pg=320.0, Qg=64.565
% INFO    : Gen at bus 5856	: Vg=1.039775 -> Vg=1.0
% INFO    : Gen at bus 5881	: Pg=60.0, Qg=6.27 -> Pg=40.0, Qg=11.795
% INFO    : Gen at bus 5881	: Vg=1.062314 -> Vg=1.0
% INFO    : Gen at bus 5940	: Pg=-74.9, Qg=7.47 -> Pg=0.065, Qg=4.74
% INFO    : Gen at bus 5940	: Vg=1.031482 -> Vg=1.0
% INFO    : Gen at bus 5970	: Pg=127.57, Qg=-18.76 -> Pg=180.0, Qg=62.065
% INFO    : Gen at bus 5970	: Vg=1.019864 -> Vg=1.0
% INFO    : Gen at bus 5971	: Pg=1221.2, Qg=389.96 -> Pg=1333.335, Qg=321.45
% INFO    : Gen at bus 5971	: Vg=1.067028 -> Vg=1.0
% INFO    : Gen at bus 5983	: Pg=-102.5, Qg=7.94 -> Pg=-18.335, Qg=12.34
% INFO    : Gen at bus 5983	: Vg=1.064637 -> Vg=1.0
% INFO    : Gen at bus 5991	: Pg=854.6, Qg=-173.92 -> Pg=800.0, Qg=150.15
% INFO    : Gen at bus 5991	: Vg=1.018313 -> Vg=1.0
% INFO    : Gen at bus 5994	: Pg=-87.3, Qg=-9.1 -> Pg=-8.2, Qg=-0.285
% INFO    : Gen at bus 5994	: Vg=1.034164 -> Vg=1.0
% INFO    : Gen at bus 6000	: Pg=617.7, Qg=351.54 -> Pg=600.0, Qg=136.225
% INFO    : Gen at bus 6000	: Vg=1.085651 -> Vg=1.0
% INFO    : Gen at bus 6036	: Pg=820.2, Qg=293.16 -> Pg=600.0, Qg=114.62
% INFO    : Gen at bus 6036	: Vg=1.041753 -> Vg=1.0
% INFO    : Gen at bus 6090	: Pg=60.4, Qg=5.42 -> Pg=40.0, Qg=11.675
% INFO    : Gen at bus 6090	: Vg=1.032192 -> Vg=1.0
% INFO    : Gen at bus 6092	: Pg=774.9, Qg=-110.76 -> Pg=600.0, Qg=119.855
% INFO    : Gen at bus 6092	: Vg=1.03946 -> Vg=1.0
% INFO    : Gen at bus 6131	: Pg=602.4, Qg=314.21 -> Pg=600.0, Qg=139.465
% INFO    : Gen at bus 6131	: Vg=1.141159 -> Vg=1.0
% INFO    : Gen at bus 6138	: Pg=-121.9, Qg=2.03 -> Pg=-31.265, Qg=4.46
% INFO    : Gen at bus 6138	: Vg=1.013527 -> Vg=1.0
% INFO    : Gen at bus 6145	: Pg=190.58, Qg=-9.83 -> Pg=120.0, Qg=31.08
% INFO    : Gen at bus 6145	: Vg=1.021227 -> Vg=1.0
% INFO    : Gen at bus 6153	: Pg=94.3, Qg=-49.64 -> Pg=401.01, Qg=-6.085
% INFO    : Gen at bus 6153	: Vg=0.996786 -> Vg=1.0
% INFO    : Gen at bus 6168	: Pg=26.3, Qg=0.51 -> Pg=26.88, Qg=2.465
% INFO    : Gen at bus 6168	: Vg=1.043938 -> Vg=1.0
% INFO    : Gen at bus 6179	: Pg=65.9, Qg=3.14 -> Pg=40.0, Qg=10.51
% INFO    : Gen at bus 6179	: Vg=1.038661 -> Vg=1.0
% INFO    : Gen at bus 6233	: Pg=879.6, Qg=231.83 -> Pg=800.0, Qg=177.855
% INFO    : Gen at bus 6233	: Vg=1.018011 -> Vg=1.0
% INFO    : Gen at bus 6239	: Pg=5.3, Qg=0.44 -> Pg=2.66, Qg=0.585
% INFO    : Gen at bus 6239	: Vg=1.029262 -> Vg=1.0
% INFO    : Gen at bus 6280	: Pg=117.9, Qg=2.77 -> Pg=60.0, Qg=13.88
% INFO    : Gen at bus 6280	: Vg=1.019445 -> Vg=1.0
% INFO    : Gen at bus 6291	: Pg=55.5, Qg=30.37 -> Pg=60.0, Qg=20.76
% INFO    : Gen at bus 6291	: Vg=1.039201 -> Vg=1.0
% INFO    : Gen at bus 6329	: Pg=223.4, Qg=0.88 -> Pg=200.0, Qg=42.465
% INFO    : Gen at bus 6329	: Vg=0.994824 -> Vg=1.0
% INFO    : Gen at bus 6331	: Pg=48.8, Qg=4.28 -> Pg=40.0, Qg=12.855
% INFO    : Gen at bus 6331	: Vg=1.053365 -> Vg=1.0
% INFO    : Gen at bus 6332	: Pg=96.0, Qg=-9.22 -> Pg=100.0, Qg=34.305
% INFO    : Gen at bus 6332	: Vg=1.064292 -> Vg=1.0
% INFO    : Gen at bus 6351	: Pg=22.08, Qg=15.6 -> Pg=40.0, Qg=13.365
% INFO    : Gen at bus 6351	: Vg=1.059908 -> Vg=1.0
% INFO    : Gen at bus 6368	: Pg=-145.3, Qg=11.28 -> Pg=-46.865, Qg=13.825
% INFO    : Gen at bus 6368	: Vg=1.046268 -> Vg=1.0
% INFO    : Gen at bus 6376	: Pg=-27.8, Qg=-15.83 -> Pg=31.465, Qg=48.96
% INFO    : Gen at bus 6376	: Vg=1.047648 -> Vg=1.0
% INFO    : Gen at bus 6415	: Pg=310.83, Qg=46.42 -> Pg=450.0, Qg=22.4
% INFO    : Gen at bus 6415	: Vg=0.987105 -> Vg=1.0
% INFO    : Gen at bus 6429	: Pg=171.0, Qg=24.15 -> Pg=100.0, Qg=26.57
% INFO    : Gen at bus 6429	: Vg=1.03915 -> Vg=1.0
% INFO    : Gen at bus 6436	: Pg=-86.5, Qg=0.45 -> Pg=-7.67, Qg=0.61
% INFO    : Gen at bus 6436	: Vg=1.01651 -> Vg=1.0
% INFO    : Gen at bus 6459	: Pg=77.4, Qg=19.01 -> Pg=90.0, Qg=30.96
% INFO    : Gen at bus 6459	: Vg=1.006942 -> Vg=1.0
% INFO    : Gen at bus 6474	: Pg=718.5, Qg=-5.42 -> Pg=666.665, Qg=132.285
% INFO    : Gen at bus 6474	: Vg=1.062877 -> Vg=1.0
% INFO    : Gen at bus 6484	: Pg=1168.8, Qg=-46.12 -> Pg=800.0, Qg=140.36
% INFO    : Gen at bus 6484	: Vg=1.030805 -> Vg=1.0
% INFO    : Gen at bus 6516	: Pg=228.2, Qg=13.22 -> Pg=140.0, Qg=39.45
% INFO    : Gen at bus 6516	: Vg=1.047972 -> Vg=1.0
% INFO    : Gen at bus 6552	: Pg=-204.2, Qg=13.04 -> Pg=-86.135, Qg=12.71
% INFO    : Gen at bus 6552	: Vg=1.048072 -> Vg=1.0
% INFO    : Gen at bus 6632	: Pg=2013.9, Qg=-440.2 -> Pg=2000.0, Qg=459.55
% INFO    : Gen at bus 6632	: Vg=1.062949 -> Vg=1.0
% INFO    : Gen at bus 6654	: Pg=742.76, Qg=-60.39 -> Pg=533.335, Qg=91.89
% INFO    : Gen at bus 6654	: Vg=1.02462 -> Vg=1.0
% INFO    : Gen at bus 6656	: Pg=249.0, Qg=-28.26 -> Pg=150.0, Qg=39.82
% INFO    : Gen at bus 6656	: Vg=1.022999 -> Vg=1.0
% INFO    : Gen at bus 6681	: Pg=21.3, Qg=-23.09 -> Pg=54.19, Qg=0.36
% INFO    : Gen at bus 6681	: Vg=1.07064 -> Vg=1.0
% INFO    : Gen at bus 6734	: Pg=382.7, Qg=-63.86 -> Pg=360.0, Qg=89.715
% INFO    : Gen at bus 6734	: Vg=1.05765 -> Vg=1.0
% INFO    : Gen at bus 6798	: Pg=949.7, Qg=162.2 -> Pg=666.665, Qg=123.065
% INFO    : Gen at bus 6798	: Vg=1.019012 -> Vg=1.0
% INFO    : Gen at bus 6807	: Pg=44.07, Qg=30.64 -> Pg=80.0, Qg=27.34
% INFO    : Gen at bus 6807	: Vg=1.012126 -> Vg=1.0
% INFO    : Gen at bus 6816	: Pg=16.53, Qg=-7.48 -> Pg=80.0, Qg=27.545
% INFO    : Gen at bus 6816	: Vg=1.055666 -> Vg=1.0
% INFO    : Gen at bus 6820	: Pg=15.9, Qg=-0.44 -> Pg=16.265, Qg=1.465
% INFO    : Gen at bus 6820	: Vg=1.051187 -> Vg=1.0
% INFO    : Gen at bus 6831	: Pg=-57.5, Qg=9.24 -> Pg=11.665, Qg=10.685
% INFO    : Gen at bus 6831	: Vg=1.034052 -> Vg=1.0
% INFO    : Gen at bus 6838	: Pg=578.0, Qg=233.2 -> Pg=400.0, Qg=71.46
% INFO    : Gen at bus 6838	: Vg=1.043313 -> Vg=1.0
% INFO    : Gen at bus 6845	: Pg=102.9, Qg=17.21 -> Pg=60.0, Qg=15.885
% INFO    : Gen at bus 6845	: Vg=1.051715 -> Vg=1.0
% INFO    : Gen at bus 6852	: Pg=-344.9, Qg=3.54 -> Pg=-179.935, Qg=6.11
% INFO    : Gen at bus 6852	: Vg=1.032911 -> Vg=1.0
% INFO    : Gen at bus 6857	: Pg=2463.6, Qg=267.78 -> Pg=2666.665, Qg=639.94
% INFO    : Gen at bus 6857	: Vg=1.014858 -> Vg=1.0
% INFO    : Gen at bus 6877	: Pg=19.8, Qg=-14.33 -> Pg=50.255, Qg=0.31
% INFO    : Gen at bus 6877	: Vg=1.066537 -> Vg=1.0
% INFO    : Gen at bus 6888	: Pg=133.0, Qg=4.46 -> Pg=194.335, Qg=64.72
% INFO    : Gen at bus 6888	: Vg=1.042814 -> Vg=1.0
% INFO    : Gen at bus 6936	: Pg=665.8, Qg=-86.19 -> Pg=600.0, Qg=113.03
% INFO    : Gen at bus 6936	: Vg=1.030076 -> Vg=1.0
% INFO    : Gen at bus 6947	: Pg=227.5, Qg=5.11 -> Pg=140.0, Qg=38.9
% INFO    : Gen at bus 6947	: Vg=1.046726 -> Vg=1.0
% INFO    : Gen at bus 6969	: Pg=39.8, Qg=-1.88 -> Pg=40.0, Qg=13.63
% INFO    : Gen at bus 6969	: Vg=1.061428 -> Vg=1.0
% INFO    : Gen at bus 6982	: Pg=-12.6, Qg=10.73 -> Pg=41.6, Qg=18.89
% INFO    : Gen at bus 6982	: Vg=1.038963 -> Vg=1.0
% INFO    : Gen at bus 7029	: Pg=1152.7, Qg=-198.11 -> Pg=800.0, Qg=140.5
% INFO    : Gen at bus 7029	: Vg=1.063951 -> Vg=1.0
% INFO    : Gen at bus 7036	: Pg=65.8, Qg=11.91 -> Pg=40.0, Qg=11.22
% INFO    : Gen at bus 7036	: Vg=1.042173 -> Vg=1.0
% INFO    : Gen at bus 7049	: Pg=55.5, Qg=17.03 -> Pg=60.0, Qg=20.81
% INFO    : Gen at bus 7049	: Vg=1.04735 -> Vg=1.0
% INFO    : Gen at bus 7056	: Pg=448.85, Qg=159.6 -> Pg=400.0, Qg=83.19
% INFO    : Gen at bus 7056	: Vg=1.005566 -> Vg=1.0
% INFO    : Gen at bus 7058	: Pg=50.4, Qg=7.48 -> Pg=40.0, Qg=12.695
% INFO    : Gen at bus 7058	: Vg=1.043279 -> Vg=1.0
% INFO    : Gen at bus 7075	: Pg=-49.37, Qg=-1.16 -> Pg=17.085, Qg=0.76
% INFO    : Gen at bus 7075	: Vg=1.026663 -> Vg=1.0
% INFO    : Gen at bus 7104	: Pg=234.2, Qg=4.4 -> Pg=200.0, Qg=41.365
% INFO    : Gen at bus 7104	: Vg=1.004388 -> Vg=1.0
% INFO    : Gen at bus 7115	: Pg=65.87, Qg=10.39 -> Pg=136.14, Qg=5.86
% INFO    : Gen at bus 7115	: Vg=1.014496 -> Vg=1.0
% INFO    : Gen at bus 7137	: Pg=876.4, Qg=-70.99 -> Pg=800.0, Qg=148.43
% INFO    : Gen at bus 7137	: Vg=1.031779 -> Vg=1.0
% INFO    : Gen at bus 7159	: Pg=861.3, Qg=131.58 -> Pg=666.665, Qg=134.495
% INFO    : Gen at bus 7159	: Vg=1.059739 -> Vg=1.0
% INFO    : Gen at bus 7183	: Pg=1250.6, Qg=357.75 -> Pg=1333.335, Qg=314.42
% INFO    : Gen at bus 7183	: Vg=1.105479 -> Vg=1.0
% INFO    : Gen at bus 7209	: Pg=7.3, Qg=0.7 -> Pg=3.675, Qg=0.83
% INFO    : Gen at bus 7209	: Vg=1.052921 -> Vg=1.0
% INFO    : Gen at bus 7257	: Pg=21.3, Qg=-9.86 -> Pg=53.645, Qg=0.27
% INFO    : Gen at bus 7257	: Vg=1.030375 -> Vg=1.0
% INFO    : Gen at bus 7260	: Pg=32.0, Qg=3.47 -> Pg=21.8, Qg=3.725
% INFO    : Gen at bus 7260	: Vg=1.016183 -> Vg=1.0
% INFO    : Gen at bus 7267	: Pg=-39.7, Qg=48.68 -> Pg=23.535, Qg=27.5
% INFO    : Gen at bus 7267	: Vg=1.012113 -> Vg=1.0
% INFO    : Gen at bus 7270	: Pg=766.8, Qg=140.62 -> Pg=600.0, Qg=119.37
% INFO    : Gen at bus 7270	: Vg=1.06851 -> Vg=1.0
% INFO    : Gen at bus 7279	: Pg=-681.7, Qg=6.43 -> Pg=-404.465, Qg=4.07
% INFO    : Gen at bus 7279	: Vg=1.030612 -> Vg=1.0
% INFO    : Gen at bus 7282	: Pg=2340.4, Qg=17.11 -> Pg=2666.665, Qg=637.065
% INFO    : Gen at bus 7282	: Vg=1.029503 -> Vg=1.0
% INFO    : Gen at bus 7303	: Pg=856.4, Qg=-40.73 -> Pg=600.0, Qg=108.65
% INFO    : Gen at bus 7303	: Vg=1.033047 -> Vg=1.0
% INFO    : Gen at bus 7327	: Pg=59.06, Qg=18.39 -> Pg=80.0, Qg=26.245
% INFO    : Gen at bus 7327	: Vg=1.042085 -> Vg=1.0
% INFO    : Gen at bus 7328	: Pg=53.0, Qg=26.39 -> Pg=40.0, Qg=12.53
% INFO    : Gen at bus 7328	: Vg=0.994679 -> Vg=1.0
% INFO    : Gen at bus 7329	: Pg=62.8, Qg=8.26 -> Pg=40.0, Qg=11.355
% INFO    : Gen at bus 7329	: Vg=1.039675 -> Vg=1.0
% INFO    : Gen at bus 7431	: Pg=735.6, Qg=-100.04 -> Pg=600.0, Qg=124.25
% INFO    : Gen at bus 7431	: Vg=1.01868 -> Vg=1.0
% INFO    : Gen at bus 7446	: Pg=13.3, Qg=-1.22 -> Pg=20.48, Qg=0.865
% INFO    : Gen at bus 7446	: Vg=1.012514 -> Vg=1.0
% INFO    : Gen at bus 7466	: Pg=-202.53, Qg=38.79 -> Pg=-85.02, Qg=-0.605
% INFO    : Gen at bus 7466	: Vg=1.057274 -> Vg=1.0
% INFO    : Gen at bus 7474	: Pg=76.5, Qg=8.16 -> Pg=60.0, Qg=18.93
% INFO    : Gen at bus 7474	: Vg=1.028765 -> Vg=1.0
% INFO    : Gen at bus 7495	: Pg=75.8, Qg=68.99 -> Pg=125.265, Qg=77.23
% INFO    : Gen at bus 7495	: Vg=1.036344 -> Vg=1.0
% INFO    : Gen at bus 7504	: Pg=5.2, Qg=0.46 -> Pg=2.65, Qg=0.595
% INFO    : Gen at bus 7504	: Vg=1.017989 -> Vg=1.0
% INFO    : Gen at bus 7508	: Pg=715.1, Qg=-123.77 -> Pg=600.0, Qg=126.49
% INFO    : Gen at bus 7508	: Vg=1.062735 -> Vg=1.0
% INFO    : Gen at bus 7520	: Pg=702.4, Qg=261.32 -> Pg=533.335, Qg=104.815
% INFO    : Gen at bus 7520	: Vg=1.033404 -> Vg=1.0
% INFO    : Gen at bus 7522	: Pg=508.0, Qg=245.55 -> Pg=533.335, Qg=125.72
% INFO    : Gen at bus 7522	: Vg=1.000638 -> Vg=1.0
% INFO    : Gen at bus 7628	: Pg=243.0, Qg=112.06 -> Pg=200.0, Qg=41.87
% INFO    : Gen at bus 7628	: Vg=1.057002 -> Vg=1.0
% INFO    : Gen at bus 7630	: Pg=33.09, Qg=-15.8 -> Pg=65.91, Qg=2.675
% INFO    : Gen at bus 7630	: Vg=1.019127 -> Vg=1.0
% INFO    : Gen at bus 7641	: Pg=769.2, Qg=22.1 -> Pg=540.0, Qg=107.93
% INFO    : Gen at bus 7641	: Vg=1.053056 -> Vg=1.0
% INFO    : Gen at bus 7659	: Pg=-39.5, Qg=-2.62 -> Pg=23.665, Qg=24.96
% INFO    : Gen at bus 7659	: Vg=1.035071 -> Vg=1.0
% INFO    : Gen at bus 7661	: Pg=168.6, Qg=6.63 -> Pg=90.0, Qg=21.48
% INFO    : Gen at bus 7661	: Vg=1.039659 -> Vg=1.0
% INFO    : Gen at bus 7697	: Pg=228.2, Qg=13.23 -> Pg=140.0, Qg=39.45
% INFO    : Gen at bus 7697	: Vg=1.047945 -> Vg=1.0
% INFO    : Gen at bus 7755	: Pg=6.3, Qg=0.09 -> Pg=6.45, Qg=0.605
% INFO    : Gen at bus 7755	: Vg=1.06304 -> Vg=1.0
% INFO    : Gen at bus 7761	: Pg=106.8, Qg=13.91 -> Pg=60.0, Qg=15.39
% INFO    : Gen at bus 7761	: Vg=1.015679 -> Vg=1.0
% INFO    : Gen at bus 7776	: Pg=1221.2, Qg=372.35 -> Pg=1333.335, Qg=321.605
% INFO    : Gen at bus 7776	: Vg=1.068185 -> Vg=1.0
% INFO    : Gen at bus 7779	: Pg=345.2, Qg=164.44 -> Pg=400.0, Qg=98.05
% INFO    : Gen at bus 7779	: Vg=1.083645 -> Vg=1.0
% INFO    : Gen at bus 7808	: Pg=1250.4, Qg=285.53 -> Pg=1333.335, Qg=314.335
% INFO    : Gen at bus 7808	: Vg=1.055 -> Vg=1.0
% INFO    : Gen at bus 7819	: Pg=25.6, Qg=-5.01 -> Pg=25.77, Qg=2.23
% INFO    : Gen at bus 7819	: Vg=1.020992 -> Vg=1.0
% INFO    : Gen at bus 7833	: Pg=15.5, Qg=21.22 -> Pg=120.0, Qg=31.98
% INFO    : Gen at bus 7833	: Vg=1.02191 -> Vg=1.0
% INFO    : Gen at bus 7842	: Pg=165.0, Qg=22.74 -> Pg=100.0, Qg=27.76
% INFO    : Gen at bus 7842	: Vg=1.005674 -> Vg=1.0
% INFO    : Gen at bus 7860	: Pg=397.0, Qg=-48.07 -> Pg=533.335, Qg=135.225
% INFO    : Gen at bus 7860	: Vg=1.058289 -> Vg=1.0
% INFO    : Gen at bus 7913	: Pg=1368.6, Qg=153.57 -> Pg=1333.335, Qg=307.415
% INFO    : Gen at bus 7913	: Vg=1.063382 -> Vg=1.0
% INFO    : Gen at bus 7929	: Pg=1101.5, Qg=-28.09 -> Pg=1066.665, Qg=207.95
% INFO    : Gen at bus 7929	: Vg=1.050833 -> Vg=1.0
% INFO    : Gen at bus 7960	: Pg=419.0, Qg=108.4 -> Pg=400.0, Qg=90.49
% INFO    : Gen at bus 7960	: Vg=1.018041 -> Vg=1.0
% INFO    : Gen at bus 7998	: Pg=811.8, Qg=140.4 -> Pg=600.0, Qg=115.31
% INFO    : Gen at bus 7998	: Vg=1.042456 -> Vg=1.0
% INFO    : Gen at bus 8043	: Pg=-27.0, Qg=8.33 -> Pg=32.0, Qg=25.855
% INFO    : Gen at bus 8043	: Vg=1.063893 -> Vg=1.0
% INFO    : Gen at bus 8044	: Pg=337.6, Qg=95.16 -> Pg=400.0, Qg=97.96
% INFO    : Gen at bus 8044	: Vg=1.052835 -> Vg=1.0
% INFO    : Gen at bus 8066	: Pg=-188.9, Qg=-0.1 -> Pg=-75.935, Qg=0.6
% INFO    : Gen at bus 8066	: Vg=1.01361 -> Vg=1.0
% INFO    : Gen at bus 8087	: Pg=322.12, Qg=-46.45 -> Pg=210.0, Qg=48.475
% INFO    : Gen at bus 8087	: Vg=1.03306 -> Vg=1.0
% INFO    : Gen at bus 8109	: Pg=992.0, Qg=788.82 -> Pg=520.8, Qg=0.0
% INFO    : Gen at bus 8109	: Vg=1.06101 -> Vg=1.0
% INFO    : Gen at bus 8158	: Pg=153.0, Qg=-5.59 -> Pg=100.0, Qg=29.33
% INFO    : Gen at bus 8158	: Vg=1.05367 -> Vg=1.0
% INFO    : Gen at bus 8159	: Pg=698.6, Qg=-109.57 -> Pg=473.245, Qg=77.15
% INFO    : Gen at bus 8159	: Vg=1.064422 -> Vg=1.0
% INFO    : Gen at bus 8207	: Pg=1.75, Qg=-40.56 -> Pg=103.635, Qg=1.86
% INFO    : Gen at bus 8207	: Vg=1.030795 -> Vg=1.0
% INFO    : Gen at bus 8210	: Pg=1321.7, Qg=-211.01 -> Pg=1066.665, Qg=219.065
% INFO    : Gen at bus 8210	: Vg=1.053137 -> Vg=1.0
% INFO    : Gen at bus 8222	: Pg=66.8, Qg=18.43 -> Pg=40.0, Qg=10.855
% INFO    : Gen at bus 8222	: Vg=1.019521 -> Vg=1.0
% INFO    : Gen at bus 8223	: Pg=401.0, Qg=150.56 -> Pg=400.0, Qg=92.965
% INFO    : Gen at bus 8223	: Vg=1.058011 -> Vg=1.0
% INFO    : Gen at bus 8225	: Pg=17.0, Qg=6.14 -> Pg=20.0, Qg=7.035
% INFO    : Gen at bus 8225	: Vg=1.067644 -> Vg=1.0
% INFO    : Gen at bus 8240	: Pg=-15.64, Qg=-18.22 -> Pg=39.575, Qg=0.375
% INFO    : Gen at bus 8240	: Vg=1.059307 -> Vg=1.0
% INFO    : Gen at bus 8242	: Pg=358.36, Qg=-36.96 -> Pg=210.0, Qg=48.94
% INFO    : Gen at bus 8242	: Vg=1.01497 -> Vg=1.0
% INFO    : Gen at bus 8247	: Pg=253.4, Qg=-41.35 -> Pg=180.0, Qg=53.725
% INFO    : Gen at bus 8247	: Vg=1.059416 -> Vg=1.0
% INFO    : Gen at bus 8267	: Pg=203.4, Qg=-0.76 -> Pg=120.0, Qg=32.14
% INFO    : Gen at bus 8267	: Vg=1.045102 -> Vg=1.0
% INFO    : Gen at bus 8278	: Pg=97.2, Qg=9.83 -> Pg=60.0, Qg=16.54
% INFO    : Gen at bus 8278	: Vg=1.006884 -> Vg=1.0
% INFO    : Gen at bus 8311	: Pg=-8.75, Qg=5.44 -> Pg=44.17, Qg=5.335
% INFO    : Gen at bus 8311	: Vg=1.039615 -> Vg=1.0
% INFO    : Gen at bus 8312	: Pg=1702.2, Qg=440.14 -> Pg=1600.0, Qg=360.845
% INFO    : Gen at bus 8312	: Vg=1.078014 -> Vg=1.0
% INFO    : Gen at bus 8378	: Pg=33.8, Qg=1.44 -> Pg=20.0, Qg=5.335
% INFO    : Gen at bus 8378	: Vg=1.022564 -> Vg=1.0
% INFO    : Gen at bus 8458	: Pg=517.1, Qg=-37.85 -> Pg=666.665, Qg=167.965
% INFO    : Gen at bus 8458	: Vg=1.045078 -> Vg=1.0
% INFO    : Gen at bus 8473	: Pg=-135.0, Qg=3.1 -> Pg=-40.0, Qg=27.88
% INFO    : Gen at bus 8473	: Vg=1.042275 -> Vg=1.0
% INFO    : Gen at bus 8486	: Pg=78.8, Qg=12.34 -> Pg=40.0, Qg=9.245
% INFO    : Gen at bus 8486	: Vg=1.046146 -> Vg=1.0
% INFO    : Gen at bus 8515	: Pg=32.3, Qg=-17.43 -> Pg=100.0, Qg=30.8
% INFO    : Gen at bus 8515	: Vg=1.055375 -> Vg=1.0
% INFO    : Gen at bus 8522	: Pg=-75.69, Qg=1.2 -> Pg=-0.46, Qg=0.96
% INFO    : Gen at bus 8522	: Vg=1.023003 -> Vg=1.0
% INFO    : Gen at bus 8564	: Pg=-65.0, Qg=23.28 -> Pg=6.665, Qg=14.525
% INFO    : Gen at bus 8564	: Vg=1.019996 -> Vg=1.0
% INFO    : Gen at bus 8605	: Pg=427.0, Qg=176.67 -> Pg=400.0, Qg=90.145
% INFO    : Gen at bus 8605	: Vg=1.009283 -> Vg=1.0
% INFO    : Gen at bus 8625	: Pg=20.3, Qg=-5.27 -> Pg=51.515, Qg=0.38
% INFO    : Gen at bus 8625	: Vg=1.055846 -> Vg=1.0
% INFO    : Gen at bus 8630	: Pg=298.2, Qg=-25.78 -> Pg=200.0, Qg=32.685
% INFO    : Gen at bus 8630	: Vg=1.064508 -> Vg=1.0
% INFO    : Gen at bus 8670	: Pg=-138.3, Qg=19.67 -> Pg=-42.2, Qg=12.47
% INFO    : Gen at bus 8670	: Vg=1.049183 -> Vg=1.0
% INFO    : Gen at bus 8676	: Pg=-259.1, Qg=16.9 -> Pg=-122.735, Qg=9.98
% INFO    : Gen at bus 8676	: Vg=1.018144 -> Vg=1.0
% INFO    : Gen at bus 8683	: Pg=-37.28, Qg=4.87 -> Pg=25.15, Qg=16.965
% INFO    : Gen at bus 8683	: Vg=1.041179 -> Vg=1.0
% INFO    : Gen at bus 8702	: Pg=130.69, Qg=-8.62 -> Pg=180.0, Qg=62.765
% INFO    : Gen at bus 8702	: Vg=1.029789 -> Vg=1.0
% INFO    : Gen at bus 8721	: Pg=1232.6, Qg=202.93 -> Pg=1333.335, Qg=319.77
% INFO    : Gen at bus 8721	: Vg=1.056768 -> Vg=1.0
% INFO    : Gen at bus 8729	: Pg=20.89, Qg=-7.62 -> Pg=50.18, Qg=2.075
% INFO    : Gen at bus 8729	: Vg=1.009953 -> Vg=1.0
% INFO    : Gen at bus 8771	: Pg=21.7, Qg=5.77 -> Pg=20.0, Qg=6.635
% INFO    : Gen at bus 8771	: Vg=1.008996 -> Vg=1.0
% INFO    : Gen at bus 8795	: Pg=166.2, Qg=-9.75 -> Pg=120.0, Qg=36.925
% INFO    : Gen at bus 8795	: Vg=1.055026 -> Vg=1.0
% INFO    : Gen at bus 8807	: Pg=-304.0, Qg=5.74 -> Pg=-152.665, Qg=10.885
% INFO    : Gen at bus 8807	: Vg=1.046456 -> Vg=1.0
% INFO    : Gen at bus 8818	: Pg=44.66, Qg=-3.57 -> Pg=80.0, Qg=27.06
% INFO    : Gen at bus 8818	: Vg=1.051013 -> Vg=1.0
% INFO    : Gen at bus 8858	: Pg=42.8, Qg=-33.21 -> Pg=180.0, Qg=53.465
% INFO    : Gen at bus 8858	: Vg=1.027559 -> Vg=1.0
% INFO    : Gen at bus 8871	: Pg=-233.8, Qg=-26.8 -> Pg=-105.865, Qg=32.935
% INFO    : Gen at bus 8871	: Vg=1.037687 -> Vg=1.0
% INFO    : Gen at bus 8872	: Pg=1232.6, Qg=185.36 -> Pg=1333.335, Qg=319.77
% INFO    : Gen at bus 8872	: Vg=1.056528 -> Vg=1.0
% INFO    : Gen at bus 8875	: Pg=443.8, Qg=92.44 -> Pg=400.0, Qg=88.875
% INFO    : Gen at bus 8875	: Vg=1.047011 -> Vg=1.0
% INFO    : Gen at bus 8903	: Pg=17.0, Qg=-0.91 -> Pg=43.365, Qg=0.29
% INFO    : Gen at bus 8903	: Vg=1.021928 -> Vg=1.0
% INFO    : Gen at bus 8927	: Pg=37.2, Qg=13.99 -> Pg=40.0, Qg=13.76
% INFO    : Gen at bus 8927	: Vg=1.015122 -> Vg=1.0
% INFO    : Gen at bus 8946	: Pg=756.8, Qg=-115.78 -> Pg=533.335, Qg=93.92
% INFO    : Gen at bus 8946	: Vg=1.041085 -> Vg=1.0
% INFO    : Gen at bus 8950	: Pg=-255.7, Qg=10.92 -> Pg=-120.47, Qg=13.31
% INFO    : Gen at bus 8950	: Vg=1.045004 -> Vg=1.0
% INFO    : Gen at bus 8956	: Pg=498.4, Qg=100.47 -> Pg=400.0, Qg=82.335
% INFO    : Gen at bus 8956	: Vg=1.064772 -> Vg=1.0
% INFO    : Gen at bus 8961	: Pg=-61.8, Qg=-10.12 -> Pg=8.8, Qg=1.57
% INFO    : Gen at bus 8961	: Vg=1.038824 -> Vg=1.0
% INFO    : Gen at bus 8973	: Pg=1624.7, Qg=-347.16 -> Pg=1333.335, Qg=245.94
% INFO    : Gen at bus 8973	: Vg=1.050147 -> Vg=1.0
% INFO    : Gen at bus 8976	: Pg=110.0, Qg=12.95 -> Pg=100.0, Qg=33.35
% INFO    : Gen at bus 8976	: Vg=1.045593 -> Vg=1.0
% INFO    : Gen at bus 8981	: Pg=19.3, Qg=-14.48 -> Pg=48.99, Qg=0.24
% INFO    : Gen at bus 8981	: Vg=1.027038 -> Vg=1.0
% INFO    : Gen at bus 8987	: Pg=-21.95, Qg=-14.59 -> Pg=35.365, Qg=0.88
% INFO    : Gen at bus 8987	: Vg=1.052269 -> Vg=1.0
% INFO    : Gen at bus 8993	: Pg=-46.19, Qg=2.46 -> Pg=19.21, Qg=14.08
% INFO    : Gen at bus 8993	: Vg=1.022201 -> Vg=1.0
% INFO    : Gen at bus 8997	: Pg=78.2, Qg=-6.48 -> Pg=158.545, Qg=3.055
% INFO    : Gen at bus 8997	: Vg=1.002676 -> Vg=1.0
% INFO    : Gen at bus 9001	: Pg=338.71, Qg=-11.52 -> Pg=333.335, Qg=67.175
% INFO    : Gen at bus 9001	: Vg=1.025721 -> Vg=1.0
% INFO    : Gen at bus 9039	: Pg=-39.85, Qg=0.37 -> Pg=23.435, Qg=0.58
% INFO    : Gen at bus 9039	: Vg=1.02063 -> Vg=1.0
% INFO    : Gen at bus 9043	: Pg=-10.55, Qg=0.7 -> Pg=42.965, Qg=5.365
% INFO    : Gen at bus 9043	: Vg=1.02106 -> Vg=1.0
% INFO    : Gen at bus 9055	: Pg=-90.0, Qg=1.17 -> Pg=-10.0, Qg=0.685
% INFO    : Gen at bus 9055	: Vg=0.982562 -> Vg=1.0
% INFO    : Gen at bus 9067	: Pg=369.6, Qg=67.07 -> Pg=293.335, Qg=60.865
% INFO    : Gen at bus 9067	: Vg=1.045155 -> Vg=1.0
% INFO    : Gen at bus 9097	: Pg=40.1, Qg=1.26 -> Pg=20.58, Qg=4.565
% INFO    : Gen at bus 9097	: Vg=1.01907 -> Vg=1.0
% INFO    : Gen at bus 9101	: Pg=698.8, Qg=-2.05 -> Pg=666.665, Qg=136.535
% INFO    : Gen at bus 9101	: Vg=1.026751 -> Vg=1.0
% INFO    : Gen at bus 9108	: Pg=-239.23, Qg=0.54 -> Pg=-109.485, Qg=2.245
% INFO    : Gen at bus 9108	: Vg=1.04489 -> Vg=1.0
% INFO    : Gen at bus 9137	: Pg=42.7, Qg=24.59 -> Pg=64.235, Qg=121.365
% INFO    : Gen at bus 9137	: Vg=1.048734 -> Vg=1.0
% INFO    : Gen at bus 9140	: Pg=-37.2, Qg=35.2 -> Pg=25.2, Qg=23.355
% INFO    : Gen at bus 9140	: Vg=1.049339 -> Vg=1.0
% INFO    : Gen at bus 9150	: Pg=860.8, Qg=128.28 -> Pg=666.665, Qg=133.05
% INFO    : Gen at bus 9150	: Vg=1.037874 -> Vg=1.0
% INFO    : Gen at bus 9174	: Pg=-331.4, Qg=165.94 -> Pg=-170.935, Qg=62.92
% INFO    : Gen at bus 9174	: Vg=1.020141 -> Vg=1.0
% INFO    : Gen at bus 9180	: Pg=72.0, Qg=6.19 -> Pg=80.0, Qg=27.86
% INFO    : Gen at bus 9180	: Vg=1.057766 -> Vg=1.0
% INFO    : Gen at bus 9239	: Pg=419.0, Qg=108.18 -> Pg=400.0, Qg=90.49
% INFO    : Gen at bus 9239	: Vg=1.018061 -> Vg=1.0
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
