%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v23.07     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                         23 - July - 2023                         %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%CASE6470RTE
%   AC Power flow data for French system.
%   Please see CASEFORMAT for details on the case file format.
%
%   This case accurately represents the size and complexity of French
%   very high voltage and high voltage transmission network.
%   These data are snapshots of French VHV+HV grid in 2013.
%   These data can be used to validate mathematical methods and tools.
%   These data should NOT be used for operation
%   nor planning of the French or European grids.
%
%   When publishing results using this data, please cite:
%     C. Josz, S. Fliscounakis, J. Maeght, and P. Panciatici,
%     "AC Power Flow Data in MATPOWER and QCQP Format: iTesla, RTE Snapshots, and PEGASE"
%     http://arxiv.org/abs/1603.01533
%
%   Contacts (primary contact for this file : Jean Maeght):
%   Cédric Josz, Stéphane Fliscounakis, Jean Maeght, Patrick Panciatici
%   firstname.lastname@rte-france.com
%   Réseau de Transport d'Electricité (French Transmission System Operator)
%   Département Expertise Système, Immeuble "Le Colbert"
%   9 rue de la Porte de Buc, 78000 Versailles Cedex, France
%   March 4th, 2016
%
%   Copyright (c) 2016 by Cédric Josz, Stéphane Fliscounakis, Jean Maeght,
%   and Patrick Panciatici
%   Licensed under the Creative Commons Attribution 4.0 International license,
%   http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case6470_rte
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	1	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3	 1	 12.5	 -0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4	 1	 44.7	 -0.9	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	5	 1	 12.0	 0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	6	 1	 13.0	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	7	 1	 1.2	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	8	 1	 25.8	 4.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	9	 1	 12.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	10	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	11	 1	 28.8	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	12	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	13	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10263	    1.05526;
	14	 1	 51.5	 1.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	15	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	16	 1	 13.8	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	17	 1	 13.1	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	18	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	19	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	20	 1	 0.9	 -21.5	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	21	 1	 8.3	 -3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	22	 1	 18.0	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	23	 1	 19.2	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	24	 1	 16.1	 -1.6	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	25	 1	 59.9	 -3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	26	 1	 35.1	 8.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	27	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	28	 1	 0.7	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	29	 1	 60.1	 2.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	30	 1	 33.5	 -0.9	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	31	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	32	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	33	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	34	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	35	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	36	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	37	 1	 3.2	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	38	 1	 6.0	 -2.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	39	 1	 41.0	 -3.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	40	 1	 32.6	 0.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	41	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	42	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04249	    0.00000	 63.0	 1	    1.13259	    0.95238;
	43	 1	 3.6	 2.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	44	 1	 13.0	 -0.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	45	 1	 3.9	 1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	46	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	47	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	48	 1	 36.5	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	49	 1	 8.8	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	50	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00331	    0.00000	 63.0	 1	    1.07012	    0.93651;
	51	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	52	 1	 5.0	 2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	53	 1	 2.5	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	54	 1	 -0.4	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	55	 1	 37.6	 6.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	56	 1	 52.1	 13.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	57	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	58	 1	 130.6	 30.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	59	 1	 5.1	 1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	60	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	61	 1	 39.5	 9.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	62	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	63	 1	 15.8	 2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	64	 1	 62.4	 1.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	65	 1	 11.0	 2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	66	 1	 13.2	 -7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	67	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	68	 1	 48.1	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	69	 1	 19.3	 -2.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	70	 1	 10.6	 2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	71	 1	 62.4	 14.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	72	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04736	    0.00000	 225.0	 1	    1.09027	    1.00444;
	73	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04734	    0.00000	 225.0	 1	    1.09025	    1.00444;
	74	 1	 50.4	 -9.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	75	 1	 22.3	 1.8	 0.0	 0.0	 1	    1.02254	    0.00000	 90.0	 1	    1.06730	    0.97778;
	76	 1	 2.6	 -0.4	 0.0	 0.0	 1	    1.03795	    0.00000	 225.0	 1	    1.08923	    0.98667;
	77	 1	 36.8	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	78	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	79	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	80	 1	 32.3	 7.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	81	 1	 36.3	 9.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	82	 1	 11.7	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	83	 1	 77.5	 26.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	84	 1	 -1.6	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	85	 1	 2.1	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	86	 1	 48.9	 3.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	87	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	88	 1	 13.5	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	89	 1	 25.4	 0.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	90	 1	 0.4	 -1.4	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	91	 1	 1.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	92	 1	 28.6	 3.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	93	 1	 2.1	 -2.5	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	94	 1	 17.5	 -4.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	95	 1	 46.5	 7.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	96	 1	 1.5	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	97	 1	 56.4	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	98	 1	 7.4	 -1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	99	 1	 26.9	 3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	100	 1	 53.3	 8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	101	 1	 17.7	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	102	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	103	 1	 18.0	 -1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	104	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	105	 1	 35.5	 1.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	106	 1	 49.8	 7.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	107	 1	 77.6	 8.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	108	 1	 12.6	 -0.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	109	 1	 68.7	 10.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	110	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	111	 1	 36.5	 -7.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	114	 1	 10.8	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	115	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	117	 1	 15.4	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	118	 1	 2.0	 0.8	 0.0	 0.0	 1	    1.02368	    0.00000	 90.0	 1	    1.06958	    0.97778;
	119	 1	 37.2	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	120	 1	 17.0	 -3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	121	 1	 17.6	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	122	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	123	 1	 9.0	 2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	124	 1	 8.0	 -0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	125	 1	 10.5	 -0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	126	 1	 0.3	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	127	 1	 7.8	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	128	 1	 11.8	 7.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	129	 1	 16.7	 11.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	131	 1	 103.0	 13.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	132	 2	 11.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	133	 1	 2.1	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	134	 1	 83.5	 23.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	136	 1	 21.9	 -0.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	137	 2	 9.6	 -4.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	138	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	139	 1	 15.7	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	140	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	141	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	142	 1	 14.8	 5.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	143	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	144	 1	 23.3	 -10.3	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	145	 1	 27.6	 5.9	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	146	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	147	 1	 29.0	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	148	 1	 6.7	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	149	 1	 17.9	 6.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	150	 1	 44.5	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	151	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	152	 1	 38.3	 8.8	 0.0	 7.7	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	153	 1	 23.2	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	155	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	157	 1	 0.3	 3.1	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	158	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	159	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	160	 1	 35.2	 5.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	161	 1	 38.2	 8.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	162	 1	 0.7	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	165	 1	 16.7	 9.2	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	166	 1	 10.1	 2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	167	 1	 13.6	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	168	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	169	 1	 10.8	 -1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	170	 1	 70.4	 11.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	171	 1	 26.5	 -0.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	172	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	173	 1	 27.7	 8.5	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	174	 1	 47.4	 4.6	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	175	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	176	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	177	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	178	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	179	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	180	 1	 0.0	 0.0	 0.0	 -32.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	181	 1	 0.0	 0.0	 0.0	 -32.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	182	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	183	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	184	 1	 12.9	 -4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	185	 1	 16.0	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	186	 1	 4.8	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	187	 1	 5.0	 1.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	188	 1	 28.7	 4.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	189	 1	 1.1	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	190	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	191	 1	 16.2	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	192	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	193	 1	 13.8	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	194	 1	 7.4	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	195	 1	 7.9	 4.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	196	 2	 1.0	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	197	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02538	    0.00000	 63.0	 1	    1.09837	    0.95238;
	198	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02538	    0.00000	 63.0	 1	    1.09837	    0.95238;
	199	 1	 24.4	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	200	 1	 9.3	 -2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	201	 1	 12.8	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	202	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	203	 1	 73.3	 24.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	204	 1	 41.8	 1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	205	 1	 17.5	 2.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	206	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	207	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	208	 1	 50.1	 6.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	209	 1	 32.9	 4.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	210	 1	 14.4	 -1.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	211	 1	 2.9	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	212	 1	 40.8	 5.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	213	 1	 31.8	 12.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	214	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	215	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	216	 1	 37.5	 3.1	 0.0	 30.4	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	217	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	218	 1	 20.7	 -2.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	219	 1	 25.0	 3.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	220	 1	 1.6	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	221	 1	 10.4	 -3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	222	 1	 11.0	 1.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	223	 1	 14.3	 -8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	224	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01118	    0.00000	 225.0	 1	    1.08902	    0.93333;
	225	 1	 40.8	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	226	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	227	 1	 37.6	 6.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	228	 1	 38.6	 44.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	229	 1	 4.0	 0.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	230	 1	 9.9	 -2.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	231	 1	 12.4	 -5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	232	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	233	 1	 6.0	 -2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	234	 1	 6.4	 1.0	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	235	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	236	 1	 23.9	 8.5	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	237	 1	 13.7	 3.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	238	 1	 26.6	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	239	 1	 46.2	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	240	 1	 21.4	 -0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	241	 1	 52.1	 3.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	242	 1	 41.4	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	243	 1	 45.4	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	244	 1	 45.5	 4.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	245	 1	 26.7	 -3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	246	 1	 53.1	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	247	 1	 12.8	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	248	 2	 12.3	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	249	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	250	 1	 28.9	 9.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	251	 1	 24.0	 -5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	252	 1	 23.5	 -7.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	253	 1	 6.1	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	254	 1	 9.5	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	255	 1	 48.5	 6.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	256	 1	 16.9	 0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	257	 1	 6.9	 -1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	258	 2	 4.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	259	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	260	 2	 -0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	261	 1	 29.7	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	262	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	263	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	264	 1	 0.0	 0.0	 0.0	 80.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	265	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	266	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05921	    0.00000	 380.0	 1	    1.10526	    1.01316;
	267	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	268	 1	 26.3	 6.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	269	 1	 57.3	 10.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	270	 1	 10.5	 9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	271	 1	 22.7	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	272	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	273	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	274	 1	 6.7	 7.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	275	 1	 55.4	 0.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	276	 1	 43.8	 8.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	277	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	279	 1	 1.8	 4.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	280	 1	 -1.5	 4.3	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	281	 1	 10.0	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	282	 1	 48.0	 11.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	283	 1	 12.8	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	284	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	285	 1	 10.8	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	286	 1	 14.7	 3.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	287	 1	 1.4	 5.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	288	 1	 19.4	 7.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	289	 1	 25.8	 -4.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	290	 1	 33.5	 -2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	291	 1	 43.4	 2.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	292	 1	 7.2	 2.9	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	293	 1	 15.3	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	294	 1	 0.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	295	 1	 42.0	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	296	 1	 0.0	 -0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	297	 1	 19.9	 2.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	298	 1	 7.7	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	299	 1	 5.0	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	300	 1	 10.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	301	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	302	 1	 53.3	 18.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	303	 1	 2.9	 0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	304	 1	 12.3	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	305	 1	 33.3	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	306	 1	 30.8	 -4.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	307	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	308	 1	 14.0	 -0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	309	 1	 21.3	 -2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	310	 1	 0.5	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	311	 1	 9.0	 2.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	312	 1	 14.0	 4.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	313	 1	 0.7	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	314	 1	 8.0	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	315	 1	 28.8	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	316	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	317	 1	 21.2	 -1.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	318	 1	 32.2	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	319	 2	 3.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	320	 1	 13.5	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	321	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	322	 1	 31.1	 4.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	324	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	325	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	326	 1	 22.0	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	327	 2	 17.1	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	328	 1	 1.1	 20.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	329	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	330	 1	 31.8	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	331	 1	 58.7	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	332	 1	 71.1	 -5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	333	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	334	 2	 9.2	 0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	335	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	336	 1	 7.9	 -3.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	337	 1	 17.0	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	338	 2	 0.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	339	 1	 13.2	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	340	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	341	 1	 16.5	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	342	 1	 21.6	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	343	 1	 7.0	 -11.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	344	 1	 9.4	 -3.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	345	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	346	 1	 12.4	 -3.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	347	 1	 24.7	 -8.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	348	 1	 12.5	 -0.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	349	 1	 -1.3	 -0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	350	 1	 47.8	 5.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	351	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	352	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	353	 1	 9.4	 3.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	354	 1	 3.4	 5.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	355	 1	 28.5	 -9.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	356	 1	 3.3	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	357	 1	 10.0	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	358	 2	 6.0	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	359	 1	 18.4	 5.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	360	 1	 21.5	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	361	 1	 26.4	 1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	362	 1	 44.6	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	364	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	365	 1	 9.3	 4.2	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	366	 2	 -1.8	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	367	 1	 -0.1	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	368	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	369	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	370	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	371	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	372	 1	 44.9	 8.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	373	 1	 10.7	 2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	374	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	375	 1	 21.6	 6.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	376	 1	 23.6	 2.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	377	 1	 13.4	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	378	 1	 47.4	 -2.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	379	 1	 4.9	 -2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	380	 1	 34.9	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	381	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	382	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	383	 1	 46.5	 8.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	384	 1	 13.8	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	385	 1	 44.6	 16.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	386	 1	 17.7	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	387	 1	 16.0	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	388	 1	 42.8	 11.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	389	 1	 7.4	 -3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	390	 1	 42.1	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	391	 1	 30.0	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	392	 1	 1.9	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	393	 1	 22.4	 -6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	394	 1	 23.2	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	395	 1	 8.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	396	 1	 6.0	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	397	 1	 33.0	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	398	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	399	 1	 13.0	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	400	 1	 7.0	 0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	401	 1	 2.8	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	402	 1	 20.4	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	403	 1	 4.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	404	 1	 20.3	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	405	 1	 22.5	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	406	 1	 31.1	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	407	 1	 5.3	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	408	 1	 51.7	 -1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	409	 1	 1.0	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	410	 1	 10.9	 -4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	411	 1	 17.8	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	412	 1	 16.6	 -0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	413	 1	 23.8	 -17.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	414	 1	 27.8	 -0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	415	 1	 -0.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	416	 1	 6.5	 -2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	417	 1	 5.5	 -42.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	418	 1	 16.1	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	419	 1	 12.0	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	420	 1	 26.5	 7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	421	 1	 -5.4	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	422	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	423	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	424	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	425	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	426	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	427	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	428	 1	 0.3	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	429	 1	 6.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	430	 1	 53.8	 7.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	431	 1	 96.4	 23.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	432	 1	 12.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	433	 1	 23.7	 -3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	434	 1	 0.3	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	435	 1	 14.3	 -5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	436	 1	 35.5	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	437	 1	 23.1	 -7.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	438	 1	 1.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	439	 1	 10.9	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	440	 1	 11.5	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	441	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	442	 1	 4.2	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	443	 1	 22.9	 1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	444	 1	 10.0	 3.2	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	445	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	446	 1	 25.8	 5.1	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	447	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	448	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	450	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04017	    0.00000	 225.0	 1	    1.09367	    0.98667;
	451	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	452	 1	 1.6	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	453	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	454	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	455	 1	 23.5	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	456	 1	 8.9	 0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	457	 1	 23.9	 2.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	458	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	460	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	461	 1	 17.0	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	462	 1	 13.9	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	463	 1	 43.3	 -1.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	464	 1	 -0.2	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	465	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.98556	    0.00000	 20.0	 1	    1.17111	    0.80000;
	466	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	467	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	468	 1	 70.8	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	469	 1	 28.4	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	470	 1	 2.2	 -2.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	471	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	472	 1	 -0.3	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	473	 1	 -176.2	 107.9	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.15789	    0.94737;
	474	 1	 -165.2	 118.9	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.15789	    0.94737;
	475	 1	 53.6	 1.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	479	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	480	 2	 9.9	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	482	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	483	 1	 14.9	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	484	 1	 44.7	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	485	 1	 41.2	 -3.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	486	 1	 36.9	 4.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	487	 1	 10.4	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	488	 1	 46.3	 14.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	489	 1	 0.9	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	490	 1	 29.6	 5.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	491	 1	 -36.0	 9.4	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	492	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	493	 1	 23.0	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	494	 1	 -2.8	 -5.7	 0.0	 0.0	 1	    1.04783	    0.00000	 225.0	 1	    1.09566	    1.00000;
	495	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	496	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	497	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	498	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	499	 1	 2.0	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	500	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04034	    0.00000	 225.0	 1	    1.09401	    0.98667;
	501	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04041	    0.00000	 225.0	 1	    1.09416	    0.98667;
	502	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	503	 1	 23.6	 -1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	504	 1	 30.5	 -7.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	505	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	506	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	507	 1	 8.0	 4.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	508	 1	 50.5	 2.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	509	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	510	 1	 34.9	 3.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	511	 1	 37.1	 -1.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	512	 1	 37.0	 6.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	513	 1	 6.9	 5.8	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	514	 1	 1.7	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	515	 1	 27.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	516	 1	 32.6	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	517	 1	 19.6	 7.3	 0.0	 0.0	 1	    0.96825	    0.00000	 63.0	 1	    1.04762	    0.88889;
	518	 1	 31.6	 1.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	519	 1	 33.6	 -7.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	520	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	521	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	522	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	523	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	524	 1	 9.2	 4.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	525	 1	 4.1	 19.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	526	 1	 -3.2	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	527	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	528	 1	 4.7	 1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	529	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	530	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	531	 1	 23.1	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	532	 1	 37.5	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	533	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	534	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	535	 1	 19.0	 -1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	536	 1	 30.6	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	537	 1	 18.8	 4.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	538	 1	 9.0	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	539	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	540	 1	 43.2	 3.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	541	 1	 47.2	 7.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	542	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	543	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	544	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	545	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	546	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	547	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	548	 1	 29.8	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	549	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	550	 1	 52.6	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	551	 1	 31.3	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	552	 1	 1.8	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	553	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	554	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	555	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	556	 1	 49.9	 7.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	557	 1	 31.8	 -1.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	558	 1	 16.4	 7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	559	 1	 10.9	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	560	 1	 26.7	 -3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	561	 1	 18.3	 -1.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	562	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	563	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	564	 1	 11.6	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	565	 1	 38.0	 8.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	566	 1	 -0.1	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	567	 1	 11.9	 5.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	568	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	569	 1	 19.1	 1.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	570	 1	 14.9	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	571	 1	 42.9	 -4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	572	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	573	 1	 6.3	 2.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	574	 1	 1.0	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	575	 1	 7.0	 -0.9	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	576	 1	 34.3	 3.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	577	 1	 6.6	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	578	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	582	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	583	 1	 1.0	 -3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	584	 1	 21.4	 3.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	585	 2	 28.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	586	 1	 28.9	 1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	587	 1	 10.5	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	588	 2	 13.5	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	589	 1	 133.0	 34.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	590	 1	 21.6	 -4.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	591	 1	 14.6	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	592	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	593	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04783	    0.00000	 225.0	 1	    1.09565	    1.00000;
	594	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	595	 1	 8.0	 -1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	596	 1	 9.9	 -1.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	597	 1	 29.1	 4.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	598	 1	 7.1	 2.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	599	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	600	 1	 -0.3	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	601	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	602	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	604	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	605	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	606	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	607	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	608	 1	 3.0	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	609	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	610	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	611	 1	 33.1	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	612	 1	 20.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	613	 1	 11.9	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	614	 1	 40.6	 16.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	615	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	616	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	617	 1	 14.6	 -4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	618	 1	 17.4	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	619	 1	 1.8	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	620	 1	 1.8	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	621	 1	 1.3	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	622	 1	 13.0	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	623	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	624	 1	 38.2	 -8.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	625	 1	 8.5	 -0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	626	 1	 16.1	 2.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	627	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	628	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02618	    0.00000	 90.0	 1	    1.07459	    0.97778;
	629	 1	 32.1	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	630	 1	 47.2	 6.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	631	 1	 -0.9	 0.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	632	 2	 12.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	633	 1	 9.7	 -0.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	634	 1	 23.7	 2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	635	 2	 32.4	 3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	636	 1	 19.1	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	637	 1	 6.6	 -2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	638	 1	 2.9	 -1.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	639	 1	 34.2	 2.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	640	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	641	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	642	 1	 13.2	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	643	 1	 12.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	644	 1	 18.9	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	645	 1	 31.9	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	646	 1	 31.8	 6.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	647	 1	 41.4	 5.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	648	 1	 43.4	 10.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	649	 1	 11.5	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	650	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	651	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	652	 1	 34.4	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	653	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	654	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	655	 1	 7.8	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	656	 1	 39.8	 6.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	657	 1	 28.1	 13.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	658	 1	 6.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	659	 1	 4.5	 -1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	660	 1	 43.7	 4.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	661	 1	 -0.0	 -14.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	662	 1	 27.4	 -5.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	663	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	664	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	665	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	666	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	667	 1	 0.0	 0.0	 0.0	 10.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	668	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	669	 1	 12.6	 -7.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	670	 1	 34.2	 -0.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	671	 1	 27.8	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	672	 1	 1.3	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	673	 1	 6.0	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	674	 1	 13.7	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	675	 1	 4.8	 2.5	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	676	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	677	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	678	 1	 12.0	 -0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	679	 1	 14.8	 -4.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	680	 1	 71.2	 9.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	681	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	682	 1	 30.1	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	683	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	684	 1	 -3.5	 -0.2	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	685	 1	 1.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	686	 1	 -3.5	 -0.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	687	 1	 1.5	 0.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	688	 1	 0.4	 0.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	689	 1	 9.3	 -6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	690	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	691	 1	 38.0	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	692	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	693	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	694	 1	 38.3	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	695	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	696	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	697	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	698	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	699	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	700	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	701	 1	 39.2	 12.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	702	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	703	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	704	 2	 7.8	 -1.3	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	705	 1	 23.8	 2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	706	 1	 20.2	 -1.5	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	707	 1	 25.2	 1.5	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	708	 1	 24.2	 -1.5	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	711	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	712	 1	 0.4	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	713	 1	 17.5	 -2.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	714	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	715	 1	 1.7	 2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	716	 1	 29.8	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	717	 1	 23.9	 -8.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	718	 1	 12.1	 -2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	719	 1	 36.3	 5.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	720	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04688	    0.00000	 225.0	 1	    1.08932	    1.00444;
	721	 1	 47.7	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	722	 1	 28.2	 -2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	723	 1	 31.4	 3.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	724	 1	 15.3	 8.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	725	 1	 8.8	 -1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	726	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02000	    0.00000	 225.0	 1	    1.08889	    0.95111;
	727	 1	 27.3	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	728	 1	 16.4	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	729	 1	 20.3	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	730	 1	 46.7	 10.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	731	 1	 14.0	 1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	732	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	733	 1	 1.8	 -3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	734	 1	 7.0	 1.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	735	 1	 28.2	 -5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	736	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	737	 1	 43.7	 -1.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	738	 1	 62.7	 11.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	739	 1	 22.0	 2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	740	 1	 12.0	 -3.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	741	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	742	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	743	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	744	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	745	 2	 13.9	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	746	 1	 12.9	 0.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	747	 1	 3.0	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	748	 1	 13.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	749	 1	 10.5	 -1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	750	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	751	 1	 10.4	 4.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	752	 1	 21.7	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	753	 1	 22.9	 1.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	754	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	755	 1	 44.2	 2.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	756	 1	 78.1	 11.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	757	 2	 2.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	758	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	759	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	760	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	761	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.82500	    0.00000	 20.0	 1	    1.15000	    0.50000;
	762	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	763	 1	 15.0	 -3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	764	 1	 21.6	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	765	 1	 1.1	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	766	 1	 17.3	 4.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	767	 1	 0.0	 0.0	 0.0	 34.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	768	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	769	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	770	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	771	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	772	 1	 66.4	 18.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	773	 1	 9.9	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	774	 1	 39.8	 5.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	775	 1	 27.4	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	776	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	777	 1	 9.0	 5.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	778	 1	 24.0	 7.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	779	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	780	 1	 5.8	 4.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	781	 1	 19.0	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	782	 1	 22.3	 1.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	783	 1	 89.0	 17.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	784	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	785	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	786	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	787	 1	 -6.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	788	 1	 -16.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	789	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	790	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	791	 1	 10.0	 4.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	792	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	793	 1	 2.4	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	794	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	795	 1	 55.3	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	796	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	797	 1	 12.0	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	798	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	799	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	800	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	801	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	802	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	803	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	804	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	805	 1	 11.0	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	806	 1	 8.9	 -4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	807	 1	 62.4	 21.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	808	 1	 -0.6	 0.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	809	 1	 -0.5	 -4.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	810	 1	 53.8	 11.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	811	 1	 12.1	 -2.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	812	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	813	 1	 16.4	 -0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	814	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	815	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	816	 1	 63.6	 11.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	817	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	818	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	819	 1	 19.8	 -1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	820	 1	 32.0	 3.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	821	 1	 25.3	 4.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	822	 1	 5.7	 1.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	823	 1	 0.9	 1.6	 0.0	 0.0	 1	    1.02667	    0.00000	 150.0	 1	    1.10667	    0.94667;
	824	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	825	 2	 0.0	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	826	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	827	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	828	 1	 45.0	 4.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	829	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	830	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	831	 1	 -0.4	 -1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	832	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	833	 1	 37.7	 -6.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	834	 1	 42.4	 -7.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	835	 2	 -1.0	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	836	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	837	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	838	 1	 7.9	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	839	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	840	 1	 39.4	 -3.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	841	 1	 2.0	 0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	842	 1	 28.2	 12.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	843	 1	 9.8	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	844	 1	 26.5	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	845	 1	 14.0	 2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	846	 1	 19.0	 -3.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	847	 1	 11.0	 -2.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	848	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	849	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	850	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	851	 1	 12.6	 -0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	852	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.08889	    0.91111;
	853	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	854	 1	 7.0	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	855	 1	 11.8	 4.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	856	 2	 13.1	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	857	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	858	 1	 25.9	 5.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	859	 1	 20.8	 2.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	860	 1	 19.9	 -9.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	861	 1	 -0.9	 -0.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	862	 1	 6.1	 -0.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	863	 2	 3.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	864	 2	 12.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	865	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	866	 1	 0.0	 -0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	867	 1	 -0.0	 -6.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	868	 1	 40.0	 4.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	869	 1	 17.0	 9.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	870	 1	 22.9	 8.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	871	 1	 -4.5	 -3.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	872	 1	 47.7	 2.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	873	 1	 5.0	 4.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	874	 1	 48.7	 1.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	875	 1	 19.3	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	876	 1	 23.3	 3.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	877	 1	 1.9	 -1.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	878	 1	 1.9	 5.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	879	 1	 11.5	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	880	 1	 30.0	 11.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	881	 1	 55.5	 0.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	882	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	883	 1	 47.5	 9.7	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	884	 1	 3.9	 0.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	885	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	886	 1	 47.4	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	887	 1	 51.2	 9.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	888	 1	 40.7	 8.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	889	 2	 4.0	 -0.7	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	890	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	891	 1	 38.1	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	892	 1	 6.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	893	 1	 27.4	 4.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	894	 1	 14.9	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	895	 1	 -8.5	 2.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	896	 1	 23.5	 22.6	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	897	 1	 -18.6	 -27.4	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	898	 1	 -38.9	 -18.6	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	899	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	900	 1	 5.0	 3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	901	 1	 10.4	 -1.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	902	 1	 23.7	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	903	 1	 23.7	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	904	 1	 36.1	 2.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	905	 1	 75.1	 14.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	906	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	907	 1	 17.9	 2.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	908	 1	 31.9	 1.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	909	 1	 15.0	 -3.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	910	 1	 5.9	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	911	 1	 0.8	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	912	 1	 7.8	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	913	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	914	 1	 0.0	 0.0	 0.0	 -64.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	915	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	916	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	917	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	918	 1	 8.3	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	919	 1	 30.0	 3.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	920	 1	 22.4	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	921	 1	 0.9	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	922	 1	 0.9	 -5.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	923	 1	 -3.2	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	924	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	925	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	926	 1	 24.0	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	927	 1	 13.5	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	928	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	929	 1	 47.8	 7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	930	 1	 1.2	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	931	 1	 29.0	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	932	 1	 0.0	 0.0	 0.0	 -58.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	933	 1	 0.0	 0.0	 0.0	 -58.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	934	 1	 0.0	 0.0	 0.0	 -58.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	935	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	936	 1	 4.3	 -0.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	937	 1	 3.4	 7.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	938	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	939	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	940	 1	 13.1	 1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	941	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	942	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00889	    0.00000	 225.0	 1	    1.08889	    0.92889;
	943	 1	 115.8	 -8.7	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	944	 1	 7.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	945	 1	 51.2	 11.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	946	 1	 0.1	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	947	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	948	 2	 0.4	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	949	 1	 25.7	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	950	 1	 15.4	 -2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	951	 1	 9.3	 1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	952	 1	 38.1	 4.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	953	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	954	 1	 8.7	 0.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	955	 1	 1.4	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	956	 1	 12.8	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	957	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	958	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	959	 1	 1.0	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	960	 1	 2.2	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	961	 1	 -0.7	 -0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	962	 1	 8.3	 -4.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	963	 1	 34.1	 -1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	964	 1	 46.8	 16.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	965	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04590	    0.00000	 225.0	 1	    1.08735	    1.00444;
	966	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	967	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	968	 1	 -0.2	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	969	 2	 48.2	 30.9	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	970	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	971	 1	 42.0	 -5.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	972	 1	 57.9	 20.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	973	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	974	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	975	 1	 0.7	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	976	 1	 33.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	977	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	978	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	979	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	980	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	981	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	982	 1	 16.3	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	983	 1	 58.0	 11.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	984	 1	 8.6	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	985	 1	 31.4	 -1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	986	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	987	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	988	 1	 7.7	 -0.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	989	 1	 9.0	 0.3	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	990	 1	 9.0	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	991	 2	 -1.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	992	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	993	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	994	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	995	 1	 17.9	 -3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	996	 1	 17.6	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	997	 1	 12.5	 -0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	998	 1	 7.5	 2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	999	 1	 0.0	 0.0	 0.0	 -64.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1000	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1001	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1002	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1003	 1	 46.2	 9.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1004	 1	 2.0	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1005	 1	 2.7	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1006	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04705	    0.00000	 225.0	 1	    1.09411	    1.00000;
	1007	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1008	 1	 17.0	 3.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1009	 1	 9.9	 -2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1010	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1011	 1	 36.9	 -1.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1012	 1	 91.6	 9.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1013	 2	 -3.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1014	 1	 31.5	 -2.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1015	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1016	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1017	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1018	 1	 9.0	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1019	 1	 46.4	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1020	 1	 14.6	 6.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1021	 1	 62.9	 12.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1022	 1	 29.2	 3.9	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1023	 1	 19.2	 4.8	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1024	 1	 33.5	 -6.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1025	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1026	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1027	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1028	 1	 1.0	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1029	 1	 30.4	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1030	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02915	    0.00000	 63.0	 1	    1.10591	    0.95238;
	1031	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02917	    0.00000	 63.0	 1	    1.10596	    0.95238;
	1032	 1	 71.3	 5.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1033	 1	 5.0	 -3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1034	 1	 32.0	 6.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1035	 1	 15.2	 3.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1036	 1	 0.0	 -7.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1037	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1038	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1039	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1040	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1041	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1042	 1	 18.1	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1043	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1044	 1	 39.6	 -1.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1045	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1046	 1	 -10.6	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1047	 1	 28.7	 5.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1048	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1050	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1051	 1	 54.8	 10.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1052	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1053	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1054	 1	 12.5	 -1.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1055	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1057	 1	 23.9	 0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1058	 1	 15.0	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1059	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1060	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1061	 2	 10.7	 2.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1062	 1	 47.0	 20.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1063	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1064	 1	 25.9	 9.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1065	 1	 5.0	 0.4	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1066	 1	 -17.4	 12.9	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1067	 1	 5.6	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1068	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98893	    0.00000	 225.0	 1	    1.08897	    0.88889;
	1069	 1	 12.6	 -0.4	 0.0	 0.0	 1	    0.96825	    0.00000	 63.0	 1	    1.04762	    0.88889;
	1070	 2	 6.3	 10.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1071	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1072	 1	 0.4	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1073	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1074	 1	 11.4	 1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1075	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1076	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1077	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1078	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1079	 1	 -1.7	 -2.9	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1080	 1	 -12.6	 -2.9	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1081	 1	 20.9	 3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1082	 1	 41.2	 -3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1083	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1084	 1	 -3.7	 -4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1085	 1	 1.5	 -3.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1086	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1087	 1	 19.4	 1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1088	 1	 -3.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1089	 1	 12.8	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1090	 1	 10.1	 0.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1091	 1	 5.0	 -2.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1092	 1	 80.7	 8.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1093	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1094	 1	 4.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1095	 1	 35.2	 2.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1096	 1	 47.2	 11.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1097	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1098	 1	 27.1	 1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1099	 1	 39.6	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1100	 1	 53.9	 15.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1101	 1	 16.2	 -0.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1102	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1103	 1	 20.0	 3.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1104	 1	 17.2	 -0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1105	 1	 18.6	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1106	 1	 32.1	 -4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1107	 1	 22.1	 -4.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1108	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1109	 1	 4.0	 1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1110	 1	 29.8	 -0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1111	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1112	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1113	 1	 12.3	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1114	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1115	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1117	 1	 1.0	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1118	 1	 10.0	 7.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1119	 1	 51.9	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1120	 1	 21.0	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1121	 1	 15.6	 2.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1122	 1	 21.1	 -1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1123	 1	 53.2	 5.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1124	 1	 20.3	 2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1125	 1	 20.9	 4.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1126	 1	 23.0	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1127	 1	 10.6	 -8.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	1128	 1	 -2.2	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1129	 2	 1.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1131	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1132	 1	 23.4	 -2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1133	 1	 1.1	 -2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1134	 1	 0.0	 0.0	 0.0	 29.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1136	 1	 47.6	 5.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1137	 1	 18.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1138	 1	 0.8	 -14.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1139	 1	 33.7	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1140	 1	 3.3	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1141	 1	 -0.1	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1142	 1	 53.2	 7.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1143	 1	 19.5	 0.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1144	 1	 16.1	 5.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1145	 1	 31.2	 -4.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1146	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1147	 1	 41.6	 0.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1148	 1	 10.0	 -3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1149	 1	 30.6	 -0.7	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1150	 1	 35.3	 6.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1151	 1	 10.5	 -3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1152	 1	 12.2	 -3.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1153	 1	 46.3	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1154	 1	 8.0	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1155	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1157	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1158	 1	 28.5	 4.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1159	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1160	 1	 67.3	 15.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1161	 1	 24.9	 11.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1162	 1	 28.0	 7.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1165	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1166	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1167	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1168	 1	 3.2	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1169	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1170	 1	 5.0	 -10.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1171	 1	 22.0	 -3.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1172	 1	 62.9	 32.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1174	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1175	 1	 0.4	 1.2	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1176	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1177	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1178	 1	 -0.5	 3.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1179	 1	 6.0	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1180	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1181	 1	 10.1	 4.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1182	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1183	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1184	 1	 1.8	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1185	 1	 0.3	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1186	 1	 53.4	 13.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1187	 1	 42.5	 6.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1188	 1	 -1.3	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1189	 1	 135.3	 15.6	 0.0	 -80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1190	 1	 24.4	 6.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1191	 1	 13.7	 -4.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1192	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1193	 1	 18.2	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1194	 1	 36.1	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1195	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1196	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1197	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1198	 1	 0.8	 2.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1199	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1200	 1	 30.7	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1201	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1202	 1	 34.3	 2.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1203	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1204	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1205	 1	 50.0	 2.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1206	 1	 21.2	 -1.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1207	 1	 18.5	 3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1208	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1209	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1210	 1	 0.0	 0.0	 0.0	 40.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1211	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1212	 1	 6.8	 2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1213	 1	 18.7	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1214	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1215	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1216	 1	 19.8	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1217	 1	 0.0	 2.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1218	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10263	    1.05526;
	1219	 1	 8.0	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1220	 1	 8.0	 -2.6	 0.0	 0.0	 1	    1.02852	    0.00000	 90.0	 1	    1.07926	    0.97778;
	1221	 1	 41.4	 7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1222	 1	 16.5	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1223	 1	 1.2	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1224	 1	 25.6	 2.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1225	 1	 32.0	 -8.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1226	 1	 24.1	 15.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1227	 1	 15.9	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1228	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1229	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1230	 1	 0.0	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1231	 1	 1.2	 -0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1232	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1233	 1	 36.8	 12.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1234	 1	 13.9	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1235	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1236	 1	 42.9	 6.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1237	 1	 27.8	 -2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1238	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1239	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1240	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1241	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1242	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1243	 1	 25.6	 -2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1244	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1245	 1	 6.9	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1246	 1	 35.9	 7.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1247	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1248	 1	 34.3	 4.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1249	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1250	 1	 0.0	 0.0	 0.0	 9.0	 1	    0.82500	    0.00000	 20.0	 1	    1.15000	    0.50000;
	1251	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1252	 1	 53.6	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1253	 1	 29.9	 2.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1254	 1	 21.7	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1255	 1	 58.5	 9.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1256	 1	 0.0	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1258	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1259	 1	 1.6	 -1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1260	 1	 12.0	 -1.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1261	 1	 0.3	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1262	 1	 12.8	 -6.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1263	 1	 6.0	 4.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1265	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1266	 1	 8.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1267	 1	 33.1	 -4.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1268	 1	 76.9	 11.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1269	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1270	 1	 9.9	 2.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1271	 1	 28.0	 -0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1272	 1	 5.9	 1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1273	 1	 13.5	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1274	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1276	 1	 2.1	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1277	 1	 39.0	 5.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1278	 1	 35.0	 8.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1279	 1	 0.7	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1280	 1	 37.8	 -1.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1281	 1	 14.3	 1.5	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1282	 1	 4.7	 -9.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1283	 1	 0.2	 -0.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1284	 1	 24.0	 4.2	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1285	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1286	 1	 48.6	 22.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1287	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1288	 1	 11.3	 12.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1289	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1290	 2	 -0.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1291	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1292	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1293	 1	 11.2	 -4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1294	 1	 19.6	 -6.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1295	 1	 0.8	 0.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1296	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1297	 1	 -22.2	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1298	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1300	 1	 42.3	 4.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1301	 1	 35.4	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1302	 1	 27.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1303	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1304	 1	 9.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1305	 1	 15.7	 1.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1306	 1	 32.9	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1307	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1308	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1309	 1	 -3.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1310	 1	 19.0	 -3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1311	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1312	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1313	 1	 0.2	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1314	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1315	 1	 1.1	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1316	 1	 31.5	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1317	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1318	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1319	 1	 40.3	 5.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1320	 1	 35.3	 -6.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1321	 1	 2.1	 1.6	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1322	 1	 0.1	 0.5	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1323	 1	 2.2	 0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1324	 1	 16.0	 -0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1325	 1	 23.4	 -1.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1326	 1	 33.4	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1327	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1328	 1	 19.0	 -4.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1329	 2	 0.0	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1330	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1331	 1	 34.3	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1332	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1333	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1334	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1335	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1336	 1	 15.7	 2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1337	 1	 0.0	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1338	 1	 -0.7	 -0.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1339	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1340	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1341	 1	 6.7	 -0.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1342	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03842	    0.00000	 225.0	 1	    1.09018	    0.98667;
	1344	 2	 -22.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1345	 1	 19.2	 8.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1346	 1	 12.0	 6.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1347	 1	 41.6	 -3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1348	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1349	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1350	 1	 13.9	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1351	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1352	 1	 7.0	 2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1353	 1	 25.8	 -0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1354	 1	 20.3	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1355	 1	 20.7	 -3.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1356	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1357	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1358	 1	 16.1	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1359	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99778	    0.00000	 225.0	 1	    1.08889	    0.90667;
	1360	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1361	 1	 4.0	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1362	 1	 19.2	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1364	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1365	 1	 2.1	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1366	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1367	 1	 17.1	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1368	 1	 5.9	 -3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1369	 1	 21.8	 -5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1370	 1	 47.0	 12.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1371	 1	 45.3	 14.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1372	 1	 -0.2	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1373	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1374	 1	 6.8	 1.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1375	 1	 104.4	 22.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1376	 1	 15.3	 8.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1377	 1	 9.2	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1378	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1379	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00445	    0.00000	 225.0	 1	    1.08889	    0.92000;
	1380	 1	 15.6	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1381	 1	 0.0	 0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1382	 1	 14.9	 -5.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1383	 1	 31.3	 3.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1384	 1	 16.0	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1385	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1386	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1387	 1	 1.8	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1388	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1389	 1	 4.4	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1390	 1	 31.7	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1391	 1	 -0.4	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1392	 1	 14.4	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1393	 1	 10.2	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1394	 1	 5.0	 2.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1395	 1	 16.9	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1396	 1	 49.0	 8.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1397	 1	 0.0	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1398	 1	 24.0	 3.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1399	 1	 -2.0	 0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1400	 1	 23.9	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1401	 1	 6.1	 -5.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1402	 1	 0.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1403	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1404	 1	 5.0	 -3.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1405	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1406	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1407	 1	 39.9	 2.9	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1408	 1	 22.7	 -0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1409	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1410	 1	 19.6	 -1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1411	 1	 14.0	 2.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1412	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1413	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1414	 1	 35.8	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1415	 1	 20.4	 -1.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1416	 1	 37.8	 6.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1417	 1	 32.3	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1418	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1419	 1	 2.8	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1420	 1	 56.3	 6.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1421	 1	 21.9	 2.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1422	 1	 10.0	 3.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1423	 2	 33.9	 19.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1424	 1	 29.0	 5.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1425	 1	 34.7	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1426	 1	 0.5	 1.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1427	 1	 22.2	 5.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1428	 1	 0.1	 -2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1429	 1	 41.8	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1430	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1431	 1	 66.6	 9.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1432	 1	 19.3	 -4.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1433	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1434	 1	 37.4	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1435	 1	 35.6	 -0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1436	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1437	 1	 6.0	 -0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1438	 1	 21.9	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1439	 1	 18.1	 -0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1440	 1	 32.4	 -3.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1441	 1	 18.3	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1442	 1	 11.9	 3.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1443	 1	 20.6	 3.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1445	 1	 9.8	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1446	 1	 0.0	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1447	 1	 46.6	 13.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1448	 1	 -0.7	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1449	 1	 59.0	 15.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1450	 1	 19.0	 -2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1451	 1	 2.0	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1452	 1	 2.0	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1453	 1	 29.8	 -1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1454	 1	 19.9	 -9.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1455	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1456	 1	 10.0	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1457	 1	 0.0	 0.0	 0.0	 6.0	 1	    0.82500	    0.00000	 20.0	 1	    1.15000	    0.50000;
	1458	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1459	 1	 15.7	 2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1460	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1461	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04638	    0.00000	 225.0	 1	    1.08833	    1.00444;
	1462	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1463	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1464	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1465	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99778	    0.00000	 225.0	 1	    1.08889	    0.90667;
	1466	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1467	 1	 17.4	 -1.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1468	 1	 12.0	 1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1469	 1	 62.0	 11.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1470	 1	 50.7	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1471	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1472	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1473	 1	 28.7	 6.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1474	 1	 43.6	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1475	 1	 9.9	 -1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1476	 1	 4.9	 0.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1477	 1	 -0.9	 8.6	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1479	 1	 30.7	 -4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02917	    0.00000	 63.0	 1	    1.10595	    0.95238;
	1481	 1	 63.1	 26.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1482	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04247	    0.00000	 63.0	 1	    1.13256	    0.95238;
	1483	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	1484	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02667	    0.00000	 150.0	 1	    1.10667	    0.94667;
	1485	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1486	 1	 41.6	 3.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1487	 1	 3.2	 -1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1488	 1	 11.0	 0.1	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1489	 1	 27.1	 4.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1490	 1	 25.7	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1491	 1	 20.8	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1492	 1	 -0.4	 -6.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1493	 1	 28.4	 1.9	 0.0	 0.0	 1	    1.02225	    0.00000	 90.0	 1	    1.06672	    0.97778;
	1494	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1495	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1496	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1497	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	1498	 1	 13.3	 5.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1499	 1	 11.0	 4.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1500	 1	 31.7	 3.8	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1501	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1502	 1	 11.6	 -83.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1503	 1	 147.0	 90.7	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	1504	 1	 11.1	 1.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1505	 1	 14.7	 3.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1506	 1	 71.9	 5.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1507	 1	 16.9	 -6.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1508	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1509	 1	 12.6	 1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1510	 1	 11.8	 0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1511	 1	 27.6	 -13.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1512	 1	 11.4	 -6.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1513	 1	 32.8	 -0.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1514	 1	 36.1	 7.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1515	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1516	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1517	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1518	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1519	 1	 33.5	 4.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1520	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	1521	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	1522	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	1523	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	1524	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 225.0	 1	    1.15556	    0.88889;
	1525	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 225.0	 1	    1.15556	    0.88889;
	1526	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1527	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1528	 1	 44.8	 -0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1529	 1	 25.6	 2.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1530	 1	 2.0	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1531	 1	 35.1	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1532	 1	 18.8	 2.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1533	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1534	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1535	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1537	 1	 17.6	 -3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1538	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1539	 1	 48.8	 15.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1540	 1	 5.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1541	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1542	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1543	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1544	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1545	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1546	 1	 10.9	 -5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1547	 1	 9.8	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1548	 1	 21.2	 1.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1549	 1	 25.5	 6.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1550	 1	 27.5	 1.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1551	 1	 21.6	 -7.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1552	 1	 7.0	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1553	 1	 29.6	 -6.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1554	 1	 31.7	 2.3	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1555	 1	 23.4	 2.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1556	 1	 39.4	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1557	 1	 3.0	 0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1558	 1	 28.1	 4.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1559	 1	 24.8	 7.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1560	 2	 31.8	 7.7	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1561	 1	 30.9	 0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1562	 1	 20.2	 18.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1563	 1	 53.1	 2.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1564	 1	 44.0	 2.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1565	 1	 40.0	 7.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1566	 1	 17.5	 0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1567	 1	 14.3	 1.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1568	 1	 25.7	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1569	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1570	 1	 23.6	 2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1571	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	1572	 1	 12.3	 14.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1573	 1	 19.6	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1574	 1	 3.9	 -0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1575	 1	 46.2	 9.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1576	 1	 38.2	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1577	 1	 23.1	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1578	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1582	 1	 22.8	 4.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1583	 1	 63.4	 11.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1584	 2	 34.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1585	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1586	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1587	 1	 27.8	 9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1588	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1589	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	1590	 1	 27.7	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1591	 1	 5.7	 2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1592	 1	 23.5	 -1.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1593	 1	 24.5	 17.2	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	1594	 1	 21.7	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1595	 1	 14.7	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1596	 1	 40.4	 2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1597	 1	 0.0	 0.0	 0.0	 -64.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1598	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1599	 2	 1.8	 -3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1600	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04507	    0.00000	 225.0	 1	    1.08571	    1.00444;
	1601	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1602	 1	 18.1	 8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1603	 1	 116.9	 17.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1604	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1605	 2	 -2.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1606	 1	 -4.4	 3.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1607	 1	 23.5	 2.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1608	 1	 0.6	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1610	 1	 45.4	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1611	 1	 22.6	 -4.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1612	 1	 45.8	 2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1613	 1	 48.0	 4.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1614	 1	 7.8	 -5.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1615	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1616	 1	 10.5	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1617	 1	 3.0	 -5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1618	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1619	 1	 27.2	 -0.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1620	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1621	 1	 40.7	 -3.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1622	 1	 52.9	 8.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1623	 1	 -1.4	 -0.6	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1624	 1	 46.0	 11.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1625	 1	 38.2	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1626	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1627	 1	 10.7	 -2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1628	 1	 27.4	 4.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1629	 1	 47.4	 12.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1630	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1631	 1	 6.9	 3.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1632	 1	 42.6	 5.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1633	 1	 23.4	 5.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1634	 1	 16.2	 -1.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1635	 1	 18.9	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1636	 1	 7.9	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1637	 1	 21.9	 10.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1638	 1	 31.1	 4.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1639	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1640	 1	 24.3	 1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1641	 1	 -2.5	 -4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1642	 1	 30.0	 5.2	 0.0	 0.0	 1	    1.00033	    0.00000	 63.0	 1	    1.06416	    0.93651;
	1643	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1644	 1	 12.5	 -4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1645	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08446	    1.00444;
	1646	 1	 21.8	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1647	 1	 17.0	 3.5	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1648	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1649	 1	 13.9	 2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1650	 1	 10.6	 -0.2	 0.0	 0.0	 1	    1.02228	    0.00000	 90.0	 1	    1.06679	    0.97778;
	1651	 1	 40.5	 6.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1652	 1	 23.9	 1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1653	 1	 37.4	 4.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1654	 1	 19.1	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1655	 1	 16.1	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1656	 1	 19.1	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1657	 1	 44.1	 7.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1658	 1	 -0.4	 0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1659	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1660	 1	 11.4	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1661	 1	 17.6	 14.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1662	 1	 32.5	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1663	 1	 38.9	 11.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1664	 1	 7.3	 -1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1665	 1	 17.0	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1666	 1	 -1.8	 0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1667	 1	 21.9	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1668	 1	 25.5	 15.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1669	 1	 21.4	 4.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1670	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1671	 1	 22.2	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1672	 1	 1.3	 0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1673	 1	 54.5	 2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1674	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1675	 1	 12.7	 -7.0	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1676	 1	 17.2	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1677	 1	 10.5	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1678	 1	 50.0	 -11.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1679	 1	 1.3	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1680	 1	 36.0	 -7.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1681	 1	 17.5	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1682	 1	 41.7	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1683	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1684	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1685	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1686	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1687	 1	 9.0	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1688	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1689	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1690	 1	 71.8	 9.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1691	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1692	 1	 8.0	 2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1693	 2	 -0.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1694	 1	 31.5	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1695	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1696	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1697	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1698	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03792	    0.00000	 225.0	 1	    1.08917	    0.98667;
	1699	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03786	    0.00000	 225.0	 1	    1.08905	    0.98667;
	1700	 2	 0.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1701	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1702	 1	 10.6	 24.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1703	 2	 0.0	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1704	 2	 8.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1705	 1	 38.9	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1706	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1707	 1	 57.8	 16.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1708	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1711	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1712	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1713	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1714	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1715	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1716	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1717	 1	 48.9	 8.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	1718	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01556	    0.00000	 225.0	 1	    1.08889	    0.94222;
	1719	 1	 50.1	 7.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1720	 1	 55.2	 12.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1721	 1	 1.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1722	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1723	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1724	 1	 1.0	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1725	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1726	 1	 27.4	 3.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1727	 1	 24.7	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1728	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1729	 1	 -2.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1730	 1	 12.7	 0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1731	 1	 46.0	 2.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1732	 1	 15.0	 3.2	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1733	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1734	 1	 12.5	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1735	 1	 22.1	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1736	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1737	 1	 12.2	 -2.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1738	 1	 18.3	 2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1739	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1740	 1	 11.9	 -1.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1741	 1	 -0.1	 3.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1742	 1	 -0.1	 3.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1743	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1744	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1745	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1746	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1747	 2	 -4.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1748	 2	 -3.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1749	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1750	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1751	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1752	 1	 14.6	 -3.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1753	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1754	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1755	 1	 23.5	 10.5	 0.0	 15.4	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1756	 1	 2.0	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1757	 1	 10.1	 -4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1758	 1	 1.2	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1759	 1	 22.0	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1760	 1	 19.1	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1761	 1	 33.6	 4.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1762	 1	 4.2	 2.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1763	 1	 6.8	 -0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1764	 1	 25.3	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1765	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1766	 1	 49.2	 8.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1767	 1	 2.1	 -4.1	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1768	 1	 11.0	 16.5	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1769	 1	 22.9	 -6.5	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1770	 1	 2.1	 -2.1	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1771	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1772	 1	 12.2	 4.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1773	 1	 -0.6	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1774	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1775	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1776	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1777	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1778	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1779	 1	 32.9	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1780	 1	 71.0	 6.0	 0.0	 30.4	 1	    1.02898	    0.00000	 90.0	 1	    1.08018	    0.97778;
	1781	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1782	 1	 15.0	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1783	 1	 0.5	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1784	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	1785	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1786	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1787	 1	 12.1	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1788	 1	 0.3	 0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1789	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1790	 1	 24.8	 -5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1791	 1	 18.0	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1792	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1793	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1794	 1	 9.7	 5.1	 0.0	 10.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1795	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1796	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1797	 1	 27.5	 3.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1798	 1	 25.0	 5.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1799	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1800	 1	 17.0	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1801	 1	 25.1	 6.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1802	 1	 11.3	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1803	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1804	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1805	 1	 4.1	 -1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1806	 1	 17.1	 3.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1807	 1	 5.1	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1808	 1	 4.7	 2.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1809	 1	 4.0	 2.3	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1810	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1811	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1812	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1813	 1	 28.0	 5.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1814	 1	 24.5	 8.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1815	 1	 45.6	 -5.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1816	 1	 7.7	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	1817	 1	 29.5	 -3.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1818	 1	 0.0	 1.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1819	 1	 2.0	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1820	 1	 12.4	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1821	 1	 45.3	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1822	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1823	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1824	 1	 19.7	 -14.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1825	 1	 37.5	 0.2	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1826	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1827	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1828	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1829	 1	 10.0	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1830	 1	 41.8	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1831	 1	 67.8	 0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1832	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1833	 1	 3.0	 -0.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1834	 1	 2.8	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1835	 1	 18.0	 4.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1836	 1	 12.8	 -3.6	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1837	 1	 38.1	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1838	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1839	 1	 43.7	 19.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1840	 1	 -4.0	 -6.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1841	 1	 -0.4	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1842	 1	 6.7	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1843	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1844	 1	 -2.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1845	 1	 7.4	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1846	 1	 10.4	 10.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1847	 1	 -0.1	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1848	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1849	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1850	 1	 21.9	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1851	 1	 0.3	 0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1852	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1853	 1	 30.2	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1854	 1	 19.0	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1855	 1	 21.0	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1856	 1	 17.4	 2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1857	 1	 25.8	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1858	 1	 32.8	 7.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1859	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1860	 2	 0.0	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1861	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1862	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1863	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1864	 1	 7.0	 0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1865	 1	 14.0	 -2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1866	 1	 25.2	 7.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1867	 1	 35.8	 1.7	 0.0	 0.0	 1	    1.01866	    0.00000	 90.0	 1	    1.06667	    0.97065;
	1868	 1	 2.9	 -2.8	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1869	 1	 34.0	 -4.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1870	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1871	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1872	 1	 45.3	 5.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1873	 1	 36.1	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1874	 1	 16.9	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1875	 1	 1.2	 1.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1876	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1877	 1	 51.8	 18.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1878	 1	 9.0	 0.7	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1879	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1880	 1	 -2.4	 2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1881	 1	 18.3	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1882	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1883	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04734	    0.00000	 225.0	 1	    1.09025	    1.00444;
	1884	 1	 13.5	 -3.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1885	 1	 11.0	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1886	 1	 10.0	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1887	 1	 31.7	 2.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1888	 1	 33.0	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1889	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1890	 1	 28.0	 12.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1891	 1	 22.9	 3.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1892	 1	 84.7	 17.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1893	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1894	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1895	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1896	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1897	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1898	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1899	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1900	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1901	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1902	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1903	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1904	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1905	 1	 14.0	 -5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1906	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1907	 1	 0.4	 -2.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1908	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1909	 1	 6.0	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1910	 1	 30.2	 -0.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1911	 1	 30.8	 6.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1912	 1	 42.8	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1913	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1914	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1915	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1916	 1	 -1.9	 -18.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1917	 1	 60.5	 6.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1918	 1	 14.5	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1919	 1	 59.7	 6.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1920	 1	 34.4	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1921	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1922	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1923	 1	 5.6	 -7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1924	 1	 27.9	 4.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1925	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1926	 1	 40.2	 6.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1927	 2	 15.5	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1928	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1929	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1930	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1931	 1	 54.4	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1932	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1933	 1	 0.0	 0.0	 0.0	 -64.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1934	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1935	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1936	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1937	 1	 -10.4	 -16.4	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1938	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1939	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1940	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1941	 1	 23.0	 1.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1942	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1943	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1944	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01556	    0.00000	 225.0	 1	    1.08889	    0.94222;
	1945	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1946	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1947	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1948	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1949	 1	 17.7	 7.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1950	 1	 25.7	 1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1951	 1	 36.7	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1952	 1	 35.5	 -5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1953	 1	 16.5	 0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1954	 1	 26.8	 2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1955	 1	 1.4	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1956	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1957	 1	 17.1	 -5.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1958	 1	 0.2	 -0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1959	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1960	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1961	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1963	 1	 21.4	 2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1964	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1965	 1	 13.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1966	 1	 30.2	 -1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1967	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1968	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1969	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1970	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1971	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1972	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1973	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1974	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1975	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1976	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1977	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1978	 1	 10.3	 3.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1979	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1980	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1981	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1982	 2	 -0.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1983	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1984	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1985	 1	 31.8	 0.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1986	 2	 -1.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1987	 1	 1.7	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1988	 1	 54.6	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1989	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1990	 1	 36.8	 1.5	 0.0	 0.0	 1	    1.02857	    0.00000	 90.0	 1	    1.07936	    0.97778;
	1991	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1992	 2	 0.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1993	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1994	 1	 0.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1995	 1	 15.1	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1996	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1997	 1	 13.6	 1.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1998	 1	 12.6	 2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1999	 1	 8.9	 3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2000	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2001	 1	 0.3	 0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2002	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2003	 1	 19.8	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2004	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2005	 1	 49.8	 11.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2006	 1	 14.4	 4.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2007	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2008	 1	 38.0	 4.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2009	 1	 17.6	 3.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2010	 1	 -0.1	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2011	 1	 28.8	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2012	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2013	 1	 12.2	 -2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2014	 1	 4.0	 3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2015	 1	 108.7	 34.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2016	 1	 -7.6	 -16.5	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	2017	 1	 1.5	 13.2	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	2018	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2019	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2020	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2021	 1	 7.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2022	 1	 3.2	 -2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2023	 1	 8.6	 17.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2024	 1	 26.9	 -1.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2025	 1	 34.7	 5.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2026	 1	 34.7	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2027	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2028	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2029	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2030	 1	 9.9	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2031	 1	 53.2	 10.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2032	 1	 31.6	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2033	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2034	 1	 29.6	 -0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2035	 1	 5.4	 -2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2036	 1	 16.2	 3.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2037	 1	 14.3	 -3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2038	 1	 7.0	 -4.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2039	 1	 35.8	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2040	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2041	 1	 39.2	 0.2	 0.0	 15.4	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2042	 1	 10.0	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2043	 1	 32.3	 -1.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2044	 1	 7.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2045	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00418	    0.00000	 150.0	 1	    1.10835	    0.90000;
	2046	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2047	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2048	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2049	 1	 30.6	 2.5	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2050	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2051	 1	 27.2	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2052	 1	 14.1	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2053	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2054	 1	 -0.0	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2055	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2057	 1	 17.0	 3.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2058	 1	 14.0	 1.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2059	 1	 15.0	 0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2060	 1	 14.3	 -4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2061	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2062	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2063	 1	 -5.6	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2064	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2065	 1	 -13.6	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2066	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2067	 1	 13.9	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2068	 1	 51.1	 2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2069	 1	 29.8	 7.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2070	 1	 -1.1	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2071	 1	 15.3	 5.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2072	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2073	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2074	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2075	 1	 14.0	 5.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2076	 1	 18.4	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2077	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2078	 1	 32.0	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2079	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2080	 1	 51.0	 -4.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2081	 1	 73.0	 -12.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2082	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2083	 1	 1.2	 -0.3	 0.0	 0.0	 1	    1.02287	    0.00000	 90.0	 1	    1.06796	    0.97778;
	2084	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2085	 1	 15.7	 -3.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2086	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2087	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2088	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2089	 1	 45.8	 8.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2090	 1	 26.6	 4.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2091	 1	 13.9	 -2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2092	 1	 17.4	 4.2	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2093	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.08889	    0.91111;
	2094	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.08889	    0.91111;
	2095	 1	 53.5	 18.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2096	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2097	 1	 11.7	 2.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2098	 2	 11.0	 4.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2099	 1	 22.7	 -1.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2100	 1	 18.2	 -7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2101	 1	 13.8	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2102	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2104	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2105	 1	 32.9	 1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2106	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2107	 1	 8.9	 -13.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2108	 1	 2.9	 -1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2109	 1	 8.9	 2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2110	 1	 5.9	 -1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2111	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2113	 1	 5.9	 -1.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2114	 1	 14.8	 -2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2115	 1	 25.7	 1.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2116	 1	 14.9	 9.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2117	 1	 24.4	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2118	 1	 0.0	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2119	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2120	 1	 3.0	 -0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2121	 1	 44.5	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2122	 1	 15.7	 -11.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2123	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2124	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2125	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2126	 1	 16.3	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2127	 1	 15.9	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2128	 1	 35.1	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2129	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2131	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2132	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2133	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02667	    0.00000	 150.0	 1	    1.10667	    0.94667;
	2134	 1	 32.0	 2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 225.0	 1	    1.08889	    0.95556;
	2135	 1	 19.4	 4.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2136	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2137	 1	 11.5	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2138	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2139	 1	 409.6	 112.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2140	 1	 19.6	 6.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2141	 1	 10.0	 -1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2142	 1	 11.4	 5.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2143	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2144	 1	 -0.5	 4.0	 0.0	 0.0	 1	    1.04636	    0.00000	 225.0	 1	    1.08827	    1.00444;
	2145	 1	 13.5	 5.0	 0.0	 0.0	 1	    1.04587	    0.00000	 225.0	 1	    1.08730	    1.00444;
	2146	 1	 51.1	 7.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2147	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2148	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2149	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2150	 1	 29.1	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2151	 1	 11.1	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2152	 1	 20.6	 2.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2153	 1	 24.4	 1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2154	 1	 10.4	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2155	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2157	 1	 37.0	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2158	 1	 11.0	 3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2159	 1	 52.9	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2160	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2161	 1	 53.2	 -0.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2162	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2164	 2	 0.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2165	 1	 25.8	 -2.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2166	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	2167	 1	 2.7	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2168	 1	 6.7	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2169	 1	 13.7	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2170	 1	 -0.7	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2171	 1	 19.3	 -2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2172	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2174	 1	 31.4	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2175	 1	 31.7	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2176	 1	 55.1	 20.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2177	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2178	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2179	 1	 39.0	 6.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2180	 1	 18.2	 5.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2181	 1	 21.6	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2182	 1	 51.5	 9.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2183	 1	 26.5	 2.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2184	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2185	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2186	 1	 22.9	 1.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2187	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2188	 1	 -0.0	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2189	 1	 36.9	 4.8	 0.0	 0.0	 1	    0.96825	    0.00000	 63.0	 1	    1.04762	    0.88889;
	2190	 1	 37.2	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2191	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2192	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2193	 1	 14.6	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2194	 2	 0.7	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2195	 1	 6.2	 -1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	2196	 1	 6.8	 0.4	 0.0	 0.0	 1	    1.04794	    0.00000	 225.0	 1	    1.09145	    1.00444;
	2197	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2198	 1	 10.8	 0.0	 0.0	 0.0	 1	    1.04802	    0.00000	 225.0	 1	    1.09160	    1.00444;
	2199	 1	 -5.2	 9.9	 0.0	 0.0	 1	    1.04793	    0.00000	 225.0	 1	    1.09143	    1.00444;
	2200	 1	 -10.2	 4.1	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2201	 1	 7.4	 -1.6	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	2202	 1	 65.9	 -2.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2203	 1	 43.8	 -0.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2204	 1	 2.0	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2205	 1	 99.9	 6.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2206	 1	 7.0	 3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2207	 1	 23.6	 6.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2208	 1	 1.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2209	 1	 69.2	 -1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2210	 1	 8.0	 -1.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2211	 1	 16.8	 2.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2212	 1	 7.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2213	 1	 41.8	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2214	 1	 22.3	 10.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2215	 1	 62.5	 3.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2216	 1	 90.9	 21.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2217	 1	 2.0	 -0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2218	 1	 15.4	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2219	 1	 34.6	 -0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2220	 1	 29.4	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2221	 1	 -2.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2222	 1	 45.9	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2223	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2224	 1	 8.4	 -0.5	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2225	 1	 37.3	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2226	 1	 26.0	 8.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2227	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2228	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2229	 1	 21.4	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2230	 1	 4.3	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2231	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2232	 1	 35.4	 2.4	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2233	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	2234	 1	 12.8	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2235	 1	 -11.7	 -1.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	2236	 1	 48.5	 10.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2237	 1	 11.0	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2238	 1	 0.2	 2.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2239	 1	 0.1	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2240	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.83000	    0.00000	 150.0	 1	    1.00000	    0.66000;
	2241	 1	 35.7	 -19.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2242	 1	 7.9	 -2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2243	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2244	 1	 4.4	 5.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2245	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2246	 2	 -0.1	 -0.5	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2247	 1	 4.4	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2248	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2249	 1	 10.8	 -8.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2250	 1	 27.4	 -0.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2251	 1	 10.3	 5.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2252	 1	 20.0	 6.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	2253	 1	 43.4	 22.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2254	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2255	 1	 84.9	 1.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2256	 1	 41.0	 10.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2257	 1	 49.7	 5.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2258	 1	 42.5	 8.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2259	 1	 2.9	 -1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2260	 1	 7.0	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2261	 1	 14.5	 2.4	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2262	 1	 32.1	 -1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2263	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2265	 1	 22.4	 -2.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2266	 1	 6.5	 0.7	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	2267	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03997	    0.00000	 63.0	 1	    1.12756	    0.95238;
	2268	 1	 1.9	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2269	 1	 -2.8	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2270	 1	 46.6	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	2272	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	2273	 1	 29.4	 5.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2274	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2275	 1	 2.0	 -4.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2277	 1	 1.2	 -1.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2278	 1	 4.9	 -0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2279	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2280	 1	 13.9	 -10.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2281	 1	 -142.1	 -72.0	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	2282	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	2283	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2284	 1	 30.9	 7.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2285	 1	 16.0	 1.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2286	 1	 5.0	 -1.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2287	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2288	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2289	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	2290	 1	 13.0	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2291	 1	 47.7	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2292	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2293	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2294	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2295	 1	 41.9	 11.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2296	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2297	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2298	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2299	 1	 41.1	 9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2300	 1	 23.9	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2301	 1	 6.4	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2302	 1	 8.0	 -1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2303	 1	 -0.3	 -2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2304	 1	 13.9	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2305	 1	 7.6	 -1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2306	 1	 5.0	 0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2307	 1	 46.8	 2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2308	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2309	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2310	 1	 24.0	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2311	 1	 18.4	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2312	 1	 53.7	 8.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2313	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2314	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2315	 1	 61.7	 15.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2316	 1	 14.7	 6.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2317	 1	 27.0	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2318	 1	 10.0	 4.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2319	 1	 13.9	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2320	 1	 44.5	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2321	 1	 13.0	 -1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2322	 1	 3.0	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2323	 1	 19.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2324	 1	 37.2	 6.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2325	 1	 30.2	 4.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2326	 1	 28.6	 6.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2327	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2328	 1	 13.9	 2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2329	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2330	 1	 35.9	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2331	 1	 8.9	 -3.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2332	 1	 4.0	 4.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2333	 1	 17.1	 3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2334	 1	 22.8	 12.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2335	 1	 0.6	 4.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2336	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07877	    0.00000	 380.0	 1	    1.10263	    1.05491;
	2337	 1	 25.1	 -3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2338	 1	 14.2	 6.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2339	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2340	 2	 7.4	 4.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2341	 2	 -0.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2342	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2343	 1	 15.1	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2344	 1	 9.8	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2345	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2346	 1	 15.8	 -1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2347	 1	 34.0	 -0.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2348	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2349	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2350	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2351	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2352	 1	 9.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2353	 1	 16.1	 -7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2354	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2355	 1	 6.5	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2356	 1	 9.9	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2357	 1	 7.5	 -3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2358	 1	 33.0	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2359	 1	 18.4	 -1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2360	 1	 29.9	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2361	 1	 49.7	 1.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2362	 1	 43.0	 -2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2364	 2	 -3.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2365	 2	 -2.7	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2366	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2367	 2	 -0.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2368	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2369	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2370	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2371	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2372	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2373	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2374	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2375	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2376	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2377	 1	 0.8	 0.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2378	 1	 21.0	 5.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2379	 1	 15.1	 -2.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2380	 1	 7.2	 2.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2381	 1	 26.5	 -4.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2382	 1	 2.8	 1.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2383	 1	 7.0	 -2.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2384	 1	 28.9	 1.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2385	 1	 9.0	 1.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2386	 1	 40.4	 2.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2387	 1	 13.8	 -1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2388	 1	 2.6	 1.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2389	 1	 10.0	 2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2390	 1	 0.0	 31.9	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2391	 1	 0.4	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2392	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2393	 1	 18.0	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2394	 1	 4.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2395	 1	 3.1	 -5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2396	 1	 17.5	 -6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2397	 1	 12.8	 -5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2398	 1	 31.9	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2399	 1	 6.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2400	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2401	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2402	 1	 43.2	 18.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2403	 1	 11.4	 5.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2404	 1	 7.4	 3.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2405	 1	 11.5	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2406	 1	 22.3	 -1.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2407	 1	 9.7	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2408	 1	 -5.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2409	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2410	 1	 9.0	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2411	 1	 10.8	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2412	 1	 16.8	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2413	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2414	 1	 29.5	 5.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2415	 1	 41.8	 3.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2416	 1	 13.6	 10.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	2417	 1	 18.4	 12.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2418	 1	 9.4	 10.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2419	 1	 2.4	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2420	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2421	 1	 -9.0	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2422	 1	 31.0	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2423	 1	 0.9	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2424	 1	 28.8	 1.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2425	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2426	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2427	 1	 32.4	 -1.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2428	 1	 14.3	 5.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2429	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2430	 1	 22.5	 6.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2431	 1	 18.3	 4.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2432	 1	 16.1	 4.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2433	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2434	 1	 15.5	 2.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2435	 1	 12.0	 -7.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2436	 1	 43.6	 8.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2437	 1	 91.2	 14.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2438	 1	 12.2	 -3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2439	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2440	 1	 4.0	 -2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2441	 1	 12.3	 -8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2442	 1	 41.7	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2443	 1	 5.3	 0.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2444	 1	 13.8	 0.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2445	 1	 28.9	 1.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2446	 1	 8.0	 -0.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2447	 1	 1.3	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2448	 1	 11.1	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2450	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2451	 1	 32.2	 -2.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2452	 1	 8.5	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2453	 1	 10.9	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2454	 1	 14.5	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2455	 1	 29.9	 -8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2456	 1	 45.7	 6.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2457	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2458	 1	 11.6	 1.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2460	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2461	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2462	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2463	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2464	 1	 1.4	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2465	 1	 3.2	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2466	 1	 8.6	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2467	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2468	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2469	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2470	 1	 0.0	 0.0	 0.0	 30.4	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2471	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2472	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2473	 1	 24.4	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2474	 1	 46.2	 0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2475	 1	 10.0	 2.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2476	 1	 12.0	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2480	 1	 10.3	 -3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2482	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2483	 1	 19.8	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2484	 1	 61.1	 11.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2485	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2486	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2487	 1	 25.9	 -3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2488	 1	 15.8	 -5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2489	 1	 21.9	 1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2490	 1	 22.6	 -7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2491	 1	 13.4	 -0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2492	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2493	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2494	 1	 24.0	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2495	 1	 40.3	 -0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2496	 1	 19.8	 2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2497	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2498	 1	 25.4	 -2.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2499	 1	 12.1	 3.6	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2500	 1	 8.0	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2501	 1	 16.4	 -6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2502	 1	 0.3	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2503	 1	 12.7	 -4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2504	 1	 37.9	 -1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2505	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2506	 1	 28.4	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2507	 1	 4.0	 -4.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2508	 1	 10.9	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2509	 1	 27.2	 -4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2510	 1	 9.0	 -2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2511	 1	 25.2	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2512	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2513	 1	 26.8	 -2.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2514	 1	 0.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2515	 1	 43.3	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2516	 1	 45.0	 10.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2517	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2518	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2519	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2520	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	2521	 1	 15.8	 7.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2522	 1	 21.8	 9.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2523	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2524	 1	 -0.1	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2525	 2	 88.0	 0.0	 0.0	 0.0	 1	    1.05434	    0.00000	 90.0	 1	    1.15313	    0.95556;
	2526	 1	 22.8	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2527	 1	 44.7	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2528	 1	 42.4	 2.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2529	 1	 9.2	 -0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2530	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2531	 1	 51.1	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2532	 1	 14.2	 -2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2533	 1	 35.4	 2.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2534	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2535	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2536	 1	 64.7	 8.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2537	 1	 31.7	 13.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2538	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2539	 1	 0.3	 -8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2540	 1	 29.4	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2541	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2542	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2543	 1	 13.3	 -2.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2544	 1	 29.3	 7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2545	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2546	 1	 21.2	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2547	 1	 26.1	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2548	 1	 -1.1	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2549	 1	 2.0	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2550	 1	 13.4	 -0.8	 0.0	 60.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2551	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	2552	 1	 27.9	 1.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2553	 1	 51.6	 12.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2554	 1	 26.5	 -2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2555	 1	 4.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2556	 1	 37.4	 -0.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2557	 1	 10.5	 -5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2558	 1	 24.2	 1.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2559	 1	 13.3	 1.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2560	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2561	 1	 9.9	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2562	 1	 24.6	 -0.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2563	 1	 19.4	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2564	 1	 32.1	 -6.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2565	 1	 10.4	 -4.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2566	 1	 15.4	 -0.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2567	 1	 16.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2568	 1	 55.4	 6.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2569	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2570	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2571	 1	 40.1	 7.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2572	 1	 6.0	 1.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2574	 1	 31.0	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2575	 1	 29.9	 6.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2576	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02615	    0.00000	 90.0	 1	    1.07453	    0.97778;
	2577	 1	 44.3	 10.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2578	 1	 8.0	 2.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2579	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2580	 1	 18.4	 17.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	2582	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2583	 1	 28.1	 -5.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2584	 1	 28.1	 5.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2585	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	2586	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	2587	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2588	 1	 19.0	 -1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2589	 1	 -0.6	 -0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2590	 1	 -0.9	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2591	 1	 12.0	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2592	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2593	 1	 41.0	 14.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2594	 1	 32.6	 1.1	 0.0	 0.0	 1	    0.97500	    0.00000	 63.0	 1	    1.15000	    0.80000;
	2595	 1	 12.8	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2596	 1	 35.0	 4.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2597	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2598	 1	 1.9	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2599	 1	 19.4	 3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2600	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2601	 1	 9.1	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2602	 1	 4.4	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2603	 1	 32.7	 -11.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2604	 1	 23.8	 -0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2605	 1	 21.2	 1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2606	 1	 29.1	 -7.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2607	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2608	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2610	 1	 15.5	 0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2611	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2612	 1	 18.8	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2613	 2	 21.8	 0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2614	 1	 4.3	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2615	 1	 27.7	 0.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2616	 1	 32.3	 8.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2617	 1	 11.6	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2618	 1	 48.6	 5.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2619	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2620	 1	 23.7	 -2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2621	 1	 17.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2622	 1	 11.1	 2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2623	 1	 30.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2624	 1	 7.4	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2625	 1	 13.8	 -1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2626	 1	 33.8	 2.5	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	2627	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	2628	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	2629	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2630	 1	 48.6	 9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2631	 1	 18.0	 -2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2632	 1	 5.0	 -0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2633	 1	 0.0	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2634	 1	 8.8	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2635	 1	 7.0	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2636	 1	 13.3	 3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2637	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2638	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2639	 1	 18.1	 -0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2640	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2641	 1	 -0.4	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2642	 2	 -1.9	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2643	 1	 6.0	 -2.7	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2644	 1	 41.9	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2645	 1	 -5.8	 -7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2646	 2	 0.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2647	 2	 6.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2648	 2	 -5.1	 -6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2649	 1	 5.7	 0.2	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2650	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2651	 1	 -2.4	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2652	 1	 17.6	 -3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2653	 1	 7.1	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2654	 2	 2.3	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2655	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2656	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	2657	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2658	 1	 8.2	 -0.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2659	 1	 -0.0	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2660	 1	 23.2	 7.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2661	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2662	 2	 3.6	 8.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2663	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2664	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2665	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2666	 2	 3.4	 0.7	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2667	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2668	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00605	    0.00000	 150.0	 1	    1.11209	    0.90000;
	2669	 1	 59.0	 5.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2670	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2671	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.82500	    0.00000	 20.0	 1	    1.15000	    0.50000;
	2672	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2673	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2674	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2675	 1	 47.0	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2676	 1	 12.0	 0.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2677	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2678	 1	 0.2	 -7.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2679	 1	 44.2	 8.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2680	 1	 3.0	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2681	 1	 8.9	 8.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2682	 1	 -0.5	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2683	 1	 37.0	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2684	 1	 54.0	 10.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2685	 1	 38.4	 0.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2686	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2687	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2688	 1	 35.7	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2689	 1	 25.4	 -0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2690	 1	 18.0	 3.3	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2691	 1	 10.0	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2692	 1	 8.8	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2693	 1	 22.8	 -0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2694	 1	 19.7	 -1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2695	 1	 89.2	 18.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2696	 1	 14.5	 9.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2697	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2698	 1	 12.0	 -3.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2699	 1	 19.2	 -1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2700	 1	 14.4	 0.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2701	 1	 17.3	 4.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2702	 1	 0.4	 0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2703	 1	 37.9	 4.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2704	 1	 19.1	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2705	 1	 12.7	 13.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2706	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2707	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2708	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2710	 1	 6.0	 2.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2711	 1	 31.3	 0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2712	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2713	 1	 31.6	 -1.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2714	 1	 30.2	 4.5	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	2715	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2716	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2717	 1	 32.8	 7.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2718	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2719	 1	 7.8	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2720	 1	 -2.8	 5.7	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	2721	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2722	 1	 0.0	 0.0	 0.0	 320.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2723	 1	 60.7	 13.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2724	 1	 25.5	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2725	 1	 3.2	 -0.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2726	 1	 28.5	 -3.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2727	 1	 23.5	 3.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2728	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2729	 1	 4.9	 -4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2730	 1	 17.3	 -0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2731	 1	 0.0	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2732	 1	 34.2	 2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2733	 1	 6.8	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2734	 1	 23.9	 -9.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2735	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2736	 1	 19.7	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2737	 1	 5.0	 1.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2738	 1	 4.4	 11.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2739	 1	 0.8	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2740	 1	 1.0	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2741	 1	 12.0	 -2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2742	 1	 17.0	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2743	 1	 11.8	 1.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2744	 1	 17.6	 1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2745	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2746	 1	 2.3	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2747	 1	 17.3	 4.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2748	 1	 3.4	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	2749	 1	 0.5	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2750	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2751	 1	 26.1	 -2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2752	 1	 -0.9	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2753	 1	 25.0	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2754	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2755	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2756	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2757	 1	 41.0	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2758	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2759	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2760	 1	 3.0	 0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2761	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2762	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2763	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2764	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2765	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2766	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04245	    0.00000	 63.0	 1	    1.13251	    0.95238;
	2767	 1	 21.9	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2768	 1	 37.0	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2769	 1	 0.0	 0.0	 0.0	 -64.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2770	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2771	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2772	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2773	 1	 24.1	 -1.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2774	 1	 11.5	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2775	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2776	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2777	 1	 33.5	 -0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2778	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2779	 1	 28.3	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2780	 1	 44.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2781	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2782	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2783	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	2784	 1	 15.1	 11.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2785	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2786	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2787	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2788	 1	 24.3	 2.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2789	 1	 14.8	 -2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2790	 1	 13.7	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2791	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2792	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2793	 1	 4.8	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2794	 1	 0.0	 -0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2795	 1	 82.1	 2.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2796	 1	 104.3	 9.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2797	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	2798	 1	 1.4	 -0.7	 0.0	 80.0	 1	    1.02222	    0.00000	 225.0	 1	    1.08889	    0.95556;
	2799	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2800	 1	 14.9	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2801	 1	 16.9	 -2.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2802	 1	 42.8	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2803	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2804	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	2805	 1	 3.3	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	2806	 1	 18.8	 7.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2807	 1	 27.7	 -7.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2808	 1	 16.3	 -5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2809	 1	 11.0	 3.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2810	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2811	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2812	 1	 25.7	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2813	 1	 20.4	 4.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2814	 1	 5.4	 1.0	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	2815	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2816	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2817	 1	 14.7	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2818	 1	 8.9	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2819	 2	 5.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2820	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2821	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03907	    0.00000	 225.0	 1	    1.09147	    0.98667;
	2822	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03906	    0.00000	 225.0	 1	    1.09145	    0.98667;
	2823	 1	 43.2	 2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2824	 1	 9.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2825	 1	 26.1	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2826	 1	 79.0	 12.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2827	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2828	 1	 27.8	 5.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2829	 1	 25.2	 5.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2830	 1	 56.4	 5.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2831	 1	 4.6	 -0.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2832	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99076	    0.00000	 225.0	 1	    1.09263	    0.88889;
	2833	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2834	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2835	 1	 25.9	 3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2836	 1	 33.9	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2837	 1	 9.0	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2838	 1	 5.0	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2839	 2	 2.8	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2840	 1	 41.2	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2841	 1	 12.6	 -3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2842	 1	 57.4	 -55.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2843	 1	 15.5	 -8.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2844	 1	 47.5	 -1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2845	 1	 -1.6	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2846	 1	 21.9	 -8.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2847	 1	 19.9	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2848	 1	 40.9	 4.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2849	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2850	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2851	 1	 15.7	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2852	 1	 35.5	 9.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2853	 1	 36.2	 13.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2854	 1	 20.3	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2855	 1	 0.0	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2856	 1	 21.2	 -9.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2857	 1	 1.7	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2858	 1	 8.0	 -2.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2859	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2860	 1	 0.4	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2861	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2862	 1	 56.7	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2863	 1	 0.9	 -0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2864	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02265	    0.00000	 90.0	 1	    1.06753	    0.97778;
	2865	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2866	 1	 17.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2867	 1	 26.0	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2868	 1	 15.7	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2869	 1	 5.0	 1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2870	 1	 15.0	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2871	 1	 -0.5	 -1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2872	 1	 -5.0	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2873	 1	 19.9	 3.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2874	 1	 1.0	 -7.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2875	 1	 36.8	 5.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2876	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2877	 1	 34.9	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2878	 1	 4.7	 2.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2879	 1	 12.7	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2880	 1	 8.8	 -0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2881	 1	 2.6	 7.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2882	 1	 1.0	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2883	 1	 1.1	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2884	 1	 28.1	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2885	 1	 22.0	 3.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2886	 1	 36.6	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2887	 1	 8.0	 -6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2888	 1	 29.8	 7.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2889	 1	 -0.0	 -0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2890	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2891	 1	 16.6	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2892	 1	 64.5	 6.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2893	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2894	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2895	 1	 1.0	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2896	 1	 47.7	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2897	 1	 5.0	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2898	 1	 15.7	 6.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2899	 1	 6.6	 -9.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2900	 2	 -1.0	 1.8	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2901	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00138	    0.00000	 150.0	 1	    1.10277	    0.90000;
	2902	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2903	 1	 30.4	 1.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2904	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2905	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2906	 1	 52.4	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2907	 1	 33.9	 -3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2908	 1	 21.5	 1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2909	 2	 19.0	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2910	 1	 14.3	 -6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2911	 1	 19.7	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2912	 1	 20.6	 -2.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2913	 1	 25.7	 3.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2914	 1	 56.8	 8.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2915	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2916	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2917	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2918	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2919	 1	 3.0	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2920	 1	 -3.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2921	 1	 41.7	 1.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2922	 1	 14.5	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2923	 1	 18.0	 2.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2924	 1	 21.0	 3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2925	 1	 10.9	 -1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2926	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2927	 1	 32.9	 -7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2928	 1	 15.2	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2929	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2930	 1	 51.8	 15.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2931	 1	 43.1	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2932	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2933	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2934	 1	 62.1	 11.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2935	 1	 43.4	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2936	 1	 10.5	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2937	 1	 21.1	 -3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2938	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2939	 1	 12.0	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2940	 1	 0.0	 -1.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2941	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2942	 1	 15.6	 -2.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2943	 1	 13.0	 6.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2944	 1	 14.0	 6.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2945	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2946	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2947	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2948	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2949	 1	 9.0	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2950	 1	 30.2	 4.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2951	 1	 157.6	 48.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2952	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2953	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2954	 1	 16.2	 -6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2955	 1	 16.8	 2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2956	 1	 39.4	 10.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2957	 1	 13.9	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2958	 1	 3.9	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2959	 1	 8.8	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2960	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2961	 1	 19.3	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2962	 1	 13.9	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2963	 1	 0.0	 1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2964	 1	 12.8	 -9.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2965	 1	 26.2	 3.7	 0.0	 0.0	 1	    1.04695	    0.00000	 225.0	 1	    1.08946	    1.00444;
	2966	 1	 0.0	 0.0	 0.0	 -60.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2967	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04679	    0.00000	 225.0	 1	    1.08914	    1.00444;
	2968	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04696	    0.00000	 225.0	 1	    1.08947	    1.00444;
	2969	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2970	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2971	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2972	 1	 3.2	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2973	 1	 48.2	 17.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2974	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2975	 1	 30.8	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2976	 1	 20.7	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2977	 2	 1.1	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2978	 1	 39.6	 2.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2979	 1	 20.3	 2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2980	 1	 25.9	 -5.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2981	 1	 34.0	 -3.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2982	 1	 -0.2	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2983	 1	 3.0	 -3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2984	 1	 23.2	 1.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2985	 1	 18.8	 9.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2986	 1	 14.5	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2987	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2988	 1	 29.3	 -1.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2989	 1	 29.3	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2990	 1	 -1.9	 7.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2991	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2992	 1	 14.0	 4.0	 0.0	 0.0	 1	    1.00024	    0.00000	 63.0	 1	    1.06397	    0.93651;
	2993	 1	 14.2	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2994	 1	 20.9	 1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2995	 2	 12.0	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2996	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2997	 1	 13.2	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2998	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2999	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3000	 1	 56.9	 16.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3001	 1	 42.4	 20.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3002	 1	 40.0	 -3.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3003	 1	 48.8	 4.5	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3004	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3005	 1	 20.8	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3006	 1	 48.5	 1.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3007	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3008	 1	 120.0	 9.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3009	 1	 0.0	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3010	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3011	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03855	    0.00000	 225.0	 1	    1.09044	    0.98667;
	3012	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3013	 1	 22.3	 5.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3014	 1	 50.6	 -2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3015	 1	 54.8	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3016	 1	 2.3	 -1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3017	 1	 45.7	 -3.1	 0.0	 0.0	 1	    1.02283	    0.00000	 90.0	 1	    1.06788	    0.97778;
	3018	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3019	 1	 22.3	 4.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3020	 1	 0.9	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3021	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3022	 2	 0.9	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3023	 2	 12.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3024	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3025	 1	 6.0	 -3.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3026	 1	 2.0	 -1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3027	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3028	 1	 33.7	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3029	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3030	 1	 50.4	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	3031	 1	 1.3	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3032	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3033	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	3034	 1	 20.5	 1.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3035	 1	 39.4	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3036	 1	 24.6	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3037	 1	 25.9	 -5.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3038	 1	 30.2	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3039	 1	 10.5	 11.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3040	 1	 0.7	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3041	 1	 23.1	 -11.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3042	 1	 2.3	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3043	 1	 47.2	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3044	 1	 22.2	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3045	 1	 18.0	 3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3046	 1	 10.0	 -2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3047	 1	 31.8	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3048	 1	 30.5	 5.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3049	 1	 10.1	 6.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3050	 1	 53.7	 6.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3051	 1	 9.0	 -2.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3052	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3053	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3054	 1	 1.8	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3055	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3057	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	3058	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	3059	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	3060	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3061	 1	 39.2	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3062	 1	 13.9	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3063	 1	 28.6	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3064	 1	 14.9	 7.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3065	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3066	 1	 14.5	 -5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3067	 1	 27.6	 -2.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3068	 1	 -0.1	 0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3069	 1	 47.9	 1.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3070	 1	 54.1	 0.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3071	 1	 9.5	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3072	 1	 2.1	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3073	 1	 25.9	 -4.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3074	 1	 27.1	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3075	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3076	 1	 1.2	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3077	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3078	 1	 1.6	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3079	 1	 18.8	 2.2	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	3080	 1	 3.5	 -1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3081	 1	 11.9	 3.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3082	 1	 21.7	 2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3083	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3084	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3085	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3086	 1	 80.7	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3087	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3088	 1	 2.1	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3089	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3090	 1	 4.8	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3091	 1	 33.1	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3092	 1	 28.7	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3093	 1	 19.4	 0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3094	 1	 1.0	 -2.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3095	 1	 13.3	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3096	 1	 10.6	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3097	 1	 11.9	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3098	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3099	 1	 27.2	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3100	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3101	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3102	 1	 56.7	 13.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3104	 1	 25.2	 1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3105	 1	 14.8	 1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3106	 1	 8.9	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3107	 2	 6.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3108	 1	 28.2	 -3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3109	 1	 62.7	 -0.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3110	 1	 -24.1	 0.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3111	 1	 44.5	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3112	 1	 39.9	 18.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3113	 1	 12.3	 -3.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3114	 1	 -0.1	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3115	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3116	 2	 -1.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3117	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3118	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3120	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3122	 1	 25.0	 2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3123	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3124	 1	 7.3	 1.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3125	 1	 15.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3126	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3127	 1	 73.1	 24.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3129	 1	 31.2	 3.8	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	3130	 1	 6.0	 1.0	 0.0	 0.0	 1	    1.00215	    0.00000	 63.0	 1	    1.08367	    0.92063;
	3131	 1	 25.3	 -0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3132	 1	 14.0	 -3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3133	 1	 37.5	 4.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	3134	 1	 26.5	 -0.7	 0.0	 0.0	 1	    1.00171	    0.00000	 63.0	 1	    1.06691	    0.93651;
	3135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3136	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3137	 1	 46.6	 7.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3138	 1	 33.6	 -6.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3139	 1	 13.1	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3140	 1	 26.5	 6.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3141	 1	 44.4	 -5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3142	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3143	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3144	 1	 10.8	 5.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3145	 1	 16.8	 9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3146	 1	 46.8	 5.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3147	 1	 26.9	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3148	 1	 2.1	 0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3149	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3150	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04802	    0.00000	 380.0	 1	    1.10263	    0.99341;
	3151	 1	 16.2	 1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3152	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.06667	    0.98889;
	3153	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3155	 1	 4.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3156	 1	 28.7	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3157	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3158	 1	 30.2	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3159	 2	 7.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3160	 1	 19.0	 2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3161	 1	 20.4	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3162	 1	 -0.3	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3163	 1	 102.2	 19.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3164	 1	 21.3	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3165	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3166	 1	 0.9	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3167	 1	 42.9	 6.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3168	 1	 33.9	 3.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3169	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3170	 1	 -0.6	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3171	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3172	 1	 15.1	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3173	 1	 0.3	 -0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3174	 1	 38.9	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3175	 1	 44.2	 16.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3176	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3177	 1	 8.6	 -3.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3178	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3179	 1	 0.0	 0.0	 0.0	 78.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3180	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	3181	 1	 16.8	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3182	 1	 22.5	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3183	 1	 13.1	 2.4	 0.0	 0.0	 1	    0.99053	    0.00000	 63.0	 1	    1.07629	    0.90476;
	3184	 1	 28.4	 -0.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3185	 1	 43.6	 -4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3186	 1	 19.6	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3187	 1	 12.5	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3188	 1	 14.5	 -1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3189	 1	 0.0	 -2.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3190	 1	 46.2	 8.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3191	 1	 9.2	 3.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3192	 1	 18.2	 3.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3193	 1	 27.4	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3194	 1	 32.0	 33.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3195	 1	 31.4	 0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3196	 1	 10.3	 3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3197	 1	 36.9	 9.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3198	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3199	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3200	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3201	 1	 50.3	 11.1	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	3202	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99556	    0.00000	 225.0	 1	    1.08889	    0.90222;
	3203	 1	 11.9	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3204	 1	 20.1	 6.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3205	 1	 0.6	 6.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3206	 1	 18.0	 -1.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3207	 1	 14.0	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3208	 1	 20.7	 2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	3209	 1	 21.1	 -3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3210	 2	 4.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3211	 1	 44.7	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3212	 1	 100.7	 23.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3213	 1	 7.9	 -0.3	 0.0	 0.0	 1	    0.96825	    0.00000	 63.0	 1	    1.04762	    0.88889;
	3214	 1	 0.7	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3215	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02536	    0.00000	 63.0	 1	    1.09834	    0.95238;
	3216	 1	 2.0	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3217	 1	 136.4	 48.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3218	 1	 41.0	 -2.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3219	 1	 16.1	 -3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3220	 1	 53.0	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3221	 1	 5.0	 -2.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3222	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3223	 1	 0.6	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3224	 1	 15.2	 4.9	 0.0	 0.0	 1	    1.01565	    0.00000	 63.0	 1	    1.06349	    0.96781;
	3225	 1	 2.1	 -0.1	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3226	 1	 26.9	 -7.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3227	 1	 23.0	 -3.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3228	 1	 4.9	 6.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3229	 1	 -0.6	 -0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3230	 1	 34.2	 -41.7	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3231	 1	 44.4	 6.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3232	 1	 40.9	 5.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3233	 1	 32.9	 6.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3234	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3235	 1	 32.4	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3236	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3237	 1	 3.5	 3.2	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3238	 1	 23.6	 2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3239	 2	 0.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3240	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3241	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3242	 1	 8.8	 3.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3243	 1	 25.0	 50.9	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	3244	 1	 18.8	 2.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3245	 1	 28.7	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3246	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3247	 1	 33.3	 1.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3248	 1	 3.5	 0.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3249	 1	 8.3	 -4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3250	 1	 43.8	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3251	 1	 46.7	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3252	 1	 10.0	 1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3253	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3254	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3255	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3256	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3258	 1	 45.1	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3259	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3260	 1	 17.8	 1.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3261	 1	 24.2	 3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3262	 1	 63.9	 9.9	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3263	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3264	 2	 0.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3265	 1	 5.7	 -11.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3266	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3267	 1	 16.6	 3.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3268	 1	 30.0	 3.5	 0.0	 0.0	 1	    0.99622	    0.00000	 63.0	 1	    1.04762	    0.94481;
	3269	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3270	 1	 31.5	 2.4	 0.0	 0.0	 1	    1.00222	    0.00000	 225.0	 1	    1.08889	    0.91556;
	3271	 1	 72.1	 11.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3272	 1	 23.0	 2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3273	 1	 115.7	 7.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3274	 1	 27.8	 -7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3276	 1	 14.8	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3277	 1	 52.4	 0.4	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	3278	 1	 -0.2	 18.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3279	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3280	 2	 -0.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3281	 2	 -2.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3282	 2	 -2.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3283	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3284	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3285	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3286	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3287	 1	 1.7	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3288	 1	 55.2	 5.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3289	 1	 0.2	 -1.5	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	3290	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02407	    0.00000	 63.0	 1	    1.09575	    0.95238;
	3291	 1	 48.4	 0.0	 0.0	 0.0	 1	    1.03795	    0.00000	 225.0	 1	    1.08924	    0.98667;
	3292	 1	 24.3	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3293	 1	 9.5	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3294	 1	 0.9	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3295	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3296	 1	 9.9	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3297	 1	 14.6	 1.4	 0.0	 15.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3298	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3300	 1	 0.3	 -0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3301	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3302	 1	 44.7	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3303	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3304	 1	 23.3	 0.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3305	 1	 1.9	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3306	 1	 2.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3307	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3308	 2	 0.7	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3309	 1	 1.5	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3310	 1	 12.0	 0.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3311	 1	 47.4	 13.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3312	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3313	 1	 2.0	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3314	 1	 30.3	 -1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3315	 1	 17.6	 -3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3316	 1	 4.0	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3317	 1	 -1.5	 64.3	 0.0	 0.0	 1	    1.07432	    0.00000	 380.0	 1	    1.10654	    1.04211;
	3318	 1	 0.0	 -4.6	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3319	 1	 27.9	 21.4	 0.0	 0.0	 1	    1.07517	    0.00000	 380.0	 1	    1.10822	    1.04211;
	3320	 1	 31.0	 25.9	 0.0	 0.0	 1	    1.07581	    0.00000	 380.0	 1	    1.10952	    1.04211;
	3321	 1	 -0.2	 0.3	 0.0	 60.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3322	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3324	 1	 -1.5	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3325	 1	 6.0	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3326	 1	 3.8	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3327	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3328	 1	 0.6	 0.3	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3329	 1	 10.6	 3.2	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3330	 1	 19.0	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3331	 1	 22.2	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3332	 1	 22.0	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3333	 1	 0.0	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3334	 1	 47.6	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3335	 1	 15.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3336	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3337	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3338	 1	 27.1	 -2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3339	 1	 51.2	 7.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3340	 1	 15.8	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3341	 1	 -0.2	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3342	 1	 53.4	 11.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3343	 1	 3.0	 2.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3344	 1	 2.9	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3345	 2	 29.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3346	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3347	 1	 8.3	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3348	 1	 34.1	 -1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3349	 1	 0.4	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3350	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3351	 1	 41.2	 -21.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3352	 1	 3.0	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3353	 1	 34.8	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3354	 1	 21.7	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3355	 1	 27.9	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3356	 1	 46.4	 6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3357	 1	 1.9	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3358	 1	 18.0	 -0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3359	 1	 42.2	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3360	 1	 25.7	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3361	 1	 23.9	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3362	 1	 1.0	 -4.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3363	 1	 40.4	 -4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3364	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3365	 1	 72.6	 7.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04228	    0.00000	 63.0	 1	    1.13217	    0.95238;
	3367	 1	 123.8	 0.0	 0.0	 0.0	 1	    1.03865	    0.00000	 225.0	 1	    1.09064	    0.98667;
	3368	 1	 2.1	 -0.1	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3369	 1	 5.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3370	 1	 30.7	 3.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3371	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3372	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3373	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07383	    0.00000	 380.0	 1	    1.10554	    1.04211;
	3374	 1	 -19.2	 8.0	 0.0	 0.0	 1	    1.07384	    0.00000	 380.0	 1	    1.10557	    1.04211;
	3375	 1	 2.9	 3.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3376	 1	 22.5	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3377	 1	 30.5	 -0.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3378	 1	 6.4	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3379	 1	 23.4	 1.4	 0.0	 0.0	 1	    1.02967	    0.00000	 90.0	 1	    1.08157	    0.97778;
	3380	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	3381	 1	 0.0	 0.0	 0.0	 80.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3382	 1	 36.3	 2.4	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3383	 1	 8.1	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3384	 1	 12.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3385	 1	 3.6	 -3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3386	 1	 0.0	 -0.9	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3387	 1	 35.0	 -2.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3388	 1	 7.8	 -0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3389	 1	 38.0	 -1.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3390	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3391	 1	 0.8	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3392	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3393	 1	 39.9	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3394	 1	 16.6	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3395	 1	 36.3	 5.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3396	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	3397	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02445	    0.00000	 225.0	 1	    1.08889	    0.96000;
	3398	 1	 34.7	 2.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3399	 1	 40.9	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3400	 1	 38.5	 3.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3401	 1	 39.9	 16.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3402	 1	 5.3	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3403	 1	 29.0	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3404	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3405	 2	 39.0	 18.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3406	 1	 24.3	 2.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3407	 1	 83.5	 0.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3408	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3409	 1	 31.8	 -3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3410	 1	 174.2	 84.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3411	 1	 15.4	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3412	 1	 15.1	 -2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3413	 1	 5.4	 0.8	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3414	 1	 3.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3415	 1	 23.7	 2.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3416	 1	 3.9	 -6.4	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	3417	 1	 3.6	 -4.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3418	 2	 -5.3	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3419	 1	 26.1	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3420	 1	 11.6	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3421	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3422	 1	 28.6	 2.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3423	 1	 44.5	 -10.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3424	 2	 41.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3425	 1	 7.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3426	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3427	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3428	 1	 -0.8	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3429	 1	 29.3	 -1.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3430	 1	 -2.0	 -12.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3431	 1	 45.3	 1.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3432	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3433	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	3434	 1	 6.6	 1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3435	 1	 12.2	 -0.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3436	 1	 25.8	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3437	 1	 4.9	 -2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3438	 1	 54.1	 1.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3439	 1	 32.0	 -0.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3440	 1	 32.1	 -4.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3441	 1	 4.8	 -32.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3442	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.95000	    0.00000	 150.0	 1	    1.10000	    0.80000;
	3443	 1	 10.2	 1.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3445	 1	 16.6	 1.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3446	 1	 0.1	 0.7	 0.0	 0.0	 1	    0.98805	    0.00000	 63.0	 1	    1.07133	    0.90476;
	3447	 1	 32.2	 -0.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3448	 1	 12.7	 -1.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3449	 1	 22.3	 1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3450	 1	 7.0	 -4.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3451	 1	 6.1	 -0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3452	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3453	 1	 25.4	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3454	 1	 17.9	 -2.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3455	 1	 27.2	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3456	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3457	 1	 69.6	 13.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3458	 1	 26.3	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3459	 1	 27.5	 -7.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3460	 1	 19.7	 2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3461	 1	 22.1	 2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3462	 1	 -0.2	 -3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3463	 1	 43.0	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3464	 1	 18.9	 12.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3465	 1	 31.3	 12.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3466	 1	 45.5	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3467	 1	 7.8	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3468	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3469	 1	 25.5	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3470	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3471	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04802	    0.00000	 380.0	 1	    1.10263	    0.99341;
	3472	 1	 1.4	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3473	 1	 1.4	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3474	 1	 0.4	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3475	 1	 6.4	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3482	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3483	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3484	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3485	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3486	 1	 34.3	 4.6	 0.0	 0.0	 1	    1.00545	    0.00000	 63.0	 1	    1.06349	    0.94742;
	3487	 1	 48.9	 0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3488	 1	 46.0	 -3.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3489	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3490	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3491	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00713	    0.00000	 150.0	 1	    1.11426	    0.90000;
	3492	 1	 11.5	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3493	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3494	 1	 12.8	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3495	 1	 10.2	 -2.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3496	 1	 20.5	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3497	 1	 21.0	 2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3498	 1	 30.7	 2.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3499	 1	 -0.2	 -0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3500	 1	 17.8	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3501	 1	 9.0	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3502	 2	 0.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3503	 1	 -2.7	 11.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3504	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3505	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3506	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3507	 1	 -5.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3508	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3509	 1	 9.6	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3510	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3511	 1	 9.0	 3.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3512	 1	 26.7	 4.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3513	 1	 42.0	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3514	 1	 8.5	 -5.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3515	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3516	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	3517	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	3518	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3519	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3520	 1	 8.7	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3521	 1	 1.5	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3522	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3523	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3524	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3525	 1	 12.9	 -3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3526	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3527	 1	 0.5	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3528	 1	 14.7	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3529	 1	 65.4	 12.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3530	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	3531	 1	 35.6	 3.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3532	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3533	 1	 14.6	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3534	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3535	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3536	 1	 1.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3537	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3538	 1	 6.2	 2.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3539	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3540	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.00889	    0.00000	 225.0	 1	    1.08889	    0.92889;
	3541	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3542	 1	 25.2	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3543	 1	 45.8	 12.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3544	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3545	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3546	 1	 46.1	 14.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3547	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3548	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3549	 1	 7.8	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3550	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04243	    0.00000	 63.0	 1	    1.13248	    0.95238;
	3551	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3552	 1	 38.7	 3.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3553	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3554	 1	 18.9	 2.3	 0.0	 0.0	 1	    1.00026	    0.00000	 63.0	 1	    1.06402	    0.93651;
	3555	 1	 28.7	 9.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3556	 1	 6.5	 12.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3557	 1	 65.7	 0.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3558	 1	 35.0	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3559	 1	 -5.0	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3560	 1	 21.5	 5.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3561	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3562	 1	 19.6	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3563	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3564	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3565	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3566	 1	 81.2	 38.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3567	 1	 19.9	 11.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3568	 1	 35.4	 4.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3569	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3570	 1	 10.2	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3571	 1	 0.2	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3572	 1	 27.1	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3573	 1	 49.2	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3574	 1	 -0.9	 0.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3575	 1	 52.1	 17.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3576	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3577	 1	 41.7	 0.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3578	 1	 49.7	 8.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3582	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3583	 1	 43.4	 7.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3584	 1	 4.6	 0.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3585	 1	 36.0	 -4.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3586	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3587	 2	 -1.7	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3588	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3589	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3590	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3591	 1	 18.7	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3592	 1	 14.1	 -0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3593	 1	 7.6	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3594	 1	 -0.9	 2.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3595	 1	 -3.6	 13.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3596	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3597	 1	 29.1	 -8.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3598	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3599	 1	 1.2	 0.8	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	3600	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00238	    0.00000	 150.0	 1	    1.10475	    0.90000;
	3601	 1	 24.9	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3602	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3604	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3605	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3606	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3607	 1	 -1.6	 -5.6	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3608	 1	 20.8	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3610	 1	 32.4	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3611	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3612	 1	 20.4	 -3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3613	 1	 16.7	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3614	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3615	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3616	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3617	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3618	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3619	 1	 3.9	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3620	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3621	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3622	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3623	 1	 22.3	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3624	 1	 7.0	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3625	 1	 0.0	 0.0	 0.0	 20.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3626	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	3627	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3628	 1	 3.9	 -0.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3629	 1	 1.9	 -0.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3630	 1	 10.0	 4.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3631	 1	 11.0	 4.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3632	 1	 67.5	 29.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3633	 1	 23.6	 8.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3634	 1	 11.6	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3635	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3636	 1	 59.2	 1.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3637	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3638	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3639	 1	 25.6	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3640	 1	 55.5	 0.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3641	 1	 17.7	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3642	 1	 10.0	 -6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3643	 1	 25.1	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3644	 1	 5.1	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3645	 1	 13.9	 -2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3646	 1	 14.8	 4.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3647	 1	 21.1	 10.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3648	 1	 32.4	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3649	 1	 44.7	 14.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3650	 1	 -12.3	 -19.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3651	 1	 9.0	 2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3652	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3653	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3654	 2	 18.2	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3655	 1	 84.3	 56.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3656	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3657	 1	 4.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3658	 1	 10.7	 -2.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3659	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3660	 1	 10.9	 -9.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3661	 1	 16.1	 20.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3662	 1	 15.7	 -1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3663	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3664	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3665	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3666	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3667	 1	 0.0	 0.0	 0.0	 40.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3668	 2	 0.7	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3669	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3670	 1	 16.6	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3671	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	3672	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	3673	 1	 16.4	 -3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3674	 1	 26.9	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3675	 1	 52.1	 -2.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3676	 1	 7.1	 6.0	 0.0	 0.0	 1	    1.04744	    0.00000	 225.0	 1	    1.09045	    1.00444;
	3677	 1	 13.7	 1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3678	 1	 2.7	 1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3679	 1	 49.1	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3680	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3681	 1	 14.0	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3682	 1	 8.0	 -4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3683	 1	 10.9	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3684	 1	 26.7	 3.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3685	 2	 16.6	 0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3686	 1	 33.8	 4.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3687	 2	 -0.6	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3688	 1	 8.1	 -0.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3690	 1	 91.4	 33.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3691	 1	 24.4	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3692	 1	 12.9	 8.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3693	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3694	 1	 47.4	 6.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	3695	 1	 27.8	 5.7	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3696	 1	 18.1	 2.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3697	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3698	 1	 15.9	 2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3699	 1	 15.9	 -0.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3700	 1	 13.4	 -10.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3701	 1	 52.8	 -0.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3702	 1	 0.6	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3703	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3704	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3706	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	3707	 1	 6.0	 2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3708	 1	 77.1	 7.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3709	 1	 5.9	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3710	 1	 32.0	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3711	 1	 74.8	 1.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3712	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3713	 1	 103.1	 20.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3714	 1	 6.5	 3.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3715	 1	 49.0	 -3.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3716	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3717	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3718	 2	 -1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3719	 1	 17.9	 -1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3720	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3721	 1	 49.6	 5.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3722	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3723	 1	 0.2	 1.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3724	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3725	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3726	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3727	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3728	 1	 -1.0	 -1.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3729	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3730	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	3731	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3732	 1	 11.0	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3733	 1	 33.9	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3734	 1	 15.7	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3735	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3736	 1	 77.9	 11.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3737	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3738	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3739	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3740	 1	 6.0	 5.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3741	 1	 6.0	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3742	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3743	 1	 44.7	 19.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3744	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3745	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3746	 1	 76.3	 14.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3747	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04733	    0.00000	 225.0	 1	    1.09023	    1.00444;
	3748	 1	 0.4	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3749	 2	 6.2	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3750	 1	 11.6	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3751	 1	 0.9	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3752	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3753	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	3754	 1	 8.2	 -6.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3755	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3756	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3757	 1	 28.6	 0.1	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3758	 1	 31.5	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3759	 1	 37.6	 11.2	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	3760	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3761	 1	 10.0	 -0.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3762	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3763	 1	 9.8	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3764	 1	 331.2	 138.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3765	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3766	 1	 13.5	 3.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3767	 1	 31.0	 3.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3768	 1	 88.6	 37.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3769	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3770	 1	 0.4	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3771	 1	 -0.2	 1.2	 0.0	 0.0	 1	    1.03965	    0.00000	 225.0	 1	    1.09264	    0.98667;
	3772	 1	 8.5	 3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3773	 1	 22.9	 2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3774	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3775	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3776	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3777	 1	 23.4	 8.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3778	 1	 47.4	 24.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3779	 1	 20.4	 -14.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3780	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3781	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3782	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3783	 1	 8.1	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3784	 1	 1.2	 1.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3785	 1	 -4.1	 3.6	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3786	 1	 33.8	 11.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3787	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3788	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3789	 1	 18.8	 3.2	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3790	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3791	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3792	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3793	 1	 55.6	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3794	 1	 29.7	 9.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3795	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3796	 1	 25.7	 3.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3797	 1	 12.5	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3798	 1	 6.8	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3799	 1	 15.5	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3800	 1	 31.0	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3801	 1	 -2.3	 -4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3802	 1	 30.7	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3803	 1	 24.8	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3804	 1	 3.3	 3.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3805	 1	 18.3	 1.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3806	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	3807	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	3808	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	3809	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	3810	 1	 18.2	 -0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3811	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3812	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3813	 1	 12.4	 -1.2	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	3814	 1	 41.2	 2.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3815	 1	 14.9	 5.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3816	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3817	 2	 -0.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3818	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3819	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3820	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3821	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3822	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3823	 1	 17.0	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3824	 1	 -0.1	 0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3825	 1	 16.5	 1.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3826	 1	 0.9	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3827	 1	 13.8	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3828	 1	 37.8	 3.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3829	 1	 24.0	 3.4	 0.0	 0.0	 1	    1.04730	    0.00000	 225.0	 1	    1.09016	    1.00444;
	3830	 1	 39.2	 10.1	 0.0	 0.0	 1	    1.04723	    0.00000	 225.0	 1	    1.09002	    1.00444;
	3831	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3832	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3833	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03814	    0.00000	 225.0	 1	    1.08961	    0.98667;
	3834	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3835	 1	 29.0	 15.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	3836	 1	 21.3	 -2.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	3837	 1	 40.5	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3838	 1	 12.2	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3839	 1	 33.8	 -8.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3840	 1	 43.7	 11.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3841	 1	 45.1	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3842	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3843	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3844	 1	 10.9	 -5.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3845	 1	 10.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3846	 1	 3.0	 0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3847	 1	 82.8	 0.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3848	 1	 1.1	 -0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3849	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3850	 1	 20.8	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3851	 1	 33.1	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3852	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3853	 1	 1.8	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3854	 2	 0.7	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3855	 1	 5.4	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3856	 1	 11.1	 1.9	 0.0	 0.0	 1	    1.00125	    0.00000	 63.0	 1	    1.06600	    0.93651;
	3857	 1	 40.3	 3.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3858	 1	 6.0	 -2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3859	 1	 39.5	 -4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3860	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3861	 1	 43.9	 1.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3862	 1	 36.8	 3.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3863	 1	 30.6	 11.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3864	 1	 3.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3865	 1	 35.8	 -8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3866	 1	 16.9	 9.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3867	 1	 17.1	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3868	 1	 21.6	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3869	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3870	 1	 40.4	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3871	 1	 22.4	 -1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3872	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3873	 1	 3.8	 4.4	 0.0	 0.0	 1	    1.04732	    0.00000	 225.0	 1	    1.09021	    1.00444;
	3874	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3875	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3876	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3877	 1	 23.0	 -3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3878	 1	 15.2	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3879	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3880	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3881	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3882	 1	 68.2	 9.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3883	 1	 35.6	 6.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3884	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3885	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3886	 1	 -0.1	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3887	 1	 35.5	 -3.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3888	 1	 21.7	 3.7	 0.0	 0.0	 1	    1.01581	    0.00000	 63.0	 1	    1.07937	    0.95225;
	3889	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3890	 1	 12.4	 -1.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.06667	    0.98889;
	3891	 1	 28.4	 -0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3892	 1	 15.5	 -2.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3893	 1	 0.2	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3894	 2	 22.7	 -1.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3895	 1	 0.2	 1.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3896	 1	 30.9	 7.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3897	 1	 35.4	 1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3898	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3899	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3900	 1	 1.0	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3901	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3902	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3903	 1	 29.5	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3904	 1	 2.5	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3905	 1	 13.8	 -2.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3906	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04676	    0.00000	 225.0	 1	    1.08908	    1.00444;
	3907	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3908	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3909	 1	 20.6	 22.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3910	 1	 6.3	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3911	 1	 1.8	 8.4	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	3912	 1	 16.2	 -2.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3913	 1	 5.0	 -2.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3914	 1	 50.2	 3.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3915	 1	 8.3	 -5.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3916	 1	 13.9	 3.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3917	 1	 25.6	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3918	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3919	 1	 10.9	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3920	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3921	 1	 39.0	 2.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3922	 1	 32.0	 6.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3923	 1	 38.4	 4.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3924	 1	 3.2	 2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	3925	 1	 18.6	 3.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	3926	 1	 14.6	 -3.7	 0.0	 0.0	 1	    1.02667	    0.00000	 225.0	 1	    1.08889	    0.96444;
	3927	 1	 10.3	 7.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3928	 2	 2.9	 -1.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3929	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	3930	 1	 11.5	 -10.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3931	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3932	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3933	 1	 10.5	 -4.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3934	 1	 2.6	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3935	 1	 55.4	 -5.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3936	 1	 58.4	 6.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3937	 1	 17.9	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3938	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3939	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	3940	 1	 24.7	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3941	 1	 1.4	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3942	 1	 0.0	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3943	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3944	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3945	 1	 20.7	 1.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3946	 1	 1.4	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3947	 1	 6.9	 -0.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3948	 1	 86.3	 31.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3949	 1	 34.6	 8.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3950	 1	 4.4	 1.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3951	 1	 8.5	 -3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3952	 1	 2.3	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3953	 1	 17.0	 2.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3954	 1	 14.7	 2.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3955	 1	 12.0	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3956	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3957	 1	 18.7	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3958	 1	 15.0	 0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3959	 1	 38.8	 7.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3960	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3961	 1	 0.6	 0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3962	 1	 0.7	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3963	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3964	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3965	 1	 41.8	 -4.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3966	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3967	 1	 94.3	 28.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3968	 1	 24.0	 6.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3969	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3970	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3971	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3972	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3973	 1	 18.3	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3974	 1	 24.2	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3975	 1	 23.2	 2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3976	 1	 6.9	 -2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3977	 1	 0.0	 -21.8	 0.0	 0.0	 1	    1.04054	    0.00000	 225.0	 1	    1.09441	    0.98667;
	3978	 2	 17.4	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3979	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3980	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3981	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3982	 1	 30.7	 -4.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3983	 1	 17.5	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3984	 1	 4.3	 2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3985	 1	 55.4	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3986	 1	 23.9	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3987	 1	 1.0	 -0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3988	 2	 14.3	 0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3989	 1	 23.3	 0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3990	 1	 7.9	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3991	 1	 13.1	 -1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3992	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3993	 1	 0.6	 1.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3994	 1	 -3.0	 -0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3995	 1	 25.3	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3996	 1	 5.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3997	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3998	 1	 -1.6	 -4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3999	 1	 14.9	 -5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4000	 1	 3.6	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4001	 1	 32.6	 -1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	4002	 1	 40.5	 8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4003	 1	 2.3	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4004	 1	 23.7	 -1.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4005	 1	 44.2	 -4.3	 0.0	 34.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4006	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4007	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4008	 1	 15.4	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4009	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4010	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4011	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4012	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4013	 1	 14.4	 -0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4014	 1	 -0.7	 -1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4015	 1	 32.4	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4016	 1	 29.9	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4017	 1	 51.1	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4018	 1	 21.8	 11.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4019	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4020	 1	 15.1	 6.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4021	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4022	 1	 35.6	 -4.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4023	 1	 5.3	 -10.3	 0.0	 0.0	 1	    1.03836	    0.00000	 225.0	 1	    1.09006	    0.98667;
	4024	 1	 28.9	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4025	 1	 20.2	 -1.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4026	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4027	 1	 -6.2	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4028	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4029	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	4030	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4031	 1	 71.7	 13.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4032	 1	 20.8	 0.1	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	4033	 1	 3.3	 -0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4034	 1	 15.0	 5.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4035	 1	 19.7	 -0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4036	 1	 23.2	 -1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4037	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4038	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4039	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4040	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4041	 1	 116.6	 32.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4042	 1	 15.6	 -3.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4043	 1	 44.5	 2.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4044	 1	 76.0	 12.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4045	 1	 47.1	 -1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4046	 1	 9.5	 -1.7	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4047	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4048	 1	 45.9	 13.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4049	 1	 17.5	 2.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4050	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4051	 1	 8.5	 5.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4052	 1	 7.9	 -1.8	 0.0	 0.0	 1	    0.97500	    0.00000	 63.0	 1	    1.15000	    0.80000;
	4053	 1	 0.5	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4054	 1	 22.0	 2.3	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	4055	 1	 9.0	 -1.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4056	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4057	 1	 11.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4058	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4059	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4060	 1	 23.7	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4061	 1	 19.7	 0.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4062	 1	 57.6	 52.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4063	 1	 8.3	 1.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4064	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4065	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4066	 1	 19.4	 3.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4067	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	4068	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4069	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4070	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4071	 1	 29.5	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4072	 1	 16.8	 -0.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4073	 1	 33.7	 6.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4074	 1	 10.8	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4075	 1	 0.7	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4076	 1	 18.3	 -1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4077	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4078	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4079	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4080	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4081	 1	 64.2	 14.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4082	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4083	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04683	    0.00000	 225.0	 1	    1.08921	    1.00444;
	4084	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4085	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4086	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4087	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4088	 1	 14.9	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4089	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4090	 1	 65.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4091	 1	 13.6	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4092	 1	 5.4	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4093	 1	 25.1	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4094	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4095	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4096	 1	 25.8	 2.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4097	 1	 31.3	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4098	 1	 -0.3	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4099	 1	 10.0	 -3.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4100	 1	 0.8	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4101	 1	 39.2	 -2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4102	 1	 17.6	 13.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4104	 1	 83.2	 21.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4105	 1	 27.2	 2.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4106	 1	 0.0	 0.0	 0.0	 -64.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4107	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4108	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4109	 1	 0.1	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4110	 1	 7.0	 -1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4111	 1	 25.5	 -1.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4114	 1	 0.5	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4115	 1	 39.3	 9.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4116	 1	 14.3	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4117	 1	 7.4	 1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4118	 1	 1.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4119	 1	 34.9	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4120	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	4121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4122	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	4123	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	4124	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	4125	 1	 14.6	 -0.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4126	 1	 11.6	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4127	 1	 7.3	 -5.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4128	 1	 74.3	 16.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4129	 1	 34.2	 6.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4130	 1	 24.5	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4131	 2	 16.0	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4132	 1	 25.1	 -0.3	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	4133	 2	 26.3	 -4.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4134	 1	 0.2	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4136	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4137	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4138	 1	 13.6	 -2.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4139	 1	 11.2	 -0.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4140	 1	 37.8	 4.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	4141	 1	 14.2	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4142	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4143	 1	 44.6	 9.5	 0.0	 34.0	 1	    1.02377	    0.00000	 90.0	 1	    1.06977	    0.97778;
	4144	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4145	 1	 18.7	 7.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4146	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4147	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4148	 1	 45.1	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4149	 1	 15.0	 -4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4150	 1	 16.8	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4151	 1	 29.4	 -1.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4152	 1	 -1.5	 -1.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4153	 1	 -1.5	 -2.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4154	 1	 14.1	 1.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	4155	 1	 29.0	 18.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4157	 1	 12.0	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4158	 1	 28.6	 2.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4159	 1	 80.1	 4.6	 0.0	 0.0	 1	    1.04730	    0.00000	 225.0	 1	    1.09015	    1.00444;
	4160	 1	 0.0	 0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4161	 1	 5.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4162	 1	 42.0	 0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4163	 1	 36.4	 2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4164	 1	 27.8	 -1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4165	 1	 14.6	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4166	 1	 25.6	 -3.6	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	4167	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	4168	 1	 6.0	 -0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4169	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4170	 1	 6.3	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4171	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4172	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04453	    0.00000	 225.0	 1	    1.08463	    1.00444;
	4174	 1	 -7.2	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4175	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4176	 1	 48.3	 6.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4177	 1	 18.8	 1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4178	 1	 24.1	 -7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4179	 1	 24.8	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4180	 1	 30.4	 7.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4181	 1	 10.0	 4.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4182	 1	 8.7	 -1.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4183	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4184	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4185	 1	 22.5	 2.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4186	 1	 13.5	 -48.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.04762	    0.98413;
	4187	 1	 19.1	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4188	 1	 1.0	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4189	 1	 -0.6	 -3.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4190	 1	 -0.6	 -3.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4191	 1	 5.0	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4192	 1	 64.3	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4193	 1	 45.9	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4194	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4195	 1	 0.3	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4196	 1	 35.3	 -3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4197	 1	 82.2	 14.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4198	 1	 55.3	 -6.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4199	 1	 9.9	 -6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4200	 1	 27.3	 -5.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4201	 1	 29.7	 3.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4202	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4203	 1	 4.0	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4204	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4205	 1	 11.2	 -4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4206	 1	 6.2	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4207	 1	 40.0	 1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4208	 1	 57.1	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4209	 1	 9.5	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4210	 1	 14.3	 -1.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4211	 1	 100.6	 6.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4212	 1	 30.3	 12.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4213	 1	 10.1	 3.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4214	 1	 6.6	 0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4215	 1	 33.1	 -2.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4216	 1	 12.1	 3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4217	 1	 0.1	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4218	 1	 31.9	 16.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4219	 1	 40.6	 13.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4220	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03779	    0.00000	 225.0	 1	    1.08892	    0.98667;
	4221	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4222	 1	 15.0	 6.9	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4223	 1	 26.0	 3.6	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4224	 1	 -0.2	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4225	 1	 8.8	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4226	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4227	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4228	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4229	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4230	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4231	 1	 1.0	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4232	 1	 19.9	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4233	 2	 -6.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4234	 1	 10.8	 -0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4235	 1	 18.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4236	 1	 12.8	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4237	 1	 30.8	 -2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4238	 1	 30.8	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4239	 1	 23.0	 3.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4240	 1	 38.0	 3.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4241	 1	 11.8	 3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4242	 1	 18.7	 -0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4243	 1	 40.9	 4.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4244	 1	 21.7	 3.5	 0.0	 34.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4245	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4246	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4247	 2	 17.8	 4.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4248	 1	 1.0	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4249	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4250	 1	 23.7	 -0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4251	 1	 14.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4252	 1	 32.5	 9.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4253	 1	 40.6	 14.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4254	 1	 48.2	 -1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4255	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4256	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4257	 1	 0.0	 0.0	 0.0	 20.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4258	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4259	 1	 29.0	 11.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4260	 1	 37.7	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4261	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4262	 1	 22.7	 -7.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4263	 1	 1.0	 -0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4265	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4266	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4267	 1	 53.4	 0.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4268	 1	 19.6	 -3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4269	 1	 2.0	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4270	 1	 2.2	 -0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4272	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4273	 1	 26.8	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4274	 1	 28.1	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4275	 1	 19.0	 2.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4276	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4277	 2	 2.2	 -2.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	4279	 1	 0.5	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4280	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4281	 1	 34.0	 8.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4282	 1	 13.7	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4283	 1	 28.5	 6.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4284	 1	 49.8	 11.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4285	 1	 35.7	 0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4286	 1	 1.3	 0.4	 0.0	 0.0	 1	    1.04692	    0.00000	 225.0	 1	    1.08941	    1.00444;
	4287	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4288	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4289	 1	 39.9	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4290	 1	 9.0	 8.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4291	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4292	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03817	    0.00000	 63.0	 1	    1.12396	    0.95238;
	4293	 1	 10.9	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4294	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4295	 2	 1.3	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4296	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4297	 1	 27.8	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4298	 1	 19.5	 0.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4300	 1	 2.0	 2.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4301	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4302	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4303	 1	 13.8	 -6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4304	 1	 55.9	 10.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4305	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4306	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4307	 1	 14.3	 0.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4308	 1	 0.4	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4309	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4310	 1	 -0.3	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4311	 1	 18.8	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4312	 1	 37.3	 1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4313	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4314	 1	 22.0	 4.2	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4315	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4316	 1	 27.6	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4317	 2	 -2.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4318	 1	 0.6	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4319	 1	 45.9	 6.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4320	 1	 39.7	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4321	 2	 -13.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4322	 2	 0.0	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4323	 1	 54.1	 -4.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4324	 1	 8.1	 -10.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4325	 1	 19.6	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4326	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4327	 1	 18.2	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4328	 2	 1.6	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4329	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4330	 1	 9.0	 -2.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4331	 1	 31.4	 15.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4332	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4333	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03805	    0.00000	 225.0	 1	    1.08943	    0.98667;
	4334	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4335	 1	 20.0	 -2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4336	 1	 14.7	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4337	 1	 15.9	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4338	 1	 25.7	 4.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4339	 1	 28.1	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4340	 1	 1.9	 -0.4	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4341	 1	 21.0	 1.7	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4342	 1	 22.0	 1.7	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4343	 1	 30.0	 -2.4	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4344	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4345	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4346	 1	 12.8	 -2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4347	 2	 0.7	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4348	 1	 153.8	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4349	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03903	    0.00000	 225.0	 1	    1.09139	    0.98667;
	4350	 1	 30.9	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4351	 1	 41.2	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4352	 1	 20.7	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4353	 1	 21.7	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4354	 2	 5.1	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4355	 1	 55.4	 7.1	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4356	 1	 7.0	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4357	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4358	 1	 24.3	 -2.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4359	 1	 21.5	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4360	 1	 15.1	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4361	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4362	 1	 27.3	 -5.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4363	 1	 45.2	 7.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4364	 1	 0.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4365	 1	 26.1	 -0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4366	 1	 57.8	 -1.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4367	 1	 -6.4	 -5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4368	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4369	 1	 8.3	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4370	 1	 4.6	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4371	 1	 32.2	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4372	 1	 21.1	 -4.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4373	 1	 4.0	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4374	 1	 17.2	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4375	 1	 11.8	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4376	 1	 12.0	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4377	 1	 17.4	 4.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4378	 1	 13.9	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4379	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4380	 1	 31.4	 2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4381	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4382	 1	 27.1	 -4.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4383	 1	 19.0	 9.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4384	 1	 3.7	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4385	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4386	 1	 34.5	 1.9	 0.0	 0.0	 1	    1.04725	    0.00000	 225.0	 1	    1.09006	    1.00444;
	4387	 1	 86.4	 7.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4388	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4389	 1	 6.4	 1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4390	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4391	 1	 56.0	 2.8	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4392	 1	 6.0	 1.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4393	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4394	 1	 11.4	 -1.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4395	 1	 9.8	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4396	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	4397	 1	 46.7	 20.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	4398	 1	 32.7	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4399	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4400	 1	 91.6	 20.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4401	 1	 3.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4402	 1	 31.0	 3.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4403	 1	 32.0	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4404	 1	 35.0	 -4.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4405	 1	 3.3	 -0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4406	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4407	 1	 21.9	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4408	 1	 46.4	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4409	 1	 13.2	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4410	 1	 21.9	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4411	 1	 24.4	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4412	 1	 41.2	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4413	 1	 43.2	 6.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4414	 1	 22.7	 -4.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4415	 1	 49.2	 2.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4416	 2	 -0.5	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4417	 1	 0.0	 0.0	 0.0	 -15.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4418	 1	 7.2	 -1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4419	 1	 31.6	 8.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4420	 1	 26.6	 1.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4421	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4422	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4423	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4424	 1	 11.4	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4425	 1	 9.8	 4.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4426	 1	 -0.2	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4427	 1	 15.1	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4428	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4429	 1	 29.8	 1.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4430	 1	 23.5	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4431	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4432	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4433	 1	 8.7	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4434	 1	 40.2	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4435	 1	 25.6	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4436	 1	 7.4	 -0.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4437	 1	 19.1	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4438	 1	 0.9	 -0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4439	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4440	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4441	 1	 62.0	 6.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4442	 1	 30.3	 10.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4443	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02486	    0.00000	 150.0	 1	    1.08306	    0.96667;
	4444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4445	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4446	 1	 2.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4447	 1	 15.9	 8.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4448	 1	 -0.3	 11.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4449	 1	 29.4	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4450	 1	 31.6	 5.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4451	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4452	 1	 13.3	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4453	 1	 0.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4454	 1	 1.0	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4455	 1	 8.8	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4456	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4457	 1	 37.0	 5.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4458	 1	 45.5	 15.0	 0.0	 20.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4460	 1	 40.5	 10.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4461	 1	 13.9	 -4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4462	 1	 6.2	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4463	 1	 0.2	 -3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4464	 1	 1.3	 -4.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4465	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4466	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4467	 1	 16.8	 12.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4468	 1	 29.6	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4469	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4470	 1	 13.9	 1.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4471	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4472	 1	 9.0	 -4.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4473	 1	 17.1	 9.2	 0.0	 15.4	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4474	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	4475	 2	 -9.0	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4476	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4477	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4478	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4479	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4480	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4482	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4483	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4484	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4485	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4486	 1	 -2.0	 2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4487	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4488	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4489	 1	 14.3	 -8.0	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	4490	 1	 9.9	 3.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4491	 1	 12.0	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4492	 1	 3.0	 -1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4493	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4494	 1	 23.7	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4495	 1	 27.2	 3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4496	 1	 33.3	 5.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4497	 1	 6.0	 3.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4498	 1	 3.9	 -2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4499	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03281	    0.00000	 63.0	 1	    1.09736	    0.96825;
	4500	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03281	    0.00000	 63.0	 1	    1.09736	    0.96825;
	4501	 1	 17.5	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	4502	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4503	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4504	 1	 0.0	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4505	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4506	 2	 61.6	 10.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4507	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4508	 1	 1.2	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4509	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4510	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4511	 1	 23.6	 -2.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4512	 1	 14.3	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4513	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4514	 1	 22.1	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4515	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.08889	    0.93778;
	4516	 1	 67.2	 6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4517	 1	 47.6	 10.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4518	 1	 5.7	 -9.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4519	 1	 19.3	 -4.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4520	 1	 30.5	 -3.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4521	 1	 12.3	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4522	 1	 1.2	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4523	 1	 15.3	 12.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4524	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	4525	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4526	 1	 12.9	 1.9	 0.0	 0.0	 1	    0.96825	    0.00000	 63.0	 1	    1.04762	    0.88889;
	4527	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4528	 1	 12.2	 -1.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4529	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4530	 1	 13.3	 3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4531	 1	 -1.9	 -1.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4532	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4533	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4534	 1	 29.9	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4535	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.82500	    0.00000	 20.0	 1	    1.15000	    0.50000;
	4536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4537	 1	 13.2	 -2.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4538	 1	 27.3	 8.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4539	 1	 39.8	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4540	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4541	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4542	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4543	 1	 39.6	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4544	 1	 0.2	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4545	 1	 23.4	 0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4546	 1	 -0.2	 0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4547	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4548	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	4549	 1	 26.8	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4550	 1	 16.5	 4.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4551	 1	 27.3	 -2.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4552	 1	 7.4	 -6.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4553	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4554	 1	 28.4	 -7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4555	 1	 13.7	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4556	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4557	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4558	 1	 -0.1	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4559	 1	 1.0	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4560	 1	 114.6	 17.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4561	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4562	 1	 3.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4563	 1	 -3.6	 -45.6	 0.0	 0.0	 1	    1.00105	    0.00000	 63.0	 1	    1.04972	    0.95238;
	4564	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4565	 1	 3.0	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4566	 1	 20.9	 -5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4567	 1	 19.5	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4568	 1	 3.5	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4569	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02993	    0.00000	 90.0	 1	    1.08209	    0.97778;
	4570	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4571	 2	 115.7	 64.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4572	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4574	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10263	    1.05526;
	4575	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4576	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4577	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4578	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04246	    0.00000	 63.0	 1	    1.13254	    0.95238;
	4579	 2	 7.8	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4580	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4582	 1	 43.9	 5.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4583	 1	 159.5	 43.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4584	 1	 3.0	 1.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4585	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4586	 1	 9.6	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4587	 1	 23.9	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4588	 1	 5.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	4589	 1	 74.5	 13.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4590	 1	 6.0	 2.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	4591	 1	 9.5	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4592	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4593	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4594	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4595	 1	 43.8	 3.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4596	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4597	 1	 0.8	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4598	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4599	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4600	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4601	 1	 11.4	 0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4602	 1	 1.4	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4603	 1	 8.7	 -2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4604	 1	 31.3	 2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4605	 1	 14.8	 -0.5	 0.0	 0.0	 1	    1.02148	    0.00000	 90.0	 1	    1.06667	    0.97629;
	4606	 1	 1.6	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4607	 1	 61.9	 -5.0	 0.0	 60.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4608	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4609	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4610	 1	 48.1	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4611	 1	 0.0	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4612	 1	 30.6	 6.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4613	 1	 2.0	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4614	 1	 36.7	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4615	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	4616	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4617	 1	 25.5	 5.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4618	 1	 15.0	 -1.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4619	 1	 0.8	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4620	 1	 17.9	 1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4621	 1	 6.8	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4622	 1	 15.8	 -1.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4623	 1	 4.0	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4624	 1	 16.5	 -4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4625	 1	 16.7	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4626	 1	 46.9	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4627	 1	 25.3	 5.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4628	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4629	 1	 39.0	 6.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4630	 1	 8.5	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4631	 1	 18.1	 -4.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4632	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4633	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4634	 1	 23.1	 6.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4635	 1	 51.6	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4636	 1	 16.3	 6.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4637	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4638	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4639	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4640	 1	 70.3	 16.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4641	 1	 21.1	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4642	 1	 9.6	 0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4643	 1	 7.7	 -3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4644	 1	 0.0	 -1.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4645	 1	 78.6	 15.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4646	 1	 0.0	 0.0	 0.0	 30.4	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4647	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4648	 1	 41.3	 6.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4649	 1	 17.0	 -1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4650	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4651	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4652	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4653	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4654	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4655	 1	 42.1	 3.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4656	 1	 41.1	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4657	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4658	 1	 11.3	 4.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4659	 1	 -1.3	 -1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4660	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4661	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4662	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4663	 1	 21.2	 4.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4664	 1	 1.0	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4665	 1	 46.4	 -8.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4666	 1	 15.1	 -4.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4667	 1	 24.3	 -6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4668	 1	 14.8	 1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4669	 1	 58.8	 -12.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4670	 1	 31.2	 0.1	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	4671	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4672	 2	 2.4	 -1.4	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4673	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4674	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4675	 1	 64.5	 14.8	 0.0	 61.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4676	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4677	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	4678	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4679	 1	 26.7	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4680	 1	 18.0	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4681	 1	 52.9	 0.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4682	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4683	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4684	 1	 21.4	 2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4685	 1	 31.0	 -9.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4686	 1	 14.9	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4687	 1	 12.6	 -2.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4688	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4690	 1	 32.0	 4.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4691	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4692	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4693	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4694	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4695	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4696	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4697	 1	 13.1	 -2.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4698	 1	 2.0	 0.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4699	 1	 30.4	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	4700	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4701	 1	 15.3	 0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4702	 1	 15.0	 6.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4703	 1	 0.3	 3.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4704	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4706	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4707	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4708	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04658	    0.00000	 225.0	 1	    1.08444	    1.00873;
	4711	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4712	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4713	 3	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10263	    1.05526;
	4714	 1	 26.9	 -3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4715	 1	 39.5	 1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4716	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4717	 2	 -1.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4718	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4719	 1	 13.6	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4720	 2	 11.1	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4721	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4722	 1	 18.6	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4723	 1	 9.3	 -2.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4724	 1	 1.3	 -1.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4725	 1	 34.3	 5.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4726	 1	 10.7	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4727	 1	 50.1	 8.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4728	 1	 3.9	 1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4729	 1	 45.2	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4730	 1	 48.2	 -6.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4731	 1	 3.2	 -3.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4732	 1	 -0.4	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4733	 1	 0.0	 -9.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4734	 1	 29.2	 8.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4735	 1	 39.5	 3.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4736	 1	 40.9	 11.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4737	 1	 2.9	 -1.4	 0.0	 0.0	 1	    1.04777	    0.00000	 225.0	 1	    1.09110	    1.00444;
	4738	 1	 6.2	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	4739	 1	 44.8	 12.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4740	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4741	 1	 46.6	 6.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4742	 1	 25.5	 -2.9	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4743	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4744	 1	 68.4	 41.4	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4745	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4746	 1	 20.1	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4747	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4748	 1	 56.0	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4749	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4750	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4751	 1	 1.0	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4752	 1	 16.2	 18.1	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	4753	 1	 16.0	 -1.9	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	4754	 1	 30.8	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4755	 2	 0.0	 -8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4756	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4757	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4758	 1	 7.0	 -1.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4759	 1	 38.1	 6.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4760	 1	 11.3	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4761	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4762	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4763	 1	 113.6	 19.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4764	 1	 26.4	 -4.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4765	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4766	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	4767	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4768	 1	 39.0	 4.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4769	 1	 11.1	 0.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4770	 1	 15.5	 -1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4771	 1	 0.0	 0.0	 0.0	 -64.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4772	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4773	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4774	 1	 -4.4	 -5.8	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4775	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4776	 1	 22.7	 5.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4777	 2	 26.8	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4778	 1	 42.0	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4779	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4780	 1	 14.4	 -2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4781	 1	 53.0	 -2.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4782	 1	 13.8	 -6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4783	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4784	 1	 28.0	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4785	 1	 1.9	 0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4786	 1	 27.3	 -3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4787	 1	 0.1	 -0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4788	 1	 19.0	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4789	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4790	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4791	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4792	 1	 16.7	 2.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4793	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4794	 1	 -5.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4795	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4796	 1	 12.0	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4797	 1	 15.2	 -0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4798	 1	 11.1	 0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4799	 1	 26.0	 4.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4800	 1	 13.9	 3.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4801	 1	 44.9	 -2.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4802	 1	 22.3	 2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4803	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03966	    0.00000	 225.0	 1	    1.09265	    0.98667;
	4804	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4805	 1	 51.2	 -0.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4806	 1	 32.5	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4807	 1	 15.7	 4.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4808	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4809	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4810	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4811	 1	 0.3	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4812	 1	 23.9	 1.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4813	 1	 4.9	 -0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4814	 1	 19.0	 -0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4815	 1	 40.7	 19.6	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	4816	 1	 69.6	 13.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4817	 2	 -2.2	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4818	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4819	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4820	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4821	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4822	 1	 -3.0	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4823	 1	 3.0	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4824	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4825	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4826	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4827	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4828	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4829	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4830	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4831	 1	 31.8	 3.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4832	 1	 37.1	 -1.0	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	4833	 1	 19.4	 -3.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4834	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4835	 1	 62.5	 15.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4836	 1	 18.3	 3.6	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	4837	 1	 16.1	 2.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4838	 1	 -0.1	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4839	 1	 18.3	 -2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4840	 1	 26.8	 3.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4841	 1	 21.2	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4842	 1	 27.9	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4843	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4844	 1	 65.7	 4.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4845	 1	 44.4	 4.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4846	 1	 15.8	 0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4847	 1	 2.7	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4848	 1	 79.2	 6.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4849	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4850	 1	 7.7	 -5.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4851	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4852	 1	 -0.4	 3.5	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4853	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4854	 1	 4.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4855	 1	 4.5	 -0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4856	 1	 22.3	 6.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4857	 1	 20.4	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4858	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4859	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	4860	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4861	 1	 49.3	 -0.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4862	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4863	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4864	 2	 4.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4865	 1	 23.2	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4866	 1	 23.6	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4867	 1	 1.2	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4868	 1	 24.5	 3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4869	 1	 48.0	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4870	 1	 10.0	 4.1	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	4871	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4872	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4873	 1	 3.0	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4874	 1	 24.0	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4875	 1	 7.0	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4876	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4877	 1	 109.4	 24.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4878	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4879	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4880	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4881	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4882	 1	 17.9	 -3.1	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	4883	 1	 10.7	 1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4884	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4885	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03947	    0.00000	 380.0	 1	    1.10526	    0.97368;
	4886	 1	 26.9	 1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4887	 1	 47.8	 5.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4888	 1	 28.8	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4889	 1	 10.9	 -2.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4890	 1	 8.9	 11.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4891	 1	 15.4	 0.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4892	 1	 -1.8	 -0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4893	 1	 25.0	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4894	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4895	 1	 13.9	 2.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4896	 1	 60.8	 8.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4897	 1	 11.0	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4898	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4899	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4900	 1	 9.7	 -6.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4901	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4902	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03880	    0.00000	 225.0	 1	    1.09094	    0.98667;
	4903	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4904	 1	 26.3	 -5.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4905	 1	 12.6	 -1.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4906	 1	 33.8	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4907	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03931	    0.00000	 225.0	 1	    1.09195	    0.98667;
	4908	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4909	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4910	 1	 7.0	 -0.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4911	 1	 15.1	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4912	 1	 31.3	 1.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4913	 1	 65.4	 15.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4914	 1	 7.4	 5.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4915	 1	 4.1	 2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4916	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4917	 1	 -9.7	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4918	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4919	 1	 26.0	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4920	 2	 26.1	 5.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4921	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4922	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4923	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4924	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4925	 1	 47.9	 11.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4926	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4927	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4928	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4929	 1	 4.4	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4930	 1	 44.6	 3.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4931	 1	 43.2	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4932	 1	 0.8	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4933	 1	 55.1	 11.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4934	 1	 36.4	 0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4935	 1	 0.8	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4936	 1	 0.8	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4937	 1	 1.8	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4938	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4939	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4940	 1	 43.6	 8.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4941	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4942	 1	 120.7	 31.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4943	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4944	 1	 32.0	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4945	 1	 6.5	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4946	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4947	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4948	 1	 0.4	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4949	 1	 24.6	 -0.6	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4950	 1	 36.9	 7.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4951	 1	 14.5	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4952	 1	 -0.1	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4953	 1	 2.1	 -0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4954	 1	 0.0	 0.0	 0.0	 -58.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4955	 1	 0.0	 0.0	 0.0	 -58.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4956	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4957	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4958	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4959	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4960	 1	 25.0	 3.1	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4961	 1	 20.4	 4.0	 0.0	 0.0	 1	    1.02368	    0.00000	 90.0	 1	    1.06959	    0.97778;
	4962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4963	 1	 18.7	 -11.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4964	 1	 29.2	 -10.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4965	 1	 10.9	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4966	 1	 1.3	 -2.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4967	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4968	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4969	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4970	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4971	 1	 0.2	 6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4972	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	4973	 1	 11.2	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4974	 1	 19.3	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4975	 1	 29.1	 4.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4976	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4977	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4978	 1	 49.9	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4979	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4980	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4981	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4982	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4983	 2	 14.2	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4984	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4985	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4986	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4987	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4988	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4989	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4990	 1	 17.5	 6.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4991	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4992	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4993	 1	 10.8	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4994	 1	 15.4	 5.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4995	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4996	 1	 5.0	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4997	 1	 31.0	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4998	 1	 27.0	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4999	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5000	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5001	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5002	 1	 -0.6	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5003	 1	 37.5	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5004	 1	 0.4	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5005	 1	 2.7	 -4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5006	 1	 0.8	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5007	 1	 41.2	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5008	 1	 18.0	 7.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5009	 1	 13.2	 -1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5010	 1	 1.2	 -4.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5011	 1	 1.2	 4.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5012	 1	 17.5	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5013	 1	 0.7	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5014	 1	 10.3	 -3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5015	 1	 9.0	 4.1	 0.0	 0.0	 1	    1.00023	    0.00000	 63.0	 1	    1.06395	    0.93651;
	5016	 1	 24.1	 -5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5017	 1	 8.6	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5018	 1	 -19.8	 -2.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.06667	    0.98889;
	5019	 1	 33.5	 1.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5020	 1	 9.0	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5021	 1	 3.6	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5022	 1	 68.4	 9.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5023	 1	 51.3	 3.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5024	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	5025	 1	 25.1	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5026	 1	 3.9	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5027	 1	 1.0	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5028	 1	 13.1	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5029	 1	 20.2	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5030	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5031	 1	 15.2	 -3.6	 0.0	 0.0	 1	    0.96825	    0.00000	 63.0	 1	    1.04762	    0.88889;
	5032	 1	 15.0	 6.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5033	 1	 14.6	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5034	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5035	 1	 128.3	 20.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5036	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	5037	 1	 10.7	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	5038	 2	 14.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5039	 1	 11.4	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5040	 1	 22.7	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5041	 2	 31.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5042	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5043	 1	 22.7	 2.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	5044	 1	 5.0	 2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5045	 1	 1.9	 -0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5046	 1	 171.8	 62.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5047	 1	 -12.0	 -2.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.06667	    0.98889;
	5048	 1	 4.3	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5049	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5050	 1	 13.5	 -2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5051	 1	 25.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5052	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5053	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5054	 1	 8.1	 -3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5055	 1	 35.7	 13.9	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	5056	 1	 4.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5057	 1	 6.0	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5058	 1	 7.6	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5059	 1	 24.4	 4.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5060	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5061	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5062	 1	 -0.8	 -11.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5063	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	5064	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	5065	 1	 43.9	 5.6	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	5066	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5067	 1	 36.7	 6.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	5068	 1	 18.5	 6.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5069	 1	 26.5	 4.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5070	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5071	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	5072	 1	 17.3	 8.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5073	 1	 29.3	 11.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5074	 1	 0.6	 1.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5075	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5076	 1	 10.2	 10.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5077	 1	 4.2	 0.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5078	 1	 9.5	 -1.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5079	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5080	 1	 4.6	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	5081	 1	 11.6	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5082	 1	 49.8	 0.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5083	 1	 20.4	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5084	 1	 36.2	 3.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5085	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5086	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	5087	 1	 30.8	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5088	 1	 1.7	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5089	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5090	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5091	 1	 28.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5092	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5093	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5094	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5095	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5096	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5097	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5098	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5099	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5100	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5101	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5102	 1	 0.2	 2.1	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5104	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5105	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5106	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5107	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5108	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5109	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5110	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5111	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5114	 1	 6.9	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5115	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5117	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5118	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 150.0	 1	    1.10000	    0.96667;
	5120	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5122	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5123	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5124	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5125	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5127	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5129	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5131	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5132	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5133	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5134	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5136	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5137	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5138	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5139	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5140	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5141	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5142	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5143	 1	 6.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5144	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5145	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5146	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5147	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5148	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5149	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5150	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5151	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5152	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5153	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5155	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5157	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5158	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5159	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5160	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5161	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5162	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5165	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5166	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5167	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5168	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5169	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5170	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5171	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5172	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5174	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5175	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5176	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5177	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5178	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5179	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5180	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5181	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5182	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5183	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	5184	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5185	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5186	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5187	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5188	 1	 32.6	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5189	 1	 16.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5190	 1	 39.8	 0.0	 0.0	 0.0	 1	    1.02615	    0.00000	 90.0	 1	    1.07453	    0.97778;
	5191	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5192	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5193	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5194	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5195	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5196	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5197	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5198	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5199	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5200	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5201	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5202	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98908	    0.00000	 225.0	 1	    1.08927	    0.88889;
	5203	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5204	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5205	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5206	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5207	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5208	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5209	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5210	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5211	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5212	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5213	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5214	 1	 -3.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5215	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5216	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5217	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5218	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5219	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5220	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5221	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5222	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5223	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5224	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5225	 1	 -6.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5226	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5227	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5228	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5229	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5230	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5231	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5232	 1	 7.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5233	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5234	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5235	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5236	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5237	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5238	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5239	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5240	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5241	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5242	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5243	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5244	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	5245	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5246	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5247	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5248	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5249	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5250	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5251	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5252	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5253	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5254	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5255	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5256	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	5257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5258	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5259	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5260	 1	 23.8	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5261	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5262	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5263	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5265	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5266	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5267	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5268	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5269	 1	 5.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5270	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5272	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5273	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	5274	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5277	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5279	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5280	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5281	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5282	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5283	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5284	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5285	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5286	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5287	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5288	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5289	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5290	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5291	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5292	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5293	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5294	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5295	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5296	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5297	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5298	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5300	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5301	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5302	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5303	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5304	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5305	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5306	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5307	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5308	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5309	 1	 17.8	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5310	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5311	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5312	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5313	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5314	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5315	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5316	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5317	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5318	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5319	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5320	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5321	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5322	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5324	 1	 8.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5325	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5326	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5327	 1	 5.9	 1.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5328	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5329	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5330	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5331	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5332	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5333	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5334	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5335	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08446	    1.00444;
	5336	 1	 -3.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5337	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5338	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5339	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5340	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5341	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5342	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5344	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5345	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5346	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5347	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5348	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5349	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5350	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5351	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5352	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5353	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5354	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5355	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5356	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5357	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5358	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5359	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5360	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5361	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5362	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5364	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5365	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5367	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5368	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5369	 1	 1.7	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5370	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5371	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5372	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5373	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5374	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98900	    0.00000	 225.0	 1	    1.08912	    0.88889;
	5375	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5376	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5377	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5378	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5379	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5380	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5381	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5382	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5383	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5384	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5385	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5386	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5387	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5388	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5389	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5390	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5391	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5392	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5393	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5394	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5395	 1	 22.4	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5396	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5397	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5398	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5399	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5400	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5401	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5402	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5403	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5404	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5405	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5406	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5407	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5408	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5409	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5410	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5411	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5412	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5413	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5414	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5415	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5416	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5417	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5418	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5419	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5420	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5421	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5422	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5423	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5424	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5425	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5426	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5427	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5428	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5429	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5430	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5431	 1	 -31.3	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5432	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5433	 1	 10.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5434	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5435	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5436	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5437	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5438	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5439	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5440	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5441	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5442	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5443	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5445	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5446	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5447	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5448	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5450	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5451	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5452	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5453	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5454	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5455	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5456	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5457	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5458	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5460	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5461	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5462	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5463	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5464	 1	 4.5	 5.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5465	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5466	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5467	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5468	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5469	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5470	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5471	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5472	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5474	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5475	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5482	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5483	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5484	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5485	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5486	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5487	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5488	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5489	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5490	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5491	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5492	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5493	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5494	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5495	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5496	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5497	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5498	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5499	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5500	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5501	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5502	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5503	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5504	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5505	 1	 51.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5506	 1	 31.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5507	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5508	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5509	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5510	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5511	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5512	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5513	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5514	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5515	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5516	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5517	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5518	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5519	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5520	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5521	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5522	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5523	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5524	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5525	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5526	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5527	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5528	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5529	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5530	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5531	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5532	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5533	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5534	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5535	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5537	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5538	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5539	 1	 -1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5540	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5541	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5542	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5543	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5544	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5545	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 150.0	 1	    1.10000	    0.96667;
	5546	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5547	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5548	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5549	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5550	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5551	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5552	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5553	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5554	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5555	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5556	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5557	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5558	 1	 -4.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5559	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5560	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5561	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5562	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5563	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5564	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5565	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5566	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5567	 1	 7.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5568	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5569	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5570	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5571	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5572	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5574	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5575	 1	 18.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5576	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5577	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5578	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5582	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5583	 1	 -54.4	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 150.0	 1	    1.10000	    0.96667;
	5584	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5585	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5586	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5587	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5588	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5589	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5590	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5591	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5592	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5593	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5594	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5595	 1	 15.6	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5596	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5597	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5598	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5599	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5600	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5601	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5602	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5604	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99085	    0.00000	 225.0	 1	    1.09281	    0.88889;
	5605	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5606	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5607	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5608	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5610	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02968	    0.00000	 90.0	 1	    1.08158	    0.97778;
	5611	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5612	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02967	    0.00000	 90.0	 1	    1.08157	    0.97778;
	5613	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5614	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5615	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5616	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5617	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5618	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5619	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5620	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5621	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5622	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5623	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5624	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5625	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5626	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5627	 1	 11.8	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5628	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5629	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5630	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5631	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5632	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5633	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5634	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5635	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5636	 1	 -14.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5637	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5638	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5639	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5640	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5641	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5642	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5643	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5644	 1	 9.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5645	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	5646	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5647	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02000	    0.00000	 150.0	 1	    1.05333	    0.98667;
	5648	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5649	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5650	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5651	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5652	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5653	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5654	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5655	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5656	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5657	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5658	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5659	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5660	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5661	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5662	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5663	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5664	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5665	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5666	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5667	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5668	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5669	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5670	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5671	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5672	 1	 3.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5673	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5674	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5675	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5676	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5677	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5678	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5679	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5680	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5681	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5682	 1	 44.7	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5683	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5684	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5685	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5686	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5687	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5688	 1	 6.8	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5690	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5691	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5692	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5693	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5694	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	5695	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5696	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5697	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5698	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5699	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5700	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5701	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5702	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5703	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5704	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5706	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5707	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5708	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	5709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5711	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5712	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5713	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5714	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5715	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5716	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5717	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5718	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5719	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5720	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5721	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5722	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5723	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	5724	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5725	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5726	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5727	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5728	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5729	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5730	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5731	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5732	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5733	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5734	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5735	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5736	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5737	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5738	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5739	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5740	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5741	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5742	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5743	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5744	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5745	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5746	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5747	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5748	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5749	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5750	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5751	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5752	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5753	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5754	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5755	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5756	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5757	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5758	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5759	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5760	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5761	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5762	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5763	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5764	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5765	 1	 32.6	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5766	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5767	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5768	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5769	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5770	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5771	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5772	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5773	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5774	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5775	 1	 39.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5776	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5777	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5778	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5779	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5780	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5781	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5782	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5783	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5784	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5785	 1	 3.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5786	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5787	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5788	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5789	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5790	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5791	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5792	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5793	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5794	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5795	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5796	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5797	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5798	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5799	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5800	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5801	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5802	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5803	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5804	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5805	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5806	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5807	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5808	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5809	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5810	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5811	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5812	 1	 -10.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5813	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5814	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5815	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5816	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5817	 1	 4.6	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5818	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5819	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5820	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5821	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5822	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5823	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07374	    0.00000	 380.0	 1	    1.10263	    1.04485;
	5824	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5825	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5826	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5827	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5828	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5829	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5830	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5831	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5832	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5833	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5834	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5835	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5836	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5837	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5838	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5839	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5840	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5841	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5842	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5843	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5844	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5845	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5846	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5847	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5848	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5849	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5850	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5851	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5852	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5853	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5854	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5855	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5856	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5857	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5858	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5859	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5860	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5861	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5862	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5863	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5864	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5865	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5866	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5867	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5868	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5869	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5870	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5871	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5872	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5873	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5874	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5875	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5876	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5877	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5878	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5879	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5880	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5881	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5882	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5883	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5884	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5885	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5886	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5887	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5888	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5889	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5890	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5891	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5892	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5893	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5894	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5895	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5896	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	5897	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5898	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5899	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5900	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5901	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5902	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5903	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5904	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5905	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5906	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5907	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5908	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5909	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5910	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5911	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5912	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5913	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5914	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5915	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5916	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5917	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5918	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5919	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5920	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5921	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5922	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5923	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5924	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5925	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5926	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5927	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5928	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5929	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5930	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5931	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5932	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5933	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	5934	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5935	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5936	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5937	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5938	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5939	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5940	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5941	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5942	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5943	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5944	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5945	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5946	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5947	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5948	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5949	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5950	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5951	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5952	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5953	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5954	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5955	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5956	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5957	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5958	 1	 116.9	 -4.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5959	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5960	 2	 -496.6	 205.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5961	 1	 81.1	 -14.3	 0.0	 0.0	 1	    0.97500	    0.00000	 90.0	 1	    1.15000	    0.80000;
	5962	 1	 56.2	 12.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5963	 2	 18.7	 213.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5964	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5965	 2	 105.6	 50.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5966	 2	 -20.0	 -15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5967	 1	 -82.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5968	 2	 807.8	 167.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5969	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5970	 1	 101.5	 11.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5971	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5972	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5973	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5974	 1	 263.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5975	 1	 9.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5976	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5977	 1	 109.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5978	 1	 568.2	 -11.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5979	 1	 222.6	 8.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5980	 1	 -1.6	 0.3	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	5981	 1	 1.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5982	 1	 107.7	 -5.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5983	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5984	 2	 256.2	 100.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5985	 1	 462.7	 151.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5986	 1	 -362.3	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5987	 1	 2.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5988	 1	 -8.7	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5989	 2	 -201.5	 -60.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5990	 1	 91.4	 14.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5991	 1	 3064.9	 -295.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5992	 1	 98.0	 26.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5993	 1	 563.4	 88.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5994	 1	 406.9	 -23.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5995	 1	 106.5	 -18.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5996	 1	 144.0	 69.1	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5997	 1	 367.3	 -10.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5998	 2	 -561.9	 255.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5999	 1	 88.2	 -76.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6000	 1	 66.8	 11.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6001	 1	 76.9	 16.7	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6002	 1	 266.7	 22.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6003	 1	 0.9	 236.1	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6004	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6005	 1	 40.3	 12.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6006	 1	 -4.5	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6007	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6008	 1	 -207.6	 -39.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6009	 1	 0.9	 10.9	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6010	 2	 8.5	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6011	 2	 147.5	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6012	 1	 94.8	 5.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6013	 1	 151.7	 16.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6014	 1	 84.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6015	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6016	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 63.0	 1	    1.15000	    0.80000;
	6017	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6018	 1	 183.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6019	 1	 214.5	 25.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6020	 1	 67.2	 -1.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6021	 1	 61.3	 -4.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6022	 2	 77.0	 -14.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6023	 1	 81.1	 73.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6024	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6025	 1	 -117.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6026	 1	 132.7	 21.5	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6027	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6028	 2	 349.9	 11.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6029	 1	 512.0	 27.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6030	 2	 -33.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6031	 1	 369.9	 46.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6032	 1	 179.4	 -16.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6033	 1	 144.0	 -96.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6034	 1	 71.0	 -25.4	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6035	 1	 118.9	 10.5	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6036	 1	 95.4	 -34.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6037	 1	 617.6	 217.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6038	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6039	 1	 311.7	 96.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6040	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6041	 2	 13.4	 -1.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6042	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6043	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6044	 1	 302.8	 43.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6045	 1	 28.0	 -15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6046	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6047	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6048	 1	 -65.5	 89.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6049	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6050	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6051	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6052	 1	 150.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6053	 1	 77.9	 -0.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6054	 1	 150.7	 25.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6055	 1	 155.7	 -6.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6056	 2	 164.0	 212.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6057	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6058	 1	 857.5	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6059	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6060	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6061	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6062	 1	 431.2	 12.4	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6063	 1	 197.7	 -91.2	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6064	 1	 1.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6065	 1	 1.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6066	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6067	 2	 579.0	 186.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6068	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6069	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6070	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6071	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6072	 1	 -966.8	 -152.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6073	 1	 26.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6074	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6075	 1	 277.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6076	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6077	 1	 141.8	 30.1	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6078	 1	 19.7	 44.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6079	 1	 120.9	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6080	 1	 329.9	 33.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6081	 1	 -225.6	 -4.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6082	 1	 28.5	 123.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6083	 1	 153.4	 -115.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6084	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6085	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6086	 1	 238.8	 289.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6087	 1	 672.9	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6088	 1	 182.0	 -19.5	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6089	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6090	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6091	 2	 178.0	 64.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6092	 1	 -536.0	 197.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6093	 2	 -147.6	 27.4	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6094	 2	 65.0	 -18.9	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6095	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6096	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6097	 1	 80.8	 -0.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6098	 1	 -0.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6099	 1	 413.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6100	 1	 -16.7	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6101	 1	 -384.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6102	 1	 -5.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6103	 1	 -135.7	 -18.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6104	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6105	 2	 244.2	 -6.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6106	 1	 -140.9	 47.8	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6107	 2	 -166.0	 -8.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6108	 1	 41.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6109	 1	 203.4	 12.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6110	 1	 232.1	 19.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6111	 1	 358.5	 71.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6112	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6113	 2	 195.4	 155.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6114	 2	 83.4	 86.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6115	 1	 -801.2	 305.9	 0.0	 -150.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6116	 2	 252.9	 19.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6117	 1	 -190.2	 16.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6118	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6119	 1	 252.5	 39.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6120	 1	 -279.8	 253.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6121	 1	 497.5	 98.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6122	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6123	 1	 11.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6124	 1	 247.1	 3.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6125	 1	 421.6	 174.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6126	 1	 206.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6127	 2	 103.4	 28.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6128	 1	 41.1	 -2.3	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6129	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6130	 1	 132.0	 1.7	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6131	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6132	 1	 1.9	 -1.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6133	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6134	 2	 433.0	 -17.1	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6135	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6136	 1	 -69.9	 1.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6137	 1	 8.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6138	 1	 301.3	 67.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6139	 1	 383.5	 -15.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6140	 2	 200.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6141	 1	 221.9	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6142	 1	 -208.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6143	 1	 -376.7	 101.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6144	 1	 138.7	 12.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6145	 1	 65.9	 2.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6146	 1	 297.5	 204.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6147	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6148	 1	 23.0	 -1.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6149	 1	 28.3	 12.4	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6150	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6151	 1	 -78.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6152	 1	 -1243.2	 -10.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6153	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6154	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6155	 1	 284.0	 -42.9	 0.0	 -150.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6156	 1	 77.5	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6157	 1	 -247.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6158	 2	 74.0	 7.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6159	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6160	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6161	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6162	 1	 -1430.2	 124.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6163	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6164	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6165	 1	 27.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6166	 2	 84.0	 -2.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6167	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6168	 1	 107.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6169	 1	 49.3	 -4.5	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6170	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6171	 1	 178.3	 -41.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6172	 1	 210.8	 28.5	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6173	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6174	 2	 321.0	 22.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6175	 2	 249.0	 51.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6176	 1	 778.2	 -39.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6177	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6178	 1	 8.9	 49.8	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6179	 1	 -72.7	 31.5	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6180	 2	 190.0	 21.4	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6181	 1	 -448.2	 12.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6182	 1	 219.3	 15.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6183	 1	 1076.8	 259.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6184	 1	 269.1	 -24.8	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6185	 2	 339.8	 -48.1	 0.0	 -150.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6186	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6187	 1	 -96.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6188	 1	 98.5	 9.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6189	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6190	 2	 133.0	 55.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6191	 1	 40.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6192	 1	 209.3	 17.1	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6193	 1	 213.4	 27.9	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6194	 2	 15.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6195	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6196	 2	 38.3	 7.8	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6197	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6198	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6199	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6200	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6201	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6202	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6203	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6204	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6205	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99566	    0.00000	 380.0	 1	    1.19131	    0.80000;
	6206	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6207	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6208	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6209	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6210	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6211	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6212	 1	 39.0	 107.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6213	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6214	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6215	 1	 101.3	 37.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6216	 1	 325.5	 -170.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6217	 2	 18.9	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6218	 1	 232.4	 63.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6219	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6220	 2	 425.4	 2.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6221	 1	 101.7	 41.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6222	 2	 4.0	 4.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6223	 2	 62.9	 -39.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6224	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6225	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6226	 1	 83.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6227	 2	 93.0	 1.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6228	 1	 172.6	 -7.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6229	 1	 204.6	 5.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6230	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6231	 1	 8.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6232	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6233	 1	 100.9	 26.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6234	 1	 9.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6235	 1	 -61.7	 6.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6236	 1	 595.2	 -5.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6237	 1	 -188.1	 75.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6238	 1	 147.7	 20.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6239	 1	 -12.5	 14.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6240	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6241	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6242	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6243	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6244	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6245	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6246	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6247	 1	 8.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6248	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6249	 1	 210.2	 53.8	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6250	 1	 173.3	 23.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6251	 1	 213.0	 138.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6252	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6253	 1	 256.2	 51.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6254	 1	 376.9	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6255	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6256	 2	 13.3	 8.7	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6257	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6258	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6259	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 11.0	 1	    1.15000	    0.80000;
	6260	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 11.0	 1	    1.15000	    0.80000;
	6261	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6262	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6263	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6264	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6265	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6266	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6267	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6268	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6269	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6270	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6271	 2	 37.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6272	 2	 37.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6273	 2	 37.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6274	 2	 37.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6276	 2	 16.0	 11.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6277	 2	 14.0	 11.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6278	 2	 14.0	 11.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6279	 2	 10.0	 7.5	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	6280	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6281	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6282	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6283	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6284	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6285	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6286	 2	 13.0	 7.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6287	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6288	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6289	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6290	 2	 31.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6291	 2	 31.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6292	 2	 38.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6293	 2	 38.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6294	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6295	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6296	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6297	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6298	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6299	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6300	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6301	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6302	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6303	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6304	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6305	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6306	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6307	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6308	 2	 1.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6309	 2	 43.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6311	 2	 43.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6312	 2	 43.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6313	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6314	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6315	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6316	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6317	 2	 3.5	 2.2	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6318	 2	 3.5	 2.2	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6319	 2	 4.2	 2.3	 0.0	 0.0	 1	    0.97500	    0.00000	 14.0	 1	    1.15000	    0.80000;
	6320	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6321	 2	 30.0	 14.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6322	 2	 30.0	 14.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6324	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6325	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6326	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6327	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6328	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6329	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6330	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6331	 2	 40.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6332	 2	 40.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6333	 2	 40.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6334	 2	 40.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6335	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6336	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6337	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 21.0	 1	    1.15000	    0.80000;
	6338	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6339	 2	 8.8	 6.6	 0.0	 0.0	 1	    0.97500	    0.00000	 19.0	 1	    1.15000	    0.80000;
	6340	 2	 40.0	 17.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6341	 2	 40.0	 17.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6342	 2	 40.0	 17.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6343	 2	 40.0	 17.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6344	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 11.0	 1	    1.15000	    0.80000;
	6345	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6346	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6347	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6348	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6349	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6350	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6351	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6352	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6353	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6354	 2	 7.3	 5.5	 0.0	 0.0	 1	    0.97500	    0.00000	 21.0	 1	    1.15000	    0.80000;
	6355	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6356	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6357	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6358	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6359	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6360	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6361	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6362	 2	 15.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6363	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 18.0	 1	    1.15000	    0.80000;
	6364	 2	 10.0	 6.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6365	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6366	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6368	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6369	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6370	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6371	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6372	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6373	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6374	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6375	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6376	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6377	 2	 15.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6378	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6379	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6380	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6381	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6382	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6383	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6384	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6385	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6386	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6387	 2	 14.0	 8.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6388	 2	 14.0	 8.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6389	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6390	 2	 5.9	 3.6	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6391	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6392	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6393	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6394	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6395	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6396	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6397	 2	 30.0	 12.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6398	 2	 30.0	 12.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6399	 2	 12.0	 3.0	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	6400	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	6401	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6402	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6403	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6404	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6405	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6406	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6407	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6408	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6409	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6410	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6411	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6412	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6413	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6414	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6415	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6416	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6417	 2	 15.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6418	 2	 15.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6419	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6420	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6421	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 11.0	 1	    1.15000	    0.80000;
	6422	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6423	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6424	 2	 10.8	 8.6	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6425	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 3.0	 1	    1.15000	    0.80000;
	6426	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 3.0	 1	    1.15000	    0.80000;
	6427	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 3.0	 1	    1.15000	    0.80000;
	6428	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6429	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6430	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6431	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6432	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6433	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6434	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6435	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6436	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6437	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6438	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6439	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6440	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6441	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6442	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6443	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6444	 2	 15.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6445	 2	 7.0	 4.0	 0.0	 0.0	 1	    0.97500	    0.00000	 19.0	 1	    1.15000	    0.80000;
	6446	 2	 7.0	 4.0	 0.0	 0.0	 1	    0.97500	    0.00000	 19.0	 1	    1.15000	    0.80000;
	6447	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6448	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6449	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6450	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6451	 2	 41.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6452	 2	 41.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6453	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6454	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6455	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6456	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6457	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6458	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6459	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6460	 2	 35.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6461	 2	 35.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6462	 2	 35.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6463	 2	 35.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6464	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6465	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6466	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6467	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6468	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6469	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6470	 2	 18.0	 10.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6471	 2	 18.0	 10.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6472	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6473	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6474	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin
mpc.gen = [
	4	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 12.0	 0.0; % COW
	4	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 10.0	 0.0; % NG
	5	 4.55	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 9.1	 0.0; % NG
	11	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 28.0	 0.0; % PEL
	11	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 18.0	 0.0; % PEL
	17	 4.1	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 8.2	 0.0; % COW
	19	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 1.2	 0.0; % PEL
	22	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % PEL
	24	 0.0	 0.0	 0.0	 0.0	 1.033333	 100.0	 0	 16.1	 0.0; % NG
	24	 17.75	 0.0	 0.0	 0.0	 1.033333	 100.0	 1	 35.5	 0.0; % PEL
	25	 18.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 1	 36.0	 0.0; % PEL
	25	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 27.2	 0.0; % NG
	40	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 8.0	 0.0; % COW
	47	 8.0	 0.0	 9.5	 -9.5	 0.999999	 100.0	 1	 16.0	 0.0; % NG
	47	 0.0	 -1.81	 9.5	 -9.5	 0.999999	 100.0	 0	 16.0	 0.0; % NG
	48	 11.5	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 23.0	 0.0; % NG
	48	 12.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 24.0	 0.0; % COW
	57	 6.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 13.0	 0.0; % NG
	64	 0.0	 0.0	 0.0	 0.0	 0.9888895	 100.0	 0	 24.0	 0.0; % PEL
	64	 13.8	 0.0	 0.0	 0.0	 0.9888895	 100.0	 1	 27.6	 0.0; % NG
	69	 15.02	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 30.04	 0.0; % NG
	70	 11.5	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 23.0	 0.0; % PEL
	85	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 6.68	 0.0; % NG
	86	 4.6	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 9.2	 0.0; % NG
	102	 23.0	 6.0	 21.0	 -9.0	 1.0158755	 100.0	 1	 46.0	 0.0; % NG
	122	 6.0	 1.5	 5.0	 -2.0	 1.0158755	 100.0	 1	 12.0	 0.0; % COW
	124	 4.5	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 9.0	 0.0; % PEL
	125	 13.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 26.0	 0.0; % NG
	125	 6.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 12.0	 0.0; % PEL
	132	 8.5	 0.0	 3.0	 -3.0	 1.000001	 100.0	 1	 17.0	 0.0; % NG
	132	 0.0	 1.0	 1.0	 -1.0	 1.000001	 100.0	 0	 4.0	 0.0; % NG
	132	 0.0	 1.99	 3.0	 -3.0	 1.000001	 100.0	 0	 14.0	 0.0; % COW
	132	 0.0	 1.99	 3.0	 -3.0	 1.000001	 100.0	 0	 14.0	 0.0; % COW
	137	 0.0	 -0.57	 0.8	 -0.8	 1.015872	 100.0	 0	 18.0	 0.0; % NG
	137	 9.0	 0.0	 0.8	 -0.8	 1.015872	 100.0	 1	 18.0	 0.0; % PEL
	155	 0.0	 -1.75	 1.76	 -1.76	 1.0000025	 100.0	 0	 5.3	 0.0; % NG
	158	 8.95	 -1.5	 10.0	 -13.0	 0.9444445	 100.0	 1	 17.9	 0.0; % NG
	158	 0.0	 -2.57	 10.0	 -13.0	 0.9444445	 100.0	 0	 17.9	 0.0; % PEL
	177	 0.0	 -1.56	 10.0	 -4.0	 1.0	 100.0	 0	 30.0	 0.0; % NG
	190	 0.0	 -1.41	 8.0	 -8.0	 1.0000025	 100.0	 0	 11.0	 0.0; % PEL
	190	 0.0	 -1.41	 2.0	 -2.0	 1.0000025	 100.0	 0	 11.0	 0.0; % NG
	192	 0.0	 -2.63	 14.0	 -14.0	 0.9444445	 100.0	 0	 30.0	 0.0; % NG
	194	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 23.5	 0.0; % PEL
	196	 7.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 15.0	 0.0; % NG
	196	 7.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 15.0	 0.0; % PEL
	219	 5.97	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 11.94	 0.0; % PEL
	226	 0.0	 0.0	 2.0	 0.0	 1.0	 100.0	 0	 6.0	 0.0; % PEL
	229	 3.75	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 7.5	 0.0; % NG
	238	 16.75	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 33.5	 0.0; % NG
	238	 12.15	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 24.3	 0.0; % PEL
	240	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.0	 0.0; % NG
	240	 18.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 36.0	 0.0; % PEL
	248	 0.0	 0.0	 2.0	 0.0	 0.999999	 100.0	 0	 1.0	 0.0; % PEL
	248	 0.0	 -2.77	 10.0	 -10.0	 0.999999	 100.0	 0	 31.0	 0.0; % NG
	248	 0.0	 -2.77	 10.0	 -10.0	 0.999999	 100.0	 0	 31.0	 0.0; % NG
	248	 0.0	 -2.77	 10.0	 -10.0	 0.999999	 100.0	 0	 31.0	 0.0; % NG
	258	 0.0	 -1.94	 10.0	 -10.0	 1.0000025	 100.0	 0	 26.0	 0.0; % NG
	258	 0.0	 0.23	 10.0	 -10.0	 1.0000025	 100.0	 0	 26.0	 0.0; % NG
	260	 15.0	 0.95	 1.0	 0.9	 1.000001	 100.0	 1	 30.0	 0.0; % COW
	263	 4.0	 0.0	 4.0	 -4.0	 1.0000025	 100.0	 1	 8.0	 0.0; % COW
	271	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.6	 0.0; % PEL
	284	 0.0	 -2.78	 6.1	 -6.2	 0.999999	 100.0	 0	 11.6	 0.0; % NG
	297	 0.0	 0.0	 0.0	 0.0	 0.9888895	 100.0	 0	 25.3	 0.0; % NG
	298	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	307	 7.5	 0.0	 9.0	 -9.0	 0.999999	 100.0	 1	 15.0	 0.0; % NG
	314	 12.9	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 25.8	 0.0; % NG
	314	 24.8	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 49.6	 0.0; % NG
	319	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 0.0	 -7.0; % SYNC
	319	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 0.0	 -7.0; % SYNC
	321	 5.4	 0.0	 0.1	 -0.1	 1.0000025	 100.0	 1	 10.8	 0.0; % NG
	327	 0.0	 -0.57	 4.0	 -4.0	 0.999999	 100.0	 0	 11.0	 0.0; % NG
	334	 0.0	 0.13	 13.0	 -9.0	 1.015872	 100.0	 0	 25.0	 0.0; % PEL
	335	 12.5	 2.0	 13.0	 -9.0	 1.0233335	 100.0	 1	 25.0	 0.0; % COW
	338	 6.5	 -0.5	 5.0	 -6.0	 1.0000025	 100.0	 1	 13.0	 0.0; % NG
	340	 0.0	 -1.82	 10.0	 -10.0	 1.0000025	 100.0	 0	 21.0	 0.0; % NG
	340	 0.0	 -0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 2.0	 0.0; % PEL
	347	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 2.3	 0.0; % PEL
	347	 9.75	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 19.5	 0.0; % PEL
	350	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 22.0	 0.0; % PEL
	358	 0.0	 1.84	 30.0	 -30.0	 1.0000025	 100.0	 0	 30.0	 0.0; % NG
	359	 6.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 12.0	 0.0; % COW
	359	 6.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 12.0	 0.0; % NG
	366	 65.0	 16.5	 59.0	 -26.0	 1.046665	 100.0	 1	 130.0	 0.0; % COW
	393	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 2.7	 0.0; % PEL
	412	 5.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 10.0	 0.0; % NG
	412	 5.75	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 11.5	 0.0; % PEL
	432	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	441	 0.0	 1.33	 10.96	 -11.99	 1.0000025	 100.0	 0	 34.25	 0.0; % NG
	448	 0.0	 0.71	 8.0	 -9.0	 1.015872	 100.0	 0	 25.0	 0.0; % COW
	463	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 2.4	 0.0; % PEL
	463	 8.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 16.0	 0.0; % NG
	465	 14.0	 1.5	 6.0	 -3.0	 0.985555	 100.0	 1	 27.0	 1.0; % NG
	465	 14.0	 1.5	 6.0	 -3.0	 0.985555	 100.0	 1	 27.0	 1.0; % NG
	467	 24.5	 4.5	 19.0	 -10.0	 1.0079355	 100.0	 1	 48.0	 1.0; % NG
	471	 0.0	 -2.86	 6.0	 -6.0	 0.999999	 100.0	 0	 10.0	 0.0; % PEL
	471	 0.0	 -5.4	 5.4	 -5.4	 0.999999	 100.0	 0	 9.0	 0.0; % NG
	480	 0.0	 -2.66	 17.0	 -16.0	 0.999999	 100.0	 0	 27.0	 0.0; % PEL
	480	 0.0	 -2.66	 17.0	 -16.0	 0.999999	 100.0	 0	 27.0	 0.0; % PEL
	480	 0.0	 -2.66	 17.0	 -16.0	 0.999999	 100.0	 0	 27.0	 0.0; % NG
	492	 0.0	 -0.74	 8.0	 -17.0	 1.033334	 100.0	 0	 23.4	 0.0; % PEL
	509	 0.0	 0.34	 2.0	 -2.0	 0.999999	 100.0	 0	 4.0	 0.0; % PEL
	518	 0.0	 0.0	 0.0	 0.0	 1.015874	 100.0	 0	 10.0	 0.0; % PEL
	519	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % COW
	529	 0.0	 -1.62	 4.8	 -4.8	 0.999999	 100.0	 0	 8.0	 0.0; % PEL
	529	 0.0	 -1.62	 4.8	 -4.8	 0.999999	 100.0	 0	 8.0	 0.0; % COW
	529	 4.0	 0.0	 4.8	 -4.8	 0.999999	 100.0	 1	 8.0	 0.0; % COW
	535	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % NG
	535	 12.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 24.0	 0.0; % PEL
	544	 4.5	 1.95	 2.0	 1.9	 1.0000025	 100.0	 1	 9.0	 0.0; % COW
	547	 0.0	 0.0	 2.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	569	 6.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 12.0	 0.0; % PEL
	569	 15.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 30.0	 0.0; % NG
	569	 5.75	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 11.5	 0.0; % NG
	582	 8.0	 1.5	 7.0	 -4.0	 1.0000005	 100.0	 1	 16.0	 0.0; % NG
	584	 4.5	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 9.0	 0.0; % NG
	585	 4.75	 0.0	 5.7	 -5.7	 0.999999	 100.0	 1	 9.5	 0.0; % NG
	588	 0.0	 0.1	 0.1	 -0.1	 1.000001	 100.0	 0	 1.0	 0.0; % PEL
	592	 0.0	 0.82	 10.0	 -10.0	 1.0000025	 100.0	 0	 21.0	 0.0; % NG
	599	 0.0	 0.03	 1.0	 -1.0	 1.015872	 100.0	 0	 6.1	 0.0; % NG
	609	 22.5	 0.0	 45.0	 -45.0	 0.975	 100.0	 1	 45.0	 0.0; % PEL
	609	 0.0	 -1.04	 45.0	 -45.0	 0.975	 100.0	 0	 45.0	 0.0; % NG
	611	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % NG
	611	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % COW
	611	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % NG
	612	 17.5	 0.0	 0.0	 0.0	 1.0000005	 100.0	 1	 35.0	 0.0; % NG
	612	 0.0	 0.0	 0.0	 0.0	 1.0000005	 100.0	 0	 11.5	 0.0; % NG
	623	 0.0	 0.0	 8.3	 -8.3	 1.0111115	 100.0	 1	 8.3	 -8.3; % COW
	632	 0.0	 2.76	 4.0	 -4.0	 0.999999	 100.0	 0	 7.3	 0.0; % NG
	635	 0.0	 0.91	 7.0	 0.0	 1.015872	 100.0	 0	 15.0	 0.0; % NG
	635	 7.5	 3.5	 7.0	 0.0	 1.015872	 100.0	 1	 15.0	 0.0; % PEL
	640	 119.5	 -11.4	 80.0	 -102.8	 1.078945	 100.0	 1	 239.0	 0.0; % NG
	651	 0.0	 1.38	 7.0	 0.0	 1.0000025	 100.0	 0	 7.0	 0.0; % NG
	669	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % NG
	669	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % NG
	670	 3.75	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 7.5	 0.0; % NG
	670	 12.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 24.0	 0.0; % NG
	678	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 6.6	 0.0; % PEL
	679	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % NG
	683	 4.5	 0.5	 6.0	 -5.0	 0.9444445	 100.0	 1	 9.0	 0.0; % NG
	683	 4.5	 0.5	 6.0	 -5.0	 0.9444445	 100.0	 1	 9.0	 0.0; % NG
	683	 0.0	 -2.58	 8.0	 -5.0	 0.9444445	 100.0	 0	 11.0	 0.0; % COW
	683	 5.5	 1.5	 8.0	 -5.0	 0.9444445	 100.0	 1	 11.0	 0.0; % NG
	694	 16.175	 0.0	 0.0	 0.0	 1.022222	 100.0	 1	 32.35	 0.0; % NG
	694	 6.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 1	 12.0	 0.0; % PEL
	694	 10.5	 0.0	 0.0	 0.0	 1.022222	 100.0	 1	 21.0	 0.0; % NG
	698	 18.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 37.0	 0.0; % PEL
	698	 18.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 37.0	 0.0; % NG
	697	 18.5	 0.0	 15.0	 -15.0	 0.975	 100.0	 1	 37.0	 0.0; % NG
	697	 18.5	 0.0	 15.0	 -15.0	 0.975	 100.0	 1	 37.0	 0.0; % PEL
	696	 18.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 37.0	 0.0; % PEL
	696	 18.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 37.0	 0.0; % NG
	704	 2.0	 0.0	 2.0	 -2.0	 0.9444445	 100.0	 1	 4.0	 0.0; % PEL
	704	 2.0	 0.0	 2.5	 -2.5	 0.9444445	 100.0	 1	 4.0	 0.0; % NG
	704	 2.85	 0.0	 3.0	 -3.0	 0.9444445	 100.0	 1	 5.7	 0.0; % NG
	704	 0.0	 -2.66	 6.0	 -5.0	 0.9444445	 100.0	 0	 8.5	 0.0; % COW
	731	 9.75	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 19.5	 0.0; % NG
	732	 19.5	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 39.0	 0.0; % NG
	733	 5.75	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 11.5	 0.0; % NG
	733	 16.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 32.0	 0.0; % PEL
	735	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 12.0	 0.0; % NG
	735	 16.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 32.0	 0.0; % NG
	736	 2.5	 0.0	 0.1	 -0.1	 1.0000025	 100.0	 1	 5.0	 0.0; % NG
	743	 3.35	 0.01	 3.72	 -3.7	 0.999999	 100.0	 1	 6.7	 0.0; % NG
	743	 2.8	 0.0	 3.0	 -3.0	 0.999999	 100.0	 1	 5.6	 0.0; % NG
	744	 13.3	 -2.38	 15.0	 -19.76	 0.999999	 100.0	 1	 26.6	 0.0; % NG
	745	 4.0	 0.0	 2.0	 -2.0	 1.022224	 100.0	 1	 7.0	 1.0; % NG
	750	 0.0	 -2.78	 3.0	 -3.0	 0.999999	 100.0	 0	 5.0	 -5.0; % NG
	757	 0.0	 1.81	 8.0	 -8.0	 0.9888895	 100.0	 0	 23.5	 0.0; % PEL
	759	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 6.0	 0.0; % PEL
	760	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 6.0	 0.0; % PEL
	759	 18.75	 2.0	 10.0	 -6.0	 0.999999	 100.0	 1	 37.5	 0.0; % NG
	760	 18.75	 2.0	 10.0	 -6.0	 0.999999	 100.0	 1	 37.5	 0.0; % NG
	761	 0.0	 0.06	 0.06	 -0.06	 0.825	 100.0	 0	 0.6	 0.0; % PEL
	761	 13.05	 0.0	 2.61	 -2.61	 0.825	 100.0	 1	 26.1	 0.0; % NG
	761	 0.0	 0.16	 0.16	 -0.16	 0.825	 100.0	 0	 1.6	 0.0; % PEL
	761	 0.0	 0.11	 0.11	 -0.11	 0.825	 100.0	 0	 1.1	 0.0; % PEL
	765	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 37.5	 0.0; % PEL
	765	 17.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 34.0	 0.0; % NG
	785	 0.0	 -0.29	 26.0	 -26.0	 0.975	 100.0	 0	 8.0	 0.0; % NG
	785	 0.0	 -0.29	 26.0	 -26.0	 0.975	 100.0	 0	 15.0	 0.0; % COW
	786	 0.0	 -0.33	 26.0	 -26.0	 0.975	 100.0	 0	 19.0	 0.0; % PEL
	800	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % NG
	800	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % NG
	801	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % NG
	801	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % NG
	802	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % PEL
	802	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % NG
	806	 20.4	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 40.8	 0.0; % NG
	814	 16.5	 -1.5	 6.0	 -9.0	 1.015872	 100.0	 1	 32.0	 1.0; % PEL
	814	 0.0	 0.0	 6.0	 -9.0	 1.015872	 100.0	 0	 32.0	 1.0; % PEL
	815	 16.5	 -1.5	 6.0	 -9.0	 1.015872	 100.0	 1	 32.0	 1.0; % NG
	815	 16.5	 -1.5	 6.0	 -9.0	 1.015872	 100.0	 1	 32.0	 1.0; % NG
	815	 16.5	 -1.5	 6.0	 -9.0	 1.015872	 100.0	 1	 32.0	 1.0; % NG
	815	 16.5	 -1.5	 6.0	 -9.0	 1.015872	 100.0	 1	 32.0	 1.0; % COW
	825	 0.0	 1.35	 3.0	 -3.0	 1.0000025	 100.0	 0	 13.0	 0.0; % NG
	825	 3.5	 0.0	 3.0	 -3.0	 1.0000025	 100.0	 1	 7.0	 0.0; % NG
	828	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 2.4	 0.0; % PEL
	829	 13.5	 0.0	 10.0	 -10.0	 1.0000025	 100.0	 1	 27.0	 0.0; % NG
	830	 0.0	 -2.71	 10.0	 -10.0	 0.9444445	 100.0	 0	 20.0	 0.0; % COW
	832	 0.0	 1.34	 3.14	 -3.43	 1.0000025	 100.0	 0	 9.8	 0.0; % NG
	832	 0.0	 1.0	 1.0	 0.0	 1.0000025	 100.0	 0	 5.0	 0.0; % NG
	835	 7.5	 2.95	 3.0	 2.9	 1.0000025	 100.0	 1	 15.0	 0.0; % COW
	837	 0.0	 -1.31	 7.5	 -7.5	 1.0000025	 100.0	 0	 19.0	 0.0; % PEL
	837	 0.0	 -1.31	 7.5	 -7.5	 1.0000025	 100.0	 0	 15.0	 0.0; % NG
	856	 0.0	 0.0	 1.0	 0.9	 1.0000025	 100.0	 0	 12.0	 0.0; % PEL
	856	 0.0	 0.0	 1.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	863	 0.0	 -5.15	 7.0	 -7.0	 1.0000025	 100.0	 0	 14.0	 0.0; % NG
	864	 7.0	 0.0	 7.0	 -7.0	 1.0000025	 100.0	 1	 14.0	 0.0; % NG
	885	 0.0	 -0.79	 6.0	 -6.0	 1.0000025	 100.0	 0	 10.0	 0.0; % PEL
	885	 0.0	 -0.79	 3.0	 -3.0	 1.0000025	 100.0	 0	 12.0	 0.0; % PEL
	889	 0.0	 0.71	 5.0	 -5.0	 0.975	 100.0	 0	 13.0	 0.0; % COW
	889	 0.0	 0.71	 5.0	 -5.0	 0.975	 100.0	 0	 13.0	 0.0; % NG
	889	 0.0	 0.71	 5.0	 -5.0	 0.975	 100.0	 0	 13.0	 0.0; % COW
	889	 0.0	 0.71	 5.0	 -5.0	 0.975	 100.0	 0	 13.0	 0.0; % NG
	907	 7.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 14.0	 0.0; % NG
	944	 4.05	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 8.1	 0.0; % NG
	948	 0.0	 0.1	 0.1	 -0.1	 1.000001	 100.0	 0	 2.0	 0.0; % PEL
	969	 25.0	 9.0	 27.0	 -9.0	 0.975	 100.0	 1	 50.0	 0.0; % NG
	971	 9.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 18.0	 0.0; % PEL
	977	 4.0	 0.0	 5.0	 -5.0	 0.999999	 100.0	 1	 8.0	 0.0; % NG
	977	 0.0	 -0.64	 5.0	 -5.0	 0.999999	 100.0	 0	 8.0	 0.0; % NG
	987	 0.0	 4.8	 22.0	 -10.0	 1.027779	 100.0	 0	 49.0	 0.0; % NG
	987	 0.0	 4.8	 7.0	 -3.0	 1.027779	 100.0	 0	 15.0	 0.0; % NG
	987	 0.0	 4.8	 22.0	 -10.0	 1.027779	 100.0	 0	 49.0	 0.0; % NG
	989	 0.0	 0.0	 0.0	 0.0	 0.984126	 100.0	 0	 22.0	 0.0; % NG
	991	 2.0	 0.0	 1.0	 -1.0	 1.022224	 100.0	 1	 4.0	 0.0; % NG
	1013	 1.5	 0.95	 1.0	 0.9	 1.000001	 100.0	 1	 3.0	 0.0; % NG
	1013	 0.0	 1.0	 1.0	 0.0	 1.000001	 100.0	 0	 3.0	 0.0; % NG
	1017	 3.6	 0.0	 4.0	 -4.0	 0.999999	 100.0	 1	 7.2	 0.0; % NG
	1029	 10.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 20.0	 0.0; % NG
	1052	 0.0	 -2.48	 12.0	 -10.0	 0.999999	 100.0	 0	 20.0	 0.0; % NG
	1054	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 13.8	 0.0; % PEL
	1054	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 1.2	 0.0; % PEL
	1061	 9.4	 1.5	 6.0	 -3.0	 1.022222	 100.0	 1	 11.8	 7.0; % COW
	1062	 4.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 8.0	 0.0; % NG
	1069	 0.0	 0.0	 0.0	 0.0	 0.9682545	 100.0	 0	 12.0	 0.0; % NG
	1070	 6.0	 1.95	 2.0	 1.9	 1.0000025	 100.0	 1	 12.0	 0.0; % NG
	1074	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 8.0	 0.0; % NG
	1112	 16.0	 0.0	 6.0	 -6.0	 0.975	 100.0	 1	 18.0	 14.0; % NG
	1112	 0.0	 0.0	 3.0	 -3.0	 0.975	 100.0	 0	 8.0	 5.0; % COW
	1112	 0.0	 0.0	 3.0	 -3.0	 0.975	 100.0	 0	 8.0	 5.0; % PEL
	1112	 0.0	 0.0	 3.0	 -3.0	 0.975	 100.0	 0	 8.0	 5.0; % NG
	1114	 0.0	 -1.7	 10.0	 -10.0	 0.999999	 100.0	 0	 18.0	 0.0; % NG
	1114	 0.0	 -1.7	 10.0	 -10.0	 0.999999	 100.0	 0	 18.0	 0.0; % PEL
	1129	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 7.0	 0.0; % NG
	1132	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % NG
	1139	 6.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 12.0	 0.0; % NG
	1151	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 6.0	 0.0; % NG
	1151	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.0	 0.0; % COW
	1214	 31.0	 0.0	 40.0	 -40.0	 1.044445	 100.0	 1	 62.0	 0.0; % NG
	1215	 20.7	 0.415	 12.42	 -11.59	 1.044445	 100.0	 1	 41.4	 0.0; % NG
	1225	 5.6	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 11.2	 0.0; % NG
	1250	 0.0	 -0.45	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	1250	 0.0	 -0.45	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	1260	 15.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 30.0	 0.0; % PEL
	1262	 12.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 24.0	 0.0; % PEL
	1263	 12.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 24.0	 0.0; % NG
	1267	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 4.6	 0.0; % PEL
	1281	 14.5	 0.0	 0.0	 0.0	 1.033333	 100.0	 1	 29.0	 0.0; % PEL
	1281	 0.0	 0.0	 0.0	 0.0	 1.033333	 100.0	 0	 14.3	 0.0; % NG
	1290	 0.0	 0.35	 0.35	 -0.35	 1.0000025	 100.0	 0	 1.06	 0.0; % PEL
	1290	 0.0	 1.3	 2.6	 -2.8	 1.0000025	 100.0	 0	 8.0	 0.0; % NG
	1290	 4.0	 -0.1	 2.6	 -2.8	 1.0000025	 100.0	 1	 8.0	 0.0; % NG
	1307	 0.0	 0.1	 0.1	 -0.1	 0.975	 100.0	 0	 4.0	 0.0; % PEL
	1314	 0.0	 1.0	 1.0	 0.0	 1.0000025	 100.0	 0	 17.0	 0.0; % NG
	1314	 8.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 17.0	 0.0; % NG
	1314	 0.0	 1.0	 1.0	 0.0	 1.0000025	 100.0	 0	 7.0	 0.0; % NG
	1317	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 0.8	 0.6; % NG
	1317	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 0.8	 0.6; % PEL
	1319	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 11.5	 0.0; % PEL
	1319	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 6.9	 0.0; % NG
	1327	 0.0	 -1.7	 6.5	 -6.5	 0.9444445	 100.0	 0	 12.4	 0.0; % NG
	1329	 2.5	 0.95	 1.0	 0.9	 1.000001	 100.0	 1	 5.0	 0.0; % NG
	1329	 2.5	 0.95	 1.0	 0.9	 1.000001	 100.0	 1	 5.0	 0.0; % NG
	1344	 0.0	 -9.87	 40.0	 -40.0	 0.999999	 100.0	 0	 72.5	 0.0; % PEL
	1348	 5.5	 3.0	 5.0	 1.0	 0.975	 100.0	 1	 11.0	 0.0; % NG
	1348	 5.5	 3.0	 5.0	 1.0	 0.975	 100.0	 1	 11.0	 0.0; % NG
	1358	 9.075	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 18.15	 0.0; % NG
	1358	 17.85	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 35.7	 0.0; % PEL
	1358	 14.2	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 28.4	 0.0; % PEL
	1360	 22.5	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 45.0	 0.0; % NG
	1366	 6.5	 1.0	 7.0	 -5.0	 1.015872	 100.0	 1	 13.0	 0.0; % NG
	1366	 0.0	 0.08	 7.0	 -5.0	 1.015872	 100.0	 0	 13.0	 0.0; % COW
	1413	 0.0	 0.0	 22.0	 -10.0	 1.015872	 100.0	 0	 50.0	 5.0; % NG
	1423	 25.0	 0.0	 50.0	 -50.0	 1.000001	 100.0	 1	 50.0	 0.0; % PEL
	1423	 25.0	 0.0	 50.0	 -50.0	 1.000001	 100.0	 1	 50.0	 0.0; % NG
	1436	 0.0	 0.0	 22.0	 -10.0	 1.015872	 100.0	 0	 50.0	 5.0; % PEL
	1443	 10.5	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 21.0	 0.0; % PEL
	1457	 0.0	 1.23	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % PEL
	1457	 0.0	 1.23	 2.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	1457	 0.0	 1.23	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	1466	 0.0	 -0.3	 0.3	 -0.3	 1.0158755	 100.0	 0	 3.0	 0.0; % PEL
	1467	 5.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 10.0	 0.0; % NG
	1477	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 10.0	 0.0; % NG
	1498	 13.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 26.0	 0.0; % PEL
	1500	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 10.0	 0.0; % NG
	1500	 10.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 20.0	 0.0; % PEL
	1520	 141.5	 20.0	 100.0	 -60.0	 0.975	 100.0	 1	 239.0	 44.0; % COW
	1522	 141.5	 20.0	 100.0	 -60.0	 0.975	 100.0	 1	 239.0	 44.0; % NG
	1523	 125.5	 12.5	 70.0	 -45.0	 0.975	 100.0	 1	 169.0	 82.0; % NG
	1521	 125.5	 12.5	 70.0	 -45.0	 0.975	 100.0	 1	 169.0	 82.0; % NG
	1553	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 20.0	 0.0; % PEL
	1553	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 15.85	 0.0; % NG
	1560	 25.0	 6.5	 22.0	 -9.0	 1.033333	 100.0	 1	 49.0	 1.0; % NG
	1564	 6.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 12.0	 0.0; % NG
	1564	 12.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 24.0	 0.0; % PEL
	1565	 2.0	 0.0	 0.0	 0.0	 1.046665	 100.0	 1	 4.0	 0.0; % NG
	1566	 5.75	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 11.5	 0.0; % COW
	1570	 12.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 24.0	 0.0; % NG
	1570	 0.01	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 14.0	 0.0; % COW
	1584	 0.0	 -7.19	 6.0	 -7.19	 0.999999	 100.0	 0	 10.2	 0.0; % NG
	1599	 18.0	 -0.5	 11.0	 -12.0	 1.022224	 100.0	 1	 36.0	 0.0; % PEL
	1599	 0.0	 3.5	 11.0	 -12.0	 1.022224	 100.0	 0	 36.0	 0.0; % NG
	1605	 21.0	 5.0	 20.0	 -10.0	 1.0000005	 100.0	 1	 42.0	 0.0; % NG
	1619	 11.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 22.0	 0.0; % NG
	1619	 5.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 10.0	 0.0; % NG
	1630	 39.0	 -2.675	 1.0	 -6.35	 1.0377785	 100.0	 1	 78.0	 0.0; % PEL
	1643	 0.0	 0.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 3.7	 0.7; % PEL
	1644	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 5.1	 0.0; % NG
	1644	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 11.9	 0.0; % NG
	1645	 26.0	 -1.5	 10.0	 -13.0	 1.04445	 100.0	 1	 52.0	 0.0; % NG
	1648	 0.0	 -0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 4.0	 0.0; % NG
	1659	 0.0	 -3.09	 6.0	 -6.0	 1.0000025	 100.0	 0	 15.0	 0.0; % NG
	1675	 5.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 10.0	 0.0; % NG
	1675	 8.75	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 17.5	 0.0; % NG
	1684	 0.0	 -0.4	 5.0	 -5.0	 1.015872	 100.0	 0	 11.0	 0.0; % NG
	1684	 0.0	 -0.4	 5.0	 -5.0	 1.015872	 100.0	 0	 11.0	 0.0; % NG
	1685	 0.0	 0.0	 3.0	 0.0	 1.0000025	 100.0	 0	 27.0	 0.0; % NG
	1686	 0.0	 1.44	 3.0	 -3.0	 1.015872	 100.0	 0	 10.33	 0.0; % NG
	1686	 0.0	 1.44	 3.0	 -3.0	 1.015872	 100.0	 0	 10.33	 0.0; % NG
	1687	 6.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 1	 12.0	 0.0; % COW
	1688	 0.0	 0.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 3.2	 0.6; % NG
	1693	 3.55	 0.07	 2.13	 -1.99	 1.0000025	 100.0	 1	 7.1	 0.0; % COW
	1697	 7.5	 0.0	 0.0	 -0.0	 1.0158755	 100.0	 1	 15.0	 0.0; % NG
	1697	 7.5	 0.0	 0.0	 -0.0	 1.0158755	 100.0	 1	 15.0	 0.0; % PEL
	1697	 7.5	 0.0	 0.0	 -0.0	 1.0158755	 100.0	 1	 15.0	 0.0; % NG
	1700	 0.0	 0.0	 3.0	 0.0	 1.0000025	 100.0	 0	 31.0	 0.0; % PEL
	1703	 9.0	 1.95	 2.0	 1.9	 1.0000025	 100.0	 1	 18.0	 0.0; % NG
	1704	 0.0	 -3.05	 25.0	 -25.0	 1.0000025	 100.0	 0	 40.0	 0.0; % NG
	1706	 0.0	 1.51	 18.0	 -18.0	 0.999999	 100.0	 0	 28.9	 0.0; % NG
	1717	 0.0	 0.0	 0.0	 0.0	 1.015874	 100.0	 0	 2.0	 0.0; % PEL
	1728	 0.0	 -2.0	 2.7	 -2.0	 0.975	 100.0	 0	 4.5	 0.0; % NG
	1728	 0.0	 -3.09	 8.0	 -8.0	 0.975	 100.0	 0	 14.5	 0.0; % PEL
	1731	 2.25	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 4.5	 0.0; % PEL
	1733	 6.0	 0.0	 7.5	 -7.5	 0.999999	 100.0	 1	 12.0	 0.0; % NG
	1739	 13.5	 0.0	 14.0	 -14.0	 1.0000025	 100.0	 1	 27.0	 0.0; % NG
	1739	 0.0	 0.43	 6.0	 -6.0	 1.0000025	 100.0	 0	 11.0	 0.0; % NG
	1746	 20.0	 1.0	 20.0	 -18.0	 0.975	 100.0	 1	 40.0	 0.0; % COW
	1747	 20.0	 1.0	 20.0	 -18.0	 0.975	 100.0	 1	 40.0	 0.0; % NG
	1748	 20.0	 1.0	 20.0	 -18.0	 0.975	 100.0	 1	 40.0	 0.0; % NG
	1802	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 3.6	 0.0; % NG
	1812	 0.0	 0.0	 2.0	 0.0	 1.0000025	 100.0	 0	 10.6	 0.0; % NG
	1829	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 9.2	 0.0; % NG
	1836	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 32.7	 0.0; % PEL
	1842	 8.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 16.0	 0.0; % PEL
	1842	 16.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 32.0	 0.0; % PEL
	1852	 0.0	 0.19	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % PEL
	1852	 0.0	 0.43	 1.0	 -1.0	 1.015872	 100.0	 0	 4.0	 0.0; % NG
	1860	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	1863	 0.0	 0.0	 1.0	 0.0	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	1863	 0.0	 -0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 2.0	 0.0; % PEL
	1868	 12.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 24.0	 0.0; % PEL
	1868	 18.25	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 36.5	 0.0; % NG
	1868	 21.75	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 43.5	 0.0; % NG
	1869	 5.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 10.0	 0.0; % NG
	1870	 22.0	 5.5	 20.0	 -9.0	 1.0000005	 100.0	 1	 44.0	 0.0; % NG
	1871	 0.0	 -1.5	 3.5	 -3.5	 0.999999	 100.0	 0	 5.9	 0.0; % PEL
	1876	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 9.0	 0.0; % COW
	1885	 5.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 10.0	 0.0; % NG
	1893	 12.0	 0.0	 4.0	 -4.0	 0.975	 100.0	 1	 24.0	 0.0; % NG
	1894	 12.0	 0.0	 4.0	 -4.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	1895	 12.0	 0.0	 4.0	 -4.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	1896	 12.0	 0.0	 4.0	 -4.0	 0.975	 100.0	 1	 24.0	 0.0; % NG
	1908	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 1.2	 0.0; % PEL
	1927	 0.0	 1.0	 1.0	 -1.0	 1.000001	 100.0	 0	 3.0	 0.0; % PEL
	1940	 0.0	 -0.55	 26.0	 -26.0	 0.999999	 100.0	 0	 43.0	 0.0; % NG
	1939	 0.0	 -0.61	 20.0	 -20.0	 0.999999	 100.0	 0	 38.0	 0.0; % PEL
	1948	 15.0	 1.95	 2.0	 1.9	 1.0000025	 100.0	 1	 30.0	 0.0; % NG
	1959	 0.0	 0.0	 2.0	 0.0	 1.0000025	 100.0	 0	 6.0	 0.0; % PEL
	1967	 12.0	 0.5	 8.0	 -7.0	 0.975	 100.0	 1	 24.0	 0.0; % NG
	1968	 12.0	 2.82	 5.65	 -0.01	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	1969	 12.0	 0.5	 8.0	 -7.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	1970	 12.0	 0.5	 8.0	 -7.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	1971	 12.0	 0.5	 8.0	 -7.0	 0.975	 100.0	 1	 24.0	 0.0; % NG
	1980	 14.5	 0.0	 10.0	 -10.0	 0.975	 100.0	 1	 29.0	 0.0; % PEL
	1980	 14.5	 0.0	 10.0	 -10.0	 0.975	 100.0	 1	 29.0	 0.0; % PEL
	1981	 14.5	 -6.5	 5.0	 -18.0	 0.999999	 100.0	 1	 29.0	 0.0; % PEL
	1982	 14.5	 -5.0	 8.0	 -18.0	 0.999999	 100.0	 1	 29.0	 0.0; % NG
	1984	 0.0	 -1.48	 6.0	 -6.0	 1.0000025	 100.0	 0	 8.0	 0.0; % PEL
	1986	 2.55	 0.0	 2.0	 -2.0	 1.0000025	 100.0	 1	 4.6	 0.5; % PEL
	1986	 0.0	 0.0	 2.0	 -2.0	 1.0000025	 100.0	 0	 4.6	 0.5; % NG
	1992	 0.0	 -3.0	 2.0	 -3.0	 0.999999	 100.0	 0	 3.6	 0.0; % NG
	2000	 0.0	 -2.61	 5.0	 -5.0	 0.9444445	 100.0	 0	 8.5	 0.0; % NG
	2007	 23.0	 6.0	 21.0	 -9.0	 1.0158755	 100.0	 1	 46.0	 0.0; % NG
	2018	 12.0	 0.0	 9.0	 -9.0	 1.0000025	 100.0	 1	 24.0	 0.0; % NG
	2019	 12.0	 0.0	 9.0	 -9.0	 1.0000025	 100.0	 1	 24.0	 0.0; % PEL
	2019	 12.0	 0.0	 9.0	 -9.0	 1.0000025	 100.0	 1	 24.0	 0.0; % NG
	2024	 6.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 12.0	 0.0; % COW
	2028	 0.0	 0.0	 7.0	 -7.0	 1.000001	 100.0	 1	 30.0	 -30.0; % NG
	2036	 4.5	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 9.0	 0.0; % NG
	2050	 17.0	 1.5	 19.0	 -16.0	 0.999999	 100.0	 1	 34.0	 0.0; % NG
	2060	 6.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 12.0	 0.0; % PEL
	2084	 0.0	 0.0	 2.0	 0.0	 1.0000025	 100.0	 0	 5.0	 0.0; % COW
	2097	 8.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 16.0	 0.0; % NG
	2098	 27.5	 6.0	 22.0	 -10.0	 1.022222	 100.0	 1	 54.0	 1.0; % NG
	2102	 8.0	 0.0	 5.0	 -5.0	 1.0079355	 100.0	 1	 16.0	 0.0; % NG
	2122	 9.95	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 19.9	 0.0; % NG
	2122	 16.2	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 32.4	 0.0; % PEL
	2150	 5.125	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 10.25	 0.0; % NG
	2150	 3.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 6.0	 0.0; % NG
	2160	 14.5	 3.5	 13.0	 -6.0	 1.027779	 100.0	 1	 29.0	 0.0; % PEL
	2164	 0.0	 2.51	 22.0	 -10.0	 1.0000005	 100.0	 0	 45.0	 0.0; % PEL
	2165	 6.0	 0.0	 0.0	 0.0	 1.033333	 100.0	 1	 12.0	 0.0; % NG
	2181	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 24.0	 0.0; % PEL
	2181	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 29.92	 0.0; % PEL
	2186	 4.6	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 9.2	 0.0; % NG
	2189	 0.0	 0.0	 0.0	 0.0	 0.9682545	 100.0	 0	 12.0	 0.0; % NG
	2189	 0.0	 0.0	 0.0	 0.0	 0.9682545	 100.0	 0	 12.0	 0.0; % NG
	2191	 0.0	 0.0	 22.0	 -10.0	 1.022222	 100.0	 0	 47.0	 37.0; % PEL
	2192	 7.5	 0.0	 9.0	 -9.0	 0.9444445	 100.0	 1	 15.0	 0.0; % NG
	2194	 10.0	 1.95	 2.0	 1.9	 1.000001	 100.0	 1	 20.0	 0.0; % NG
	2225	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 28.0	 0.0; % PEL
	2225	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 26.0	 0.0; % NG
	2244	 6.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 12.0	 0.0; % NG
	2244	 18.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 36.0	 0.0; % NG
	2246	 0.0	 0.0	 8.0	 -8.0	 0.975	 100.0	 0	 24.0	 2.5; % PEL
	2246	 13.25	 0.0	 8.0	 -8.0	 0.975	 100.0	 1	 24.0	 2.5; % NG
	2280	 6.9	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 13.8	 0.0; % COW
	2290	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % NG
	2294	 28.0	 -1.5	 17.0	 -20.0	 1.0000005	 100.0	 1	 56.0	 0.0; % NG
	2296	 0.0	 3.5	 20.0	 -20.0	 1.0000005	 100.0	 0	 64.0	 -64.0; % NG
	2302	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % NG
	2302	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % NG
	2328	 6.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 12.0	 0.0; % NG
	2334	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 11.5	 0.0; % NG
	2338	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 3.6	 0.0; % NG
	2340	 14.0	 1.5	 12.0	 -9.0	 1.015872	 100.0	 1	 28.0	 0.0; % NG
	2340	 14.0	 1.5	 12.0	 -9.0	 1.015872	 100.0	 1	 28.0	 0.0; % NG
	2340	 14.0	 1.5	 12.0	 -9.0	 1.015872	 100.0	 1	 28.0	 0.0; % NG
	2341	 0.0	 1.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	2341	 0.0	 0.96	 3.0	 0.0	 1.0000025	 100.0	 0	 7.0	 0.0; % COW
	2342	 3.5	 0.0	 2.0	 -2.0	 1.022224	 100.0	 1	 7.0	 0.0; % COW
	2364	 12.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	2365	 12.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	2366	 12.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 24.0	 0.0; % COW
	2367	 12.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	2368	 10.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 20.0	 0.0; % PEL
	2378	 4.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 8.0	 0.0; % NG
	2395	 6.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 12.0	 0.0; % PEL
	2397	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 34.9	 0.0; % PEL
	2397	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 19.3	 0.0; % PEL
	2413	 18.0	 0.0	 14.0	 -14.0	 1.000001	 100.0	 1	 36.0	 0.0; % NG
	2415	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 6.9	 0.0; % NG
	2415	 9.6	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 19.2	 0.0; % PEL
	2422	 4.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 8.0	 0.0; % COW
	2422	 8.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 16.0	 0.0; % COW
	2422	 6.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 12.0	 0.0; % COW
	2434	 9.85	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 19.7	 0.0; % COW
	2438	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 22.6	 0.0; % PEL
	2438	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 1.7	 0.0; % PEL
	2441	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 18.0	 0.0; % NG
	2441	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 21.0	 0.0; % NG
	2446	 5.2	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 10.4	 0.0; % NG
	2445	 11.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 22.0	 0.0; % NG
	2462	 0.0	 -2.36	 8.0	 -8.0	 1.044445	 100.0	 0	 21.0	 0.0; % NG
	2463	 0.0	 0.93	 3.0	 -3.0	 1.015872	 100.0	 0	 4.5	 0.0; % NG
	2463	 2.25	 0.0	 3.0	 -3.0	 1.015872	 100.0	 1	 4.5	 0.0; % NG
	2466	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 20.7	 0.0; % PEL
	2477	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 12.0	 0.0; % NG
	2483	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 26.0	 0.0; % NG
	2497	 0.0	 -0.73	 5.0	 -5.0	 1.015872	 100.0	 0	 12.0	 0.0; % NG
	2525	 44.0	 5.5	 19.0	 -8.0	 1.054343	 100.0	 1	 50.0	 38.0; % NG
	2525	 44.0	 5.5	 19.0	 -8.0	 1.054343	 100.0	 1	 50.0	 38.0; % PEL
	2531	 10.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 20.0	 0.0; % PEL
	2531	 18.425	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 36.85	 0.0; % PEL
	2532	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.5	 0.0; % NG
	2532	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 15.0	 0.0; % NG
	2534	 4.8	 0.005	 0.97	 -0.96	 1.0158755	 100.0	 1	 9.6	 0.0; % NG
	2547	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 5.66	 0.0; % PEL
	2549	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 16.0	 0.0; % NG
	2557	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 18.85	 0.0; % NG
	2557	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 34.0	 0.0; % NG
	2560	 8.0	 1.5	 12.0	 -9.0	 0.999999	 100.0	 1	 16.0	 0.0; % NG
	2565	 8.4	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 16.8	 0.0; % PEL
	2578	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 16.8	 0.0; % NG
	2578	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 13.5	 0.0; % COW
	2583	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 11.5	 0.0; % NG
	2588	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % COW
	2588	 10.35	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 20.7	 0.0; % COW
	2594	 0.0	 0.0	 0.0	 0.0	 0.975	 100.0	 0	 4.6	 0.0; % NG
	2603	 6.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 12.0	 0.0; % COW
	2603	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 9.0	 0.0; % NG
	2612	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 22.0	 0.0; % NG
	2613	 0.0	 -1.4	 1.0	 -2.0	 1.015872	 100.0	 0	 8.9	 0.0; % NG
	2618	 5.525	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 11.05	 0.0; % NG
	2626	 18.75	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 37.5	 0.0; % NG
	2626	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 12.0	 0.0; % NG
	2629	 14.0	 4.5	 16.0	 -7.0	 1.0158755	 100.0	 1	 28.0	 0.0; % NG
	2642	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 5.0	 0.0; % PEL
	2642	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	2642	 0.0	 1.0	 1.0	 0.0	 1.0000025	 100.0	 0	 5.0	 0.0; % PEL
	2645	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 2.3	 0.0; % PEL
	2646	 9.0	 0.0	 10.0	 -10.0	 1.0000025	 100.0	 1	 18.0	 0.0; % PEL
	2647	 0.0	 -1.94	 14.0	 -14.0	 1.0000025	 100.0	 0	 22.0	 0.0; % PEL
	2647	 11.0	 0.0	 14.0	 -14.0	 1.0000025	 100.0	 1	 22.0	 0.0; % PEL
	2647	 0.0	 -1.94	 8.0	 -16.0	 1.0000025	 100.0	 0	 29.0	 0.0; % NG
	2648	 0.0	 -0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 1.0	 0.0; % PEL
	2648	 0.0	 -1.21	 6.0	 -6.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	2648	 0.0	 -1.21	 5.0	 -5.0	 1.0000025	 100.0	 0	 9.0	 0.0; % NG
	2651	 17.5	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 35.0	 0.0; % NG
	2651	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 24.0	 0.0; % PEL
	2654	 14.0	 3.95	 4.0	 3.9	 1.0000025	 100.0	 1	 28.0	 0.0; % COW
	2661	 0.0	 -0.8	 1.7	 -1.7	 0.999999	 100.0	 0	 2.6	 0.0; % PEL
	2661	 4.9	 0.0	 6.0	 -6.0	 0.999999	 100.0	 1	 9.8	 0.0; % NG
	2662	 17.5	 -1.5	 12.0	 -15.0	 1.015872	 100.0	 1	 35.0	 0.0; % PEL
	2662	 17.5	 -1.5	 12.0	 -15.0	 1.015872	 100.0	 1	 35.0	 0.0; % PEL
	2665	 0.0	 0.0	 1.0	 0.0	 0.975	 100.0	 0	 11.0	 0.0; % NG
	2666	 3.5	 0.95	 1.0	 0.9	 0.975	 100.0	 1	 7.0	 0.0; % COW
	2665	 0.0	 -0.1	 0.1	 -0.1	 0.975	 100.0	 0	 3.0	 0.0; % NG
	2664	 6.0	 -1.5	 4.0	 -7.0	 0.975	 100.0	 1	 12.0	 0.0; % NG
	2666	 0.0	 -0.1	 0.1	 -0.1	 0.975	 100.0	 0	 4.0	 0.0; % NG
	2667	 6.0	 -1.205	 4.59	 -7.0	 1.0000025	 100.0	 1	 12.0	 0.0; % PEL
	2671	 0.0	 -1.87	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	2671	 0.0	 -1.87	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	2671	 0.0	 -1.87	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	2671	 0.0	 -1.87	 2.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	2671	 0.0	 -1.87	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	2676	 3.075	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 6.15	 0.0; % PEL
	2690	 18.2	 0.0	 0.0	 0.0	 1.033333	 100.0	 1	 36.4	 0.0; % PEL
	2697	 7.5	 -0.5	 6.0	 -7.0	 1.0000005	 100.0	 1	 15.0	 0.0; % NG
	2730	 10.9	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 21.8	 0.0; % NG
	2735	 8.5	 0.0	 10.0	 -10.0	 1.000001	 100.0	 1	 17.0	 0.0; % NG
	2735	 8.5	 0.0	 10.0	 -10.0	 1.000001	 100.0	 1	 17.0	 0.0; % NG
	2767	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 26.5	 0.0; % NG
	2777	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 14.0	 0.0; % COW
	2813	 4.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 8.0	 0.0; % NG
	2814	 0.0	 0.0	 0.0	 0.0	 0.984126	 100.0	 0	 16.15	 0.0; % NG
	2819	 0.0	 2.02	 8.0	 -8.0	 1.0000025	 100.0	 0	 20.0	 0.0; % PEL
	2823	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % COW
	2834	 6.0	 1.5	 5.0	 -2.0	 1.0000005	 100.0	 1	 12.0	 0.0; % COW
	2839	 0.0	 -1.37	 4.63	 -5.56	 1.033334	 100.0	 0	 13.8	 0.0; % PEL
	2841	 10.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 20.0	 0.0; % PEL
	2841	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % NG
	2844	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % NG
	2844	 16.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 32.0	 0.0; % PEL
	2846	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 2.0	 0.0; % PEL
	2846	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 12.0	 0.0; % NG
	2858	 8.8	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 17.6	 0.0; % PEL
	2869	 4.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 8.0	 0.0; % NG
	2875	 6.9	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 13.8	 0.0; % NG
	2877	 7.4	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 14.8	 0.0; % COW
	2877	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 2.4	 0.0; % PEL
	2885	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 8.2	 0.0; % PEL
	2900	 0.0	 0.0	 9.0	 -9.0	 0.975	 100.0	 0	 26.5	 6.0; % NG
	2900	 16.25	 0.0	 9.0	 -9.0	 0.975	 100.0	 1	 26.5	 6.0; % PEL
	2900	 0.0	 0.0	 8.0	 -8.0	 0.975	 100.0	 0	 22.9	 6.0; % PEL
	2905	 0.0	 0.0	 1.0	 0.0	 1.0	 100.0	 0	 14.0	 0.0; % NG
	2905	 0.0	 0.0	 1.0	 0.0	 1.0	 100.0	 0	 12.0	 -10.0; % NG
	2905	 0.0	 0.0	 1.0	 0.0	 1.0	 100.0	 0	 12.0	 -10.0; % NG
	2909	 0.0	 -5.43	 5.43	 -5.43	 1.0000025	 100.0	 0	 16.3	 0.0; % NG
	2929	 0.0	 -0.74	 3.0	 -3.0	 0.999999	 100.0	 0	 6.0	 0.0; % NG
	2930	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 8.0	 0.0; % COW
	2942	 17.25	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 34.5	 0.0; % PEL
	2949	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 8.0	 0.0; % PEL
	2955	 9.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 18.0	 0.0; % NG
	2955	 5.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 10.0	 0.0; % NG
	2977	 0.0	 -1.3	 0.47	 -1.3	 1.0158755	 100.0	 0	 4.7	 0.0; % NG
	2984	 4.1	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 8.2	 0.0; % COW
	2995	 17.0	 0.0	 17.0	 -17.0	 0.999999	 100.0	 1	 34.0	 0.0; % PEL
	3022	 0.0	 -1.7	 1.7	 -1.7	 1.0158755	 100.0	 0	 17.0	 0.0; % PEL
	3022	 0.0	 -1.7	 1.7	 -1.7	 1.0158755	 100.0	 0	 17.0	 0.0; % PEL
	3023	 2.5	 0.0	 3.0	 -3.0	 0.999999	 100.0	 1	 5.0	 0.0; % COW
	3025	 9.2	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 18.4	 0.0; % NG
	3028	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 2.4	 0.0; % PEL
	3028	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	3030	 5.75	 0.0	 0.0	 0.0	 1.022222	 100.0	 1	 11.5	 0.0; % NG
	3037	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 6.9	 0.0; % NG
	3039	 0.0	 0.0	 0.0	 0.0	 1.044445	 100.0	 0	 55.4	 0.0; % PEL
	3050	 8.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 16.0	 0.0; % COW
	3060	 0.0	 1.62	 9.0	 -9.0	 0.999999	 100.0	 0	 15.8	 0.0; % PEL
	3061	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 2.0	 0.0; % PEL
	3071	 8.625	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 17.25	 0.0; % PEL
	3098	 0.0	 -2.86	 5.0	 -10.0	 0.9444445	 100.0	 0	 19.5	 0.0; % NG
	3107	 0.0	 3.38	 12.0	 0.0	 0.999999	 100.0	 0	 9.0	 0.0; % NG
	3110	 0.0	 0.0	 0.0	 0.0	 1.0377785	 100.0	 0	 54.0	 0.0; % NG
	3113	 5.55	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 11.1	 0.0; % NG
	3116	 19.0	 0.5	 20.0	 -19.0	 0.975	 100.0	 1	 38.0	 0.0; % NG
	3117	 19.0	 0.5	 20.0	 -19.0	 0.975	 100.0	 1	 38.0	 0.0; % NG
	3118	 19.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 38.0	 0.0; % NG
	3122	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 4.25	 0.0; % PEL
	3123	 8.4	 0.0	 10.0	 -10.0	 0.999999	 100.0	 1	 16.8	 0.0; % NG
	3123	 8.0	 0.0	 17.3	 -17.3	 0.999999	 100.0	 1	 16.0	 0.0; % NG
	3125	 10.4	 0.0	 0.0	 0.0	 0.999999	 100.0	 1	 20.8	 0.0; % NG
	3126	 0.0	 -1.03	 6.0	 -6.0	 1.0000025	 100.0	 0	 8.0	 0.0; % NG
	3131	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 7.2	 0.0; % COW
	3132	 5.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 10.0	 0.0; % NG
	3132	 9.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 18.0	 0.0; % NG
	3136	 5.5	 0.95	 1.0	 0.9	 1.000001	 100.0	 1	 11.0	 0.0; % PEL
	3136	 0.0	 0.1	 0.1	 -0.1	 1.000001	 100.0	 0	 14.0	 0.0; % NG
	3140	 0.0	 0.0	 0.0	 0.0	 1.0377785	 100.0	 0	 8.0	 0.0; % COW
	3140	 0.0	 0.0	 0.0	 0.0	 1.0377785	 100.0	 0	 8.0	 0.0; % NG
	3142	 0.0	 -0.5	 0.5	 -0.5	 1.0000025	 100.0	 0	 1.5	 0.0; % PEL
	3147	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.5	 0.0; % NG
	3147	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 8.6	 0.0; % NG
	3151	 6.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 12.0	 0.0; % PEL
	3157	 26.5	 6.0	 22.0	 -10.0	 1.0111115	 100.0	 1	 48.0	 5.0; % NG
	3159	 0.0	 1.0	 1.0	 0.0	 1.000001	 100.0	 0	 16.0	 0.0; % NG
	3159	 0.0	 1.0	 1.0	 0.0	 1.000001	 100.0	 0	 16.0	 0.0; % COW
	3159	 9.0	 0.0	 12.0	 -12.0	 1.000001	 100.0	 1	 18.0	 0.0; % NG
	3178	 0.0	 -0.61	 10.0	 -3.0	 1.0	 100.0	 0	 27.0	 0.0; % NG
	3178	 0.0	 -0.61	 10.0	 -3.0	 1.0	 100.0	 0	 27.0	 0.0; % NG
	3185	 5.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 10.0	 0.0; % PEL
	3185	 6.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 12.0	 0.0; % NG
	3188	 9.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 1	 18.0	 0.0; % PEL
	3188	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 10.0	 0.0; % NG
	3210	 10.0	 1.0	 2.0	 0.0	 1.0	 100.0	 1	 20.0	 0.0; % PEL
	3219	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 22.6	 0.0; % PEL
	3219	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	3238	 11.15	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 22.3	 0.0; % PEL
	3239	 0.0	 0.0	 2.0	 1.9	 1.000001	 100.0	 0	 22.0	 0.0; % NG
	3241	 0.0	 -0.75	 3.0	 -3.0	 0.999999	 100.0	 0	 5.2	 0.0; % NG
	3244	 4.6	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 9.2	 0.0; % NG
	3246	 0.0	 -3.96	 4.0	 -4.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	3250	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.8	 0.0; % COW
	3260	 3.75	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 7.5	 0.0; % NG
	3264	 0.0	 -0.07	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	3265	 18.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 36.0	 0.0; % PEL
	3265	 16.35	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 32.7	 0.0; % COW
	3265	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % NG
	3266	 21.0	 2.5	 25.0	 -20.0	 1.0	 100.0	 1	 42.0	 0.0; % NG
	3266	 21.0	 2.5	 25.0	 -20.0	 1.0	 100.0	 1	 42.0	 0.0; % NG
	3276	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	3276	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	3280	 18.05	 2.5	 20.0	 -15.0	 0.975	 100.0	 1	 36.1	 0.0; % PEL
	3281	 18.05	 2.5	 20.0	 -15.0	 0.975	 100.0	 1	 36.1	 0.0; % NG
	3282	 18.05	 2.5	 20.0	 -15.0	 0.975	 100.0	 1	 36.1	 0.0; % NG
	3295	 0.0	 1.36	 8.5	 -8.5	 0.999999	 100.0	 0	 11.4	 0.0; % NG
	3301	 0.0	 0.23	 5.0	 -5.0	 1.015872	 100.0	 0	 13.0	 0.0; % COW
	3308	 8.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 17.0	 0.0; % NG
	3308	 8.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 17.0	 0.0; % PEL
	3313	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 18.0	 0.0; % NG
	3313	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 10.2	 0.0; % NG
	3315	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % PEL
	3315	 9.7	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 19.4	 0.0; % NG
	3339	 5.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 10.0	 0.0; % NG
	3345	 0.0	 0.0	 24.0	 -24.0	 0.999999	 100.0	 0	 51.0	 0.8; % NG
	3377	 4.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 8.0	 0.0; % PEL
	3377	 10.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 20.0	 0.0; % PEL
	3382	 19.9	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 39.8	 0.0; % NG
	3383	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 15.0	 0.0; % NG
	3405	 21.5	 6.0	 22.0	 -10.0	 1.0158755	 100.0	 1	 43.0	 0.0; % NG
	3408	 12.0	 -0.13	 7.0	 -7.26	 0.999999	 100.0	 1	 24.0	 0.0; % PEL
	3418	 0.0	 1.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 7.5	 0.0; % COW
	3418	 3.75	 0.0	 1.0	 -1.0	 1.0000025	 100.0	 1	 7.5	 0.0; % PEL
	3418	 0.0	 1.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 7.5	 0.0; % NG
	3418	 0.0	 1.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 7.5	 0.0; % NG
	3418	 0.0	 1.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 7.5	 0.0; % COW
	3423	 17.5	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 35.0	 0.0; % PEL
	3423	 18.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 36.0	 0.0; % PEL
	3424	 11.55	 0.0	 14.0	 -14.0	 0.999999	 100.0	 1	 23.1	 0.0; % PEL
	3424	 11.55	 0.0	 14.0	 -14.0	 0.999999	 100.0	 1	 23.1	 0.0; % NG
	3431	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 3.0	 0.0; % NG
	3434	 10.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 20.0	 0.0; % COW
	3437	 12.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 24.0	 0.0; % PEL
	3440	 6.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 12.0	 0.0; % NG
	3440	 5.25	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 10.5	 0.0; % NG
	3445	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 1.7	 0.0; % PEL
	3450	 10.275	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 20.55	 0.0; % NG
	3451	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 6.0	 0.0; % NG
	3454	 6.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 12.0	 0.0; % NG
	3461	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	3468	 6.6	 0.0	 8.0	 -8.0	 0.999999	 100.0	 1	 13.2	 0.0; % COW
	3488	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 1.25	 0.0; % PEL
	3491	 0.0	 0.0	 0.0	 0.0	 1.00713	 100.0	 0	 0.0	 -8.0; % SYNC
	3491	 26.5	 3.5	 17.0	 -10.0	 1.00713	 100.0	 1	 53.0	 0.0; % NG
	3495	 10.6	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 21.2	 0.0; % NG
	3502	 0.0	 0.24	 6.0	 -3.0	 1.0000025	 100.0	 0	 11.0	 0.0; % NG
	3502	 0.0	 0.24	 12.0	 -6.0	 1.0000025	 100.0	 0	 22.0	 0.0; % PEL
	3505	 0.0	 -2.33	 15.0	 -15.0	 1.044445	 100.0	 0	 35.0	 0.0; % PEL
	3506	 0.0	 -2.74	 15.0	 -10.0	 0.975	 100.0	 0	 50.0	 0.0; % NG
	3508	 0.0	 1.37	 2.8	 -2.8	 0.999999	 100.0	 0	 4.8	 0.0; % NG
	3509	 9.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 1	 18.0	 0.0; % PEL
	3514	 24.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 48.0	 0.0; % NG
	3514	 8.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 16.0	 0.0; % NG
	3522	 0.0	 -16.0	 16.0	 -16.0	 0.999999	 100.0	 0	 26.2	 0.0; % NG
	3531	 5.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 10.0	 0.0; % NG
	3545	 6.4	 0.0	 7.6	 -7.6	 0.999999	 100.0	 1	 12.8	 0.0; % PEL
	3546	 6.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 12.0	 0.0; % NG
	3551	 0.0	 -2.0	 5.0	 -2.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	3551	 0.0	 -2.0	 5.0	 -2.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	3551	 0.0	 -2.0	 5.0	 -2.0	 1.0158755	 100.0	 0	 12.0	 0.0; % PEL
	3550	 0.0	 -2.34	 22.0	 -10.0	 1.0424305	 100.0	 0	 43.0	 0.0; % NG
	3585	 5.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 10.0	 0.0; % NG
	3588	 10.4	 -2.0	 6.0	 -10.0	 0.975	 100.0	 1	 20.0	 0.8; % NG
	3588	 10.4	 0.0	 4.2	 -4.2	 0.975	 100.0	 1	 20.0	 0.8; % PEL
	3587	 0.0	 0.0	 4.2	 -4.2	 0.975	 100.0	 0	 20.0	 0.8; % PEL
	3587	 10.4	 0.0	 4.2	 -4.2	 0.975	 100.0	 1	 20.0	 0.8; % NG
	3600	 19.5	 0.0	 19.0	 -19.0	 1.002375	 100.0	 1	 39.0	 0.0; % COW
	3602	 0.0	 1.58	 10.0	 -9.0	 1.000001	 100.0	 0	 23.0	 0.0; % PEL
	3602	 0.0	 1.58	 10.0	 -9.0	 1.000001	 100.0	 0	 23.0	 0.0; % NG
	3602	 0.0	 1.58	 10.0	 -9.0	 1.000001	 100.0	 0	 23.0	 0.0; % COW
	3606	 0.0	 10.0	 30.0	 -10.0	 0.999999	 100.0	 1	 40.0	 -40.0; % NG
	3606	 0.0	 0.0	 28.0	 -28.0	 0.999999	 100.0	 1	 50.0	 -50.0; % NG
	3638	 0.0	 0.26	 3.0	 -1.0	 0.999999	 100.0	 0	 2.0	 0.0; % PEL
	3648	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 14.89	 0.0; % COW
	3648	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 34.77	 0.0; % NG
	3651	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	3653	 3.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 7.0	 0.0; % NG
	3653	 3.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 7.0	 0.0; % COW
	3654	 0.0	 -9.01	 12.0	 -12.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	3659	 0.0	 -0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	3662	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % NG
	3663	 0.0	 1.0	 1.0	 -1.0	 1.0079355	 100.0	 0	 3.0	 0.0; % NG
	3668	 0.0	 -1.08	 7.0	 -7.0	 0.999999	 100.0	 0	 12.0	 0.0; % PEL
	3668	 0.0	 -1.08	 7.0	 -7.0	 0.999999	 100.0	 0	 12.0	 0.0; % NG
	3669	 0.0	 -3.0	 3.0	 -3.0	 0.999999	 100.0	 0	 4.5	 0.0; % NG
	3685	 0.0	 -1.74	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % NG
	3687	 1.5	 0.0	 1.8	 -1.8	 0.999999	 100.0	 1	 3.0	 0.0; % PEL
	3693	 4.75	 0.0	 6.0	 -6.0	 0.999999	 100.0	 1	 9.5	 0.0; % NG
	3695	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 8.0	 0.0; % COW
	3697	 0.0	 1.63	 5.6	 -5.6	 0.999999	 100.0	 0	 8.8	 0.0; % NG
	3714	 12.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 24.0	 0.0; % PEL
	3716	 9.0	 0.0	 8.0	 -8.0	 1.027779	 100.0	 1	 18.0	 0.0; % PEL
	3717	 0.0	 -2.2	 17.0	 -11.0	 0.999999	 100.0	 0	 19.0	 0.0; % PEL
	3718	 22.0	 0.0	 17.0	 -17.0	 0.999999	 100.0	 1	 44.0	 0.0; % NG
	3745	 0.0	 -2.71	 6.0	 -7.0	 0.999999	 100.0	 0	 9.0	 0.0; % NG
	3749	 8.4	 0.25	 4.6	 -4.1	 0.999999	 100.0	 1	 11.2	 5.6; % NG
	3754	 21.5	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 43.0	 0.0; % NG
	3759	 5.0	 0.0	 0.0	 0.0	 0.984126	 100.0	 1	 10.0	 0.0; % NG
	3759	 0.0	 0.0	 0.0	 0.0	 0.984126	 100.0	 0	 20.0	 0.0; % PEL
	3761	 11.025	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 22.05	 0.0; % PEL
	3762	 6.0	 0.0	 1.2	 -1.2	 1.0158755	 100.0	 1	 12.0	 0.0; % NG
	3797	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	3797	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	3800	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 26.25	 0.0; % COW
	3800	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 20.25	 0.0; % PEL
	3800	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % PEL
	3802	 10.01	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 20.02	 0.0; % NG
	3802	 10.175	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 20.35	 0.0; % NG
	3817	 18.9	 2.0	 12.0	 -8.0	 0.975	 100.0	 1	 37.8	 0.0; % NG
	3818	 18.9	 2.0	 12.0	 -8.0	 0.975	 100.0	 1	 37.8	 0.0; % NG
	3819	 18.9	 2.0	 12.0	 -8.0	 0.975	 100.0	 1	 37.8	 0.0; % PEL
	3823	 13.6	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 27.2	 0.0; % PEL
	3827	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 30.0	 0.0; % PEL
	3837	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 9.1	 0.0; % NG
	3843	 6.0	 0.0	 7.2	 -7.2	 0.999999	 100.0	 1	 12.0	 0.0; % NG
	3843	 6.5	 0.0	 7.8	 -7.8	 0.999999	 100.0	 1	 13.0	 0.0; % COW
	3854	 11.0	 1.0	 6.0	 -4.0	 1.0000025	 100.0	 1	 22.0	 0.0; % COW
	3864	 3.34	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 6.68	 0.0; % NG
	3869	 4.5	 0.0	 3.0	 -3.0	 1.022224	 100.0	 1	 9.0	 0.0; % NG
	3870	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	3877	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 8.0	 0.0; % NG
	3890	 6.0	 0.0	 0.0	 0.0	 1.0277795	 100.0	 1	 12.0	 0.0; % NG
	3894	 0.0	 0.22	 1.0	 -1.0	 1.0079355	 100.0	 0	 2.0	 0.0; % PEL
	3894	 0.0	 1.0	 1.0	 -1.0	 1.0079355	 100.0	 0	 2.0	 0.0; % PEL
	3905	 6.6	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 13.2	 0.0; % NG
	3905	 9.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 18.0	 0.0; % PEL
	3920	 0.0	 -0.07	 5.0	 -4.5	 1.0000025	 100.0	 0	 7.0	 0.0; % COW
	3925	 0.0	 0.0	 0.0	 0.0	 1.015874	 100.0	 0	 32.0	 0.0; % NG
	3926	 0.0	 0.0	 0.0	 0.0	 1.026667	 100.0	 0	 55.0	 0.0; % NG
	3928	 0.0	 0.47	 2.0	 -3.0	 1.015872	 100.0	 0	 7.0	 0.0; % COW
	3940	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 17.2	 0.0; % NG
	3941	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 11.69	 0.0; % NG
	3952	 18.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 36.0	 0.0; % NG
	3970	 20.5	 0.0	 6.0	 -6.0	 0.975	 100.0	 1	 40.0	 1.0; % NG
	3970	 20.5	 0.0	 6.0	 -6.0	 0.975	 100.0	 1	 40.0	 1.0; % COW
	3969	 20.5	 -5.0	 5.0	 -15.0	 0.975	 100.0	 1	 40.0	 1.0; % NG
	3969	 20.5	 -5.0	 5.0	 -15.0	 0.975	 100.0	 1	 40.0	 1.0; % NG
	3978	 0.0	 0.1	 0.1	 -0.1	 1.000001	 100.0	 0	 2.2	 0.0; % PEL
	3978	 0.0	 0.0	 4.0	 3.9	 1.000001	 100.0	 0	 12.0	 0.0; % COW
	3988	 0.0	 0.75	 1.0	 -1.0	 1.015872	 100.0	 0	 2.0	 0.0; % PEL
	3988	 0.0	 2.25	 3.0	 -3.0	 1.015872	 100.0	 0	 8.0	 0.0; % NG
	3988	 4.0	 0.0	 3.0	 -3.0	 1.015872	 100.0	 1	 8.0	 0.0; % PEL
	3999	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % COW
	3999	 12.4	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 24.8	 0.0; % NG
	4001	 6.9	 0.0	 0.0	 0.0	 1.022222	 100.0	 1	 13.8	 0.0; % NG
	4001	 11.35	 0.0	 0.0	 0.0	 1.022222	 100.0	 1	 22.7	 0.0; % NG
	4026	 5.3	 0.0	 6.5	 -6.5	 0.999999	 100.0	 1	 10.6	 0.0; % NG
	4030	 0.0	 -2.84	 11.0	 -11.0	 0.9444445	 100.0	 0	 18.0	 0.0; % NG
	4032	 15.2	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 30.4	 0.0; % PEL
	4032	 8.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 16.0	 0.0; % PEL
	4055	 13.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 26.0	 0.0; % NG
	4056	 13.5	 -2.5	 6.0	 -11.0	 1.015872	 100.0	 1	 27.0	 0.0; % NG
	4056	 13.5	 -2.5	 6.0	 -11.0	 1.015872	 100.0	 1	 27.0	 0.0; % PEL
	4066	 8.55	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 17.1	 0.0; % PEL
	4072	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 2.4	 0.0; % NG
	4110	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % PEL
	4127	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 6.9	 0.0; % NG
	4131	 6.15	 0.0	 5.0	 -5.0	 0.999999	 100.0	 1	 12.3	 0.0; % COW
	4131	 0.0	 -1.93	 5.0	 -5.0	 0.999999	 100.0	 0	 12.3	 0.0; % NG
	4131	 6.15	 0.0	 5.0	 -5.0	 0.999999	 100.0	 1	 12.3	 0.0; % NG
	4133	 0.0	 0.49	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % COW
	4133	 0.0	 2.0	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % NG
	4171	 12.0	 0.0	 10.0	 -10.0	 1.0000025	 100.0	 1	 24.0	 0.0; % PEL
	4200	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % PEL
	4200	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % PEL
	4219	 6.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 12.0	 0.0; % PEL
	4218	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % NG
	4233	 6.5	 6.5	 13.0	 0.0	 0.999999	 100.0	 1	 13.0	 0.0; % NG
	4237	 8.2	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 16.4	 0.0; % COW
	4246	 0.0	 1.2	 42.0	 -42.0	 1.000001	 100.0	 0	 42.0	 0.0; % NG
	4247	 0.0	 0.26	 5.0	 -5.0	 1.015872	 100.0	 0	 19.0	 0.0; % NG
	4262	 7.75	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 15.5	 0.0; % NG
	4262	 12.85	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 25.7	 0.0; % NG
	4276	 6.0	 0.0	 5.0	 -5.0	 0.975	 100.0	 1	 12.0	 0.0; % PEL
	4276	 6.0	 0.0	 5.0	 -5.0	 0.975	 100.0	 1	 12.0	 0.0; % COW
	4277	 0.0	 0.27	 5.0	 -5.0	 1.015872	 100.0	 0	 12.0	 0.0; % COW
	4277	 0.0	 0.27	 5.0	 -5.0	 1.015872	 100.0	 0	 12.0	 0.0; % COW
	4295	 0.0	 0.53	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % NG
	4301	 23.0	 -7.0	 20.0	 -34.0	 0.999999	 100.0	 1	 46.0	 0.0; % PEL
	4302	 0.0	 -0.31	 3.6	 -3.6	 0.999999	 100.0	 0	 6.0	 0.0; % PEL
	4303	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 1.74	 0.0; % PEL
	4307	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 8.1	 0.0; % COW
	4311	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 13.8	 0.0; % NG
	4311	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 15.0	 0.0; % COW
	4317	 22.0	 0.0	 25.0	 -25.0	 0.999999	 100.0	 1	 44.0	 0.0; % NG
	4321	 9.0	 0.0	 14.0	 -14.0	 1.000001	 100.0	 1	 18.0	 0.0; % PEL
	4322	 0.0	 -0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 4.0	 0.0; % NG
	4326	 0.0	 -0.48	 35.0	 -35.0	 1.0111115	 100.0	 0	 58.0	 0.0; % PEL
	4328	 5.5	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 11.0	 0.0; % NG
	4328	 0.0	 2.0	 2.0	 -2.0	 1.0079355	 100.0	 0	 6.0	 0.0; % NG
	4329	 19.5	 0.0	 24.0	 -24.0	 0.999999	 100.0	 1	 39.0	 0.0; % NG
	4339	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % PEL
	4339	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 33.0	 0.0; % PEL
	4347	 13.0	 1.95	 2.0	 1.9	 1.0000025	 100.0	 1	 26.0	 0.0; % PEL
	4354	 0.0	 0.0	 1.0	 0.9	 1.0000025	 100.0	 0	 11.0	 0.0; % NG
	4377	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 4.0	 0.0; % PEL
	4380	 8.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 16.0	 0.0; % NG
	4385	 0.0	 0.04	 1.0	 -1.0	 1.015872	 100.0	 0	 2.0	 0.0; % PEL
	4385	 0.0	 0.04	 1.0	 -1.0	 1.015872	 100.0	 0	 2.0	 0.0; % PEL
	4385	 0.0	 0.04	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % NG
	4394	 6.8	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 13.6	 0.0; % COW
	4414	 1.3	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 2.6	 0.0; % PEL
	4414	 8.95	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 17.9	 0.0; % PEL
	4415	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 6.0	 0.0; % NG
	4415	 5.125	 0.0	 0.0	 0.0	 1.0079355	 100.0	 1	 10.25	 0.0; % NG
	4416	 0.0	 1.0	 1.0	 -1.0	 1.015872	 100.0	 0	 3.0	 0.0; % PEL
	4431	 3.0	 0.0	 2.0	 -2.0	 1.0000025	 100.0	 1	 6.0	 0.0; % NG
	4449	 6.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 1	 12.0	 0.0; % NG
	4449	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 4.0	 0.0; % PEL
	4454	 14.95	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 29.9	 0.0; % COW
	4455	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 13.7	 0.0; % NG
	4473	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	4475	 0.0	 -0.93	 1.0	 -1.0	 1.0000025	 100.0	 0	 50.0	 0.0; % NG
	4476	 11.85	 0.73	 3.46	 -2.0	 0.975	 100.0	 1	 23.7	 0.0; % NG
	4477	 11.85	 2.0	 7.0	 -3.0	 0.975	 100.0	 1	 23.7	 0.0; % PEL
	4478	 11.85	 2.0	 7.0	 -3.0	 0.975	 100.0	 1	 23.7	 0.0; % PEL
	4479	 11.85	 2.0	 7.0	 -3.0	 0.975	 100.0	 1	 23.7	 0.0; % PEL
	4480	 11.85	 2.0	 7.0	 -3.0	 0.975	 100.0	 1	 23.7	 0.0; % PEL
	4493	 0.0	 2.22	 15.0	 -15.0	 1.0158755	 100.0	 0	 21.4	 0.0; % PEL
	4506	 0.0	 0.98	 16.0	 -14.0	 1.015872	 100.0	 0	 31.0	 0.0; % PEL
	4509	 10.5	 1.1	 6.7	 -4.5	 0.975	 100.0	 1	 21.0	 0.0; % PEL
	4509	 10.5	 1.0	 6.0	 -4.0	 0.975	 100.0	 1	 21.0	 0.0; % PEL
	4513	 43.5	 0.87	 26.1	 -24.36	 1.044445	 100.0	 1	 87.0	 0.0; % COW
	4535	 0.0	 -1.95	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	4535	 0.0	 -1.95	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	4535	 0.0	 -1.95	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	4535	 0.0	 -1.95	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	4535	 0.0	 -1.95	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % PEL
	4564	 11.0	 0.0	 7.1	 -7.1	 1.0000025	 100.0	 1	 22.0	 0.0; % COW
	4568	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 11.7	 0.0; % NG
	4571	 44.5	 9.0	 27.0	 -9.0	 1.0377785	 100.0	 1	 45.0	 44.0; % NG
	4571	 44.5	 9.0	 27.0	 -9.0	 1.0377785	 100.0	 1	 45.0	 44.0; % NG
	4579	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	4580	 0.0	 1.37	 10.0	 -10.0	 0.999999	 100.0	 0	 16.8	 0.0; % NG
	4582	 3.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 6.0	 0.0; % NG
	4585	 0.0	 1.27	 5.0	 -5.0	 1.0000025	 100.0	 0	 12.7	 0.0; % NG
	4585	 6.35	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 12.7	 0.0; % NG
	4620	 18.4	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 36.8	 0.0; % NG
	4631	 4.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 8.0	 0.0; % NG
	4632	 0.0	 -0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	4633	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 4.0	 0.0; % NG
	4642	 15.75	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 31.5	 0.0; % NG
	4643	 16.5	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 33.0	 0.0; % PEL
	4648	 8.75	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 17.5	 0.0; % NG
	4654	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 9.0	 0.0; % NG
	4658	 5.75	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 11.5	 0.0; % NG
	4659	 17.5	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 35.0	 0.0; % PEL
	4666	 5.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 10.0	 0.0; % NG
	4666	 11.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 22.0	 0.0; % NG
	4672	 0.0	 -0.1	 0.1	 -0.1	 0.975	 100.0	 0	 3.0	 0.0; % PEL
	4672	 0.0	 -0.1	 0.1	 -0.1	 0.975	 100.0	 0	 1.0	 0.0; % PEL
	4672	 0.0	 -0.1	 0.1	 -0.1	 0.975	 100.0	 0	 5.0	 0.0; % COW
	4671	 0.0	 -0.1	 0.1	 -0.1	 0.975	 100.0	 0	 7.0	 0.0; % COW
	4672	 0.0	 -0.1	 0.1	 -0.1	 0.975	 100.0	 0	 7.0	 0.0; % PEL
	4672	 0.0	 -0.1	 0.1	 -0.1	 0.975	 100.0	 0	 3.0	 0.0; % NG
	4671	 10.5	 0.54	 1.18	 -0.1	 0.975	 100.0	 1	 32.0	 -11.0; % COW
	4685	 7.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 14.0	 0.0; % COW
	4700	 0.0	 0.04	 1.0	 -1.0	 1.015872	 100.0	 0	 1.0	 0.0; % NG
	4700	 0.0	 0.04	 1.0	 -1.0	 1.015872	 100.0	 0	 1.0	 0.0; % PEL
	4700	 0.0	 0.04	 1.0	 -1.0	 1.015872	 100.0	 0	 1.0	 0.0; % PEL
	4717	 0.0	 0.92	 1.0	 -1.0	 1.0000025	 100.0	 0	 11.5	 0.0; % NG
	4717	 0.0	 0.92	 1.0	 -1.0	 1.0000025	 100.0	 0	 11.5	 0.0; % NG
	4718	 0.0	 0.0	 1.0	 0.0	 1.0	 100.0	 0	 11.0	 0.0; % NG
	4718	 0.0	 -0.1	 0.1	 -0.1	 1.0	 100.0	 0	 2.5	 0.0; % PEL
	4719	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % NG
	4720	 5.0	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 10.0	 0.0; % NG
	4720	 7.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 15.0	 0.0; % NG
	4720	 0.0	 0.0	 1.0	 0.9	 1.0000025	 100.0	 0	 15.0	 0.0; % NG
	4755	 4.5	 0.0	 0.1	 -0.1	 1.0000025	 100.0	 1	 9.0	 0.0; % NG
	4756	 5.0	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 10.0	 0.0; % NG
	4756	 5.0	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 10.0	 0.0; % PEL
	4757	 5.0	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 10.0	 0.0; % NG
	4757	 5.0	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 10.0	 0.0; % NG
	4766	 15.0	 0.0	 10.0	 -10.0	 1.0233335	 100.0	 1	 30.0	 0.0; % PEL
	4769	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 3.3	 0.0; % NG
	4777	 0.0	 0.0	 1.0	 0.0	 1.0000025	 100.0	 0	 7.0	 0.0; % NG
	4782	 14.0	 0.0	 0.0	 0.0	 1.0000005	 100.0	 1	 28.0	 0.0; % PEL
	4788	 4.6	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 9.2	 0.0; % NG
	4793	 7.0	 0.0	 8.5	 -8.5	 0.999999	 100.0	 1	 14.0	 0.0; % NG
	4804	 13.5	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 27.0	 0.0; % NG
	4814	 10.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 20.0	 0.0; % NG
	4817	 3.2	 0.0	 0.64	 -0.64	 1.0158755	 100.0	 1	 6.4	 0.0; % COW
	4818	 8.0	 -0.45	 3.6	 -4.5	 0.975	 100.0	 1	 15.0	 1.0; % PEL
	4818	 7.5	 -0.5	 3.0	 -4.0	 0.975	 100.0	 1	 15.0	 0.0; % NG
	4819	 7.5	 -0.5	 3.0	 -4.0	 0.975	 100.0	 1	 15.0	 0.0; % NG
	4819	 8.0	 -0.45	 3.6	 -4.5	 0.975	 100.0	 1	 15.0	 1.0; % NG
	4824	 0.0	 -0.45	 70.0	 -70.0	 0.975	 100.0	 0	 150.0	 0.0; % NG
	4825	 75.0	 0.0	 70.0	 -70.0	 0.975	 100.0	 1	 150.0	 0.0; % COW
	4825	 75.0	 0.0	 70.0	 -70.0	 0.975	 100.0	 1	 150.0	 0.0; % COW
	4824	 75.0	 0.0	 70.0	 -70.0	 0.975	 100.0	 1	 150.0	 0.0; % NG
	4832	 0.0	 0.0	 0.0	 0.0	 0.984126	 100.0	 0	 34.0	 0.0; % PEL
	4832	 0.0	 0.0	 0.0	 0.0	 0.984126	 100.0	 0	 24.0	 0.0; % PEL
	4843	 0.0	 0.26	 5.5	 -5.5	 0.999999	 100.0	 0	 9.0	 0.0; % COW
	4851	 3.2	 0.0	 4.0	 -4.0	 0.9444445	 100.0	 1	 6.4	 0.0; % NG
	4851	 5.4	 0.0	 6.4	 -6.4	 0.9444445	 100.0	 1	 10.8	 0.0; % NG
	4864	 0.0	 -0.57	 6.8	 -6.8	 0.999999	 100.0	 0	 11.2	 0.0; % NG
	4864	 0.0	 5.28	 6.8	 -6.8	 0.999999	 100.0	 0	 11.2	 0.0; % NG
	4871	 11.0	 -2.5	 7.0	 -12.0	 1.033334	 100.0	 1	 22.0	 0.0; % NG
	4878	 6.4	 0.0	 7.7	 -7.7	 0.999999	 100.0	 1	 12.8	 0.0; % COW
	4882	 17.51	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 35.02	 0.0; % NG
	4882	 10.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 20.0	 0.0; % PEL
	4894	 0.0	 -1.0	 0.0	 -1.0	 1.0158755	 100.0	 0	 5.0	 0.0; % NG
	4898	 0.0	 0.0	 9.8	 -9.8	 0.999999	 100.0	 0	 15.9	 0.2; % NG
	4900	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 21.6	 0.0; % NG
	4900	 10.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 20.0	 0.0; % NG
	4900	 15.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 30.0	 0.0; % NG
	4920	 16.0	 2.0	 12.0	 -8.0	 1.015872	 100.0	 1	 32.0	 0.0; % NG
	4923	 16.5	 0.0	 12.0	 -12.0	 1.0000025	 100.0	 1	 33.0	 0.0; % NG
	4930	 10.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 20.0	 0.0; % NG
	4946	 4.8	 0.0	 6.0	 -6.0	 0.9444445	 100.0	 1	 9.6	 0.0; % NG
	4950	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 4.0	 0.0; % NG
	4963	 11.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 22.0	 0.0; % PEL
	4963	 12.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 24.0	 0.0; % COW
	4970	 0.0	 0.83	 18.0	 -18.0	 0.999999	 100.0	 0	 30.0	 0.0; % NG
	4970	 15.0	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 30.0	 0.0; % PEL
	4983	 16.0	 -1.0	 16.0	 -18.0	 0.999999	 100.0	 1	 32.0	 0.0; % NG
	4984	 17.55	 -4.5	 12.0	 -21.0	 0.975	 100.0	 1	 35.1	 0.0; % PEL
	4985	 17.55	 -4.5	 12.0	 -21.0	 0.975	 100.0	 1	 35.1	 0.0; % NG
	4986	 17.55	 -4.5	 12.0	 -21.0	 0.975	 100.0	 1	 35.1	 0.0; % COW
	4993	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % PEL
	4994	 15.25	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 30.5	 0.0; % COW
	5012	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	5012	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 20.0	 0.0; % PEL
	5014	 10.35	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 20.7	 0.0; % NG
	5020	 9.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 18.0	 0.0; % NG
	5024	 18.0	 3.95	 4.0	 3.9	 1.000001	 100.0	 1	 36.0	 0.0; % NG
	5030	 25.3	 0.505	 15.18	 -14.17	 1.0000025	 100.0	 1	 50.6	 0.0; % NG
	5038	 0.0	 -3.46	 11.0	 -11.0	 0.999999	 100.0	 0	 18.0	 0.0; % NG
	5039	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	5041	 0.0	 1.3	 5.0	 -5.0	 1.0000025	 100.0	 0	 15.0	 0.0; % NG
	5041	 0.0	 0.57	 5.0	 -5.0	 1.0000025	 100.0	 0	 15.0	 0.0; % NG
	5043	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 24.0	 0.0; % NG
	5043	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 16.0	 0.0; % NG
	5047	 0.0	 0.0	 0.0	 0.0	 1.0277795	 100.0	 0	 36.0	 0.0; % COW
	5049	 0.0	 -0.01	 0.0	 -0.01	 1.0158755	 100.0	 0	 5.6	 0.0; % NG
	5049	 0.0	 -0.01	 0.0	 -0.01	 1.0158755	 100.0	 0	 5.6	 0.0; % COW
	5055	 0.0	 0.0	 0.0	 0.0	 1.033333	 100.0	 0	 3.0	 0.0; % PEL
	5959	 0.0	 -6.05	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % NG
	5959	 0.0	 -6.05	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % NG
	5959	 0.0	 -6.05	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % NG
	5960	 0.0	 2.05	 125.0	 -125.0	 0.975	 100.0	 0	 670.0	 0.0; % COW
	5960	 0.0	 2.05	 125.0	 -125.0	 0.975	 100.0	 0	 670.0	 0.0; % NG
	5962	 0.0	 0.0	 100.0	 -100.0	 0.975	 100.0	 0	 250.0	 50.0; % NG
	5963	 700.0	 70.0	 470.0	 -330.0	 0.975	 100.0	 1	 1100.0	 300.0; % COW
	5963	 700.0	 70.0	 470.0	 -330.0	 0.975	 100.0	 1	 1100.0	 300.0; % COW
	5965	 0.0	 -3.43	 60.0	 -60.0	 0.975	 100.0	 0	 200.0	 -20.0; % NG
	5966	 0.0	 -17.08	 60.0	 -60.0	 0.975	 100.0	 0	 200.0	 -20.0; % COW
	5968	 0.0	 0.0	 0.0	 0.0	 0.975	 100.0	 0	 1500.0	 0.0; % NUC
	5968	 0.0	 0.0	 0.0	 0.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	5969	 0.0	 0.0	 0.84	 0.0	 0.975	 100.0	 0	 0.0	 -0.28; % SYNC
	5969	 0.0	 0.0	 0.84	 0.0	 0.975	 100.0	 0	 0.0	 -0.28; % SYNC
	5973	 275.0	 -40.0	 300.0	 -380.0	 0.975	 100.0	 1	 500.0	 50.0; % COW
	5976	 29.58	 -4.82	 17.75	 -27.39	 0.975	 100.0	 1	 59.16	 0.0; % PEL
	5976	 29.58	 -4.82	 17.75	 -27.39	 0.975	 100.0	 1	 59.16	 0.0; % PEL
	5984	 0.0	 10.25	 100.0	 -100.0	 0.975	 100.0	 0	 250.0	 -250.0; % NG
	5984	 0.0	 10.25	 100.0	 -100.0	 0.975	 100.0	 0	 250.0	 -250.0; % NG
	5987	 0.0	 -4.89	 40.0	 -40.0	 0.975	 100.0	 0	 30.0	 0.0; % NG
	5987	 0.0	 -4.89	 40.0	 -40.0	 0.975	 100.0	 0	 60.0	 0.0; % NG
	5989	 225.0	 0.0	 200.0	 -200.0	 0.975	 100.0	 1	 450.0	 0.0; % PEL
	5989	 225.0	 0.0	 200.0	 -200.0	 0.975	 100.0	 1	 450.0	 0.0; % COW
	5998	 0.0	 85.83	 90.0	 0.0	 0.975	 100.0	 0	 0.0	 -53.0; % SYNC
	5998	 0.0	 85.83	 90.0	 0.0	 0.975	 100.0	 0	 0.0	 -16.0; % SYNC
	6003	 0.0	 -3.01	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % NUC
	6003	 0.0	 -3.01	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % NG
	6003	 0.0	 -3.01	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6003	 0.0	 -3.01	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6003	 0.0	 -3.01	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6003	 0.0	 -3.01	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6004	 81.535	 9.71	 68.34	 -48.92	 0.975	 100.0	 1	 163.07	 0.0; % NG
	6004	 132.685	 0.0	 79.61	 -79.61	 0.975	 100.0	 1	 265.37	 0.0; % NG
	6004	 57.735	 16.85	 68.34	 -34.64	 0.975	 100.0	 1	 115.47	 0.0; % COW
	6007	 204.21	 -3.995	 122.53	 -130.52	 0.975	 100.0	 1	 408.42	 0.0; % NG
	6010	 0.0	 0.0	 280.0	 -280.0	 0.975	 100.0	 0	 600.0	 300.0; % COW
	6011	 0.0	 -60.67	 280.0	 -280.0	 0.975	 100.0	 0	 500.0	 0.0; % NG
	6015	 301.5	 66.5	 304.0	 -171.0	 0.975	 100.0	 1	 418.0	 185.0; % NG
	6015	 0.0	 0.0	 304.0	 -171.0	 0.975	 100.0	 0	 418.0	 185.0; % COW
	6015	 0.0	 0.0	 304.0	 -171.0	 0.975	 100.0	 0	 379.0	 230.0; % NG
	6015	 279.0	 98.0	 367.0	 -171.0	 0.975	 100.0	 1	 393.0	 165.0; % COW
	6023	 0.0	 -4.64	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6022	 78.805	 -21.74	 47.28	 -90.76	 0.975	 100.0	 1	 157.61	 0.0; % NG
	6024	 137.35	 0.0	 82.41	 -82.41	 0.975	 100.0	 1	 274.7	 0.0; % NG
	6027	 259.14	 0.0	 155.48	 -155.48	 0.975	 100.0	 1	 518.28	 0.0; % NG
	6028	 0.0	 2.92	 7.0	 0.0	 0.975	 100.0	 0	 0.0	 -1.0; % SYNC
	6030	 653.0	 235.0	 570.0	 -100.0	 0.975	 100.0	 1	 1056.0	 250.0; % NUC
	6030	 0.0	 0.0	 523.0	 -125.0	 0.975	 100.0	 0	 1056.0	 200.0; % COW
	6030	 304.0	 84.0	 263.0	 -95.0	 0.975	 100.0	 1	 412.0	 196.0; % NG
	6030	 304.0	 72.5	 240.0	 -95.0	 0.975	 100.0	 1	 412.0	 196.0; % NG
	6041	 350.0	 142.5	 400.0	 -115.0	 0.975	 100.0	 1	 600.0	 100.0; % COW
	6046	 0.0	 -6.42	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6050	 0.0	 0.0	 1.23	 0.0	 0.975	 100.0	 0	 0.0	 -4.02; % SYNC
	6056	 202.5	 0.0	 121.5	 -121.5	 0.975	 100.0	 1	 405.0	 0.0; % NG
	6059	 546.385	 0.0	 327.83	 -327.83	 0.975	 100.0	 1	 1092.77	 0.0; % COW
	6067	 675.0	 70.0	 355.0	 -215.0	 0.975	 100.0	 1	 1050.0	 300.0; % NUC
	6067	 605.0	 70.0	 355.0	 -215.0	 0.975	 100.0	 1	 910.0	 300.0; % COW
	6067	 605.0	 70.0	 355.0	 -215.0	 0.975	 100.0	 1	 910.0	 300.0; % NUC
	6070	 0.0	 -6.38	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6071	 0.0	 -4.45	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6084	 0.0	 -6.36	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % NUC
	6085	 0.0	 -4.49	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6089	 0.0	 -4.43	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6090	 0.0	 -4.52	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6091	 89.0	 5.3	 64.0	 -53.4	 0.975	 100.0	 1	 178.0	 0.0; % NG
	6093	 0.0	 -4.01	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % NUC
	6094	 27.5	 15.75	 48.0	 -16.5	 0.975	 100.0	 1	 55.0	 0.0; % NG
	6093	 4.5	 0.0	 2.7	 -2.7	 0.975	 100.0	 1	 9.0	 0.0; % NG
	6093	 0.0	 -0.5	 0.0	 -0.5	 0.975	 100.0	 0	 0.0	 -1.0; % SYNC
	6096	 0.0	 81.06	 85.31	 0.0	 0.975	 100.0	 0	 0.0	 -142.21; % SYNC
	6095	 70.45	 0.0	 42.27	 -42.27	 0.975	 100.0	 1	 140.9	 0.0; % COW
	6104	 612.365	 0.0	 367.42	 -367.42	 0.975	 100.0	 1	 1224.73	 0.0; % COW
	6105	 225.0	 0.0	 200.0	 -200.0	 0.975	 100.0	 1	 450.0	 0.0; % NG
	6107	 0.0	 -9.71	 0.0	 -9.71	 0.975	 100.0	 0	 0.0	 -276.44; % SYNC
	6114	 33.0	 0.0	 19.8	 -19.8	 0.975	 100.0	 1	 66.0	 0.0; % COW
	6113	 74.0	 0.0	 44.4	 -44.4	 0.975	 100.0	 1	 148.0	 0.0; % COW
	6114	 73.5	 0.0	 44.1	 -44.1	 0.975	 100.0	 1	 147.0	 0.0; % NG
	6113	 0.0	 -5.24	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6116	 0.0	 -4.15	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % NUC
	6116	 200.5	 0.0	 120.3	 -120.3	 0.975	 100.0	 1	 401.0	 0.0; % NG
	6118	 0.0	 -1.37	 0.0	 -1.37	 0.975	 100.0	 0	 0.0	 -5.72; % SYNC
	6127	 369.0	 0.0	 221.4	 -221.4	 0.975	 100.0	 1	 738.0	 0.0; % COW
	6131	 512.405	 0.0	 300.0	 -300.0	 0.975	 100.0	 1	 1024.81	 0.0; % COW
	6133	 0.0	 -5.84	 0.52	 -5.84	 0.975	 100.0	 0	 1.73	 0.0; % NG
	6134	 93.0	 0.0	 55.8	 -55.8	 0.975	 100.0	 1	 186.0	 0.0; % NG
	6134	 94.5	 0.0	 56.7	 -56.7	 0.975	 100.0	 1	 189.0	 0.0; % NG
	6135	 0.0	 0.75	 182.0	 -252.0	 0.975	 100.0	 0	 280.0	 -280.0; % NG
	6135	 0.0	 0.75	 182.0	 -252.0	 0.975	 100.0	 0	 280.0	 -280.0; % NG
	6135	 0.0	 0.75	 182.0	 -252.0	 0.975	 100.0	 0	 280.0	 -280.0; % COW
	6135	 0.0	 0.75	 182.0	 -252.0	 0.975	 100.0	 0	 280.0	 -280.0; % NG
	6140	 231.0	 0.0	 138.6	 -138.6	 0.975	 100.0	 1	 462.0	 0.0; % COW
	6140	 83.0	 0.0	 49.8	 -49.8	 0.975	 100.0	 1	 166.0	 0.0; % NG
	6140	 27.5	 15.25	 47.0	 -16.5	 0.975	 100.0	 1	 55.0	 0.0; % PEL
	6140	 48.0	 9.1	 47.0	 -28.8	 0.975	 100.0	 1	 96.0	 0.0; % NG
	6140	 34.5	 13.15	 47.0	 -20.7	 0.975	 100.0	 1	 69.0	 0.0; % NG
	6147	 0.0	 -4.8	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % NUC
	6158	 0.0	 -7.27	 0.0	 -7.27	 0.975	 100.0	 0	 0.0	 -95.84; % SYNC
	6158	 0.0	 -7.27	 0.0	 -7.27	 0.975	 100.0	 0	 0.0	 -95.84; % SYNC
	6159	 0.0	 -6.41	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6161	 0.0	 -4.78	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6163	 181.055	 0.0	 108.63	 -108.63	 0.975	 100.0	 1	 362.11	 0.0; % NG
	6163	 108.04	 0.0	 64.82	 -64.82	 0.975	 100.0	 1	 216.08	 0.0; % COW
	6166	 23.7	 0.0	 14.22	 -14.22	 0.975	 100.0	 1	 47.4	 0.0; % NG
	6166	 23.7	 0.0	 14.22	 -14.22	 0.975	 100.0	 1	 47.4	 0.0; % PEL
	6173	 1341.385	 0.0	 804.83	 -804.83	 0.975	 100.0	 1	 2682.77	 0.0; % COW
	6174	 0.0	 -1.45	 0.0	 -1.45	 0.975	 100.0	 0	 0.0	 -17.81; % SYNC
	6175	 2.81	 7.855	 17.39	 -1.68	 0.975	 100.0	 1	 5.62	 0.0; % NG
	6175	 2.81	 7.855	 17.39	 -1.68	 0.975	 100.0	 1	 5.62	 0.0; % NG
	6177	 0.0	 -6.45	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6180	 0.0	 0.0	 343.0	 -169.0	 0.975	 100.0	 0	 396.0	 223.0; % NG
	6185	 0.0	 98.19	 200.0	 -200.0	 0.975	 100.0	 0	 300.0	 -30.0; % COW
	6189	 101.795	 0.0	 61.08	 -61.08	 0.975	 100.0	 1	 203.59	 0.0; % NG
	6189	 103.41	 0.0	 62.05	 -62.05	 0.975	 100.0	 1	 206.82	 0.0; % NG
	6190	 0.0	 6.1	 10.84	 0.0	 0.975	 100.0	 0	 0.0	 -5.38; % SYNC
	6194	 0.0	 -3.02	 300.0	 -300.0	 0.975	 100.0	 0	 770.0	 0.0; % COW
	6194	 0.0	 -3.02	 300.0	 -300.0	 0.975	 100.0	 0	 770.0	 0.0; % NUC
	6195	 0.0	 45.36	 49.86	 0.0	 0.975	 100.0	 0	 0.0	 -455.19; % SYNC
	6195	 0.0	 45.36	 49.86	 0.0	 0.975	 100.0	 0	 0.0	 -455.19; % SYNC
	6195	 0.0	 45.36	 49.86	 0.0	 0.975	 100.0	 0	 0.0	 -455.19; % SYNC
	6196	 100.0	 0.0	 100.0	 -100.0	 0.975	 100.0	 1	 200.0	 0.0; % NG
	6197	 0.0	 -4.71	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6197	 0.0	 -99.91	 0.0	 -99.91	 0.975	 100.0	 0	 0.0	 -13.86; % SYNC
	6213	 0.0	 -6.47	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6216	 0.0	 0.0	 355.0	 -215.0	 0.975	 100.0	 0	 910.0	 300.0; % COW
	6217	 0.0	 -2.09	 99.0	 -99.0	 0.975	 100.0	 0	 330.0	 0.0; % COW
	6217	 0.0	 -2.09	 99.0	 -99.0	 0.975	 100.0	 0	 330.0	 0.0; % NG
	6217	 0.0	 -4.35	 216.0	 -216.0	 0.975	 100.0	 0	 720.0	 0.0; % COW
	6219	 0.0	 -4.47	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % NG
	6219	 0.0	 43.08	 47.55	 0.0	 0.975	 100.0	 0	 0.0	 -278.77; % SYNC
	6219	 125.0	 0.0	 120.0	 -120.0	 0.975	 100.0	 1	 250.0	 0.0; % NG
	6219	 0.0	 43.08	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % NG
	6219	 125.0	 0.0	 120.0	 -120.0	 0.975	 100.0	 1	 250.0	 0.0; % NG
	6219	 0.0	 -4.47	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % NG
	6219	 0.0	 -4.47	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % COW
	6220	 321.0	 142.5	 400.0	 -115.0	 0.975	 100.0	 1	 642.0	 0.0; % COW
	6222	 0.0	 6.67	 10.16	 -0.31	 0.975	 100.0	 0	 1.03	 0.0; % PEL
	6223	 700.0	 70.0	 470.0	 -330.0	 0.975	 100.0	 1	 1100.0	 300.0; % COW
	6227	 73.93	 0.0	 44.36	 -44.36	 0.975	 100.0	 1	 147.86	 0.0; % COW
	6230	 0.0	 0.0	 0.48	 0.0	 0.975	 100.0	 0	 0.0	 -76.5; % SYNC
	6230	 0.0	 0.0	 0.48	 0.0	 0.975	 100.0	 0	 0.0	 -76.5; % SYNC
	6232	 41.745	 15.01	 55.07	 -25.05	 0.975	 100.0	 1	 83.49	 0.0; % NG
	6232	 41.745	 15.01	 55.07	 -25.05	 0.975	 100.0	 1	 83.49	 0.0; % NG
	6240	 183.38	 0.0	 110.03	 -110.03	 0.975	 100.0	 1	 366.76	 0.0; % NG
	6246	 0.0	 -6.21	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6248	 625.0	 -14.0	 515.0	 -543.0	 0.975	 100.0	 1	 970.0	 280.0; % NUC
	6248	 285.0	 -44.0	 206.0	 -294.0	 0.975	 100.0	 1	 370.0	 200.0; % NG
	6248	 285.0	 -44.0	 206.0	 -294.0	 0.975	 100.0	 1	 370.0	 200.0; % NG
	6256	 448.3	 52.615	 269.67	 -164.44	 0.975	 100.0	 1	 683.3	 213.3; % COW
	6257	 0.0	 0.0	 269.33	 -111.09	 0.975	 100.0	 0	 700.0	 140.0; % COW
	6258	 13.5	 4.515	 22.36	 -13.33	 0.975	 100.0	 1	 27.0	 0.0; % NG
	6259	 43.0	 20.295	 44.04	 -3.45	 0.975	 100.0	 1	 86.0	 0.0; % NG
	6260	 0.0	 1.08	 22.19	 -3.23	 0.975	 100.0	 0	 49.0	 0.0; % NG
	6261	 16.0	 1.705	 10.21	 -6.8	 0.975	 100.0	 1	 32.0	 0.0; % NG
	6262	 16.0	 1.705	 10.21	 -6.8	 0.975	 100.0	 1	 32.0	 0.0; % PEL
	6263	 16.0	 1.545	 9.89	 -6.8	 0.975	 100.0	 1	 32.0	 0.0; % NG
	6264	 16.0	 1.545	 9.89	 -6.8	 0.975	 100.0	 1	 32.0	 0.0; % NG
	6265	 46.0	 14.82	 59.82	 -30.18	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6266	 46.0	 14.82	 59.82	 -30.18	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6267	 46.0	 17.7	 62.7	 -27.3	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6268	 46.0	 17.7	 62.7	 -27.3	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6269	 46.0	 12.5	 62.7	 -37.7	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6270	 46.0	 13.715	 62.7	 -35.27	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6271	 589.92	 -38.37	 341.76	 -418.5	 0.975	 100.0	 1	 934.92	 244.92; % COW
	6272	 631.89	 -27.81	 351.94	 -407.56	 0.975	 100.0	 1	 976.89	 286.89; % COW
	6273	 614.92	 -32.13	 344.05	 -408.31	 0.975	 100.0	 1	 974.92	 254.92; % COW
	6274	 591.92	 -37.99	 342.1	 -418.08	 0.975	 100.0	 1	 936.92	 246.92; % COW
	6276	 204.0	 31.78	 164.82	 -101.26	 0.975	 100.0	 1	 252.0	 156.0; % NG
	6277	 202.0	 31.955	 164.82	 -100.91	 0.975	 100.0	 1	 250.0	 154.0; % NG
	6278	 202.0	 22.52	 101.23	 -56.19	 0.975	 100.0	 1	 250.0	 154.0; % NG
	6279	 213.5	 42.55	 245.17	 -160.07	 0.975	 100.0	 1	 305.0	 122.0; % NG
	6280	 0.0	 0.0	 102.26	 -66.49	 0.975	 100.0	 0	 155.0	 89.0; % COW
	6281	 29.0	 -0.45	 19.65	 -20.55	 0.975	 100.0	 1	 58.0	 0.0; % PEL
	6282	 29.0	 -0.1	 12.29	 -12.49	 0.975	 100.0	 1	 58.0	 0.0; % PEL
	6283	 29.0	 -0.45	 19.65	 -20.55	 0.975	 100.0	 1	 58.0	 0.0; % PEL
	6284	 29.0	 -0.1	 12.29	 -12.49	 0.975	 100.0	 1	 58.0	 0.0; % NG
	6285	 29.0	 -0.1	 12.29	 -12.49	 0.975	 100.0	 1	 58.0	 0.0; % NG
	6286	 198.0	 45.885	 173.05	 -81.28	 0.975	 100.0	 1	 263.0	 133.0; % NG
	6287	 16.0	 4.37	 22.37	 -13.63	 0.975	 100.0	 1	 32.0	 0.0; % NG
	6288	 16.0	 2.335	 20.37	 -15.7	 0.975	 100.0	 1	 32.0	 0.0; % NG
	6289	 16.0	 3.82	 22.21	 -14.57	 0.975	 100.0	 1	 32.0	 0.0; % PEL
	6290	 600.97	 162.755	 552.2	 -226.69	 0.975	 100.0	 1	 935.97	 265.97; % COW
	6291	 602.77	 166.03	 555.68	 -223.62	 0.975	 100.0	 1	 937.77	 267.77; % NUC
	6292	 598.96	 149.145	 520.68	 -222.39	 0.975	 100.0	 1	 923.96	 273.96; % COW
	6293	 592.76	 149.315	 521.4	 -222.77	 0.975	 100.0	 1	 917.76	 267.76; % COW
	6294	 813.0	 218.085	 673.87	 -237.7	 0.975	 100.0	 1	 1308.0	 318.0; % NUC
	6295	 813.0	 218.085	 673.87	 -237.7	 0.975	 100.0	 1	 1308.0	 318.0; % COW
	6296	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % PEL
	6297	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % PEL
	6298	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % NG
	6299	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % NG
	6300	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % PEL
	6301	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % NG
	6302	 10.0	 1.73	 10.77	 -7.31	 0.975	 100.0	 1	 20.0	 0.0; % NG
	6303	 10.0	 1.73	 10.77	 -7.31	 0.975	 100.0	 1	 20.0	 0.0; % COW
	6304	 833.5	 226.955	 703.47	 -249.56	 0.975	 100.0	 1	 1330.0	 337.0; % NUC
	6305	 863.5	 235.535	 712.05	 -240.98	 0.975	 100.0	 1	 1360.0	 367.0; % NUC
	6306	 863.5	 235.535	 712.05	 -240.98	 0.975	 100.0	 1	 1360.0	 367.0; % COW
	6307	 47.5	 10.18	 53.63	 -33.27	 0.975	 100.0	 1	 95.0	 0.0; % NG
	6308	 1.45	 91.015	 285.21	 -103.18	 0.975	 100.0	 1	 1.5	 1.4; % PEL
	6309	 587.38	 172.985	 503.57	 -157.6	 0.975	 100.0	 1	 942.38	 232.38; % COW
	6311	 596.4	 192.69	 536.07	 -150.69	 0.975	 100.0	 1	 951.4	 241.4; % COW
	6312	 593.4	 201.74	 554.99	 -151.51	 0.975	 100.0	 1	 948.4	 238.4; % NG
	6313	 953.0	 217.35	 657.68	 -222.98	 0.975	 100.0	 1	 1503.0	 403.0; % COW
	6314	 953.0	 217.35	 657.68	 -222.98	 0.975	 100.0	 1	 1503.0	 403.0; % COW
	6315	 948.0	 -28.08	 390.29	 -446.45	 0.975	 100.0	 1	 1498.0	 398.0; % COW
	6316	 948.0	 -38.82	 368.81	 -446.45	 0.975	 100.0	 1	 1498.0	 398.0; % COW
	6317	 66.75	 21.35	 93.6	 -50.9	 0.975	 100.0	 1	 125.0	 8.5; % COW
	6318	 66.75	 21.35	 93.6	 -50.9	 0.975	 100.0	 1	 125.0	 8.5; % NG
	6319	 76.2	 35.07	 72.7	 -2.56	 0.975	 100.0	 1	 148.2	 4.2; % NG
	6320	 0.0	 0.0	 328.92	 -51.66	 0.975	 100.0	 0	 685.0	 180.0; % NG
	6321	 460.0	 94.405	 359.66	 -170.85	 0.975	 100.0	 1	 610.0	 310.0; % COW
	6322	 460.0	 55.15	 323.14	 -212.84	 0.975	 100.0	 1	 610.0	 310.0; % NG
	6324	 0.0	 0.0	 380.92	 -216.75	 0.975	 100.0	 0	 700.0	 205.0; % COW
	6325	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % COW
	6326	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6327	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6328	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6329	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6330	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6331	 640.0	 196.325	 521.6	 -128.95	 0.975	 100.0	 1	 1000.0	 280.0; % COW
	6332	 640.0	 196.325	 521.6	 -128.95	 0.975	 100.0	 1	 1000.0	 280.0; % COW
	6333	 640.0	 218.295	 566.43	 -129.84	 0.975	 100.0	 1	 1000.0	 280.0; % COW
	6334	 605.0	 208.07	 565.46	 -149.32	 0.975	 100.0	 1	 930.0	 280.0; % NUC
	6335	 28.5	 4.565	 21.89	 -12.76	 0.975	 100.0	 1	 57.0	 0.0; % COW
	6336	 28.5	 4.565	 21.89	 -12.76	 0.975	 100.0	 1	 57.0	 0.0; % NG
	6337	 0.0	 0.0	 320.29	 -95.56	 0.975	 100.0	 0	 451.0	 239.0; % COW
	6338	 0.0	 0.0	 63.51	 -8.25	 0.975	 100.0	 0	 63.0	 21.0; % NG
	6339	 341.3	 54.86	 274.22	 -164.5	 0.975	 100.0	 1	 433.8	 248.8; % NG
	6340	 582.69	 187.52	 526.3	 -151.26	 0.975	 100.0	 1	 927.69	 237.69; % NUC
	6341	 582.69	 187.52	 526.3	 -151.26	 0.975	 100.0	 1	 927.69	 237.69; % COW
	6342	 589.69	 188.875	 527.1	 -149.35	 0.975	 100.0	 1	 934.69	 244.69; % NG
	6343	 604.695	 191.875	 528.95	 -145.2	 0.975	 100.0	 1	 949.7	 259.69; % NUC
	6344	 0.0	 -5.12	 10.38	 -6.6	 0.975	 100.0	 0	 32.0	 0.0; % NG
	6345	 860.0	 -28.245	 407.48	 -463.97	 0.975	 100.0	 1	 1380.0	 340.0; % COW
	6346	 860.0	 -28.245	 407.48	 -463.97	 0.975	 100.0	 1	 1380.0	 340.0; % NG
	6347	 15.75	 4.47	 22.47	 -13.53	 0.975	 100.0	 1	 31.5	 0.0; % NG
	6348	 32.5	 7.34	 37.34	 -22.66	 0.975	 100.0	 1	 65.0	 0.0; % NG
	6349	 35.0	 0.32	 22.34	 -21.7	 0.975	 100.0	 1	 70.0	 0.0; % PEL
	6350	 32.5	 10.38	 55.38	 -34.62	 0.975	 100.0	 1	 65.0	 0.0; % PEL
	6351	 35.0	 9.63	 39.63	 -20.37	 0.975	 100.0	 1	 70.0	 0.0; % PEL
	6352	 798.0	 36.21	 566.82	 -494.4	 0.975	 100.0	 1	 1308.0	 288.0; % NUC
	6353	 798.0	 36.21	 566.82	 -494.4	 0.975	 100.0	 1	 1308.0	 288.0; % PEL
	6354	 273.76	 84.835	 286.78	 -117.11	 0.975	 100.0	 1	 458.26	 89.26; % NG
	6355	 18.0	 -1.11	 10.34	 -12.56	 0.975	 100.0	 1	 36.0	 0.0; % NG
	6356	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % NUC
	6357	 607.0	 190.895	 527.89	 -146.1	 0.975	 100.0	 1	 947.0	 267.0; % COW
	6358	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % COW
	6359	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % COW
	6360	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % COW
	6361	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % COW
	6362	 197.5	 60.46	 132.48	 -11.56	 0.975	 100.0	 1	 255.0	 140.0; % NG
	6363	 0.0	 0.0	 262.39	 -135.97	 0.975	 100.0	 0	 446.0	 206.0; % COW
	6364	 195.0	 33.755	 166.41	 -98.9	 0.975	 100.0	 1	 260.0	 130.0; % NG
	6365	 0.0	 0.0	 280.73	 -126.32	 0.975	 100.0	 0	 585.0	 250.0; % COW
	6366	 0.0	 0.0	 287.58	 -119.25	 0.975	 100.0	 0	 585.0	 250.0; % COW
	6368	 28.5	 12.31	 32.55	 -7.93	 0.975	 100.0	 1	 57.0	 0.0; % NG
	6369	 8.0	 6.455	 20.13	 -7.22	 0.975	 100.0	 1	 31.0	 -15.0; % PEL
	6370	 9.75	 1.46	 7.83	 -4.91	 0.975	 100.0	 1	 19.5	 0.0; % NG
	6371	 9.75	 1.46	 7.83	 -4.91	 0.975	 100.0	 1	 19.5	 0.0; % PEL
	6372	 10.5	 1.405	 8.32	 -5.51	 0.975	 100.0	 1	 21.0	 0.0; % PEL
	6373	 17.5	 -0.555	 6.13	 -7.24	 0.975	 100.0	 1	 35.0	 0.0; % NG
	6374	 17.5	 -0.555	 6.13	 -7.24	 0.975	 100.0	 1	 35.0	 0.0; % NG
	6375	 17.5	 -0.15	 11.43	 -11.73	 0.975	 100.0	 1	 35.0	 0.0; % NG
	6376	 17.5	 -0.555	 6.13	 -7.24	 0.975	 100.0	 1	 35.0	 0.0; % COW
	6377	 192.5	 0.99	 115.63	 -113.65	 0.975	 100.0	 1	 250.0	 135.0; % COW
	6378	 23.5	 2.37	 10.25	 -5.51	 0.975	 100.0	 1	 47.0	 0.0; % PEL
	6379	 36.5	 10.17	 51.92	 -31.58	 0.975	 100.0	 1	 73.0	 0.0; % NG
	6380	 34.5	 13.355	 55.2	 -28.49	 0.975	 100.0	 1	 69.0	 0.0; % NG
	6381	 38.0	 11.28	 51.28	 -28.72	 0.975	 100.0	 1	 76.0	 0.0; % PEL
	6382	 38.75	 10.505	 51.13	 -30.12	 0.975	 100.0	 1	 77.5	 0.0; % NG
	6383	 15.5	 2.31	 15.29	 -10.67	 0.975	 100.0	 1	 31.0	 0.0; % NG
	6384	 15.5	 2.31	 15.29	 -10.67	 0.975	 100.0	 1	 31.0	 0.0; % NG
	6385	 15.5	 2.37	 15.41	 -10.67	 0.975	 100.0	 1	 31.0	 0.0; % PEL
	6386	 25.0	 8.315	 32.2	 -15.57	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6387	 193.5	 68.455	 170.47	 -33.56	 0.975	 100.0	 1	 250.0	 137.0; % NG
	6388	 193.5	 68.455	 170.47	 -33.56	 0.975	 100.0	 1	 250.0	 137.0; % NG
	6389	 9.5	 1.75	 10.62	 -7.12	 0.975	 100.0	 1	 19.0	 0.0; % NG
	6390	 310.9	 26.99	 215.24	 -161.26	 0.975	 100.0	 1	 419.9	 201.9; % NG
	6391	 26.0	 10.215	 39.82	 -19.39	 0.975	 100.0	 1	 52.0	 0.0; % NG
	6392	 26.0	 10.215	 39.82	 -19.39	 0.975	 100.0	 1	 52.0	 0.0; % NG
	6393	 0.0	 0.0	 104.23	 -23.38	 0.975	 100.0	 0	 185.0	 5.0; % NG
	6394	 0.0	 0.0	 104.23	 -23.38	 0.975	 100.0	 0	 185.0	 5.0; % NG
	6395	 32.5	 12.59	 79.87	 -54.69	 0.975	 100.0	 1	 65.0	 0.0; % PEL
	6396	 32.5	 12.59	 79.87	 -54.69	 0.975	 100.0	 1	 65.0	 0.0; % NG
	6397	 593.5	 182.745	 511.82	 -146.33	 0.975	 100.0	 1	 950.0	 237.0; % NG
	6398	 593.5	 193.685	 533.7	 -146.33	 0.975	 100.0	 1	 950.0	 237.0; % COW
	6399	 242.0	 22.125	 194.0	 -149.75	 0.975	 100.0	 1	 316.0	 168.0; % COW
	6400	 0.0	 0.0	 194.29	 -148.96	 0.975	 100.0	 0	 304.0	 156.0; % COW
	6401	 824.5	 229.315	 671.92	 -213.29	 0.975	 100.0	 1	 1360.0	 289.0; % COW
	6402	 30.5	 2.34	 28.9	 -24.22	 0.975	 100.0	 1	 61.0	 0.0; % PEL
	6403	 30.5	 2.34	 28.9	 -24.22	 0.975	 100.0	 1	 61.0	 0.0; % NG
	6404	 17.5	 6.57	 23.24	 -10.1	 0.975	 100.0	 1	 35.0	 0.0; % NG
	6405	 865.0	 235.84	 706.84	 -235.16	 0.975	 100.0	 1	 1380.0	 350.0; % COW
	6406	 865.0	 235.84	 706.84	 -235.16	 0.975	 100.0	 1	 1380.0	 350.0; % COW
	6407	 865.0	 230.335	 695.83	 -235.16	 0.975	 100.0	 1	 1380.0	 350.0; % NG
	6408	 820.0	 210.31	 681.31	 -260.69	 0.975	 100.0	 1	 1290.0	 350.0; % COW
	6409	 25.9	 13.51	 37.51	 -10.49	 0.975	 100.0	 1	 51.0	 0.8; % NG
	6410	 860.0	 234.135	 675.48	 -207.21	 0.975	 100.0	 1	 1380.0	 340.0; % COW
	6411	 860.0	 234.135	 675.48	 -207.21	 0.975	 100.0	 1	 1380.0	 340.0; % COW
	6412	 0.0	 0.0	 322.12	 -100.08	 0.975	 100.0	 0	 585.0	 175.0; % COW
	6413	 0.0	 0.0	 322.12	 -100.08	 0.975	 100.0	 0	 585.0	 175.0; % COW
	6414	 0.0	 0.0	 322.12	 -100.08	 0.975	 100.0	 0	 585.0	 175.0; % COW
	6415	 0.0	 0.0	 311.95	 -109.4	 0.975	 100.0	 0	 585.0	 175.0; % COW
	6416	 40.0	 10.44	 42.66	 -21.78	 0.975	 100.0	 1	 80.0	 0.0; % PEL
	6417	 165.0	 16.655	 109.16	 -75.85	 0.975	 100.0	 1	 245.0	 85.0; % NG
	6418	 450.0	 57.26	 230.47	 -115.95	 0.975	 100.0	 1	 605.0	 295.0; % COW
	6419	 28.0	 4.12	 24.74	 -16.5	 0.975	 100.0	 1	 56.0	 0.0; % PEL
	6420	 28.0	 4.12	 24.74	 -16.5	 0.975	 100.0	 1	 56.0	 0.0; % NG
	6421	 29.0	 29.66	 61.2	 -1.88	 0.975	 100.0	 1	 58.0	 0.0; % NG
	6422	 11.55	 3.15	 17.15	 -10.85	 0.975	 100.0	 1	 23.1	 0.0; % PEL
	6423	 11.55	 3.14	 17.14	 -10.86	 0.975	 100.0	 1	 23.1	 0.0; % PEL
	6424	 335.3	 81.55	 169.82	 -6.72	 0.975	 100.0	 1	 439.8	 230.8; % COW
	6425	 0.0	 5.695	 18.02	 -6.63	 0.975	 100.0	 1	 80.0	 -80.0; % COW
	6426	 0.0	 5.695	 18.02	 -6.63	 0.975	 100.0	 1	 80.0	 -80.0; % NG
	6427	 0.0	 5.695	 18.02	 -6.63	 0.975	 100.0	 1	 80.0	 -80.0; % NG
	6428	 16.0	 4.57	 19.57	 -10.43	 0.975	 100.0	 1	 32.0	 0.0; % PEL
	6429	 0.0	 -5.54	 19.57	 -10.43	 0.975	 100.0	 0	 32.0	 0.0; % NG
	6430	 16.0	 4.57	 19.57	 -10.43	 0.975	 100.0	 1	 32.0	 0.0; % PEL
	6431	 0.0	 -5.54	 19.57	 -10.43	 0.975	 100.0	 0	 32.0	 0.0; % COW
	6432	 22.0	 4.315	 14.64	 -6.01	 0.975	 100.0	 1	 44.0	 0.0; % NG
	6433	 15.5	 2.94	 19.26	 -13.38	 0.975	 100.0	 1	 31.0	 0.0; % NG
	6434	 15.5	 2.94	 19.26	 -13.38	 0.975	 100.0	 1	 31.0	 0.0; % NG
	6435	 19.0	 4.36	 27.02	 -18.3	 0.975	 100.0	 1	 38.0	 0.0; % NG
	6436	 19.0	 4.225	 26.96	 -18.51	 0.975	 100.0	 1	 38.0	 0.0; % PEL
	6437	 42.0	 15.305	 54.62	 -24.01	 0.975	 100.0	 1	 84.0	 0.0; % NG
	6438	 0.0	 -4.05	 26.24	 -4.05	 0.975	 100.0	 0	 33.0	 0.0; % COW
	6439	 65.0	 6.33	 30.84	 -18.18	 0.975	 100.0	 1	 130.0	 0.0; % NG
	6440	 65.0	 6.33	 30.84	 -18.18	 0.975	 100.0	 1	 130.0	 0.0; % NG
	6441	 807.0	 215.91	 671.48	 -239.66	 0.975	 100.0	 1	 1332.0	 282.0; % NUC
	6442	 807.0	 215.91	 671.48	 -239.66	 0.975	 100.0	 1	 1332.0	 282.0; % COW
	6443	 217.5	 91.59	 168.9	 14.28	 0.975	 100.0	 1	 285.0	 150.0; % COW
	6444	 410.0	 53.715	 204.97	 -97.54	 0.975	 100.0	 1	 595.0	 225.0; % COW
	6445	 285.0	 62.505	 144.31	 -19.3	 0.975	 100.0	 1	 443.0	 127.0; % COW
	6446	 285.0	 13.06	 45.5	 -19.38	 0.975	 100.0	 1	 443.0	 127.0; % COW
	6447	 25.0	 1.74	 27.73	 -24.25	 0.975	 100.0	 1	 50.0	 0.0; % COW
	6448	 25.0	 1.74	 27.73	 -24.25	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6449	 15.0	 4.19	 21.62	 -13.24	 0.975	 100.0	 1	 30.0	 0.0; % NG
	6450	 42.5	 19.785	 57.42	 -17.85	 0.975	 100.0	 1	 85.0	 0.0; % NG
	6451	 591.95	 196.325	 543.14	 -150.49	 0.975	 100.0	 1	 951.95	 231.95; % NUC
	6452	 594.94	 196.865	 543.37	 -149.64	 0.975	 100.0	 1	 954.94	 234.94; % COW
	6453	 24.5	 1.45	 23.1	 -20.2	 0.975	 100.0	 1	 49.0	 0.0; % NG
	6454	 24.5	 0.99	 22.18	 -20.2	 0.975	 100.0	 1	 49.0	 0.0; % NG
	6455	 24.5	 0.99	 22.18	 -20.2	 0.975	 100.0	 1	 49.0	 0.0; % NG
	6456	 0.0	 34.06	 114.06	 -45.94	 0.975	 100.0	 1	 161.0	 -161.0; % NG
	6457	 78.0	 32.39	 112.39	 -47.61	 0.975	 100.0	 1	 156.0	 0.0; % COW
	6458	 49.5	 -5.525	 22.91	 -33.96	 0.975	 100.0	 1	 99.0	 0.0; % NG
	6459	 49.5	 -5.525	 22.91	 -33.96	 0.975	 100.0	 1	 99.0	 0.0; % NG
	6460	 630.0	 121.775	 405.58	 -162.03	 0.975	 100.0	 1	 985.0	 275.0; % COW
	6461	 630.0	 116.775	 400.58	 -167.03	 0.975	 100.0	 1	 985.0	 275.0; % COW
	6462	 630.0	 116.775	 400.58	 -167.03	 0.975	 100.0	 1	 985.0	 275.0; % PEL
	6463	 630.0	 116.775	 400.58	 -167.03	 0.975	 100.0	 1	 985.0	 275.0; % NUC
	6464	 0.0	 0.0	 102.61	 -26.72	 0.975	 100.0	 0	 185.0	 72.0; % NG
	6465	 0.0	 0.0	 102.61	 -24.82	 0.975	 100.0	 0	 185.0	 72.0; % NG
	6466	 0.0	 0.0	 102.61	 -24.82	 0.975	 100.0	 0	 185.0	 72.0; % NG
	6467	 0.0	 19.4	 89.4	 -50.6	 0.975	 100.0	 1	 64.0	 -64.0; % NG
	6468	 0.0	 19.4	 89.4	 -50.6	 0.975	 100.0	 1	 64.0	 -64.0; % NG
	6469	 0.0	 19.4	 89.4	 -50.6	 0.975	 100.0	 1	 64.0	 -64.0; % NG
	6470	 203.0	 30.365	 148.09	 -87.36	 0.975	 100.0	 1	 268.0	 138.0; % NG
	6471	 203.0	 30.365	 148.09	 -87.36	 0.975	 100.0	 1	 268.0	 138.0; % NG
	6472	 90.0	 27.8	 97.8	 -42.2	 0.975	 100.0	 1	 180.0	 0.0; % NG
	6473	 0.0	 -0.36	 133.88	 -46.12	 0.975	 100.0	 0	 136.0	 0.0; % COW
	6474	 0.0	 -0.36	 123.95	 -46.05	 0.975	 100.0	 0	 128.0	 0.0; % COW
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.000000	  34.719101	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.265118	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.019985	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.857376	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.274748	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.070751	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 119.380030	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.079386	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.189962	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.259097	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.532072	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.396400	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.678889	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.908293	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.955047	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.606677	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.523451	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.638733	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.834409	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.083247	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.792247	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.515196	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.151628	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.074090	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.793597	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.357020	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 109.277329	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.491471	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.919519	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.940816	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.055135	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.788534	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.292879	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.056287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.368659	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.412142	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.017630	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  85.173223	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.124945	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.165706	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.841243	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.416093	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  89.218155	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.960757	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.606964	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.028872	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 128.292721	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.252739	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.604131	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.053547	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.695640	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.917974	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.578795	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.549157	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.612219	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.443741	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.179175	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.208485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   1.662592	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.923511	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 126.105536	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.572834	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.215485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.060489	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.353876	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.437419	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.404293	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  37.769362	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.537122	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.286591	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.822099	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.186204	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.176649	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.465506	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.703695	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.728291	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.467444	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.860206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.435021	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.746964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.628857	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 116.967755	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.652095	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.581812	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.235955	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.468556	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.794314	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 105.683734	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.255781	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.838414	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.254685	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.434555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.508658	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.539658	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.377381	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 130.391311	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.239645	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.473273	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.604090	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.271036	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.429866	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  94.368814	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.652288	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.600913	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.654925	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.129387	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.531880	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.021147	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.716028	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.794253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.764542	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.058639	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.141387	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.299414	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.796127	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.249014	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.079776	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.250372	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.195589	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.853672	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.301367	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  56.566140	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.436204	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.587332	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.976528	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.670915	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.815549	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.511273	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.593521	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.720267	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.945291	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.737080	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.340923	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.906874	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 124.031387	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.544045	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.300055	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.258305	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.190997	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.450705	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.794383	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.788062	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.330962	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.055981	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.547072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.728876	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 127.485755	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.084227	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.313139	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.210828	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.604391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.444437	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.771394	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.216057	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.033731	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.216850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.390466	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.537687	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.394466	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.218830	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.842194	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.058422	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.551368	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.707886	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.375807	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.687688	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.783294	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.473966	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.049845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.661350	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.862811	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.187626	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.030831	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.392307	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.926813	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.165960	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.807188	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.108732	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 100.937756	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.764707	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.574396	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.480994	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.661678	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.879595	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.468964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.764040	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  92.614130	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.769661	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  60.691391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.594703	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.610774	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.473187	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.395905	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.701638	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.084654	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.597860	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.066900	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.605613	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.877829	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.104651	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.058094	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.244405	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.919627	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.018104	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.021913	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.394500	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.217897	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.310033	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  12.718277	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.938286	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.931320	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.627692	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.974007	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.856342	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  89.406143	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  61.833307	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 129.631907	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.336715	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.930188	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.277322	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.583659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.099842	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.024282	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.933546	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.022741	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.771126	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.233862	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.281287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  75.838128	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.157015	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  83.491323	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.459742	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.623817	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.591490	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.071754	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.278971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.378738	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.767873	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 119.490048	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.340076	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.763411	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.758165	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  52.445944	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.750425	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.024802	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.378990	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.570960	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.057615	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.435548	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   4.042618	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.064417	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.538304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  95.799680	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.737778	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.187231	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.334575	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.418283	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.099250	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.869239	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.538949	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.673204	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.420972	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.992737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.073432	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.705565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.392219	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.637502	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 124.470461	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  57.663913	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.622037	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.310464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.918779	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.058733	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.486419	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.058842	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.252292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.857517	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.950751	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.937589	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.491818	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.507001	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.325620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.551234	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.852799	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.642065	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.793637	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.459974	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.170699	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.972079	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.208895	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.245395	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.539916	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.610202	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.565269	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.713841	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.913576	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.145163	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.731539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.244339	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.874943	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.927629	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.258569	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.269342	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.747597	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.192828	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.607502	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.363526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.856978	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.672965	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.691934	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  52.504627	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.793427	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.582730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.454069	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.532112	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.974242	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.838856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.092446	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.774663	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.725731	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.134871	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.146088	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.636445	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.338458	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.409867	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.718616	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.630330	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.097198	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.069497	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.400965	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.055105	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.295835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.978319	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.134956	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  92.969177	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.569512	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.847465	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.291754	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.519448	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.497094	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.679564	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.056469	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.626360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.521958	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.447798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.641927	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.476006	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.859329	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.672833	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.989765	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.207665	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 128.150032	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  88.261130	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.081121	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.959228	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.031147	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.830798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.549416	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  93.712963	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.505530	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.577132	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.269513	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.453954	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.912573	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.723948	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.308214	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.428064	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.765802	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.974304	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.044426	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.953031	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.768253	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 132.824014	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.796033	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  94.371528	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   9.632764	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.049405	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.358605	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.091362	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.941307	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.390526	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.388522	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.010142	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.650513	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.646263	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.168901	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.957829	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.296012	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.647727	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.126555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.500964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.740249	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.036904	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  89.549472	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  66.961358	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.137387	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.411590	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.470087	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.562796	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.754447	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.147073	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.894991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.881744	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.058895	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.159806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.850401	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.419663	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.665417	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.992612	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.792299	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.981696	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.085309	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 136.777870	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.361855	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.776378	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.447740	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.196613	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.152195	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.155407	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.382701	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.691413	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.170877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.319778	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.880656	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.459642	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.327291	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.834744	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.329650	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.284723	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.476668	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.327288	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.089733	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.104172	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.326508	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.917461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.950330	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.877198	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.702982	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.345755	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.941825	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 113.221653	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 125.028176	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.698092	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.412440	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.737619	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.922509	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.901769	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.153615	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.317318	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  62.389514	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.939805	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.837697	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.980002	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.950689	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.367761	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.049317	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 109.612703	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.001936	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   8.025319	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.721936	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.559369	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.839430	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.521236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.173608	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.987079	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.936246	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.676058	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.868094	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.886095	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.284078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.483214	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 131.970508	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.014154	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.815478	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.996197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.724896	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.152429	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.736402	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.837687	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.930144	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.381100	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.729938	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.106325	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.528863	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.048448	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.896545	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.799354	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.333807	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.622192	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.370893	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.779689	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.743149	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.342966	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.917269	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.697253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.412264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.143120	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.831658	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.434463	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.631740	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.569448	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.232924	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.972175	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.279467	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.120906	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.805884	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  66.160570	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.931161	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.758827	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.095219	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 123.123262	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.903036	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.523822	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.021766	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.430014	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.359079	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.319625	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.861961	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.632730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.526450	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.661029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.229889	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.892310	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.522322	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.092004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.204098	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.498031	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.484938	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.895066	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.043859	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.424152	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.619922	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.438497	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.746365	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.102008	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.755404	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.744715	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.611914	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 122.162979	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.318772	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.788341	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.360742	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.149007	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.817969	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.486236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.194093	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.935885	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.584303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.850717	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 117.180457	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.027667	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.861479	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.343373	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.621052	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.473902	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.172276	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.618162	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.382655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.208643	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.273863	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 101.698569	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.093585	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.239428	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.478992	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.739518	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.707837	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.887336	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.474844	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.783794	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.467175	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.895448	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.271782	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.303588	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.845681	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.289346	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.850897	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.573659	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 117.707892	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.953827	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.602615	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.129991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.382908	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.523438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.082364	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.433339	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.904197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.924907	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.708928	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.269429	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.902388	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.060560	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.162079	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.815890	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.174089	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.154160	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.954907	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.134287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.034469	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.328723	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.761050	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  12.863687	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.367300	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.462986	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.782343	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.297482	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.553342	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.203098	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.717238	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.914335	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.184646	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.775242	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.773203	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.391266	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.715226	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.016594	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.599122	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.842299	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.685935	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.367895	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.373073	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.297344	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.456062	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.477264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.176455	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.976090	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.261284	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.421522	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.435598	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.800245	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.540283	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.384499	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  86.455819	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.746863	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.489080	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.739851	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.130854	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.958193	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.565929	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.686223	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.941465	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.781638	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.213990	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.867748	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.418903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.363698	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.156266	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.545662	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.039794	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   2.356517	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 130.742767	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  12.844483	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  98.715237	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.386619	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.172000	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.599281	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 122.283234	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.413784	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.526752	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.942982	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.453621	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.378283	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.897725	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.667571	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.490421	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.266079	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.524230	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.290349	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.658790	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.016872	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.621516	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 118.206842	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  12.859049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.547489	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.548030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.673507	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.706255	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.056933	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.008521	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.354812	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.704815	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.424828	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.049887	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.195390	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.116041	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.368993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.834357	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.403263	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.769034	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.968295	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.317726	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.077696	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.292742	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.890349	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.766771	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.180977	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.867854	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.964038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.665443	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.472190	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.708350	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.353405	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.411303	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.574141	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.361566	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.937628	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.006062	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.835902	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.077027	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.088164	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.063397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.491813	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.981207	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.567226	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.595155	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.734121	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.448355	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.713376	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.367460	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.054864	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.338443	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.508812	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  53.181285	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.047527	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.448946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.727283	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.648649	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.352742	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.862698	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.354566	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.554267	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.674007	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.981909	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 109.269325	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.232332	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.239158	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.746784	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.187959	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.157577	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  86.216901	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.560474	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.510294	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  54.434557	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.585427	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.938645	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.982755	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.439411	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.282792	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.386124	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.166621	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.635832	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.558191	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.298283	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.887147	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.849745	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.545032	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.732900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.046802	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.251670	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.741827	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.766733	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.578284	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.150060	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.139336	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.286420	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.519646	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.199405	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.399841	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.339226	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.403060	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.299490	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.111468	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  59.736677	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.289399	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.526353	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.112972	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.530812	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.367020	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.103050	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.085304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.964657	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.739590	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.340987	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.027912	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.564696	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.846017	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.134540	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.408130	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.195764	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.190388	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.978292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.495919	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  95.415813	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.508750	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.586392	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.851480	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.400944	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.935636	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  56.355556	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.366428	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.226145	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.385483	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.966691	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.412236	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.358330	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.563814	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.401812	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.434919	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.417793	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.303255	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.056496	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.485682	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.709726	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.178643	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.468690	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.267776	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.064604	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.548607	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.380396	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.307925	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.590833	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.354277	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 125.242760	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.883603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.862465	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.077351	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  95.331345	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.860172	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.913213	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.403361	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 118.563256	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.152039	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.869879	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.292594	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.025412	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.553886	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.331219	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  92.436887	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.835465	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.504130	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.091166	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.739604	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.309763	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.348427	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.595206	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.786522	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.601159	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.836866	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.289462	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.429393	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 128.735705	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.791868	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.617792	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.416420	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.081764	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.755952	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.687243	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.791592	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.453597	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.089210	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.129609	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.655060	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.338140	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.324477	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.145313	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.105030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.617041	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.735526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.220984	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  62.605777	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.981705	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.021016	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.299417	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.503398	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.893935	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.412652	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.618827	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.562285	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.735178	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.443701	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.439237	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.215748	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  98.135121	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.442851	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.266939	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.496547	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.825675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.402536	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.528926	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.587842	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.346519	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.502709	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  95.015519	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.255237	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.350688	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.049865	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.863813	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.833472	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.153380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.720598	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.311406	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.702272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.405026	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.116047	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.491932	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.056009	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.274308	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.288676	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.438587	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.853875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.593423	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 116.989652	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.258309	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.810810	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.115063	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.043212	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.648598	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.243466	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.877243	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 128.858850	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.463522	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.121508	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.997783	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.482929	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.666488	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.417089	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.015072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.033992	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.508189	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.451978	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.270507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.094243	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.088679	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.142177	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.742820	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.254327	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.546758	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.600774	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.614954	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.903949	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.610805	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.200238	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.329592	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.027587	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.019567	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.239002	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.537987	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.749793	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  92.686154	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.777031	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.101971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.587706	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.971620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.450291	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.102637	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.058608	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.321072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.299795	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.645884	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.701671	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.785779	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.290737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.929656	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.919285	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.348355	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.081099	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.610318	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.663272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.336844	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.630717	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.134251	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.530992	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.726272	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.390183	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.974799	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.236795	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.135839	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  27.562243	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  29.921286	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 102.151857	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.411620	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.990577	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.851565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.719399	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.162936	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.514020	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.124493	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   6.639905	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  12.913778	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.347570	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.923936	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.924343	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.515043	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.598856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.751444	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.077308	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.642484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.321661	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.449160	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.864308	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.913503	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.309168	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.645081	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.054950	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.827854	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.279303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.475394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   8.298502	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  33.380705	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.798682	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.580995	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.377532	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.945916	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  19.242001	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.617980	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.680743	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  10.693864	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.105615	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  48.873735	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.817256	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.038179	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  17.278390	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.630592	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.840924	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  59.885745	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.906350	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  46.683311	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.000524	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  27.110678	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.474841	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.466623	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  34.625531	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.771295	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.414552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.951545	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.504924	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  23.161400	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  16.838269	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.650622	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.404421	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.417686	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.873572	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.942073	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.922015	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.035991	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.465395	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.754072	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.243589	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.065958	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.738120	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.743229	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.451735	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  31.436407	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.614265	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.547777	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.556656	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.139942	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.763005	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.458952	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  38.062507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.903917	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.395264	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.960622	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.722636	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.807606	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.844500	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  38.728859	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.064613	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  38.361688	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.576176	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   6.530455	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.031254	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.889123	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.837150	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.032007	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.477561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  37.489575	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.109445	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.892135	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.681410	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.418254	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.647930	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.715610	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.097841	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.713178	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  35.509004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.276134	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.986272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.202117	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.520025	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  39.461952	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.379672	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.247748	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.254294	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.738150	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.657829	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.045892	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.904747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.582531	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.414104	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.689768	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.073616	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.351244	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.370425	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.932784	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.907082	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.577038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.822778	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.126576	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.873951	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.901138	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.741937	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.939001	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.622215	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.462870	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.378057	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  95.087079	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.464126	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.198864	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.474132	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.781627	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.049562	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.869142	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.875240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.241712	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.132327	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.758711	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  21.004877	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.126897	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.492695	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  35.236652	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 115.378170	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 125.760081	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.134216	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.829629	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.801829	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.595321	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.456056	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.726258	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.179973	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   7.020862	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  29.261740	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.224980	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.284572	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.754831	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.254518	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.237652	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.955619	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.783446	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.810767	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.747601	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.568046	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.946616	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.306760	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.749933	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.701430	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.915681	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.382796	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.837749	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.409287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.498877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.731801	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.434062	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.443406	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.481868	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.040728	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.693187	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.658451	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  26.670506	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.656170	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.579554	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.578776	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.354639	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.552536	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  22.277872	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.784440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.600112	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  43.859966	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.920983	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.812317	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.883051	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.479942	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.519857	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.345791	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  91.639195	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   7.226884	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	 117.315637	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.249467	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.898040	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.471422	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  21.567316	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.277934	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.249134	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.866377	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.732486	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.240001	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.725680	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.101751	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.945682	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.521363	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.732328	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.354222	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.840476	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.020158	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.274431	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.307347	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.720375	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.124293	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.814174	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.812942	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.693241	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.380501	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.607011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.856177	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.387421	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.022414	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.179920	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.560157	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.513496	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.973457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.622310	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.379276	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.261576	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.220750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.594832	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.934071	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.108566	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.669454	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.800516	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.587701	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   3.526977	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.071697	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   5.033525	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.645057	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 115.442105	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.857282	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.140103	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.847720	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.732821	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.518194	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.999750	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.120140	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.148431	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.442192	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.391621	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.266810	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.353440	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.177336	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 118.039667	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.241652	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.203767	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 123.829637	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.561412	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.320659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.121218	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.817182	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.898293	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.138483	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.303674	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.528970	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.680302	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  12.620521	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.726104	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.012029	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.816480	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.716893	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.809846	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.987454	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.385528	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.795851	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.818443	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.150930	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.380175	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.996993	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  33.540625	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.650796	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.831979	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.227064	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.929667	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.006987	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  64.463060	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.157952	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.126738	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.459916	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  33.859288	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.166205	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.390669	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.226518	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.254199	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.404855	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.693645	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.997143	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.069173	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.859880	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 104.438037	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   6.629114	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  31.009600	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.963495	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.468059	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.221097	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.604119	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.858337	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.158331	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.902488	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.814178	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.373867	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.977498	   0.000000; % COW
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	4644	 1	 0.005726	 0.010482	 0.0	 2186	 2186	 2186	 0.0	 0.0	 1	 -30.0	 30.0;
	5243	 1	 0.01284	 0.025679	 0.0	 910	 910	 910	 0.0	 0.0	 1	 -30.0	 30.0;
	1682	 2	 0.005799	 0.010615	 0.0075	 2441	 2441	 2441	 0.0	 0.0	 1	 -30.0	 30.0;
	1673	 3	 0.134039	 0.309398	 0.0035	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	2302	 3	 0.049131	 0.133283	 0.0015	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	694	 4	 0.025926	 0.109136	 0.0002	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	3940	 4	 0.05	 0.126914	 0.0006	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	5043	 4	 0.02321	 0.097407	 0.0016	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	4414	 5	 0.040564	 0.113631	 0.0013	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	2780	 6	 0.006047	 0.020912	 0.0222	 1398	 1398	 1398	 0.0	 0.0	 1	 -30.0	 30.0;
	2781	 7	 0.012472	 0.032099	 0.0061	 884	 884	 884	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 8	 0.002607	 0.017462	 0.0324	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	471	 9	 0.053893	 0.14258	 0.0017	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 10	 0.000247	 0.001235	 0.0005	 24078	 24078	 24078	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 10	 0.000247	 0.001235	 0.0002	 24078	 24078	 24078	 0.0	 0.0	 1	 -30.0	 30.0;
	30	 11	 0.039753	 0.100988	 0.0047	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 11	 0.037654	 0.096173	 0.001	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	2180	 12	 0.014613	 0.060721	 0.0008	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	4018	 12	 0.034064	 0.121139	 0.0015	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	4020	 12	 0.000242	 0.000442	 0.0004	 60355	 60355	 60355	 0.0	 0.0	 1	 -30.0	 30.0;
	115	 13	 2.1e-05	 0.000125	 0.1386	 737.0	 737.0	 737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2336	 13	 0.000145	 0.001877	 0.0635	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4574	 13	 0.000319	 0.003234	 0.0838	 1841.0	 1841.0	 1841.0	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 13	 2.1e-05	 0.000125	 0.1386	 737.0	 737.0	 737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1224	 14	 0.04	 0.134198	 0.0274	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	2875	 14	 0.012222	 0.052346	 0.0026	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	4592	 14	 0.007284	 0.045432	 0.0024	 660	 660	 660	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 14	 0.059963	 0.154222	 0.0236	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5229	 14	 0.018025	 0.110988	 0.0073	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	2875	 14	 0.012222	 0.052593	 0.0032	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	4592	 14	 0.007284	 0.044938	 0.0024	 667	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 15	 0.037541	 0.100529	 0.0011	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	4126	 15	 0.090199	 0.211388	 0.0023	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	4454	 15	 0.09801	 0.267574	 0.0	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	251	 16	 0.071806	 0.191484	 0.0019	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	339	 16	 0.119174	 0.284958	 0.0044	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	5835	 17	 0.022346	 0.061111	 0.0029	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	3728	 18	 0.009383	 0.019753	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	5091	 19	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	3728	 20	 0.001975	 0.004444	 0.0	 5369	 5369	 5369	 0.0	 0.0	 1	 -30.0	 30.0;
	1353	 21	 0.036296	 0.099012	 0.0045	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	1598	 21	 0.032716	 0.089136	 0.0057	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	1842	 22	 0.138574	 0.351474	 0.0058	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	5020	 22	 0.094407	 0.210456	 0.0044	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	1156	 23	 0.047115	 0.117158	 0.001	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	2705	 23	 0.039557	 0.120937	 0.0132	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	3425	 23	 0.022676	 0.062484	 0.0007	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	144	 24	 0.064568	 0.16716	 0.0113	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 24	 0.048605	 0.128481	 0.0062	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	491	 25	 0.004815	 0.02963	 0.0016	 1048	 1048	 1048	 0.0	 0.0	 1	 -30.0	 30.0;
	2092	 25	 0.007309	 0.04463	 0.0073	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	611	 26	 0.034321	 0.145802	 0.0073	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	1865	 26	 0.004815	 0.009753	 0.0005	 2731	 2731	 2731	 0.0	 0.0	 1	 -30.0	 30.0;
	2604	 26	 0.049012	 0.133704	 0.0063	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	2923	 26	 0.04642	 0.126543	 0.0058	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	3339	 26	 0.046296	 0.125926	 0.006	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	4629	 26	 0.053704	 0.136753	 0.0065	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	2923	 26	 0.03358	 0.120988	 0.0062	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	534	 27	 0.006163	 0.041067	 0.0759	 446.0	 446.0	 446.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2349	 27	 0.000652	 0.004369	 0.0081	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2686	 28	 0.050945	 0.131922	 0.0015	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	3893	 28	 0.058781	 0.149005	 0.0017	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	2888	 29	 0.067019	 0.137566	 0.0037	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 29	 0.032754	 0.088939	 0.0039	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 29	 0.030184	 0.080096	 0.0053	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	144	 30	 0.066049	 0.187778	 0.0099	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	1553	 30	 0.065062	 0.133704	 0.0062	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	4836	 30	 0.041728	 0.106049	 0.005	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 31	 0.009574	 0.03875	 0.0114	 740	 740	 740	 0.0	 0.0	 1	 -30.0	 30.0;
	3162	 31	 0.000171	 0.000313	 0.0002	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	3693	 31	 0.034266	 0.09423	 0.001	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	4740	 31	 0.006803	 0.028219	 0.0	 1018	 1018	 1018	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 31	 0.008566	 0.037541	 0.0121	 767	 767	 767	 0.0	 0.0	 1	 -30.0	 30.0;
	3730	 32	 0.009733	 0.034089	 0.0185	 902	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	368	 34	 0.000277	 0.002015	 0.003	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1016	 33	 0.00881	 0.033995	 0.0607	 289.0	 289.0	 289.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1157	 33	 0.004642	 0.019832	 0.0354	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2582	 34	 0.008861	 0.03506	 0.0623	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2706	 34	 0.006993	 0.032869	 0.0557	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4745	 33	 0.002173	 0.008731	 0.0152	 3441	 3441	 3441	 0.0	 0.0	 1	 -30.0	 30.0;
	4853	 34	 0.00077	 0.003121	 0.0051	 9629	 9629	 9629	 0.0	 0.0	 1	 -30.0	 30.0;
	5670	 33	 0.004109	 0.016138	 0.0284	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	370	 35	 8.3e-05	 0.000907	 0.0202	 1034.0	 1034.0	 1034.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1108	 35	 0.000552	 0.006726	 0.0939	 1786.0	 1786.0	 1786.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 35	 0.000512	 0.008012	 0.2455	 2462.0	 2462.0	 2462.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3135	 35	 0.001107	 0.00918	 0.1906	 1644.0	 1644.0	 1644.0	 0.0	 0.0	 1	 -30.0	 30.0;
	369	 36	 6.2e-05	 0.000741	 0.0173	 1095.0	 1095.0	 1095.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 35	 0.000512	 0.008019	 0.2455	 2462.0	 2462.0	 2462.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 36	 0.001153	 0.013123	 0.1841	 1433.0	 1433.0	 1433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5228	 37	 0.055933	 0.120685	 0.0013	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5514	 37	 0.039053	 0.084404	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	724	 38	 0.00252	 0.006551	 0.0001	 4462	 4462	 4462	 0.0	 0.0	 1	 -30.0	 30.0;
	1228	 39	 0.009877	 0.042222	 0.0021	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	5809	 39	 0.024815	 0.063086	 0.0029	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	1228	 39	 0.009877	 0.042222	 0.0021	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	2250	 40	 0.056173	 0.142593	 0.0066	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4592	 40	 0.034444	 0.109012	 0.0076	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	431	 41	 0.000158	 0.000672	 0.0719	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3954	 41	 4.5e-05	 8.9e-05	 0.002	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1482	 42	 0.01096	 0.020063	 0.009	 1465	 1465	 1465	 0.0	 0.0	 1	 -30.0	 30.0;
	2766	 42	 0.002268	 0.008818	 0.0099	 3678	 3678	 3678	 0.0	 0.0	 1	 -30.0	 30.0;
	2725	 43	 0.001481	 0.006296	 0.0039	 4689	 4689	 4689	 0.0	 0.0	 1	 -30.0	 30.0;
	3488	 44	 0.050617	 0.137012	 0.009	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	4324	 44	 0.074326	 0.194507	 0.0021	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	5094	 45	 0.000247	 0.000741	 0.0	 38027	 38027	 38027	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 46	 0.049131	 0.134039	 0.001	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	2193	 46	 0.033258	 0.090955	 0.001	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	3305	 46	 0.067437	 0.123442	 0.001	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 47	 0.037289	 0.118166	 0.001	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 48	 0.021358	 0.057037	 0.0005	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	1222	 49	 0.071303	 0.180902	 0.0021	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	2344	 49	 0.071554	 0.18191	 0.0021	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	471	 50	 0.028193	 0.104535	 0.0013	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	1676	 50	 0.055404	 0.171429	 0.01	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 50	 0.010834	 0.071554	 0.001	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 50	 0.013857	 0.030234	 0.0003	 897	 897	 897	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 50	 0.011414	 0.070648	 0.0009	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 50	 0.013757	 0.030108	 0.0003	 901	 901	 901	 0.0	 0.0	 1	 -30.0	 30.0;
	1195	 51	 0.00478	 0.028622	 0.0547	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1196	 51	 0.00478	 0.028583	 0.0547	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	166	 52	 0.01284	 0.032716	 0.0015	 846	 846	 846	 0.0	 0.0	 1	 -30.0	 30.0;
	5488	 52	 0.014198	 0.036049	 0.0016	 767	 767	 767	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 53	 0.005291	 0.021668	 0.0003	 1285	 1285	 1285	 0.0	 0.0	 1	 -30.0	 30.0;
	2770	 54	 0.01358	 0.047654	 0.0023	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	375	 55	 0.000257	 0.000514	 0.0294	 53862	 53862	 53862	 0.0	 0.0	 1	 -30.0	 30.0;
	2695	 56	 0.000257	 0.002153	 0.2147	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3427	 56	 0.000277	 0.000869	 0.0931	 481.0	 481.0	 481.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5095	 57	 0.000756	 0.00252	 0.0	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 58	 0.000237	 0.00083	 0.1863	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3566	 58	 0.000178	 0.000612	 0.1377	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	142	 59	 0.030486	 0.076342	 0.002	 370	 370	 370	 0.0	 0.0	 1	 -30.0	 30.0;
	1652	 59	 0.011086	 0.024691	 0.0015	 1124	 1124	 1124	 0.0	 0.0	 1	 -30.0	 30.0;
	2478	 60	 0.044344	 0.170572	 0.0021	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	3526	 60	 0.036709	 0.151776	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	2227	 61	 0.017788	 0.048551	 0.0006	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	2636	 61	 0.057521	 0.145251	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	2047	 62	 0.014109	 0.057949	 0.0029	 510	 510	 510	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 62	 0.007055	 0.02973	 0.0014	 996	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	373	 63	 0.024263	 0.065911	 0.0007	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 63	 0.020912	 0.059209	 0.0016	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	145	 64	 0.002568	 0.011753	 0.0203	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5105	 64	 0.002568	 0.011615	 0.0228	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4604	 65	 0.006299	 0.033585	 0.0599	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	4604	 65	 0.006299	 0.033661	 0.06	 889	 889	 889	 0.0	 0.0	 1	 -30.0	 30.0;
	1546	 66	 0.102293	 0.226757	 0.0025	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 66	 0.177551	 0.405291	 0.0046	 67	 67	 67	 0.0	 0.0	 1	 -30.0	 30.0;
	3249	 66	 0.088264	 0.161566	 0.0017	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	3031	 67	 0.007307	 0.014613	 0.0002	 1862	 1862	 1862	 0.0	 0.0	 1	 -30.0	 30.0;
	2193	 68	 0.043336	 0.11867	 0.001	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	2884	 68	 0.067775	 0.139834	 0.001	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	4534	 68	 0.047367	 0.16125	 0.0021	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 68	 0.004031	 0.016629	 0.001	 1726	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 69	 0.073066	 0.205089	 0.0022	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 70	 4.8e-05	 8.8e-05	 0.0001	 303410	 303410	 303410	 0.0	 0.0	 1	 -30.0	 30.0;
	2164	 71	 0.000252	 0.00252	 0.0008	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	3145	 71	 0.030738	 0.088687	 0.0169	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 71	 0.006551	 0.016377	 0.0171	 1625	 1625	 1625	 0.0	 0.0	 1	 -30.0	 30.0;
	3145	 71	 0.025195	 0.07483	 0.0204	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	3747	 72	 9.9e-05	 0.00077	 0.078	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3747	 73	 9.9e-05	 0.00077	 0.077	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5105	 74	 0.000514	 0.003437	 0.0061	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 74	 0.005476	 0.036879	 0.1255	 522.0	 522.0	 522.0	 0.0	 0.0	 1	 -30.0	 30.0;
	145	 74	 0.000514	 0.003457	 0.0061	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4961	 75	 0.017531	 0.046914	 0.0023	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 75	 0.005309	 0.014321	 0.0006	 1949	 1949	 1949	 0.0	 0.0	 1	 -30.0	 30.0;
	3083	 76	 0.003477	 0.01118	 0.0187	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3833	 76	 0.000612	 0.003121	 0.0152	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2343	 77	 0.013857	 0.035525	 0.0004	 775	 775	 775	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 78	 0.002771	 0.008314	 0.0083	 3471	 3471	 3471	 0.0	 0.0	 1	 -30.0	 30.0;
	4559	 78	 0.000151	 0.000302	 0.0	 90076	 90076	 90076	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 79	 0.010758	 0.02187	 0.0071	 1176	 1176	 1176	 0.0	 0.0	 1	 -30.0	 30.0;
	1870	 79	 0.003779	 0.014613	 0.0198	 1899	 1899	 1899	 0.0	 0.0	 1	 -30.0	 30.0;
	2411	 79	 0.008314	 0.017057	 0.024	 1510	 1510	 1510	 0.0	 0.0	 1	 -30.0	 30.0;
	4078	 79	 0.000252	 0.001764	 0.0043	 16079	 16079	 16079	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 79	 0.010758	 0.02187	 0.0071	 1176	 1176	 1176	 0.0	 0.0	 1	 -30.0	 30.0;
	4077	 79	 0.000302	 0.001562	 0.0037	 18009	 18009	 18009	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 81	 2.4e-05	 0.000144	 0.0213	 701.0	 701.0	 701.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 80	 7.1e-05	 0.000162	 0.0162	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	674	 82	 0.068027	 0.173091	 0.002	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	797	 82	 0.027211	 0.068783	 0.001	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	2072	 82	 0.03099	 0.202822	 0.002	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	3485	 83	 0.000257	 0.001165	 0.002	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2128	 84	 0.045603	 0.11741	 0.001	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	3803	 84	 0.008566	 0.024691	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 85	 0.047317	 0.131595	 0.0015	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	2810	 86	 0.040494	 0.128889	 0.0064	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	3512	 86	 0.037778	 0.097037	 0.0045	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 87	 0.032071	 0.058705	 0.0006	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 87	 0.062887	 0.204157	 0.002	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 87	 0.032026	 0.058624	 0.0006	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	1617	 88	 0.075838	 0.224742	 0.0027	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	1706	 88	 0.028471	 0.089695	 0.001	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	3644	 88	 0.080373	 0.255732	 0.003	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	5558	 88	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	2498	 89	 0.033531	 0.087235	 0.0166	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	4228	 89	 0.03037	 0.08321	 0.0039	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	5101	 90	 0.000444	 0.001136	 0.0	 21404	 21404	 21404	 0.0	 0.0	 1	 -30.0	 30.0;
	3728	 91	 0.057284	 0.130864	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	647	 92	 0.054749	 0.157445	 0.0027	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	4057	 92	 0.038549	 0.103049	 0.0012	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	5728	 92	 0.012598	 0.052406	 0.0006	 548	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 93	 0.006914	 0.020741	 0.0	 1195	 1195	 1195	 0.0	 0.0	 1	 -30.0	 30.0;
	3769	 94	 0.007901	 0.020741	 0.001	 1339	 1339	 1339	 0.0	 0.0	 1	 -30.0	 30.0;
	5845	 94	 0.02	 0.054691	 0.0026	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	285	 95	 0.012099	 0.030864	 0.0047	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	1173	 95	 0.013704	 0.034444	 0.003	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	5704	 95	 0.005679	 0.014198	 0.0023	 1943	 1943	 1943	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 96	 0.009549	 0.040766	 0.0005	 706	 706	 706	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 97	 0.026505	 0.119426	 0.1007	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	4178	 97	 0.087641	 0.160426	 0.0015	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	4445	 97	 0.021542	 0.05868	 0.003	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 97	 0.026505	 0.119426	 0.1007	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 98	 0.000176	 0.000479	 0.0006	 59599	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 98	 0.141119	 0.363442	 0.0042	 79	 79	 79	 0.0	 0.0	 1	 -30.0	 30.0;
	4649	 98	 0.074477	 0.177601	 0.0021	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	2635	 99	 0.025195	 0.067523	 0.0064	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	2636	 99	 0.025069	 0.067599	 0.0064	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	551	 100	 0.024792	 0.057949	 0.003	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	1193	 100	 0.028723	 0.11683	 0.0015	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	1194	 100	 0.027589	 0.112547	 0.0048	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	1903	 101	 0.032124	 0.082892	 0.003	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 101	 0.025573	 0.09869	 0.0012	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	1477	 102	 0.001512	 0.005291	 0.0064	 5495	 5495	 5495	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 103	 0.03351	 0.120433	 0.0058	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 103	 0.062988	 0.159486	 0.0017	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 103	 0.024943	 0.104283	 0.0031	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 103	 0.033762	 0.120433	 0.0057	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 104	 0.005709	 0.037926	 0.0688	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5493	 104	 0.001758	 0.011654	 0.0208	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	265	 105	 0.001383	 0.009462	 0.0172	 463.0	 463.0	 463.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1559	 105	 0.00156	 0.006933	 0.0121	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2094	 105	 0.006376	 0.028733	 0.0506	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3540	 105	 0.00158	 0.010627	 0.0192	 481.0	 481.0	 481.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2207	 106	 0.005556	 0.025185	 0.0008	 1225	 1225	 1225	 0.0	 0.0	 1	 -30.0	 30.0;
	2271	 106	 0.007531	 0.046914	 0.0036	 676	 676	 676	 0.0	 0.0	 1	 -30.0	 30.0;
	3262	 106	 0.033457	 0.09642	 0.0047	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 106	 0.006914	 0.042469	 0.0005	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 107	 0.001086	 0.003536	 0.3766	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 107	 0.001086	 0.003536	 0.3766	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3980	 108	 0.026543	 0.074691	 0.0034	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	3979	 108	 0.026914	 0.075802	 0.0034	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	632	 109	 0.04059	 0.110708	 0.0013	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	671	 109	 0.073646	 0.225598	 0.0087	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	759	 109	 0.02066	 0.088687	 0.0021	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	5201	 109	 0.019904	 0.08516	 0.001	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 109	 0.014361	 0.068027	 0.0035	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	4739	 109	 0.059209	 0.150164	 0.0021	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	482	 110	 0.004741	 0.020385	 0.0334	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	5404	 110	 0.009027	 0.048869	 0.084	 351.0	 351.0	 351.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 110	 0.003516	 0.016257	 0.0273	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	713	 111	 0.059461	 0.163265	 0.0018	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	4442	 111	 0.146384	 0.373394	 0.0051	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	1167	 112	 0.006299	 0.027715	 0.0003	 1009	 1009	 1009	 0.0	 0.0	 1	 -30.0	 30.0;
	1656	 112	 0.008818	 0.028471	 0.0003	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	2295	 112	 0.043588	 0.145629	 0.008	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	5313	 112	 0.015117	 0.051902	 0.0006	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	1168	 112	 0.006551	 0.025951	 0.0003	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	1655	 112	 0.008314	 0.027211	 0.0003	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	2295	 112	 0.043689	 0.145528	 0.0081	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	1654	 112	 0.008566	 0.027967	 0.0003	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	1032	 113	 0.000514	 0.003417	 0.0278	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1075	 113	 0.001084	 0.007198	 0.0132	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5263	 113	 0.000523	 0.002436	 0.0167	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1032	 113	 0.000514	 0.003457	 0.0203	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1075	 113	 0.001086	 0.007249	 0.0132	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5262	 113	 0.000553	 0.002469	 0.0157	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1075	 113	 0.001086	 0.007269	 0.0132	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3522	 114	 0.038725	 0.112799	 0.0116	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	3995	 114	 0.023935	 0.079617	 0.0021	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	1243	 117	 0.135693	 0.248384	 0.0025	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	1246	 117	 0.192681	 0.352701	 0.0037	 76	 76	 76	 0.0	 0.0	 1	 -30.0	 30.0;
	5408	 117	 0.057193	 0.145377	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5530	 117	 0.021736	 0.039788	 0.0004	 671	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	4961	 118	 0.002469	 0.006938	 0.0248	 4056	 4056	 4056	 0.0	 0.0	 1	 -30.0	 30.0;
	1000	 119	 0.016125	 0.068279	 0.0081	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	4554	 119	 0.059209	 0.150416	 0.0021	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	1000	 119	 0.016125	 0.068279	 0.0081	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	2705	 120	 0.013605	 0.039305	 0.0061	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	5233	 121	 0.031015	 0.078685	 0.0032	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 121	 0.080927	 0.181204	 0.0038	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 122	 0.007811	 0.016377	 0.0024	 1677	 1677	 1677	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 123	 0.007811	 0.016377	 0.0024	 1677	 1677	 1677	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 124	 0.010124	 0.028518	 0.0013	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 125	 0.084656	 0.231041	 0.0026	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 125	 0.061225	 0.275888	 0.003	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	4311	 126	 0.102293	 0.245906	 0.0027	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	5737	 126	 0.036533	 0.088435	 0.001	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	182	 127	 0.001039	 0.001902	 0.0015	 13220	 13220	 13220	 0.0	 0.0	 1	 -30.0	 30.0;
	2390	 129	 0.000756	 0.007811	 0.0001	 3763	 3763	 3763	 0.0	 0.0	 1	 -30.0	 30.0;
	2747	 129	 0.019148	 0.081381	 0.0012	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	4261	 129	 0.02318	 0.04258	 0.0006	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	5295	 129	 0.002268	 0.022424	 0.0002	 1311	 1311	 1311	 0.0	 0.0	 1	 -30.0	 30.0;
	5741	 128	 0.012094	 0.030486	 0.0004	 901	 901	 901	 0.0	 0.0	 1	 -30.0	 30.0;
	2747	 128	 0.03351	 0.088435	 0.001	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	5294	 128	 0.00252	 0.02066	 0.0002	 1419	 1419	 1419	 0.0	 0.0	 1	 -30.0	 30.0;
	2991	 130	 0.001837	 0.011694	 0.0759	 467.0	 467.0	 467.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3413	 130	 0.001067	 0.007131	 0.0132	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4572	 130	 0.001284	 0.008593	 0.0152	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4573	 130	 0.001284	 0.008593	 0.0162	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4573	 130	 0.001284	 0.008533	 0.0162	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	782	 131	 0.000494	 0.000928	 0.0699	 29203	 29203	 29203	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 131	 0.000184	 0.00159	 0.1661	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4043	 131	 0.000198	 0.001711	 0.1711	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4103	 131	 0.000751	 0.003358	 0.1534	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2194	 132	 0.007037	 0.022716	 0.0011	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	2735	 132	 0.028025	 0.071111	 0.0034	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 133	 0.005192	 0.009503	 0.009	 2646	 2646	 2646	 0.0	 0.0	 1	 -30.0	 30.0;
	1189	 135	 0.000178	 0.001047	 0.1499	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1716	 134	 0.000119	 0.000474	 0.0688	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 135	 0.000316	 0.002232	 0.2774	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1884	 136	 0.060864	 0.152469	 0.0071	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	4814	 136	 0.058222	 0.146864	 0.007	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	625	 137	 0.047115	 0.108088	 0.0031	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	3049	 137	 0.036281	 0.154195	 0.0037	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	4524	 138	 0.037227	 0.106836	 0.0328	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 138	 0.006089	 0.020756	 0.0067	 1408	 1408	 1408	 0.0	 0.0	 1	 -30.0	 30.0;
	3558	 139	 0.086848	 0.206626	 0.0036	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	4750	 139	 0.032754	 0.0839	 0.001	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	3004	 140	 0.000729	 0.005118	 0.0933	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3004	 140	 0.000755	 0.005235	 0.0909	 419.0	 419.0	 419.0	 0.0	 0.0	 1	 -30.0	 30.0;
	850	 141	 0.001787	 0.01946	 0.4214	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	188	 142	 0.01615	 0.036583	 0.027	 761	 761	 761	 0.0	 0.0	 1	 -30.0	 30.0;
	1652	 142	 0.018645	 0.048123	 0.0006	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	2217	 142	 0.03351	 0.061476	 0.0006	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	2218	 142	 0.024943	 0.066264	 0.0007	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	3892	 142	 0.079617	 0.198035	 0.0025	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	5724	 142	 0.0194	 0.05291	 0.0006	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	3892	 142	 0.068279	 0.185689	 0.0021	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	1674	 143	 0.001719	 0.00877	 0.0157	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4135	 143	 0.009165	 0.04318	 0.077	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1553	 144	 0.070988	 0.185185	 0.0089	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	1560	 144	 0.000617	 0.001852	 0.0011	 16510	 16510	 16510	 0.0	 0.0	 1	 -30.0	 30.0;
	3694	 144	 0.010988	 0.068148	 0.0006	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	5043	 144	 0.005309	 0.034691	 0.0382	 915	 915	 915	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 144	 0.00963	 0.059753	 0.0032	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	1560	 144	 0.002346	 0.006173	 0.0002	 4881	 4881	 4881	 0.0	 0.0	 1	 -30.0	 30.0;
	506	 145	 0.004879	 0.032454	 0.0602	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	695	 145	 0.006341	 0.042746	 0.0785	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	758	 145	 0.006914	 0.031249	 0.0547	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1049	 146	 0.000582	 0.007652	 0.2643	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2722	 146	 0.001648	 0.021634	 0.748	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	3372	 146	 0.000838	 0.014301	 0.5198	 2227	 2227	 2227	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 146	 0.001163	 0.015312	 0.5285	 2077	 2077	 2077	 0.0	 0.0	 1	 -30.0	 30.0;
	1049	 146	 0.000575	 0.007576	 0.2614	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2722	 146	 0.001646	 0.021633	 0.7479	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	3372	 146	 0.000838	 0.014287	 0.5198	 2229	 2229	 2229	 0.0	 0.0	 1	 -30.0	 30.0;
	4600	 146	 0.00117	 0.015339	 0.5285	 2074	 2074	 2074	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 146	 0.001821	 0.017874	 0.4318	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4978	 147	 0.004485	 0.01683	 0.0154	 1696	 1696	 1696	 0.0	 0.0	 1	 -30.0	 30.0;
	481	 148	 0.003023	 0.01159	 0.0002	 2466	 2466	 2466	 0.0	 0.0	 1	 -30.0	 30.0;
	4244	 149	 0.022222	 0.060124	 0.0029	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	1994	 150	 0.007307	 0.030486	 0.0071	 942	 942	 942	 0.0	 0.0	 1	 -30.0	 30.0;
	4270	 152	 0.070043	 0.190728	 0.0021	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	4518	 151	 0.110103	 0.294533	 0.004	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	4701	 152	 0.034014	 0.145629	 0.0018	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	156	 151	 0.000171	 0.000313	 0.0003	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	3576	 153	 0.042328	 0.115898	 0.001	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 153	 0.021416	 0.061476	 0.001	 454	 454	 454	 0.0	 0.0	 1	 -30.0	 30.0;
	5725	 153	 0.0194	 0.053414	 0.001	 520	 520	 520	 0.0	 0.0	 1	 -30.0	 30.0;
	5484	 153	 0.021416	 0.061728	 0.0	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	1961	 154	 0.000672	 0.003477	 0.0365	 254.0	 254.0	 254.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5106	 155	 0.000831	 0.001688	 0.0	 16165	 16165	 16165	 0.0	 0.0	 1	 -30.0	 30.0;
	683	 157	 0.138123	 0.332	 0.001	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	4744	 158	 0.000988	 0.003457	 0.0	 7261	 7261	 7261	 0.0	 0.0	 1	 -30.0	 30.0;
	5810	 157	 0.008395	 0.02321	 0.0	 1058	 1058	 1058	 0.0	 0.0	 1	 -30.0	 30.0;
	1727	 159	 0.047518	 0.118922	 0.0013	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	2765	 159	 0.022928	 0.053414	 0.0006	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	2840	 159	 0.080373	 0.201562	 0.004	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	3693	 159	 0.019652	 0.05291	 0.001	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 161	 0.000632	 0.004188	 0.0081	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 160	 0.000612	 0.004148	 0.0071	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4620	 162	 0.024321	 0.06679	 0.0031	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	4666	 162	 0.015062	 0.041605	 0.0019	 672	 672	 672	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 164	 0.001587	 0.003527	 0.0013	 7864	 7864	 7864	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 163	 0.001587	 0.003527	 0.0013	 7864	 7864	 7864	 0.0	 0.0	 1	 -30.0	 30.0;
	1408	 167	 0.03642	 0.095185	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	1590	 167	 0.014938	 0.061852	 0.0046	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3620	 167	 0.043951	 0.11642	 0.007	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	3786	 166	 0.014815	 0.033457	 0.0015	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	4181	 166	 0.004198	 0.010741	 0.0013	 2576	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	4494	 166	 0.02	 0.049136	 0.0629	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 167	 0.014444	 0.036173	 0.0018	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	5191	 167	 0.015679	 0.042593	 0.0019	 655	 655	 655	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 166	 0.041975	 0.106173	 0.0125	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	3449	 166	 0.022753	 0.056914	 0.0028	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	5855	 166	 0.031235	 0.082839	 0.0042	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	3705	 168	 0.000672	 0.004405	 0.0081	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5665	 168	 0.000968	 0.004602	 0.0081	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3705	 168	 0.000632	 0.004444	 0.0081	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5107	 169	 0.016173	 0.044198	 0.0021	 632	 632	 632	 0.0	 0.0	 1	 -30.0	 30.0;
	2572	 170	 0.001481	 0.005679	 0.0267	 5167	 5167	 5167	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 170	 0.008642	 0.018272	 0.0045	 1501	 1501	 1501	 0.0	 0.0	 1	 -30.0	 30.0;
	1563	 171	 0.006173	 0.026296	 0.0015	 1123	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	4618	 171	 0.039753	 0.105062	 0.0073	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 171	 0.010617	 0.027407	 0.0034	 1032	 1032	 1032	 0.0	 0.0	 1	 -30.0	 30.0;
	1563	 171	 0.006173	 0.026173	 0.0013	 1128	 1128	 1128	 0.0	 0.0	 1	 -30.0	 30.0;
	5677	 172	 0.001975	 0.013215	 0.0243	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5678	 172	 0.001956	 0.013037	 0.0243	 2348	 2348	 2348	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 173	 0.000988	 0.004074	 0.0002	 8279	 8279	 8279	 0.0	 0.0	 1	 -30.0	 30.0;
	446	 174	 0.030494	 0.121605	 0.0071	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	5368	 174	 0.009877	 0.025062	 0.0011	 1284	 1284	 1284	 0.0	 0.0	 1	 -30.0	 30.0;
	1943	 174	 0.020741	 0.052469	 0.0003	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 175	 0.09675	 0.264298	 0.0029	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 175	 0.003275	 0.008566	 0.0001	 3317	 3317	 3317	 0.0	 0.0	 1	 -30.0	 30.0;
	5150	 176	 0.018896	 0.056185	 0.0006	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	5166	 176	 0.002771	 0.008314	 0.0001	 3471	 3471	 3471	 0.0	 0.0	 1	 -30.0	 30.0;
	4718	 177	 0.002933	 0.010267	 0.0032	 2959	 2959	 2959	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 177	 0.0028	 0.007511	 0.0022	 3941	 3941	 3941	 0.0	 0.0	 1	 -30.0	 30.0;
	183	 178	 2e-05	 0.000198	 0.0121	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	183	 179	 2e-05	 0.000198	 0.0142	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	911	 182	 0.001008	 0.002268	 0.0034	 11544	 11544	 11544	 0.0	 0.0	 1	 -30.0	 30.0;
	1447	 182	 0.002771	 0.007055	 0.0075	 3780	 3780	 3780	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 182	 0.008411	 0.015397	 0.0491	 1634	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	3467	 182	 0.008566	 0.016377	 0.0064	 1551	 1551	 1551	 0.0	 0.0	 1	 -30.0	 30.0;
	4932	 182	 0.006299	 0.01159	 0.0008	 2172	 2172	 2172	 0.0	 0.0	 1	 -30.0	 30.0;
	4937	 182	 0.002478	 0.004537	 0.0024	 5543	 5543	 5543	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 182	 0.006488	 0.011876	 0.015	 2118	 2118	 2118	 0.0	 0.0	 1	 -30.0	 30.0;
	912	 182	 0.001008	 0.002771	 0.0037	 9717	 9717	 9717	 0.0	 0.0	 1	 -30.0	 30.0;
	1447	 182	 0.003191	 0.005842	 0.0075	 4305	 4305	 4305	 0.0	 0.0	 1	 -30.0	 30.0;
	1447	 182	 0.002771	 0.007307	 0.0079	 3667	 3667	 3667	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 182	 0.000756	 0.002268	 0.003	 11985	 11985	 11985	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 182	 0.000974	 0.001783	 0.0033	 14102	 14102	 14102	 0.0	 0.0	 1	 -30.0	 30.0;
	993	 183	 0.000277	 0.000928	 0.2066	 31961	 31961	 31961	 0.0	 0.0	 1	 -30.0	 30.0;
	1050	 183	 0.002037	 0.010904	 0.0187	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1123	 183	 0.000415	 0.002015	 0.1266	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 183	 0.000395	 0.00156	 0.1893	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2106	 183	 4e-05	 0.000178	 0.0152	 169660	 169660	 169660	 0.0	 0.0	 1	 -30.0	 30.0;
	2968	 183	 0.001323	 0.012444	 0.0678	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4387	 183	 0.000454	 0.002133	 0.2511	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4942	 183	 0.000119	 0.000691	 0.1002	 387.0	 387.0	 387.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5035	 183	 0.00083	 0.005175	 0.0203	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	993	 183	 0.000277	 0.000928	 0.2086	 31961	 31961	 31961	 0.0	 0.0	 1	 -30.0	 30.0;
	2968	 183	 0.001314	 0.012115	 0.0673	 943.0	 943.0	 943.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4939	 183	 5.9e-05	 0.000217	 0.0496	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4938	 183	 5.9e-05	 0.000217	 0.0466	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5111	 184	 0.023583	 0.064324	 0.0007	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	4412	 185	 0.000854	 0.001563	 0.0007	 16578	 16578	 16578	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 186	 0.015369	 0.060469	 0.0013	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 187	 0.004314	 0.007897	 0.0123	 3370	 3370	 3370	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 188	 0.009625	 0.024339	 0.0003	 1163	 1163	 1163	 0.0	 0.0	 1	 -30.0	 30.0;
	5113	 189	 0.002593	 0.00716	 0.0003	 3901	 3901	 3901	 0.0	 0.0	 1	 -30.0	 30.0;
	5405	 190	 0.008566	 0.018896	 0.0002	 1466	 1466	 1466	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 191	 0.041068	 0.139078	 0.0016	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	5603	 191	 0.070547	 0.233132	 0.0127	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	5114	 192	 0.000494	 0.000988	 0.0	 23633	 23633	 23633	 0.0	 0.0	 1	 -30.0	 30.0;
	2751	 193	 0.018025	 0.049136	 0.0023	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	4833	 193	 0.024198	 0.061728	 0.0029	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	319	 194	 0.062232	 0.138574	 0.0015	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5095	 194	 0.035525	 0.084782	 0.0009	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	4096	 195	 0.000158	 0.000948	 0.002	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2506	 196	 0.043588	 0.119174	 0.0013	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	2781	 196	 0.095062	 0.299849	 0.0069	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	5336	 196	 0.048375	 0.166037	 0.002	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3215	 197	 0.004193	 0.007675	 0.0057	 3602	 3602	 3602	 0.0	 0.0	 1	 -30.0	 30.0;
	3215	 198	 0.004377	 0.008012	 0.0058	 3450	 3450	 3450	 0.0	 0.0	 1	 -30.0	 30.0;
	323	 199	 0.035273	 0.218443	 0.0029	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	572	 199	 0.000252	 0.000504	 0.0	 53974	 53974	 53974	 0.0	 0.0	 1	 -30.0	 30.0;
	931	 199	 0.034442	 0.11809	 0.0091	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	323	 199	 0.034266	 0.221466	 0.0	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	825	 200	 0.0839	 0.229025	 0.0025	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	1759	 200	 0.048627	 0.123205	 0.0014	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	5115	 201	 0.008025	 0.021852	 0.001	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	2457	 202	 0.001521	 0.007076	 0.0118	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4557	 202	 0.002469	 0.011457	 0.0203	 315.0	 315.0	 315.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 203	 0.001442	 0.009699	 0.0172	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1485	 203	 0.001422	 0.009541	 0.0172	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	394	 204	 0.024691	 0.056941	 0.001	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	1073	 204	 0.0194	 0.038549	 0.0033	 685	 685	 685	 0.0	 0.0	 1	 -30.0	 30.0;
	828	 205	 0.006914	 0.029259	 0.0015	 1051	 1051	 1051	 0.0	 0.0	 1	 -30.0	 30.0;
	1924	 205	 0.007037	 0.029877	 0.0015	 1030	 1030	 1030	 0.0	 0.0	 1	 -30.0	 30.0;
	2068	 205	 0.02037	 0.08642	 0.0044	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	2720	 205	 0.007531	 0.047037	 0.0047	 674	 674	 674	 0.0	 0.0	 1	 -30.0	 30.0;
	2994	 205	 0.019136	 0.051481	 0.0024	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	828	 205	 0.007531	 0.031605	 0.0016	 973	 973	 973	 0.0	 0.0	 1	 -30.0	 30.0;
	1924	 205	 0.00716	 0.031852	 0.0021	 968	 968	 968	 0.0	 0.0	 1	 -30.0	 30.0;
	1589	 206	 0.004681	 0.028227	 0.0516	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2721	 206	 0.001185	 0.008	 0.0152	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5695	 206	 0.005333	 0.02722	 0.0491	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2722	 207	 0.000145	 0.001911	 0.0661	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 207	 0.000253	 0.003323	 0.1148	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	394	 208	 0.018645	 0.041068	 0.0005	 655	 655	 655	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 208	 0.049131	 0.124465	 0.0014	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5134	 208	 0.02192	 0.091207	 0.0011	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	562	 209	 0.015117	 0.039808	 0.0005	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	562	 209	 0.015117	 0.039808	 0.0005	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	5586	 210	 0.012296	 0.031173	 0.0015	 905	 905	 905	 0.0	 0.0	 1	 -30.0	 30.0;
	5853	 210	 0.020988	 0.06716	 0.0032	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 211	 0.004787	 0.018141	 0.0002	 1574	 1574	 1574	 0.0	 0.0	 1	 -30.0	 30.0;
	1796	 213	 0.003779	 0.020912	 0.0028	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	4834	 212	 0.007055	 0.020408	 0.0002	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	1796	 213	 0.003779	 0.020912	 0.0028	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	3875	 214	 0.000494	 0.002252	 0.004	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3875	 215	 0.000494	 0.002252	 0.004	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	524	 216	 0.000741	 0.001358	 0.0036	 19602	 19602	 19602	 0.0	 0.0	 1	 -30.0	 30.0;
	1181	 216	 0.044444	 0.111728	 0.0053	 253	 253	 253	 0.0	 0.0	 1	 -30.0	 30.0;
	1418	 216	 0.093457	 0.227654	 0.0115	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	1737	 216	 0.024938	 0.06642	 0.0032	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	1884	 216	 0.045309	 0.116049	 0.0055	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 216	 0.06758	 0.184444	 0.0162	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	4910	 216	 0.065062	 0.177531	 0.0083	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	354	 217	 0.004563	 0.030696	 0.0557	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1135	 217	 0.009857	 0.04478	 0.077	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 217	 0.017106	 0.078321	 0.1387	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4622	 217	 0.010272	 0.048691	 0.0866	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 218	 0.11867	 0.311413	 0.0041	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	5419	 218	 0.087931	 0.176115	 0.0018	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	1516	 219	 0.057654	 0.152716	 0.0076	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	1582	 219	 0.037654	 0.101605	 0.0047	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	2770	 220	 0.00037	 0.001235	 0.0015	 23039	 23039	 23039	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 221	 0.013827	 0.037778	 0.0018	 739	 739	 739	 0.0	 0.0	 1	 -30.0	 30.0;
	5116	 222	 0.015631	 0.028612	 0.0002	 933	 933	 933	 0.0	 0.0	 1	 -30.0	 30.0;
	257	 223	 0.093978	 0.258755	 0.004	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	2044	 223	 0.160699	 0.294157	 0.003	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	4401	 223	 0.059209	 0.163265	 0.0019	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	1600	 224	 0.012978	 0.059338	 0.1002	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 224	 0.01197	 0.056632	 0.0942	 262.0	 262.0	 262.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2313	 225	 0.014613	 0.039808	 0.0005	 718	 718	 718	 0.0	 0.0	 1	 -30.0	 30.0;
	4156	 225	 0.114412	 0.301335	 0.0036	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	2313	 225	 0.026002	 0.055883	 0.0011	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 226	 0.000578	 0.001156	 0.0004	 24440	 24440	 24440	 0.0	 0.0	 1	 -30.0	 30.0;
	3834	 228	 0.000316	 0.001679	 0.0192	 17970	 17970	 17970	 0.0	 0.0	 1	 -30.0	 30.0;
	3834	 227	 0.000316	 0.001679	 0.0192	 17970	 17970	 17970	 0.0	 0.0	 1	 -30.0	 30.0;
	1550	 230	 0.06576	 0.166541	 0.0019	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	1550	 229	 0.063946	 0.174402	 0.002	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	423	 231	 0.015369	 0.064399	 0.0106	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	3141	 231	 0.163093	 0.298541	 0.0034	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	4562	 231	 0.017407	 0.031864	 0.0009	 838	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	423	 231	 0.015344	 0.064248	 0.0103	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	2492	 232	 0.000277	 0.000573	 0.0334	 48541	 48541	 48541	 0.0	 0.0	 1	 -30.0	 30.0;
	519	 233	 0.049383	 0.134444	 0.0063	 208	 208	 208	 0.0	 0.0	 1	 -30.0	 30.0;
	1868	 234	 0.009383	 0.039012	 0.0019	 772	 772	 772	 0.0	 0.0	 1	 -30.0	 30.0;
	4882	 234	 0.015803	 0.066543	 0.0034	 453	 453	 453	 0.0	 0.0	 1	 -30.0	 30.0;
	3671	 236	 0.009012	 0.029012	 0.0003	 1054	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	3672	 237	 0.001055	 0.004836	 0.0081	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	505	 238	 0.003951	 0.010247	 0.0005	 2910	 2910	 2910	 0.0	 0.0	 1	 -30.0	 30.0;
	1015	 239	 0.042303	 0.10708	 0.0017	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	3946	 239	 0.006047	 0.015117	 0.0	 1814	 1814	 1814	 0.0	 0.0	 1	 -30.0	 30.0;
	2699	 240	 0.035185	 0.095802	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	5014	 240	 0.039691	 0.108716	 0.0052	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	2381	 241	 0.081633	 0.151675	 0.0016	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 241	 0.057949	 0.240111	 0.003	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	5446	 241	 0.006299	 0.017133	 0.0038	 1618	 1618	 1618	 0.0	 0.0	 1	 -30.0	 30.0;
	5738	 241	 0.047871	 0.197783	 0.0025	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	362	 242	 0.044092	 0.11164	 0.0017	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	4558	 242	 0.003704	 0.023029	 0.0026	 1304	 1304	 1304	 0.0	 0.0	 1	 -30.0	 30.0;
	691	 243	 0.009111	 0.029012	 0.0043	 998	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	4452	 243	 0.020926	 0.060074	 0.0028	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	5497	 243	 0.014222	 0.048111	 0.0024	 605	 605	 605	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 244	 0.056437	 0.160242	 0.0019	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	5691	 244	 0.050894	 0.146384	 0.0017	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	3155	 245	 0.058957	 0.160494	 0.0018	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 245	 0.067019	 0.17032	 0.0019	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	1927	 246	 0.038148	 0.094691	 0.018	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	2355	 246	 0.034259	 0.085321	 0.0145	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	5121	 247	 0.058705	 0.164777	 0.0018	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	284	 248	 0.004031	 0.009826	 0.0001	 2780	 2780	 2780	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 248	 0.024943	 0.112371	 0.003	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 248	 0.006097	 0.011161	 0.0002	 2322	 2322	 2322	 0.0	 0.0	 1	 -30.0	 30.0;
	2453	 248	 0.106843	 0.195575	 0.0051	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	4732	 248	 0.010582	 0.039557	 0.001	 722	 722	 722	 0.0	 0.0	 1	 -30.0	 30.0;
	3580	 249	 0.002114	 0.008553	 0.0152	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3167	 250	 0.000198	 0.000731	 0.0942	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2114	 251	 0.058705	 0.235072	 0.0025	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	3569	 251	 0.042378	 0.116024	 0.0134	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	1271	 252	 0.087176	 0.228773	 0.0059	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	1627	 252	 0.092727	 0.169735	 0.005	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	2262	 252	 0.113127	 0.312169	 0.006	 92	 92	 92	 0.0	 0.0	 1	 -30.0	 30.0;
	2947	 253	 0.005424	 0.009929	 0.0373	 2626	 2626	 2626	 0.0	 0.0	 1	 -30.0	 30.0;
	4014	 254	 0.026667	 0.07037	 0.0032	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	5113	 254	 0.00963	 0.026049	 0.0011	 1070	 1070	 1070	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 255	 0.004812	 0.019703	 0.0002	 1500	 1500	 1500	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 255	 0.005039	 0.022424	 0.0002	 1324	 1324	 1324	 0.0	 0.0	 1	 -30.0	 30.0;
	1117	 256	 0.067599	 0.171378	 0.0019	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	3824	 256	 0.043336	 0.111363	 0.0013	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	4639	 256	 0.004787	 0.013102	 0.0002	 2181	 2181	 2181	 0.0	 0.0	 1	 -30.0	 30.0;
	558	 257	 0.166768	 0.305266	 0.003	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	1687	 257	 0.06198	 0.171076	 0.0042	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 258	 0.019652	 0.04258	 0.0	 649	 649	 649	 0.0	 0.0	 1	 -30.0	 30.0;
	4171	 258	 0.037365	 0.080247	 0.0009	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	4555	 258	 0.06198	 0.162409	 0.0017	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	4557	 259	 0.00324	 0.012616	 0.0225	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1113	 260	 0.005679	 0.015185	 0.0006	 1871	 1871	 1871	 0.0	 0.0	 1	 -30.0	 30.0;
	762	 261	 0.086288	 0.157948	 0.0015	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 261	 0.000882	 0.002494	 0.0021	 11497	 11497	 11497	 0.0	 0.0	 1	 -30.0	 30.0;
	4982	 262	 0.007522	 0.029736	 0.0496	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5805	 262	 0.006809	 0.03043	 0.0521	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5122	 263	 0.038297	 0.078861	 0.0	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 265	 0.002153	 0.014736	 0.0273	 565.0	 565.0	 565.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1629	 264	 0.000581	 0.003838	 0.0071	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 264	 0.001857	 0.020306	 0.0557	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4844	 265	 0.002331	 0.015526	 0.0278	 549.0	 549.0	 549.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5416	 264	 0.001345	 0.008968	 0.0162	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1628	 264	 0.000573	 0.003911	 0.0071	 415.0	 415.0	 415.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2205	 264	 0.001896	 0.012701	 0.0233	 501.0	 501.0	 501.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1945	 266	 0.000602	 0.006717	 0.1357	 1725.0	 1725.0	 1725.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2799	 266	 0.00063	 0.007098	 0.1588	 1916.0	 1916.0	 1916.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5071	 266	 0.000367	 0.004631	 0.1126	 2275.0	 2275.0	 2275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2799	 266	 0.000472	 0.006201	 0.2137	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 266	 0.001504	 0.019298	 0.4577	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	727	 267	 0.001844	 0.003375	 0.0026	 7450	 7450	 7450	 0.0	 0.0	 1	 -30.0	 30.0;
	738	 268	 0.000158	 0.001106	 0.1357	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1277	 269	 0.000219	 0.00193	 0.1954	 407.0	 407.0	 407.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1375	 269	 0.000158	 0.000909	 0.1316	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3529	 269	 0.000411	 0.00356	 0.3564	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3882	 268	 0.000158	 0.001264	 0.1286	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1905	 270	 0.045855	 0.121189	 0.0013	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	2682	 270	 0.064248	 0.156211	 0.0018	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	548	 271	 0.100277	 0.244898	 0.0026	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	5287	 271	 0.072411	 0.175888	 0.0019	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	2991	 273	 0.000198	 0.001383	 0.003	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2991	 272	 0.000217	 0.001402	 0.003	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1412	 274	 0.036029	 0.091711	 0.001	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	1701	 274	 0.018896	 0.047367	 0.0008	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	4450	 274	 0.003427	 0.009272	 0.0121	 2987	 2987	 2987	 0.0	 0.0	 1	 -30.0	 30.0;
	4837	 274	 0.006299	 0.018392	 0.0164	 1519	 1519	 1519	 0.0	 0.0	 1	 -30.0	 30.0;
	5254	 274	 0.017637	 0.044092	 0.0008	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	5802	 274	 0.046273	 0.084703	 0.0015	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	4450	 274	 0.00383	 0.008869	 0.0143	 3057	 3057	 3057	 0.0	 0.0	 1	 -30.0	 30.0;
	1325	 275	 0.001304	 0.008691	 0.0152	 525.0	 525.0	 525.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2991	 275	 0.000691	 0.004662	 0.0091	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1943	 276	 0.009506	 0.058889	 0.0039	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	1943	 276	 0.009383	 0.058765	 0.0031	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	280	 277	 9.9e-05	 0.000415	 0.0456	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1056	 278	 1e-06	 0.000104	 0.078	 1072.0	 1072.0	 1072.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 278	 0.000353	 0.004584	 0.1184	 2357.0	 2357.0	 2357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2460	 278	 0.000699	 0.009179	 0.3177	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 278	 0.000353	 0.004584	 0.1184	 2357.0	 2357.0	 2357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2460	 278	 0.000734	 0.009245	 0.3148	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1060	 278	 7e-06	 0.000104	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1059	 278	 7e-06	 0.000104	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 279	 0.01	 0.026667	 0.0046	 1043	 1043	 1043	 0.0	 0.0	 1	 -30.0	 30.0;
	985	 279	 0.049259	 0.114321	 0.0079	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	1058	 279	 0.019383	 0.049383	 0.0256	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	740	 279	 0.009877	 0.026667	 0.0046	 1045	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	1057	 279	 0.02037	 0.052469	 0.0097	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	1517	 280	 0.002556	 0.017333	 0.0805	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3705	 280	 0.008849	 0.062617	 0.1144	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2989	 281	 0.024943	 0.069287	 0.0	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 282	 0.032259	 0.085247	 0.0109	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 282	 0.051284	 0.130198	 0.0139	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 282	 0.049012	 0.133827	 0.0063	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 282	 0.006543	 0.026148	 0.1306	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 283	 0.136634	 0.39607	 0.0046	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 285	 0.000617	 0.001728	 0.0	 16188	 16188	 16188	 0.0	 0.0	 1	 -30.0	 30.0;
	449	 286	 0.010582	 0.03351	 0.0004	 866	 866	 866	 0.0	 0.0	 1	 -30.0	 30.0;
	2672	 286	 0.000227	 0.000907	 0.0013	 32529	 32529	 32529	 0.0	 0.0	 1	 -30.0	 30.0;
	3647	 286	 0.00907	 0.026707	 0.0103	 1079	 1079	 1079	 0.0	 0.0	 1	 -30.0	 30.0;
	5124	 287	 2.2e-05	 9.9e-05	 0.001	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5123	 288	 2e-05	 9.9e-05	 0.0	 306461	 306461	 306461	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 289	 0.025062	 0.064074	 0.0135	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	2322	 290	 1.2e-05	 0.000123	 0.0002	 240340	 240340	 240340	 0.0	 0.0	 1	 -30.0	 30.0;
	2913	 290	 0.00679	 0.013704	 0.0523	 1943	 1943	 1943	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 290	 0.022346	 0.075432	 0.0037	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 290	 1.2e-05	 0.000123	 0.0002	 240340	 240340	 240340	 0.0	 0.0	 1	 -30.0	 30.0;
	2628	 291	 0.000573	 0.002588	 0.0051	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 292	 0.002407	 0.006741	 0.0242	 4503	 4503	 4503	 0.0	 0.0	 1	 -30.0	 30.0;
	2171	 293	 0.102041	 0.259007	 0.0029	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	2633	 293	 0.060555	 0.110845	 0.0026	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	3155	 293	 0.053918	 0.146888	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5203	 293	 0.047367	 0.19098	 0.0021	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	294	 295	 0.00385	 0.007048	 0.0043	 3677	 3677	 3677	 0.0	 0.0	 1	 -30.0	 30.0;
	481	 295	 0.039808	 0.117914	 0.0111	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	1569	 295	 0.019854	 0.04772	 0.0085	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	1243	 296	 0.011208	 0.020515	 0.0007	 1302	 1302	 1302	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 297	 2e-05	 0.000198	 0.001	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1303	 298	 0.085412	 0.216931	 0.0024	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	1755	 299	 0.003275	 0.008062	 0.0001	 3394	 3394	 3394	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 300	 0.027715	 0.069791	 0.001	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	2165	 301	 0.000988	 0.003827	 0.001	 8155	 8155	 8155	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 302	 0.000138	 0.00077	 0.001	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5126	 303	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	1344	 304	 0.006551	 0.028219	 0.042	 1020	 1020	 1020	 0.0	 0.0	 1	 -30.0	 30.0;
	1344	 304	 0.005291	 0.024036	 0.0256	 1200	 1200	 1200	 0.0	 0.0	 1	 -30.0	 30.0;
	199	 305	 0.036533	 0.120433	 0.0015	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	4591	 305	 0.071303	 0.195263	 0.0022	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	5746	 305	 0.046259	 0.156664	 0.0024	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	199	 305	 0.036533	 0.120433	 0.0015	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	4591	 305	 0.071378	 0.195288	 0.0022	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	4831	 306	 0.039305	 0.163517	 0.0072	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	5410	 306	 0.04006	 0.090703	 0.0039	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	689	 307	 0.091993	 0.168392	 0.001	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	4688	 307	 0.059713	 0.134543	 0.001	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	3898	 308	 0.090023	 0.243966	 0.0043	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	2485	 309	 0.055309	 0.140247	 0.0065	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4933	 309	 0.027531	 0.070124	 0.0032	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	1309	 310	 0.023003	 0.052003	 0.0006	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	4579	 310	 0.01358	 0.034114	 0.0004	 829	 829	 829	 0.0	 0.0	 1	 -30.0	 30.0;
	1638	 312	 0.001512	 0.010078	 0.014	 2898	 2898	 2898	 0.0	 0.0	 1	 -30.0	 30.0;
	1638	 311	 0.006551	 0.012094	 0.0046	 2147	 2147	 2147	 0.0	 0.0	 1	 -30.0	 30.0;
	5622	 313	 0.003951	 0.007901	 0.0003	 3363	 3363	 3363	 0.0	 0.0	 1	 -30.0	 30.0;
	3152	 314	 0.000123	 0.001235	 0.0006	 24326	 24326	 24326	 0.0	 0.0	 1	 -30.0	 30.0;
	2644	 315	 0.003049	 0.011111	 0.0172	 2640	 2640	 2640	 0.0	 0.0	 1	 -30.0	 30.0;
	5159	 315	 0.024188	 0.061476	 0.0007	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	5158	 315	 0.008818	 0.053918	 0.0007	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	653	 316	 0.001171	 0.007842	 0.0166	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3032	 316	 0.002212	 0.014979	 0.0388	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 317	 0.025309	 0.057778	 0.0026	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	5128	 317	 0.000741	 0.001852	 0.0002	 15203	 15203	 15203	 0.0	 0.0	 1	 -30.0	 30.0;
	2288	 318	 0.021416	 0.086672	 0.0011	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	5287	 318	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 318	 0.00252	 0.006551	 0.0001	 4334	 4334	 4334	 0.0	 0.0	 1	 -30.0	 30.0;
	2288	 318	 0.021164	 0.08642	 0.0011	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	3297	 319	 0.083799	 0.195137	 0.0022	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	3275	 320	 0.002585	 0.004732	 0.0029	 5314	 5314	 5314	 0.0	 0.0	 1	 -30.0	 30.0;
	5129	 321	 0.000479	 0.001285	 0.0	 22178	 22178	 22178	 0.0	 0.0	 1	 -30.0	 30.0;
	1257	 322	 0.019259	 0.061728	 0.0021	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	1657	 322	 0.020123	 0.051111	 0.0021	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	829	 323	 0.008679	 0.015886	 0.0142	 1681	 1681	 1681	 0.0	 0.0	 1	 -30.0	 30.0;
	2310	 323	 0.035878	 0.14646	 0.0	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	3127	 323	 0.009675	 0.060166	 0.0022	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	3147	 323	 0.039053	 0.145377	 0.0054	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	4568	 323	 0.040312	 0.118166	 0.0049	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	2310	 323	 0.036054	 0.147241	 0.0074	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	3127	 323	 0.0097	 0.060393	 0.0027	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	3147	 323	 0.020408	 0.13026	 0.0016	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	3127	 323	 0.020106	 0.076216	 0.0011	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	4152	 324	 0.000691	 0.002588	 0.1691	 11556	 11556	 11556	 0.0	 0.0	 1	 -30.0	 30.0;
	4153	 324	 0.000691	 0.002588	 0.1509	 11556	 11556	 11556	 0.0	 0.0	 1	 -30.0	 30.0;
	1935	 325	 0.001627	 0.014855	 0.3899	 1717.0	 1717.0	 1717.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1935	 325	 0.001676	 0.013899	 0.4216	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2311	 326	 0.002771	 0.009574	 0.0091	 2963	 2963	 2963	 0.0	 0.0	 1	 -30.0	 30.0;
	1682	 326	 0.002771	 0.010834	 0.016	 2641	 2641	 2641	 0.0	 0.0	 1	 -30.0	 30.0;
	521	 327	 0.027186	 0.073369	 0.0039	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	520	 327	 0.027085	 0.073243	 0.0034	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	1844	 328	 0.023285	 0.042623	 0.0	 627	 627	 627	 0.0	 0.0	 1	 -30.0	 30.0;
	2612	 328	 0.04258	 0.112371	 0.0012	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	2926	 328	 0.062988	 0.133535	 0.0017	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	4119	 328	 0.006677	 0.035122	 0.0059	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	5376	 328	 0.039053	 0.099017	 0.0011	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	4119	 328	 0.006551	 0.035021	 0.0059	 854	 854	 854	 0.0	 0.0	 1	 -30.0	 30.0;
	1795	 329	 0.003081	 0.020286	 0.0365	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3087	 329	 0.00241	 0.01603	 0.0294	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 330	 0.034014	 0.100025	 0.0012	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 330	 0.048526	 0.153691	 0.0023	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	2271	 331	 0.001605	 0.009877	 0.0342	 3207	 3207	 3207	 0.0	 0.0	 1	 -30.0	 30.0;
	2271	 331	 0.00284	 0.006049	 0.0031	 4803	 4803	 4803	 0.0	 0.0	 1	 -30.0	 30.0;
	4398	 332	 0.0194	 0.049635	 0.0022	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	4653	 332	 0.000252	 0.00126	 0.0	 23670	 23670	 23670	 0.0	 0.0	 1	 -30.0	 30.0;
	4748	 332	 0.028975	 0.075082	 0.0009	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	4669	 333	 0.000176	 0.001385	 0.1521	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 333	 0.001817	 0.012642	 0.0233	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 333	 0.001865	 0.012502	 0.0229	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1366	 334	 0.039053	 0.099269	 0.0011	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	3685	 334	 0.074578	 0.195767	 0.0022	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	1010	 335	 0.007422	 0.024489	 0.0081	 1190	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	1615	 335	 0.028356	 0.083956	 0.0274	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	2551	 335	 0.016844	 0.058489	 0.0198	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	4766	 335	 0.009067	 0.028133	 0.0095	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	5266	 336	 0.051146	 0.143613	 0.0016	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	1137	 337	 0.001008	 0.00252	 0.0	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	2825	 338	 0.028723	 0.075082	 0.0009	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	4923	 338	 0.01285	 0.032502	 0.0004	 871	 871	 871	 0.0	 0.0	 1	 -30.0	 30.0;
	2506	 339	 0.098514	 0.257748	 0.0029	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	2648	 339	 0.179853	 0.329219	 0.0038	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	1700	 340	 0.039557	 0.089695	 0.001	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 340	 0.053726	 0.098344	 0.0014	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	3297	 341	 0.111615	 0.283699	 0.0033	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	3501	 341	 0.037213	 0.126279	 0.0015	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 341	 0.090199	 0.228773	 0.0026	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	3064	 342	 0.054938	 0.149753	 0.007	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	3385	 343	 0.067574	 0.180927	 0.0108	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3238	 344	 0.041824	 0.115394	 0.0013	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	3889	 344	 0.041975	 0.173293	 0.0021	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5407	 344	 0.015117	 0.080625	 0.0006	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	5131	 345	 0.000593	 0.00401	 0.0071	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1864	 346	 0.055959	 0.123205	 0.0037	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	4523	 346	 0.130763	 0.331822	 0.0039	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	5299	 346	 0.116906	 0.21416	 0.0029	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	670	 347	 0.048272	 0.114444	 0.0049	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	1731	 347	 0.065679	 0.150988	 0.0068	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 348	 0.010351	 0.032395	 0.0562	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	5456	 348	 0.009146	 0.025778	 0.041	 1123	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	4921	 349	 0.060217	 0.164273	 0.0018	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	445	 350	 0.022839	 0.046914	 0.0021	 616	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	3382	 350	 0.035062	 0.071852	 0.0074	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	3318	 351	 0.000395	 0.006648	 0.2426	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3372	 351	 0.000492	 0.008345	 0.3032	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3775	 352	 0.001198	 0.015699	 0.5401	 2026	 2026	 2026	 0.0	 0.0	 1	 -30.0	 30.0;
	3908	 352	 0.000734	 0.010623	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 351	 0.001479	 0.019446	 0.6729	 1636	 1636	 1636	 0.0	 0.0	 1	 -30.0	 30.0;
	4830	 352	 0.000305	 0.003975	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3319	 351	 0.000395	 0.006641	 0.2426	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3372	 352	 0.000492	 0.008338	 0.3032	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3775	 351	 0.001184	 0.015568	 0.5372	 2043	 2043	 2043	 0.0	 0.0	 1	 -30.0	 30.0;
	3908	 351	 0.000734	 0.010623	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4600	 352	 0.001482	 0.019467	 0.6729	 1634	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	4830	 351	 0.000305	 0.003982	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3320	 352	 0.000388	 0.0066	 0.2397	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3317	 352	 0.000388	 0.006593	 0.2397	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4028	 353	 0.001817	 0.012049	 0.0233	 439.0	 439.0	 439.0	 0.0	 0.0	 1	 -30.0	 30.0;
	557	 354	 0.003496	 0.023269	 0.0425	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	880	 355	 0.03225	 0.10456	 0.0013	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2697	 355	 0.004558	 0.008344	 0.0062	 3014	 3014	 3014	 0.0	 0.0	 1	 -30.0	 30.0;
	5850	 355	 0.018645	 0.063996	 0.0007	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 356	 0.001008	 0.00252	 0.0	 11206	 11206	 11206	 0.0	 0.0	 1	 -30.0	 30.0;
	1358	 357	 0.050139	 0.112371	 0.0012	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	360	 358	 0.004031	 0.010078	 0.0001	 2802	 2802	 2802	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 359	 0.114764	 0.210075	 0.006	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	3151	 359	 0.065294	 0.11952	 0.0013	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	3879	 359	 0.037818	 0.16125	 0.0025	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	2299	 360	 0.07231	 0.176619	 0.002	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	3031	 360	 0.053414	 0.133787	 0.001	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5136	 360	 0.002268	 0.005014	 0.0001	 5527	 5527	 5527	 0.0	 0.0	 1	 -30.0	 30.0;
	5617	 360	 0.006551	 0.016881	 0.0002	 1680	 1680	 1680	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 361	 0.028723	 0.06324	 0.0007	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	4024	 362	 0.028849	 0.113731	 0.042	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	4558	 362	 0.004031	 0.024691	 0.0003	 1216	 1216	 1216	 0.0	 0.0	 1	 -30.0	 30.0;
	4924	 362	 0.016881	 0.042832	 0.0005	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 362	 0.008239	 0.053641	 0.0017	 561	 561	 561	 0.0	 0.0	 1	 -30.0	 30.0;
	2354	 363	 0.030213	 0.105538	 0.0315	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 363	 0.019498	 0.06712	 0.0206	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	2450	 364	 0.006262	 0.040849	 0.0749	 398.0	 398.0	 398.0	 0.0	 0.0	 1	 -30.0	 30.0;
	491	 365	 0.008272	 0.035062	 0.0171	 860	 860	 860	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 365	 0.002346	 0.009877	 0.0002	 3419	 3419	 3419	 0.0	 0.0	 1	 -30.0	 30.0;
	5109	 365	 0.002346	 0.009753	 0.0002	 3460	 3460	 3460	 0.0	 0.0	 1	 -30.0	 30.0;
	4400	 366	 2e-05	 0.000198	 0.003	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	4740	 367	 0.001114	 0.002039	 0.0009	 12708	 12708	 12708	 0.0	 0.0	 1	 -30.0	 30.0;
	2138	 368	 0.001936	 0.0128	 0.0182	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	858	 371	 2e-05	 0.000198	 0.0081	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 371	 0.000296	 0.000988	 0.2207	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	859	 372	 8.5e-05	 0.000198	 0.0192	 386.0	 386.0	 386.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3013	 373	 0.025145	 0.068808	 0.0008	 416	 416	 416	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 373	 0.011892	 0.061199	 0.0007	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	1902	 374	 0.002487	 0.016492	 0.0304	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2175	 374	 0.000873	 0.003563	 0.004	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2763	 374	 0.003563	 0.023682	 0.044	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3765	 374	 0.002724	 0.018108	 0.0334	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2174	 374	 0.000873	 0.003563	 0.004	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 375	 0.000257	 0.000928	 0.1134	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3552	 376	 0.0839	 0.212648	 0.0024	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	3666	 376	 0.083396	 0.21164	 0.0024	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	1173	 377	 0.055309	 0.150988	 0.0071	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	1779	 377	 0.039753	 0.108519	 0.005	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	2584	 377	 0.034691	 0.094568	 0.0044	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 378	 0.049383	 0.137062	 0.0016	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	2103	 378	 0.029479	 0.186445	 0.0024	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2103	 378	 0.02973	 0.188461	 0.0024	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	646	 379	 0.047292	 0.098262	 0.0011	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	2328	 379	 0.066012	 0.13681	 0.0015	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	2774	 379	 0.046107	 0.127236	 0.0014	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	403	 380	 0.069035	 0.187957	 0.0021	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	1256	 380	 0.057924	 0.106028	 0.0026	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	1537	 380	 0.174099	 0.45553	 0.0051	 61	 61	 61	 0.0	 0.0	 1	 -30.0	 30.0;
	1908	 380	 0.083396	 0.211892	 0.0051	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	4093	 380	 0.127992	 0.330814	 0.004	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	4896	 380	 0.081381	 0.206097	 0.0036	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	5017	 380	 0.03351	 0.09675	 0.003	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	4896	 380	 0.062988	 0.200302	 0.004	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	5017	 380	 0.03351	 0.09675	 0.003	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	470	 381	 0.002291	 0.009936	 0.0304	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3101	 381	 0.004168	 0.028918	 0.0597	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3943	 381	 0.002054	 0.024691	 0.1276	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 381	 0.004879	 0.032533	 0.0607	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4999	 381	 0.005294	 0.036998	 0.0668	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 381	 0.001422	 0.009896	 0.0172	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 382	 0.002168	 0.029238	 0.9906	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	2074	 382	 0.001468	 0.01491	 0.3841	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2772	 382	 0.002479	 0.028151	 0.6296	 1128	 1128	 1128	 0.0	 0.0	 1	 -30.0	 30.0;
	3944	 382	 0.00072	 0.00946	 0.3263	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2073	 382	 0.00142	 0.01617	 0.3636	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2772	 382	 0.002486	 0.028165	 0.6296	 1127	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	4294	 382	 0.001184	 0.016073	 0.4869	 1979	 1979	 1979	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 383	 0.033333	 0.08321	 0.0039	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 383	 0.016543	 0.041975	 0.0019	 673	 673	 673	 0.0	 0.0	 1	 -30.0	 30.0;
	2431	 384	 0.102797	 0.262031	 0.0029	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	3698	 384	 0.078534	 0.19229	 0.0021	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	5424	 384	 0.014361	 0.036785	 0.0012	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	941	 385	 0.037289	 0.152381	 0.002	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	3800	 385	 0.082263	 0.222676	 0.0025	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	941	 385	 0.037264	 0.15223	 0.0023	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	3800	 385	 0.082263	 0.222676	 0.0025	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	2442	 386	 0.080877	 0.164021	 0.0016	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	5232	 386	 0.052406	 0.143361	 0.0017	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5761	 386	 0.096643	 0.176905	 0.0017	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	2931	 387	 0.088687	 0.230033	 0.0002	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5778	 387	 0.033258	 0.089947	 0.001	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	3032	 388	 0.000521	 0.002315	 0.019	 13045	 13045	 13045	 0.0	 0.0	 1	 -30.0	 30.0;
	1595	 389	 0.018272	 0.07679	 0.0039	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 389	 0.013765	 0.057852	 0.007	 510	 510	 510	 0.0	 0.0	 1	 -30.0	 30.0;
	2714	 390	 0.006667	 0.043457	 0.0003	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	3539	 390	 0.024691	 0.103704	 0.0016	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 391	 0.002016	 0.004283	 0.0021	 6238	 6238	 6238	 0.0	 0.0	 1	 -30.0	 30.0;
	1881	 391	 0.008793	 0.026405	 0.0003	 1061	 1061	 1061	 0.0	 0.0	 1	 -30.0	 30.0;
	3855	 391	 0.013958	 0.087679	 0.0011	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	4688	 391	 0.075913	 0.210683	 0.0023	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	1402	 391	 0.002135	 0.003909	 0.0034	 6629	 6629	 6629	 0.0	 0.0	 1	 -30.0	 30.0;
	4595	 392	 0.053918	 0.138574	 0.0016	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	5729	 392	 0.014865	 0.038045	 0.0004	 723	 723	 723	 0.0	 0.0	 1	 -30.0	 30.0;
	1725	 393	 0.031746	 0.072058	 0.0008	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 393	 0.090703	 0.247669	 0.0028	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	2329	 393	 0.061225	 0.148652	 0.0016	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	2473	 393	 0.16513	 0.330511	 0.0096	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	3941	 393	 0.031998	 0.08642	 0.001	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	5607	 394	 0.018645	 0.077097	 0.001	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	1912	 395	 0.057308	 0.104902	 0.001	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	397	 396	 0.001008	 0.002268	 0.0	 12255	 12255	 12255	 0.0	 0.0	 1	 -30.0	 30.0;
	1791	 397	 0.00252	 0.015369	 0.0002	 1953	 1953	 1953	 0.0	 0.0	 1	 -30.0	 30.0;
	4564	 397	 0.004001	 0.007323	 0.0	 3645	 3645	 3645	 0.0	 0.0	 1	 -30.0	 30.0;
	1791	 397	 0.002268	 0.015369	 0.0002	 1958	 1958	 1958	 0.0	 0.0	 1	 -30.0	 30.0;
	3872	 398	 0.015621	 0.081355	 0.001	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	4089	 398	 0.016175	 0.085462	 0.0014	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	2400	 399	 0.053918	 0.184933	 0.0	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3851	 399	 0.066264	 0.227261	 0.0	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 400	 0.005432	 0.013827	 0.0066	 2000	 2000	 2000	 0.0	 0.0	 1	 -30.0	 30.0;
	848	 401	 0.000504	 0.00252	 0.0006	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	2242	 402	 0.056286	 0.153515	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 402	 0.07231	 0.184429	 0.0021	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	2305	 404	 0.073593	 0.163333	 0.007	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 404	 0.084197	 0.191605	 0.0089	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	2775	 405	 0.019652	 0.055682	 0.0061	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	5172	 405	 0.069035	 0.142353	 0.001	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	2297	 406	 0.023683	 0.067775	 0.0	 412	 412	 412	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 406	 0.004031	 0.015369	 0.0185	 1859	 1859	 1859	 0.0	 0.0	 1	 -30.0	 30.0;
	1083	 407	 0.020242	 0.037052	 0.0011	 700	 700	 700	 0.0	 0.0	 1	 -30.0	 30.0;
	1024	 408	 0.016049	 0.045679	 0.0076	 614	 614	 614	 0.0	 0.0	 1	 -30.0	 30.0;
	1866	 408	 0.00584	 0.019309	 0.001	 1473	 1473	 1473	 0.0	 0.0	 1	 -30.0	 30.0;
	4014	 408	 0.010864	 0.035803	 0.0018	 794	 794	 794	 0.0	 0.0	 1	 -30.0	 30.0;
	2362	 409	 0.008605	 0.022012	 0.001	 1257	 1257	 1257	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 409	 0.013173	 0.041235	 0.002	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	2819	 410	 0.085664	 0.233711	 0.0028	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	488	 411	 0.012963	 0.035062	 0.0028	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	1062	 411	 0.004691	 0.012963	 0.0018	 2155	 2155	 2155	 0.0	 0.0	 1	 -30.0	 30.0;
	1869	 412	 0.023457	 0.098765	 0.005	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	3197	 412	 0.02021	 0.085111	 0.0044	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	1637	 413	 0.016881	 0.069035	 0.0017	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	2047	 413	 0.076342	 0.184933	 0.0024	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 413	 0.027261	 0.115294	 0.0019	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	4081	 413	 0.057848	 0.157823	 0.0046	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	1145	 414	 0.065004	 0.18065	 0.0019	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	1145	 414	 0.062232	 0.178634	 0.0019	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	4195	 415	 0.059209	 0.150416	 0.0021	 188	 188	 188	 0.0	 0.0	 1	 -30.0	 30.0;
	5141	 415	 0.000176	 0.000454	 0.0	 60637	 60637	 60637	 0.0	 0.0	 1	 -30.0	 30.0;
	1246	 416	 0.070295	 0.181658	 0.0021	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	3673	 416	 0.067271	 0.173091	 0.002	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	4446	 416	 0.001008	 0.003275	 0.0004	 8876	 8876	 8876	 0.0	 0.0	 1	 -30.0	 30.0;
	543	 417	 0.000178	 0.000909	 0.002	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	856	 418	 0.067019	 0.2129	 0.0024	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	3679	 418	 0.07735	 0.263542	 0.0029	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 418	 0.087377	 0.23996	 0.0028	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	3742	 419	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	4316	 420	 0.082389	 0.209121	 0.0024	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	5144	 420	 0.013354	 0.03477	 0.0004	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	5142	 420	 0.003779	 0.023432	 0.0003	 1282	 1282	 1282	 0.0	 0.0	 1	 -30.0	 30.0;
	5142	 421	 0.004031	 0.010834	 0.0002	 2632	 2632	 2632	 0.0	 0.0	 1	 -30.0	 30.0;
	3555	 422	 0.001512	 0.003023	 0.0013	 8736	 8736	 8736	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 423	 0.039305	 0.173217	 0.0571	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 423	 0.039305	 0.173293	 0.0571	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	849	 424	 0.00241	 0.015694	 0.0294	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2782	 424	 0.006874	 0.044761	 0.0835	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1567	 425	 0.051146	 0.139078	 0.0019	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	3411	 425	 0.05165	 0.140842	 0.0016	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	4022	 425	 0.018645	 0.050643	 0.002	 564	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	4530	 425	 0.074074	 0.188713	 0.0036	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	1567	 425	 0.051398	 0.14059	 0.0016	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	4022	 425	 0.017637	 0.048375	 0.002	 591	 591	 591	 0.0	 0.0	 1	 -30.0	 30.0;
	4022	 425	 0.017637	 0.048375	 0.002	 591	 591	 591	 0.0	 0.0	 1	 -30.0	 30.0;
	2763	 426	 0.001521	 0.021728	 0.0871	 831.0	 831.0	 831.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5707	 426	 0.001304	 0.017205	 0.0729	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5143	 427	 0.001678	 0.003072	 0.0	 8185	 8185	 8185	 0.0	 0.0	 1	 -30.0	 30.0;
	1155	 428	 0.008314	 0.018645	 0.0002	 1447	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 429	 0.008314	 0.022928	 0.0002	 1211	 1211	 1211	 0.0	 0.0	 1	 -30.0	 30.0;
	3874	 430	 0.006047	 0.015873	 0.0002	 1739	 1739	 1739	 0.0	 0.0	 1	 -30.0	 30.0;
	5209	 430	 0.00252	 0.006299	 0.0004	 4352	 4352	 4352	 0.0	 0.0	 1	 -30.0	 30.0;
	3874	 430	 0.005795	 0.016125	 0.0002	 1724	 1724	 1724	 0.0	 0.0	 1	 -30.0	 30.0;
	1666	 430	 0.021083	 0.038593	 0.0004	 672	 672	 672	 0.0	 0.0	 1	 -30.0	 30.0;
	1051	 431	 0.000336	 0.001363	 0.1499	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1269	 431	 0.000178	 0.001422	 0.1448	 339.0	 339.0	 339.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3297	 432	 0.052482	 0.176846	 0.0022	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	3207	 433	 0.147392	 0.387503	 0.0044	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	4009	 433	 0.124465	 0.321492	 0.0	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	879	 434	 0.001764	 0.004535	 0.0001	 5888	 5888	 5888	 0.0	 0.0	 1	 -30.0	 30.0;
	1448	 435	 0.03351	 0.108214	 0.0013	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	5475	 435	 0.018392	 0.060217	 0.0008	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	986	 436	 0.027531	 0.072222	 0.0034	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	3064	 436	 0.036173	 0.098518	 0.0047	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5273	 436	 0.016049	 0.042716	 0.0	 665	 665	 665	 0.0	 0.0	 1	 -30.0	 30.0;
	2847	 436	 0.031605	 0.088889	 0.004	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	3064	 436	 0.034815	 0.095062	 0.0044	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	3988	 437	 0.080121	 0.168304	 0.0018	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5703	 437	 0.046863	 0.196019	 0.0024	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	2553	 438	 0.009322	 0.021668	 0.0004	 1320	 1320	 1320	 0.0	 0.0	 1	 -30.0	 30.0;
	2986	 439	 0.052397	 0.095912	 0.001	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	1673	 440	 0.023885	 0.059587	 0.0012	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	2218	 440	 0.032903	 0.060228	 0.0006	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 440	 0.031721	 0.081885	 0.0013	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	5147	 441	 0.000403	 0.001109	 0.0	 25776	 25776	 25776	 0.0	 0.0	 1	 -30.0	 30.0;
	5145	 442	 0.006047	 0.025951	 0.0	 1109	 1109	 1109	 0.0	 0.0	 1	 -30.0	 30.0;
	2759	 443	 0.025447	 0.067775	 0.0008	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	4218	 443	 0.024188	 0.064752	 0.012	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	1558	 444	 0.014074	 0.059136	 0.0038	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	1651	 446	 0.002469	 0.015679	 0.0008	 2031	 2031	 2031	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 444	 0.008272	 0.035062	 0.0028	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	4870	 446	 0.005062	 0.01037	 0.0005	 2793	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	5338	 444	 0.007531	 0.019259	 0.0019	 1672	 1672	 1672	 0.0	 0.0	 1	 -30.0	 30.0;
	1651	 446	 0.002469	 0.015679	 0.0008	 2031	 2031	 2031	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 445	 0.008272	 0.034815	 0.0046	 897	 897	 897	 0.0	 0.0	 1	 -30.0	 30.0;
	4870	 446	 0.005062	 0.010494	 0.0005	 2767	 2767	 2767	 0.0	 0.0	 1	 -30.0	 30.0;
	4844	 447	 0.002252	 0.011951	 0.0218	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5149	 447	 0.00079	 0.005333	 0.0101	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3595	 448	 0.008062	 0.020408	 0.0002	 1346	 1346	 1346	 0.0	 0.0	 1	 -30.0	 30.0;
	1233	 449	 0.027211	 0.172336	 0.0117	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	2908	 449	 0.015117	 0.065004	 0.0008	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	3984	 449	 0.02372	 0.043419	 0.0005	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	2908	 449	 0.014109	 0.038549	 0.0015	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	1343	 450	 0.001501	 0.010015	 0.0182	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1433	 450	 0.003103	 0.021146	 0.04	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 450	 0.00162	 0.010765	 0.0203	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5604	 450	 0.001807	 0.017201	 0.0618	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	501	 450	 0.000217	 0.001442	 0.003	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 450	 0.00162	 0.010726	 0.0203	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 450	 0.000119	 0.001086	 0.004	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2245	 451	 0.00072	 0.009453	 0.3263	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 451	 0.003206	 0.03536	 0.9025	 899	 899	 899	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 451	 0.000616	 0.008054	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2245	 451	 0.000713	 0.009384	 0.3235	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 451	 0.000616	 0.008061	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	502	 451	 3.5e-05	 0.000374	 0.0087	 921.0	 921.0	 921.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5153	 452	 0.000756	 0.00252	 0.0	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	463	 453	 0.106324	 0.289746	 0.0033	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	2338	 453	 0.060217	 0.168808	 0.0018	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	2701	 453	 0.048879	 0.124717	 0.0013	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	3714	 453	 0.058705	 0.152935	 0.0017	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	2338	 453	 0.060972	 0.169312	 0.0018	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	3440	 453	 0.008818	 0.025195	 0.0002	 1107	 1107	 1107	 0.0	 0.0	 1	 -30.0	 30.0;
	3547	 454	 0.013393	 0.069551	 0.1261	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3667	 454	 0.013491	 0.070361	 0.1271	 412.0	 412.0	 412.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 455	 0.006299	 0.017385	 0.0002	 1645	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	4067	 457	 0.002346	 0.006296	 0.0002	 4777	 4777	 4777	 0.0	 0.0	 1	 -30.0	 30.0;
	4067	 456	 0.002346	 0.00642	 0.0003	 4695	 4695	 4695	 0.0	 0.0	 1	 -30.0	 30.0;
	4247	 458	 0.001764	 0.004535	 0.0048	 6068	 6068	 6068	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 459	 0.001956	 0.010469	 0.3286	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3622	 459	 0.001402	 0.010173	 0.2673	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4677	 460	 0.000648	 0.00657	 0.1704	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4677	 460	 0.000651	 0.006572	 0.1704	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3174	 461	 0.004485	 0.020282	 0.0241	 1465	 1465	 1465	 0.0	 0.0	 1	 -30.0	 30.0;
	4022	 462	 0.05029	 0.138246	 0.0033	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 463	 0.05165	 0.140842	 0.0016	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 464	 0.002963	 0.008025	 0.0003	 3473	 3473	 3473	 0.0	 0.0	 1	 -30.0	 30.0;
	2714	 466	 0.003311	 0.006061	 0.0112	 4634	 4634	 4634	 0.0	 0.0	 1	 -30.0	 30.0;
	5157	 467	 2.5e-05	 0.00252	 0.0001	 11716	 11716	 11716	 0.0	 0.0	 1	 -30.0	 30.0;
	2184	 468	 0.002016	 0.005039	 0.0093	 5279	 5279	 5279	 0.0	 0.0	 1	 -30.0	 30.0;
	3481	 468	 0.022681	 0.041517	 0.0216	 606	 606	 606	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 469	 0.011086	 0.028219	 0.0301	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	2184	 468	 0.001512	 0.005291	 0.0095	 5207	 5207	 5207	 0.0	 0.0	 1	 -30.0	 30.0;
	3480	 468	 0.022761	 0.041664	 0.0218	 604	 604	 604	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 469	 0.011086	 0.028219	 0.0302	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	2184	 468	 0.002016	 0.005039	 0.0091	 5279	 5279	 5279	 0.0	 0.0	 1	 -30.0	 30.0;
	2989	 471	 0.078181	 0.17866	 0.0021	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 472	 0.062358	 0.148047	 0.0068	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	3345	 472	 0.018392	 0.05291	 0.001	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	3745	 472	 0.011208	 0.020515	 0.0002	 1264	 1264	 1264	 0.0	 0.0	 1	 -30.0	 30.0;
	2722	 474	 1e-05	 0.0001	 0.0029	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2722	 473	 1e-05	 0.0001	 0.0029	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4299	 475	 0.012568	 0.033383	 0.0066	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	4300	 475	 0.012568	 0.033383	 0.0066	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	2173	 476	 0.035777	 0.088435	 0.001	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	3876	 476	 0.027211	 0.072058	 0.0009	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	5575	 477	 0.027715	 0.070547	 0.0	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	3764	 478	 0.008062	 0.03351	 0.0004	 883	 883	 883	 0.0	 0.0	 1	 -30.0	 30.0;
	3764	 478	 0.008062	 0.03351	 0.0004	 883	 883	 883	 0.0	 0.0	 1	 -30.0	 30.0;
	4046	 479	 0.059259	 0.163457	 0.0	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	641	 480	 0.008062	 0.027463	 0.0021	 1032	 1032	 1032	 0.0	 0.0	 1	 -30.0	 30.0;
	1834	 480	 0.01033	 0.036029	 0.003	 788	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	3579	 480	 0.000252	 0.00126	 0.0021	 22978	 22978	 22978	 0.0	 0.0	 1	 -30.0	 30.0;
	975	 481	 0.000436	 0.000797	 0.0006	 32501	 32501	 32501	 0.0	 0.0	 1	 -30.0	 30.0;
	1568	 481	 0.012002	 0.02197	 0.0233	 1180	 1180	 1180	 0.0	 0.0	 1	 -30.0	 30.0;
	2147	 481	 0.074578	 0.197279	 0.003	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	2167	 481	 0.005039	 0.01285	 0.0002	 2140	 2140	 2140	 0.0	 0.0	 1	 -30.0	 30.0;
	3156	 481	 0.003527	 0.01285	 0.0015	 2216	 2216	 2216	 0.0	 0.0	 1	 -30.0	 30.0;
	1569	 481	 0.015042	 0.040539	 0.0164	 683	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	2168	 481	 0.005039	 0.01285	 0.0002	 2140	 2140	 2140	 0.0	 0.0	 1	 -30.0	 30.0;
	2169	 481	 0.003023	 0.013102	 0.0002	 2196	 2196	 2196	 0.0	 0.0	 1	 -30.0	 30.0;
	2148	 482	 0.00332	 0.015328	 0.0267	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2013	 483	 0.047972	 0.124465	 0.0037	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	2511	 484	 0.007307	 0.029226	 0.0316	 1010	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	5442	 484	 0.006551	 0.01285	 0.0128	 2109	 2109	 2109	 0.0	 0.0	 1	 -30.0	 30.0;
	5598	 484	 0.001512	 0.004283	 0.0001	 6697	 6697	 6697	 0.0	 0.0	 1	 -30.0	 30.0;
	5603	 484	 0.001008	 0.003779	 0.0001	 7777	 7777	 7777	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 485	 0.010864	 0.045062	 0.0305	 641	 641	 641	 0.0	 0.0	 1	 -30.0	 30.0;
	4176	 485	 0.010494	 0.04321	 0.0245	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	3546	 486	 0.108088	 0.349458	 0.0048	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	5158	 487	 0.010078	 0.025447	 0.0003	 1112	 1112	 1112	 0.0	 0.0	 1	 -30.0	 30.0;
	1029	 488	 0.04642	 0.125432	 0.0058	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	1062	 488	 0.022963	 0.062346	 0.0058	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	652	 489	 0.011338	 0.027715	 0.0	 1016	 1016	 1016	 0.0	 0.0	 1	 -30.0	 30.0;
	3641	 489	 0.018896	 0.053666	 0.0	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	2262	 490	 0.035525	 0.097758	 0.0011	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	2620	 490	 0.049131	 0.135047	 0.0013	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	2202	 491	 0.010864	 0.070494	 0.0006	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	5160	 492	 2.4e-05	 9.7e-05	 0.001	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3572	 493	 0.028496	 0.059461	 0.0006	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	5083	 493	 0.074074	 0.152683	 0.002	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	593	 494	 9.9e-05	 0.000198	 0.0223	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	594	 495	 1.4e-05	 0.000145	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	594	 496	 7e-06	 0.000159	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	594	 497	 1.4e-05	 0.000166	 0.0058	 1737.0	 1737.0	 1737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	594	 498	 1.4e-05	 0.00018	 0.0058	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2157	 499	 0.001008	 0.00252	 0.0019	 11206	 11206	 11206	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 503	 0.018148	 0.085185	 0.004	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	2564	 503	 0.035679	 0.097901	 0.0047	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5199	 503	 0.056173	 0.23963	 0.0121	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	3980	 504	 0.017654	 0.074815	 0.0076	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	3979	 504	 0.017778	 0.074074	 0.0081	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	735	 505	 0.044815	 0.11642	 0.0008	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 505	 0.040494	 0.104198	 0.0049	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	1816	 505	 0.009753	 0.026049	 0.0013	 1243	 1243	 1243	 0.0	 0.0	 1	 -30.0	 30.0;
	5120	 505	 0.000123	 0.001235	 0.0002	 27851	 27851	 27851	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 505	 0.009753	 0.026049	 0.0002	 1243	 1243	 1243	 0.0	 0.0	 1	 -30.0	 30.0;
	2669	 507	 0.020408	 0.066264	 0.0013	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	4344	 507	 0.009322	 0.02973	 0.0019	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	5161	 508	 0.010124	 0.025679	 0.0011	 1077	 1077	 1077	 0.0	 0.0	 1	 -30.0	 30.0;
	5162	 508	 0.010247	 0.025926	 0.0013	 1066	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	3983	 509	 0.047329	 0.086634	 0.0007	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	1564	 510	 0.021111	 0.121111	 0.006	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	5229	 510	 0.016173	 0.091235	 0.005	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 511	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	5620	 511	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 512	 0.000251	 0.002177	 0.2187	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2970	 513	 0.001084	 0.014247	 0.491	 2232	 2232	 2232	 0.0	 0.0	 1	 -30.0	 30.0;
	3153	 513	 0.000492	 0.006489	 0.2224	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3236	 513	 7e-06	 0.000152	 0.0058	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2971	 513	 0.001112	 0.01462	 0.5054	 2175	 2175	 2175	 0.0	 0.0	 1	 -30.0	 30.0;
	3154	 513	 0.000492	 0.006489	 0.2238	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3237	 513	 7e-06	 0.000104	 0.0029	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1081	 514	 0.023086	 0.061111	 0.0029	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	2589	 514	 0.024938	 0.065802	 0.0031	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	1194	 515	 0.099585	 0.18229	 0.0019	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	5455	 516	 0.011842	 0.032502	 0.0004	 880	 880	 880	 0.0	 0.0	 1	 -30.0	 30.0;
	2266	 517	 0.031746	 0.072058	 0.001	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	3213	 517	 0.028219	 0.069539	 0.0015	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	564	 518	 0.088183	 0.199295	 0.0021	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	4200	 519	 0.044568	 0.11321	 0.0053	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	4312	 519	 0.054691	 0.140864	 0.0066	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	1405	 520	 0.016377	 0.102041	 0.0017	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	2891	 520	 0.018392	 0.084908	 0.0021	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 521	 0.011766	 0.048702	 0.0026	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	3674	 520	 0.005719	 0.022726	 0.0023	 1260	 1260	 1260	 0.0	 0.0	 1	 -30.0	 30.0;
	3839	 521	 0.040816	 0.117914	 0.0061	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 520	 0.044596	 0.113631	 0.0037	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	5657	 521	 0.004661	 0.018392	 0.0022	 1557	 1557	 1557	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 520	 0.013883	 0.056009	 0.0025	 512	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 522	 0.001264	 0.00964	 0.0375	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1406	 522	 0.001264	 0.008415	 0.0152	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2881	 522	 0.002627	 0.012188	 0.0218	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2892	 522	 0.001063	 0.007064	 0.0132	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4464	 522	 0.002489	 0.016711	 0.0304	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 522	 0.0016	 0.014933	 0.0537	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 522	 0.001264	 0.009659	 0.0405	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	958	 523	 0.000501	 0.005472	 0.1155	 1429.0	 1429.0	 1429.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2918	 523	 0.000429	 0.004737	 0.1011	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1131	 525	 0.040564	 0.086924	 0.001	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	1921	 525	 0.04006	 0.107836	 0.0012	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	2958	 525	 0.035651	 0.095087	 0.0011	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 525	 0.011842	 0.031746	 0.0003	 872	 872	 872	 0.0	 0.0	 1	 -30.0	 30.0;
	3316	 525	 0.015117	 0.032502	 0.0004	 824	 824	 824	 0.0	 0.0	 1	 -30.0	 30.0;
	4250	 525	 0.07357	 0.192744	 0.0021	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	4692	 525	 0.013303	 0.035072	 0.0004	 788	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	4767	 525	 0.058201	 0.147644	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	5555	 525	 0.012572	 0.033207	 0.0003	 832	 832	 832	 0.0	 0.0	 1	 -30.0	 30.0;
	5699	 525	 0.065508	 0.233812	 0.0033	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	4691	 525	 0.010834	 0.035777	 0.0004	 790	 790	 790	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 526	 0.000553	 0.003714	 0.0116	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1444	 526	 0.003951	 0.020148	 0.0511	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4596	 526	 0.007447	 0.034884	 0.0628	 397.0	 397.0	 397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4704	 526	 0.000632	 0.004286	 0.0081	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 526	 0.000553	 0.003714	 0.0121	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3538	 526	 0.001106	 0.005353	 0.0091	 5617	 5617	 5617	 0.0	 0.0	 1	 -30.0	 30.0;
	4704	 526	 0.000672	 0.004543	 0.0081	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	528	 527	 0.003149	 0.007962	 0.0001	 3553	 3553	 3553	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 527	 0.018166	 0.094533	 0.0071	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	1842	 527	 0.019425	 0.101209	 0.0084	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 529	 0.003527	 0.008818	 0.0003	 3109	 3109	 3109	 0.0	 0.0	 1	 -30.0	 30.0;
	531	 530	 2.5e-05	 0.000252	 0.0003	 113138	 113138	 113138	 0.0	 0.0	 1	 -30.0	 30.0;
	1395	 530	 0.013754	 0.025176	 0.0118	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	1395	 530	 0.011276	 0.02064	 0.0109	 1219	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 532	 0.008314	 0.01683	 0.0143	 1527	 1527	 1527	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 532	 0.008314	 0.016528	 0.014	 1549	 1549	 1549	 0.0	 0.0	 1	 -30.0	 30.0;
	662	 533	 0.008852	 0.029938	 0.0015	 952	 952	 952	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 533	 0.009049	 0.023296	 0.0011	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	2880	 533	 0.000123	 0.000741	 0.0	 39543	 39543	 39543	 0.0	 0.0	 1	 -30.0	 30.0;
	3459	 533	 0.017531	 0.047778	 0.0023	 584	 584	 584	 0.0	 0.0	 1	 -30.0	 30.0;
	5681	 533	 0.010988	 0.02963	 0.0015	 940	 940	 940	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 533	 0.004444	 0.008889	 0.0003	 2989	 2989	 2989	 0.0	 0.0	 1	 -30.0	 30.0;
	662	 533	 0.009259	 0.029333	 0.0015	 966	 966	 966	 0.0	 0.0	 1	 -30.0	 30.0;
	3459	 533	 0.009753	 0.040617	 0.0021	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	5538	 533	 0.006049	 0.025062	 0.0013	 1153	 1153	 1153	 0.0	 0.0	 1	 -30.0	 30.0;
	3259	 534	 0.004188	 0.027872	 0.0516	 485.0	 485.0	 485.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4773	 534	 0.00322	 0.022183	 0.0395	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4773	 534	 0.00322	 0.022183	 0.0395	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	645	 535	 0.035049	 0.095617	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	1320	 535	 0.032099	 0.081728	 0.0039	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	1356	 535	 0.049876	 0.121235	 0.0058	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	1193	 536	 0.034517	 0.092719	 0.003	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	5385	 536	 0.06198	 0.16125	 0.0021	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	1134	 537	 0.053086	 0.144321	 0.0068	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	2100	 538	 0.029012	 0.081605	 0.0	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	1344	 539	 0.008115	 0.014854	 0.0098	 1745	 1745	 1745	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 540	 0.000217	 0.00081	 0.1013	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 541	 0.000257	 0.000988	 0.1215	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2090	 542	 0.02037	 0.05358	 0.0045	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	2685	 542	 0.017901	 0.057778	 0.0028	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	2988	 542	 0.000988	 0.004074	 0.0005	 7234	 7234	 7234	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 542	 0.005185	 0.016049	 0.0008	 1798	 1798	 1798	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 543	 0.003358	 0.02242	 0.0415	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5677	 543	 0.003437	 0.022933	 0.0425	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1685	 544	 0.05417	 0.111111	 0.0012	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	5167	 544	 0.06387	 0.131318	 0.0014	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	5577	 545	 0.02973	 0.081129	 0.0009	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	5598	 545	 0.031746	 0.086924	 0.001	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 546	 0.000252	 0.000504	 0.0	 53974	 53974	 53974	 0.0	 0.0	 1	 -30.0	 30.0;
	5811	 546	 0.001008	 0.003023	 0.0	 9545	 9545	 9545	 0.0	 0.0	 1	 -30.0	 30.0;
	2600	 547	 0.061225	 0.153691	 0.0015	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5130	 547	 0.099043	 0.241547	 0.0023	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	3072	 548	 0.001764	 0.005039	 0.0001	 5697	 5697	 5697	 0.0	 0.0	 1	 -30.0	 30.0;
	3200	 549	 0.052154	 0.112623	 0.0013	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	1543	 550	 0.012346	 0.032716	 0.0016	 868	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	2735	 550	 0.075309	 0.190988	 0.0091	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3570	 550	 0.015926	 0.041605	 0.0019	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	5196	 550	 0.020123	 0.051111	 0.0024	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	1543	 550	 0.015679	 0.040494	 0.0019	 699	 699	 699	 0.0	 0.0	 1	 -30.0	 30.0;
	1192	 551	 0.045352	 0.114386	 0.0013	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	1556	 551	 0.060721	 0.154699	 0.0021	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	3394	 552	 0.03351	 0.069539	 0.0067	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	5706	 552	 0.031368	 0.064752	 0.001	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 553	 0.017133	 0.054422	 0.0006	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	4894	 553	 0.144873	 0.279919	 0.003	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 553	 0.017133	 0.054422	 0.0006	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 555	 0.002145	 0.009679	 0.017	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 554	 0.002125	 0.009576	 0.0168	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1793	 556	 0.000691	 0.001383	 0.2045	 20021	 20021	 20021	 0.0	 0.0	 1	 -30.0	 30.0;
	3907	 557	 0.001699	 0.011299	 0.0213	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1137	 558	 0.054674	 0.175359	 0.002	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	3074	 558	 0.099017	 0.282187	 0.003	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	3644	 558	 0.029226	 0.09297	 0.001	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	4376	 558	 0.003023	 0.010078	 0.0099	 2807	 2807	 2807	 0.0	 0.0	 1	 -30.0	 30.0;
	5408	 559	 0.003527	 0.00907	 0.0001	 3126	 3126	 3126	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 560	 0.045603	 0.11615	 0.0013	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	1132	 561	 0.050864	 0.130617	 0.006	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 561	 0.040741	 0.103704	 0.0049	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	2660	 562	 0.04006	 0.109599	 0.0013	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 562	 0.035777	 0.09549	 0.0011	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	1444	 563	 0.0048	 0.022637	 0.0405	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3089	 563	 0.003319	 0.015664	 0.0263	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	851	 564	 0.031267	 0.19413	 0.0025	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	2983	 564	 0.003779	 0.010078	 0.0005	 2826	 2826	 2826	 0.0	 0.0	 1	 -30.0	 30.0;
	851	 564	 0.031267	 0.194104	 0.0025	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	1014	 565	 0.024938	 0.068148	 0.0032	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	4237	 565	 0.024198	 0.065802	 0.0031	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 566	 0.029151	 0.079289	 0.0009	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	5806	 566	 0.030562	 0.083371	 0.0009	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	4533	 567	 0.001008	 0.00252	 0.0	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	2310	 568	 0.016881	 0.055682	 0.0	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	5028	 568	 0.065256	 0.219451	 0.0025	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	584	 569	 0.048803	 0.131973	 0.0015	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	4219	 569	 0.0839	 0.233308	 0.003	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	1072	 570	 0.015369	 0.037541	 0.0	 750	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	3324	 570	 0.094986	 0.236332	 0.0025	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	1903	 571	 0.063668	 0.160393	 0.0018	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 571	 0.020408	 0.052658	 0.001	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	1184	 573	 0.053704	 0.141111	 0.0066	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	3891	 573	 0.046543	 0.118025	 0.0055	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 573	 0.02	 0.054691	 0.0026	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 573	 0.022593	 0.071852	 0.0036	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	3114	 573	 0.042716	 0.116667	 0.0055	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	5702	 573	 0.021728	 0.059506	 0.0028	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	1576	 574	 0.175697	 0.321613	 0.003	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	2044	 574	 0.123346	 0.225783	 0.002	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	1825	 575	 0.001696	 0.003104	 0.0005	 8751	 8751	 8751	 0.0	 0.0	 1	 -30.0	 30.0;
	653	 576	 0.000514	 0.001541	 0.1144	 19054	 19054	 19054	 0.0	 0.0	 1	 -30.0	 30.0;
	5170	 577	 0.00252	 0.006878	 0.0001	 4152	 4152	 4152	 0.0	 0.0	 1	 -30.0	 30.0;
	1211	 579	 0.00324	 0.034272	 0.1336	 892	 892	 892	 0.0	 0.0	 1	 -30.0	 30.0;
	1726	 580	 0.005077	 0.023783	 0.0425	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3253	 580	 0.002368	 0.018825	 0.0511	 519.0	 519.0	 519.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 580	 0.003279	 0.043101	 0.1822	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 580	 0.0014	 0.011018	 0.0192	 519.0	 519.0	 519.0	 0.0	 0.0	 1	 -30.0	 30.0;
	579	 578	 4.8e-05	 8.8e-05	 0.004	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3530	 581	 0.000102	 0.001632	 0.0491	 2450.0	 2450.0	 2450.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 582	 0.005291	 0.011338	 0.0102	 2290	 2290	 2290	 0.0	 0.0	 1	 -30.0	 30.0;
	3041	 583	 0.005543	 0.014109	 0.0002	 1948	 1948	 1948	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 584	 0.038196	 0.104182	 0.0012	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	1156	 585	 0.033762	 0.104056	 0.001	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	4983	 585	 0.017637	 0.050139	 0.001	 556	 556	 556	 0.0	 0.0	 1	 -30.0	 30.0;
	5277	 585	 0.010078	 0.031494	 0.0	 893	 893	 893	 0.0	 0.0	 1	 -30.0	 30.0;
	2431	 586	 0.024213	 0.076921	 0.0015	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	2496	 586	 0.018645	 0.059713	 0.0007	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	5172	 587	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 588	 0.027407	 0.071852	 0.0034	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	5692	 588	 0.017407	 0.045556	 0.0021	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	1525	 589	 0.001027	 0.017738	 0.0101	 1954	 1954	 1954	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 589	 0.000318	 0.002424	 0.0052	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1524	 589	 0.001027	 0.017738	 0.0101	 1954	 1954	 1954	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 589	 0.000397	 0.002657	 0.0051	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5173	 590	 0.000101	 0.00252	 0.0	 11707	 11707	 11707	 0.0	 0.0	 1	 -30.0	 30.0;
	3207	 591	 0.058201	 0.15873	 0.0017	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	4009	 591	 0.119602	 0.316553	 0.0038	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	4009	 591	 0.119577	 0.316503	 0.004	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	2645	 592	 0.035777	 0.097506	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	3033	 594	 0.000637	 0.008255	 0.2123	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3517	 594	 0.000688	 0.009993	 0.257	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1333	 594	 0.000443	 0.006454	 0.1675	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3516	 594	 0.000688	 0.009993	 0.257	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1333	 594	 0.000464	 0.006766	 0.1762	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1333	 594	 0.000464	 0.006773	 0.1762	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 595	 0.008519	 0.016049	 0.0007	 1635	 1635	 1635	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 596	 0.013328	 0.059864	 0.0006	 496	 496	 496	 0.0	 0.0	 1	 -30.0	 30.0;
	3519	 597	 0.001025	 0.004614	 0.0081	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1516	 598	 0.052963	 0.205926	 0.0119	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	1852	 599	 0.045855	 0.116402	 0.0013	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	5730	 599	 0.019148	 0.053162	 0.0006	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	2688	 600	 0.007778	 0.028642	 0.0015	 1022	 1022	 1022	 0.0	 0.0	 1	 -30.0	 30.0;
	5352	 600	 0.024284	 0.063691	 0.003	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	736	 601	 0.023126	 0.042332	 0.0004	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	1888	 601	 0.01232	 0.034543	 0.0298	 830	 830	 830	 0.0	 0.0	 1	 -30.0	 30.0;
	2060	 601	 0.061275	 0.155707	 0.0047	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	3854	 601	 0.001461	 0.004006	 0.0007	 7133	 7133	 7133	 0.0	 0.0	 1	 -30.0	 30.0;
	1888	 601	 0.01232	 0.034543	 0.0298	 830	 830	 830	 0.0	 0.0	 1	 -30.0	 30.0;
	3364	 602	 0.001934	 0.01293	 0.024	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 602	 0.004642	 0.03089	 0.0573	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	607	 605	 0.000968	 0.001975	 0.0081	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	607	 604	 0.000968	 0.001975	 0.001	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	607	 603	 0.000968	 0.001975	 0.001	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2379	 606	 0.076846	 0.209373	 0.0024	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	3945	 606	 0.091711	 0.258251	 0.0049	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	4328	 606	 0.026707	 0.072562	 0.0008	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	2785	 607	 0.00348	 0.023956	 0.0456	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3605	 607	 0.002449	 0.017106	 0.0304	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5265	 607	 0.006001	 0.041452	 0.078	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	880	 608	 0.027715	 0.184429	 0.0025	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	4369	 608	 0.006551	 0.04258	 0.0006	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 610	 4e-05	 0.000198	 0.0	 153231	 153231	 153231	 0.0	 0.0	 1	 -30.0	 30.0;
	3339	 611	 0.047407	 0.129383	 0.006	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	2189	 612	 0.075082	 0.226757	 0.0026	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	5375	 612	 0.03099	 0.114386	 0.0014	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	3090	 613	 0.04006	 0.109095	 0.0009	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2264	 614	 0.001205	 0.005511	 0.0091	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 615	 0.01438	 0.065067	 0.1154	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 615	 0.003538	 0.016484	 0.0273	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3603	 615	 0.012634	 0.056573	 0.1008	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 615	 0.003516	 0.016158	 0.0273	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5331	 615	 0.00316	 0.014914	 0.0253	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 615	 0.007704	 0.034647	 0.0607	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 615	 0.002489	 0.016257	 0.0294	 410.0	 410.0	 410.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1006	 615	 0.003457	 0.015467	 0.0273	 309.0	 309.0	 309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2772	 616	 0.006579	 0.049467	 1.0137	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	3939	 616	 0.001357	 0.014821	 0.3321	 1171.0	 1171.0	 1171.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5176	 618	 0.000504	 0.003023	 0.0	 9349	 9349	 9349	 0.0	 0.0	 1	 -30.0	 30.0;
	5180	 617	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 619	 0.003527	 0.006551	 0.0076	 3851	 3851	 3851	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 620	 0.002771	 0.007307	 0.0077	 3667	 3667	 3667	 0.0	 0.0	 1	 -30.0	 30.0;
	1246	 621	 0.022928	 0.060721	 0.0007	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	4898	 622	 0.04258	 0.119678	 0.001	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5038	 622	 0.031494	 0.082137	 0.001	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 622	 0.004787	 0.013605	 0.001	 2048	 2048	 2048	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 622	 0.033006	 0.122449	 0.001	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	2706	 623	 0.00352	 0.014823	 0.0263	 2032	 2032	 2032	 0.0	 0.0	 1	 -30.0	 30.0;
	817	 624	 0.004334	 0.011489	 0.013	 2405	 2405	 2405	 0.0	 0.0	 1	 -30.0	 30.0;
	1107	 624	 0.009322	 0.058957	 0.0033	 495	 495	 495	 0.0	 0.0	 1	 -30.0	 30.0;
	2596	 624	 0.017385	 0.110607	 0.004	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 627	 0.001111	 0.003244	 0.0014	 8880	 8880	 8880	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 628	 0.018395	 0.050099	 0.0023	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	5181	 631	 2e-05	 0.000198	 0.0223	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	5184	 630	 9.9e-05	 0.000296	 0.004	 99170	 99170	 99170	 0.0	 0.0	 1	 -30.0	 30.0;
	4233	 632	 0.024389	 0.066516	 0.0007	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	5182	 633	 0.000756	 0.002016	 0.0	 13714	 13714	 13714	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 634	 0.157974	 0.39229	 0.0049	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	4284	 634	 0.215495	 0.516578	 0.0058	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	2463	 635	 0.01033	 0.028219	 0.0003	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	2543	 635	 0.066264	 0.221718	 0.0027	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 635	 0.027211	 0.08642	 0.001	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	2793	 636	 0.084656	 0.214916	 0.003	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	4567	 636	 0.049131	 0.124465	 0.001	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5705	 636	 0.066264	 0.147644	 0.002	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	1110	 637	 0.035926	 0.100864	 0.0049	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	3982	 637	 0.02037	 0.058272	 0.0028	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	5157	 638	 0.000504	 0.001008	 0.001	 26199	 26199	 26199	 0.0	 0.0	 1	 -30.0	 30.0;
	5062	 639	 0.000936	 0.006236	 0.0146	 441.0	 441.0	 441.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3939	 640	 0.000111	 0.001026	 0.0884	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1000	 642	 0.010859	 0.033384	 0.0319	 842	 842	 842	 0.0	 0.0	 1	 -30.0	 30.0;
	1344	 643	 0.013667	 0.025018	 0.0102	 1036	 1036	 1036	 0.0	 0.0	 1	 -30.0	 30.0;
	1344	 644	 0.014521	 0.026581	 0.0111	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	1356	 645	 0.039136	 0.164198	 0.0083	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	4284	 646	 0.094054	 0.195112	 0.0064	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	1740	 647	 0.025951	 0.083648	 0.001	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	4457	 647	 0.007811	 0.023432	 0.0137	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	1740	 647	 0.019652	 0.082892	 0.001	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 647	 0.018443	 0.068178	 0.0152	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	5789	 647	 0.004283	 0.016881	 0.0005	 1696	 1696	 1696	 0.0	 0.0	 1	 -30.0	 30.0;
	1785	 648	 0.006652	 0.028269	 0.0137	 1017	 1017	 1017	 0.0	 0.0	 1	 -30.0	 30.0;
	5187	 648	 0.002419	 0.0064	 0.0072	 4316	 4316	 4316	 0.0	 0.0	 1	 -30.0	 30.0;
	3181	 649	 0.039808	 0.101537	 0.0	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	3578	 649	 0.059965	 0.152431	 0.001	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	5226	 649	 0.042832	 0.121189	 0.0	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 650	 0.011358	 0.031852	 0.0015	 879	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 651	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	2005	 652	 0.026405	 0.082792	 0.0072	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	2753	 652	 0.078962	 0.217737	 0.0167	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	2862	 652	 0.009977	 0.060393	 0.0031	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	4373	 652	 0.035796	 0.065524	 0.0048	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	5159	 652	 0.015344	 0.039103	 0.0014	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	5432	 652	 0.041572	 0.119426	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	1077	 652	 0.1581	 0.413883	 0.0054	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	2190	 652	 0.043008	 0.113782	 0.0031	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	5158	 652	 0.006198	 0.037642	 0.002	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	3400	 653	 0.001636	 0.010939	 0.0216	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2172	 654	 0.07677	 0.194835	 0.0021	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	3764	 654	 0.071651	 0.131155	 0.0098	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	4120	 655	 0.044344	 0.269085	 0.0001	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	1210	 656	 0.004535	 0.026707	 0.0045	 1090	 1090	 1090	 0.0	 0.0	 1	 -30.0	 30.0;
	3871	 656	 0.008062	 0.015369	 0.0117	 1702	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	1210	 656	 0.015747	 0.039909	 0.0005	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 657	 0.000257	 0.001758	 0.003	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3816	 657	 0.00162	 0.011121	 0.0213	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1625	 658	 0.00252	 0.006047	 0.0001	 4374	 4374	 4374	 0.0	 0.0	 1	 -30.0	 30.0;
	1432	 659	 0.03477	 0.094734	 0.001	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	5247	 659	 0.003779	 0.008818	 0.0001	 3171	 3171	 3171	 0.0	 0.0	 1	 -30.0	 30.0;
	5641	 660	 0.003173	 0.008432	 0.0005	 3297	 3297	 3297	 0.0	 0.0	 1	 -30.0	 30.0;
	4890	 661	 0.011185	 0.030482	 0.0014	 934	 934	 934	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 666	 1.4e-05	 0.000173	 0.0982	 183736	 183736	 183736	 0.0	 0.0	 1	 -30.0	 30.0;
	4465	 665	 1.4e-05	 0.000187	 0.0809	 170060	 170060	 170060	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 664	 1.4e-05	 0.000201	 0.0058	 158275	 158275	 158275	 0.0	 0.0	 1	 -30.0	 30.0;
	4465	 663	 1.4e-05	 0.000201	 0.0058	 158275	 158275	 158275	 0.0	 0.0	 1	 -30.0	 30.0;
	1821	 667	 0.038297	 0.171403	 0.0026	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	2532	 667	 0.119929	 0.324767	 0.0003	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	2557	 667	 0.044596	 0.286722	 0.0003	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	2767	 667	 0.131771	 0.295792	 0.0038	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	2229	 667	 0.006551	 0.017133	 0.0002	 1698	 1698	 1698	 0.0	 0.0	 1	 -30.0	 30.0;
	3672	 668	 0.005215	 0.035002	 0.0638	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2770	 669	 0.020494	 0.064938	 0.0031	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	4846	 669	 0.016914	 0.072593	 0.0036	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	5820	 669	 0.021482	 0.067284	 0.0032	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	4846	 669	 0.016914	 0.072716	 0.0036	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	1506	 670	 0.02037	 0.085185	 0.0044	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	2024	 670	 0.015309	 0.066296	 0.0029	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 670	 0.046543	 0.147531	 0.0072	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	1390	 671	 0.064349	 0.163291	 0.0018	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	3850	 671	 0.027916	 0.112976	 0.0013	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	4911	 671	 0.09229	 0.251852	 0.0033	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	3380	 672	 0.038801	 0.079617	 0.0009	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	3064	 673	 0.039506	 0.079012	 0.0036	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	1755	 674	 0.045603	 0.12522	 0.001	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	1674	 675	 0.001397	 0.009306	 0.0172	 340.0	 340.0	 340.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2715	 675	 0.003415	 0.021827	 0.04	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2823	 676	 0.015815	 0.042765	 0.0038	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	5398	 676	 0.01721	 0.046852	 0.0028	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	5192	 677	 2e-05	 9.9e-05	 0.0	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4933	 678	 0.012346	 0.034691	 0.0032	 807	 807	 807	 0.0	 0.0	 1	 -30.0	 30.0;
	2683	 679	 0.051111	 0.129383	 0.0062	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 680	 0.00952	 0.017427	 0.016	 1443	 1443	 1443	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 680	 0.009515	 0.017417	 0.0159	 1444	 1444	 1444	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 680	 0.008818	 0.016377	 0.0112	 1541	 1541	 1541	 0.0	 0.0	 1	 -30.0	 30.0;
	1318	 681	 0.043336	 0.082137	 0.0008	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5193	 681	 0.000171	 0.000313	 0.0	 85273	 85273	 85273	 0.0	 0.0	 1	 -30.0	 30.0;
	3903	 682	 0.0194	 0.081885	 0.0013	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	2000	 683	 0.022222	 0.047407	 0.0002	 499	 499	 499	 0.0	 0.0	 1	 -30.0	 30.0;
	5415	 683	 0.034568	 0.075062	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 684	 7e-06	 0.000132	 0.0058	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 685	 0.000171	 0.000313	 0.001	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 686	 7e-06	 0.000104	 0.0029	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2347	 687	 0.000525	 0.000961	 0.0032	 27692	 27692	 27692	 0.0	 0.0	 1	 -30.0	 30.0;
	2348	 688	 0.000483	 0.000885	 0.0031	 30077	 30077	 30077	 0.0	 0.0	 1	 -30.0	 30.0;
	5487	 689	 0.047871	 0.145377	 0.001	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	4583	 690	 0.000237	 0.000573	 0.078	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	886	 691	 0.00716	 0.023086	 0.0014	 1255	 1255	 1255	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 691	 0.041975	 0.114568	 0.0	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	2335	 693	 0.000869	 0.003891	 0.0116	 414.0	 414.0	 414.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2335	 692	 0.000869	 0.003891	 0.0116	 414.0	 414.0	 414.0	 0.0	 0.0	 1	 -30.0	 30.0;
	735	 694	 0.031099	 0.097333	 0.0045	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 694	 0.016667	 0.087037	 0.0046	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	5580	 694	 0.00942	 0.025679	 0.0011	 1266	 1266	 1266	 0.0	 0.0	 1	 -30.0	 30.0;
	4685	 694	 0.013951	 0.057901	 0.0033	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	5207	 700	 0.002706	 0.0128	 0.0213	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3897	 702	 0.014074	 0.051235	 0.0119	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	4319	 701	 0.023704	 0.064	 0.0031	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 702	 0.009136	 0.05358	 0.0028	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 702	 0.016296	 0.044198	 0.0045	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	4319	 701	 0.02337	 0.062988	 0.0053	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	5264	 703	 0.00237	 0.015803	 0.0294	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4030	 704	 0.074074	 0.158025	 0.0012	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	5415	 704	 0.02321	 0.051852	 0.0	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	5840	 704	 0.044444	 0.09679	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 704	 0.108938	 0.258025	 0.001	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	5720	 705	 0.010988	 0.03	 0.0015	 930	 930	 930	 0.0	 0.0	 1	 -30.0	 30.0;
	2618	 710	 0.069753	 0.176914	 0.0083	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2732	 710	 0.030741	 0.094568	 0.0082	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	2913	 709	 0.005309	 0.01284	 0.0138	 2138	 2138	 2138	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 709	 0.010321	 0.037247	 0.0019	 769	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 709	 0.010963	 0.037037	 0.0019	 769	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 709	 0.010321	 0.037235	 0.0019	 769	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	1723	 711	 0.003554	 0.024524	 0.0466	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2055	 711	 0.006493	 0.043265	 0.08	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 711	 0.007921	 0.053985	 0.1013	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 711	 0.004543	 0.030262	 0.0557	 485.0	 485.0	 485.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5195	 712	 0.000741	 0.002099	 0.0002	 13344	 13344	 13344	 0.0	 0.0	 1	 -30.0	 30.0;
	5231	 713	 0.038095	 0.105115	 0.0012	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 714	 0.001126	 0.004978	 0.0091	 6053	 6053	 6053	 0.0	 0.0	 1	 -30.0	 30.0;
	961	 715	 0.079869	 0.202822	 0.0023	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5004	 715	 0.079693	 0.202066	 0.0023	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	1185	 715	 0.035777	 0.090955	 0.001	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	3038	 715	 0.014865	 0.037793	 0.0004	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	1929	 716	 0.002963	 0.012346	 0.0025	 2340	 2340	 2340	 0.0	 0.0	 1	 -30.0	 30.0;
	715	 717	 0.007811	 0.019148	 0.0002	 1471	 1471	 1471	 0.0	 0.0	 1	 -30.0	 30.0;
	3568	 718	 0.032346	 0.088148	 0.004	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	5816	 718	 0.024321	 0.06642	 0.0031	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	5347	 719	 0.011086	 0.028723	 0.0003	 988	 988	 988	 0.0	 0.0	 1	 -30.0	 30.0;
	5531	 719	 0.022424	 0.057445	 0.0032	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	4331	 719	 0.027967	 0.071051	 0.0008	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	965	 720	 0.003536	 0.01683	 0.0284	 306.0	 306.0	 306.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4286	 720	 0.001541	 0.009936	 0.0258	 3082	 3082	 3082	 0.0	 0.0	 1	 -30.0	 30.0;
	4737	 720	 0.008375	 0.039704	 0.0658	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5196	 721	 0.007901	 0.020123	 0.001	 1403	 1403	 1403	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 721	 0.001975	 0.005309	 0.0003	 5354	 5354	 5354	 0.0	 0.0	 1	 -30.0	 30.0;
	1390	 722	 0.070799	 0.179894	 0.002	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	1903	 722	 0.06324	 0.181658	 0.002	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 722	 0.035273	 0.089947	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	2848	 723	 0.03225	 0.082389	 0.0046	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	4281	 723	 0.001008	 0.003779	 0.0035	 7550	 7550	 7550	 0.0	 0.0	 1	 -30.0	 30.0;
	4742	 723	 0.018392	 0.076846	 0.001	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	4280	 723	 0.001008	 0.003779	 0.0006	 7550	 7550	 7550	 0.0	 0.0	 1	 -30.0	 30.0;
	4742	 723	 0.0194	 0.079113	 0.001	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	2181	 725	 0.078357	 0.200554	 0.0023	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	2455	 725	 0.081129	 0.214916	 0.0037	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 724	 0.056185	 0.351474	 0.0047	 88	 88	 88	 0.0	 0.0	 1	 -30.0	 30.0;
	4140	 724	 0.024188	 0.098262	 0.0013	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	4148	 724	 0.117158	 0.298312	 0.0033	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	5507	 724	 0.034014	 0.21542	 0.0027	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	5579	 724	 0.035777	 0.081633	 0.0039	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	2181	 725	 0.074326	 0.202066	 0.0023	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	4140	 724	 0.02318	 0.094986	 0.0012	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	4588	 724	 0.012598	 0.025951	 0.0003	 1086	 1086	 1086	 0.0	 0.0	 1	 -30.0	 30.0;
	852	 726	 0.011378	 0.053886	 0.0957	 276.0	 276.0	 276.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2467	 726	 0.003457	 0.023724	 0.0445	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2657	 726	 0.008415	 0.041422	 0.0739	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4121	 726	 0.003793	 0.017007	 0.0294	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5696	 726	 0.004701	 0.026726	 0.0481	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 726	 0.001877	 0.018252	 0.0638	 604.0	 604.0	 604.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 726	 0.001857	 0.017521	 0.0648	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 728	 0.022424	 0.057193	 0.0006	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 727	 0.021164	 0.056689	 0.0006	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 729	 0.021668	 0.05543	 0.0006	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	924	 730	 0.01033	 0.043588	 0.0012	 640	 640	 640	 0.0	 0.0	 1	 -30.0	 30.0;
	924	 730	 0.011338	 0.046359	 0.0013	 601	 601	 601	 0.0	 0.0	 1	 -30.0	 30.0;
	971	 731	 0.037037	 0.100988	 0.0052	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 732	 0.000252	 0.000756	 0.0	 37051	 37051	 37051	 0.0	 0.0	 1	 -30.0	 30.0;
	5198	 733	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 734	 0.00358	 0.00716	 0.0277	 3789	 3789	 3789	 0.0	 0.0	 1	 -30.0	 30.0;
	4827	 737	 0.015679	 0.040123	 0.0015	 704	 704	 704	 0.0	 0.0	 1	 -30.0	 30.0;
	1562	 738	 4.8e-05	 8.8e-05	 0.0051	 308785	 308785	 308785	 0.0	 0.0	 1	 -30.0	 30.0;
	4048	 738	 0.000533	 0.004642	 0.4647	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2535	 741	 0.045024	 0.12522	 0.008	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	3662	 741	 0.022827	 0.061804	 0.0073	 462	 462	 462	 0.0	 0.0	 1	 -30.0	 30.0;
	4776	 741	 0.034266	 0.095994	 0.001	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	5473	 741	 0.045981	 0.13351	 0.0013	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	1674	 742	 0.002827	 0.011058	 0.0192	 363.0	 363.0	 363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2715	 742	 0.002258	 0.00946	 0.0172	 363.0	 363.0	 363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	744	 743	 0.024691	 0.062232	 0.001	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	5040	 743	 0.025951	 0.058453	 0.001	 462	 462	 462	 0.0	 0.0	 1	 -30.0	 30.0;
	3668	 744	 0.03351	 0.068783	 0.001	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	3619	 745	 0.00358	 0.009753	 0.0005	 2859	 2859	 2859	 0.0	 0.0	 1	 -30.0	 30.0;
	3429	 746	 0.049383	 0.13933	 0.0015	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	488	 747	 0.000617	 0.001358	 0.0018	 19914	 19914	 19914	 0.0	 0.0	 1	 -30.0	 30.0;
	2011	 748	 0.051146	 0.129756	 0.001	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	2042	 748	 0.070547	 0.176871	 0.0165	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	5051	 748	 0.082389	 0.208869	 0.0024	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	1219	 749	 0.046107	 0.21416	 0.003	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	4093	 749	 0.094986	 0.241875	 0.003	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	4951	 749	 0.152179	 0.27866	 0.003	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	1475	 751	 0.085412	 0.216427	 0.0025	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	3441	 751	 0.068304	 0.173369	 0.002	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	4688	 752	 0.025951	 0.07231	 0.001	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	2552	 753	 0.001363	 0.009126	 0.0172	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4743	 753	 0.0016	 0.010825	 0.0203	 470.0	 470.0	 470.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2552	 753	 0.001402	 0.009422	 0.0172	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4743	 753	 0.00162	 0.010963	 0.0213	 470.0	 470.0	 470.0	 0.0	 0.0	 1	 -30.0	 30.0;
	460	 754	 0.001153	 0.010798	 0.283	 1355.0	 1355.0	 1355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	460	 754	 0.00115	 0.010796	 0.283	 1355.0	 1355.0	 1355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2747	 755	 0.03099	 0.078861	 0.0009	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	2958	 755	 0.02328	 0.065306	 0.0008	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	4388	 755	 0.009826	 0.018141	 0.0005	 1432	 1432	 1432	 0.0	 0.0	 1	 -30.0	 30.0;
	5699	 755	 0.040312	 0.100025	 0.0011	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	3635	 756	 0.000377	 0.00069	 0.0273	 39366	 39366	 39366	 0.0	 0.0	 1	 -30.0	 30.0;
	3882	 756	 0.000336	 0.001304	 0.2906	 22986	 22986	 22986	 0.0	 0.0	 1	 -30.0	 30.0;
	758	 757	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4167	 758	 0.005472	 0.024889	 0.0445	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5201	 760	 0.000252	 0.000504	 0.001	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	1846	 763	 0.002137	 0.003912	 0.0002	 6823	 6823	 6823	 0.0	 0.0	 1	 -30.0	 30.0;
	1557	 764	 0.040312	 0.103804	 0.0012	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	3311	 764	 0.107811	 0.276493	 0.0035	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	3810	 765	 0.040262	 0.155757	 0.0032	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 765	 0.052406	 0.133787	 0.0015	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	342	 766	 0.03358	 0.091728	 0.0042	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 766	 0.002099	 0.005802	 0.0003	 4814	 4814	 4814	 0.0	 0.0	 1	 -30.0	 30.0;
	660	 767	 0.029877	 0.077654	 0.0102	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 767	 0.023457	 0.066173	 0.0031	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	2220	 767	 0.002222	 0.013951	 0.0013	 2103	 2103	 2103	 0.0	 0.0	 1	 -30.0	 30.0;
	2316	 767	 0.026741	 0.067815	 0.0037	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	3061	 767	 0.028272	 0.076914	 0.0045	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	4117	 767	 0.006049	 0.015679	 0.0006	 1768	 1768	 1768	 0.0	 0.0	 1	 -30.0	 30.0;
	4545	 767	 0.006667	 0.01679	 0.0008	 1645	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	5411	 767	 0.004691	 0.012716	 0.0006	 2192	 2192	 2192	 0.0	 0.0	 1	 -30.0	 30.0;
	5623	 767	 0.055679	 0.199383	 0.0094	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 767	 0.022346	 0.062716	 0.0057	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	3061	 767	 0.033704	 0.091852	 0.0053	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 768	 0.002015	 0.013551	 0.0764	 449.0	 449.0	 449.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3739	 768	 0.012484	 0.056454	 0.1002	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3793	 768	 0.000869	 0.003911	 0.0071	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3792	 768	 0.000869	 0.003911	 0.0071	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5759	 768	 0.001001	 0.006712	 0.0121	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1757	 772	 0.003578	 0.013454	 0.0002	 2121	 2121	 2121	 0.0	 0.0	 1	 -30.0	 30.0;
	1877	 772	 0.00126	 0.004535	 0.0	 6273	 6273	 6273	 0.0	 0.0	 1	 -30.0	 30.0;
	3718	 772	 0.001688	 0.00446	 0.0041	 6192	 6192	 6192	 0.0	 0.0	 1	 -30.0	 30.0;
	4847	 772	 0.017385	 0.071806	 0.001	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 772	 0.001764	 0.01285	 0.0	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	1877	 772	 0.001764	 0.004535	 0.0	 6068	 6068	 6068	 0.0	 0.0	 1	 -30.0	 30.0;
	5648	 772	 0.001512	 0.010582	 0.0	 2763	 2763	 2763	 0.0	 0.0	 1	 -30.0	 30.0;
	2301	 773	 0.069035	 0.192744	 0.0	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	919	 774	 0.026815	 0.072247	 0.0036	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	4827	 774	 0.004605	 0.022	 0.0888	 1350	 1350	 1350	 0.0	 0.0	 1	 -30.0	 30.0;
	899	 775	 0.013605	 0.039808	 0.0005	 723	 723	 723	 0.0	 0.0	 1	 -30.0	 30.0;
	2727	 775	 0.019148	 0.057697	 0.0007	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	3766	 775	 0.027715	 0.083144	 0.001	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	900	 775	 0.013605	 0.039557	 0.0005	 728	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 776	 0.000614	 0.004093	 0.0278	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	952	 779	 0.002016	 0.005543	 0.0001	 5006	 5006	 5006	 0.0	 0.0	 1	 -30.0	 30.0;
	952	 778	 0.001008	 0.003023	 0.0001	 9266	 9266	 9266	 0.0	 0.0	 1	 -30.0	 30.0;
	952	 777	 0.00126	 0.004787	 0.0001	 5965	 5965	 5965	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 780	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	1760	 781	 0.116679	 0.308919	 0.0037	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	2518	 781	 0.102545	 0.271529	 0.0045	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	1690	 783	 0.000523	 0.002596	 0.2992	 342.0	 342.0	 342.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5206	 784	 0.000171	 0.000313	 0.0002	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	1128	 788	 0.021416	 0.058201	 0.001	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	3424	 787	 0.048123	 0.15747	 0.002	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	3463	 788	 0.03477	 0.097254	 0.002	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	4329	 787	 0.066516	 0.17284	 0.0051	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	4539	 788	 0.024691	 0.062736	 0.0	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	4778	 787	 0.045603	 0.137566	 0.002	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	5808	 788	 0.026959	 0.085664	 0.001	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	5830	 788	 0.001008	 0.004031	 0.0	 7106	 7106	 7106	 0.0	 0.0	 1	 -30.0	 30.0;
	1340	 788	 0.032363	 0.059241	 0.001	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	4539	 787	 0.027715	 0.089443	 0.001	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	699	 789	 0.00484	 0.021393	 0.0385	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 789	 0.001541	 0.007309	 0.0121	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	922	 789	 0.000672	 0.004602	 0.0152	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1983	 789	 0.00243	 0.011477	 0.0192	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4779	 789	 0.002311	 0.011378	 0.0233	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 789	 0.000474	 0.002331	 0.0081	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5274	 789	 0.002825	 0.019082	 0.0344	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1904	 789	 0.004286	 0.029037	 0.0527	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5207	 789	 0.002074	 0.009758	 0.0162	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	958	 790	 0.001566	 0.015874	 0.4101	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1218	 790	 0.001309	 0.01286	 0.335	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2631	 791	 0.005346	 0.009785	 0.0123	 2728	 2728	 2728	 0.0	 0.0	 1	 -30.0	 30.0;
	2348	 792	 0.030617	 0.077654	 0.006	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	4620	 792	 0.019259	 0.05321	 0.0024	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	4900	 793	 0.030234	 0.076846	 0.0009	 369	 369	 369	 0.0	 0.0	 1	 -30.0	 30.0;
	4838	 794	 0.045352	 0.11489	 0.0013	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	4900	 794	 0.030234	 0.076846	 0.0009	 369	 369	 369	 0.0	 0.0	 1	 -30.0	 30.0;
	481	 795	 0.012547	 0.053666	 0.0118	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	923	 795	 0.000504	 0.001764	 0.0021	 16094	 16094	 16094	 0.0	 0.0	 1	 -30.0	 30.0;
	817	 796	 0.00252	 0.006677	 0.0075	 4138	 4138	 4138	 0.0	 0.0	 1	 -30.0	 30.0;
	3124	 796	 0.001764	 0.003779	 0.0	 7080	 7080	 7080	 0.0	 0.0	 1	 -30.0	 30.0;
	4404	 796	 0.004913	 0.012976	 0.0147	 2128	 2128	 2128	 0.0	 0.0	 1	 -30.0	 30.0;
	1222	 797	 0.026707	 0.067271	 0.001	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	1988	 798	 0.019904	 0.083144	 0.0091	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	3494	 798	 0.0451	 0.131267	 0.0172	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	4408	 798	 0.003275	 0.011086	 0.0152	 2555	 2555	 2555	 0.0	 0.0	 1	 -30.0	 30.0;
	1988	 798	 0.019652	 0.082892	 0.0091	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	943	 799	 7e-06	 0.000125	 0.0029	 552.0	 552.0	 552.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1962	 799	 0.000693	 0.007687	 0.1704	 1355.0	 1355.0	 1355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5207	 803	 0.000691	 0.003279	 0.0051	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3679	 805	 0.002398	 0.004389	 0.0	 6082	 6082	 6082	 0.0	 0.0	 1	 -30.0	 30.0;
	1765	 806	 0.000171	 0.000313	 0.0	 85273	 85273	 85273	 0.0	 0.0	 1	 -30.0	 30.0;
	3147	 806	 0.053666	 0.152431	 0.0002	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	1478	 808	 0.000277	 0.001916	 0.003	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1478	 807	 0.000277	 0.001936	 0.003	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 809	 0.07609	 0.179642	 0.0017	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	4921	 809	 0.037289	 0.079113	 0.0009	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	844	 810	 0.007811	 0.029	 0.0303	 1013	 1013	 1013	 0.0	 0.0	 1	 -30.0	 30.0;
	5613	 810	 0.010456	 0.02905	 0.0003	 986	 986	 986	 0.0	 0.0	 1	 -30.0	 30.0;
	5608	 810	 0.008818	 0.029982	 0.0003	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	3752	 811	 0.000217	 0.001205	 0.0086	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4931	 812	 0.00446	 0.009121	 0.0001	 2909	 2909	 2909	 0.0	 0.0	 1	 -30.0	 30.0;
	4442	 813	 0.052658	 0.134467	 0.0039	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	4920	 813	 0.025598	 0.068405	 0.0012	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	5295	 815	 0.000252	 0.001512	 0.0	 19262	 19262	 19262	 0.0	 0.0	 1	 -30.0	 30.0;
	5294	 814	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 816	 0.00162	 0.007447	 0.0132	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3736	 816	 0.000889	 0.005965	 0.0111	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2443	 817	 0.000252	 0.000504	 0.0005	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	819	 818	 0.001008	 0.003527	 0.0043	 8292	 8292	 8292	 0.0	 0.0	 1	 -30.0	 30.0;
	4327	 818	 0.010834	 0.042328	 0.0101	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 819	 0.056941	 0.155203	 0.0017	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5534	 819	 0.066264	 0.139582	 0.0015	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	1690	 820	 0.000533	 0.003536	 0.0061	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5211	 821	 0.000178	 0.001185	 0.002	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4827	 822	 0.008148	 0.020247	 0.0008	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	2133	 823	 0.002889	 0.0064	 0.0022	 4554	 4554	 4554	 0.0	 0.0	 1	 -30.0	 30.0;
	4250	 824	 0.008062	 0.022172	 0.0002	 1252	 1252	 1252	 0.0	 0.0	 1	 -30.0	 30.0;
	2011	 825	 0.13293	 0.358201	 0.0161	 80	 80	 80	 0.0	 0.0	 1	 -30.0	 30.0;
	3667	 826	 0.000205	 0.002108	 0.2577	 546.0	 546.0	 546.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 827	 0.002899	 0.029385	 0.7595	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	2787	 827	 0.002045	 0.020735	 0.5343	 1524	 1524	 1524	 0.0	 0.0	 1	 -30.0	 30.0;
	2720	 828	 0.010864	 0.032346	 0.0046	 941	 941	 941	 0.0	 0.0	 1	 -30.0	 30.0;
	3094	 830	 0.028148	 0.076543	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	4046	 830	 0.019753	 0.048889	 0.0	 496	 496	 496	 0.0	 0.0	 1	 -30.0	 30.0;
	4678	 831	 0.002922	 0.005348	 0.0048	 4845	 4845	 4845	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 832	 0.001906	 0.003489	 0.0	 7650	 7650	 7650	 0.0	 0.0	 1	 -30.0	 30.0;
	1678	 833	 0.008889	 0.055185	 0.0031	 543	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	4636	 833	 0.006914	 0.043457	 0.0023	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	2235	 834	 0.021416	 0.110355	 0.0205	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	3028	 834	 0.051146	 0.139078	 0.01	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	3380	 834	 0.041068	 0.135551	 0.0215	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 835	 0.05039	 0.120937	 0.0014	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	3659	 835	 0.017637	 0.048375	 0.0006	 591	 591	 591	 0.0	 0.0	 1	 -30.0	 30.0;
	4777	 835	 0.010582	 0.027967	 0.0003	 1018	 1018	 1018	 0.0	 0.0	 1	 -30.0	 30.0;
	2959	 837	 0.031903	 0.058397	 0.0006	 458	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	5405	 836	 0.053666	 0.119174	 0.0013	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5544	 836	 0.001214	 0.002222	 0.0001	 12012	 12012	 12012	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 838	 0.015092	 0.041673	 0.0005	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	2954	 839	 0.081104	 0.188234	 0.0033	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	4126	 839	 0.050139	 0.113631	 0.0013	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	4827	 840	 0.016543	 0.033951	 0.0016	 803	 803	 803	 0.0	 0.0	 1	 -30.0	 30.0;
	5208	 841	 0.000378	 0.001008	 0.0001	 27427	 27427	 27427	 0.0	 0.0	 1	 -30.0	 30.0;
	1882	 842	 0.000988	 0.002716	 0.0133	 10493	 10493	 10493	 0.0	 0.0	 1	 -30.0	 30.0;
	1882	 842	 0.000988	 0.002716	 0.0133	 10493	 10493	 10493	 0.0	 0.0	 1	 -30.0	 30.0;
	1552	 843	 0.059209	 0.148652	 0.0018	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 843	 0.069539	 0.19098	 0.0	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	3001	 845	 0.011298	 0.020682	 0.0088	 1253	 1253	 1253	 0.0	 0.0	 1	 -30.0	 30.0;
	3001	 847	 0.008062	 0.017133	 0.0156	 1560	 1560	 1560	 0.0	 0.0	 1	 -30.0	 30.0;
	3001	 846	 0.007811	 0.016125	 0.0148	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 848	 0.075838	 0.19224	 0.0021	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3798	 848	 0.010834	 0.027715	 0.0003	 1023	 1023	 1023	 0.0	 0.0	 1	 -30.0	 30.0;
	3957	 848	 0.02973	 0.096246	 0.0218	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	5546	 848	 0.009826	 0.031242	 0.0004	 929	 929	 929	 0.0	 0.0	 1	 -30.0	 30.0;
	5267	 848	 0.043537	 0.154271	 0.0224	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	5547	 848	 0.01285	 0.032754	 0.0004	 865	 865	 865	 0.0	 0.0	 1	 -30.0	 30.0;
	2782	 849	 0.00924	 0.060219	 0.1124	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3004	 849	 0.009007	 0.066726	 0.1192	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	3165	 849	 0.004543	 0.030479	 0.0547	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3165	 849	 0.004326	 0.029037	 0.0527	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4029	 850	 0.001357	 0.017597	 0.3494	 1807	 1807	 1807	 0.0	 0.0	 1	 -30.0	 30.0;
	4029	 850	 0.001343	 0.01741	 0.3437	 1827	 1827	 1827	 0.0	 0.0	 1	 -30.0	 30.0;
	1821	 851	 0.022928	 0.141849	 0.0095	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	1821	 851	 0.022424	 0.140086	 0.0026	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	3672	 852	 0.003615	 0.024178	 0.0445	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2592	 853	 0.001136	 0.012154	 0.2657	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2799	 853	 0.001309	 0.013996	 0.3061	 1917.0	 1917.0	 1917.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1141	 854	 0.053918	 0.138574	 0.0016	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	5689	 855	 0.005039	 0.013102	 0.0002	 2104	 2104	 2104	 0.0	 0.0	 1	 -30.0	 30.0;
	2719	 856	 0.092441	 0.276669	 0.0072	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 856	 0.084152	 0.229781	 0.0025	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	5756	 856	 0.036281	 0.092215	 0.001	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	2973	 857	 0.011086	 0.038045	 0.0137	 768	 768	 768	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 857	 0.002268	 0.007559	 0.0075	 3854	 3854	 3854	 0.0	 0.0	 1	 -30.0	 30.0;
	3217	 859	 0.000257	 0.001521	 0.162	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3342	 859	 0.000259	 0.000506	 0.042	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2379	 860	 0.103301	 0.282187	 0.0032	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	3450	 860	 0.062106	 0.169463	 0.0019	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 860	 0.068027	 0.185941	 0.0021	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	4328	 860	 0.078357	 0.213404	 0.0024	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	4107	 862	 0.000928	 0.006202	 0.0111	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4107	 861	 0.000928	 0.006202	 0.0111	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5221	 864	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 863	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	4219	 865	 0.044344	 0.084656	 0.0015	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	1158	 866	 0.01033	 0.028219	 0.0013	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	5391	 867	 0.005679	 0.011358	 0.0005	 2340	 2340	 2340	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 868	 0.114135	 0.237087	 0.0026	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	2253	 868	 0.04258	 0.178634	 0.0021	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	4492	 868	 0.000756	 0.002268	 0.0	 12351	 12351	 12351	 0.0	 0.0	 1	 -30.0	 30.0;
	2491	 870	 0.009245	 0.016923	 0.0002	 1532	 1532	 1532	 0.0	 0.0	 1	 -30.0	 30.0;
	2491	 869	 0.006047	 0.011086	 0.0059	 2339	 2339	 2339	 0.0	 0.0	 1	 -30.0	 30.0;
	4646	 871	 0.005062	 0.032222	 0.0048	 930	 930	 930	 0.0	 0.0	 1	 -30.0	 30.0;
	4648	 871	 0.005802	 0.035926	 0.0019	 834	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	4595	 872	 0.031494	 0.085412	 0.001	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	5259	 872	 0.025951	 0.066516	 0.0007	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	4595	 872	 0.006803	 0.014361	 0.013	 1859	 1859	 1859	 0.0	 0.0	 1	 -30.0	 30.0;
	5210	 873	 0.000252	 0.00252	 0.0	 11659	 11659	 11659	 0.0	 0.0	 1	 -30.0	 30.0;
	2669	 874	 0.024213	 0.081355	 0.029	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	4344	 874	 0.011338	 0.033006	 0.0133	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	2253	 876	 0.014613	 0.03099	 0.0281	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	2253	 875	 0.014613	 0.03099	 0.0283	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	5222	 877	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5219	 878	 2e-05	 0.000198	 0.001	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3393	 879	 0.079869	 0.176619	 0.0094	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3733	 879	 0.066667	 0.149232	 0.0017	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	4760	 879	 0.003023	 0.01033	 0.0002	 2662	 2662	 2662	 0.0	 0.0	 1	 -30.0	 30.0;
	5048	 879	 0.068027	 0.128748	 0.0014	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	5669	 880	 0.045352	 0.116906	 0.0013	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5773	 880	 0.120181	 0.240867	 0.0026	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 879	 0.122701	 0.306374	 0.0034	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	2043	 881	 0.001067	 0.00723	 0.0132	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2987	 882	 0.003358	 0.022341	 0.0415	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3614	 881	 0.00318	 0.020938	 0.0395	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4598	 881	 0.000928	 0.008968	 0.0314	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 882	 0.004899	 0.022815	 0.0405	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4598	 882	 0.000889	 0.008415	 0.0314	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2209	 883	 0.004444	 0.028395	 0.0151	 1095	 1095	 1095	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 883	 0.004691	 0.029012	 0.0016	 1181	 1181	 1181	 0.0	 0.0	 1	 -30.0	 30.0;
	5448	 884	 0.007055	 0.018392	 0.0002	 1499	 1499	 1499	 0.0	 0.0	 1	 -30.0	 30.0;
	5225	 885	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	3307	 886	 0.01037	 0.026173	 0.0013	 1078	 1078	 1078	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 886	 0.070864	 0.193457	 0.0091	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	5556	 886	 0.022222	 0.056914	 0.0	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	2185	 888	 0.000237	 0.001422	 0.1686	 21471	 21471	 21471	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 887	 0.000277	 0.001086	 0.1417	 27618	 27618	 27618	 0.0	 0.0	 1	 -30.0	 30.0;
	4128	 887	 0.000296	 0.000672	 0.0678	 42153	 42153	 42153	 0.0	 0.0	 1	 -30.0	 30.0;
	1311	 890	 0.002267	 0.007156	 0.0022	 4057	 4057	 4057	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 891	 0.016377	 0.102041	 0.0013	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	5223	 891	 0.008062	 0.050139	 0.0006	 599	 599	 599	 0.0	 0.0	 1	 -30.0	 30.0;
	2540	 892	 0.001512	 0.004787	 0.004	 5882	 5882	 5882	 0.0	 0.0	 1	 -30.0	 30.0;
	3380	 893	 0.031746	 0.133031	 0.0002	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	4154	 893	 0.020912	 0.088939	 0.001	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 894	 0.05543	 0.147644	 0.0017	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 895	 0.000286	 0.004868	 0.1762	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 896	 0.000287	 0.004892	 0.1776	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 897	 0.000283	 0.004814	 0.1762	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 898	 0.000285	 0.004843	 0.1733	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5078	 901	 0.011852	 0.045062	 0.017	 651	 651	 651	 0.0	 0.0	 1	 -30.0	 30.0;
	5852	 901	 0.000864	 0.002593	 0.0136	 11095	 11095	 11095	 0.0	 0.0	 1	 -30.0	 30.0;
	4720	 902	 0.048249	 0.235702	 0.0035	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	3940	 903	 0.044321	 0.121605	 0.001	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	4166	 903	 0.028765	 0.078889	 0.0006	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	3380	 904	 0.019652	 0.080877	 0.0014	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	4154	 904	 0.017385	 0.073822	 0.0001	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	3575	 905	 0.000514	 0.001383	 0.0952	 20979	 20979	 20979	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 905	 0.000247	 0.001084	 0.1478	 403.0	 403.0	 403.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5802	 906	 0.013857	 0.025447	 0.0002	 1019	 1019	 1019	 0.0	 0.0	 1	 -30.0	 30.0;
	5229	 907	 0.00284	 0.011235	 0.001	 2617	 2617	 2617	 0.0	 0.0	 1	 -30.0	 30.0;
	3649	 908	 0.015369	 0.040816	 0.0005	 677	 677	 677	 0.0	 0.0	 1	 -30.0	 30.0;
	5803	 908	 0.041068	 0.104812	 0.0012	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	2487	 909	 0.058957	 0.16125	 0.0018	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	4441	 909	 0.024439	 0.102293	 0.0012	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	1753	 910	 0.006047	 0.016629	 0.014	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	5232	 913	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	2314	 916	 0.013096	 0.066153	 0.12	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2450	 915	 0.002074	 0.009956	 0.0172	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2450	 915	 0.001533	 0.009225	 0.0172	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2450	 916	 0.00156	 0.009343	 0.0172	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2783	 917	 0.001452	 0.020223	 0.6741	 1573	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	4859	 917	 0.001672	 0.022177	 0.7607	 1434	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	2783	 917	 0.001447	 0.020166	 0.6721	 1578	 1578	 1578	 0.0	 0.0	 1	 -30.0	 30.0;
	4859	 917	 0.001669	 0.022168	 0.7624	 1435	 1435	 1435	 0.0	 0.0	 1	 -30.0	 30.0;
	5233	 918	 0.035525	 0.090199	 0.001	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	4827	 919	 0.031568	 0.094272	 0.0992	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	1802	 920	 0.118166	 0.243386	 0.0026	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	5671	 920	 0.015621	 0.032754	 0.0003	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	4458	 920	 0.05417	 0.183673	 0.0021	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5168	 921	 0.040338	 0.097909	 0.0009	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5752	 921	 0.022424	 0.053918	 0.0	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	5561	 923	 0.02066	 0.088183	 0.0051	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 924	 0.014361	 0.059461	 0.006	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	2563	 924	 0.016377	 0.101537	 0.0023	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 924	 0.014361	 0.059713	 0.006	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	2563	 924	 0.016377	 0.101537	 0.0019	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	3154	 925	 0.002874	 0.022174	 0.4476	 1397.0	 1397.0	 1397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3368	 925	 0.000139	 0.001115	 0.0231	 1486.0	 1486.0	 1486.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2399	 926	 0.00252	 0.006551	 0.0001	 4207	 4207	 4207	 0.0	 0.0	 1	 -30.0	 30.0;
	3840	 926	 0.011842	 0.052658	 0.001	 548	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	2708	 927	 0.089947	 0.390527	 0.0051	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	5323	 927	 0.027463	 0.060721	 0.001	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	2172	 928	 0.009877	 0.026959	 0.0003	 1060	 1060	 1060	 0.0	 0.0	 1	 -30.0	 30.0;
	1791	 929	 0.010582	 0.063492	 0.0076	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	1791	 929	 0.009902	 0.059007	 0.0157	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	4122	 930	 0.013605	 0.054926	 0.0007	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	5819	 931	 0.042328	 0.160998	 0.0017	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	3485	 935	 0.00322	 0.021136	 0.0395	 460.0	 460.0	 460.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 935	 0.000553	 0.003694	 0.0071	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 936	 0.000494	 0.005689	 0.0142	 720.0	 720.0	 720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5472	 935	 0.000652	 0.004504	 0.0081	 437.0	 437.0	 437.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5474	 935	 0.000652	 0.004504	 0.0081	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5421	 936	 0.000514	 0.005689	 0.0142	 720.0	 720.0	 720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5364	 937	 0.000869	 0.008435	 0.0339	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 937	 0.000889	 0.008553	 0.039	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2894	 938	 0.000686	 0.007091	 0.1747	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 938	 0.000609	 0.006378	 0.1473	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2894	 939	 0.000686	 0.007119	 0.1747	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4600	 939	 0.000609	 0.006406	 0.1487	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2813	 940	 0.027531	 0.074938	 0.0036	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	5674	 940	 0.024198	 0.065802	 0.0031	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	2117	 941	 0.090199	 0.246158	 0.0033	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	2553	 941	 0.005291	 0.022172	 0.0006	 1366	 1366	 1366	 0.0	 0.0	 1	 -30.0	 30.0;
	3211	 941	 0.012346	 0.050894	 0.001	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	3549	 941	 0.053414	 0.224238	 0.0028	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	5478	 941	 0.007811	 0.032502	 0.0004	 1012	 1012	 1012	 0.0	 0.0	 1	 -30.0	 30.0;
	5643	 941	 0.034014	 0.142857	 0.0002	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	2553	 941	 0.005543	 0.022172	 0.0006	 1363	 1363	 1363	 0.0	 0.0	 1	 -30.0	 30.0;
	4884	 942	 0.002074	 0.013847	 0.0253	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4884	 942	 0.002074	 0.013847	 0.0253	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2561	 944	 0.036533	 0.12522	 0.0014	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	1533	 945	 0.009012	 0.025062	 0.0056	 1116	 1116	 1116	 0.0	 0.0	 1	 -30.0	 30.0;
	1533	 945	 0.006667	 0.028025	 0.0015	 1032	 1032	 1032	 0.0	 0.0	 1	 -30.0	 30.0;
	3338	 947	 0.031771	 0.081809	 0.001	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	3917	 947	 0.070799	 0.179894	 0.002	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	2464	 946	 0.075586	 0.191736	 0.0021	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3917	 946	 0.070925	 0.179239	 0.0021	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3307	 948	 0.003901	 0.009877	 0.0005	 2856	 2856	 2856	 0.0	 0.0	 1	 -30.0	 30.0;
	2710	 949	 0.003023	 0.008314	 0.0001	 3338	 3338	 3338	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 949	 0.037793	 0.097002	 0.0011	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	5501	 949	 0.003023	 0.008314	 0.0001	 3338	 3338	 3338	 0.0	 0.0	 1	 -30.0	 30.0;
	2213	 950	 0.020988	 0.058272	 0.0176	 480	 480	 480	 0.0	 0.0	 1	 -30.0	 30.0;
	2813	 950	 0.02679	 0.072222	 0.0034	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	2599	 951	 0.018519	 0.047654	 0.0185	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	3432	 951	 0.029877	 0.080864	 0.0039	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	1044	 952	 0.016125	 0.067775	 0.0051	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	1102	 952	 0.032502	 0.083144	 0.0009	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 952	 0.025447	 0.08642	 0.0079	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	3073	 952	 0.02192	 0.04384	 0.0383	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	1046	 953	 0.00083	 0.005649	 0.0111	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1198	 953	 0.002193	 0.014894	 0.0284	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2663	 954	 0.002145	 0.011151	 0.0203	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 954	 0.00638	 0.031486	 0.0537	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1516	 955	 0.01037	 0.020741	 0.002	 1281	 1281	 1281	 0.0	 0.0	 1	 -30.0	 30.0;
	1372	 956	 0.002346	 0.006296	 0.0003	 4421	 4421	 4421	 0.0	 0.0	 1	 -30.0	 30.0;
	2300	 957	 0.022096	 0.08841	 0.0011	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	2315	 957	 0.025724	 0.105316	 0.0184	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	2914	 957	 0.029957	 0.121013	 0.0046	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	4412	 957	 0.009322	 0.028471	 0.0	 986	 986	 986	 0.0	 0.0	 1	 -30.0	 30.0;
	4635	 957	 0.046107	 0.130763	 0.001	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	4869	 957	 0.006047	 0.041068	 0.001	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	4412	 957	 0.004334	 0.026732	 0.001	 1091	 1091	 1091	 0.0	 0.0	 1	 -30.0	 30.0;
	1218	 958	 0.002877	 0.028829	 0.7494	 1100	 1100	 1100	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 958	 0.002188	 0.024233	 0.5227	 1311	 1311	 1311	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 958	 0.000997	 0.014175	 0.465	 2245	 2245	 2245	 0.0	 0.0	 1	 -30.0	 30.0;
	2918	 958	 0.000376	 0.002891	 0.0606	 1308.0	 1308.0	 1308.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3607	 958	 0.000976	 0.009886	 0.2541	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4465	 958	 0.000389	 0.003951	 0.1011	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 958	 0.001562	 0.01912	 0.4274	 1567.0	 1567.0	 1567.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 958	 0.000998	 0.014177	 0.465	 2244	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	2918	 958	 0.000199	 0.002553	 0.0838	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3607	 958	 0.000976	 0.009891	 0.2541	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 958	 0.000388	 0.003954	 0.1011	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 958	 0.000395	 0.004003	 0.104	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4465	 958	 0.000395	 0.004003	 0.104	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 959	 0.000617	 0.001235	 0.0019	 21515	 21515	 21515	 0.0	 0.0	 1	 -30.0	 30.0;
	5240	 960	 0.00037	 0.000864	 0.0	 31602	 31602	 31602	 0.0	 0.0	 1	 -30.0	 30.0;
	2950	 961	 0.00252	 0.007811	 0.0001	 3706	 3706	 3706	 0.0	 0.0	 1	 -30.0	 30.0;
	1183	 962	 0.029383	 0.08037	 0.0037	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	5702	 962	 0.000617	 0.001728	 0.0002	 16188	 16188	 16188	 0.0	 0.0	 1	 -30.0	 30.0;
	2949	 963	 0.066264	 0.181154	 0.0024	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3917	 963	 0.086672	 0.222021	 0.0026	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	4439	 963	 0.020584	 0.054523	 0.0006	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	2741	 964	 0.009506	 0.029383	 0.0094	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	3460	 964	 0.014691	 0.038518	 0.0121	 721	 721	 721	 0.0	 0.0	 1	 -30.0	 30.0;
	3770	 964	 0.030494	 0.079136	 0.0134	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	4014	 964	 0.022839	 0.059012	 0.0131	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	4051	 964	 0.01716	 0.081975	 0.005	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	5310	 964	 0.002593	 0.006173	 0.0042	 4437	 4437	 4437	 0.0	 0.0	 1	 -30.0	 30.0;
	2742	 964	 0.009506	 0.029506	 0.0096	 959	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	3769	 964	 0.030494	 0.079012	 0.0153	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	1461	 965	 0.003101	 0.020859	 0.0375	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1461	 965	 0.004978	 0.022005	 0.0359	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1461	 965	 0.003121	 0.0208	 0.0506	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 967	 0.000499	 0.005048	 0.13	 1380.0	 1380.0	 1380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 966	 0.000499	 0.005042	 0.13	 1380.0	 1380.0	 1380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 968	 0.010985	 0.027891	 0.0014	 1015	 1015	 1015	 0.0	 0.0	 1	 -30.0	 30.0;
	2950	 968	 0.079113	 0.201058	 0.0075	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	1745	 970	 0.002193	 0.010884	 0.0197	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4135	 970	 0.004049	 0.018272	 0.0324	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3315	 971	 0.057284	 0.127778	 0.0057	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	5786	 971	 0.015309	 0.041728	 0.0019	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	2262	 972	 0.091711	 0.291509	 0.0034	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	2606	 972	 0.193139	 0.35354	 0.0037	 76	 76	 76	 0.0	 0.0	 1	 -30.0	 30.0;
	4098	 972	 0.056437	 0.143109	 0.0016	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	1851	 972	 0.049131	 0.124969	 0.0078	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	4811	 972	 0.021416	 0.054422	 0.0006	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 973	 0.011032	 0.050442	 0.0871	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2087	 973	 0.001481	 0.013926	 0.0516	 604.0	 604.0	 604.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2087	 973	 0.001481	 0.013926	 0.0516	 604.0	 604.0	 604.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2774	 974	 0.023935	 0.0645	 0.0007	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	3052	 976	 0.000342	 0.000625	 0.0002	 41442	 41442	 41442	 0.0	 0.0	 1	 -30.0	 30.0;
	3345	 976	 0.059713	 0.152179	 0.003	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	5241	 977	 0.018645	 0.047871	 0.0013	 575	 575	 575	 0.0	 0.0	 1	 -30.0	 30.0;
	2961	 978	 0.019259	 0.052593	 0.0024	 531	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	3365	 978	 0.01716	 0.044938	 0.0021	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	5717	 978	 0.025185	 0.064691	 0.0031	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	3365	 978	 0.00716	 0.029753	 0.0016	 971	 971	 971	 0.0	 0.0	 1	 -30.0	 30.0;
	5361	 978	 0.046667	 0.125926	 0.006	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3365	 978	 0.00716	 0.02963	 0.0016	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 979	 0.0016	 0.017334	 0.4043	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2460	 979	 0.000312	 0.004044	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3706	 979	 0.000824	 0.010499	 0.3754	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4968	 979	 0.00133	 0.014252	 0.3263	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2460	 979	 0.000312	 0.004044	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3706	 979	 0.000824	 0.010505	 0.3754	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2244	 980	 0.140111	 0.432376	 0.0055	 67	 67	 67	 0.0	 0.0	 1	 -30.0	 30.0;
	2651	 980	 0.1065	 0.298388	 0.0035	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	2774	 980	 0.012346	 0.05039	 0.0012	 587	 587	 587	 0.0	 0.0	 1	 -30.0	 30.0;
	3810	 980	 0.024994	 0.166415	 0.0019	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 980	 0.033686	 0.073394	 0.0008	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	4284	 980	 0.009347	 0.042404	 0.0163	 701	 701	 701	 0.0	 0.0	 1	 -30.0	 30.0;
	4728	 980	 0.089796	 0.228471	 0.0026	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	4284	 980	 0.0097	 0.04457	 0.0192	 667	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	3811	 981	 0.001936	 0.012879	 0.0243	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1114	 982	 0.023432	 0.074578	 0.001	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	5552	 982	 0.035273	 0.103301	 0.001	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 982	 0.009322	 0.023935	 0.0002	 1150	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	5005	 982	 0.019728	 0.054548	 0.0006	 510	 510	 510	 0.0	 0.0	 1	 -30.0	 30.0;
	2484	 983	 0.010617	 0.044444	 0.0023	 651	 651	 651	 0.0	 0.0	 1	 -30.0	 30.0;
	2823	 983	 0.044198	 0.120864	 0.0058	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	2170	 984	 0.010582	 0.027463	 0.0003	 1004	 1004	 1004	 0.0	 0.0	 1	 -30.0	 30.0;
	3839	 984	 0.011842	 0.030486	 0.0003	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	1382	 986	 0.020123	 0.052839	 0.0024	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	2718	 986	 0.011482	 0.023086	 0.001	 1152	 1152	 1152	 0.0	 0.0	 1	 -30.0	 30.0;
	1205	 987	 0.001111	 0.00321	 0.0008	 8928	 8928	 8928	 0.0	 0.0	 1	 -30.0	 30.0;
	4423	 988	 0.000164	 0.001106	 0.002	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3201	 989	 0.024188	 0.067523	 0.0031	 412	 412	 412	 0.0	 0.0	 1	 -30.0	 30.0;
	3469	 990	 0.038765	 0.105062	 0.0049	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	2305	 991	 0.011358	 0.022839	 0.001	 1165	 1165	 1165	 0.0	 0.0	 1	 -30.0	 30.0;
	2296	 992	 0.001764	 0.006299	 0.0076	 4380	 4380	 4380	 0.0	 0.0	 1	 -30.0	 30.0;
	3741	 992	 0.004188	 0.007666	 0.006	 3280	 3280	 3280	 0.0	 0.0	 1	 -30.0	 30.0;
	4796	 992	 0.004289	 0.007852	 0.0061	 3203	 3203	 3203	 0.0	 0.0	 1	 -30.0	 30.0;
	4795	 992	 0.002016	 0.005039	 0.0054	 5279	 5279	 5279	 0.0	 0.0	 1	 -30.0	 30.0;
	1123	 994	 0.000336	 0.000849	 0.1448	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1186	 993	 0.000178	 0.000691	 0.1002	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4912	 994	 0.000316	 0.001304	 0.1863	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4942	 994	 9.9e-05	 0.000612	 0.082	 387.0	 387.0	 387.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 995	 0.024691	 0.083648	 0.001	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	3776	 995	 0.070547	 0.239607	 0.0028	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	1350	 996	 0.065256	 0.144369	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	2072	 996	 0.024943	 0.10456	 0.001	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 997	 0.036029	 0.09675	 0.0045	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	1089	 998	 0.074074	 0.201562	 0.0022	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	2111	 998	 0.112119	 0.304107	 0.0034	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	1042	 1000	 0.019652	 0.081885	 0.0052	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	1082	 1000	 0.010078	 0.039305	 0.0	 728	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	1255	 1000	 0.019652	 0.082389	 0.0081	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	5278	 1000	 0.00252	 0.01033	 0.0	 2777	 2777	 2777	 0.0	 0.0	 1	 -30.0	 30.0;
	4763	 1001	 0.001146	 0.007111	 0.2238	 298.0	 298.0	 298.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2074	 1002	 0.001136	 0.012874	 0.2917	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3607	 1002	 0.000547	 0.010021	 0.2801	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4465	 1002	 0.001184	 0.012029	 0.309	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1586	 1002	 0.000369	 0.006726	 0.1892	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2073	 1002	 0.001136	 0.012874	 0.2917	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 1002	 0.001177	 0.012029	 0.309	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 1003	 0.007531	 0.019136	 0.0042	 1475	 1475	 1475	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 1003	 0.011975	 0.031975	 0.0065	 889	 889	 889	 0.0	 0.0	 1	 -30.0	 30.0;
	4635	 1004	 0.00861	 0.015761	 0.0002	 1645	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	2127	 1005	 0.008062	 0.022172	 0.0	 1252	 1252	 1252	 0.0	 0.0	 1	 -30.0	 30.0;
	2906	 1005	 0.025951	 0.083144	 0.001	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 1007	 7.9e-05	 0.000316	 0.001	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1730	 1008	 0.030494	 0.083333	 0.0039	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	5354	 1008	 0.031358	 0.085556	 0.004	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 1009	 0.005185	 0.014198	 0.0006	 1966	 1966	 1966	 0.0	 0.0	 1	 -30.0	 30.0;
	3929	 1010	 0.001956	 0.008844	 0.0027	 3362	 3362	 3362	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 1012	 0.000198	 0.000672	 0.1509	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5683	 1011	 0.000198	 0.000691	 0.1529	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5242	 1013	 0.000988	 0.001975	 0.0002	 13732	 13732	 13732	 0.0	 0.0	 1	 -30.0	 30.0;
	2213	 1014	 0.037284	 0.094815	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	2864	 1014	 0.024074	 0.065309	 0.0031	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	2864	 1014	 0.025185	 0.064938	 0.0031	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	1252	 1015	 0.002822	 0.013404	 0.02	 2156	 2156	 2156	 0.0	 0.0	 1	 -30.0	 30.0;
	3458	 1015	 0.010834	 0.033006	 0.0146	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	5238	 1015	 0.000171	 0.000313	 0.0001	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	5357	 1015	 0.004082	 0.012295	 0.0107	 2280	 2280	 2280	 0.0	 0.0	 1	 -30.0	 30.0;
	1252	 1015	 0.003956	 0.018569	 0.0074	 1556	 1556	 1556	 0.0	 0.0	 1	 -30.0	 30.0;
	1960	 1016	 0.009264	 0.031822	 0.0567	 289.0	 289.0	 289.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5238	 1017	 0.023331	 0.055304	 0.0038	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	4790	 1018	 0.024074	 0.063086	 0.0031	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	1755	 1019	 0.062661	 0.158806	 0.0018	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	4149	 1019	 0.058755	 0.186143	 0.0104	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	2276	 1020	 0.003779	 0.011338	 0.0002	 2545	 2545	 2545	 0.0	 0.0	 1	 -30.0	 30.0;
	4291	 1020	 0.020282	 0.08385	 0.001	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 1021	 0.026203	 0.066264	 0.0008	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	2629	 1021	 0.001409	 0.002579	 0.0012	 10350	 10350	 10350	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 1021	 0.026203	 0.066012	 0.0008	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 1021	 0.027387	 0.067523	 0.0008	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	1357	 1023	 2e-05	 0.000198	 0.0051	 154266	 154266	 154266	 0.0	 0.0	 1	 -30.0	 30.0;
	1357	 1022	 4e-05	 0.000198	 0.0061	 151981	 151981	 151981	 0.0	 0.0	 1	 -30.0	 30.0;
	5391	 1024	 0.024444	 0.074074	 0.0089	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	5243	 1025	 0.01037	 0.022222	 0.0	 1065	 1065	 1065	 0.0	 0.0	 1	 -30.0	 30.0;
	3344	 1027	 0.00642	 0.022222	 0.0	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	3344	 1026	 0.014815	 0.03358	 0.0	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	4511	 1028	 0.027617	 0.074617	 0.0036	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	2158	 1029	 0.005432	 0.010988	 0.0318	 2424	 2424	 2424	 0.0	 0.0	 1	 -30.0	 30.0;
	2810	 1029	 0.018765	 0.079506	 0.004	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	1480	 1031	 0.000756	 0.003527	 0.0053	 8853	 8853	 8853	 0.0	 0.0	 1	 -30.0	 30.0;
	1480	 1030	 0.001008	 0.004283	 0.0066	 7257	 7257	 7257	 0.0	 0.0	 1	 -30.0	 30.0;
	4096	 1032	 0.00322	 0.021689	 0.0688	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1358	 1033	 0.015117	 0.027715	 0.0018	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	4646	 1034	 0.01037	 0.027778	 0.0013	 1023	 1023	 1023	 0.0	 0.0	 1	 -30.0	 30.0;
	4646	 1035	 0.00963	 0.024815	 0.0016	 1140	 1140	 1140	 0.0	 0.0	 1	 -30.0	 30.0;
	4646	 1034	 0.009506	 0.025185	 0.0011	 1127	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	4895	 1036	 0.011482	 0.024321	 0.0109	 1105	 1105	 1105	 0.0	 0.0	 1	 -30.0	 30.0;
	2159	 1037	 0.014109	 0.046107	 0.0036	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	3053	 1037	 0.038801	 0.098262	 0.0038	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	4368	 1037	 0.024439	 0.06198	 0.0007	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	2159	 1037	 0.014109	 0.046107	 0.0036	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 1037	 0.039053	 0.098765	 0.004	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	4367	 1037	 0.024188	 0.060972	 0.0007	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	3783	 1037	 0.011086	 0.030738	 0.0012	 877	 877	 877	 0.0	 0.0	 1	 -30.0	 30.0;
	3783	 1037	 0.011086	 0.028219	 0.0014	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	1385	 1038	 0.003516	 0.016415	 0.0273	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3176	 1038	 0.004168	 0.028346	 0.0537	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3351	 1038	 0.001936	 0.00883	 0.0445	 3425	 3425	 3425	 0.0	 0.0	 1	 -30.0	 30.0;
	3918	 1038	 0.008099	 0.036603	 0.0901	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5010	 1038	 0.000948	 0.005886	 0.0289	 5192	 5192	 5192	 0.0	 0.0	 1	 -30.0	 30.0;
	5011	 1038	 0.000948	 0.005748	 0.0304	 5314	 5314	 5314	 0.0	 0.0	 1	 -30.0	 30.0;
	1385	 1038	 0.002311	 0.015763	 0.0435	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3784	 1038	 0.000336	 0.002331	 0.004	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3056	 1038	 0.000211	 0.001199	 0.0405	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3055	 1038	 0.000209	 0.001189	 0.0405	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1043	 1039	 2.1e-05	 0.000208	 0.0058	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1076	 1039	 0.00126	 0.014141	 0.2845	 1191.0	 1191.0	 1191.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3785	 1040	 7.9e-05	 0.000859	 0.0173	 1204.0	 1204.0	 1204.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 1041	 0.001904	 0.021302	 0.4679	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	4949	 1040	 0.001517	 0.01687	 0.3494	 1659.0	 1659.0	 1659.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5244	 1041	 2.1e-05	 0.000187	 0.0029	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1043	 1041	 2.1e-05	 0.000208	 0.0058	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1076	 1039	 0.00126	 0.01412	 0.2859	 1191.0	 1191.0	 1191.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2970	 1040	 0.000983	 0.010949	 0.2397	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3154	 1040	 0.001711	 0.017348	 0.4476	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 1040	 0.001281	 0.018476	 0.491	 1720	 1720	 1720	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 1040	 0.001274	 0.018324	 0.4837	 1735	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	1104	 1045	 0.002268	 0.004535	 0.0029	 5823	 5823	 5823	 0.0	 0.0	 1	 -30.0	 30.0;
	2277	 1045	 0.024691	 0.063492	 0.0033	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	3303	 1045	 0.131771	 0.345427	 0.0075	 80	 80	 80	 0.0	 0.0	 1	 -30.0	 30.0;
	4402	 1045	 0.056185	 0.182162	 0.0038	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 1045	 0.164777	 0.432855	 0.0096	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	5173	 1045	 0.026455	 0.070043	 0.004	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	5689	 1044	 0.011086	 0.028219	 0.0003	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	1101	 1045	 0.001738	 0.005442	 0.0058	 5169	 5169	 5169	 0.0	 0.0	 1	 -30.0	 30.0;
	5690	 1044	 0.010985	 0.028093	 0.0003	 979	 979	 979	 0.0	 0.0	 1	 -30.0	 30.0;
	1103	 1044	 0.002016	 0.004031	 0.0033	 6551	 6551	 6551	 0.0	 0.0	 1	 -30.0	 30.0;
	2669	 1044	 0.037793	 0.09801	 0.0017	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	1198	 1046	 0.002943	 0.02001	 0.0375	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2865	 1046	 0.005926	 0.04079	 0.077	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3757	 1046	 0.004571	 0.030552	 0.0557	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4881	 1046	 0.002121	 0.009661	 0.0162	 355.0	 355.0	 355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5320	 1046	 0.002969	 0.013217	 0.0233	 400.0	 400.0	 400.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5447	 1046	 0.005551	 0.025146	 0.0445	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1228	 1047	 0.01037	 0.028395	 0.0013	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	1228	 1047	 0.010247	 0.028395	 0.0013	 1001	 1001	 1001	 0.0	 0.0	 1	 -30.0	 30.0;
	3134	 1048	 0.006954	 0.049307	 0.0161	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	4978	 1048	 0.00257	 0.015949	 0.0282	 1828	 1828	 1828	 0.0	 0.0	 1	 -30.0	 30.0;
	1945	 1049	 0.000409	 0.005409	 0.1877	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2469	 1049	 0.001371	 0.013871	 0.361	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 1049	 0.002154	 0.021884	 0.566	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	1945	 1049	 0.000416	 0.005443	 0.1877	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2469	 1049	 0.001364	 0.01383	 0.3596	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 1049	 0.002154	 0.021877	 0.566	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	1187	 1051	 0.000968	 0.002943	 0.3453	 9991	 9991	 9991	 0.0	 0.0	 1	 -30.0	 30.0;
	1269	 1051	 0.000217	 0.000849	 0.0931	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3168	 1051	 0.001205	 0.002746	 0.4668	 10322	 10322	 10322	 0.0	 0.0	 1	 -30.0	 30.0;
	3949	 1051	 0.000454	 0.002331	 0.0516	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4957	 1051	 0.001284	 0.0096	 0.038	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5035	 1050	 0.001225	 0.006104	 0.0203	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 1050	 0.000257	 0.000849	 0.1893	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3948	 1050	 0.000553	 0.002548	 0.0486	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4957	 1051	 0.001284	 0.00956	 0.038	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4957	 1051	 0.000909	 0.00879	 0.039	 833.0	 833.0	 833.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 1051	 0.000533	 0.005096	 0.0248	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 1052	 0.001764	 0.003527	 0.0005	 7488	 7488	 7488	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 1053	 0.000277	 0.002618	 0.0693	 921.0	 921.0	 921.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2412	 1054	 0.058453	 0.13026	 0.001	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	4425	 1054	 0.069035	 0.16906	 0.0026	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	3201	 1055	 0.016629	 0.04258	 0.0005	 680	 680	 680	 0.0	 0.0	 1	 -30.0	 30.0;
	4396	 1061	 0.011235	 0.025679	 0.0113	 1127	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	2213	 1062	 0.045926	 0.11679	 0.0055	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	2813	 1062	 0.037284	 0.100617	 0.0049	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 1062	 0.032778	 0.088963	 0.0074	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	5380	 1062	 0.029518	 0.074827	 0.0034	 370	 370	 370	 0.0	 0.0	 1	 -30.0	 30.0;
	1517	 1063	 0.007802	 0.052444	 0.1018	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2811	 1063	 0.003101	 0.020563	 0.0385	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3757	 1063	 0.003761	 0.025235	 0.0456	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5053	 1063	 0.008889	 0.032197	 0.0537	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1517	 1063	 0.01442	 0.071763	 0.1291	 372.0	 372.0	 372.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4994	 1064	 0.08516	 0.17682	 0.0019	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	2592	 1065	 0.000381	 0.007008	 0.2079	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2592	 1066	 0.000374	 0.006434	 0.2209	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2003	 1067	 0.014361	 0.041824	 0.0006	 688	 688	 688	 0.0	 0.0	 1	 -30.0	 30.0;
	2266	 1067	 0.106576	 0.275384	 0.0031	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 1067	 0.022676	 0.070043	 0.0013	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	5366	 1067	 0.021164	 0.057949	 0.0001	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	2832	 1068	 0.001679	 0.017284	 0.0582	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2832	 1068	 0.001501	 0.018568	 0.0562	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5031	 1069	 0.066012	 0.134543	 0.0014	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	5248	 1069	 0.06576	 0.166793	 0.0019	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 1070	 0.079113	 0.21542	 0.0024	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	2667	 1070	 0.072058	 0.150668	 0.0017	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 1070	 7.6e-05	 0.000151	 0.0	 179912	 179912	 179912	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 1071	 0.020408	 0.055682	 0.0006	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	3005	 1072	 0.03477	 0.078861	 0.0016	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	5716	 1073	 0.058201	 0.120534	 0.0013	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	2219	 1074	 0.168733	 0.377072	 0.004	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	3952	 1074	 0.06329	 0.171429	 0.0019	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	2573	 1075	 0.00079	 0.005345	 0.0354	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2703	 1075	 0.00255	 0.017084	 0.0309	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2573	 1075	 0.000745	 0.005047	 0.0349	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1930	 1076	 0.000741	 0.009716	 0.335	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 1076	 0.000422	 0.004709	 0.0953	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1930	 1076	 0.000741	 0.009709	 0.335	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 1076	 0.000422	 0.004758	 0.0953	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 1076	 0.000644	 0.005035	 0.1112	 1397.0	 1397.0	 1397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2249	 1077	 0.024188	 0.063744	 0.0737	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	2753	 1077	 0.107533	 0.274654	 0.0194	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	2837	 1077	 0.017637	 0.051146	 0.0578	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	5601	 1077	 0.047109	 0.086232	 0.0012	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5602	 1077	 0.026203	 0.066516	 0.0007	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	5834	 1077	 0.132023	 0.291509	 0.0	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	3032	 1078	 0.004514	 0.029863	 0.1096	 439.0	 439.0	 439.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 1080	 1.4e-05	 0.000208	 0.0058	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 1079	 2.1e-05	 0.000242	 0.0087	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5312	 1081	 7.4e-05	 0.001235	 0.0	 24008	 24008	 24008	 0.0	 0.0	 1	 -30.0	 30.0;
	1952	 1083	 0.035853	 0.12517	 0.0031	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	2343	 1083	 0.076594	 0.195011	 0.003	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	2297	 1084	 0.012094	 0.066264	 0.0021	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	4680	 1084	 0.041824	 0.106576	 0.004	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	5552	 1084	 0.037793	 0.122197	 0.0021	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	5719	 1084	 0.068531	 0.232804	 0.0027	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	1786	 1085	 0.002402	 0.015149	 0.0582	 472.0	 472.0	 472.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2298	 1085	 0.000889	 0.005333	 0.0101	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1669	 1086	 0.004787	 0.013354	 0.0002	 2144	 2144	 2144	 0.0	 0.0	 1	 -30.0	 30.0;
	4981	 1087	 0.066541	 0.175309	 0.002	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	4981	 1087	 0.066692	 0.174628	 0.002	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	1939	 1088	 0.002268	 0.004787	 0.0	 5574	 5574	 5574	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 1088	 0.002016	 0.004031	 0.0	 6551	 6551	 6551	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 1088	 0.000252	 0.000756	 0.0	 37051	 37051	 37051	 0.0	 0.0	 1	 -30.0	 30.0;
	2743	 1089	 0.096498	 0.261779	 0.0071	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	2513	 1090	 0.057949	 0.147644	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	4358	 1090	 0.040564	 0.103301	 0.0012	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	1205	 1091	 0.009383	 0.039506	 0.007	 747	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 1091	 0.003615	 0.006617	 0.019	 4022	 4022	 4022	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 1092	 0.000751	 0.004978	 0.0091	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2726	 1092	 0.001738	 0.011694	 0.0213	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 1092	 0.000652	 0.004346	 0.0081	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1470	 1093	 0.000252	 0.00252	 0.0016	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	1469	 1094	 0.000252	 0.00252	 0.0017	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	1485	 1096	 0.000593	 0.002667	 0.0051	 374.0	 374.0	 374.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1485	 1095	 0.000591	 0.00268	 0.0046	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4260	 1097	 0.001764	 0.004787	 0.0001	 5788	 5788	 5788	 0.0	 0.0	 1	 -30.0	 30.0;
	1766	 1098	 0.106296	 0.194573	 0.002	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 1098	 0.05543	 0.187957	 0.0022	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	2297	 1099	 0.006047	 0.013605	 0.0152	 1984	 1984	 1984	 0.0	 0.0	 1	 -30.0	 30.0;
	2297	 1099	 0.010834	 0.030234	 0.0051	 920	 920	 920	 0.0	 0.0	 1	 -30.0	 30.0;
	3523	 1100	 0.002469	 0.015319	 0.0271	 1903	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	3523	 1100	 0.002771	 0.009322	 0.0121	 3036	 3036	 3036	 0.0	 0.0	 1	 -30.0	 30.0;
	4551	 1102	 0.007055	 0.014109	 0.0103	 1872	 1872	 1872	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 1105	 2.5e-05	 0.000252	 0.0003	 113138	 113138	 113138	 0.0	 0.0	 1	 -30.0	 30.0;
	5576	 1106	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5577	 1106	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	2424	 1107	 0.059965	 0.158982	 0.0019	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	2596	 1107	 0.007811	 0.051146	 0.0006	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	2424	 1107	 0.059965	 0.158982	 0.0019	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3582	 1108	 0.000972	 0.012113	 0.1636	 1786.0	 1786.0	 1786.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2747	 1109	 0.007811	 0.014361	 0.0107	 1807	 1807	 1807	 0.0	 0.0	 1	 -30.0	 30.0;
	2321	 1110	 0.032099	 0.089506	 0.0044	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 1110	 0.002469	 0.007284	 0.0154	 3862	 3862	 3862	 0.0	 0.0	 1	 -30.0	 30.0;
	5253	 1111	 0.000493	 0.000902	 0.0001	 27873	 27873	 27873	 0.0	 0.0	 1	 -30.0	 30.0;
	2452	 1113	 0.030617	 0.077778	 0.0037	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	4504	 1113	 0.048765	 0.13716	 0.0068	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	5080	 1113	 0.033827	 0.092222	 0.0044	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 1114	 0.024943	 0.071806	 0.001	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	3578	 1115	 0.009322	 0.038801	 0.0005	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 1115	 0.097002	 0.245654	 0.0028	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	5226	 1115	 0.006551	 0.019148	 0.0002	 1503	 1503	 1503	 0.0	 0.0	 1	 -30.0	 30.0;
	5227	 1115	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 1115	 0.135047	 0.342404	 0.0039	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	3578	 1115	 0.010078	 0.041572	 0.0006	 711	 711	 711	 0.0	 0.0	 1	 -30.0	 30.0;
	3601	 1115	 0.01877	 0.076266	 0.0016	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	3601	 1115	 0.018796	 0.076392	 0.0018	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	1541	 1116	 0.003477	 0.023249	 0.0425	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2125	 1116	 0.006341	 0.042232	 0.078	 415.0	 415.0	 415.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1957	 1117	 0.012824	 0.032552	 0.0004	 870	 870	 870	 0.0	 0.0	 1	 -30.0	 30.0;
	2568	 1118	 0.013681	 0.036029	 0.001	 790	 790	 790	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 1120	 0.016125	 0.041572	 0.0	 683	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	2504	 1119	 0.009826	 0.034517	 0.0479	 848	 848	 848	 0.0	 0.0	 1	 -30.0	 30.0;
	4440	 1119	 0.003779	 0.010078	 0.0001	 2826	 2826	 2826	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 1120	 0.025699	 0.066012	 0.0	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	2504	 1119	 0.009826	 0.034517	 0.0479	 848	 848	 848	 0.0	 0.0	 1	 -30.0	 30.0;
	3548	 1121	 0.000171	 0.000313	 0.0003	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	5254	 1121	 0.001764	 0.010582	 0.0002	 2753	 2753	 2753	 0.0	 0.0	 1	 -30.0	 30.0;
	1499	 1122	 0.014074	 0.038889	 0.0018	 719	 719	 719	 0.0	 0.0	 1	 -30.0	 30.0;
	1918	 1122	 0.026667	 0.072963	 0.0034	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	2082	 1122	 0.022099	 0.067778	 0.0033	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	1545	 1124	 0.004198	 0.011482	 0.0005	 2430	 2430	 2430	 0.0	 0.0	 1	 -30.0	 30.0;
	4961	 1124	 0.038518	 0.103951	 0.005	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	4961	 1124	 0.038518	 0.103827	 0.0053	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	2568	 1125	 0.015873	 0.04258	 0.0039	 670	 670	 670	 0.0	 0.0	 1	 -30.0	 30.0;
	2568	 1126	 0.003754	 0.010557	 0.0129	 2715	 2715	 2715	 0.0	 0.0	 1	 -30.0	 30.0;
	5256	 1127	 4.5e-05	 8.9e-05	 0.0007	 320583	 320583	 320583	 0.0	 0.0	 1	 -30.0	 30.0;
	1306	 1128	 0.023683	 0.0645	 0.001	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	2320	 1129	 0.014109	 0.060217	 0.0	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	4529	 1129	 0.002771	 0.007559	 0.0	 3778	 3778	 3778	 0.0	 0.0	 1	 -30.0	 30.0;
	1382	 1130	 0.027778	 0.070494	 0.0032	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	3392	 1130	 0.008272	 0.016543	 0.0007	 1606	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	4686	 1132	 0.043803	 0.118383	 0.0061	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	5258	 1133	 0.001008	 0.002771	 0.0001	 10315	 10315	 10315	 0.0	 0.0	 1	 -30.0	 30.0;
	1228	 1134	 0.03642	 0.105309	 0.0052	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	2717	 1134	 0.009136	 0.024568	 0.0011	 1134	 1134	 1134	 0.0	 0.0	 1	 -30.0	 30.0;
	5503	 1134	 0.009259	 0.024568	 0.0011	 1132	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	1229	 1135	 0.002601	 0.017284	 0.0324	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5098	 1135	 0.008257	 0.036427	 0.0582	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 1136	 0.033704	 0.10358	 0.0053	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	5649	 1136	 0.022222	 0.058395	 0.0028	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	3074	 1137	 0.047619	 0.141345	 0.002	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	3749	 1137	 0.002016	 0.008566	 0.0013	 3356	 3356	 3356	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 1137	 0.00126	 0.003527	 0.0	 7884	 7884	 7884	 0.0	 0.0	 1	 -30.0	 30.0;
	3100	 1137	 0.013102	 0.05543	 0.001	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	2264	 1138	 0.001857	 0.014461	 0.0481	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4901	 1138	 0.003202	 0.030829	 0.1164	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1358	 1139	 0.084656	 0.189216	 0.0023	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	3245	 1139	 0.098765	 0.269085	 0.003	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	1358	 1139	 0.080373	 0.203326	 0.0023	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	2803	 1141	 0.05543	 0.141597	 0.0018	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	2986	 1140	 0.104308	 0.216175	 0.0023	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 1141	 0.006047	 0.016377	 0.0002	 1642	 1642	 1642	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 1140	 0.006475	 0.028395	 0.0436	 984	 984	 984	 0.0	 0.0	 1	 -30.0	 30.0;
	5485	 1141	 0.04384	 0.142101	 0.0017	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	2467	 1142	 0.006005	 0.02878	 0.0496	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2987	 1142	 0.003595	 0.0176	 0.0294	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4999	 1143	 0.002133	 0.014756	 0.0294	 2077	 2077	 2077	 0.0	 0.0	 1	 -30.0	 30.0;
	5259	 1144	 0.016377	 0.044596	 0.0005	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	2383	 1145	 0.059965	 0.168556	 0.002	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	2843	 1145	 0.018141	 0.05039	 0.0006	 552	 552	 552	 0.0	 0.0	 1	 -30.0	 30.0;
	5224	 1145	 0.051398	 0.2129	 0.0027	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 1145	 0.094734	 0.259007	 0.0027	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	5448	 1145	 0.0451	 0.186193	 0.0023	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	5266	 1145	 0.023432	 0.066264	 0.0007	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	3667	 1146	 0.00642	 0.043852	 0.083	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4184	 1146	 0.003002	 0.020227	 0.0385	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3713	 1147	 8.9e-05	 0.000751	 0.079	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 1148	 0.039557	 0.107886	 0.0012	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	1241	 1150	 0.003477	 0.018074	 0.0304	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 1150	 0.003141	 0.015526	 0.0268	 253.0	 253.0	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3336	 1150	 0.000237	 0.001541	 0.0091	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2588	 1151	 0.068272	 0.212346	 0.0104	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	4350	 1151	 0.051975	 0.158025	 0.0076	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	1814	 1152	 0.074049	 0.166364	 0.0018	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 1152	 0.074931	 0.204031	 0.0023	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	3619	 1153	 0.020494	 0.046049	 0.0021	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	3810	 1154	 0.004837	 0.017334	 0.0007	 1691	 1691	 1691	 0.0	 0.0	 1	 -30.0	 30.0;
	2137	 1155	 0.022676	 0.075082	 0.0009	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	3023	 1156	 0.006803	 0.018896	 0.0002	 1471	 1471	 1471	 0.0	 0.0	 1	 -30.0	 30.0;
	3465	 1156	 0.003779	 0.009826	 0.0	 2805	 2805	 2805	 0.0	 0.0	 1	 -30.0	 30.0;
	3507	 1156	 0.04006	 0.134039	 0.0021	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 1155	 0.006047	 0.028723	 0.0	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	5629	 1155	 0.006047	 0.016125	 0.0	 1715	 1715	 1715	 0.0	 0.0	 1	 -30.0	 30.0;
	5667	 1155	 0.022928	 0.065508	 0.001	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	2138	 1157	 0.001086	 0.00642	 0.0121	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2706	 1157	 0.004464	 0.021452	 0.0385	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3362	 1158	 0.023683	 0.043588	 0.0004	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	4742	 1158	 0.004283	 0.021164	 0.0156	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	5770	 1158	 0.071554	 0.184177	 0.002	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	5260	 1159	 0.00679	 0.018025	 0.0008	 1543	 1543	 1543	 0.0	 0.0	 1	 -30.0	 30.0;
	2456	 1160	 0.000158	 0.000474	 0.0506	 278.0	 278.0	 278.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 1160	 0.000198	 0.00077	 0.0972	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5263	 1161	 1.6e-05	 9.9e-05	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5262	 1162	 1.6e-05	 9.9e-05	 0.001	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4792	 1163	 0.001358	 0.008148	 0.0005	 3672	 3672	 3672	 0.0	 0.0	 1	 -30.0	 30.0;
	4791	 1164	 0.001481	 0.009012	 0.0005	 3321	 3321	 3321	 0.0	 0.0	 1	 -30.0	 30.0;
	4792	 1165	 0.001481	 0.009259	 0.0005	 3234	 3234	 3234	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 1166	 0.004899	 0.033007	 0.0699	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3906	 1166	 0.005531	 0.037215	 0.0678	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4660	 1166	 0.004365	 0.029491	 0.0537	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3906	 1166	 0.005452	 0.036365	 0.0668	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4563	 1167	 0.008314	 0.034266	 0.0004	 816	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	5114	 1169	 0.04	 0.088889	 0.0	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	2580	 1170	 0.03477	 0.088183	 0.003	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	4981	 1171	 0.054271	 0.137566	 0.0016	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5594	 1171	 0.111481	 0.204065	 0.0019	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	1485	 1172	 0.003002	 0.014163	 0.0253	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1944	 1172	 0.001778	 0.009837	 0.0248	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2829	 1173	 0.031975	 0.089753	 0.0042	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	3091	 1173	 0.026296	 0.066667	 0.0031	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	3639	 1173	 0.031975	 0.082963	 0.0037	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	4201	 1173	 0.00437	 0.011975	 0.0097	 2331	 2331	 2331	 0.0	 0.0	 1	 -30.0	 30.0;
	4225	 1173	 0.002963	 0.018642	 0.0015	 1574	 1574	 1574	 0.0	 0.0	 1	 -30.0	 30.0;
	4684	 1173	 0.009136	 0.024938	 0.0011	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	5621	 1173	 0.009012	 0.022222	 0.001	 1239	 1239	 1239	 0.0	 0.0	 1	 -30.0	 30.0;
	3091	 1173	 0.026049	 0.071111	 0.0034	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	4224	 1173	 0.006667	 0.01679	 0.0008	 1645	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	5704	 1173	 0.007802	 0.01979	 0.001	 1397	 1397	 1397	 0.0	 0.0	 1	 -30.0	 30.0;
	1517	 1174	 0.005491	 0.037076	 0.0658	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4226	 1174	 0.000454	 0.0032	 0.0051	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5264	 1174	 0.00083	 0.005669	 0.0111	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1517	 1174	 0.005412	 0.036543	 0.0658	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1517	 1174	 0.005432	 0.036543	 0.0658	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 1179	 0.109785	 0.20096	 0.0	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 1180	 0.00877	 0.026489	 0.0435	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	4053	 1180	 0.000968	 0.003516	 0.0061	 8488	 8488	 8488	 0.0	 0.0	 1	 -30.0	 30.0;
	5698	 1180	 0.008099	 0.028247	 0.0466	 1054	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	3541	 1180	 0.001521	 0.00721	 0.0121	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5019	 1181	 0.06358	 0.165802	 0.0079	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	1191	 1182	 0.000335	 0.000613	 0.001	 43410	 43410	 43410	 0.0	 0.0	 1	 -30.0	 30.0;
	2652	 1184	 0.011852	 0.030988	 0.0015	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	5845	 1183	 0.019383	 0.052469	 0.0024	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	3227	 1185	 0.034266	 0.089947	 0.001	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	1707	 1186	 0.000138	 0.000573	 0.0699	 259.0	 259.0	 259.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3915	 1188	 0.006296	 0.016914	 0.0008	 1646	 1646	 1646	 0.0	 0.0	 1	 -30.0	 30.0;
	5403	 1188	 0.03321	 0.087778	 0.0042	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	3163	 1189	 0.000198	 0.000731	 0.647	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 1189	 0.000652	 0.002351	 0.5123	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 1189	 0.000593	 0.005649	 0.0223	 656.0	 656.0	 656.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3163	 1189	 0.000182	 0.000622	 0.5559	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 1189	 0.000652	 0.00237	 0.5133	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5421	 1189	 0.000612	 0.005669	 0.0278	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3163	 1189	 0.000237	 0.002114	 0.1954	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5364	 1189	 0.000217	 0.002054	 0.0197	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 1189	 0.000217	 0.002035	 0.0147	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 1190	 0.065508	 0.1678	 0.0024	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	4617	 1190	 0.036332	 0.092089	 0.001	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 1191	 0.008148	 0.034197	 0.0016	 863	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 1191	 0.005679	 0.021975	 0.0137	 1337	 1337	 1337	 0.0	 0.0	 1	 -30.0	 30.0;
	4160	 1191	 0.000753	 0.001379	 0.0026	 19301	 19301	 19301	 0.0	 0.0	 1	 -30.0	 30.0;
	4082	 1193	 2.5e-05	 0.151172	 0.0	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	4320	 1194	 0.060972	 0.168052	 0.0021	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	5749	 1193	 0.03676	 0.081381	 0.0027	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	4082	 1192	 2.5e-05	 0.000252	 0.0	 116592	 116592	 116592	 0.0	 0.0	 1	 -30.0	 30.0;
	3524	 1196	 0.00287	 0.017709	 0.0334	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 1195	 0.002015	 0.012879	 0.0243	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1960	 1196	 0.00482	 0.03119	 0.0577	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1962	 1197	 0.000529	 0.008085	 0.2498	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3135	 1197	 0.001142	 0.014569	 0.3855	 1746.0	 1746.0	 1746.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2104	 1198	 0.002884	 0.019358	 0.0714	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3547	 1198	 0.004978	 0.024514	 0.0435	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3667	 1198	 0.015328	 0.102262	 0.1903	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	4345	 1198	 0.005531	 0.02797	 0.0567	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5637	 1198	 0.001067	 0.007289	 0.0486	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1175	 1198	 5.9e-05	 0.000889	 0.003	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3547	 1198	 0.002805	 0.019002	 0.0365	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5447	 1198	 0.001027	 0.006775	 0.0121	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1176	 1198	 7.9e-05	 0.00083	 0.002	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1177	 1198	 5.9e-05	 0.000652	 0.001	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 1199	 0.003102	 0.031524	 0.8202	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	2609	 1199	 0.001168	 0.011767	 0.3018	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 1199	 0.00313	 0.031724	 0.8202	 996	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	2608	 1199	 0.001163	 0.011728	 0.3018	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2786	 1199	 0.004905	 0.049964	 1.301	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	1178	 1199	 2.1e-05	 0.000249	 0.0058	 921.0	 921.0	 921.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3388	 1200	 0.082389	 0.220711	 0.0026	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	4004	 1200	 0.083648	 0.172084	 0.0019	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5582	 1200	 0.051398	 0.110355	 0.0015	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	4656	 1201	 0.01479	 0.048677	 0.0187	 564	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	5439	 1201	 0.002595	 0.011665	 0.0285	 2398	 2398	 2398	 0.0	 0.0	 1	 -30.0	 30.0;
	5438	 1201	 0.002595	 0.011665	 0.0285	 2398	 2398	 2398	 0.0	 0.0	 1	 -30.0	 30.0;
	1206	 1202	 0.001027	 0.004721	 0.0081	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2968	 1202	 0.001027	 0.004899	 0.0091	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 1204	 0.000741	 0.002346	 0.0002	 12326	 12326	 12326	 0.0	 0.0	 1	 -30.0	 30.0;
	4980	 1204	 0.042963	 0.117531	 0.0	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	5089	 1203	 0.01963	 0.051481	 0.0024	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	5163	 1203	 0.020247	 0.055556	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	2725	 1205	 0.011482	 0.051111	 0.0026	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	3958	 1205	 0.014938	 0.037654	 0.013	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	3959	 1205	 0.015185	 0.037531	 0.0133	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	4421	 1205	 0.000123	 0.001235	 0.0016	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	4422	 1205	 0.000123	 0.001235	 0.0016	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	2940	 1206	 0.002548	 0.012346	 0.0203	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3887	 1207	 0.021416	 0.054422	 0.0006	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	5004	 1207	 0.053414	 0.136306	 0.0015	 208	 208	 208	 0.0	 0.0	 1	 -30.0	 30.0;
	1987	 1207	 0.016755	 0.04263	 0.0005	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 1207	 0.0194	 0.049887	 0.0006	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 1208	 0.004721	 0.031348	 0.0587	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4902	 1208	 0.003556	 0.023585	 0.0435	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5269	 1209	 0.000123	 0.001235	 0.0002	 27851	 27851	 27851	 0.0	 0.0	 1	 -30.0	 30.0;
	2253	 1210	 0.03225	 0.148904	 0.0018	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	3871	 1210	 0.008314	 0.034014	 0.0245	 844	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	4138	 1210	 0.084404	 0.252457	 0.0098	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	2253	 1210	 0.032754	 0.15092	 0.0014	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	5726	 1210	 0.014361	 0.038801	 0.0004	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	1639	 1211	 0.00156	 0.01039	 0.0192	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 1211	 0.001084	 0.005086	 0.0111	 361.0	 361.0	 361.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3179	 1211	 0.002153	 0.012978	 0.0243	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 1211	 0.0011	 0.004978	 0.0142	 353.0	 353.0	 353.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3179	 1211	 0.002173	 0.013017	 0.0243	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4606	 1212	 0.002469	 0.009877	 0.0008	 2918	 2918	 2918	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 1213	 0.00963	 0.025309	 0.0013	 1097	 1097	 1097	 0.0	 0.0	 1	 -30.0	 30.0;
	5717	 1213	 0.037037	 0.094938	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	5271	 1214	 0.000158	 0.000691	 0.001	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3039	 1215	 0.002544	 0.02015	 0.0348	 561.0	 561.0	 561.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4456	 1215	 0.003727	 0.028836	 0.0527	 562.0	 562.0	 562.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3710	 1216	 0.012522	 0.044041	 0.0263	 665	 665	 665	 0.0	 0.0	 1	 -30.0	 30.0;
	4360	 1216	 0.044848	 0.110103	 0.0013	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	2662	 1217	 0.032704	 0.079542	 0.0022	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	2889	 1217	 0.011338	 0.026455	 0.0009	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	1299	 1218	 3.5e-05	 0.000512	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3607	 1218	 0.001887	 0.019088	 0.4938	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4574	 1218	 0.001579	 0.01509	 0.4087	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 1218	 0.000949	 0.009342	 0.2426	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1296	 1218	 3.5e-05	 0.000506	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3607	 1218	 0.001874	 0.018954	 0.491	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 1218	 0.00097	 0.009536	 0.2484	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1298	 1218	 3.5e-05	 0.000547	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 1218	 0.00097	 0.009536	 0.2484	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1297	 1218	 3.5e-05	 0.000547	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1990	 1220	 0.021679	 0.058309	 0.0041	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	1810	 1221	 0.007307	 0.029479	 0.005	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	2752	 1221	 0.000756	 0.00252	 0.0037	 10890	 10890	 10890	 0.0	 0.0	 1	 -30.0	 30.0;
	1350	 1222	 0.081436	 0.149069	 0.001	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3859	 1222	 0.069287	 0.175611	 0.002	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	3428	 1223	 0.047161	 0.123827	 0.0058	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 1224	 0.044198	 0.12058	 0.0057	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	5268	 1225	 0.049876	 0.126444	 0.006	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	5274	 1226	 0.000869	 0.006025	 0.0101	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1246	 1227	 0.035021	 0.091963	 0.0021	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5412	 1228	 0.047901	 0.095926	 0.004	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	1383	 1230	 0.006047	 0.018896	 0.0067	 1489	 1489	 1489	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 1231	 0.070295	 0.178634	 0.002	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	4439	 1231	 0.061804	 0.156765	 0.0017	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	3496	 1232	 0.001134	 0.002671	 0.0006	 10482	 10482	 10482	 0.0	 0.0	 1	 -30.0	 30.0;
	4438	 1232	 0.065079	 0.165004	 0.0019	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	1342	 1233	 0.00897	 0.050315	 0.0103	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	1653	 1233	 0.028975	 0.081885	 0.0127	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	2430	 1233	 0.048501	 0.135047	 0.0031	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	2496	 1233	 0.02192	 0.071051	 0.0011	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	4350	 1234	 0.034568	 0.087407	 0.004	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	4452	 1234	 0.038642	 0.105309	 0.0049	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	1777	 1236	 0.009506	 0.039259	 0.0021	 736	 736	 736	 0.0	 0.0	 1	 -30.0	 30.0;
	3046	 1236	 0.050124	 0.136543	 0.0073	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	1777	 1236	 0.009506	 0.039259	 0.0021	 736	 736	 736	 0.0	 0.0	 1	 -30.0	 30.0;
	3606	 1238	 0.001764	 0.012346	 0.0011	 2368	 2368	 2368	 0.0	 0.0	 1	 -30.0	 30.0;
	4282	 1238	 0.006803	 0.028975	 0.0	 993	 993	 993	 0.0	 0.0	 1	 -30.0	 30.0;
	5241	 1237	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 1237	 0.008314	 0.018141	 0.0	 1480	 1480	 1480	 0.0	 0.0	 1	 -30.0	 30.0;
	5650	 1237	 0.004686	 0.019829	 0.0002	 1450	 1450	 1450	 0.0	 0.0	 1	 -30.0	 30.0;
	3606	 1238	 0.007307	 0.028975	 0.0018	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	1683	 1241	 0.001027	 0.006677	 0.0121	 488.0	 488.0	 488.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2086	 1240	 0.009521	 0.064237	 0.1215	 375.0	 375.0	 375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 1241	 0.002133	 0.023348	 0.0648	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3336	 1239	 0.002232	 0.007802	 0.0142	 287.0	 287.0	 287.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3967	 1240	 0.000593	 0.002588	 0.0162	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 1240	 2e-05	 0.015803	 0.0	 287.0	 287.0	 287.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4139	 1241	 0.001778	 0.016356	 0.0405	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4525	 1241	 0.011694	 0.078657	 0.1519	 375.0	 375.0	 375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5698	 1241	 0.000237	 0.00156	 0.0142	 19617	 19617	 19617	 0.0	 0.0	 1	 -30.0	 30.0;
	1683	 1240	 0.001027	 0.006657	 0.0121	 464.0	 464.0	 464.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3541	 1240	 0.00476	 0.022499	 0.0375	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 1239	 2e-05	 0.000198	 0.0	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 1242	 0.000462	 0.006438	 0.1689	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 1242	 0.000462	 0.006434	 0.1689	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5551	 1243	 0.106551	 0.225649	 0.0024	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	1827	 1244	 0.003234	 0.01923	 0.0365	 410.0	 410.0	 410.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1960	 1244	 0.019951	 0.071546	 0.1144	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	3312	 1244	 0.016	 0.053472	 0.0861	 555	 555	 555	 0.0	 0.0	 1	 -30.0	 30.0;
	1616	 1245	 0.017637	 0.056185	 0.001	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	1855	 1245	 0.002851	 0.005218	 0.0036	 4966	 4966	 4966	 0.0	 0.0	 1	 -30.0	 30.0;
	1617	 1245	 0.018141	 0.057193	 0.001	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	1854	 1245	 0.00126	 0.004535	 0.0046	 6273	 6273	 6273	 0.0	 0.0	 1	 -30.0	 30.0;
	2874	 1246	 0.212444	 0.388876	 0.0042	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	3824	 1246	 0.012598	 0.031998	 0.0004	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	5177	 1246	 0.022928	 0.060721	 0.0007	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	3574	 1247	 0.005472	 0.037728	 0.0709	 411.0	 411.0	 411.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4571	 1247	 0.000968	 0.00638	 0.0111	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5496	 1247	 0.005669	 0.025639	 0.0456	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4291	 1248	 0.147644	 0.301587	 0.0057	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 1248	 0.125548	 0.318292	 0.0036	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	4291	 1248	 0.179214	 0.32805	 0.0054	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	2263	 1249	 0.082196	 0.171444	 0.0486	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	4565	 1252	 0.001008	 0.002771	 0.0021	 10014	 10014	 10014	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 1252	 0.001367	 0.002502	 0.0021	 10356	 10356	 10356	 0.0	 0.0	 1	 -30.0	 30.0;
	5115	 1253	 0.032963	 0.083704	 0.0039	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 1253	 0.037901	 0.103457	 0.0049	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	5278	 1254	 0.017133	 0.071806	 0.0071	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	1657	 1257	 0.007037	 0.019012	 0.0002	 1583	 1583	 1583	 0.0	 0.0	 1	 -30.0	 30.0;
	2094	 1258	 0.002825	 0.018765	 0.0349	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2526	 1258	 0.000474	 0.003101	 0.0061	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 1258	 0.00173	 0.01154	 0.0213	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 1258	 0.001719	 0.011496	 0.0289	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 1259	 0.074074	 0.187957	 0.0021	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	5494	 1259	 0.008163	 0.021769	 0.0002	 1309	 1309	 1309	 0.0	 0.0	 1	 -30.0	 30.0;
	2338	 1260	 0.064752	 0.177375	 0.002	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 1261	 0.000436	 0.000797	 0.0	 32501	 32501	 32501	 0.0	 0.0	 1	 -30.0	 30.0;
	2256	 1263	 0.060897	 0.161552	 0.0022	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	4715	 1263	 0.020433	 0.06062	 0.0007	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	4734	 1262	 0.017611	 0.061779	 0.0101	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	5548	 1262	 0.075787	 0.176316	 0.0041	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5777	 1263	 0.076871	 0.206828	 0.0028	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	4715	 1262	 0.009574	 0.038549	 0.0017	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	4734	 1263	 0.019148	 0.071051	 0.0075	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	1843	 1264	 0.013472	 0.067378	 0.1215	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3899	 1264	 0.004563	 0.02448	 0.0425	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5131	 1264	 0.010627	 0.045511	 0.0749	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 1264	 0.009798	 0.045748	 0.0815	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 1264	 0.011674	 0.053096	 0.0921	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3153	 1265	 0.000812	 0.006278	 0.1271	 1397.0	 1397.0	 1397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3812	 1265	 0.001797	 0.019272	 0.4216	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 1265	 0.003831	 0.029281	 0.592	 1080	 1080	 1080	 0.0	 0.0	 1	 -30.0	 30.0;
	4093	 1266	 0.042076	 0.209121	 0.0025	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	1510	 1267	 0.145125	 0.32124	 0.0037	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	2662	 1267	 0.07609	 0.189468	 0.0021	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	2008	 1269	 0.000198	 0.0016	 0.162	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3953	 1269	 0.000454	 0.001106	 0.1002	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4645	 1268	 0.000316	 0.000948	 0.1094	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 1270	 0.00642	 0.026914	 0.0013	 1096	 1096	 1096	 0.0	 0.0	 1	 -30.0	 30.0;
	2262	 1271	 0.037793	 0.118922	 0.0013	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	4218	 1272	 0.067926	 0.165331	 0.0019	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 1272	 0.012598	 0.031242	 0.0003	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	5282	 1273	 0.008566	 0.019652	 0.0017	 1337	 1337	 1337	 0.0	 0.0	 1	 -30.0	 30.0;
	1962	 1274	 0.00077	 0.011178	 0.312	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 1274	 0.00088	 0.012722	 0.3292	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 1274	 0.000312	 0.004467	 0.1155	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1962	 1275	 0.000771	 0.011192	 0.291	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 1275	 0.00088	 0.012715	 0.3292	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4465	 1275	 0.000312	 0.004467	 0.1155	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1547	 1276	 0.028975	 0.073318	 0.0008	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	3201	 1276	 0.036785	 0.093222	 0.001	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 1278	 2e-05	 0.000198	 0.003	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	4583	 1277	 0.000178	 0.000632	 0.078	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5283	 1279	 0.007559	 0.020912	 0.0002	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 1280	 0.026914	 0.085062	 0.0049	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	3980	 1280	 0.021235	 0.067654	 0.004	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	4792	 1283	 0.000675	 0.001235	 0.0036	 21546	 21546	 21546	 0.0	 0.0	 1	 -30.0	 30.0;
	2271	 1284	 0.005556	 0.029136	 0.0005	 1079	 1079	 1079	 0.0	 0.0	 1	 -30.0	 30.0;
	2714	 1284	 0.012099	 0.059753	 0.0013	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	2272	 1285	 0.00077	 0.005195	 0.0091	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3640	 1285	 0.000553	 0.003694	 0.0157	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3922	 1285	 0.000514	 0.001007	 0.1499	 27378	 27378	 27378	 0.0	 0.0	 1	 -30.0	 30.0;
	4879	 1285	 0.001679	 0.008296	 0.0152	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 1285	 0.002548	 0.016968	 0.0314	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2272	 1285	 0.000731	 0.004938	 0.0091	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3640	 1285	 0.000533	 0.003635	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3921	 1285	 0.000494	 0.001007	 0.1488	 27596	 27596	 27596	 0.0	 0.0	 1	 -30.0	 30.0;
	1838	 1286	 0.000514	 0.001185	 0.0719	 23964	 23964	 23964	 0.0	 0.0	 1	 -30.0	 30.0;
	2048	 1287	 0.016327	 0.049786	 0.0024	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	3764	 1287	 0.009574	 0.033006	 0.0017	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	1633	 1288	 0.038889	 0.098889	 0.0047	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	5178	 1288	 0.002049	 0.005617	 0.0124	 4968	 4968	 4968	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 1288	 0.002481	 0.006531	 0.0003	 4252	 4252	 4252	 0.0	 0.0	 1	 -30.0	 30.0;
	5143	 1289	 0.013144	 0.024059	 0.004	 1046	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	5813	 1290	 0.006551	 0.016629	 0.0005	 1702	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	2011	 1291	 0.000756	 0.005795	 0.0001	 5205	 5205	 5205	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 1292	 0.000138	 0.000573	 0.001	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5216	 1293	 0.001008	 0.003527	 0.0001	 8292	 8292	 8292	 0.0	 0.0	 1	 -30.0	 30.0;
	5217	 1293	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	2306	 1294	 0.048879	 0.100781	 0.0011	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	3945	 1294	 0.085664	 0.234568	 0.0033	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	3945	 1294	 0.091711	 0.240363	 0.0032	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	2663	 1295	 0.000632	 0.004168	 0.0081	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3449	 1300	 0.011518	 0.029173	 0.0014	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	2032	 1301	 0.03679	 0.10037	 0.0047	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 1301	 0.03321	 0.090494	 0.0039	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	5844	 1302	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	1304	 1303	 0.000504	 0.00252	 0.0001	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	4900	 1303	 0.089695	 0.201058	 0.0022	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 1305	 2e-05	 0.000198	 0.003	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2118	 1306	 0.006299	 0.017133	 0.0	 1618	 1618	 1618	 0.0	 0.0	 1	 -30.0	 30.0;
	2643	 1308	 0.0125	 0.025	 0.0	 1236	 1236	 1236	 0.0	 0.0	 1	 -30.0	 30.0;
	5825	 1309	 0.095666	 0.21222	 0.0023	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	5147	 1310	 0.011867	 0.030083	 0.0003	 941	 941	 941	 0.0	 0.0	 1	 -30.0	 30.0;
	5388	 1310	 0.133787	 0.246914	 0.0025	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	1349	 1311	 0.0004	 0.001244	 0.0004	 23302	 23302	 23302	 0.0	 0.0	 1	 -30.0	 30.0;
	1615	 1311	 0.019956	 0.0604	 0.0198	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	3911	 1311	 0.017467	 0.063733	 0.0216	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	3347	 1312	 0.005543	 0.015621	 0.0015	 1835	 1835	 1835	 0.0	 0.0	 1	 -30.0	 30.0;
	3710	 1312	 0.016125	 0.0516	 0.0253	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	4841	 1312	 0.028723	 0.062484	 0.0007	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 1313	 0.000252	 0.000756	 0.0	 38166	 38166	 38166	 0.0	 0.0	 1	 -30.0	 30.0;
	2928	 1314	 0.019652	 0.082137	 0.001	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 1314	 0.112875	 0.361048	 0.0037	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	5288	 1315	 0.005291	 0.013102	 0.0002	 2153	 2153	 2153	 0.0	 0.0	 1	 -30.0	 30.0;
	2621	 1316	 0.035021	 0.094734	 0.0011	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	5288	 1316	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 1316	 0.008566	 0.02318	 0.0002	 1231	 1231	 1231	 0.0	 0.0	 1	 -30.0	 30.0;
	1317	 1318	 0.00252	 0.005039	 0.0	 5399	 5399	 5399	 0.0	 0.0	 1	 -30.0	 30.0;
	1986	 1318	 0.039557	 0.078861	 0.0008	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	2607	 1319	 0.027901	 0.073951	 0.0036	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 1319	 0.02358	 0.064198	 0.0031	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	2607	 1319	 0.019753	 0.052963	 0.0026	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	2942	 1320	 0.047654	 0.121728	 0.0058	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 1322	 0.001975	 0.00642	 0.0001	 3887	 3887	 3887	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 1321	 0.001481	 0.004938	 0.0012	 5064	 5064	 5064	 0.0	 0.0	 1	 -30.0	 30.0;
	3431	 1323	 0.066012	 0.167549	 0.0019	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	1383	 1324	 0.031494	 0.131015	 0.007	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	4410	 1324	 0.01159	 0.04132	 0.0298	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	5588	 1324	 0.028219	 0.117158	 0.0017	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 1325	 0.001233	 0.008227	 0.0147	 525.0	 525.0	 525.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3679	 1326	 0.014462	 0.046762	 0.0375	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	5651	 1326	 0.002268	 0.005039	 0.011	 5504	 5504	 5504	 0.0	 0.0	 1	 -30.0	 30.0;
	4046	 1327	 0.002761	 0.005054	 0.0	 4533	 4533	 4533	 0.0	 0.0	 1	 -30.0	 30.0;
	3258	 1328	 0.018519	 0.047901	 0.0104	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	3527	 1328	 0.004198	 0.010741	 0.0005	 2576	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	2100	 1329	 0.077407	 0.154691	 0.0	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	5242	 1329	 0.009136	 0.020617	 0.001	 1345	 1345	 1345	 0.0	 0.0	 1	 -30.0	 30.0;
	4429	 1330	 0.000756	 0.00252	 0.0003	 11223	 11223	 11223	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 1331	 0.086143	 0.234971	 0.0039	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	4273	 1331	 0.035525	 0.095742	 0.0011	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	5745	 1331	 0.035878	 0.096649	 0.002	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	2077	 1332	 0.003911	 0.027062	 0.0486	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3032	 1332	 0.000711	 0.006894	 0.0223	 865.0	 865.0	 865.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3065	 1332	 0.007012	 0.030617	 0.0511	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 1332	 0.007639	 0.051542	 0.2291	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 1333	 0.002597	 0.034127	 1.1812	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	3433	 1333	 0.002999	 0.033656	 0.6729	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	4029	 1333	 0.001302	 0.013172	 0.3408	 1727.0	 1727.0	 1727.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 1333	 0.002597	 0.034127	 1.1783	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	3033	 1333	 0.000256	 0.002701	 0.0693	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4029	 1333	 0.001309	 0.013255	 0.3437	 1727.0	 1727.0	 1727.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5102	 1334	 0.004467	 0.008177	 0.0	 2802	 2802	 2802	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 1335	 0.010582	 0.066264	 0.0009	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 1335	 0.003527	 0.025699	 0.0	 1139	 1139	 1139	 0.0	 0.0	 1	 -30.0	 30.0;
	2135	 1336	 0.031242	 0.080121	 0.0009	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	5005	 1336	 0.11615	 0.314437	 0.0036	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 1337	 0.035525	 0.073066	 0.001	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	5172	 1337	 0.004787	 0.009574	 0.001	 2759	 2759	 2759	 0.0	 0.0	 1	 -30.0	 30.0;
	4884	 1338	 0.002765	 0.01843	 0.0344	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2086	 1339	 0.002114	 0.012662	 0.0233	 374.0	 374.0	 374.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5160	 1339	 0.000595	 0.004024	 0.0081	 503.0	 503.0	 503.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2087	 1341	 0.001264	 0.008415	 0.0152	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1845	 1342	 0.000504	 0.00252	 0.0021	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	1846	 1342	 0.000504	 0.00252	 0.0021	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	1756	 1344	 0.008987	 0.016452	 0.0116	 1575	 1575	 1575	 0.0	 0.0	 1	 -30.0	 30.0;
	5281	 1344	 0.019123	 0.0484	 0.0008	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	4198	 1345	 0.000731	 0.001383	 0.1853	 19787	 19787	 19787	 0.0	 0.0	 1	 -30.0	 30.0;
	3010	 1346	 0.019652	 0.049131	 0.0006	 575	 575	 575	 0.0	 0.0	 1	 -30.0	 30.0;
	2362	 1352	 0.000617	 0.001235	 0.0021	 21515	 21515	 21515	 0.0	 0.0	 1	 -30.0	 30.0;
	2362	 1351	 0.000617	 0.001235	 0.0016	 21515	 21515	 21515	 0.0	 0.0	 1	 -30.0	 30.0;
	1598	 1353	 0.07963	 0.159259	 0.0092	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	3879	 1354	 0.149205	 0.273119	 0.0029	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 1355	 0.045062	 0.118519	 0.0057	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 1355	 0.036914	 0.098025	 0.0047	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	1388	 1356	 0.03679	 0.081728	 0.0039	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	1950	 1356	 0.005432	 0.03358	 0.0018	 874	 874	 874	 0.0	 0.0	 1	 -30.0	 30.0;
	2625	 1356	 0.001852	 0.012099	 0.0006	 2427	 2427	 2427	 0.0	 0.0	 1	 -30.0	 30.0;
	2693	 1356	 0.046914	 0.118395	 0.0057	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	2694	 1356	 0.007654	 0.031975	 0.0016	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	2699	 1356	 0.018765	 0.072099	 0.0036	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	1387	 1356	 0.03679	 0.081852	 0.0039	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	1461	 1357	 0.005867	 0.03919	 0.083	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5335	 1357	 0.003812	 0.025482	 0.0466	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5135	 1358	 0.037289	 0.094734	 0.0001	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	3760	 1359	 0.00316	 0.021017	 0.0375	 528.0	 528.0	 528.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3811	 1359	 0.004612	 0.030706	 0.0547	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 1360	 0.006299	 0.028219	 0.0003	 1022	 1022	 1022	 0.0	 0.0	 1	 -30.0	 30.0;
	4473	 1361	 0.0451	 0.082641	 0.0044	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	5359	 1362	 0.063333	 0.161605	 0.0076	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	3834	 1364	 0.000138	 0.001363	 0.2025	 22551	 22551	 22551	 0.0	 0.0	 1	 -30.0	 30.0;
	3834	 1363	 0.000158	 0.001323	 0.1822	 23186	 23186	 23186	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 1365	 0.000741	 0.001481	 0.0021	 17936	 17936	 17936	 0.0	 0.0	 1	 -30.0	 30.0;
	5770	 1366	 0.034014	 0.086672	 0.001	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	1708	 1369	 0.011633	 0.021293	 0.0127	 1181	 1181	 1181	 0.0	 0.0	 1	 -30.0	 30.0;
	1714	 1368	 0.008062	 0.016377	 0.0115	 1570	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	1715	 1367	 0.007307	 0.014613	 0.0112	 1754	 1754	 1754	 0.0	 0.0	 1	 -30.0	 30.0;
	1798	 1370	 0.000559	 0.001024	 0.0729	 26532	 26532	 26532	 0.0	 0.0	 1	 -30.0	 30.0;
	1381	 1371	 0.021083	 0.038593	 0.0279	 672	 672	 672	 0.0	 0.0	 1	 -30.0	 30.0;
	3257	 1371	 0.001512	 0.003779	 0.0001	 7254	 7254	 7254	 0.0	 0.0	 1	 -30.0	 30.0;
	5293	 1371	 0.001764	 0.006047	 0.0001	 4688	 4688	 4688	 0.0	 0.0	 1	 -30.0	 30.0;
	5295	 1371	 0.031242	 0.127488	 0.0017	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5294	 1371	 0.031494	 0.127992	 0.0023	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	5310	 1373	 0.021111	 0.055679	 0.0026	 499	 499	 499	 0.0	 0.0	 1	 -30.0	 30.0;
	2078	 1372	 0.044938	 0.12284	 0.0057	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 1374	 0.001235	 0.003704	 0.0002	 7767	 7767	 7767	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 1375	 0.000292	 0.002538	 0.2546	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 1376	 0.058201	 0.116654	 0.0012	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	2541	 1377	 0.069035	 0.233308	 0.0028	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 1378	 0.000123	 0.001235	 0.0002	 27851	 27851	 27851	 0.0	 0.0	 1	 -30.0	 30.0;
	4844	 1379	 0.000632	 0.004306	 0.0081	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2346	 1380	 0.071907	 0.195263	 0.0025	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	3707	 1380	 0.001764	 0.003275	 0.0025	 8177	 8177	 8177	 0.0	 0.0	 1	 -30.0	 30.0;
	3917	 1380	 0.067599	 0.182036	 0.0029	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 1380	 0.015369	 0.04132	 0.0005	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	4450	 1383	 0.004787	 0.01285	 0.0232	 2154	 2154	 2154	 0.0	 0.0	 1	 -30.0	 30.0;
	5276	 1383	 0.003275	 0.014361	 0.0069	 2005	 2005	 2005	 0.0	 0.0	 1	 -30.0	 30.0;
	1665	 1384	 0.041824	 0.180146	 0.0022	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	2051	 1384	 0.04132	 0.14059	 0.0017	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	3275	 1384	 0.041068	 0.16906	 0.0021	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	4003	 1384	 0.067775	 0.174099	 0.0019	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	5520	 1384	 0.035928	 0.074502	 0.0135	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	5760	 1384	 0.031998	 0.081129	 0.001	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	2539	 1384	 0.06324	 0.158982	 0.0072	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	4002	 1384	 0.065508	 0.166037	 0.0019	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	4945	 1384	 0.039305	 0.102797	 0.0181	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	5519	 1384	 0.03094	 0.06382	 0.0116	 404	 404	 404	 0.0	 0.0	 1	 -30.0	 30.0;
	3438	 1386	 0.001244	 0.008415	 0.0309	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4096	 1386	 0.002114	 0.014242	 0.0486	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3412	 1388	 0.001852	 0.004198	 0.0002	 6474	 6474	 6474	 0.0	 0.0	 1	 -30.0	 30.0;
	2611	 1387	 0.044198	 0.094074	 0.0044	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 1389	 0.136558	 0.304107	 0.0033	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	2662	 1391	 0.023935	 0.060469	 0.0007	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	3050	 1391	 0.031494	 0.079869	 0.0009	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	3394	 1392	 0.042983	 0.090073	 0.0047	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5529	 1392	 0.007811	 0.016125	 0.0002	 1600	 1600	 1600	 0.0	 0.0	 1	 -30.0	 30.0;
	2147	 1393	 0.036281	 0.082389	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	3866	 1393	 0.015117	 0.036281	 0.0004	 752	 752	 752	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 1393	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 1393	 0.028723	 0.090451	 0.001	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 1394	 0.000617	 0.001235	 0.0006	 21515	 21515	 21515	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 1395	 0.046359	 0.095994	 0.0011	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	4973	 1395	 0.046611	 0.09801	 0.0011	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	4975	 1396	 0.001719	 0.008	 0.0132	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 1397	 0.009948	 0.01821	 0.0	 1462	 1462	 1462	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 1398	 0.013354	 0.034266	 0.0004	 827	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	2568	 1398	 0.043689	 0.110784	 0.0017	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	5299	 1399	 0.000252	 0.001008	 0.0	 28417	 28417	 28417	 0.0	 0.0	 1	 -30.0	 30.0;
	2343	 1400	 0.091459	 0.249685	 0.0028	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 1401	 0.112634	 0.206176	 0.0021	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	5594	 1401	 0.097905	 0.179214	 0.0018	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	5300	 1404	 0.012346	 0.024943	 0.0002	 1093	 1093	 1093	 0.0	 0.0	 1	 -30.0	 30.0;
	1952	 1405	 0.019929	 0.079592	 0.0093	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	3702	 1405	 0.051071	 0.160116	 0.0096	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3865	 1405	 0.008566	 0.018896	 0.0213	 1424	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	3865	 1405	 0.008566	 0.018896	 0.0213	 1424	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	1300	 1408	 0.021482	 0.055185	 0.0026	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	1813	 1408	 0.004568	 0.012716	 0.0457	 2199	 2199	 2199	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 1408	 0.049012	 0.132963	 0.0062	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	5098	 1409	 0.000608	 0.004067	 0.0071	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5665	 1409	 0.002054	 0.013689	 0.0253	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2871	 1410	 0.001764	 0.005039	 0.0056	 5697	 5697	 5697	 0.0	 0.0	 1	 -30.0	 30.0;
	3173	 1410	 0.063593	 0.161275	 0.0018	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	5571	 1411	 0.00126	 0.003779	 0.0001	 7412	 7412	 7412	 0.0	 0.0	 1	 -30.0	 30.0;
	5803	 1412	 0.000504	 0.001008	 0.0	 26199	 26199	 26199	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 1413	 0.000504	 0.001764	 0.0018	 16094	 16094	 16094	 0.0	 0.0	 1	 -30.0	 30.0;
	2237	 1414	 0.020937	 0.064651	 0.001	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	4149	 1414	 0.026455	 0.084656	 0.001	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	5797	 1414	 0.013605	 0.062938	 0.0076	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 1415	 0.029151	 0.078005	 0.0009	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	5768	 1415	 0.031998	 0.083144	 0.001	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	2485	 1416	 0.049568	 0.127321	 0.006	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	2873	 1416	 0.028876	 0.078765	 0.0039	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	4627	 1416	 0.058988	 0.149741	 0.0071	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 1417	 0.009826	 0.025951	 0.0003	 1097	 1097	 1097	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 1417	 0.014865	 0.039808	 0.0005	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	2610	 1419	 0.033086	 0.069383	 0.0032	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	3235	 1418	 0.014938	 0.040494	 0.0018	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	2611	 1419	 0.033086	 0.069506	 0.0032	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	3234	 1419	 0.014938	 0.040494	 0.0018	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	3675	 1420	 0.002716	 0.007519	 0.0391	 3794	 3794	 3794	 0.0	 0.0	 1	 -30.0	 30.0;
	3675	 1420	 0.004631	 0.008476	 0.0207	 3140	 3140	 3140	 0.0	 0.0	 1	 -30.0	 30.0;
	3879	 1422	 0.010758	 0.044621	 0.0011	 663	 663	 663	 0.0	 0.0	 1	 -30.0	 30.0;
	3879	 1421	 0.034713	 0.063542	 0.0007	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	3608	 1423	 0.007432	 0.019803	 0.0019	 1434	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	2008	 1424	 0.000356	 0.000731	 0.0415	 38069	 38069	 38069	 0.0	 0.0	 1	 -30.0	 30.0;
	3888	 1425	 0.065256	 0.173091	 0.0065	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	5304	 1425	 0.000252	 0.001008	 0.0001	 29272	 29272	 29272	 0.0	 0.0	 1	 -30.0	 30.0;
	5305	 1425	 0.000252	 0.001008	 0.0008	 29272	 29272	 29272	 0.0	 0.0	 1	 -30.0	 30.0;
	5307	 1426	 0.001167	 0.002137	 0.0	 12455	 12455	 12455	 0.0	 0.0	 1	 -30.0	 30.0;
	978	 1427	 0.07	 0.188889	 0.0091	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 1427	 0.027654	 0.075309	 0.0036	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	5094	 1427	 0.022222	 0.060741	 0.0029	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	5361	 1427	 0.023086	 0.062346	 0.0031	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	4004	 1428	 0.115646	 0.293777	 0.0033	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	5319	 1428	 0.065508	 0.166793	 0.0019	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	4051	 1429	 0.02642	 0.099012	 0.005	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	4520	 1429	 0.028889	 0.097901	 0.0047	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	1433	 1430	 2e-05	 9.8e-05	 0.0111	 309464	 309464	 309464	 0.0	 0.0	 1	 -30.0	 30.0;
	2552	 1431	 0.000968	 0.005906	 0.0602	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 1431	 0.001331	 0.009015	 0.0906	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1064	 1432	 0.035273	 0.092391	 0.001	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	4536	 1432	 0.000857	 0.002394	 0.0021	 11961	 11961	 11961	 0.0	 0.0	 1	 -30.0	 30.0;
	5032	 1432	 0.012094	 0.05165	 0.0006	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	1064	 1432	 0.034064	 0.09093	 0.001	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	2433	 1433	 0.00561	 0.030894	 0.0567	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 1433	 0.003812	 0.025383	 0.0471	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	926	 1434	 0.010582	 0.046359	 0.001	 621	 621	 621	 0.0	 0.0	 1	 -30.0	 30.0;
	1245	 1434	 0.014109	 0.044596	 0.001	 632	 632	 632	 0.0	 0.0	 1	 -30.0	 30.0;
	1616	 1434	 0.035273	 0.099521	 0.001	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	1773	 1434	 0.001915	 0.011817	 0.0209	 2467	 2467	 2467	 0.0	 0.0	 1	 -30.0	 30.0;
	2540	 1434	 0.005795	 0.023432	 0.004	 1224	 1224	 1224	 0.0	 0.0	 1	 -30.0	 30.0;
	1780	 1435	 0.034321	 0.087037	 0.004	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	5309	 1436	 0.000504	 0.001764	 0.0018	 16094	 16094	 16094	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 1437	 0.081381	 0.179894	 0.0021	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	4227	 1438	 0.008272	 0.018519	 0.0008	 1496	 1496	 1496	 0.0	 0.0	 1	 -30.0	 30.0;
	2495	 1439	 0.005039	 0.019148	 0.0268	 1537	 1537	 1537	 0.0	 0.0	 1	 -30.0	 30.0;
	2736	 1439	 0.070547	 0.192744	 0.0027	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	4207	 1439	 0.003275	 0.011086	 0.013	 2632	 2632	 2632	 0.0	 0.0	 1	 -30.0	 30.0;
	4697	 1439	 0.112371	 0.291509	 0.0033	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	5283	 1439	 0.038801	 0.098514	 0.001	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	2495	 1439	 0.004031	 0.014109	 0.014	 2073	 2073	 2073	 0.0	 0.0	 1	 -30.0	 30.0;
	2736	 1439	 0.107332	 0.198791	 0.0021	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	2495	 1439	 0.010756	 0.019689	 0.0139	 1356	 1356	 1356	 0.0	 0.0	 1	 -30.0	 30.0;
	4902	 1440	 0.005233	 0.024413	 0.0435	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5496	 1440	 0.002252	 0.01037	 0.0182	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4901	 1440	 0.00397	 0.02639	 0.0537	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2961	 1441	 0.034321	 0.088518	 0.0042	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 1441	 0.031482	 0.083333	 0.0039	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	1267	 1443	 0.141597	 0.439657	 0.0056	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	1323	 1443	 0.005291	 0.013605	 0.0002	 2023	 2023	 2023	 0.0	 0.0	 1	 -30.0	 30.0;
	3050	 1442	 0.048123	 0.121945	 0.0013	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	3071	 1443	 0.062484	 0.139834	 0.0016	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	4582	 1443	 0.028219	 0.071554	 0.0014	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	4767	 1442	 0.055682	 0.139078	 0.0016	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 1443	 0.018392	 0.040312	 0.0005	 667	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	5793	 1442	 0.012346	 0.037541	 0.0004	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	2663	 1444	 0.005314	 0.024119	 0.0425	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4704	 1444	 0.003398	 0.017541	 0.0314	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2663	 1444	 0.005412	 0.024571	 0.0461	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1447	 1445	 0.006159	 0.011274	 0.0058	 2231	 2231	 2231	 0.0	 0.0	 1	 -30.0	 30.0;
	1447	 1445	 0.004699	 0.008601	 0.0045	 2924	 2924	 2924	 0.0	 0.0	 1	 -30.0	 30.0;
	5310	 1446	 0.000247	 0.001235	 0.0	 23584	 23584	 23584	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 1448	 0.00126	 0.003275	 0.0	 8415	 8415	 8415	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 1449	 0.001256	 0.008251	 0.2389	 375.0	 375.0	 375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4763	 1449	 0.000158	 0.000652	 0.0729	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 1450	 0.012346	 0.037037	 0.0015	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 1452	 0.008209	 0.015026	 0.0002	 1777	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 1451	 0.008209	 0.015026	 0.0002	 1777	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	2686	 1453	 0.008566	 0.022172	 0.0002	 1280	 1280	 1280	 0.0	 0.0	 1	 -30.0	 30.0;
	5283	 1453	 0.007811	 0.020156	 0.0002	 1407	 1407	 1407	 0.0	 0.0	 1	 -30.0	 30.0;
	3461	 1454	 0.149811	 0.308818	 0.0034	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 1455	 0.001047	 0.006973	 0.0132	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3201	 1456	 0.002771	 0.005795	 0.0056	 4708	 4708	 4708	 0.0	 0.0	 1	 -30.0	 30.0;
	4331	 1459	 0.07483	 0.210632	 0.0024	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	3265	 1460	 0.027901	 0.076173	 0.0036	 367	 367	 367	 0.0	 0.0	 1	 -30.0	 30.0;
	4643	 1460	 0.016914	 0.044691	 0.0021	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	4659	 1460	 0.049383	 0.132222	 0.0063	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	5014	 1460	 0.077037	 0.201605	 0.0094	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	5113	 1460	 0.00284	 0.007531	 0.0003	 3691	 3691	 3691	 0.0	 0.0	 1	 -30.0	 30.0;
	4642	 1460	 0.016914	 0.044444	 0.0021	 625	 625	 625	 0.0	 0.0	 1	 -30.0	 30.0;
	5246	 1460	 0.015938	 0.040741	 0.0019	 679	 679	 679	 0.0	 0.0	 1	 -30.0	 30.0;
	2144	 1461	 0.005393	 0.029649	 0.0638	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2145	 1461	 0.005393	 0.02963	 0.0638	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5335	 1461	 0.001877	 0.012543	 0.0344	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1930	 1462	 0.000589	 0.007708	 0.2628	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 1462	 0.00115	 0.01169	 0.3032	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5086	 1462	 0.00241	 0.024446	 0.6325	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	1930	 1462	 0.000589	 0.007708	 0.2628	 2389.0	 2389.0	 2389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 1462	 0.00115	 0.01169	 0.3032	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 1462	 0.00153	 0.015526	 0.4014	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1622	 1463	 0.013605	 0.08516	 0.0011	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	2748	 1463	 0.030434	 0.05571	 0.0001	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	3528	 1463	 0.030486	 0.07735	 0.0057	 375	 375	 375	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 1463	 0.012598	 0.079365	 0.0017	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 1463	 0.092215	 0.209121	 0.0022	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	4882	 1464	 0.031975	 0.135062	 0.0069	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	3202	 1465	 0.004464	 0.029669	 0.0547	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4884	 1465	 0.005156	 0.034489	 0.0638	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2535	 1466	 0.027595	 0.050512	 0.0004	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	5019	 1467	 0.033086	 0.086049	 0.004	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 1467	 0.019753	 0.05	 0.0024	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 1468	 0.025951	 0.107332	 0.0045	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 1468	 0.025951	 0.107332	 0.0045	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 1469	 0.005367	 0.029554	 0.0308	 954	 954	 954	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 1470	 0.002771	 0.013605	 0.0249	 2064	 2064	 2064	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 1469	 0.004535	 0.023683	 0.026	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	3036	 1471	 0.040312	 0.104056	 0.0023	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	4359	 1471	 0.102797	 0.222978	 0.0025	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 1471	 0.040539	 0.105014	 0.0015	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	3036	 1471	 0.04132	 0.090552	 0.0028	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 1472	 0.008122	 0.036857	 0.0655	 329.0	 329.0	 329.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 1472	 0.011081	 0.049936	 0.0891	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 1473	 0.000336	 0.002173	 0.004	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5278	 1474	 0.02066	 0.055682	 0.001	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	4940	 1475	 0.063744	 0.162006	 0.0018	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 1476	 0.00037	 0.000988	 0.004	 28743	 28743	 28743	 0.0	 0.0	 1	 -30.0	 30.0;
	1889	 1477	 0.000974	 0.001783	 0.0008	 14533	 14533	 14533	 0.0	 0.0	 1	 -30.0	 30.0;
	2007	 1477	 0.000403	 0.001386	 0.0001	 20949	 20949	 20949	 0.0	 0.0	 1	 -30.0	 30.0;
	2702	 1477	 0.027967	 0.082137	 0.002	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	2944	 1477	 0.000504	 0.00126	 0.0	 21757	 21757	 21757	 0.0	 0.0	 1	 -30.0	 30.0;
	2943	 1477	 0.000504	 0.00126	 0.0	 21757	 21757	 21757	 0.0	 0.0	 1	 -30.0	 30.0;
	5532	 1477	 0.011338	 0.044848	 0.0014	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 1478	 0.00156	 0.01041	 0.0192	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2046	 1478	 0.000178	 0.001659	 0.0061	 818.0	 818.0	 818.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3744	 1478	 0.002035	 0.012563	 0.1094	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3768	 1478	 0.000257	 0.001659	 0.003	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 1478	 0.001432	 0.009557	 0.0223	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3768	 1478	 0.000158	 0.001067	 0.0046	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2518	 1479	 0.059209	 0.159486	 0.0019	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	2518	 1479	 0.059209	 0.159486	 0.0019	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	2554	 1481	 0.068959	 0.28511	 0.0156	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	4178	 1481	 0.050214	 0.205996	 0.0246	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	4279	 1481	 0.006727	 0.018141	 0.0009	 1572	 1572	 1572	 0.0	 0.0	 1	 -30.0	 30.0;
	4445	 1481	 0.100126	 0.274402	 0.0092	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	5111	 1481	 0.020408	 0.055933	 0.0023	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	5272	 1481	 0.050516	 0.173747	 0.0192	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 1481	 0.024439	 0.067019	 0.0023	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	5267	 1481	 0.050542	 0.17415	 0.02	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	3550	 1482	 0.004787	 0.011338	 0.006	 2721	 2721	 2721	 0.0	 0.0	 1	 -30.0	 30.0;
	4578	 1482	 0.00907	 0.018141	 0.0088	 1651	 1651	 1651	 0.0	 0.0	 1	 -30.0	 30.0;
	3366	 1482	 0.016125	 0.051398	 0.0004	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	4738	 1483	 0.003457	 0.008395	 0.0	 3272	 3272	 3272	 0.0	 0.0	 1	 -30.0	 30.0;
	4738	 1483	 0.000494	 0.008395	 0.0	 3532	 3532	 3532	 0.0	 0.0	 1	 -30.0	 30.0;
	2133	 1484	 0.008542	 0.029422	 0.0095	 1044	 1044	 1044	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 1485	 0.003368	 0.036373	 0.0273	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4848	 1486	 0.000375	 0.001383	 0.1711	 313.0	 313.0	 313.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4248	 1487	 0.027337	 0.11678	 0.0047	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	5314	 1487	 0.000171	 0.000313	 0.0	 85273	 85273	 85273	 0.0	 0.0	 1	 -30.0	 30.0;
	2806	 1488	 0.003086	 0.006173	 0.01	 4650	 4650	 4650	 0.0	 0.0	 1	 -30.0	 30.0;
	1673	 1489	 0.04966	 0.126455	 0.0014	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	5724	 1489	 0.052658	 0.143613	 0.0019	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	1717	 1490	 0.042076	 0.124213	 0.0028	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	5061	 1492	 0.000903	 0.006023	 0.0111	 522.0	 522.0	 522.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3017	 1493	 0.00284	 0.007531	 0.0003	 3697	 3697	 3697	 0.0	 0.0	 1	 -30.0	 30.0;
	4963	 1493	 0.039877	 0.104815	 0.0049	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	2607	 1498	 0.03284	 0.088765	 0.0042	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	2626	 1500	 0.06321	 0.14284	 0.0065	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	4001	 1500	 0.024074	 0.053704	 0.0024	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	2279	 1501	 0.063996	 0.161754	 0.0019	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 1501	 0.047956	 0.087783	 0.0025	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	4062	 1501	 0.010532	 0.063719	 0.0019	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	4716	 1501	 0.024691	 0.166515	 0.005	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	5066	 1501	 0.027816	 0.117662	 0.0028	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	4062	 1501	 0.010532	 0.063719	 0.0019	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	2763	 1502	 0.002359	 0.016431	 0.0203	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2281	 1503	 4e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4693	 1503	 5.9e-05	 0.001185	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4707	 1503	 4e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5315	 1504	 0.000123	 0.001235	 0.0002	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	4827	 1505	 0.010124	 0.043086	 0.0021	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	3371	 1506	 0.014568	 0.089753	 0.0079	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	5675	 1506	 0.00716	 0.044074	 0.0024	 680	 680	 680	 0.0	 0.0	 1	 -30.0	 30.0;
	3077	 1507	 0.059965	 0.163265	 0.0018	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	3042	 1508	 0.063744	 0.153742	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	3251	 1508	 0.058705	 0.149156	 0.0	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	2422	 1509	 0.070093	 0.188461	 0.0025	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 1509	 0.078357	 0.210708	 0.0088	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	4212	 1511	 0.110545	 0.202352	 0.0021	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	4212	 1511	 0.08642	 0.191232	 0.0021	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	2111	 1512	 0.065356	 0.166238	 0.0019	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	3646	 1512	 0.033333	 0.090829	 0.0021	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	3737	 1513	 0.061476	 0.209625	 0.0025	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	3894	 1513	 0.053918	 0.146888	 0.0017	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	4537	 1513	 0.017863	 0.060695	 0.0007	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3429	 1514	 0.049131	 0.204082	 0.0025	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	3737	 1514	 0.005543	 0.018896	 0.0002	 1500	 1500	 1500	 0.0	 0.0	 1	 -30.0	 30.0;
	3737	 1514	 0.005795	 0.0194	 0.0002	 1459	 1459	 1459	 0.0	 0.0	 1	 -30.0	 30.0;
	5814	 1515	 0.000968	 0.00644	 0.0121	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 1516	 0.064815	 0.170741	 0.0081	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	2604	 1516	 0.058778	 0.149012	 0.007	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4045	 1516	 0.010247	 0.027778	 0.0013	 1004	 1004	 1004	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 1516	 0.022469	 0.057407	 0.0028	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	5713	 1516	 0.012222	 0.026914	 0.0021	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	4045	 1516	 0.012346	 0.027407	 0.0021	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	3259	 1517	 0.011773	 0.053926	 0.0962	 427.0	 427.0	 427.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2351	 1518	 0.000966	 0.009803	 0.2526	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3416	 1518	 0.002015	 0.020838	 0.5401	 1517	 1517	 1517	 0.0	 0.0	 1	 -30.0	 30.0;
	2350	 1518	 0.000963	 0.009792	 0.2541	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4791	 1519	 0.029383	 0.123951	 0.0065	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	4792	 1519	 0.029383	 0.123951	 0.0065	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	1634	 1526	 0.041572	 0.113379	 0.0018	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	2415	 1526	 0.014865	 0.061476	 0.0008	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3435	 1526	 0.108088	 0.299824	 0.0027	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 1526	 0.096246	 0.262283	 0.0029	 106	 106	 106	 0.0	 0.0	 1	 -30.0	 30.0;
	5186	 1526	 0.058201	 0.161502	 0.0017	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	2415	 1526	 0.014865	 0.061476	 0.0008	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3739	 1527	 0.004207	 0.029077	 0.0547	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 1527	 0.002805	 0.019378	 0.0365	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2326	 1528	 0.01285	 0.055933	 0.0035	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	4915	 1528	 0.073318	 0.185941	 0.0038	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 1528	 0.074578	 0.22197	 0.007	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	4429	 1529	 0.065004	 0.182414	 0.0021	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	5316	 1530	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 1531	 0.018392	 0.114386	 0.0015	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	1780	 1532	 0.046049	 0.117284	 0.0058	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	2575	 1532	 0.042469	 0.114321	 0.0055	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	1549	 1533	 0.026173	 0.069753	 0.0139	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	1566	 1533	 0.062099	 0.167778	 0.0188	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 1534	 0.012099	 0.030617	 0.0013	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	4933	 1533	 0.049383	 0.128148	 0.006	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	5722	 1533	 0.011111	 0.028518	 0.0015	 971	 971	 971	 0.0	 0.0	 1	 -30.0	 30.0;
	4115	 1533	 0.017901	 0.048395	 0.0023	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	5447	 1535	 0.010311	 0.068543	 0.1276	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	5759	 1535	 0.001017	 0.006912	 0.0633	 449.0	 449.0	 449.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2472	 1536	 0.000976	 0.013206	 0.4448	 2406	 2406	 2406	 0.0	 0.0	 1	 -30.0	 30.0;
	2609	 1536	 0.001017	 0.010325	 0.2657	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2948	 1536	 0.001369	 0.017997	 0.6209	 1759	 1759	 1759	 0.0	 0.0	 1	 -30.0	 30.0;
	3626	 1536	 0.002352	 0.025391	 0.5704	 1245	 1245	 1245	 0.0	 0.0	 1	 -30.0	 30.0;
	3706	 1536	 0.002021	 0.026575	 0.9197	 1191	 1191	 1191	 0.0	 0.0	 1	 -30.0	 30.0;
	2472	 1536	 0.000976	 0.013213	 0.4448	 2405	 2405	 2405	 0.0	 0.0	 1	 -30.0	 30.0;
	2608	 1536	 0.001017	 0.010325	 0.2657	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1850	 1537	 0.016661	 0.030497	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	5017	 1537	 0.143109	 0.388511	 0.0044	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 1537	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5854	 1537	 0.096498	 0.265558	 0.003	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	2931	 1538	 0.047115	 0.12774	 0.0013	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5843	 1538	 0.006299	 0.015873	 0.0002	 1981	 1981	 1981	 0.0	 0.0	 1	 -30.0	 30.0;
	2103	 1539	 0.023935	 0.082389	 0.001	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 1539	 0.017889	 0.045855	 0.0006	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	3546	 1539	 0.063996	 0.162509	 0.0018	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	5185	 1539	 0.012598	 0.043588	 0.0005	 651	 651	 651	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 1540	 0.071806	 0.194004	 0.0022	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 1541	 0.005223	 0.034671	 0.076	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2016	 1542	 2.1e-05	 0.000301	 0.0116	 2176.0	 2176.0	 2176.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2520	 1542	 0.000697	 0.009107	 0.3114	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2017	 1542	 1.9e-05	 0.00028	 0.0108	 2176.0	 2176.0	 2176.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4859	 1542	 0.001244	 0.016445	 0.5652	 1934	 1934	 1934	 0.0	 0.0	 1	 -30.0	 30.0;
	1932	 1543	 0.008272	 0.021975	 0.001	 1292	 1292	 1292	 0.0	 0.0	 1	 -30.0	 30.0;
	3608	 1543	 0.026914	 0.111605	 0.0058	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	3978	 1543	 0.026173	 0.06716	 0.0031	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 1543	 0.014568	 0.03963	 0.0018	 719	 719	 719	 0.0	 0.0	 1	 -30.0	 30.0;
	3608	 1543	 0.026914	 0.111605	 0.0058	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	1736	 1544	 0.005096	 0.033837	 0.0628	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 1544	 0.005057	 0.030084	 0.0567	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3528	 1547	 0.044848	 0.113631	 0.0013	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	2152	 1548	 0.005301	 0.009703	 0.0123	 2751	 2751	 2751	 0.0	 0.0	 1	 -30.0	 30.0;
	2635	 1548	 0.012875	 0.032552	 0.0007	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	2152	 1548	 0.003023	 0.010582	 0.0124	 2764	 2764	 2764	 0.0	 0.0	 1	 -30.0	 30.0;
	2635	 1548	 0.013051	 0.029201	 0.0003	 951	 951	 951	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 1550	 0.082892	 0.223734	 0.0044	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5740	 1550	 0.044671	 0.121995	 0.0013	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 1550	 0.059461	 0.162258	 0.0056	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5319	 1551	 0.123457	 0.228521	 0.0025	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	1836	 1553	 0.038148	 0.078395	 0.0036	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	5320	 1554	 2e-06	 0.000198	 0.0066	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3244	 1555	 0.017654	 0.074444	 0.0039	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	4267	 1555	 0.01	 0.041975	 0.0021	 703	 703	 703	 0.0	 0.0	 1	 -30.0	 30.0;
	2746	 1556	 0.05291	 0.134291	 0.001	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	3311	 1557	 0.081633	 0.204334	 0.0052	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	2522	 1559	 0.000336	 0.001481	 0.003	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4844	 1559	 0.000652	 0.004346	 0.0081	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2521	 1559	 0.000336	 0.001501	 0.003	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4675	 1561	 0.009776	 0.020635	 0.0187	 1294	 1294	 1294	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 1563	 0.000123	 0.000247	 0.001	 109898	 109898	 109898	 0.0	 0.0	 1	 -30.0	 30.0;
	5500	 1563	 0.021975	 0.054815	 0.0026	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	1818	 1563	 0.002335	 0.004274	 0.0002	 6227	 6227	 6227	 0.0	 0.0	 1	 -30.0	 30.0;
	1849	 1563	 0.000123	 0.000247	 0.0006	 109898	 109898	 109898	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 1564	 0.005679	 0.014198	 0.0104	 1984	 1984	 1984	 0.0	 0.0	 1	 -30.0	 30.0;
	3244	 1564	 0.033457	 0.086173	 0.0044	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	3377	 1564	 0.052346	 0.14037	 0.0168	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	3244	 1564	 0.033086	 0.085432	 0.0045	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	3244	 1564	 0.033333	 0.085556	 0.004	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	1781	 1565	 0.006202	 0.041343	 0.0759	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4660	 1565	 0.001205	 0.008099	 0.0152	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4660	 1565	 0.001225	 0.008099	 0.0152	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2013	 1567	 0.068758	 0.187579	 0.0021	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	4377	 1570	 0.100529	 0.273369	 0.003	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	4856	 1570	 0.018645	 0.06576	 0.005	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	5198	 1570	 0.083144	 0.246158	 0.0024	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	5269	 1571	 0.02037	 0.049259	 0.0003	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 1572	 0.000988	 0.005709	 0.0101	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4434	 1573	 0.056552	 0.103518	 0.001	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	4688	 1573	 0.059965	 0.149156	 0.0041	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5322	 1574	 0.020012	 0.126593	 0.0056	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	3752	 1575	 0.001877	 0.012504	 0.0223	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3875	 1575	 0.001462	 0.009758	 0.0182	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3074	 1576	 0.029982	 0.102293	 0.001	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	4337	 1576	 0.016377	 0.05543	 0.002	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	4453	 1576	 0.00379	 0.006937	 0.0042	 3736	 3736	 3736	 0.0	 0.0	 1	 -30.0	 30.0;
	5324	 1576	 0.008566	 0.027463	 0.0	 1027	 1027	 1027	 0.0	 0.0	 1	 -30.0	 30.0;
	3951	 1577	 0.024943	 0.101209	 0.002	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	5146	 1577	 0.02973	 0.085412	 0.001	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	5697	 1577	 0.023759	 0.096548	 0.0013	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	2986	 1577	 0.056941	 0.154951	 0.0017	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 1578	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 1579	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 1580	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 1581	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1516	 1582	 0.020617	 0.055556	 0.0026	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	2552	 1583	 0.000672	 0.003891	 0.08	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2552	 1583	 0.000632	 0.003812	 0.0911	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3335	 1584	 0.015873	 0.042328	 0.001	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	5325	 1584	 0.003023	 0.006047	 0.0001	 4368	 4368	 4368	 0.0	 0.0	 1	 -30.0	 30.0;
	2004	 1585	 0.00083	 0.005709	 0.0182	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3857	 1585	 0.001709	 0.016636	 0.0577	 866.0	 866.0	 866.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4151	 1585	 0.001758	 0.017442	 0.0547	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2004	 1585	 0.00083	 0.005709	 0.0223	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3607	 1586	 0.000187	 0.00349	 0.0941	 2250.0	 2250.0	 2250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4233	 1587	 0.026833	 0.059889	 0.0007	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	4997	 1587	 0.073797	 0.187075	 0.0021	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	3277	 1588	 0.001605	 0.010247	 0.0005	 3108	 3108	 3108	 0.0	 0.0	 1	 -30.0	 30.0;
	3289	 1588	 0.003086	 0.009012	 0.0153	 3384	 3384	 3384	 0.0	 0.0	 1	 -30.0	 30.0;
	4001	 1588	 0.027407	 0.070124	 0.0032	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	5055	 1588	 0.005059	 0.009261	 0.035	 3055	 3055	 3055	 0.0	 0.0	 1	 -30.0	 30.0;
	5592	 1588	 0.001975	 0.012222	 0.0006	 2792	 2792	 2792	 0.0	 0.0	 1	 -30.0	 30.0;
	3277	 1588	 0.001481	 0.009383	 0.0005	 3393	 3393	 3393	 0.0	 0.0	 1	 -30.0	 30.0;
	3599	 1588	 0.002782	 0.005093	 0.0092	 5554	 5554	 5554	 0.0	 0.0	 1	 -30.0	 30.0;
	5055	 1588	 0.004198	 0.012963	 0.0091	 2366	 2366	 2366	 0.0	 0.0	 1	 -30.0	 30.0;
	2721	 1589	 0.003773	 0.025264	 0.0466	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4167	 1589	 0.005195	 0.023585	 0.0415	 364.0	 364.0	 364.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2622	 1590	 0.031728	 0.12358	 0.0057	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5704	 1591	 0.000617	 0.001235	 0.0019	 21515	 21515	 21515	 0.0	 0.0	 1	 -30.0	 30.0;
	5326	 1592	 0.000222	 0.000938	 0.0	 31460	 31460	 31460	 0.0	 0.0	 1	 -30.0	 30.0;
	3788	 1593	 4e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4712	 1593	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4696	 1593	 7.9e-05	 0.001284	 0.002	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4538	 1594	 0.102797	 0.280675	 0.0032	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	5328	 1594	 0.02318	 0.100529	 0.0046	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	4754	 1595	 0.081556	 0.202099	 0.0097	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 1595	 0.031358	 0.082593	 0.004	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	1612	 1596	 0.022676	 0.073318	 0.0008	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 1596	 0.081885	 0.259259	 0.0043	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	2357	 1599	 0.055556	 0.14642	 0.007	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	4980	 1598	 0.01	 0.027531	 0.0	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	5403	 1599	 0.011852	 0.030988	 0.0015	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	4372	 1599	 0.042716	 0.112099	 0.0053	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	4979	 1598	 0.01	 0.027531	 0.0	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 1600	 0.028721	 0.081007	 0.1357	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	2816	 1600	 0.012247	 0.062222	 0.1073	 414.0	 414.0	 414.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3018	 1600	 0.009067	 0.042884	 0.0861	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3075	 1600	 0.020602	 0.068109	 0.1083	 258.0	 258.0	 258.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3259	 1600	 0.016691	 0.075299	 0.1336	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4306	 1600	 0.008158	 0.03516	 0.0582	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4737	 1600	 0.016612	 0.078676	 0.1316	 293.0	 293.0	 293.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 1600	 0.023407	 0.110815	 0.1853	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	2772	 1601	 0.001898	 0.021337	 0.4245	 1482	 1482	 1482	 0.0	 0.0	 1	 -30.0	 30.0;
	3433	 1601	 0.001828	 0.020533	 0.4101	 1546	 1546	 1546	 0.0	 0.0	 1	 -30.0	 30.0;
	3939	 1601	 0.004633	 0.051018	 1.1581	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 1601	 0.001053	 0.013843	 0.4765	 2287	 2287	 2287	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 1601	 0.002888	 0.031752	 0.7595	 996	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 1601	 0.001053	 0.01383	 0.4765	 2289	 2289	 2289	 0.0	 0.0	 1	 -30.0	 30.0;
	2616	 1602	 0.044596	 0.137365	 0.0425	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	3063	 1602	 0.052658	 0.118418	 0.003	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3426	 1602	 0.023432	 0.070043	 0.0008	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 1602	 0.006803	 0.014109	 0.007	 1830	 1830	 1830	 0.0	 0.0	 1	 -30.0	 30.0;
	2616	 1602	 0.045855	 0.139582	 0.0516	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	3062	 1602	 0.043336	 0.113883	 0.0031	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 1603	 0.003319	 0.021472	 0.0405	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4041	 1603	 0.001205	 0.007684	 0.0142	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4211	 1604	 0.002212	 0.014558	 0.0299	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4861	 1604	 0.000435	 0.002923	 0.0091	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5085	 1603	 0.000593	 0.00397	 0.4759	 530.0	 530.0	 530.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4041	 1603	 0.001146	 0.007664	 0.0142	 493.0	 493.0	 493.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5329	 1605	 0.000436	 0.000797	 0.0007	 31538	 31538	 31538	 0.0	 0.0	 1	 -30.0	 30.0;
	5330	 1606	 0.000178	 0.001185	 0.002	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3049	 1607	 0.070799	 0.154951	 0.0017	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4523	 1607	 0.042832	 0.241371	 0.0048	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5331	 1608	 9.9e-05	 0.000454	 0.001	 262.0	 262.0	 262.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 1609	 0.03225	 0.097254	 0.0001	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 1609	 0.03225	 0.097254	 0.0001	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	2630	 1610	 0.081129	 0.197531	 0.0019	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	4458	 1610	 0.038045	 0.13026	 0.0015	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5153	 1610	 0.036281	 0.098866	 0.0011	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	2095	 1611	 0.024364	 0.10519	 0.0135	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	2307	 1611	 0.026455	 0.104308	 0.0017	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 1612	 0.031242	 0.101537	 0.0012	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 1612	 0.025195	 0.077097	 0.0015	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	4675	 1613	 0.015193	 0.061854	 0.0031	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	2120	 1614	 0.06324	 0.155077	 0.0017	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	3513	 1617	 0.028521	 0.087402	 0.001	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	4017	 1616	 0.041824	 0.153691	 0.002	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 1616	 0.084404	 0.230537	 0.002	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5771	 1616	 0.073621	 0.187352	 0.0023	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	2292	 1618	 0.005669	 0.026094	 0.0476	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4999	 1618	 0.001719	 0.01199	 0.0213	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3371	 1619	 0.006667	 0.042222	 0.0046	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	5675	 1619	 0.002593	 0.016049	 0.0008	 1866	 1866	 1866	 0.0	 0.0	 1	 -30.0	 30.0;
	1946	 1620	 0.034517	 0.073318	 0.0009	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	2693	 1621	 0.01284	 0.034444	 0.0016	 809	 809	 809	 0.0	 0.0	 1	 -30.0	 30.0;
	5498	 1621	 0.012716	 0.034321	 0.0016	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	5101	 1623	 0.018272	 0.041481	 0.0	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	5743	 1623	 0.075062	 0.195556	 0.0012	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	3962	 1624	 0.028471	 0.116654	 0.0016	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	5439	 1625	 0.040464	 0.123684	 0.0015	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5438	 1625	 0.040464	 0.123684	 0.0015	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5644	 1626	 0.018889	 0.050988	 0.0024	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	2262	 1627	 0.161829	 0.34389	 0.0034	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 1630	 1.3e-05	 9.9e-05	 0.001	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 1631	 0.002741	 0.010506	 0.0005	 2793	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	2009	 1632	 0.000138	 0.000336	 0.0314	 85214	 85214	 85214	 0.0	 0.0	 1	 -30.0	 30.0;
	5398	 1633	 0.014321	 0.039012	 0.0018	 715	 715	 715	 0.0	 0.0	 1	 -30.0	 30.0;
	3429	 1634	 0.081381	 0.222474	 0.0025	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	2208	 1635	 0.005136	 0.009402	 0.0004	 2839	 2839	 2839	 0.0	 0.0	 1	 -30.0	 30.0;
	5418	 1635	 0.001638	 0.004334	 0.0039	 6565	 6565	 6565	 0.0	 0.0	 1	 -30.0	 30.0;
	1856	 1636	 0.038498	 0.097707	 0.0011	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	5116	 1636	 0.039557	 0.100529	 0.0011	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	2047	 1637	 0.029226	 0.125649	 0.0026	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	2533	 1638	 0.007559	 0.015621	 0.0217	 1702	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	3029	 1638	 0.006218	 0.011382	 0.0057	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	3583	 1638	 0.01285	 0.048879	 0.0683	 585	 585	 585	 0.0	 0.0	 1	 -30.0	 30.0;
	4129	 1638	 0.017637	 0.039808	 0.0067	 679	 679	 679	 0.0	 0.0	 1	 -30.0	 30.0;
	4517	 1638	 0.014109	 0.036281	 0.0102	 759	 759	 759	 0.0	 0.0	 1	 -30.0	 30.0;
	2533	 1638	 0.007055	 0.016881	 0.0194	 1614	 1614	 1614	 0.0	 0.0	 1	 -30.0	 30.0;
	4129	 1638	 0.016125	 0.04258	 0.0079	 649	 649	 649	 0.0	 0.0	 1	 -30.0	 30.0;
	4517	 1638	 0.013605	 0.033762	 0.0102	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	3179	 1639	 0.001888	 0.013914	 0.403	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4138	 1640	 0.08642	 0.260015	 0.0073	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	4363	 1640	 0.048375	 0.132275	 0.0015	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	1807	 1641	 0.031998	 0.137062	 0.001	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	4755	 1641	 0.022928	 0.06324	 0.0	 453	 453	 453	 0.0	 0.0	 1	 -30.0	 30.0;
	3134	 1642	 0.006979	 0.034316	 0.0531	 848	 848	 848	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 1643	 0.000171	 0.000313	 0.0	 85273	 85273	 85273	 0.0	 0.0	 1	 -30.0	 30.0;
	2547	 1644	 0.082137	 0.180398	 0.002	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	2973	 1644	 0.102646	 0.348652	 0.0041	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	4755	 1644	 0.125397	 0.284127	 0.0032	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	5335	 1645	 2e-05	 9.9e-05	 0.0	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1725	 1646	 0.063089	 0.153162	 0.0021	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	3409	 1646	 0.058957	 0.141849	 0.0014	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4458	 1646	 0.046284	 0.109448	 0.0016	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	1942	 1647	 0.018889	 0.057654	 0.0028	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	1942	 1647	 0.018395	 0.057531	 0.0005	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	5336	 1648	 0.004431	 0.00811	 0.0001	 3291	 3291	 3291	 0.0	 0.0	 1	 -30.0	 30.0;
	2864	 1650	 0.008148	 0.033704	 0.0016	 858	 858	 858	 0.0	 0.0	 1	 -30.0	 30.0;
	5337	 1649	 8.6e-05	 0.001235	 0.0	 23993	 23993	 23993	 0.0	 0.0	 1	 -30.0	 30.0;
	1878	 1651	 0.002099	 0.003951	 0.0063	 7204	 7204	 7204	 0.0	 0.0	 1	 -30.0	 30.0;
	5462	 1653	 0.022676	 0.070799	 0.0111	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	5338	 1657	 0.025432	 0.064444	 0.0031	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	5339	 1658	 0.027211	 0.049887	 0.0005	 520	 520	 520	 0.0	 0.0	 1	 -30.0	 30.0;
	2647	 1659	 0.008566	 0.016881	 0.0003	 1607	 1607	 1607	 0.0	 0.0	 1	 -30.0	 30.0;
	2803	 1660	 0.055933	 0.149408	 0.002	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	1718	 1661	 0.002481	 0.012134	 0.0218	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2807	 1661	 0.003398	 0.021373	 0.04	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4781	 1661	 0.00081	 0.005551	 0.0101	 565.0	 565.0	 565.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2127	 1662	 0.022676	 0.071554	 0.0021	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	3610	 1662	 0.036281	 0.101789	 0.002	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	1791	 1663	 0.00383	 0.017133	 0.0265	 1733	 1733	 1733	 0.0	 0.0	 1	 -30.0	 30.0;
	1791	 1663	 0.005442	 0.015923	 0.0269	 1808	 1808	 1808	 0.0	 0.0	 1	 -30.0	 30.0;
	2428	 1664	 0.101789	 0.280927	 0.0031	 102	 102	 102	 0.0	 0.0	 1	 -30.0	 30.0;
	4856	 1664	 0.092467	 0.259033	 0.0068	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	5057	 1664	 0.059662	 0.164903	 0.0018	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3275	 1665	 0.020912	 0.090955	 0.0011	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5341	 1666	 0.000756	 0.002268	 0.0	 12351	 12351	 12351	 0.0	 0.0	 1	 -30.0	 30.0;
	5025	 1667	 0.095414	 0.176846	 0.0022	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	1944	 1668	 0.000336	 0.000672	 0.0469	 41198	 41198	 41198	 0.0	 0.0	 1	 -30.0	 30.0;
	2006	 1669	 0.065256	 0.177879	 0.002	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	3027	 1669	 0.000512	 0.000938	 0.0005	 28461	 28461	 28461	 0.0	 0.0	 1	 -30.0	 30.0;
	3719	 1669	 0.079315	 0.208944	 0.0023	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	3740	 1669	 0.021164	 0.055682	 0.0006	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	4234	 1669	 0.084908	 0.2323	 0.0026	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	5049	 1669	 0.035777	 0.097758	 0.0029	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	5763	 1669	 0.015117	 0.040312	 0.0015	 707	 707	 707	 0.0	 0.0	 1	 -30.0	 30.0;
	3026	 1669	 0.00126	 0.00252	 0.0006	 10795	 10795	 10795	 0.0	 0.0	 1	 -30.0	 30.0;
	5766	 1670	 0.005294	 0.036464	 0.0618	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2041	 1671	 0.09297	 0.253716	 0.0028	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	4729	 1671	 0.069035	 0.228017	 0.0026	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5342	 1672	 0.002599	 0.004757	 0.0002	 5595	 5595	 5595	 0.0	 0.0	 1	 -30.0	 30.0;
	3405	 1673	 0.005518	 0.02197	 0.0033	 1343	 1343	 1343	 0.0	 0.0	 1	 -30.0	 30.0;
	4088	 1673	 0.013756	 0.025179	 0.0011	 1061	 1061	 1061	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 1673	 0.047518	 0.123104	 0.0017	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	3405	 1673	 0.005392	 0.02187	 0.0027	 1351	 1351	 1351	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 1674	 0.006558	 0.029807	 0.0516	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1868	 1675	 0.024198	 0.099383	 0.0053	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	3152	 1675	 0.046667	 0.199383	 0.017	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 1677	 0.046822	 0.085707	 0.0021	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	4636	 1678	 0.015803	 0.097531	 0.005	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5307	 1678	 0.012346	 0.056049	 0.0026	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	5502	 1678	 0.03642	 0.092469	 0.0044	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 1678	 0.026049	 0.065926	 0.0031	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	1680	 1679	 0.008765	 0.022099	 0.001	 1250	 1250	 1250	 0.0	 0.0	 1	 -30.0	 30.0;
	4519	 1679	 0.037407	 0.094938	 0.0044	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	2485	 1680	 0.062099	 0.157531	 0.0073	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	2516	 1681	 0.118166	 0.32124	 0.0036	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	4624	 1681	 0.058201	 0.147392	 0.0017	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	3942	 1682	 0.002696	 0.007155	 0.0081	 3862	 3862	 3862	 0.0	 0.0	 1	 -30.0	 30.0;
	5533	 1682	 0.009574	 0.038297	 0.0152	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	5661	 1682	 0.029378	 0.111287	 0.0018	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	5464	 1683	 0.001975	 0.013412	 0.0233	 488.0	 488.0	 488.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3049	 1684	 0.018645	 0.041572	 0.0005	 649	 649	 649	 0.0	 0.0	 1	 -30.0	 30.0;
	3658	 1686	 0.022928	 0.058453	 0.0006	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	4518	 1686	 0.01348	 0.034467	 0.0004	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 1688	 0.027353	 0.05007	 0.0	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	5607	 1689	 0.012144	 0.049332	 0.0012	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	5605	 1689	 0.012094	 0.049206	 0.0009	 583	 583	 583	 0.0	 0.0	 1	 -30.0	 30.0;
	1639	 1690	 0.005017	 0.033403	 0.0618	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1726	 1690	 0.003595	 0.019635	 0.0354	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2826	 1690	 0.001422	 0.008217	 0.1007	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3323	 1690	 0.002212	 0.014044	 0.0253	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3713	 1690	 0.001408	 0.008494	 0.2344	 278.0	 278.0	 278.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3752	 1690	 0.002647	 0.01762	 0.0324	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3323	 1690	 0.002212	 0.013985	 0.0263	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5211	 1690	 0.000336	 0.002232	 0.004	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5346	 1691	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	3715	 1692	 1.2e-05	 0.000123	 0.0003	 240340	 240340	 240340	 0.0	 0.0	 1	 -30.0	 30.0;
	5348	 1693	 0.000302	 0.001033	 0.0	 28260	 28260	 28260	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 1694	 0.00963	 0.027284	 0.0013	 1027	 1027	 1027	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 1694	 0.00963	 0.024568	 0.0011	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 1694	 0.018642	 0.049876	 0.0021	 558	 558	 558	 0.0	 0.0	 1	 -30.0	 30.0;
	4221	 1696	 4.8e-05	 8.8e-05	 0.1993	 318139	 318139	 318139	 0.0	 0.0	 1	 -30.0	 30.0;
	4221	 1695	 4.8e-05	 8.8e-05	 0.1993	 318139	 318139	 318139	 0.0	 0.0	 1	 -30.0	 30.0;
	4218	 1697	 4.8e-05	 8.8e-05	 0.0001	 303410	 303410	 303410	 0.0	 0.0	 1	 -30.0	 30.0;
	4220	 1699	 4.8e-05	 8.8e-05	 0.001	 308858	 308858	 308858	 0.0	 0.0	 1	 -30.0	 30.0;
	4220	 1698	 4.8e-05	 8.8e-05	 0.001	 308909	 308909	 308909	 0.0	 0.0	 1	 -30.0	 30.0;
	5336	 1700	 0.008314	 0.028471	 0.0003	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	4528	 1702	 0.011332	 0.020743	 0.0007	 1287	 1287	 1287	 0.0	 0.0	 1	 -30.0	 30.0;
	5735	 1702	 0.00252	 0.011086	 0.0002	 2676	 2676	 2676	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 1702	 0.00257	 0.010935	 0.0002	 2708	 2708	 2708	 0.0	 0.0	 1	 -30.0	 30.0;
	4354	 1703	 0.033762	 0.085664	 0.0	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 1704	 0.008062	 0.027463	 0.0003	 1063	 1063	 1063	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 1705	 0.008768	 0.030209	 0.0003	 967	 967	 967	 0.0	 0.0	 1	 -30.0	 30.0;
	5302	 1705	 0.044344	 0.149912	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5303	 1705	 0.043789	 0.148375	 0.0017	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	5349	 1705	 0.001285	 0.004107	 0.0	 7068	 7068	 7068	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 1705	 0.01033	 0.028471	 0.0003	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	1715	 1709	 0.000756	 0.007559	 0.0002	 3772	 3772	 3772	 0.0	 0.0	 1	 -30.0	 30.0;
	2733	 1708	 0.00315	 0.005766	 0.0047	 4361	 4361	 4361	 0.0	 0.0	 1	 -30.0	 30.0;
	3216	 1708	 0.008566	 0.017385	 0.0148	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 1708	 0.011842	 0.055178	 0.0442	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4074	 1708	 0.001022	 0.001871	 0.0012	 13439	 13439	 13439	 0.0	 0.0	 1	 -30.0	 30.0;
	1714	 1708	 0.000756	 0.007559	 0.0002	 3772	 3772	 3772	 0.0	 0.0	 1	 -30.0	 30.0;
	3216	 1708	 0.008314	 0.016629	 0.0144	 1542	 1542	 1542	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 1708	 0.012497	 0.039909	 0.0442	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	3216	 1708	 0.009826	 0.019652	 0.0144	 1304	 1304	 1304	 0.0	 0.0	 1	 -30.0	 30.0;
	3216	 1708	 0.014024	 0.025671	 0.0148	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	1716	 1711	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1716	 1713	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1716	 1710	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1716	 1712	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	3217	 1716	 0.000316	 0.001067	 0.2359	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4640	 1716	 0.000395	 0.002706	 0.0253	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3217	 1716	 0.000217	 0.001817	 0.1812	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3614	 1716	 0.002193	 0.014736	 0.0461	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 1716	 0.001225	 0.007822	 0.0324	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5350	 1716	 0.001225	 0.007822	 0.0324	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2235	 1717	 0.053414	 0.145881	 0.0017	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	2252	 1717	 0.011791	 0.040716	 0.0005	 739	 739	 739	 0.0	 0.0	 1	 -30.0	 30.0;
	3130	 1717	 0.000504	 0.002771	 0.0001	 11069	 11069	 11069	 0.0	 0.0	 1	 -30.0	 30.0;
	4615	 1717	 0.039557	 0.11489	 0.0002	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	5727	 1717	 0.074074	 0.195515	 0.0022	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	2252	 1717	 0.011842	 0.040816	 0.0005	 737	 737	 737	 0.0	 0.0	 1	 -30.0	 30.0;
	2134	 1718	 0.002779	 0.013788	 0.0243	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 1720	 0.000553	 0.001106	 0.163	 25032	 25032	 25032	 0.0	 0.0	 1	 -30.0	 30.0;
	5350	 1719	 0.000553	 0.001106	 0.163	 25032	 25032	 25032	 0.0	 0.0	 1	 -30.0	 30.0;
	2237	 1721	 0.00126	 0.003023	 0.0	 9016	 9016	 9016	 0.0	 0.0	 1	 -30.0	 30.0;
	3868	 1722	 0.022469	 0.065556	 0.0031	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 1722	 0.032593	 0.100864	 0.005	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	4730	 1722	 0.008519	 0.026543	 0.0013	 1066	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	5107	 1722	 0.028889	 0.078889	 0.0037	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 1722	 0.008148	 0.053333	 0.0026	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	2055	 1723	 0.005057	 0.033561	 0.0607	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 1724	 0.031746	 0.08642	 0.001	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	5353	 1729	 0.000504	 0.001008	 0.0	 26199	 26199	 26199	 0.0	 0.0	 1	 -30.0	 30.0;
	3979	 1731	 0.029259	 0.122346	 0.0164	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	5326	 1731	 0.016049	 0.067901	 0.0138	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	2806	 1732	 0.001728	 0.007037	 0.0288	 4341	 4341	 4341	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 1733	 0.002446	 0.004477	 0.0	 5788	 5788	 5788	 0.0	 0.0	 1	 -30.0	 30.0;
	5356	 1734	 0.057748	 0.157571	 0.0018	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	1993	 1735	 0.067775	 0.141597	 0.0016	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	4016	 1735	 0.127139	 0.232726	 0.0026	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	4085	 1735	 0.000756	 0.103301	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	4169	 1735	 0.003779	 0.019652	 0.0002	 1520	 1520	 1520	 0.0	 0.0	 1	 -30.0	 30.0;
	5569	 1735	 0.017637	 0.087176	 0.0007	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	4085	 1735	 0.000756	 0.103301	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 1736	 0.004913	 0.032622	 0.0608	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3900	 1738	 0.038395	 0.093951	 0.0158	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	3915	 1738	 0.076914	 0.200864	 0.0096	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	5359	 1738	 0.015679	 0.039877	 0.0019	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	1800	 1739	 0.004535	 0.015369	 0.0194	 1898	 1898	 1898	 0.0	 0.0	 1	 -30.0	 30.0;
	5526	 1739	 0.027538	 0.063013	 0.0011	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	1745	 1742	 0.00033	 0.001503	 0.002	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1745	 1741	 0.000296	 0.001349	 0.002	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3103	 1744	 7e-06	 0.000132	 0.0029	 1737.0	 1737.0	 1737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3103	 1743	 7e-06	 0.000125	 0.0029	 1737.0	 1737.0	 1737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1751	 1745	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	3279	 1745	 0.00322	 0.014835	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4991	 1745	 0.00083	 0.00796	 0.0334	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 1745	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1749	 1745	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2332	 1752	 0.004283	 0.014109	 0.0033	 2003	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	5827	 1753	 0.005291	 0.009826	 0.0044	 2646	 2646	 2646	 0.0	 0.0	 1	 -30.0	 30.0;
	2331	 1753	 0.006218	 0.011382	 0.0068	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	2863	 1753	 0.001764	 0.003527	 0.0025	 7488	 7488	 7488	 0.0	 0.0	 1	 -30.0	 30.0;
	5532	 1752	 0.023683	 0.083396	 0.001	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	2492	 1754	 0.002015	 0.013551	 0.0243	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 1754	 0.001094	 0.011536	 0.036	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3834	 1754	 2e-05	 9.9e-05	 0.0405	 695.0	 695.0	 695.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3863	 1754	 0.001205	 0.008	 0.0152	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4256	 1754	 0.00403	 0.027496	 0.0516	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 1754	 0.001096	 0.011575	 0.0359	 355.0	 355.0	 355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3834	 1754	 2e-05	 0.000119	 0.0506	 695.0	 695.0	 695.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2935	 1755	 0.060217	 0.230537	 0.003	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	3095	 1755	 0.051146	 0.130763	 0.001	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	3099	 1755	 0.048123	 0.145629	 0.002	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	5581	 1755	 0.078105	 0.22449	 0.002	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	1757	 4134	 0.012774	 0.04064	 0.0005	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	5357	 1758	 0.001792	 0.00328	 0.0	 7900	 7900	 7900	 0.0	 0.0	 1	 -30.0	 30.0;
	2011	 1759	 0.081129	 0.180902	 0.0021	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	2518	 1760	 0.041043	 0.108844	 0.0025	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2689	 1761	 0.126016	 0.230672	 0.0025	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	2312	 1762	 0.001383	 0.007881	 0.0142	 3869	 3869	 3869	 0.0	 0.0	 1	 -30.0	 30.0;
	2146	 1763	 0.037037	 0.09675	 0.0019	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	2334	 1763	 0.022172	 0.056437	 0.0006	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 1764	 0.090703	 0.232048	 0.0026	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 1766	 0.033258	 0.084908	 0.001	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	4100	 1766	 0.036533	 0.093222	 0.001	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	5844	 1766	 0.083396	 0.219703	 0.0025	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 1766	 0.070043	 0.177627	 0.002	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 1766	 0.03351	 0.08516	 0.001	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	2850	 1769	 0.000256	 0.004377	 0.156	 1994.0	 1994.0	 1994.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2850	 1768	 0.000263	 0.004377	 0.1574	 1994.0	 1994.0	 1994.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2850	 1770	 0.000263	 0.004384	 0.1588	 997.0	 997.0	 997.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2850	 1767	 0.000263	 0.004391	 0.1588	 1592.0	 1592.0	 1592.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 1771	 0.008818	 0.025951	 0.0	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 1772	 0.000134	 0.000245	 0.001	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2707	 1773	 0.007861	 0.049509	 0.0006	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	2684	 1774	 0.000178	 0.000711	 0.079	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3882	 1774	 0.000316	 0.001264	 0.1417	 287.0	 287.0	 287.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2321	 1776	 0.042099	 0.122963	 0.0062	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	3309	 1777	 0.027654	 0.072593	 0.0034	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	3571	 1777	 0.012469	 0.031728	 0.0015	 872	 872	 872	 0.0	 0.0	 1	 -30.0	 30.0;
	3715	 1777	 0.01963	 0.051605	 0.0024	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	3867	 1776	 0.064691	 0.164198	 0.0078	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	3910	 1776	 0.028518	 0.077778	 0.0043	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 1776	 0.028025	 0.07642	 0.0036	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	3715	 1777	 0.02037	 0.051852	 0.0024	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	3032	 1778	 0.010943	 0.072652	 0.1347	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	3065	 1778	 0.014775	 0.052267	 0.083	 566	 566	 566	 0.0	 0.0	 1	 -30.0	 30.0;
	3199	 1778	 0.020543	 0.073482	 0.1174	 279.0	 279.0	 279.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4010	 1778	 0.015921	 0.072375	 0.1281	 329.0	 329.0	 329.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 1778	 0.008435	 0.056138	 0.1043	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4925	 1779	 0.042469	 0.115432	 0.0054	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	5191	 1779	 0.045679	 0.124691	 0.0058	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	2575	 1780	 0.041728	 0.112346	 0.0053	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	2984	 1780	 0.063951	 0.162346	 0.0076	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	4930	 1780	 0.054444	 0.138025	 0.0065	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 1780	 0.018395	 0.047161	 0.0023	 602	 602	 602	 0.0	 0.0	 1	 -30.0	 30.0;
	2471	 1781	 0.009912	 0.044701	 0.1817	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4622	 1781	 0.007605	 0.036603	 0.0658	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5192	 1781	 0.005114	 0.03518	 0.0668	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2313	 1782	 0.110355	 0.300076	 0.0034	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	2500	 1782	 0.040312	 0.086924	 0.0001	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	4948	 1783	 0.035273	 0.089695	 0.001	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	4157	 1784	 0.069539	 0.189972	 0.0002	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	3462	 1785	 0.037037	 0.088183	 0.001	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	4931	 1785	 0.003452	 0.021315	 0.0003	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	5187	 1785	 0.0161	 0.065533	 0.005	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	5839	 1785	 0.003452	 0.021819	 0.0002	 1337	 1337	 1337	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 1786	 0.00557	 0.03362	 0.0628	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5329	 1787	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	4649	 1788	 0.066566	 0.168758	 0.0019	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 1788	 0.047871	 0.121693	 0.0013	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	4308	 1789	 0.055808	 0.141471	 0.0016	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4649	 1789	 0.067271	 0.170824	 0.0019	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	3276	 1790	 0.075334	 0.19098	 0.0021	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	4587	 1790	 0.036785	 0.087679	 0.001	 320	 320	 320	 0.0	 0.0	 1	 -30.0	 30.0;
	4972	 1790	 0.013354	 0.036785	 0.0004	 796	 796	 796	 0.0	 0.0	 1	 -30.0	 30.0;
	3974	 1791	 0.059965	 0.152935	 0.0017	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4297	 1791	 0.038851	 0.099975	 0.0058	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	3007	 1792	 0.033704	 0.092222	 0.004	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	3032	 1793	 0.002975	 0.019475	 0.0504	 444.0	 444.0	 444.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3400	 1793	 0.002627	 0.017975	 0.0324	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3032	 1793	 0.002993	 0.019532	 0.0472	 444.0	 444.0	 444.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3409	 1794	 0.049131	 0.139078	 0.0016	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	4893	 1794	 0.025397	 0.090728	 0.0016	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	4459	 1795	 0.002923	 0.020543	 0.0365	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3566	 1797	 0.000142	 0.000822	 0.1073	 37106	 37106	 37106	 0.0	 0.0	 1	 -30.0	 30.0;
	3566	 1798	 0.000217	 0.000849	 0.1104	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5451	 1799	 0.003779	 0.009826	 0.0112	 2889	 2889	 2889	 0.0	 0.0	 1	 -30.0	 30.0;
	1799	 1800	 0.003527	 0.009574	 0.0108	 2981	 2981	 2981	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 4727	 0.000138	 0.000296	 0.0223	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2395	 1802	 0.098262	 0.20257	 0.0022	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	4409	 1803	 0.06576	 0.180146	 0.0024	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	4468	 1803	 0.046359	 0.124465	 0.001	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	4896	 1803	 0.015117	 0.044596	 0.001	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	3842	 1804	 0.005965	 0.039901	 0.0739	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 1804	 0.000889	 0.006104	 0.0111	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2759	 1806	 0.005795	 0.015117	 0.0002	 1879	 1879	 1879	 0.0	 0.0	 1	 -30.0	 30.0;
	2759	 1805	 0.005795	 0.015117	 0.0002	 1879	 1879	 1879	 0.0	 0.0	 1	 -30.0	 30.0;
	3376	 1807	 0.041799	 0.175384	 0.0026	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	1936	 1808	 0.000756	 0.003275	 0.0046	 8785	 8785	 8785	 0.0	 0.0	 1	 -30.0	 30.0;
	3189	 1808	 0.005795	 0.020408	 0.0002	 1392	 1392	 1392	 0.0	 0.0	 1	 -30.0	 30.0;
	3933	 1808	 0.113883	 0.281683	 0.0032	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	5419	 1808	 0.065004	 0.217687	 0.0025	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	5582	 1808	 0.003275	 0.01348	 0.0002	 2129	 2129	 2129	 0.0	 0.0	 1	 -30.0	 30.0;
	5826	 1808	 0.024943	 0.106576	 0.0013	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	2165	 1809	 0.004318	 0.007903	 0.0058	 3579	 3579	 3579	 0.0	 0.0	 1	 -30.0	 30.0;
	2165	 1809	 0.004398	 0.00805	 0.0058	 3514	 3514	 3514	 0.0	 0.0	 1	 -30.0	 30.0;
	2752	 1810	 0.006551	 0.028219	 0.0003	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	3361	 1810	 0.038549	 0.156966	 0.0021	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	5282	 1810	 0.02318	 0.098262	 0.0023	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	3361	 1810	 0.038549	 0.156715	 0.0022	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	4538	 1810	 0.032502	 0.134543	 0.0038	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	3273	 1811	 0.004681	 0.021847	 0.1382	 386.0	 386.0	 386.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 1812	 0.000831	 0.001688	 0.0	 16165	 16165	 16165	 0.0	 0.0	 1	 -30.0	 30.0;
	3441	 1814	 0.025951	 0.066516	 0.0007	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	5458	 1815	 0.019876	 0.083482	 0.0042	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	5644	 1815	 0.022839	 0.062346	 0.0029	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	4816	 1817	 0.018395	 0.048148	 0.0019	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	5371	 1817	 0.023457	 0.059753	 0.0028	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	1821	 1819	 0.005543	 0.011338	 0.0002	 2468	 2468	 2468	 0.0	 0.0	 1	 -30.0	 30.0;
	1821	 1819	 0.005795	 0.01159	 0.0002	 2403	 2403	 2403	 0.0	 0.0	 1	 -30.0	 30.0;
	5361	 1820	 0.020741	 0.055679	 0.0028	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	2483	 1822	 0.032452	 0.110179	 0.0013	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	2567	 1822	 0.071303	 0.193752	 0.0022	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 1822	 0.017259	 0.056941	 0.002	 512	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	4547	 1823	 0.002953	 0.019787	 0.0363	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4547	 1823	 0.002963	 0.019733	 0.0365	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 1824	 0.000494	 0.002212	 0.004	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 1824	 0.000474	 0.002193	 0.004	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3671	 1825	 0.013704	 0.061728	 0.0008	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	3671	 1825	 0.019383	 0.082963	 0.0015	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	3016	 1826	 0.011168	 0.020443	 0.002	 1306	 1306	 1306	 0.0	 0.0	 1	 -30.0	 30.0;
	3543	 1826	 0.053313	 0.199471	 0.0173	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	1962	 1828	 0.002086	 0.025528	 0.4534	 1246	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	2716	 1828	 0.001432	 0.015665	 0.3754	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4073	 1829	 0.036667	 0.102963	 0.0047	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	3086	 1830	 0.020408	 0.085412	 0.0014	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	3555	 1831	 0.010582	 0.022928	 0.0231	 1170	 1170	 1170	 0.0	 0.0	 1	 -30.0	 30.0;
	4413	 1831	 0.04132	 0.114135	 0.0022	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	5769	 1831	 0.015117	 0.04006	 0.0005	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	3555	 1831	 0.011086	 0.02318	 0.0211	 1150	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	4676	 1832	 0.002726	 0.018212	 0.0481	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4676	 1832	 0.002765	 0.018212	 0.0486	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4732	 1834	 0.008314	 0.031494	 0.001	 907	 907	 907	 0.0	 0.0	 1	 -30.0	 30.0;
	5809	 1835	 0.010753	 0.029321	 0.0014	 952	 952	 952	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 1836	 0.051444	 0.105716	 0.0048	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	2021	 1837	 0.034593	 0.087579	 0.0014	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	2421	 1837	 0.025185	 0.046101	 0.0005	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	2855	 1837	 0.039683	 0.14714	 0.0023	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	3637	 1837	 0.003595	 0.00658	 0.0006	 3938	 3938	 3938	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 1837	 0.086168	 0.187453	 0.0021	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 1837	 0.015873	 0.09801	 0.0013	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	2479	 1837	 0.063996	 0.139582	 0.001	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	5464	 1838	 0.000375	 0.002548	 0.0061	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 1838	 0.001969	 0.011678	 0.0223	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5364	 1840	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 1839	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2135	 1841	 0.05805	 0.147443	 0.0017	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	2606	 1841	 0.041068	 0.104812	 0.0012	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	2022	 1842	 0.168002	 0.377601	 0.0079	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	2328	 1842	 0.037289	 0.098262	 0.0077	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	4883	 1842	 0.107987	 0.222827	 0.0057	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 1843	 0.003832	 0.019733	 0.0359	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1943	 1847	 0.011975	 0.03037	 0.0015	 984	 984	 984	 0.0	 0.0	 1	 -30.0	 30.0;
	2883	 1851	 0.08642	 0.218947	 0.0025	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	4277	 1852	 0.022172	 0.056437	 0.0006	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	2304	 1853	 0.053691	 0.137944	 0.0016	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	2504	 1853	 0.027715	 0.071554	 0.0008	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	2260	 1856	 0.017889	 0.067523	 0.0008	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	2428	 1856	 0.064248	 0.166541	 0.0018	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	4331	 1856	 0.047569	 0.122575	 0.0019	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 1857	 0.014865	 0.039305	 0.0005	 724	 724	 724	 0.0	 0.0	 1	 -30.0	 30.0;
	4009	 1857	 0.023935	 0.075838	 0.0009	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	4742	 1858	 0.019904	 0.085412	 0.0039	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	3071	 1859	 0.026959	 0.061225	 0.0007	 442	 442	 442	 0.0	 0.0	 1	 -30.0	 30.0;
	3077	 1859	 0.038801	 0.081885	 0.0009	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	3036	 1860	 0.003779	 0.012598	 0.0021	 2313	 2313	 2313	 0.0	 0.0	 1	 -30.0	 30.0;
	3335	 1861	 0.010834	 0.052658	 0.001	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	4026	 1861	 0.010293	 0.018841	 0.0002	 1376	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	4289	 1861	 0.007055	 0.026707	 0.0	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	3655	 1862	 0.002066	 0.012018	 0.0148	 2495	 2495	 2495	 0.0	 0.0	 1	 -30.0	 30.0;
	4014	 1866	 0.005901	 0.019494	 0.001	 1459	 1459	 1459	 0.0	 0.0	 1	 -30.0	 30.0;
	4508	 1867	 0.02321	 0.049259	 0.0023	 546	 546	 546	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 1868	 0.024198	 0.101728	 0.0052	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	1730	 1869	 0.051728	 0.099383	 0.0042	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	2303	 1869	 0.074815	 0.149753	 0.0066	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	3196	 1869	 0.035494	 0.14963	 0.0076	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 1871	 0.053162	 0.173343	 0.0021	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	5276	 1872	 0.002771	 0.011338	 0.0002	 2530	 2530	 2530	 0.0	 0.0	 1	 -30.0	 30.0;
	5588	 1872	 0.007307	 0.031242	 0.0059	 921	 921	 921	 0.0	 0.0	 1	 -30.0	 30.0;
	1947	 1873	 0.046863	 0.127992	 0.0014	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	2563	 1873	 0.053414	 0.13681	 0.0018	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	1821	 1874	 0.034517	 0.144621	 0.0024	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	2685	 1875	 0.009787	 0.017916	 0.0319	 1486	 1486	 1486	 0.0	 0.0	 1	 -30.0	 30.0;
	5369	 1876	 0.000123	 0.001235	 0.0	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	3656	 1879	 0.018695	 0.036256	 0.0004	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	5370	 1880	 0.000247	 0.001235	 0.0006	 23584	 23584	 23584	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 1881	 0.023432	 0.074074	 0.001	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	3856	 1881	 0.04384	 0.109851	 0.001	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	4747	 1881	 0.010078	 0.024439	 0.0003	 1117	 1117	 1117	 0.0	 0.0	 1	 -30.0	 30.0;
	5402	 1881	 0.054674	 0.137818	 0.002	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 1882	 0.004321	 0.019876	 0.0172	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 1882	 0.004321	 0.019876	 0.0172	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	3747	 1883	 5.9e-05	 0.000138	 0.0081	 206750	 206750	 206750	 0.0	 0.0	 1	 -30.0	 30.0;
	3061	 1885	 0.036667	 0.098889	 0.0049	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	3061	 1886	 0.036667	 0.098889	 0.0049	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	4228	 1887	 0.012469	 0.031482	 0.0015	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	5372	 1890	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5373	 1891	 2e-05	 0.000198	 0.001	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	2695	 1892	 0.000217	 0.00081	 0.1002	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1902	 1900	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1902	 1899	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1902	 1898	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1902	 1897	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	3876	 1901	 0.03036	 0.087856	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5060	 1901	 0.041068	 0.104308	 0.0012	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	4090	 1902	 0.00381	 0.02541	 0.0471	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3971	 1903	 0.007559	 0.050643	 0.001	 577	 577	 577	 0.0	 0.0	 1	 -30.0	 30.0;
	4217	 1903	 0.054422	 0.150214	 0.0844	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	4260	 1903	 0.031746	 0.136054	 0.0016	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 1903	 0.023432	 0.126228	 0.002	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	5275	 1903	 0.036281	 0.153943	 0.002	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	5475	 1903	 0.021164	 0.073293	 0.0011	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 1903	 0.008314	 0.035525	 0.0	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 1903	 0.035273	 0.089947	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 1903	 0.008314	 0.035525	 0.001	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	2915	 1904	 0.00476	 0.032099	 0.0567	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3611	 1904	 0.002825	 0.019082	 0.0344	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3972	 1904	 0.000593	 0.00403	 0.0071	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5274	 1904	 0.0016	 0.010884	 0.0192	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4456	 1906	 0.018712	 0.063684	 0.1073	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	4927	 1906	 0.01297	 0.04896	 0.079	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	4267	 1907	 0.008519	 0.017037	 0.0008	 1592	 1592	 1592	 0.0	 0.0	 1	 -30.0	 30.0;
	5091	 1908	 0.032754	 0.089191	 0.001	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 1909	 0.049887	 0.127992	 0.0014	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	5077	 1910	 0.012716	 0.052593	 0.0034	 561	 561	 561	 0.0	 0.0	 1	 -30.0	 30.0;
	2085	 1911	 0.010078	 0.018645	 0.0236	 1394	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	5652	 1911	 0.075334	 0.13807	 0.0024	 188	 188	 188	 0.0	 0.0	 1	 -30.0	 30.0;
	2085	 1911	 0.010078	 0.018645	 0.0236	 1394	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	4291	 1912	 0.045881	 0.12197	 0.0017	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5138	 1912	 0.038801	 0.080121	 0.0013	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	5319	 1912	 0.020912	 0.066767	 0.001	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	4293	 1913	 0.001363	 0.009106	 0.0304	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5384	 1913	 0.011437	 0.078084	 0.1377	 276.0	 276.0	 276.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 1915	 0.002016	 0.007055	 0.0065	 4122	 4122	 4122	 0.0	 0.0	 1	 -30.0	 30.0;
	5309	 1914	 0.000171	 0.000313	 0.0	 84779	 84779	 84779	 0.0	 0.0	 1	 -30.0	 30.0;
	5726	 1916	 0.007307	 0.019904	 0.0002	 1393	 1393	 1393	 0.0	 0.0	 1	 -30.0	 30.0;
	2254	 1917	 0.000869	 0.004407	 0.4212	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5179	 1918	 0.008642	 0.022346	 0.0011	 1240	 1240	 1240	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 1919	 0.003527	 0.015117	 0.0002	 1903	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 1919	 0.001764	 0.006047	 0.006	 4688	 4688	 4688	 0.0	 0.0	 1	 -30.0	 30.0;
	3321	 1919	 0.003779	 0.015117	 0.0011	 1895	 1895	 1895	 0.0	 0.0	 1	 -30.0	 30.0;
	5376	 1920	 0.003527	 0.009322	 0.0106	 3052	 3052	 3052	 0.0	 0.0	 1	 -30.0	 30.0;
	5126	 1921	 0.000756	 0.002016	 0.0	 13714	 13714	 13714	 0.0	 0.0	 1	 -30.0	 30.0;
	5016	 1922	 0.001948	 0.003565	 0.0	 7487	 7487	 7487	 0.0	 0.0	 1	 -30.0	 30.0;
	3930	 1923	 0.107332	 0.272109	 0.0031	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	2098	 1924	 0.00069	 0.001263	 0.0032	 21948	 21948	 21948	 0.0	 0.0	 1	 -30.0	 30.0;
	3835	 1924	 0.001728	 0.005679	 0.0003	 5407	 5407	 5407	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 1925	 0.01033	 0.034014	 0.0004	 806	 806	 806	 0.0	 0.0	 1	 -30.0	 30.0;
	2325	 1926	 0.000217	 0.000474	 0.0445	 59375	 59375	 59375	 0.0	 0.0	 1	 -30.0	 30.0;
	2194	 1927	 0.039136	 0.124321	 0.007	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	2355	 1927	 0.039383	 0.101358	 0.0057	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	2409	 1927	 0.030247	 0.079383	 0.0046	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	4246	 1927	 0.000741	 0.001728	 0.0011	 16129	 16129	 16129	 0.0	 0.0	 1	 -30.0	 30.0;
	4246	 1927	 0.000741	 0.001728	 0.0012	 16129	 16129	 16129	 0.0	 0.0	 1	 -30.0	 30.0;
	5331	 1928	 0.002765	 0.012998	 0.0213	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 1929	 0.012593	 0.078025	 0.004	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 1929	 0.012099	 0.078272	 0.004	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 1930	 0.001205	 0.015845	 0.5487	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 1930	 0.000623	 0.008172	 0.283	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 1930	 0.001205	 0.015852	 0.5487	 1997	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 1930	 0.000623	 0.008172	 0.283	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3877	 1931	 0.072814	 0.198287	 0.0022	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	4120	 1931	 0.017133	 0.072814	 0.0001	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	4120	 1931	 0.017133	 0.072814	 0.0001	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 1932	 0.014938	 0.039012	 0.0018	 726	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	2562	 1934	 0.001622	 0.010949	 0.0816	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2974	 1934	 0.004361	 0.019407	 0.0346	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4459	 1934	 0.00644	 0.043615	 0.081	 537.0	 537.0	 537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2974	 1934	 0.002884	 0.019127	 0.0357	 537.0	 537.0	 537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3939	 1935	 0.003553	 0.040406	 0.8776	 787	 787	 787	 0.0	 0.0	 1	 -30.0	 30.0;
	4548	 1935	 0.001413	 0.020512	 0.5314	 1552	 1552	 1552	 0.0	 0.0	 1	 -30.0	 30.0;
	4859	 1935	 0.002029	 0.020568	 0.5372	 1543	 1543	 1543	 0.0	 0.0	 1	 -30.0	 30.0;
	2289	 1935	 0.001233	 0.012465	 0.3235	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4548	 1935	 0.00141	 0.019927	 0.5463	 1597	 1597	 1597	 0.0	 0.0	 1	 -30.0	 30.0;
	4294	 1937	 0.000983	 0.012909	 0.4476	 2461	 2461	 2461	 0.0	 0.0	 1	 -30.0	 30.0;
	2661	 1940	 0.028647	 0.075032	 0.0049	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 1941	 0.001058	 0.006576	 0.0116	 4433	 4433	 4433	 0.0	 0.0	 1	 -30.0	 30.0;
	2209	 1942	 0.009617	 0.05921	 0.0071	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 1942	 0.014321	 0.036667	 0.0016	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	3133	 1943	 0.010864	 0.06	 0.019	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	4067	 1943	 0.011728	 0.029753	 0.0015	 1008	 1008	 1008	 0.0	 0.0	 1	 -30.0	 30.0;
	5368	 1943	 0.010988	 0.028518	 0.0003	 1132	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	2209	 1942	 0.00963	 0.059247	 0.0071	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	4067	 1942	 0.009506	 0.030864	 0.0022	 998	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	3397	 1944	 0.011299	 0.051259	 0.0881	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4844	 1944	 0.002232	 0.012286	 0.0218	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4844	 1944	 0.003714	 0.017975	 0.0405	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3503	 1948	 0.017385	 0.044344	 0.0	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	2047	 1949	 0.003527	 0.009574	 0.0004	 2981	 2981	 2981	 0.0	 0.0	 1	 -30.0	 30.0;
	2699	 1950	 0.003827	 0.010124	 0.0005	 2745	 2745	 2745	 0.0	 0.0	 1	 -30.0	 30.0;
	2891	 1951	 0.017385	 0.074326	 0.0091	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	2914	 1951	 0.013857	 0.056185	 0.0108	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	5380	 1953	 0.000123	 0.000333	 0.0	 83671	 83671	 83671	 0.0	 0.0	 1	 -30.0	 30.0;
	3311	 1954	 0.034417	 0.113429	 0.0021	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	5285	 1955	 0.004938	 0.01	 0.0005	 2664	 2664	 2664	 0.0	 0.0	 1	 -30.0	 30.0;
	5725	 1956	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	2686	 1957	 0.026707	 0.070547	 0.0051	 404	 404	 404	 0.0	 0.0	 1	 -30.0	 30.0;
	3272	 1958	 0.065004	 0.171328	 0.0019	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	3311	 1958	 0.029226	 0.073066	 0.0035	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 1959	 0.002268	 0.005291	 0.0001	 5284	 5284	 5284	 0.0	 0.0	 1	 -30.0	 30.0;
	4431	 1959	 0.012774	 0.023558	 0.0002	 1135	 1135	 1135	 0.0	 0.0	 1	 -30.0	 30.0;
	2298	 1961	 0.003812	 0.018568	 0.0557	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4113	 1960	 0.003911	 0.01679	 0.0284	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 1961	 0.005057	 0.031131	 0.0587	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 1960	 0.002785	 0.018153	 0.0334	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 1962	 0.002569	 0.036468	 0.9253	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 1962	 0.002569	 0.036468	 0.9253	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 1962	 0.005422	 0.039197	 0.841	 806	 806	 806	 0.0	 0.0	 1	 -30.0	 30.0;
	3015	 1964	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	3610	 1965	 0.005039	 0.013857	 0.0016	 2003	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 1966	 0.082464	 0.277879	 0.0031	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	1979	 1977	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1979	 1976	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1979	 1975	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1979	 1974	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1979	 1973	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1979	 1972	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	3815	 1978	 0.054674	 0.149534	 0.0017	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4486	 1978	 0.054926	 0.166289	 0.0019	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3816	 1979	 0.00164	 0.011299	 0.0213	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 1979	 0.002647	 0.018035	 0.0334	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3294	 1981	 0.045855	 0.140338	 0.002	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4114	 1982	 0.031494	 0.076846	 0.001	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 1984	 0.035097	 0.068405	 0.0007	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	4755	 1984	 0.040816	 0.092719	 0.001	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	4344	 1985	 0.057697	 0.151927	 0.0034	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 1986	 0.018645	 0.037037	 0.0004	 734	 734	 734	 0.0	 0.0	 1	 -30.0	 30.0;
	3227	 1987	 0.059209	 0.153439	 0.0017	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	4259	 1988	 0.078357	 0.222726	 0.003	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	3933	 1989	 0.154926	 0.396699	 0.0098	 70	 70	 70	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 1990	 0.013025	 0.037111	 0.0018	 772	 772	 772	 0.0	 0.0	 1	 -30.0	 30.0;
	5370	 1990	 0.028568	 0.097111	 0.0062	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	5384	 1991	 2e-05	 0.000138	 0.001	 509.0	 509.0	 509.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 1991	 0.000395	 0.002647	 0.0051	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5385	 1992	 0.000504	 0.00126	 0.0	 21757	 21757	 21757	 0.0	 0.0	 1	 -30.0	 30.0;
	3200	 1993	 0.041824	 0.090451	 0.001	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	5734	 1994	 0.036533	 0.159486	 0.0021	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	2304	 1995	 0.081129	 0.207861	 0.0024	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	2313	 1995	 0.095641	 0.247367	 0.0028	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	3203	 1995	 0.056437	 0.148652	 0.0019	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4192	 1996	 0.007055	 0.044596	 0.0006	 674	 674	 674	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 1996	 0.006803	 0.045855	 0.0028	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	4748	 1996	 0.019652	 0.05417	 0.0006	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	4192	 1996	 0.006299	 0.039305	 0.0005	 765	 765	 765	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 1996	 0.007055	 0.047367	 0.0006	 636	 636	 636	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 1996	 0.006979	 0.046813	 0.0006	 643	 643	 643	 0.0	 0.0	 1	 -30.0	 30.0;
	2519	 1997	 0.003259	 0.021669	 0.0405	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2519	 1997	 0.00324	 0.021768	 0.0395	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 1998	 0.026102	 0.066087	 0.0011	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	4940	 1999	 0.066516	 0.181406	 0.0028	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	4075	 2001	 0.05543	 0.141093	 0.0016	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	4872	 2001	 0.054422	 0.138574	 0.0016	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	4075	 2002	 0.055178	 0.140338	 0.0016	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	4873	 2002	 0.05417	 0.13807	 0.0016	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5366	 2003	 0.000252	 0.00252	 0.0001	 13395	 13395	 13395	 0.0	 0.0	 1	 -30.0	 30.0;
	2681	 2004	 0.002351	 0.011022	 0.0182	 2747	 2747	 2747	 0.0	 0.0	 1	 -30.0	 30.0;
	3288	 2004	 0.002252	 0.015842	 0.079	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 2004	 0.00132	 0.013076	 0.0385	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4151	 2004	 0.005531	 0.027042	 0.0628	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 2005	 0.016755	 0.051348	 0.0053	 564	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	3719	 2006	 0.058453	 0.15747	 0.0022	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	4645	 2009	 0.000138	 0.000316	 0.0314	 89765	 89765	 89765	 0.0	 0.0	 1	 -30.0	 30.0;
	4163	 2010	 0.020988	 0.055185	 0.0026	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	5179	 2010	 0.016049	 0.040741	 0.0019	 679	 679	 679	 0.0	 0.0	 1	 -30.0	 30.0;
	2818	 2011	 0.076594	 0.194507	 0.0022	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	5051	 2011	 0.120106	 0.327186	 0.0042	 88	 88	 88	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 2011	 0.180957	 0.33124	 0.0039	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 2012	 0.009264	 0.038696	 0.0638	 309.0	 309.0	 309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4456	 2012	 0.022084	 0.061906	 0.1013	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 2012	 0.017185	 0.07921	 0.1336	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 2013	 0.089494	 0.244142	 0.0028	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	4312	 2014	 0.001358	 0.003704	 0.0002	 7529	 7529	 7529	 0.0	 0.0	 1	 -30.0	 30.0;
	5393	 2015	 0.000296	 0.001936	 0.0137	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5846	 2018	 0.008818	 0.024188	 0.0002	 1182	 1182	 1182	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 2019	 0.00907	 0.024439	 0.0002	 1167	 1167	 1167	 0.0	 0.0	 1	 -30.0	 30.0;
	5466	 2020	 0.00237	 0.005748	 0.0111	 5010	 5010	 5010	 0.0	 0.0	 1	 -30.0	 30.0;
	3186	 2022	 0.072814	 0.15999	 0.0017	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4940	 2022	 0.104157	 0.283522	 0.0038	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	3616	 2023	 0.000336	 0.002252	 0.004	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2711	 2025	 0.068531	 0.186697	 0.0021	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	4295	 2025	 0.016881	 0.045855	 0.0006	 605	 605	 605	 0.0	 0.0	 1	 -30.0	 30.0;
	2550	 2026	 0.022676	 0.070295	 0.0065	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	4742	 2026	 0.035021	 0.081129	 0.0025	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	5654	 2027	 0.001008	 0.00252	 0.001	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 2028	 0.002593	 0.006914	 0.0003	 4107	 4107	 4107	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 2029	 0.002099	 0.006173	 0.0003	 4651	 4651	 4651	 0.0	 0.0	 1	 -30.0	 30.0;
	5398	 2030	 0.010124	 0.027296	 0.0045	 1021	 1021	 1021	 0.0	 0.0	 1	 -30.0	 30.0;
	2092	 2031	 0.022593	 0.077901	 0.0045	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	2690	 2031	 0.008395	 0.017531	 0.0826	 1651	 1651	 1651	 0.0	 0.0	 1	 -30.0	 30.0;
	3382	 2031	 0.016173	 0.068395	 0.0044	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 2033	 0.046667	 0.119136	 0.0057	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	4754	 2033	 0.017531	 0.040123	 0.0019	 693	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	4880	 2034	 0.00358	 0.00716	 0.0194	 3711	 3711	 3711	 0.0	 0.0	 1	 -30.0	 30.0;
	5563	 2035	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5564	 2035	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 2036	 0.061225	 0.171328	 0.0018	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	5186	 2036	 0.072688	 0.199899	 0.0022	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	5314	 2037	 0.020988	 0.107155	 0.0126	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	5568	 2037	 0.021164	 0.107332	 0.0012	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	5569	 2037	 0.021164	 0.107332	 0.0012	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	2435	 2038	 0.047619	 0.129756	 0.0014	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	2060	 2039	 0.117914	 0.298816	 0.0034	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	2825	 2039	 0.059234	 0.162761	 0.0018	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3750	 2039	 0.071429	 0.181532	 0.0021	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	5221	 2039	 0.03225	 0.081885	 0.0009	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	5223	 2039	 0.008566	 0.053666	 0.0007	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 2039	 0.03225	 0.081129	 0.001	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	4456	 2040	 0.011556	 0.052998	 0.0942	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 2040	 0.011299	 0.057086	 0.1013	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4729	 2041	 0.075334	 0.243638	 0.0022	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 2042	 0.109625	 0.278786	 0.0174	 102	 102	 102	 0.0	 0.0	 1	 -30.0	 30.0;
	3614	 2043	 0.002173	 0.014519	 0.0273	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2449	 2045	 0.026449	 0.06568	 0.0207	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	2668	 2045	 0.012133	 0.030178	 0.0095	 992	 992	 992	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 2048	 0.013253	 0.051348	 0.0013	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	2234	 2048	 0.010582	 0.063744	 0.001	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 2048	 0.014588	 0.067498	 0.0008	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	2842	 2048	 0.012169	 0.032779	 0.001	 870	 870	 870	 0.0	 0.0	 1	 -30.0	 30.0;
	2223	 2049	 0.000942	 0.004946	 0.0182	 6148	 6148	 6148	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 2049	 0.008533	 0.038716	 0.0678	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2763	 2049	 0.002977	 0.014748	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3765	 2049	 0.002483	 0.016496	 0.0304	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4068	 2049	 0.004188	 0.019082	 0.0334	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4182	 2049	 0.001742	 0.01171	 0.038	 457.0	 457.0	 457.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 2049	 0.001414	 0.009527	 0.0172	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5402	 2050	 0.002771	 0.007307	 0.0	 3779	 3779	 3779	 0.0	 0.0	 1	 -30.0	 30.0;
	2986	 2052	 0.029479	 0.064248	 0.0007	 406	 406	 406	 0.0	 0.0	 1	 -30.0	 30.0;
	2986	 2052	 0.022928	 0.062484	 0.0007	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 2053	 0.008672	 0.04002	 0.084	 256.0	 256.0	 256.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5463	 2053	 0.001237	 0.005636	 0.0256	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4811	 2054	 0.068027	 0.173091	 0.0019	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	5305	 2054	 0.012094	 0.031242	 0.0003	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	3198	 2055	 0.003062	 0.020365	 0.0385	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4313	 2055	 0.000786	 0.00524	 0.0273	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 2055	 0.003615	 0.024336	 0.0445	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4314	 2055	 0.001274	 0.008486	 0.0152	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2351	 2056	 0.001634	 0.016835	 0.4361	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3517	 2056	 0.000935	 0.013565	 0.3523	 2335	 2335	 2335	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 2056	 0.001434	 0.01885	 0.6527	 1679	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	2350	 2056	 0.001634	 0.016842	 0.4361	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3516	 2056	 0.000934	 0.013565	 0.3523	 2335	 2335	 2335	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 2056	 0.001434	 0.01885	 0.6527	 1679	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	3621	 2059	 0.001512	 0.006803	 0.0001	 4237	 4237	 4237	 0.0	 0.0	 1	 -30.0	 30.0;
	3621	 2058	 0.001512	 0.006803	 0.0001	 4237	 4237	 4237	 0.0	 0.0	 1	 -30.0	 30.0;
	3621	 2057	 0.001512	 0.006803	 0.0001	 4237	 4237	 4237	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 2061	 0.000111	 0.001604	 0.0416	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 2062	 0.000111	 0.0016	 0.0404	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 2063	 0.000111	 0.0016	 0.0404	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 2064	 0.000111	 0.0016	 0.0404	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 2065	 0.000111	 0.001606	 0.0416	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 2066	 0.000111	 0.001616	 0.0419	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5399	 2067	 0.000756	 0.004283	 0.0002	 6789	 6789	 6789	 0.0	 0.0	 1	 -30.0	 30.0;
	2126	 2069	 0.07357	 0.199647	 0.0022	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	2736	 2069	 0.157697	 0.401864	 0.0045	 71	 71	 71	 0.0	 0.0	 1	 -30.0	 30.0;
	4697	 2069	 0.090955	 0.248425	 0.0058	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	4095	 2070	 0.014696	 0.0269	 0.0656	 935	 935	 935	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 2071	 0.000988	 0.006953	 0.0273	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3841	 2072	 0.013102	 0.089947	 0.002	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	3859	 2072	 0.016881	 0.071806	 0.001	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	5581	 2072	 0.066012	 0.21542	 0.002	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	2806	 2075	 0.001481	 0.005309	 0.0002	 5731	 5731	 5731	 0.0	 0.0	 1	 -30.0	 30.0;
	3974	 2076	 0.049635	 0.127992	 0.0014	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	4403	 2076	 0.038549	 0.100277	 0.0011	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	2125	 2077	 0.005195	 0.034528	 0.0648	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4967	 2079	 0.018025	 0.047531	 0.0049	 585	 585	 585	 0.0	 0.0	 1	 -30.0	 30.0;
	5720	 2079	 0.023457	 0.064074	 0.0029	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	4967	 2078	 0.018025	 0.047407	 0.0049	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	5263	 2081	 0.0013	 0.005888	 0.0101	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5262	 2080	 0.001306	 0.005912	 0.0101	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2278	 2082	 0.009506	 0.019136	 0.0008	 1391	 1391	 1391	 0.0	 0.0	 1	 -30.0	 30.0;
	3258	 2082	 0.010124	 0.026296	 0.0013	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	4961	 2083	 0.01321	 0.035185	 0.0018	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	5405	 2084	 0.000953	 0.001744	 0.0	 15304	 15304	 15304	 0.0	 0.0	 1	 -30.0	 30.0;
	3049	 2085	 0.184933	 0.456034	 0.0052	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	3613	 2085	 0.031494	 0.11615	 0.0014	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	4052	 2085	 0.111363	 0.3419	 0.0039	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	4523	 2085	 0.039305	 0.161502	 0.002	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	4525	 2086	 0.002094	 0.013294	 0.0243	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 2087	 0.006499	 0.043259	 0.08	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2678	 2087	 0.003737	 0.037823	 0.1088	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5292	 2087	 0.001254	 0.008365	 0.0152	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 2088	 0.00247	 0.027208	 0.5747	 1168	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 2088	 0.001766	 0.019792	 0.3957	 1605	 1605	 1605	 0.0	 0.0	 1	 -30.0	 30.0;
	3621	 2089	 0.008062	 0.019904	 0.0187	 1375	 1375	 1375	 0.0	 0.0	 1	 -30.0	 30.0;
	3621	 2089	 0.007811	 0.019652	 0.0187	 1397	 1397	 1397	 0.0	 0.0	 1	 -30.0	 30.0;
	2734	 2090	 0.01679	 0.042346	 0.0021	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	2618	 2091	 0.039753	 0.106506	 0.0052	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2202	 2092	 0.014568	 0.090123	 0.0146	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	2284	 2094	 0.000401	 0.001817	 0.003	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5851	 2093	 0.0032	 0.014637	 0.0243	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2093	 1494	 2e-05	 0.000198	 0.0	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	3139	 2095	 0.036256	 0.092492	 0.0034	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	2569	 2096	 0.003401	 0.022763	 0.0415	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4992	 2096	 0.004122	 0.027542	 0.0501	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2451	 2097	 0.090955	 0.247669	 0.0069	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	5465	 2097	 0.040514	 0.110506	 0.0013	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	2488	 2100	 0.010557	 0.019325	 0.0008	 1378	 1378	 1378	 0.0	 0.0	 1	 -30.0	 30.0;
	4305	 2100	 0.004938	 0.01321	 0.0006	 2151	 2151	 2151	 0.0	 0.0	 1	 -30.0	 30.0;
	4305	 2100	 0.004938	 0.01321	 0.0006	 2151	 2151	 2151	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 2101	 0.048395	 0.119753	 0.0248	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 2101	 0.048395	 0.119753	 0.0245	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	3113	 2102	 0.006047	 0.016125	 0.0002	 1715	 1715	 1715	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 2103	 0.037289	 0.154195	 0.0019	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 2103	 0.017889	 0.045855	 0.0005	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	4698	 2103	 0.00907	 0.025951	 0.0002	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	5185	 2103	 0.011338	 0.038801	 0.0005	 731	 731	 731	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 2103	 0.019148	 0.051398	 0.0006	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	4392	 2103	 0.023432	 0.09675	 0.0012	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	5764	 2103	 0.017133	 0.071051	 0.0009	 404	 404	 404	 0.0	 0.0	 1	 -30.0	 30.0;
	4393	 2104	 0.001817	 0.008198	 0.0142	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5637	 2104	 0.001857	 0.012504	 0.0233	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2877	 2105	 0.065679	 0.209012	 0.0097	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	5623	 2105	 0.009136	 0.025556	 0.0011	 1095	 1095	 1095	 0.0	 0.0	 1	 -30.0	 30.0;
	2111	 2108	 0.007105	 0.014009	 0.0002	 1937	 1937	 1937	 0.0	 0.0	 1	 -30.0	 30.0;
	2111	 2107	 0.00325	 0.00844	 0.0001	 3363	 3363	 3363	 0.0	 0.0	 1	 -30.0	 30.0;
	2111	 2110	 0.000252	 0.001613	 0.0002	 18630	 18630	 18630	 0.0	 0.0	 1	 -30.0	 30.0;
	2111	 2109	 0.000252	 0.001663	 0.0002	 18082	 18082	 18082	 0.0	 0.0	 1	 -30.0	 30.0;
	2620	 2111	 0.094104	 0.251676	 0.0028	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	3646	 2111	 0.066868	 0.185059	 0.0047	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	4165	 2111	 0.163517	 0.334593	 0.004	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 2111	 0.069992	 0.202973	 0.002	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 2111	 0.106122	 0.297178	 0.0032	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 2112	 0.002844	 0.018884	 0.0354	 402.0	 402.0	 402.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3901	 2113	 0.079365	 0.221466	 0.0025	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	5406	 2113	 0.015293	 0.042328	 0.0005	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 2114	 0.068783	 0.261779	 0.003	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	3666	 2115	 0.075838	 0.216679	 0.0024	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	3700	 2115	 0.074074	 0.211136	 0.0024	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	5407	 2116	 0.004787	 0.033938	 0.0003	 888	 888	 888	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 2117	 0.081381	 0.225246	 0.0019	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	3015	 2118	 0.023683	 0.052406	 0.001	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	2996	 2119	 0.00025	 0.0025	 0.0	 13742	 13742	 13742	 0.0	 0.0	 1	 -30.0	 30.0;
	2465	 2121	 0.000252	 0.00252	 0.0017	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	3175	 2121	 0.0194	 0.05417	 0.0026	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	3177	 2122	 0.058453	 0.163517	 0.0018	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	3448	 2122	 0.097002	 0.267826	 0.003	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 2122	 0.040312	 0.109095	 0.0017	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 2123	 0.024691	 0.074326	 0.0009	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	3526	 2123	 0.05543	 0.140842	 0.0016	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	2768	 2124	 0.018645	 0.051146	 0.0006	 559	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	3352	 2124	 0.015369	 0.048627	 0.0721	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	3794	 2124	 0.078357	 0.161754	 0.0018	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	4060	 2124	 0.087402	 0.222525	 0.0272	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	5388	 2124	 0.016629	 0.044092	 0.0006	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	3794	 2124	 0.054926	 0.148652	 0.0017	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 2124	 0.016629	 0.044092	 0.0006	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	5381	 2126	 0.066037	 0.18002	 0.002	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	2680	 2127	 0.051272	 0.133459	 0.0015	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	3610	 2128	 0.075082	 0.193248	 0.003	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	3955	 2127	 0.065004	 0.162509	 0.002	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	4015	 2128	 0.06198	 0.178634	 0.002	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2004	 2131	 4e-05	 0.000375	 0.0	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2004	 2130	 5.9e-05	 0.000395	 0.0	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2004	 2129	 5.9e-05	 0.000454	 0.001	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4670	 2132	 0.010988	 0.035432	 0.001	 848	 848	 848	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 2134	 0.000494	 0.003319	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4781	 2134	 0.00318	 0.016237	 0.0289	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5818	 2134	 0.003565	 0.013003	 0.0218	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2238	 2134	 0.001363	 0.006104	 0.0111	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 2134	 0.000514	 0.003496	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 2134	 0.000988	 0.004879	 0.0091	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4194	 2135	 0.001764	 0.004787	 0.0001	 5962	 5962	 5962	 0.0	 0.0	 1	 -30.0	 30.0;
	4195	 2135	 0.001512	 0.004031	 0.0001	 7065	 7065	 7065	 0.0	 0.0	 1	 -30.0	 30.0;
	2499	 2136	 0.006914	 0.021235	 0.0013	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	3225	 2136	 0.008395	 0.019753	 0.0047	 1217	 1217	 1217	 0.0	 0.0	 1	 -30.0	 30.0;
	5252	 2137	 0.008314	 0.028219	 0.0	 1004	 1004	 1004	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 2137	 0.010078	 0.054926	 0.0021	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	5522	 2137	 0.081633	 0.229277	 0.003	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	5062	 2139	 0.000356	 0.003319	 0.0121	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5061	 2140	 0.00036	 0.003356	 0.0167	 853.0	 853.0	 853.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2431	 2141	 0.003652	 0.006685	 0.0004	 3993	 3993	 3993	 0.0	 0.0	 1	 -30.0	 30.0;
	2431	 2141	 0.003652	 0.006685	 0.0004	 3993	 3993	 3993	 0.0	 0.0	 1	 -30.0	 30.0;
	1910	 2142	 0.011605	 0.06358	 0.004	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	2760	 2142	 0.000247	 0.000691	 0.0024	 41324	 41324	 41324	 0.0	 0.0	 1	 -30.0	 30.0;
	4423	 2143	 0.001086	 0.007289	 0.0132	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4828	 2143	 0.00308	 0.020628	 0.0375	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4423	 2143	 0.001067	 0.007289	 0.0132	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4828	 2143	 0.003022	 0.020109	 0.0375	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4829	 2143	 0.003022	 0.020168	 0.0435	 463.0	 463.0	 463.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3195	 2146	 0.019904	 0.051902	 0.0106	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	3545	 2147	 0.025156	 0.046047	 0.0021	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	4353	 2147	 0.003779	 0.009826	 0.0	 2805	 2805	 2805	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 2147	 0.0194	 0.103553	 0.001	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	5561	 2147	 0.008062	 0.034266	 0.0	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	4352	 2147	 0.003023	 0.009826	 0.0	 2872	 2872	 2872	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 2148	 0.001705	 0.010438	 0.0304	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4164	 2150	 0.027161	 0.070876	 0.0034	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	5739	 2150	 0.010741	 0.027531	 0.0013	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 2151	 0.000494	 0.001481	 0.0002	 19026	 19026	 19026	 0.0	 0.0	 1	 -30.0	 30.0;
	3543	 2153	 0.099017	 0.241119	 0.0037	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	5410	 2154	 0.005896	 0.030713	 0.0396	 973	 973	 973	 0.0	 0.0	 1	 -30.0	 30.0;
	3656	 2155	 0.01008	 0.018452	 0.0006	 1447	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	3543	 2156	 0.037185	 0.068066	 0.0007	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	5551	 2156	 0.080747	 0.147806	 0.0015	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	1996	 2157	 0.004031	 0.017637	 0.0243	 1682	 1682	 1682	 0.0	 0.0	 1	 -30.0	 30.0;
	1996	 2157	 0.004535	 0.018392	 0.0252	 1606	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 2160	 0.002298	 0.004207	 0.0063	 6326	 6326	 6326	 0.0	 0.0	 1	 -30.0	 30.0;
	5315	 2161	 0.000123	 0.001235	 0.0047	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	4828	 2162	 0.001106	 0.007546	 0.0354	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2104	 2163	 0.000158	 0.001343	 0.5594	 654.0	 654.0	 654.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2068	 2165	 0.015148	 0.064062	 0.0037	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	3208	 2165	 0.009383	 0.040123	 0.0005	 779	 779	 779	 0.0	 0.0	 1	 -30.0	 30.0;
	5269	 2165	 0.010617	 0.043704	 0.0016	 769	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	4753	 2165	 0.001235	 0.00642	 0.0013	 4930	 4930	 4930	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 2166	 0.002264	 0.015056	 0.0273	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3708	 2166	 0.002173	 0.014617	 0.0263	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3927	 2166	 0.000375	 0.002509	 0.004	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5062	 2166	 0.001746	 0.011648	 0.0216	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5073	 2166	 0.000909	 0.00478	 0.0086	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 2166	 0.001936	 0.011239	 0.0203	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5061	 2166	 0.001738	 0.011635	 0.0213	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5072	 2166	 0.000751	 0.004148	 0.0101	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5061	 2166	 0.001679	 0.01122	 0.0203	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5685	 2170	 0.024188	 0.066213	 0.0007	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	2781	 2171	 0.120862	 0.306551	 0.0035	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	4433	 2171	 0.05291	 0.134291	 0.0015	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 2172	 0.031922	 0.135097	 0.0017	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	3526	 2173	 0.040564	 0.153187	 0.0018	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	3876	 2173	 0.06198	 0.158982	 0.0018	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 2172	 0.031973	 0.135299	 0.0017	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	3526	 2173	 0.040564	 0.146888	 0.0018	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4646	 2176	 0.008889	 0.092593	 0.0151	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	4646	 2176	 0.008889	 0.092469	 0.0144	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 2178	 0.005693	 0.01042	 0.0044	 2562	 2562	 2562	 0.0	 0.0	 1	 -30.0	 30.0;
	2222	 2177	 0.005693	 0.01042	 0.0044	 2562	 2562	 2562	 0.0	 0.0	 1	 -30.0	 30.0;
	2684	 2179	 0.000381	 0.000697	 0.0486	 38967	 38967	 38967	 0.0	 0.0	 1	 -30.0	 30.0;
	4018	 2180	 0.007307	 0.017133	 0.0191	 1633	 1633	 1633	 0.0	 0.0	 1	 -30.0	 30.0;
	2882	 2181	 0.000756	 0.00252	 0.0001	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	3877	 2181	 0.094986	 0.240867	 0.0032	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	2187	 2184	 0.000252	 0.00252	 0.0011	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	2294	 2184	 0.000756	 0.002016	 0.0023	 13307	 13307	 13307	 0.0	 0.0	 1	 -30.0	 30.0;
	3097	 2184	 0.007559	 0.015369	 0.0126	 1673	 1673	 1673	 0.0	 0.0	 1	 -30.0	 30.0;
	3296	 2184	 0.009964	 0.01824	 0.0118	 1379	 1379	 1379	 0.0	 0.0	 1	 -30.0	 30.0;
	3709	 2184	 0.002217	 0.004059	 0.0026	 6195	 6195	 6195	 0.0	 0.0	 1	 -30.0	 30.0;
	4806	 2184	 0.008296	 0.015186	 0.0096	 1656	 1656	 1656	 0.0	 0.0	 1	 -30.0	 30.0;
	2187	 2184	 0.000252	 0.00252	 0.0011	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	4806	 2184	 0.006551	 0.01285	 0.0112	 1987	 1987	 1987	 0.0	 0.0	 1	 -30.0	 30.0;
	4806	 2184	 0.004283	 0.01033	 0.0111	 2563	 2563	 2563	 0.0	 0.0	 1	 -30.0	 30.0;
	2325	 2185	 0.000158	 0.000593	 0.0688	 50437	 50437	 50437	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 2185	 0.000336	 0.001304	 0.162	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 2185	 4e-05	 0.000237	 0.0334	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3963	 2185	 0.000296	 0.002667	 0.1863	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2324	 2185	 0.000362	 0.000664	 0.0466	 40928	 40928	 40928	 0.0	 0.0	 1	 -30.0	 30.0;
	3964	 2185	 0.000435	 0.001659	 0.3351	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 2186	 0.017284	 0.06321	 0.0232	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	5414	 2188	 0.007055	 0.022676	 0.0002	 1207	 1207	 1207	 0.0	 0.0	 1	 -30.0	 30.0;
	3924	 2189	 0.083648	 0.211892	 0.0024	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	5431	 2191	 0.000123	 0.001235	 0.0002	 27888	 27888	 27888	 0.0	 0.0	 1	 -30.0	 30.0;
	5415	 2192	 0.000988	 0.002469	 0.0	 9817	 9817	 9817	 0.0	 0.0	 1	 -30.0	 30.0;
	2804	 2195	 0.001975	 0.004938	 0.0	 5585	 5585	 5585	 0.0	 0.0	 1	 -30.0	 30.0;
	2198	 2196	 2e-05	 0.000198	 0.0233	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3676	 2196	 0.000237	 0.002272	 0.0081	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3676	 2196	 0.000257	 0.002449	 0.0081	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2199	 2196	 2e-05	 0.000198	 0.0132	 870.0	 870.0	 870.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2200	 2197	 1e-05	 0.0001	 0.0462	 895.0	 895.0	 895.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3908	 2197	 0.001143	 0.011399	 0.2946	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3908	 2197	 0.001087	 0.012375	 0.2513	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3813	 2201	 0.043336	 0.109095	 0.0015	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	4928	 2201	 0.028471	 0.078861	 0.0264	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	5764	 2203	 0.019904	 0.082892	 0.001	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	2990	 2204	 0.010582	 0.026455	 0.0003	 1037	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	3138	 2205	 0.000879	 0.0037	 0.085	 8140	 8140	 8140	 0.0	 0.0	 1	 -30.0	 30.0;
	5416	 2205	 0.000533	 0.003556	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3137	 2205	 0.000869	 0.003437	 0.0851	 8731	 8731	 8731	 0.0	 0.0	 1	 -30.0	 30.0;
	4022	 2206	 0.031746	 0.082389	 0.001	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	3133	 2209	 0.004444	 0.028148	 0.0211	 1109	 1109	 1109	 0.0	 0.0	 1	 -30.0	 30.0;
	5419	 2210	 0.073066	 0.199043	 0.0022	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5422	 2211	 0.02066	 0.056185	 0.0006	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	2503	 2212	 0.082892	 0.15999	 0.0017	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	2872	 2214	 0.047115	 0.08642	 0.0017	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	5176	 2214	 0.021164	 0.132275	 0.0017	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	5180	 2214	 0.036281	 0.13681	 0.0017	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 2216	 0.000316	 0.002153	 0.004	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5421	 2215	 0.000316	 0.002153	 0.004	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4807	 2219	 0.056941	 0.156211	 0.0073	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	5424	 2219	 0.078861	 0.176619	 0.0019	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	2582	 2221	 4e-05	 0.000237	 0.0	 483.0	 483.0	 483.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2842	 2222	 0.002897	 0.014412	 0.0002	 2069	 2069	 2069	 0.0	 0.0	 1	 -30.0	 30.0;
	2469	 2224	 0.000852	 0.008636	 0.2224	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4977	 2224	 0.001288	 0.013033	 0.335	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2225	 1496	 0.000595	 0.001089	 0.0	 25273	 25273	 25273	 0.0	 0.0	 1	 -30.0	 30.0;
	4166	 2225	 0.032099	 0.135679	 0.007	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 2225	 0.000988	 0.003951	 0.0002	 8499	 8499	 8499	 0.0	 0.0	 1	 -30.0	 30.0;
	5426	 2226	 0.002872	 0.01227	 0.0183	 2414	 2414	 2414	 0.0	 0.0	 1	 -30.0	 30.0;
	5059	 2227	 0.026959	 0.073318	 0.0009	 390	 390	 390	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 2228	 2e-05	 0.000198	 0.001	 393.0	 393.0	 393.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2501	 2230	 0.06324	 0.176367	 0.002	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	2523	 2230	 0.024943	 0.07735	 0.001	 375	 375	 375	 0.0	 0.0	 1	 -30.0	 30.0;
	3764	 2231	 0.014412	 0.039305	 0.0415	 727	 727	 727	 0.0	 0.0	 1	 -30.0	 30.0;
	3764	 2231	 0.01421	 0.039405	 0.0442	 727	 727	 727	 0.0	 0.0	 1	 -30.0	 30.0;
	2994	 2232	 0.033827	 0.086667	 0.0006	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	3836	 2232	 0.017407	 0.111728	 0.0013	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5065	 2232	 0.020148	 0.125259	 0.0092	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 2232	 0.035926	 0.102716	 0.0011	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	2586	 2233	 0.001541	 0.010291	 0.0238	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3947	 2233	 0.000178	 0.001225	 0.002	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5062	 2233	 0.002489	 0.016612	 0.0304	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5851	 2233	 0.002805	 0.01282	 0.0223	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2586	 2233	 0.001541	 0.010252	 0.0192	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5695	 2233	 0.000158	 0.001106	 0.002	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3764	 2234	 0.022928	 0.058881	 0.0013	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 2236	 0.007284	 0.044321	 0.0059	 718	 718	 718	 0.0	 0.0	 1	 -30.0	 30.0;
	3521	 2236	 0.010124	 0.058519	 0.05	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 2236	 0.00716	 0.044198	 0.0059	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	4015	 2237	 0.02192	 0.049131	 0.001	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	4781	 2238	 0.00243	 0.01357	 0.0248	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3489	 2239	 0.061365	 0.112327	 0.001	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	3489	 2239	 0.062911	 0.115158	 0.001	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	2859	 2239	 0.019652	 0.054296	 0.0006	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	5527	 2241	 0.001402	 0.005452	 0.0101	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4027	 2242	 0.012346	 0.057949	 0.1202	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	3326	 2243	 0.011852	 0.031358	 0.0015	 887	 887	 887	 0.0	 0.0	 1	 -30.0	 30.0;
	3459	 2243	 0.006889	 0.020272	 0.001	 1388	 1388	 1388	 0.0	 0.0	 1	 -30.0	 30.0;
	2570	 2245	 0.00214	 0.024723	 0.5545	 1286	 1286	 1286	 0.0	 0.0	 1	 -30.0	 30.0;
	3153	 2245	 0.00338	 0.034294	 0.8866	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	3230	 2245	 0.000229	 0.002465	 0.0549	 1487.0	 1487.0	 1487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4918	 2245	 0.000561	 0.006198	 0.1473	 1731.0	 1731.0	 1731.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3154	 2245	 0.00338	 0.034294	 0.8866	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 2247	 0.005533	 0.010128	 0.0	 2636	 2636	 2636	 0.0	 0.0	 1	 -30.0	 30.0;
	2782	 2248	 0.008535	 0.038929	 0.0678	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2902	 2248	 0.001106	 0.005136	 0.0081	 5892	 5892	 5892	 0.0	 0.0	 1	 -30.0	 30.0;
	2396	 2249	 0.099521	 0.25296	 0.0029	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	4646	 2250	 0.031111	 0.078642	 0.0067	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	4769	 2250	 0.038272	 0.101975	 0.0044	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	5426	 2251	 5e-05	 0.000227	 0.0002	 130845	 130845	 130845	 0.0	 0.0	 1	 -30.0	 30.0;
	2487	 2253	 0.042832	 0.179894	 0.0022	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	3615	 2255	 0.003081	 0.020109	 0.0375	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5474	 2255	 0.000533	 0.003536	 0.0061	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3898	 2256	 0.007559	 0.0194	 0.0002	 1461	 1461	 1461	 0.0	 0.0	 1	 -30.0	 30.0;
	4829	 2258	 0.001067	 0.004306	 0.08	 6978	 6978	 6978	 0.0	 0.0	 1	 -30.0	 30.0;
	4828	 2257	 0.001067	 0.004306	 0.08	 6978	 6978	 6978	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 2259	 0.004059	 0.007429	 0.0057	 3593	 3593	 3593	 0.0	 0.0	 1	 -30.0	 30.0;
	2271	 2261	 0.004662	 0.008534	 0.0039	 3315	 3315	 3315	 0.0	 0.0	 1	 -30.0	 30.0;
	2620	 2262	 0.066566	 0.17284	 0.0022	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 2262	 0.090249	 0.228773	 0.0026	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5647	 2263	 0.006444	 0.012667	 0.0036	 2205	 2205	 2205	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 2264	 0.001936	 0.01284	 0.0243	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5292	 2264	 0.001363	 0.015427	 0.0445	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4648	 2265	 0.047901	 0.15	 0.007	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	5612	 2265	 0.014284	 0.08858	 0.0049	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	4417	 2265	 0.001926	 0.018247	 0.1021	 1653	 1653	 1653	 0.0	 0.0	 1	 -30.0	 30.0;
	5268	 2265	 0.005037	 0.03142	 0.0017	 953	 953	 953	 0.0	 0.0	 1	 -30.0	 30.0;
	4332	 2268	 0.012346	 0.051146	 0.0006	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	5429	 2269	 0.000233	 0.00156	 0.003	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3147	 2270	 0.017989	 0.07546	 0.0069	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	2207	 2271	 0.007901	 0.039506	 0.0032	 797	 797	 797	 0.0	 0.0	 1	 -30.0	 30.0;
	2183	 2272	 0.000691	 0.003852	 0.0071	 320.0	 320.0	 320.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2205	 2272	 0.000454	 0.003121	 0.0061	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5069	 2272	 0.001896	 0.011022	 0.0284	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2182	 2272	 0.000514	 0.002331	 0.0116	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2205	 2272	 0.000474	 0.003101	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5068	 2272	 0.002272	 0.011062	 0.0263	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4487	 2273	 0.016982	 0.096271	 0.001	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	5431	 2274	 0.000123	 0.001235	 0.0002	 27888	 27888	 27888	 0.0	 0.0	 1	 -30.0	 30.0;
	4022	 2275	 0.009423	 0.017248	 0.0002	 1548	 1548	 1548	 0.0	 0.0	 1	 -30.0	 30.0;
	4022	 2275	 0.009423	 0.017248	 0.0002	 1548	 1548	 1548	 0.0	 0.0	 1	 -30.0	 30.0;
	3410	 2279	 0.05506	 0.100786	 0.001	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	3567	 2280	 0.044092	 0.119929	 0.0015	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	3243	 2282	 5.9e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4706	 2282	 5.9e-05	 0.001126	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4705	 2281	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5688	 2283	 0.028471	 0.072562	 0.0008	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 2285	 0.038395	 0.099136	 0.0047	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	4592	 2285	 0.034444	 0.110123	 0.008	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	5432	 2287	 0.01159	 0.031998	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	4784	 2288	 0.068783	 0.23356	 0.0027	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	3802	 2288	 0.032754	 0.111363	 0.0013	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	4859	 2289	 0.00081	 0.008193	 0.2108	 1694.0	 1694.0	 1694.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2607	 2290	 0.011482	 0.031111	 0.0015	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	3226	 2290	 0.037407	 0.100864	 0.0047	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	2827	 2291	 0.000756	 0.002016	 0.0	 13714	 13714	 13714	 0.0	 0.0	 1	 -30.0	 30.0;
	3414	 2291	 0.02287	 0.041864	 0.0004	 619	 619	 619	 0.0	 0.0	 1	 -30.0	 30.0;
	4567	 2291	 0.089947	 0.230537	 0.003	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	5616	 2291	 0.196901	 0.539708	 0.006	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	2542	 2292	 0.002528	 0.016731	 0.0304	 469.0	 469.0	 469.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 2292	 4.8e-05	 8.8e-05	 0.0051	 308785	 308785	 308785	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 2292	 0.008988	 0.060563	 0.1043	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 2293	 0.001008	 0.002016	 0.0	 12712	 12712	 12712	 0.0	 0.0	 1	 -30.0	 30.0;
	3292	 2297	 0.058176	 0.132376	 0.0043	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	5745	 2299	 0.073822	 0.164928	 0.0026	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	5831	 2299	 0.00252	 0.007055	 0.0001	 4060	 4060	 4060	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 2300	 0.065256	 0.259259	 0.0031	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	3308	 2301	 0.085132	 0.155833	 0.0058	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 2301	 0.067432	 0.123433	 0.0032	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	5300	 2302	 0.038284	 0.070078	 0.0007	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	2732	 2303	 0.013333	 0.026667	 0.0012	 997	 997	 997	 0.0	 0.0	 1	 -30.0	 30.0;
	2342	 2305	 0.018148	 0.036296	 0.0016	 732	 732	 732	 0.0	 0.0	 1	 -30.0	 30.0;
	3869	 2305	 0.018148	 0.036296	 0.0016	 732	 732	 732	 0.0	 0.0	 1	 -30.0	 30.0;
	5622	 2305	 0.082222	 0.183951	 0.0084	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	2494	 2307	 0.009574	 0.018896	 0.0254	 1436	 1436	 1436	 0.0	 0.0	 1	 -30.0	 30.0;
	3104	 2307	 0.005442	 0.014386	 0.0163	 1978	 1978	 1978	 0.0	 0.0	 1	 -30.0	 30.0;
	3858	 2307	 0.013855	 0.025362	 0.0002	 1053	 1053	 1053	 0.0	 0.0	 1	 -30.0	 30.0;
	5059	 2307	 0.097178	 0.252708	 0.0075	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	5615	 2307	 0.007256	 0.030637	 0.0008	 966	 966	 966	 0.0	 0.0	 1	 -30.0	 30.0;
	3858	 2307	 0.014556	 0.026645	 0.0002	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	5614	 2307	 0.007307	 0.030738	 0.0009	 963	 963	 963	 0.0	 0.0	 1	 -30.0	 30.0;
	3401	 2307	 0.005795	 0.018392	 0.0009	 1578	 1578	 1578	 0.0	 0.0	 1	 -30.0	 30.0;
	2637	 2308	 0.002193	 0.014716	 0.0263	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3279	 2308	 0.001323	 0.00883	 0.0162	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2286	 2309	 0.039557	 0.087679	 0.001	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	4765	 2309	 0.04258	 0.09423	 0.001	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5533	 2311	 0.013102	 0.035525	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	3857	 2312	 0.001481	 0.007072	 0.0121	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4151	 2312	 0.001956	 0.013136	 0.0243	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2922	 2313	 0.067523	 0.184429	 0.0021	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 2313	 0.073056	 0.133728	 0.0043	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5033	 2313	 0.065508	 0.271101	 0.0034	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	5033	 2313	 0.065508	 0.271101	 0.0034	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	2519	 2314	 0.011	 0.056595	 0.1027	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4869	 2315	 0.038574	 0.10199	 0.0201	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	3218	 2316	 0.010222	 0.025914	 0.0013	 1067	 1067	 1067	 0.0	 0.0	 1	 -30.0	 30.0;
	4129	 2317	 0.005795	 0.014361	 0.0135	 1907	 1907	 1907	 0.0	 0.0	 1	 -30.0	 30.0;
	4517	 2317	 0.006551	 0.016125	 0.0152	 1697	 1697	 1697	 0.0	 0.0	 1	 -30.0	 30.0;
	3649	 2318	 0.02066	 0.052154	 0.0006	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	5434	 2319	 0.012716	 0.052469	 0.0026	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 2320	 0.026984	 0.068808	 0.0022	 412	 412	 412	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 2323	 0.002383	 0.006457	 0.0003	 4316	 4316	 4316	 0.0	 0.0	 1	 -30.0	 30.0;
	4389	 2326	 0.028219	 0.194004	 0.0023	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	5393	 2327	 0.000691	 0.004563	 0.0081	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3084	 2329	 0.084656	 0.181406	 0.002	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	5439	 2330	 0.007332	 0.024842	 0.0003	 1107	 1107	 1107	 0.0	 0.0	 1	 -30.0	 30.0;
	3195	 2333	 0.07609	 0.171076	 0.0187	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3247	 2333	 0.036533	 0.093726	 0.001	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	3415	 2334	 0.069035	 0.175359	 0.002	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	4612	 2334	 0.019501	 0.079516	 0.0085	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	4701	 2334	 0.095742	 0.282691	 0.0062	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	5571	 2334	 0.013605	 0.037541	 0.0019	 740	 740	 740	 0.0	 0.0	 1	 -30.0	 30.0;
	3415	 2333	 0.066264	 0.168304	 0.0019	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	4612	 2333	 0.019652	 0.080625	 0.0102	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	4253	 2335	 0.002449	 0.016336	 0.0354	 479.0	 479.0	 479.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 2335	 0.006461	 0.021728	 0.0385	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4253	 2335	 0.002568	 0.017146	 0.0405	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4574	 2336	 0.000457	 0.005035	 0.1458	 1841.0	 1841.0	 1841.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3064	 2337	 0.059753	 0.161605	 0.0077	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	3469	 2337	 0.041728	 0.105802	 0.005	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2858	 2338	 0.110355	 0.310658	 0.0037	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	2428	 2339	 0.004283	 0.008566	 0.0001	 3176	 3176	 3176	 0.0	 0.0	 1	 -30.0	 30.0;
	2888	 2340	 0.029479	 0.121945	 0.0015	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	4442	 2340	 0.076594	 0.160242	 0.0019	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	2888	 2340	 0.02973	 0.124717	 0.0016	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	5821	 2341	 0.04258	 0.079617	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	3353	 2343	 0.015243	 0.050617	 0.0006	 559	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 2343	 0.055984	 0.153691	 0.0018	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 2344	 0.017561	 0.045906	 0.0035	 601	 601	 601	 0.0	 0.0	 1	 -30.0	 30.0;
	5099	 2344	 0.011842	 0.029982	 0.0	 916	 916	 916	 0.0	 0.0	 1	 -30.0	 30.0;
	2881	 2345	 0.003	 0.013517	 0.0243	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 2345	 0.003812	 0.013017	 0.0213	 2283	 2283	 2283	 0.0	 0.0	 1	 -30.0	 30.0;
	2572	 2347	 0.020161	 0.05458	 0.0192	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	2978	 2347	 0.012963	 0.036667	 0.0084	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	4299	 2347	 0.015556	 0.039877	 0.007	 709	 709	 709	 0.0	 0.0	 1	 -30.0	 30.0;
	2572	 2347	 0.020123	 0.054444	 0.0187	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	4300	 2347	 0.015383	 0.039642	 0.007	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	4619	 2348	 0.043333	 0.109877	 0.0079	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	2572	 2347	 0.020247	 0.054568	 0.019	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	4018	 2352	 0.006223	 0.016956	 0.0002	 1684	 1684	 1684	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 2353	 0.014568	 0.046543	 0.0023	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	4350	 2353	 0.079753	 0.250247	 0.0123	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	2650	 2354	 0.021422	 0.075067	 0.0243	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	2901	 2354	 0.0252	 0.085911	 0.0252	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 2356	 0.085412	 0.289746	 0.0034	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	5762	 2357	 0.048518	 0.128025	 0.006	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 2358	 0.004283	 0.008314	 0.0117	 3252	 3252	 3252	 0.0	 0.0	 1	 -30.0	 30.0;
	5195	 2359	 0.010617	 0.028518	 0.0013	 977	 977	 977	 0.0	 0.0	 1	 -30.0	 30.0;
	4344	 2361	 0.035525	 0.123457	 0.0069	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	5443	 2362	 0.000123	 0.001235	 0.0002	 23932	 23932	 23932	 0.0	 0.0	 1	 -30.0	 30.0;
	5444	 2363	 0.097758	 0.229025	 0.0025	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 2374	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 2373	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 2372	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 2371	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 2370	 2e-06	 0.001244	 0.0	 24882	 24882	 24882	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 2369	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2636	 2375	 0.081381	 0.248173	 0.0031	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	3896	 2375	 0.003779	 0.012346	 0.0161	 2356	 2356	 2356	 0.0	 0.0	 1	 -30.0	 30.0;
	5426	 2375	 0.016881	 0.062963	 0.0177	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3896	 2375	 0.010078	 0.040514	 0.0022	 729	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	3279	 2376	 0.002449	 0.011141	 0.0203	 293.0	 293.0	 293.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4135	 2376	 0.000672	 0.003141	 0.0051	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 2377	 0.01285	 0.027463	 0.0004	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	2759	 2378	 0.034014	 0.08642	 0.0017	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	4018	 2378	 0.033006	 0.107836	 0.0204	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	3113	 2380	 0.056412	 0.18453	 0.0021	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	3552	 2380	 0.012195	 0.032225	 0.0364	 857	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	3714	 2380	 0.105518	 0.344898	 0.0039	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	5446	 2381	 0.053414	 0.145629	 0.0017	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	3699	 2381	 0.048627	 0.130511	 0.0068	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5345	 2382	 0.001008	 0.00252	 0.001	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	3666	 2384	 0.03351	 0.142857	 0.0043	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	2513	 2385	 0.039078	 0.106576	 0.0012	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	2593	 2386	 0.006299	 0.01159	 0.0125	 2239	 2239	 2239	 0.0	 0.0	 1	 -30.0	 30.0;
	3666	 2386	 0.038045	 0.104812	 0.0198	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	4900	 2387	 0.108163	 0.234492	 0.0027	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	3303	 2388	 0.001008	 0.002771	 0.0001	 10014	 10014	 10014	 0.0	 0.0	 1	 -30.0	 30.0;
	4990	 2389	 0.02318	 0.060972	 0.0007	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	2753	 2391	 0.011386	 0.020842	 0.0153	 1281	 1281	 1281	 0.0	 0.0	 1	 -30.0	 30.0;
	3641	 2391	 0.033485	 0.091333	 0.001	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	2393	 2392	 0.000454	 0.001209	 0.0	 23551	 23551	 23551	 0.0	 0.0	 1	 -30.0	 30.0;
	5471	 2392	 0.070043	 0.23356	 0.0025	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	2910	 2393	 0.102797	 0.260771	 0.0029	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	3331	 2393	 0.078861	 0.267826	 0.0031	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	5546	 2393	 0.053918	 0.183422	 0.0021	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	2910	 2393	 0.103049	 0.261275	 0.0029	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	5547	 2393	 0.054926	 0.185941	 0.0021	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2825	 2394	 0.057697	 0.12522	 0.0002	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	4923	 2395	 0.058453	 0.120433	 0.0013	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	2503	 2396	 0.07609	 0.241875	 0.0029	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	2645	 2397	 0.098765	 0.239607	 0.0026	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	2780	 2398	 0.015672	 0.037591	 0.0066	 747	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	2780	 2398	 0.015672	 0.037591	 0.0066	 747	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	3325	 2400	 0.000252	 0.00126	 0.0	 23670	 23670	 23670	 0.0	 0.0	 1	 -30.0	 30.0;
	3851	 2400	 0.024439	 0.084656	 0.0	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	5456	 2401	 0.000296	 0.000751	 0.001	 38032	 38032	 38032	 0.0	 0.0	 1	 -30.0	 30.0;
	3014	 2402	 0.008314	 0.024691	 0.0305	 1168	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	3679	 2402	 0.01033	 0.044848	 0.0	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	3722	 2402	 0.003145	 0.005757	 0.0079	 4637	 4637	 4637	 0.0	 0.0	 1	 -30.0	 30.0;
	5651	 2402	 0.005039	 0.021416	 0.0002	 1383	 1383	 1383	 0.0	 0.0	 1	 -30.0	 30.0;
	3679	 2402	 0.011363	 0.047241	 0.0047	 626	 626	 626	 0.0	 0.0	 1	 -30.0	 30.0;
	4704	 2404	 5.9e-05	 0.000198	 0.0091	 148594	 148594	 148594	 0.0	 0.0	 1	 -30.0	 30.0;
	4704	 2403	 4e-05	 0.000198	 0.0051	 151981	 151981	 151981	 0.0	 0.0	 1	 -30.0	 30.0;
	5457	 2405	 0.069892	 0.190653	 0.0021	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 2406	 0.025556	 0.064691	 0.0032	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	2984	 2406	 0.041543	 0.107901	 0.0316	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	5736	 2407	 0.02318	 0.06324	 0.0007	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	4720	 2408	 0.018645	 0.078357	 0.001	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	2413	 2409	 0.000123	 0.00037	 0.0	 77773	 77773	 77773	 0.0	 0.0	 1	 -30.0	 30.0;
	4541	 2409	 0.014198	 0.037654	 0.0019	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	3216	 2410	 0.003779	 0.007559	 0.0052	 3391	 3391	 3391	 0.0	 0.0	 1	 -30.0	 30.0;
	5808	 2412	 0.113379	 0.252457	 0.003	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 2414	 0.044848	 0.131519	 0.0015	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	5768	 2415	 0.036029	 0.081381	 0.0009	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	4836	 2416	 0.005432	 0.014321	 0.0006	 2105	 2105	 2105	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 2416	 0.004815	 0.012222	 0.0006	 2632	 2632	 2632	 0.0	 0.0	 1	 -30.0	 30.0;
	3163	 2417	 8e-05	 0.000147	 0.0091	 184947	 184947	 184947	 0.0	 0.0	 1	 -30.0	 30.0;
	3163	 2418	 8.7e-05	 0.00016	 0.0091	 169954	 169954	 169954	 0.0	 0.0	 1	 -30.0	 30.0;
	5349	 2419	 0.014941	 0.041572	 0.0005	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	5463	 2420	 0.00019	 0.00062	 0.001	 48031	 48031	 48031	 0.0	 0.0	 1	 -30.0	 30.0;
	4219	 2422	 0.085916	 0.238095	 0.0037	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	4219	 2422	 0.091207	 0.235828	 0.0041	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5454	 2423	 0.00284	 0.005802	 0.0003	 4599	 4599	 4599	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 2424	 0.045603	 0.183422	 0.0021	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2513	 2424	 0.053918	 0.137062	 0.0016	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	3369	 2424	 0.004031	 0.011086	 0.0002	 2503	 2503	 2503	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 2424	 0.05291	 0.143109	 0.0016	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	5774	 2424	 0.026203	 0.067523	 0.0007	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	2513	 2424	 0.051146	 0.139582	 0.0016	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	2597	 2426	 0.003062	 0.020365	 0.0375	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2785	 2426	 0.000435	 0.002607	 0.0051	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2785	 2425	 0.000494	 0.002923	 0.0051	 463.0	 463.0	 463.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5606	 2427	 0.057697	 0.147392	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	3010	 2428	 0.047921	 0.111968	 0.0059	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 2428	 0.100781	 0.231293	 0.0058	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	4719	 2428	 0.038297	 0.097002	 0.0011	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	4856	 2428	 0.190843	 0.349335	 0.0091	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	3011	 2429	 0.00239	 0.015842	 0.0284	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3083	 2429	 0.002765	 0.018548	 0.0344	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4474	 2429	 0.005539	 0.038098	 0.0719	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4907	 2429	 0.005116	 0.034252	 0.0628	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5429	 2429	 0.004306	 0.019919	 0.0354	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2431	 2430	 0.027967	 0.075435	 0.0039	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	4254	 2432	 0.016881	 0.043084	 0.0054	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 2432	 0.004913	 0.025044	 0.0229	 1192	 1192	 1192	 0.0	 0.0	 1	 -30.0	 30.0;
	5316	 2431	 0.023432	 0.09801	 0.0054	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	5462	 2432	 0.027463	 0.074326	 0.0009	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 2431	 0.016125	 0.052658	 0.0012	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	5491	 2431	 0.016629	 0.057445	 0.0013	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	5535	 2431	 0.012673	 0.053792	 0.0037	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	4254	 2432	 0.021466	 0.053616	 0.0102	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 2432	 0.005367	 0.025724	 0.0279	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	4254	 2432	 0.023961	 0.054497	 0.0097	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 2433	 0.007802	 0.036069	 0.0633	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 2433	 0.000257	 0.00164	 0.003	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5711	 2433	 0.005077	 0.023921	 0.0425	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4394	 2434	 0.066767	 0.182162	 0.0021	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	4682	 2434	 0.074326	 0.20131	 0.0023	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 2435	 0.096498	 0.218443	 0.0024	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5448	 2435	 0.043336	 0.179138	 0.0022	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	5715	 2435	 0.036785	 0.151927	 0.0019	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	2968	 2437	 0.000514	 0.0048	 0.0172	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 2436	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3313	 2438	 0.097279	 0.215092	 0.0025	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 2438	 0.01326	 0.024272	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	4915	 2440	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	4915	 2439	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 2441	 0.103301	 0.230033	 0.003	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	5705	 2441	 0.040816	 0.090955	 0.001	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	3794	 2442	 0.089695	 0.185185	 0.002	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	4027	 2442	 0.078055	 0.318443	 0.0378	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	4364	 2442	 0.030206	 0.055292	 0.0006	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	5236	 2442	 0.043059	 0.174679	 0.0345	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	5761	 2442	 0.000252	 0.00252	 0.0007	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5465	 2444	 0.023935	 0.065508	 0.0007	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	2596	 2445	 0.055178	 0.140086	 0.0016	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	2596	 2446	 0.050643	 0.139834	 0.0016	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	4777	 2448	 0.087176	 0.292265	 0.0013	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	5563	 2448	 0.057949	 0.156966	 0.0018	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	5150	 2447	 0.067271	 0.207861	 0.0023	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 2447	 0.014412	 0.037516	 0.0007	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	5130	 2448	 0.013102	 0.035903	 0.0007	 796	 796	 796	 0.0	 0.0	 1	 -30.0	 30.0;
	5545	 2449	 0.010533	 0.0368	 0.0121	 826	 826	 826	 0.0	 0.0	 1	 -30.0	 30.0;
	3505	 2450	 0.011206	 0.050285	 0.0899	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3901	 2451	 0.013857	 0.038045	 0.0004	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	3901	 2451	 0.014361	 0.04006	 0.0005	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 2452	 0.023951	 0.060741	 0.0029	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	5449	 2454	 0.000176	 0.000504	 0.0	 56971	 56971	 56971	 0.0	 0.0	 1	 -30.0	 30.0;
	3420	 2455	 0.048123	 0.193752	 0.0027	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	2568	 2458	 0.061225	 0.151675	 0.0027	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4378	 2458	 0.064374	 0.150894	 0.0034	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	2564	 2459	 0.062716	 0.162222	 0.0075	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	3093	 2459	 0.070988	 0.180741	 0.0086	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	4163	 2459	 0.020617	 0.056543	 0.0028	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	4216	 2459	 0.00216	 0.013605	 0.0006	 2157	 2157	 2157	 0.0	 0.0	 1	 -30.0	 30.0;
	5443	 2459	 0.01716	 0.052839	 0.0026	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	5679	 2459	 0.019012	 0.048642	 0.0023	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	4215	 2459	 0.002148	 0.013568	 0.0006	 2163	 2163	 2163	 0.0	 0.0	 1	 -30.0	 30.0;
	4654	 2461	 0.071816	 0.131457	 0.0011	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 2461	 0.006047	 0.011842	 0.0001	 2288	 2288	 2288	 0.0	 0.0	 1	 -30.0	 30.0;
	5466	 2462	 2e-05	 0.000198	 0.001	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3338	 2464	 0.060469	 0.156715	 0.0017	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	3175	 2465	 0.019652	 0.050894	 0.0006	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	3651	 2466	 0.032185	 0.086951	 0.141	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	5039	 2466	 0.042086	 0.112951	 0.0054	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	3397	 2468	 0.001975	 0.013235	 0.0309	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3926	 2468	 0.001284	 0.00879	 0.0162	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4977	 2469	 0.002119	 0.02151	 0.5545	 1476	 1476	 1476	 0.0	 0.0	 1	 -30.0	 30.0;
	4242	 2470	 0.062716	 0.114815	 0.004	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	4892	 2470	 0.005556	 0.013827	 0.0006	 2035	 2035	 2035	 0.0	 0.0	 1	 -30.0	 30.0;
	5458	 2470	 0.021605	 0.092222	 0.0045	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	3738	 2471	 0.011536	 0.054933	 0.0931	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4570	 2472	 0.001136	 0.014935	 0.5198	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	4570	 2472	 0.001136	 0.014935	 0.517	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 2473	 0.078105	 0.191232	 0.0021	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	4455	 2473	 0.046988	 0.086012	 0.0032	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	4657	 2473	 0.030234	 0.073822	 0.0009	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 2474	 0.027211	 0.070547	 0.0008	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	3636	 2474	 0.028723	 0.073066	 0.0046	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	2491	 2476	 0.002771	 0.007811	 0.0001	 3563	 3563	 3563	 0.0	 0.0	 1	 -30.0	 30.0;
	2491	 2475	 0.003527	 0.010078	 0.0001	 2766	 2766	 2766	 0.0	 0.0	 1	 -30.0	 30.0;
	4566	 2477	 0.049131	 0.140338	 0.0017	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	4089	 2478	 0.023029	 0.09743	 0.0012	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	3853	 2479	 0.000604	 0.001106	 0.0007	 23430	 23430	 23430	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 2479	 0.03225	 0.070043	 0.0	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 2480	 0.152734	 0.410481	 0.0048	 70	 70	 70	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 2481	 0.000504	 0.00126	 0.0	 22412	 22412	 22412	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 2482	 0.009322	 0.017133	 0.0012	 1514	 1514	 1514	 0.0	 0.0	 1	 -30.0	 30.0;
	2823	 2484	 0.053086	 0.158148	 0.0076	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	4269	 2484	 0.044691	 0.113457	 0.0053	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	4611	 2484	 0.004802	 0.013457	 0.0483	 2079	 2079	 2079	 0.0	 0.0	 1	 -30.0	 30.0;
	5115	 2485	 0.024074	 0.061235	 0.0029	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	5192	 2486	 0.003996	 0.027473	 0.0516	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5264	 2486	 0.007111	 0.048909	 0.0921	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2729	 2488	 0.065524	 0.119941	 0.0052	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 2489	 0.06324	 0.16906	 0.0019	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	4755	 2490	 0.15092	 0.310229	 0.0036	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 2490	 0.094558	 0.194381	 0.0024	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 2491	 0.014361	 0.088939	 0.0012	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	3034	 2491	 0.02066	 0.076594	 0.0009	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 2491	 0.014361	 0.090955	 0.0012	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 2492	 0.000124	 0.001383	 0.0051	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3598	 2492	 0.001047	 0.006953	 0.0132	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3782	 2492	 9.9e-05	 0.000277	 0.0284	 104366	 104366	 104366	 0.0	 0.0	 1	 -30.0	 30.0;
	4103	 2492	 0.003417	 0.022696	 0.0425	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3781	 2492	 9.9e-05	 0.000336	 0.0263	 87644	 87644	 87644	 0.0	 0.0	 1	 -30.0	 30.0;
	3780	 2492	 4e-05	 9.9e-05	 0.0	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 2493	 0.044092	 0.121441	 0.0013	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	5288	 2493	 0.023432	 0.063492	 0.0007	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	3592	 2495	 0.004031	 0.008314	 0.0057	 3292	 3292	 3292	 0.0	 0.0	 1	 -30.0	 30.0;
	4687	 2497	 0.042076	 0.100529	 0.0012	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	2725	 2498	 0.026173	 0.067531	 0.0042	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	2719	 2501	 0.103049	 0.262535	 0.0029	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	3009	 2501	 0.029151	 0.079516	 0.0009	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	4080	 2501	 0.065205	 0.153263	 0.0018	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	5167	 2501	 0.002268	 0.006047	 0.0001	 4710	 4710	 4710	 0.0	 0.0	 1	 -30.0	 30.0;
	5467	 2502	 0.012812	 0.023452	 0.0002	 1105	 1105	 1105	 0.0	 0.0	 1	 -30.0	 30.0;
	5449	 2503	 0.058604	 0.159436	 0.018	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 2503	 0.115797	 0.297682	 0.0097	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	2519	 2505	 0.004484	 0.021195	 0.0365	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 2505	 0.00324	 0.014894	 0.0243	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2781	 2506	 0.084077	 0.265709	 0.005	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	2923	 2507	 0.026914	 0.073457	 0.0034	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	5468	 2508	 5e-05	 0.000252	 0.0	 114924	 114924	 114924	 0.0	 0.0	 1	 -30.0	 30.0;
	4199	 2509	 0.063643	 0.173646	 0.002	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 2509	 0.122197	 0.331066	 0.0038	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	5228	 2509	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 2509	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 2509	 0.123709	 0.335853	 0.0038	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	4994	 2510	 0.04389	 0.107256	 0.0012	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	4994	 2510	 0.062482	 0.114371	 0.0012	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 2511	 0.017133	 0.054926	 0.0006	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	2782	 2512	 0.002143	 0.014358	 0.0264	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2837	 2514	 0.001335	 0.003527	 0.004	 8065	 8065	 8065	 0.0	 0.0	 1	 -30.0	 30.0;
	5731	 2514	 0.102041	 0.278156	 0.0031	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	2836	 2515	 0.007307	 0.021164	 0.0147	 1359	 1359	 1359	 0.0	 0.0	 1	 -30.0	 30.0;
	4398	 2515	 0.006903	 0.018468	 0.0008	 1543	 1543	 1543	 0.0	 0.0	 1	 -30.0	 30.0;
	4009	 2516	 0.029226	 0.079365	 0.0009	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	4009	 2516	 0.025195	 0.079365	 0.001	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	3251	 2518	 0.012018	 0.051298	 0.0006	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	3251	 2518	 0.012094	 0.051474	 0.001	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 2519	 0.00403	 0.018054	 0.0349	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 2519	 0.004484	 0.021156	 0.0365	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4859	 2520	 0.000557	 0.007335	 0.2533	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2719	 2523	 0.020887	 0.068682	 0.0015	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	4777	 2523	 0.075838	 0.202066	 0.0021	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	5167	 2523	 0.089443	 0.243386	 0.0029	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	5720	 2524	 0.00716	 0.014321	 0.0006	 1856	 1856	 1856	 0.0	 0.0	 1	 -30.0	 30.0;
	2538	 2527	 0.013354	 0.03477	 0.005	 770	 770	 770	 0.0	 0.0	 1	 -30.0	 30.0;
	5469	 2527	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 2528	 0.000116	 0.000212	 0.0142	 128083	 128083	 128083	 0.0	 0.0	 1	 -30.0	 30.0;
	4808	 2529	 0.059012	 0.158642	 0.0077	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 2530	 0.072058	 0.233812	 0.0036	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	2561	 2531	 0.086924	 0.209121	 0.0021	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	5348	 2531	 0.026027	 0.062887	 0.0006	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	2561	 2531	 0.060721	 0.207357	 0.0024	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	2931	 2532	 0.172084	 0.417737	 0.0047	 68	 68	 68	 0.0	 0.0	 1	 -30.0	 30.0;
	2535	 2534	 0.028958	 0.053008	 0.0005	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	2689	 2535	 0.039053	 0.08642	 0.001	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	3662	 2535	 0.033258	 0.078357	 0.001	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	4817	 2535	 0.080306	 0.146998	 0.0012	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	5473	 2535	 0.013983	 0.038095	 0.0005	 750	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	2573	 2536	 0.001327	 0.008873	 0.0466	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4958	 2536	 0.002291	 0.01521	 0.0284	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5472	 2537	 0.000179	 0.000327	 0.0233	 83031	 83031	 83031	 0.0	 0.0	 1	 -30.0	 30.0;
	5760	 2538	 0.03351	 0.083396	 0.0069	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	5469	 2539	 0.013102	 0.034266	 0.0051	 781	 781	 781	 0.0	 0.0	 1	 -30.0	 30.0;
	2708	 2540	 0.012094	 0.058957	 0.0172	 491	 491	 491	 0.0	 0.0	 1	 -30.0	 30.0;
	2896	 2541	 0.004359	 0.018544	 0.0008	 1550	 1550	 1550	 0.0	 0.0	 1	 -30.0	 30.0;
	3158	 2541	 0.030234	 0.08642	 0.001	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	3158	 2541	 0.030234	 0.08642	 0.001	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	3943	 2542	 0.001244	 0.008296	 0.0142	 483.0	 483.0	 483.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4212	 2543	 0.087679	 0.284455	 0.0034	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 2544	 0.008566	 0.026959	 0.0003	 1013	 1013	 1013	 0.0	 0.0	 1	 -30.0	 30.0;
	5477	 2546	 0.004787	 0.014361	 0.0002	 1893	 1893	 1893	 0.0	 0.0	 1	 -30.0	 30.0;
	5506	 2545	 0.00252	 0.007307	 0.0001	 3707	 3707	 3707	 0.0	 0.0	 1	 -30.0	 30.0;
	2973	 2547	 0.115898	 0.248173	 0.0027	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	2973	 2547	 0.072562	 0.248173	 0.0029	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	5475	 2548	 0.005845	 0.012925	 0.0001	 2082	 2082	 2082	 0.0	 0.0	 1	 -30.0	 30.0;
	5476	 2549	 0.091774	 0.167992	 0.0017	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	3685	 2550	 0.042328	 0.173595	 0.001	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 2550	 0.008062	 0.047619	 0.0006	 612	 612	 612	 0.0	 0.0	 1	 -30.0	 30.0;
	4840	 2550	 0.025447	 0.070295	 0.0008	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 2550	 0.017637	 0.056437	 0.0019	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	5694	 2551	 0.010667	 0.034444	 0.0112	 845	 845	 845	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 2552	 0.009857	 0.066884	 0.1266	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	4736	 2552	 0.000632	 0.003931	 0.0243	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4743	 2552	 0.002153	 0.009758	 0.0172	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4178	 2554	 0.063996	 0.163013	 0.0019	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3188	 2555	 0.097758	 0.247518	 0.0089	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	4792	 2556	 0.021482	 0.057407	 0.0032	 495	 495	 495	 0.0	 0.0	 1	 -30.0	 30.0;
	4792	 2556	 0.020494	 0.057654	 0.0026	 496	 496	 496	 0.0	 0.0	 1	 -30.0	 30.0;
	2767	 2557	 0.046107	 0.192996	 0.0083	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	3666	 2558	 0.100277	 0.276896	 0.0031	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	3700	 2558	 0.026707	 0.076342	 0.0009	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	3377	 2559	 0.045926	 0.12358	 0.0058	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	4910	 2559	 0.021235	 0.054691	 0.0026	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	3843	 2560	 0.019174	 0.04447	 0.0006	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 2560	 0.080877	 0.187705	 0.002	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	3648	 2561	 0.113076	 0.249786	 0.0028	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 2561	 0.007811	 0.047871	 0.0006	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	5573	 2561	 0.007307	 0.022172	 0.0002	 1303	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	5848	 2561	 0.075586	 0.24641	 0.0024	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	2630	 2561	 0.011842	 0.072814	 0.001	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	4459	 2562	 0.003279	 0.022637	 0.0415	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 2564	 0.044815	 0.122222	 0.0057	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 2565	 0.000252	 0.00252	 0.0001	 11659	 11659	 11659	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 2566	 0.015621	 0.043084	 0.0005	 645	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	3941	 2567	 0.055933	 0.146888	 0.0	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 2567	 0.031545	 0.104006	 0.0043	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	3105	 2568	 0.089695	 0.165281	 0.0025	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	3825	 2568	 0.049383	 0.126228	 0.0022	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	4081	 2568	 0.090098	 0.249055	 0.0072	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 2568	 0.019425	 0.04898	 0.001	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	5767	 2568	 0.027765	 0.082389	 0.0015	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	5493	 2569	 0.001932	 0.012802	 0.0233	 477.0	 477.0	 477.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3103	 2570	 0.00063	 0.006413	 0.1632	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 2571	 0.014691	 0.049876	 0.0024	 584	 584	 584	 0.0	 0.0	 1	 -30.0	 30.0;
	4792	 2571	 0.042716	 0.14963	 0.0071	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 2572	 0.009753	 0.024074	 0.0133	 1168	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	5710	 2572	 0.010247	 0.025309	 0.0133	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	5479	 2573	 0.000593	 0.003951	 0.0339	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4003	 2574	 0.031998	 0.081129	 0.001	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	4368	 2574	 0.009322	 0.02318	 0.0002	 1147	 1147	 1147	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 2576	 0.000802	 0.002173	 0.0001	 13013	 13013	 13013	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 2577	 0.000198	 0.001699	 0.1731	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3010	 2578	 0.04389	 0.139053	 0.014	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	3010	 2578	 0.04389	 0.139053	 0.014	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	4340	 2579	 0.02088	 0.03822	 0.0012	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 2579	 0.024296	 0.118963	 0.0004	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	5753	 2579	 0.002963	 0.009877	 0.0012	 2532	 2532	 2532	 0.0	 0.0	 1	 -30.0	 30.0;
	5794	 2579	 0.051852	 0.13679	 0.0047	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	5256	 2581	 0.010444	 0.032756	 0.0103	 930	 930	 930	 0.0	 0.0	 1	 -30.0	 30.0;
	5046	 2582	 0.000296	 0.001758	 0.003	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5849	 2582	 0.000356	 0.002054	 0.004	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5670	 2582	 0.006696	 0.029985	 0.0527	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 2583	 0.040247	 0.10963	 0.0052	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	4143	 2583	 0.044815	 0.122346	 0.0057	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	2829	 2584	 0.029136	 0.081605	 0.0037	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	2626	 2585	 0.022963	 0.051728	 0.0023	 566	 566	 566	 0.0	 0.0	 1	 -30.0	 30.0;
	4397	 2585	 0.000988	 0.005926	 0.0863	 5342	 5342	 5342	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 2585	 0.00321	 0.02	 0.0002	 1707	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	4396	 2585	 0.000988	 0.005926	 0.0002	 5342	 5342	 5342	 0.0	 0.0	 1	 -30.0	 30.0;
	5109	 2585	 0.00321	 0.02	 0.0002	 1707	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	2739	 2587	 0.074074	 0.177879	 0.001	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	5752	 2587	 0.074074	 0.177879	 0.001	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3169	 2589	 0.015839	 0.041543	 0.0019	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	5484	 2590	 0.001764	 0.005039	 0.0	 5531	 5531	 5531	 0.0	 0.0	 1	 -30.0	 30.0;
	2986	 2591	 0.031494	 0.0645	 0.0007	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	2833	 2592	 0.000222	 0.002327	 0.0578	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3012	 2592	 0.001565	 0.020568	 0.7076	 1547	 1547	 1547	 0.0	 0.0	 1	 -30.0	 30.0;
	5723	 2592	 0.000914	 0.009875	 0.2238	 1704.0	 1704.0	 1704.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2799	 2592	 0.001641	 0.021544	 0.7451	 1476	 1476	 1476	 0.0	 0.0	 1	 -30.0	 30.0;
	2833	 2592	 0.000229	 0.002313	 0.0578	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3012	 2592	 0.001558	 0.020568	 0.7076	 1547	 1547	 1547	 0.0	 0.0	 1	 -30.0	 30.0;
	2799	 2592	 0.001634	 0.021503	 0.7451	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	3666	 2593	 0.014109	 0.089443	 0.0011	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	3666	 2593	 0.014109	 0.089443	 0.0011	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	5382	 2594	 0.060972	 0.168808	 0.0019	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	5632	 2594	 0.000252	 0.001008	 0.0	 33358	 33358	 33358	 0.0	 0.0	 1	 -30.0	 30.0;
	5486	 2595	 0.021852	 0.059753	 0.0028	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	4404	 2596	 0.036483	 0.090854	 0.0011	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	4414	 2596	 0.050643	 0.140842	 0.0015	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4404	 2596	 0.037995	 0.094835	 0.0011	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	4414	 2596	 0.050643	 0.140842	 0.0015	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	2785	 2597	 0.003378	 0.02242	 0.0415	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 2598	 0.002222	 0.004444	 0.0002	 5979	 5979	 5979	 0.0	 0.0	 1	 -30.0	 30.0;
	2602	 2600	 0.000176	 0.000454	 0.0005	 62462	 62462	 62462	 0.0	 0.0	 1	 -30.0	 30.0;
	4673	 2600	 0.021668	 0.052154	 0.0005	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	5487	 2601	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	3113	 2603	 0.07231	 0.206853	 0.0023	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 2603	 0.04384	 0.122953	 0.0013	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	3113	 2603	 0.072058	 0.206601	 0.0023	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	5488	 2605	 0.026296	 0.071728	 0.0028	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	3573	 2606	 0.171076	 0.313152	 0.0033	 86	 86	 86	 0.0	 0.0	 1	 -30.0	 30.0;
	4448	 2606	 0.025699	 0.065508	 0.0008	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	2877	 2607	 0.075556	 0.205309	 0.0097	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	3226	 2607	 0.048642	 0.131481	 0.0063	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	3348	 2607	 0.058765	 0.152099	 0.0073	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	4073	 2607	 0.087161	 0.224198	 0.0107	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	3412	 2610	 0.04284	 0.091728	 0.0042	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	3409	 2612	 0.071504	 0.176997	 0.0018	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	3621	 2613	 0.039305	 0.102293	 0.0012	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	5033	 2614	 0.116906	 0.242126	 0.0026	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	5457	 2614	 0.03477	 0.072814	 0.0008	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	4792	 2615	 0.021605	 0.091111	 0.0049	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	3360	 2616	 0.011838	 0.02167	 0.0235	 1161	 1161	 1161	 0.0	 0.0	 1	 -30.0	 30.0;
	3978	 2617	 0.033086	 0.089876	 0.0042	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 2617	 0.088642	 0.185679	 0.0079	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3025	 2618	 0.033086	 0.09	 0.0042	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5816	 2618	 0.048889	 0.124321	 0.0059	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 2621	 0.08642	 0.23608	 0.0026	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5094	 2622	 0.018642	 0.050617	 0.0024	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 2623	 0.000756	 0.00252	 0.0001	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	5491	 2623	 0.00068	 0.002268	 0.0001	 12845	 12845	 12845	 0.0	 0.0	 1	 -30.0	 30.0;
	2959	 2624	 0.04515	 0.122222	 0.0025	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5806	 2624	 0.00126	 0.003779	 0.0	 7635	 7635	 7635	 0.0	 0.0	 1	 -30.0	 30.0;
	5807	 2624	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	2931	 2627	 0.010078	 0.04258	 0.0005	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	4587	 2627	 0.009826	 0.041068	 0.0016	 738	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	2832	 2628	 0.003826	 0.018665	 0.0334	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2933	 2628	 0.00077	 0.003536	 0.0066	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4474	 2628	 0.005037	 0.034785	 0.0653	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2832	 2628	 0.003615	 0.01762	 0.0314	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2932	 2628	 0.000711	 0.004583	 0.0081	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 2630	 0.004283	 0.025951	 0.0003	 1157	 1157	 1157	 0.0	 0.0	 1	 -30.0	 30.0;
	2639	 2631	 0.133006	 0.305266	 0.0033	 92	 92	 92	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 2631	 0.129252	 0.306374	 0.004	 92	 92	 92	 0.0	 0.0	 1	 -30.0	 30.0;
	3892	 2631	 0.05039	 0.117158	 0.0013	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	2911	 2632	 0.024074	 0.054198	 0.0024	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 2632	 0.048148	 0.108148	 0.005	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	5492	 2634	 0.009574	 0.017637	 0.0289	 1516	 1516	 1516	 0.0	 0.0	 1	 -30.0	 30.0;
	2790	 2635	 0.066264	 0.166289	 0.0074	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	3139	 2635	 0.035525	 0.091459	 0.0032	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	4604	 2635	 0.020257	 0.117108	 0.0127	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	4604	 2636	 0.020433	 0.117914	 0.0121	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	4135	 2637	 0.002726	 0.018193	 0.0334	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4634	 2637	 0.002596	 0.01165	 0.0203	 326.0	 326.0	 326.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4135	 2637	 0.002726	 0.018193	 0.0334	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 2638	 0.06125	 0.156866	 0.0017	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 2638	 0.035047	 0.090098	 0.001	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	3441	 2639	 0.080121	 0.194255	 0.0021	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	5232	 2640	 0.066012	 0.179894	 0.0	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5504	 2641	 0.003086	 0.008148	 0.0005	 3410	 3410	 3410	 0.0	 0.0	 1	 -30.0	 30.0;
	5835	 2641	 0.017037	 0.044691	 0.0021	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	5534	 2642	 0.001512	 0.003023	 0.0	 8999	 8999	 8999	 0.0	 0.0	 1	 -30.0	 30.0;
	2646	 2645	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5221	 2645	 0.029226	 0.080625	 0.001	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 2646	 0.031746	 0.080121	 0.0009	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	3503	 2647	 0.024439	 0.064752	 0.0016	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	4174	 2647	 0.039305	 0.111363	 0.0012	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	3653	 2647	 0.017385	 0.049383	 0.0006	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	4175	 2650	 0.004507	 0.013102	 0.0043	 2280	 2280	 2280	 0.0	 0.0	 1	 -30.0	 30.0;
	5545	 2650	 0.012933	 0.044356	 0.0144	 684	 684	 684	 0.0	 0.0	 1	 -30.0	 30.0;
	5583	 2650	 0.002711	 0.008889	 0.0032	 3399	 3399	 3399	 0.0	 0.0	 1	 -30.0	 30.0;
	4993	 2651	 0.106828	 0.220207	 0.0024	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	5822	 2651	 0.034575	 0.063288	 0.0007	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	3770	 2652	 0.036543	 0.096173	 0.0045	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	3376	 2653	 0.095238	 0.206097	 0.0	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	3489	 2653	 0.04384	 0.111867	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	4540	 2654	 0.003275	 0.014109	 0.0002	 2100	 2100	 2100	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 2654	 0.01852	 0.033901	 0.0003	 788	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 2655	 0.000198	 0.000909	 0.002	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4148	 2656	 0.036029	 0.15873	 0.0029	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4514	 2656	 0.052658	 0.144117	 0.0016	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	5356	 2656	 0.006551	 0.027211	 0.0003	 1209	 1209	 1209	 0.0	 0.0	 1	 -30.0	 30.0;
	4515	 2657	 0.002252	 0.010509	 0.0187	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 2657	 0.008	 0.03998	 0.0709	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3540	 2658	 0.000109	 0.000494	 0.001	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2719	 2659	 0.054926	 0.133535	 0.0013	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 2659	 0.024439	 0.058957	 0.0006	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	3988	 2660	 0.06576	 0.17939	 0.002	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	3689	 2661	 0.007811	 0.027211	 0.0	 1043	 1043	 1043	 0.0	 0.0	 1	 -30.0	 30.0;
	2594	 2662	 0.022928	 0.094734	 0.0012	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	3531	 2662	 0.039053	 0.144117	 0.0086	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4040	 2662	 0.014865	 0.033006	 0.0004	 816	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	5430	 2662	 0.012094	 0.033006	 0.0004	 840	 840	 840	 0.0	 0.0	 1	 -30.0	 30.0;
	2594	 2662	 0.02318	 0.093978	 0.0013	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	4779	 2663	 0.005827	 0.02703	 0.0476	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3491	 2668	 0.006409	 0.016431	 0.005	 1836	 1836	 1836	 0.0	 0.0	 1	 -30.0	 30.0;
	5689	 2669	 0.024691	 0.067271	 0.0013	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	5690	 2669	 0.026203	 0.066516	 0.0013	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	3512	 2670	 0.039753	 0.104568	 0.005	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	4164	 2670	 0.006259	 0.020988	 0.0013	 1357	 1357	 1357	 0.0	 0.0	 1	 -30.0	 30.0;
	4880	 2670	 0.001481	 0.006667	 0.0288	 4350	 4350	 4350	 0.0	 0.0	 1	 -30.0	 30.0;
	3573	 2674	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	3573	 2673	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	4257	 2675	 0.013102	 0.03477	 0.0004	 819	 819	 819	 0.0	 0.0	 1	 -30.0	 30.0;
	4887	 2675	 0.074326	 0.157218	 0.0017	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4257	 2675	 0.017889	 0.045855	 0.0006	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	4402	 2676	 0.07483	 0.202822	 0.0029	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	5494	 2677	 0.007559	 0.021164	 0.0002	 1354	 1354	 1354	 0.0	 0.0	 1	 -30.0	 30.0;
	3884	 2677	 0.047871	 0.125976	 0.0014	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 2678	 0.001956	 0.020958	 0.0871	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 2679	 0.014613	 0.040816	 0.0005	 702	 702	 702	 0.0	 0.0	 1	 -30.0	 30.0;
	4360	 2682	 0.057823	 0.168178	 0.0102	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	3017	 2683	 0.009136	 0.019259	 0.0062	 1396	 1396	 1396	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 2683	 0.026914	 0.070741	 0.0034	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	5762	 2683	 0.047654	 0.124815	 0.0058	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	3017	 2683	 0.009012	 0.018889	 0.0062	 1422	 1422	 1422	 0.0	 0.0	 1	 -30.0	 30.0;
	3483	 2685	 0.013704	 0.043333	 0.0021	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	4697	 2686	 0.059133	 0.16198	 0.0018	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	5496	 2687	 5.9e-05	 0.000435	 0.0025	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5497	 2688	 0.002593	 0.010741	 0.0005	 2745	 2745	 2745	 0.0	 0.0	 1	 -30.0	 30.0;
	3762	 2689	 0.058026	 0.106216	 0.001	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 2691	 0.036231	 0.098262	 0.0023	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 2692	 0.099622	 0.273217	 0.0149	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	2694	 2693	 0.020988	 0.088518	 0.0045	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	5498	 2693	 1.2e-05	 0.001235	 0.0002	 24050	 24050	 24050	 0.0	 0.0	 1	 -30.0	 30.0;
	3167	 2695	 0.000336	 0.001225	 0.1529	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3883	 2695	 0.000138	 0.00079	 0.1063	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4913	 2695	 0.000138	 0.000889	 0.1215	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 2696	 0.001764	 0.004787	 0.0042	 5788	 5788	 5788	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 2696	 0.001008	 0.003023	 0.003	 9266	 9266	 9266	 0.0	 0.0	 1	 -30.0	 30.0;
	3898	 2698	 0.02066	 0.052406	 0.0006	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	4734	 2698	 0.006551	 0.027463	 0.009	 1078	 1078	 1078	 0.0	 0.0	 1	 -30.0	 30.0;
	4827	 2700	 0.015309	 0.031728	 0.0013	 861	 861	 861	 0.0	 0.0	 1	 -30.0	 30.0;
	4324	 2701	 0.049887	 0.12648	 0.0014	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	3658	 2702	 0.011086	 0.028471	 0.0003	 967	 967	 967	 0.0	 0.0	 1	 -30.0	 30.0;
	3438	 2703	 0.001041	 0.006967	 0.0152	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3175	 2704	 0.076846	 0.267826	 0.0033	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	4058	 2704	 0.000604	 0.001106	 0.0006	 22736	 22736	 22736	 0.0	 0.0	 1	 -30.0	 30.0;
	4667	 2704	 0.071303	 0.194759	 0.0022	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	4059	 2704	 0.000773	 0.001416	 0.0007	 17760	 17760	 17760	 0.0	 0.0	 1	 -30.0	 30.0;
	4898	 2705	 0.019728	 0.057546	 0.0029	 486	 486	 486	 0.0	 0.0	 1	 -30.0	 30.0;
	5206	 2705	 0.006047	 0.020912	 0.0	 1357	 1357	 1357	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 2705	 0.011086	 0.057445	 0.0021	 505	 505	 505	 0.0	 0.0	 1	 -30.0	 30.0;
	3346	 2706	 0.009067	 0.029116	 0.0486	 262.0	 262.0	 262.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2896	 2708	 0.024439	 0.101789	 0.001	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	3840	 2707	 0.040539	 0.128168	 0.0015	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	4614	 2708	 0.087931	 0.279667	 0.0033	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	4865	 2707	 0.025195	 0.159486	 0.0021	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	5399	 2707	 0.009826	 0.047115	 0.001	 614	 614	 614	 0.0	 0.0	 1	 -30.0	 30.0;
	3943	 2709	 0.000701	 0.004599	 0.0082	 484.0	 484.0	 484.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3943	 2709	 0.000705	 0.00463	 0.0083	 484.0	 484.0	 484.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 2711	 0.026959	 0.112875	 0.0023	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	3932	 2712	 0.001956	 0.008691	 0.0248	 3468	 3468	 3468	 0.0	 0.0	 1	 -30.0	 30.0;
	5502	 2713	 0.026543	 0.066296	 0.0031	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	3312	 2715	 0.012496	 0.043621	 0.0734	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3544	 2715	 0.018805	 0.069215	 0.1235	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	3561	 2715	 0.012306	 0.062598	 0.1109	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3312	 2715	 0.00717	 0.042726	 0.0749	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4137	 2716	 0.001627	 0.017031	 0.3812	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5168	 2719	 0.018392	 0.045074	 0.0004	 625	 625	 625	 0.0	 0.0	 1	 -30.0	 30.0;
	5170	 2719	 0.020106	 0.048828	 0.0046	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	3030	 2720	 0.017284	 0.108148	 0.0075	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	4725	 2721	 0.000257	 0.000612	 0.0547	 46632	 46632	 46632	 0.0	 0.0	 1	 -30.0	 30.0;
	4724	 2721	 0.000237	 0.000553	 0.0496	 51447	 51447	 51447	 0.0	 0.0	 1	 -30.0	 30.0;
	4723	 2721	 0.000237	 0.000553	 0.0496	 51447	 51447	 51447	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 2722	 0.000395	 0.005229	 0.1791	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3666	 2723	 0.008062	 0.054926	 0.0006	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	3666	 2723	 0.008062	 0.054926	 0.0006	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	3584	 2725	 0.002963	 0.008642	 0.0024	 3320	 3320	 3320	 0.0	 0.0	 1	 -30.0	 30.0;
	4816	 2725	 0.00679	 0.028642	 0.0034	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	4816	 2725	 0.007284	 0.03037	 0.0028	 971	 971	 971	 0.0	 0.0	 1	 -30.0	 30.0;
	4229	 2726	 0.005017	 0.033521	 0.0607	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3916	 2727	 0.049131	 0.127488	 0.0014	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 2728	 0.001679	 0.007526	 0.0132	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3602	 2729	 0.055595	 0.101765	 0.0043	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	5504	 2730	 0.005926	 0.016173	 0.0008	 1725	 1725	 1725	 0.0	 0.0	 1	 -30.0	 30.0;
	4149	 2731	 0.003275	 0.010582	 0.0002	 2666	 2666	 2666	 0.0	 0.0	 1	 -30.0	 30.0;
	4227	 2734	 0.018025	 0.045679	 0.0021	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 2738	 0.009753	 0.018272	 0.0008	 1465	 1465	 1465	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 2737	 0.003185	 0.008914	 0.0319	 3204	 3204	 3204	 0.0	 0.0	 1	 -30.0	 30.0;
	3679	 2739	 0.054422	 0.127236	 0.0021	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	5650	 2740	 0.000579	 0.001587	 0.0	 17478	 17478	 17478	 0.0	 0.0	 1	 -30.0	 30.0;
	3646	 2743	 0.128484	 0.235189	 0.0033	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	3815	 2744	 0.066264	 0.1678	 0.0019	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	4990	 2744	 0.060217	 0.164021	 0.0019	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	3121	 2745	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4068	 2745	 0.004326	 0.019694	 0.0344	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4992	 2745	 0.003338	 0.015091	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3120	 2745	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4992	 2745	 0.003338	 0.015091	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 2745	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 2746	 0.008818	 0.022172	 0.0	 1238	 1238	 1238	 0.0	 0.0	 1	 -30.0	 30.0;
	3422	 2747	 0.025951	 0.072814	 0.0085	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 2749	 0.000951	 0.003593	 0.0002	 8159	 8159	 8159	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 2750	 0.000138	 0.000593	 0.0	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4730	 2751	 0.041975	 0.106543	 0.0049	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	4786	 2751	 0.034568	 0.094444	 0.024	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	5107	 2751	 0.031111	 0.084938	 0.004	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	4786	 2751	 0.034568	 0.094444	 0.024	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	2846	 2754	 0.15873	 0.35349	 0.0	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	4206	 2754	 0.000756	 0.005291	 0.0001	 5525	 5525	 5525	 0.0	 0.0	 1	 -30.0	 30.0;
	4426	 2754	 0.068531	 0.165961	 0.0018	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 2754	 0.096246	 0.238851	 0.0027	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	5737	 2754	 0.005039	 0.012598	 0.0002	 2177	 2177	 2177	 0.0	 0.0	 1	 -30.0	 30.0;
	4205	 2754	 0.002771	 0.006047	 0.0001	 4439	 4439	 4439	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 2755	 0.007723	 0.032119	 0.0527	 937	 937	 937	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 2755	 0.009541	 0.039585	 0.0648	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5509	 2756	 0.00397	 0.007268	 0.0102	 3460	 3460	 3460	 0.0	 0.0	 1	 -30.0	 30.0;
	3424	 2757	 0.03094	 0.093298	 0.0011	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	4804	 2757	 0.015621	 0.04132	 0.0	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	5506	 2758	 0.000252	 0.001008	 0.0	 27575	 27575	 27575	 0.0	 0.0	 1	 -30.0	 30.0;
	3664	 2759	 0.007055	 0.016629	 0.0007	 1684	 1684	 1684	 0.0	 0.0	 1	 -30.0	 30.0;
	5505	 2761	 0.000705	 0.002973	 0.0001	 9377	 9377	 9377	 0.0	 0.0	 1	 -30.0	 30.0;
	5510	 2762	 0.00252	 0.004787	 0.0001	 6271	 6271	 6271	 0.0	 0.0	 1	 -30.0	 30.0;
	2953	 2763	 0.001519	 0.010582	 0.0162	 510.0	 510.0	 510.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3765	 2763	 0.002216	 0.014805	 0.0273	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2952	 2763	 0.001529	 0.010637	 0.0162	 477.0	 477.0	 477.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3765	 2763	 0.002206	 0.014728	 0.0273	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4069	 2764	 0.000457	 0.006025	 0.2079	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 2764	 0.001856	 0.025166	 0.8563	 1264	 1264	 1264	 0.0	 0.0	 1	 -30.0	 30.0;
	4625	 2765	 0.056941	 0.143613	 0.0016	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	3366	 2766	 0.014865	 0.045855	 0.0002	 695	 695	 695	 0.0	 0.0	 1	 -30.0	 30.0;
	3366	 2766	 0.014865	 0.046107	 0.0002	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	5507	 2767	 0.055178	 0.139834	 0.0016	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 2768	 0.090703	 0.190476	 0.0021	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 2768	 0.006551	 0.017637	 0.0002	 1617	 1617	 1617	 0.0	 0.0	 1	 -30.0	 30.0;
	2841	 2770	 0.013086	 0.045803	 0.0021	 624	 624	 624	 0.0	 0.0	 1	 -30.0	 30.0;
	3261	 2770	 0.005185	 0.031975	 0.0023	 917	 917	 917	 0.0	 0.0	 1	 -30.0	 30.0;
	4285	 2770	 0.015803	 0.053086	 0.0026	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	4411	 2770	 0.039506	 0.113457	 0.0053	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 2770	 0.025802	 0.106914	 0.0057	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	5820	 2770	 0.018519	 0.065679	 0.0036	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	4285	 2770	 0.024815	 0.071975	 0.0032	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	5240	 2770	 0.025679	 0.106543	 0.0055	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	3018	 2771	 0.014914	 0.055309	 0.0896	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	4810	 2771	 0.009383	 0.042607	 0.0759	 276.0	 276.0	 276.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 2772	 0.002597	 0.020332	 0.4202	 1408.0	 1408.0	 1408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 2772	 0.001932	 0.021399	 0.4448	 1391.0	 1391.0	 1391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5502	 2773	 0.020988	 0.052469	 0.0024	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 2773	 0.018025	 0.045926	 0.0021	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	3904	 2775	 0.068783	 0.155959	 0.0021	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	5081	 2775	 0.026707	 0.07483	 0.0008	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 2776	 0.000198	 0.000909	 0.001	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3810	 2777	 0.148778	 0.326556	 0.0036	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	5135	 2777	 0.028924	 0.07672	 0.0001	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 2778	 0.001106	 0.007328	 0.0132	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4009	 2779	 0.028471	 0.074326	 0.0	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	2962	 2780	 0.031973	 0.079441	 0.0041	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 2780	 0.005039	 0.021416	 0.0002	 1383	 1383	 1383	 0.0	 0.0	 1	 -30.0	 30.0;
	5442	 2781	 0.071454	 0.242605	 0.0033	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 2781	 0.018267	 0.062031	 0.0007	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	5453	 2781	 0.018392	 0.06198	 0.0007	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	5599	 2781	 0.022525	 0.13933	 0.0018	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	3330	 2780	 0.005039	 0.021668	 0.0002	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 2781	 0.068531	 0.219955	 0.0026	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	3505	 2782	 0.015488	 0.067417	 0.1205	 298.0	 298.0	 298.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3483	 2784	 0.010247	 0.02037	 0.001	 1330	 1330	 1330	 0.0	 0.0	 1	 -30.0	 30.0;
	4184	 2785	 0.005985	 0.041383	 0.0739	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5814	 2785	 0.000243	 0.001614	 0.003	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5422	 2788	 0.033762	 0.092215	 0.001	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 2789	 0.022147	 0.129554	 0.004	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 2789	 0.023658	 0.133686	 0.0041	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	4604	 2790	 0.064669	 0.118376	 0.0067	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	4071	 2791	 0.054422	 0.143613	 0.0017	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	5449	 2791	 0.074779	 0.202444	 0.0048	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 2791	 0.074049	 0.255959	 0.0301	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	5471	 2791	 0.077123	 0.256362	 0.0254	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	4071	 2791	 0.054422	 0.143865	 0.0017	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	3400	 2792	 0.003737	 0.024798	 0.0456	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5132	 2792	 0.000869	 0.005886	 0.0415	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 2793	 0.119224	 0.218238	 0.002	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 2794	 0.004074	 0.028025	 0.0058	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	4958	 2795	 0.000514	 0.004247	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 2796	 5.9e-05	 0.000474	 0.002	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3381	 2798	 0.004286	 0.020405	 0.0344	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3672	 2798	 0.007625	 0.035378	 0.0668	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3859	 2800	 0.008818	 0.024943	 0.0	 1117	 1117	 1117	 0.0	 0.0	 1	 -30.0	 30.0;
	4200	 2801	 0.042963	 0.084938	 0.0038	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 2802	 0.038045	 0.116402	 0.0013	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	3799	 2803	 0.000252	 0.00252	 0.0002	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	3925	 2803	 0.027715	 0.170824	 0.0132	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 2803	 0.045528	 0.124112	 0.0016	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	3671	 2806	 0.010988	 0.042963	 0.0003	 724	 724	 724	 0.0	 0.0	 1	 -30.0	 30.0;
	3672	 2807	 0.001146	 0.005551	 0.0101	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4924	 2808	 0.097506	 0.263794	 0.0029	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	5457	 2808	 0.054674	 0.112623	 0.0012	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	3700	 2809	 0.00126	 0.00252	 0.0018	 10480	 10480	 10480	 0.0	 0.0	 1	 -30.0	 30.0;
	3512	 2810	 0.033827	 0.143333	 0.0073	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	4177	 2810	 0.012716	 0.034321	 0.0058	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	4380	 2810	 0.004198	 0.017407	 0.003	 1659	 1659	 1659	 0.0	 0.0	 1	 -30.0	 30.0;
	4881	 2811	 0.008296	 0.038795	 0.0648	 309.0	 309.0	 309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4257	 2812	 0.024969	 0.106223	 0.0026	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	5515	 2814	 0.000756	 0.00252	 0.0001	 12969	 12969	 12969	 0.0	 0.0	 1	 -30.0	 30.0;
	3307	 2815	 0.024691	 0.063827	 0.0031	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 2815	 0.019506	 0.052593	 0.0024	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	5037	 2815	 0.034197	 0.093951	 0.0	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 2815	 0.011358	 0.026914	 0.0013	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	5554	 2815	 0.014938	 0.039383	 0.0018	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	5556	 2815	 0.014198	 0.039012	 0.0	 731	 731	 731	 0.0	 0.0	 1	 -30.0	 30.0;
	5570	 2815	 0.036667	 0.116049	 0.0057	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	5036	 2815	 0.034321	 0.094691	 0.0	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	3603	 2816	 0.00528	 0.029102	 0.0496	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 2817	 0.052593	 0.119012	 0.0039	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5751	 2817	 0.065556	 0.146914	 0.0068	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	4720	 2819	 0.033762	 0.137566	 0.0018	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 2819	 0.085528	 0.156557	 0.0016	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5459	 2819	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 2820	 0.011417	 0.020898	 0.0002	 1278	 1278	 1278	 0.0	 0.0	 1	 -30.0	 30.0;
	4349	 2822	 9.9e-05	 0.001007	 0.003	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4349	 2821	 0.000119	 0.001067	 0.004	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4316	 2824	 0.177421	 0.324767	 0.0071	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	4336	 2824	 0.084656	 0.216427	 0.0025	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	5450	 2825	 0.052154	 0.104308	 0.0011	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	3713	 2826	 0.000395	 0.001126	 0.1043	 25728	 25728	 25728	 0.0	 0.0	 1	 -30.0	 30.0;
	3182	 2830	 0.101481	 0.203086	 0.0089	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	3848	 2830	 0.00642	 0.02	 0.0154	 1415	 1415	 1415	 0.0	 0.0	 1	 -30.0	 30.0;
	5322	 2830	 0.005864	 0.036531	 0.0019	 803	 803	 803	 0.0	 0.0	 1	 -30.0	 30.0;
	5820	 2830	 0.013951	 0.044321	 0.0021	 640	 640	 640	 0.0	 0.0	 1	 -30.0	 30.0;
	5149	 2831	 0.000849	 0.003812	 0.0071	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3809	 2833	 7.6e-05	 0.000554	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3808	 2833	 7.6e-05	 0.000554	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3807	 2833	 7.6e-05	 0.000554	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3806	 2833	 7.6e-05	 0.000568	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 2834	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	4398	 2836	 0.003679	 0.018418	 0.0286	 1620	 1620	 1620	 0.0	 0.0	 1	 -30.0	 30.0;
	5516	 2838	 0.000756	 0.00252	 0.0	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	5518	 2839	 1.5e-05	 9.9e-05	 0.001	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3345	 2840	 0.044973	 0.126127	 0.0015	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5092	 2841	 0.002963	 0.008889	 0.0005	 3170	 3170	 3170	 0.0	 0.0	 1	 -30.0	 30.0;
	5266	 2843	 0.005543	 0.014865	 0.0002	 1862	 1862	 1862	 0.0	 0.0	 1	 -30.0	 30.0;
	5392	 2844	 0.054568	 0.138519	 0.0065	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5520	 2845	 2.5e-05	 0.000252	 0.0001	 113138	 113138	 113138	 0.0	 0.0	 1	 -30.0	 30.0;
	2954	 2846	 0.125894	 0.230447	 0.0021	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	4561	 2846	 0.109599	 0.26455	 0.003	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	5730	 2848	 0.04006	 0.101033	 0.0068	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 2849	 0.000277	 0.001244	 0.0886	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4570	 2850	 0.000499	 0.006557	 0.2282	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4647	 2850	 0.000298	 0.003019	 0.078	 1971.0	 1971.0	 1971.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4570	 2850	 0.000505	 0.006637	 0.231	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4647	 2850	 0.000298	 0.003012	 0.078	 1971.0	 1971.0	 1971.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4570	 2850	 0.000499	 0.006557	 0.2282	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4570	 2850	 0.000499	 0.006557	 0.2282	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5252	 2851	 0.074578	 0.210632	 0.0025	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	5522	 2851	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	3102	 2853	 0.000158	 0.001284	 0.1185	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3566	 2853	 0.000178	 0.001521	 0.1397	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5792	 2854	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 2856	 1.5e-05	 9.9e-05	 0.0	 309124	 309124	 309124	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 2857	 0.000454	 0.001008	 0.0	 27511	 27511	 27511	 0.0	 0.0	 1	 -30.0	 30.0;
	5523	 2859	 0.006299	 0.016377	 0.0002	 1734	 1734	 1734	 0.0	 0.0	 1	 -30.0	 30.0;
	5523	 2860	 0.001208	 0.002211	 0.0	 12072	 12072	 12072	 0.0	 0.0	 1	 -30.0	 30.0;
	5527	 2861	 0.000158	 0.000652	 0.001	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3399	 2862	 0.011262	 0.075762	 0.0018	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	3758	 2864	 0.015148	 0.040877	 0.0019	 683	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	5337	 2864	 0.008395	 0.034815	 0.0018	 831	 831	 831	 0.0	 0.0	 1	 -30.0	 30.0;
	5786	 2864	 0.028025	 0.174815	 0.0096	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 2865	 0.002983	 0.020385	 0.0375	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 2865	 0.005136	 0.034548	 0.0628	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2998	 2868	 0.003049	 0.012824	 0.0194	 2240	 2240	 2240	 0.0	 0.0	 1	 -30.0	 30.0;
	4847	 2866	 0.003275	 0.012094	 0.0132	 2357	 2357	 2357	 0.0	 0.0	 1	 -30.0	 30.0;
	4847	 2867	 0.005382	 0.009851	 0.0091	 2631	 2631	 2631	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 2869	 0.000123	 0.001235	 0.0	 23932	 23932	 23932	 0.0	 0.0	 1	 -30.0	 30.0;
	4685	 2870	 0.000247	 0.000741	 0.0005	 38824	 38824	 38824	 0.0	 0.0	 1	 -30.0	 30.0;
	4448	 2871	 0.059939	 0.151978	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	5530	 2874	 0.002875	 0.005263	 0.0001	 5072	 5072	 5072	 0.0	 0.0	 1	 -30.0	 30.0;
	4930	 2875	 0.054568	 0.138889	 0.0065	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	3276	 2876	 0.007004	 0.015142	 0.0002	 1823	 1823	 1823	 0.0	 0.0	 1	 -30.0	 30.0;
	5618	 2877	 0.037494	 0.102284	 0.0049	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	5532	 2878	 0.003779	 0.014865	 0.0018	 1925	 1925	 1925	 0.0	 0.0	 1	 -30.0	 30.0;
	5531	 2879	 0.010632	 0.026228	 0.0027	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	3038	 2883	 0.025447	 0.064575	 0.0007	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	3076	 2884	 0.069035	 0.148652	 0.0021	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	3010	 2885	 0.01033	 0.02842	 0.0003	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 2886	 0.005795	 0.022424	 0.0002	 1275	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	5533	 2886	 0.000504	 0.002268	 0.0	 12709	 12709	 12709	 0.0	 0.0	 1	 -30.0	 30.0;
	3036	 2887	 0.091963	 0.211892	 0.0021	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	5534	 2887	 0.048375	 0.10708	 0.0012	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	4295	 2888	 0.02973	 0.124969	 0.0027	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	4582	 2889	 0.055682	 0.13933	 0.0016	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	4565	 2890	 0.003527	 0.013354	 0.0	 2138	 2138	 2138	 0.0	 0.0	 1	 -30.0	 30.0;
	2917	 2892	 0.001323	 0.008824	 0.0339	 411.0	 411.0	 411.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3485	 2893	 0.000731	 0.00484	 0.0091	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4861	 2893	 0.002884	 0.018686	 0.0375	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5565	 2893	 0.001817	 0.012168	 0.0223	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 2893	 0.002785	 0.018884	 0.0334	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3485	 2893	 0.00077	 0.005136	 0.0091	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5678	 2893	 0.003121	 0.020859	 0.0385	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3485	 2893	 0.000731	 0.00482	 0.0091	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3479	 2894	 9.7e-05	 0.00097	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4637	 2894	 0.001468	 0.014903	 0.3841	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	5086	 2894	 0.00036	 0.003636	 0.0953	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3478	 2894	 9.7e-05	 0.00097	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4638	 2894	 0.001461	 0.014785	 0.3812	 2147	 2147	 2147	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 2894	 0.001247	 0.012673	 0.3263	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3477	 2894	 9.7e-05	 0.000983	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3476	 2894	 9.7e-05	 0.001025	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3326	 2895	 0.007037	 0.019259	 0.001	 1449	 1449	 1449	 0.0	 0.0	 1	 -30.0	 30.0;
	5655	 2895	 0.003827	 0.010864	 0.0005	 2579	 2579	 2579	 0.0	 0.0	 1	 -30.0	 30.0;
	4017	 2896	 0.024439	 0.096498	 0.0194	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	3181	 2897	 0.046259	 0.11736	 0.0013	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	5535	 2898	 0.001638	 0.004334	 0.0048	 6565	 6565	 6565	 0.0	 0.0	 1	 -30.0	 30.0;
	3845	 2899	 0.046687	 0.127387	 0.0014	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5033	 2899	 0.108592	 0.275636	 0.0031	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	5492	 2899	 0.0839	 0.23356	 0.0027	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	3600	 2901	 0.006889	 0.018756	 0.0	 1594	 1594	 1594	 0.0	 0.0	 1	 -30.0	 30.0;
	5537	 2903	 0.001512	 0.004031	 0.0001	 7065	 7065	 7065	 0.0	 0.0	 1	 -30.0	 30.0;
	5536	 2903	 0.001461	 0.003704	 0.0001	 7639	 7639	 7639	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 2904	 0.013444	 0.026877	 0.0011	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	4718	 2905	 0.001644	 0.005778	 0.0018	 5259	 5259	 5259	 0.0	 0.0	 1	 -30.0	 30.0;
	4134	 2906	 0.038272	 0.114311	 0.0065	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	2910	 2909	 0.008844	 0.024112	 0.0003	 1185	 1185	 1185	 0.0	 0.0	 1	 -30.0	 30.0;
	5622	 2911	 0.007741	 0.017333	 0.0008	 1565	 1565	 1565	 0.0	 0.0	 1	 -30.0	 30.0;
	3901	 2912	 0.047367	 0.131267	 0.0014	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5406	 2912	 0.027841	 0.076594	 0.0008	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	4854	 2914	 0.028471	 0.113883	 0.0032	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 2916	 0.011753	 0.05438	 0.0931	 294.0	 294.0	 294.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3000	 2916	 0.00083	 0.008375	 0.0263	 866.0	 866.0	 866.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3611	 2916	 0.00241	 0.016435	 0.0273	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4464	 2915	 0.007585	 0.028128	 0.0456	 1063	 1063	 1063	 0.0	 0.0	 1	 -30.0	 30.0;
	4848	 2917	 0.000652	 0.005946	 0.0172	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5404	 2915	 0.000632	 0.004346	 0.0233	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2999	 2915	 0.000869	 0.008514	 0.0273	 866.0	 866.0	 866.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4848	 2915	 0.000632	 0.00559	 0.0476	 494.0	 494.0	 494.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2921	 2919	 0.000252	 0.000504	 0.0003	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	3794	 2920	 0.004443	 0.008133	 0.0048	 3282	 3282	 3282	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 2921	 0.057949	 0.137062	 0.0015	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	4255	 2921	 0.011665	 0.066465	 0.0027	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	5779	 2921	 0.006475	 0.017259	 0.001	 1602	 1602	 1602	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 2924	 0.060141	 0.152532	 0.0017	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4940	 2924	 0.078357	 0.21416	 0.0024	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	3851	 2925	 0.078105	 0.208617	 0.0024	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	3851	 2925	 0.076594	 0.202822	 0.0025	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	3086	 2926	 0.046359	 0.100781	 0.0011	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	4383	 2927	 0.001981	 0.003626	 0.0025	 7146	 7146	 7146	 0.0	 0.0	 1	 -30.0	 30.0;
	3297	 2928	 0.079365	 0.215923	 0.0025	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	5539	 2929	 0.000436	 0.000797	 0.0004	 32501	 32501	 32501	 0.0	 0.0	 1	 -30.0	 30.0;
	3213	 2931	 0.046863	 0.11867	 0.0013	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	3683	 2931	 0.045855	 0.121693	 0.0039	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	2987	 2934	 0.007862	 0.038716	 0.0658	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3614	 2934	 0.001719	 0.00881	 0.0203	 358.0	 358.0	 358.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3099	 2935	 0.067775	 0.178382	 0.002	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 2935	 0.068279	 0.174855	 0.002	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3850	 2937	 0.022676	 0.06576	 0.001	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	4997	 2936	 0.024188	 0.061728	 0.001	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	5609	 2937	 0.003779	 0.024943	 0.0	 1171	 1171	 1171	 0.0	 0.0	 1	 -30.0	 30.0;
	3850	 2936	 0.016377	 0.066264	 0.001	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	5611	 2936	 0.003779	 0.024439	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	5542	 2939	 0.000504	 0.001512	 0.001	 18526	 18526	 18526	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 2941	 0.034266	 0.094482	 0.001	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	5846	 2941	 0.084908	 0.220711	 0.0025	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	4845	 2942	 0.05037	 0.129877	 0.0062	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 2945	 0.010049	 0.026543	 0.0041	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	5024	 2945	 0.005148	 0.013309	 0.0006	 2126	 2126	 2126	 0.0	 0.0	 1	 -30.0	 30.0;
	5080	 2945	 0.016914	 0.04642	 0.0021	 614	 614	 614	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 2946	 0.014262	 0.067397	 0.1124	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4306	 2946	 0.021077	 0.088869	 0.1468	 301.0	 301.0	 301.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4406	 2946	 0.00016	 0.000755	 0.0013	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 2946	 0.013452	 0.063625	 0.1063	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3968	 2947	 0.002815	 0.017518	 0.097	 1675	 1675	 1675	 0.0	 0.0	 1	 -30.0	 30.0;
	4925	 2947	 0.002395	 0.014938	 0.0828	 1964	 1964	 1964	 0.0	 0.0	 1	 -30.0	 30.0;
	3706	 2948	 0.00065	 0.008537	 0.2946	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 2951	 0.013102	 0.081129	 0.001	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	5066	 2951	 0.044041	 0.186369	 0.0022	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5444	 2951	 0.013983	 0.038045	 0.0005	 751	 751	 751	 0.0	 0.0	 1	 -30.0	 30.0;
	4426	 2954	 0.081129	 0.199043	 0.002	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	5052	 2955	 0.022235	 0.057469	 0.0047	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	5674	 2955	 0.009296	 0.024593	 0.0011	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 2956	 0.056941	 0.148652	 0.0017	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4244	 2957	 0.03679	 0.103704	 0.0053	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	5544	 2959	 0.028723	 0.057193	 0.0006	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	5545	 2960	 0.000347	 0.000813	 0.0018	 35735	 35735	 35735	 0.0	 0.0	 1	 -30.0	 30.0;
	4668	 2963	 0.011208	 0.020517	 0.0771	 1271	 1271	 1271	 0.0	 0.0	 1	 -30.0	 30.0;
	2969	 2964	 4e-05	 0.000198	 0.0223	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2968	 2965	 2e-05	 0.000198	 0.0152	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4083	 2968	 0.000138	 0.019753	 0.001	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4159	 2968	 0.000494	 0.003002	 0.242	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5035	 2967	 0.002726	 0.013728	 0.084	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5591	 2969	 0.000356	 0.003358	 0.0121	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4083	 2967	 9.9e-05	 0.000198	 0.0091	 446.0	 446.0	 446.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4159	 2968	 0.000514	 0.003101	 0.2521	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 2968	 0.000909	 0.006005	 0.0142	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4977	 2970	 0.000166	 0.002749	 0.1069	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5244	 2971	 0.001004	 0.010997	 0.2339	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4977	 2971	 0.000159	 0.002701	 0.0982	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5546	 2972	 0.00126	 0.00252	 0.0	 10795	 10795	 10795	 0.0	 0.0	 1	 -30.0	 30.0;
	3999	 2973	 0.03613	 0.097783	 0.0021	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 2973	 0.028975	 0.07483	 0.0008	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	5217	 2973	 0.103049	 0.264802	 0.0132	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	3998	 2973	 0.036004	 0.09743	 0.0011	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	3041	 2975	 0.081633	 0.15999	 0.0021	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	5201	 2975	 0.040564	 0.110859	 0.001	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	3983	 2976	 0.163976	 0.300156	 0.003	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	4259	 2976	 0.119224	 0.218238	 0.0021	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	5548	 2977	 0.002091	 0.004308	 0.0001	 6352	 6352	 6352	 0.0	 0.0	 1	 -30.0	 30.0;
	5618	 2979	 0.024815	 0.063086	 0.0028	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	5641	 2979	 0.023679	 0.060074	 0.0028	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 2980	 0.02037	 0.050988	 0.0608	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	3604	 2981	 0.023683	 0.09801	 0.0012	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	4358	 2981	 0.074074	 0.1678	 0.0018	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	5465	 2981	 0.030738	 0.084354	 0.017	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	5606	 2981	 0.010078	 0.041824	 0.0005	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	5643	 2982	 0.014865	 0.027211	 0.0001	 1095	 1095	 1095	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 2985	 0.001358	 0.006049	 0.0003	 4892	 4892	 4892	 0.0	 0.0	 1	 -30.0	 30.0;
	3403	 2986	 0.023683	 0.083648	 0.001	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 2986	 0.054926	 0.145377	 0.0017	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	4369	 2986	 0.012598	 0.077853	 0.001	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	5146	 2986	 0.024943	 0.071051	 0.0008	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	5850	 2986	 0.038549	 0.133031	 0.0016	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 2986	 0.053918	 0.147392	 0.0017	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	3484	 2988	 0.030864	 0.096667	 0.0053	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	4056	 2990	 0.004283	 0.026959	 0.0003	 1082	 1082	 1082	 0.0	 0.0	 1	 -30.0	 30.0;
	4162	 2990	 0.042076	 0.093222	 0.001	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	5254	 2990	 0.003275	 0.02066	 0.0002	 1412	 1412	 1412	 0.0	 0.0	 1	 -30.0	 30.0;
	5741	 2990	 0.044848	 0.114135	 0.0013	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	3909	 2991	 0.000395	 0.002686	 0.0051	 490.0	 490.0	 490.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 2992	 0.000252	 0.000504	 0.0004	 52449	 52449	 52449	 0.0	 0.0	 1	 -30.0	 30.0;
	4983	 2993	 0.032754	 0.09675	 0.001	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	5667	 2993	 0.049887	 0.143109	 0.0021	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 2995	 0.021416	 0.054674	 0.001	 503	 503	 503	 0.0	 0.0	 1	 -30.0	 30.0;
	4793	 2995	 0.028219	 0.071303	 0.001	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	3287	 2998	 0.005291	 0.028219	 0.0	 1029	 1029	 1029	 0.0	 0.0	 1	 -30.0	 30.0;
	3681	 2997	 0.01914	 0.035035	 0.0329	 740	 740	 740	 0.0	 0.0	 1	 -30.0	 30.0;
	4317	 2997	 0.001512	 0.005543	 0.0055	 5139	 5139	 5139	 0.0	 0.0	 1	 -30.0	 30.0;
	5542	 2997	 0.007055	 0.029479	 0.001	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 2997	 0.003023	 0.021164	 0.001	 1382	 1382	 1382	 0.0	 0.0	 1	 -30.0	 30.0;
	5648	 2998	 0.003275	 0.022676	 0.001	 1289	 1289	 1289	 0.0	 0.0	 1	 -30.0	 30.0;
	3288	 3000	 0.000316	 0.002351	 0.0061	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3389	 3000	 0.000512	 0.001327	 0.159	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4768	 3001	 0.029479	 0.062988	 0.0015	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 3001	 0.026329	 0.069866	 0.0021	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	4768	 3001	 0.029479	 0.062988	 0.0007	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	3622	 3002	 0.001146	 0.008296	 0.0663	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3174	 3003	 0.039128	 0.099824	 0.0012	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	5169	 3003	 0.008062	 0.022424	 0.0002	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	5775	 3003	 0.059965	 0.165029	 0.0002	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3047	 3003	 0.023683	 0.099017	 0.0013	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	3174	 3003	 0.043865	 0.11038	 0.0016	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	4560	 3004	 0.000711	 0.00324	 0.2916	 293.0	 293.0	 293.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3679	 3005	 0.093474	 0.228773	 0.0025	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 3006	 0.001857	 0.008435	 0.0152	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4596	 3006	 0.002647	 0.013254	 0.0243	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3466	 3007	 0.036543	 0.095926	 0.0045	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	4957	 3008	 0.001146	 0.010923	 0.1706	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4957	 3008	 0.001185	 0.010844	 0.1671	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 3010	 0.021668	 0.057193	 0.0007	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	5116	 3010	 0.026153	 0.066289	 0.0016	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 3012	 0.000852	 0.011233	 0.387	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 3012	 0.000852	 0.011226	 0.387	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 3013	 0.04132	 0.10582	 0.002	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	3679	 3014	 0.014084	 0.042001	 0.014	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	4778	 3015	 0.011338	 0.048627	 0.001	 592	 592	 592	 0.0	 0.0	 1	 -30.0	 30.0;
	4778	 3015	 0.011338	 0.048627	 0.001	 592	 592	 592	 0.0	 0.0	 1	 -30.0	 30.0;
	5454	 3017	 0.018025	 0.047407	 0.0023	 587	 587	 587	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 3019	 0.047115	 0.196523	 0.0068	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	5169	 3020	 0.000176	 0.000504	 0.0	 56971	 56971	 56971	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 3020	 0.027337	 0.074553	 0.0008	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	4790	 3021	 0.01321	 0.02642	 0.0011	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	3543	 3022	 0.062736	 0.151424	 0.0075	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4770	 3022	 0.066012	 0.177879	 0.002	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	5778	 3024	 0.00126	 0.003275	 0.0001	 9667	 9667	 9667	 0.0	 0.0	 1	 -30.0	 30.0;
	5784	 3024	 0.007559	 0.019148	 0.0002	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	3520	 3028	 0.030486	 0.102545	 0.0012	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	5592	 3030	 0.011111	 0.054568	 0.0028	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	5025	 3031	 0.049559	 0.13424	 0.002	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	5136	 3031	 0.057344	 0.129478	 0.0031	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	4029	 3033	 0.001101	 0.012181	 0.2599	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3597	 3034	 0.013303	 0.036306	 0.0053	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	3399	 3035	 0.058503	 0.157596	 0.0063	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	5343	 3035	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	4720	 3036	 0.325276	 0.595412	 0.0048	 45	 45	 45	 0.0	 0.0	 1	 -30.0	 30.0;
	4459	 3039	 0.003356	 0.026424	 0.0458	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 3040	 0.014046	 0.025712	 0.0002	 978	 978	 978	 0.0	 0.0	 1	 -30.0	 30.0;
	4462	 3041	 0.035273	 0.150164	 0.0021	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 3041	 0.015873	 0.066012	 0.001	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	4635	 3041	 0.075586	 0.202822	 0.0021	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 3042	 0.001512	 0.004031	 0.0001	 7065	 7065	 7065	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 3043	 0.007181	 0.044797	 0.0006	 671	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 3043	 0.01615	 0.043638	 0.0046	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	4231	 3044	 0.006551	 0.017889	 0.0002	 1597	 1597	 1597	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 3044	 0.083198	 0.152293	 0.0016	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3311	 3045	 0.00839	 0.023507	 0.0286	 1219	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	4304	 3045	 0.002973	 0.012673	 0.0189	 2337	 2337	 2337	 0.0	 0.0	 1	 -30.0	 30.0;
	4844	 3048	 0.000573	 0.003832	 0.0071	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 3048	 0.003615	 0.025225	 0.0486	 549.0	 549.0	 549.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4813	 3049	 0.026707	 0.112371	 0.0013	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	4582	 3050	 0.017637	 0.044848	 0.0086	 613	 613	 613	 0.0	 0.0	 1	 -30.0	 30.0;
	3064	 3051	 0.033333	 0.089383	 0.0043	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	3268	 3053	 0.112371	 0.281179	 0.0032	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	3496	 3054	 0.070295	 0.178131	 0.0027	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3059	 3057	 2.1e-05	 0.000127	 0.1141	 1092.0	 1092.0	 1092.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3939	 3057	 0.000111	 0.001932	 0.0289	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3058	 3057	 2.1e-05	 0.000127	 0.1155	 1053.0	 1053.0	 1053.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5558	 3060	 0.026707	 0.059965	 0.0009	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	5196	 3066	 0.049506	 0.125556	 0.0058	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5306	 3066	 0.025442	 0.046572	 0.0018	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	3675	 3067	 0.002963	 0.016914	 0.0314	 1766	 1766	 1766	 0.0	 0.0	 1	 -30.0	 30.0;
	3979	 3067	 0.004074	 0.025309	 0.0026	 1183	 1183	 1183	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 3068	 0.005432	 0.022222	 0.0073	 1326	 1326	 1326	 0.0	 0.0	 1	 -30.0	 30.0;
	5559	 3070	 2e-05	 0.000198	 0.0172	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5560	 3069	 2e-05	 0.000198	 0.0142	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3679	 3072	 0.079718	 0.1935	 0.0031	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	4337	 3074	 0.017637	 0.059713	 0.0021	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	5324	 3074	 0.027715	 0.086924	 0.001	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 3074	 0.03225	 0.087931	 0.0015	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	3101	 3075	 0.003461	 0.013896	 0.0243	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5657	 3076	 0.013605	 0.033258	 0.003	 822	 822	 822	 0.0	 0.0	 1	 -30.0	 30.0;
	4767	 3077	 0.069035	 0.150416	 0.0016	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	5828	 3077	 0.001512	 0.004031	 0.0001	 6858	 6858	 6858	 0.0	 0.0	 1	 -30.0	 30.0;
	4798	 3077	 0.004283	 0.011842	 0.0002	 2345	 2345	 2345	 0.0	 0.0	 1	 -30.0	 30.0;
	5561	 3078	 0.009826	 0.026455	 0.0003	 1047	 1047	 1047	 0.0	 0.0	 1	 -30.0	 30.0;
	3201	 3079	 0.086672	 0.236332	 0.0026	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	4772	 3080	 0.03358	 0.090741	 0.0151	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5437	 3080	 1.2e-05	 0.000123	 0.0	 240340	 240340	 240340	 0.0	 0.0	 1	 -30.0	 30.0;
	5157	 3081	 0.005039	 0.010078	 0.01	 2621	 2621	 2621	 0.0	 0.0	 1	 -30.0	 30.0;
	4657	 3084	 0.064752	 0.145629	 0.0016	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 3085	 0.050643	 0.138322	 0.0016	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	5736	 3085	 0.026203	 0.071554	 0.0008	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	3710	 3086	 0.048879	 0.16125	 0.0018	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	5363	 3086	 0.023683	 0.060217	 0.0006	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	5376	 3086	 0.04006	 0.101789	 0.0011	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	3407	 3087	 0.001462	 0.006677	 0.1488	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4547	 3087	 0.001231	 0.008198	 0.0587	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 3087	 0.000865	 0.005772	 0.0101	 436.0	 436.0	 436.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4547	 3087	 0.002588	 0.015862	 0.0304	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3313	 3088	 0.063316	 0.146813	 0.0025	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	5660	 3088	 0.017385	 0.037541	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 3089	 0.011804	 0.05293	 0.0942	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 3090	 0.036533	 0.075334	 0.0008	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	3968	 3091	 0.062963	 0.160123	 0.0075	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	5141	 3092	 0.053011	 0.144318	 0.0025	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	5628	 3092	 0.042555	 0.1161	 0.002	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	4076	 3093	 0.046049	 0.118025	 0.0057	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	5000	 3095	 0.046082	 0.122827	 0.0025	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 3096	 0.00907	 0.022928	 0.0276	 1162	 1162	 1162	 0.0	 0.0	 1	 -30.0	 30.0;
	3344	 3098	 0.043457	 0.090864	 0.0011	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	4951	 3100	 0.05417	 0.137818	 0.001	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 3100	 0.01285	 0.052658	 0.001	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	4069	 3103	 0.001101	 0.012445	 0.3105	 1488.0	 1488.0	 1488.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4136	 3103	 0.0009	 0.007479	 0.0982	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4918	 3103	 0.002209	 0.024924	 0.5733	 1275	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	4137	 3103	 0.0009	 0.00741	 0.13	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3689	 3107	 0.07609	 0.180146	 0.003	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	3689	 3106	 0.082892	 0.184933	 0.002	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	3457	 3108	 0.024188	 0.091459	 0.0064	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	5378	 3108	 0.017637	 0.057445	 0.0012	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	5358	 3108	 0.011842	 0.031746	 0.0007	 846	 846	 846	 0.0	 0.0	 1	 -30.0	 30.0;
	5565	 3109	 0.000395	 0.002607	 0.0051	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4917	 3110	 0.01022	 0.054673	 0.0997	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 3110	 0.003488	 0.015777	 0.0284	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3679	 3111	 0.041572	 0.112623	 0.0013	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	3679	 3111	 0.043084	 0.110103	 0.0013	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 3112	 0.013102	 0.056437	 0.0433	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	5584	 3112	 0.024439	 0.099269	 0.0013	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	3552	 3113	 0.064248	 0.163517	 0.0019	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	3761	 3113	 0.041068	 0.103804	 0.0021	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	4394	 3113	 0.068279	 0.18972	 0.0021	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	4758	 3113	 0.069287	 0.193248	 0.0024	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	5624	 3113	 0.155455	 0.425548	 0.0042	 66	 66	 66	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 3113	 0.05543	 0.153943	 0.0032	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 3115	 0.024938	 0.068395	 0.0032	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	5092	 3114	 0.028642	 0.064568	 0.0029	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	5285	 3115	 0.022346	 0.061235	 0.0029	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	4963	 3114	 0.040741	 0.111358	 0.0052	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	5566	 3122	 0.003951	 0.010864	 0.0005	 2570	 2570	 2570	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 3123	 0.003275	 0.007307	 0.0	 3688	 3688	 3688	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 3125	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	4354	 3126	 0.0237	 0.043383	 0.0	 616	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	5613	 3127	 0.024969	 0.073268	 0.0013	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	5746	 3127	 0.024389	 0.077576	 0.001	 375	 375	 375	 0.0	 0.0	 1	 -30.0	 30.0;
	5819	 3127	 0.025951	 0.090955	 0.001	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	5608	 3127	 0.024969	 0.083094	 0.001	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	3178	 3128	 0.029978	 0.100778	 0.0366	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	2931	 3129	 0.053666	 0.125724	 0.0014	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3813	 3129	 0.078861	 0.206752	 0.0062	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	4270	 3131	 0.002016	 0.005291	 0.0001	 5215	 5215	 5215	 0.0	 0.0	 1	 -30.0	 30.0;
	5117	 3131	 0.092467	 0.244898	 0.0028	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	4365	 3132	 0.027457	 0.074876	 0.0036	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	4978	 3134	 0.008566	 0.067523	 0.0496	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	5570	 3136	 0.002099	 0.00642	 0.0003	 4490	 4490	 4490	 0.0	 0.0	 1	 -30.0	 30.0;
	4609	 3139	 0.017637	 0.045352	 0.0005	 626	 626	 626	 0.0	 0.0	 1	 -30.0	 30.0;
	3011	 3140	 0.001025	 0.008148	 0.0142	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3164	 3141	 0.012371	 0.032199	 0.0049	 882	 882	 882	 0.0	 0.0	 1	 -30.0	 30.0;
	3930	 3141	 0.139529	 0.255404	 0.0024	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	3164	 3141	 0.034517	 0.089695	 0.001	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 3142	 0.007386	 0.013519	 0.0001	 1975	 1975	 1975	 0.0	 0.0	 1	 -30.0	 30.0;
	5571	 3143	 0.001512	 0.003779	 0.0001	 7254	 7254	 7254	 0.0	 0.0	 1	 -30.0	 30.0;
	3146	 3144	 4.3e-05	 9e-05	 0.004	 310318	 310318	 310318	 0.0	 0.0	 1	 -30.0	 30.0;
	3903	 3145	 0.025195	 0.103804	 0.0015	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 3145	 0.025951	 0.088687	 0.0133	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 3145	 0.027967	 0.085412	 0.001	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	4973	 3145	 0.025951	 0.089695	 0.0132	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	4048	 3146	 0.00079	 0.003931	 0.0071	 339.0	 339.0	 339.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4975	 3146	 0.001442	 0.006696	 0.0121	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3986	 3147	 0.013983	 0.047468	 0.0025	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	5848	 3147	 0.087075	 0.287932	 0.0029	 102	 102	 102	 0.0	 0.0	 1	 -30.0	 30.0;
	5779	 3148	 0.04006	 0.07735	 0.0008	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 3149	 3.6e-05	 9.3e-05	 0.0121	 655.0	 655.0	 655.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3471	 3150	 2.8e-05	 0.000277	 0.0058	 2187.0	 2187.0	 2187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3879	 3151	 0.067775	 0.171832	 0.0019	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	3890	 3152	 0.024321	 0.097901	 0.007	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 3152	 0.033827	 0.143951	 0.0071	 208	 208	 208	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 3152	 0.018765	 0.07663	 0.0079	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	5047	 3152	 0.000173	 0.00079	 0.0034	 36728	 36728	 36728	 0.0	 0.0	 1	 -30.0	 30.0;
	4885	 3154	 0.001734	 0.018573	 0.4072	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 3154	 0.002181	 0.031662	 0.8231	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	5244	 3153	 0.001711	 0.017313	 0.4476	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 3153	 0.002181	 0.031648	 0.8202	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 3157	 0.004568	 0.008395	 0.0224	 3291	 3291	 3291	 0.0	 0.0	 1	 -30.0	 30.0;
	3602	 3159	 0.050988	 0.129259	 0.0062	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	4890	 3159	 0.040988	 0.107531	 0.0052	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	3258	 3160	 0.035926	 0.091235	 0.0044	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	3527	 3160	 0.000988	 0.002716	 0.0002	 10278	 10278	 10278	 0.0	 0.0	 1	 -30.0	 30.0;
	3275	 3161	 0.025195	 0.053414	 0.0079	 486	 486	 486	 0.0	 0.0	 1	 -30.0	 30.0;
	3566	 3163	 0.000198	 0.000652	 0.5832	 475.0	 475.0	 475.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3936	 3163	 0.000316	 0.001442	 0.1326	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3566	 3163	 0.000237	 0.001422	 0.1873	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3935	 3163	 0.000257	 0.001007	 0.1215	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3385	 3164	 0.083724	 0.227488	 0.0026	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	4433	 3164	 0.050643	 0.13026	 0.0015	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	5203	 3164	 0.019904	 0.133031	 0.0015	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	5492	 3164	 0.034517	 0.2129	 0.0029	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 3166	 0.004283	 0.012346	 0.0002	 2328	 2328	 2328	 0.0	 0.0	 1	 -30.0	 30.0;
	4522	 3169	 0.004568	 0.009259	 0.0003	 2877	 2877	 2877	 0.0	 0.0	 1	 -30.0	 30.0;
	5504	 3169	 0.012222	 0.032222	 0.0015	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 3170	 0.000773	 0.001416	 0.0006	 18302	 18302	 18302	 0.0	 0.0	 1	 -30.0	 30.0;
	5575	 3171	 0.000252	 0.00126	 0.0	 23670	 23670	 23670	 0.0	 0.0	 1	 -30.0	 30.0;
	4722	 3172	 0.011111	 0.030124	 0.0	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 3172	 0.034938	 0.092222	 0.0045	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	3673	 3173	 0.035979	 0.091207	 0.001	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 3174	 0.000454	 0.001209	 0.0002	 23551	 23551	 23551	 0.0	 0.0	 1	 -30.0	 30.0;
	4667	 3175	 0.073318	 0.259007	 0.0031	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	4962	 3176	 0.003319	 0.022716	 0.0415	 1346	 1346	 1346	 0.0	 0.0	 1	 -30.0	 30.0;
	5626	 3177	 0.030738	 0.084152	 0.001	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	3266	 3178	 0.024307	 0.078747	 0.0251	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	4871	 3179	 3.4e-05	 9.4e-05	 0.002	 286.0	 286.0	 286.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4922	 3179	 0.003297	 0.021902	 0.0466	 477.0	 477.0	 477.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3753	 3180	 0.001496	 0.014148	 0.3697	 1537.0	 1537.0	 1537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3753	 3180	 0.001496	 0.014148	 0.3697	 1537.0	 1537.0	 1537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4677	 3180	 0.000942	 0.009536	 0.2455	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3396	 3183	 0.018645	 0.050894	 0.0006	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 3184	 0.024568	 0.066296	 0.0031	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	4636	 3184	 0.008642	 0.054198	 0.0061	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	5580	 3185	 0.043012	 0.146025	 0.0071	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5120	 3185	 0.045309	 0.147654	 0.0073	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	4883	 3186	 0.095792	 0.23361	 0.0026	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5581	 3187	 0.012346	 0.033258	 0.0004	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	5616	 3188	 0.042051	 0.106601	 0.0012	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	5788	 3188	 0.015369	 0.04258	 0.0	 653	 653	 653	 0.0	 0.0	 1	 -30.0	 30.0;
	4291	 3190	 0.006803	 0.027715	 0.0004	 1066	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	5377	 3190	 0.002771	 0.011338	 0.0002	 2606	 2606	 2606	 0.0	 0.0	 1	 -30.0	 30.0;
	4400	 3192	 0.000277	 0.000632	 0.0607	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4400	 3191	 0.000395	 0.000731	 0.0628	 37253	 37253	 37253	 0.0	 0.0	 1	 -30.0	 30.0;
	3515	 3193	 0.028025	 0.114815	 0.0016	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	4253	 3194	 0.000178	 0.000928	 0.3564	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4252	 3195	 0.021416	 0.07735	 0.0093	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	4312	 3196	 0.021482	 0.054568	 0.0026	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	4690	 3196	 0.003951	 0.008025	 0.0233	 3321	 3321	 3321	 0.0	 0.0	 1	 -30.0	 30.0;
	5239	 3197	 0.007037	 0.017901	 0.0008	 1545	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	5354	 3197	 0.059876	 0.15284	 0.0071	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4312	 3196	 0.025926	 0.065556	 0.0031	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	5053	 3199	 0.012247	 0.044385	 0.0739	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4575	 3198	 9.9e-05	 0.000988	 0.004	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5562	 3201	 0.006803	 0.018392	 0.0002	 1740	 1740	 1740	 0.0	 0.0	 1	 -30.0	 30.0;
	3270	 3202	 0.006918	 0.046044	 0.0851	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3882	 3204	 0.000158	 0.000289	 0.0203	 93975	 93975	 93975	 0.0	 0.0	 1	 -30.0	 30.0;
	3883	 3205	 0.000145	 0.000265	 0.0182	 102466	 102466	 102466	 0.0	 0.0	 1	 -30.0	 30.0;
	5500	 3206	 0.011482	 0.028765	 0.0015	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	4624	 3207	 0.094734	 0.240363	 0.0027	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 3208	 0.005926	 0.016914	 0.0018	 1932	 1932	 1932	 0.0	 0.0	 1	 -30.0	 30.0;
	4219	 3209	 0.002771	 0.011086	 0.0002	 2662	 2662	 2662	 0.0	 0.0	 1	 -30.0	 30.0;
	4498	 3209	 0.001764	 0.006803	 0.0001	 4328	 4328	 4328	 0.0	 0.0	 1	 -30.0	 30.0;
	5583	 3210	 0.000222	 0.000711	 0.0004	 42408	 42408	 42408	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 3211	 0.029226	 0.119174	 0.0015	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	5565	 3212	 0.000968	 0.00644	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5585	 3214	 0.036684	 0.06715	 0.0006	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 3218	 0.008395	 0.021358	 0.001	 1295	 1295	 1295	 0.0	 0.0	 1	 -30.0	 30.0;
	5579	 3219	 0.08516	 0.20131	 0.0022	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	3826	 3220	 0.047544	 0.093827	 0.001	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	3924	 3220	 0.0451	 0.19224	 0.0025	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3925	 3220	 0.045855	 0.194004	 0.0027	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 3221	 0.001481	 0.00358	 0.0002	 7828	 7828	 7828	 0.0	 0.0	 1	 -30.0	 30.0;
	3300	 3222	 0.044848	 0.113379	 0.0013	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	4231	 3222	 0.050894	 0.128748	 0.0014	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	3299	 3223	 0.044394	 0.112547	 0.0013	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	4230	 3223	 0.05039	 0.128244	 0.0014	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	4764	 3224	 0.073318	 0.197531	 0.0035	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	5828	 3224	 0.052406	 0.141345	 0.0028	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	3823	 3226	 0.034197	 0.096049	 0.0044	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 3228	 0.008642	 0.021975	 0.0011	 1285	 1285	 1285	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 3229	 0.022575	 0.071151	 0.0008	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	3427	 3233	 0.000229	 0.000419	 0.0527	 64823	 64823	 64823	 0.0	 0.0	 1	 -30.0	 30.0;
	3427	 3232	 0.000229	 0.000419	 0.0527	 64823	 64823	 64823	 0.0	 0.0	 1	 -30.0	 30.0;
	3427	 3231	 0.000284	 0.00052	 0.0461	 52241	 52241	 52241	 0.0	 0.0	 1	 -30.0	 30.0;
	4605	 3235	 0.027037	 0.055556	 0.0026	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	4606	 3234	 0.027037	 0.055556	 0.0026	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	5444	 3240	 0.107332	 0.252457	 0.0028	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	5539	 3241	 0.028219	 0.062736	 0.0007	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 3242	 0.014361	 0.028975	 0.0003	 914	 914	 914	 0.0	 0.0	 1	 -30.0	 30.0;
	4694	 3243	 4e-05	 0.001086	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4708	 3243	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4267	 3244	 0.012469	 0.051852	 0.0028	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 3244	 0.01284	 0.037037	 0.0016	 774	 774	 774	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 3245	 0.038549	 0.083144	 0.001	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	4632	 3246	 0.031998	 0.068027	 0.0007	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	5028	 3246	 0.045352	 0.09675	 0.001	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	5588	 3247	 0.050894	 0.128748	 0.0014	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 3248	 0.002041	 0.003736	 0.0002	 7124	 7124	 7124	 0.0	 0.0	 1	 -30.0	 30.0;
	4614	 3249	 0.124501	 0.227898	 0.0024	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 3250	 0.021605	 0.058765	 0.0028	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	4323	 3250	 0.042469	 0.107778	 0.005	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	5566	 3250	 0.029259	 0.074074	 0.0036	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	5841	 3251	 0.017637	 0.046611	 0.0006	 611	 611	 611	 0.0	 0.0	 1	 -30.0	 30.0;
	5754	 3251	 0.030234	 0.082389	 0.001	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	4787	 3252	 0.01	 0.027407	 0.0013	 1019	 1019	 1019	 0.0	 0.0	 1	 -30.0	 30.0;
	5649	 3252	 0.008642	 0.022222	 0.001	 1246	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	4146	 3253	 0.009007	 0.043872	 0.0749	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 3253	 0.002738	 0.018562	 0.04	 503.0	 503.0	 503.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5518	 3253	 0.002078	 0.008442	 0.0152	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3652	 3255	 0.004082	 0.00907	 0.0031	 3058	 3058	 3058	 0.0	 0.0	 1	 -30.0	 30.0;
	3652	 3254	 0.004082	 0.00907	 0.0031	 3058	 3058	 3058	 0.0	 0.0	 1	 -30.0	 30.0;
	3652	 3256	 0.004707	 0.008615	 0.0033	 3099	 3099	 3099	 0.0	 0.0	 1	 -30.0	 30.0;
	3437	 3258	 0.024568	 0.105062	 0.0049	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	4447	 3258	 0.01963	 0.05321	 0.0038	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	5195	 3258	 0.047284	 0.121728	 0.0058	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	4792	 3260	 0.043457	 0.183457	 0.0094	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	5322	 3261	 0.002704	 0.018296	 0.0008	 1606	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	4670	 3262	 0.021099	 0.079901	 0.0235	 375	 375	 375	 0.0	 0.0	 1	 -30.0	 30.0;
	3580	 3263	 2.8e-05	 0.000172	 0.0243	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5590	 3264	 0.009582	 0.017539	 0.0002	 1522	 1522	 1522	 0.0	 0.0	 1	 -30.0	 30.0;
	4556	 3266	 0.020569	 0.065387	 0.0217	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	3949	 3267	 0.000126	 0.000261	 0.0152	 106799	 106799	 106799	 0.0	 0.0	 1	 -30.0	 30.0;
	4238	 3269	 0.008062	 0.034266	 0.0004	 864	 864	 864	 0.0	 0.0	 1	 -30.0	 30.0;
	4240	 3270	 0.00083	 0.003931	 0.0071	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4884	 3270	 0.002825	 0.018943	 0.0344	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 3270	 0.003338	 0.019161	 0.0349	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4239	 3270	 0.00083	 0.003832	 0.0071	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4884	 3270	 0.002588	 0.017264	 0.0314	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4400	 3271	 0.000356	 0.000988	 0.1094	 280.0	 280.0	 280.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4770	 3272	 0.119848	 0.219381	 0.0023	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	4976	 3273	 0.002568	 0.011358	 0.1539	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5591	 3273	 0.000454	 0.00399	 0.3675	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4976	 3273	 0.000909	 0.007901	 0.4445	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5111	 3274	 0.090955	 0.301083	 0.0031	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	5129	 3274	 0.03351	 0.067271	 0.0007	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	5543	 3274	 0.039305	 0.132527	 0.0015	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	4473	 3276	 0.067271	 0.186445	 0.0021	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	3284	 3278	 2.5e-05	 0.015117	 0.0	 2012	 2012	 2012	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 3278	 0.013694	 0.025067	 0.0002	 1065	 1065	 1065	 0.0	 0.0	 1	 -30.0	 30.0;
	5615	 3278	 0.018392	 0.078105	 0.001	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	3283	 3278	 2.5e-05	 0.015117	 0.0	 2012	 2012	 2012	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 3278	 0.003729	 0.007886	 0.0071	 3487	 3487	 3487	 0.0	 0.0	 1	 -30.0	 30.0;
	5614	 3278	 0.018392	 0.078105	 0.001	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	3286	 3279	 2e-06	 0.001185	 0.0	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3285	 3279	 2e-06	 0.001185	 0.0	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4039	 3287	 0.000943	 0.001727	 0.0008	 15006	 15006	 15006	 0.0	 0.0	 1	 -30.0	 30.0;
	4333	 3291	 0.000425	 0.001934	 0.003	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 3294	 0.045603	 0.140338	 0.002	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5593	 3295	 0.006803	 0.014109	 0.001	 1885	 1885	 1885	 0.0	 0.0	 1	 -30.0	 30.0;
	3500	 3297	 0.009574	 0.051902	 0.0006	 577	 577	 577	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 3297	 0.015319	 0.073998	 0.0104	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 3298	 0.005798	 0.039696	 0.0724	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5782	 3298	 0.004938	 0.033165	 0.0607	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4649	 3300	 0.048123	 0.122197	 0.0013	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	4649	 3299	 0.048123	 0.122197	 0.0013	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	4277	 3301	 0.015569	 0.028499	 0.0003	 910	 910	 910	 0.0	 0.0	 1	 -30.0	 30.0;
	3399	 3302	 0.010859	 0.046964	 0.0052	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	4543	 3302	 0.003527	 0.008566	 0.0001	 3284	 3284	 3284	 0.0	 0.0	 1	 -30.0	 30.0;
	3399	 3302	 0.048375	 0.191988	 0.0019	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 3303	 0.015369	 0.043336	 0.0373	 643	 643	 643	 0.0	 0.0	 1	 -30.0	 30.0;
	5406	 3304	 0.043109	 0.117511	 0.0012	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	4209	 3306	 0.042026	 0.104837	 0.0139	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	5170	 3308	 0.028219	 0.071554	 0.0008	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	5756	 3308	 0.041068	 0.105568	 0.0012	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	5835	 3309	 0.000123	 0.001235	 0.0	 23932	 23932	 23932	 0.0	 0.0	 1	 -30.0	 30.0;
	4304	 3311	 0.006853	 0.042454	 0.075	 708	 708	 708	 0.0	 0.0	 1	 -30.0	 30.0;
	5381	 3311	 0.029353	 0.078786	 0.0009	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	5585	 3311	 0.007055	 0.02066	 0.0011	 1394	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	5750	 3311	 0.035021	 0.089065	 0.0016	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	3692	 3312	 0.001058	 0.001937	 0.161	 14024	 14024	 14024	 0.0	 0.0	 1	 -30.0	 30.0;
	4822	 3314	 0.003704	 0.008519	 0.0037	 3198	 3198	 3198	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 3315	 0.031728	 0.080494	 0.0037	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	5739	 3315	 0.048642	 0.123333	 0.0058	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5309	 3321	 0.004031	 0.013102	 0.0121	 2154	 2154	 2154	 0.0	 0.0	 1	 -30.0	 30.0;
	5691	 3321	 0.015621	 0.039808	 0.0017	 691	 691	 691	 0.0	 0.0	 1	 -30.0	 30.0;
	3914	 3322	 0.011842	 0.041824	 0.0472	 680	 680	 680	 0.0	 0.0	 1	 -30.0	 30.0;
	4103	 3323	 0.001027	 0.012543	 0.0243	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 3323	 0.006935	 0.036516	 0.0663	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4103	 3323	 0.001798	 0.012089	 0.0223	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3535	 3323	 4.8e-05	 8.8e-05	 0.001	 308192	 308192	 308192	 0.0	 0.0	 1	 -30.0	 30.0;
	3534	 3323	 4.8e-05	 8.8e-05	 0.001	 308192	 308192	 308192	 0.0	 0.0	 1	 -30.0	 30.0;
	3851	 3324	 0.008062	 0.019904	 0.0002	 1417	 1417	 1417	 0.0	 0.0	 1	 -30.0	 30.0;
	3428	 3326	 0.02037	 0.053951	 0.0026	 516	 516	 516	 0.0	 0.0	 1	 -30.0	 30.0;
	4285	 3327	 0.001111	 0.004568	 0.0002	 6319	 6319	 6319	 0.0	 0.0	 1	 -30.0	 30.0;
	3705	 3328	 0.005906	 0.026627	 0.0456	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3705	 3329	 0.005906	 0.026627	 0.0445	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 3331	 0.064979	 0.182263	 0.0021	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	5575	 3331	 0.044092	 0.112119	 0.0	 253	 253	 253	 0.0	 0.0	 1	 -30.0	 30.0;
	4847	 3333	 0.001039	 0.001902	 0.0048	 13624	 13624	 13624	 0.0	 0.0	 1	 -30.0	 30.0;
	4847	 3332	 0.00126	 0.004031	 0.0056	 6991	 6991	 6991	 0.0	 0.0	 1	 -30.0	 30.0;
	4289	 3335	 0.017385	 0.047367	 0.0102	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	5040	 3335	 0.07483	 0.18972	 0.0071	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	5325	 3335	 0.008617	 0.035097	 0.0015	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 3337	 0.02066	 0.056437	 0.0006	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 3339	 0.081975	 0.191605	 0.0088	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 3341	 0.003522	 0.006446	 0.0038	 3901	 3901	 3901	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 3340	 0.003522	 0.006446	 0.0036	 3901	 3901	 3901	 0.0	 0.0	 1	 -30.0	 30.0;
	4442	 3343	 0.068783	 0.125976	 0.0013	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5243	 3344	 0.000988	 0.001975	 0.0	 11822	 11822	 11822	 0.0	 0.0	 1	 -30.0	 30.0;
	5353	 3345	 0.010582	 0.028219	 0.0	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	3524	 3346	 0.004573	 0.020316	 0.0405	 289.0	 289.0	 289.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5618	 3348	 0.009259	 0.023457	 0.0011	 1178	 1178	 1178	 0.0	 0.0	 1	 -30.0	 30.0;
	3774	 3349	 0.028975	 0.194759	 0.0031	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 3349	 0.010834	 0.038801	 0.0005	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	5093	 3349	 0.005291	 0.022172	 0.0002	 1257	 1257	 1257	 0.0	 0.0	 1	 -30.0	 30.0;
	3774	 3349	 0.029226	 0.194507	 0.0031	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	5638	 3349	 0.009574	 0.037793	 0.0005	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	5772	 3349	 0.041068	 0.104308	 0.0012	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	4598	 3350	 0.002825	 0.019239	 0.0476	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5600	 3354	 0.014613	 0.029226	 0.0003	 931	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	5601	 3354	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 3355	 0.007559	 0.025447	 0.0239	 1146	 1146	 1146	 0.0	 0.0	 1	 -30.0	 30.0;
	5599	 3356	 0.030738	 0.075586	 0.0009	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	5598	 3357	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5486	 3358	 0.013086	 0.035309	 0.0016	 789	 789	 789	 0.0	 0.0	 1	 -30.0	 30.0;
	4961	 3358	 0.036173	 0.097654	 0.0047	 287	 287	 287	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 3359	 0.00952	 0.017427	 0.0134	 1443	 1443	 1443	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 3359	 0.010756	 0.019689	 0.0156	 1278	 1278	 1278	 0.0	 0.0	 1	 -30.0	 30.0;
	5328	 3361	 0.093726	 0.249685	 0.0028	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	4456	 3364	 0.007723	 0.044444	 0.082	 472.0	 472.0	 472.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3487	 3365	 0.002222	 0.005556	 0.0198	 4964	 4964	 4964	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 3365	 0.015309	 0.065926	 0.0032	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 3365	 0.015309	 0.065926	 0.0032	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	4578	 3366	 0.014916	 0.060544	 0.0006	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	4349	 3367	 0.001659	 0.011575	 0.0091	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4349	 3367	 0.001659	 0.011575	 0.0091	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 3370	 0.03351	 0.084404	 0.001	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 3370	 0.03351	 0.084656	 0.001	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	3373	 3372	 2.1e-05	 0.000339	 0.0087	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3374	 3372	 2.1e-05	 0.000325	 0.0087	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5607	 3375	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5122	 3376	 0.011338	 0.038549	 0.0	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	5225	 3376	 0.025498	 0.054926	 0.0008	 503	 503	 503	 0.0	 0.0	 1	 -30.0	 30.0;
	5609	 3378	 0.006299	 0.018392	 0.0	 1519	 1519	 1519	 0.0	 0.0	 1	 -30.0	 30.0;
	5610	 3379	 2.5e-05	 0.000123	 0.0002	 243304	 243304	 243304	 0.0	 0.0	 1	 -30.0	 30.0;
	3837	 3380	 0.039808	 0.137566	 0.0016	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	4339	 3380	 0.078861	 0.250945	 0.0029	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	3837	 3380	 0.039808	 0.13681	 0.0025	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	4121	 3381	 0.004741	 0.022124	 0.038	 320.0	 320.0	 320.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4407	 3382	 0.03321	 0.071358	 0.0032	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 3383	 0.014361	 0.039053	 0.0005	 816	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	5540	 3384	 0.013857	 0.039808	 0.0001	 805	 805	 805	 0.0	 0.0	 1	 -30.0	 30.0;
	5090	 3386	 0.14768	 0.270326	 0.001	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	3901	 3387	 0.030738	 0.083648	 0.0009	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	3901	 3387	 0.031746	 0.08642	 0.0009	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	5138	 3388	 0.199295	 0.440917	 0.005	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	4589	 3390	 0.000198	 0.000751	 0.0921	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3887	 3391	 0.01285	 0.032754	 0.0004	 865	 865	 865	 0.0	 0.0	 1	 -30.0	 30.0;
	4838	 3391	 0.041572	 0.105316	 0.0012	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	3924	 3396	 0.035273	 0.120181	 0.0014	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 3396	 0.048123	 0.131771	 0.0032	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	3925	 3396	 0.035273	 0.120181	 0.0014	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	5540	 3396	 0.045603	 0.131519	 0.0002	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	3926	 3397	 0.002133	 0.009659	 0.0162	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4295	 3398	 0.044848	 0.142857	 0.0017	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	3542	 3399	 0.03351	 0.11295	 0.0033	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	4335	 3399	 0.076846	 0.262535	 0.003	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	5303	 3399	 0.044092	 0.149912	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5516	 3399	 0.019652	 0.062232	 0.0007	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	4028	 3400	 0.002438	 0.016458	 0.0314	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4028	 3400	 0.00243	 0.016454	 0.0319	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5614	 3402	 0.001764	 0.007811	 0.0001	 3799	 3799	 3799	 0.0	 0.0	 1	 -30.0	 30.0;
	5485	 3403	 0.007307	 0.029982	 0.0004	 929	 929	 929	 0.0	 0.0	 1	 -30.0	 30.0;
	3405	 3404	 0.001512	 0.006551	 0.0001	 4524	 4524	 4524	 0.0	 0.0	 1	 -30.0	 30.0;
	4133	 3406	 0.057445	 0.119678	 0.0019	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	4044	 3407	 0.000356	 0.001422	 0.0	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5616	 3408	 0.000227	 0.000605	 0.0	 45692	 45692	 45692	 0.0	 0.0	 1	 -30.0	 30.0;
	4062	 3411	 0.029982	 0.082892	 0.001	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	3913	 3415	 0.077324	 0.210154	 0.0033	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	4969	 3416	 0.000616	 0.006627	 0.1531	 1754.0	 1754.0	 1754.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 3417	 0.004975	 0.009106	 0.0065	 2846	 2846	 2846	 0.0	 0.0	 1	 -30.0	 30.0;
	4455	 3418	 0.009574	 0.026707	 0.0	 1072	 1072	 1072	 0.0	 0.0	 1	 -30.0	 30.0;
	3982	 3419	 0.00716	 0.029506	 0.0015	 979	 979	 979	 0.0	 0.0	 1	 -30.0	 30.0;
	4036	 3419	 0.039877	 0.111605	 0.0052	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	3982	 3419	 0.00716	 0.029506	 0.0015	 979	 979	 979	 0.0	 0.0	 1	 -30.0	 30.0;
	4148	 3420	 0.034517	 0.135551	 0.0025	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 3421	 0.012593	 0.034444	 0.0016	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 3422	 0.036489	 0.066792	 0.0007	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	5555	 3422	 0.049887	 0.126732	 0.0014	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 3423	 0.038272	 0.080494	 0.0037	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	4329	 3424	 0.043084	 0.144873	 0.002	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	5414	 3426	 0.054674	 0.165281	 0.002	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	3883	 3427	 0.000776	 0.004612	 0.1736	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5124	 3427	 0.000119	 0.000691	 0.0076	 397.0	 397.0	 397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5123	 3427	 0.000119	 0.000711	 0.0071	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5372	 3427	 0.001126	 0.005965	 0.0162	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3737	 3429	 0.051146	 0.212094	 0.0081	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	3894	 3429	 0.104208	 0.284303	 0.0028	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	5126	 3431	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	4350	 3432	 0.013901	 0.039222	 0.002	 729	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 3432	 0.011605	 0.032963	 0.0	 868	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	4350	 3432	 0.01358	 0.039012	 0.0019	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	5623	 3434	 0.017778	 0.049753	 0.0023	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	3525	 3437	 0.043827	 0.090247	 0.0454	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 3439	 0.050643	 0.136054	 0.0015	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	5587	 3439	 0.034266	 0.093978	 0.001	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	3773	 3441	 0.066112	 0.16775	 0.0019	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	4916	 3442	 0.032364	 0.095227	 0.0297	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	5624	 3443	 0.028219	 0.078105	 0.0008	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	3447	 3444	 0.063492	 0.168556	 0.002	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	4243	 3444	 0.01033	 0.019148	 0.0204	 1358	 1358	 1358	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 3444	 0.017889	 0.045603	 0.0021	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	5774	 3445	 0.035273	 0.121693	 0.0014	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5625	 3446	 0.000302	 0.00252	 0.0001	 13401	 13401	 13401	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 3447	 0.102797	 0.27614	 0.003	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 3448	 0.05039	 0.138574	 0.0015	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 3449	 0.008284	 0.020679	 0.001	 1334	 1334	 1334	 0.0	 0.0	 1	 -30.0	 30.0;
	5626	 3451	 0.02066	 0.056689	 0.0006	 490	 490	 490	 0.0	 0.0	 1	 -30.0	 30.0;
	5235	 3453	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5236	 3453	 0.000252	 0.00252	 0.0006	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5343	 3453	 0.079012	 0.200277	 0.0023	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 3454	 0.008272	 0.021111	 0.0042	 1338	 1338	 1338	 0.0	 0.0	 1	 -30.0	 30.0;
	4919	 3455	 0.004568	 0.012963	 0.0463	 2162	 2162	 2162	 0.0	 0.0	 1	 -30.0	 30.0;
	4967	 3455	 0.004444	 0.018889	 0.0028	 1531	 1531	 1531	 0.0	 0.0	 1	 -30.0	 30.0;
	4967	 3455	 0.004444	 0.018765	 0.0028	 1541	 1541	 1541	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 3456	 0.016377	 0.0451	 0.0005	 634	 634	 634	 0.0	 0.0	 1	 -30.0	 30.0;
	3556	 3457	 0.023683	 0.137818	 0.0132	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	5538	 3459	 0.00379	 0.015753	 0.0008	 1834	 1834	 1834	 0.0	 0.0	 1	 -30.0	 30.0;
	4014	 3460	 0.007407	 0.020247	 0.001	 1378	 1378	 1378	 0.0	 0.0	 1	 -30.0	 30.0;
	5777	 3461	 0.062988	 0.171328	 0.005	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	5628	 3462	 0.042555	 0.090678	 0.001	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	4778	 3463	 0.017637	 0.075334	 0.002	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	5273	 3466	 0.024568	 0.065432	 0.0031	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	5629	 3468	 0.001008	 0.002771	 0.0	 10014	 10014	 10014	 0.0	 0.0	 1	 -30.0	 30.0;
	3515	 3469	 0.022593	 0.102222	 0.005	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	3752	 3470	 0.001993	 0.020458	 0.0638	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3752	 3470	 0.001993	 0.020472	 0.0638	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 3473	 0.001966	 0.003599	 0.0024	 6987	 6987	 6987	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 3475	 0.001367	 0.002502	 0.0013	 10050	 10050	 10050	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 3472	 0.001284	 0.00235	 0.0013	 10699	 10699	 10699	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 3474	 0.001025	 0.001876	 0.001	 13403	 13403	 13403	 0.0	 0.0	 1	 -30.0	 30.0;
	4876	 3481	 0.003527	 0.007055	 0.0069	 3633	 3633	 3633	 0.0	 0.0	 1	 -30.0	 30.0;
	4876	 3480	 0.003527	 0.007055	 0.0069	 3633	 3633	 3633	 0.0	 0.0	 1	 -30.0	 30.0;
	5329	 3482	 0.027463	 0.092215	 0.001	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	5378	 3482	 0.018141	 0.058957	 0.0007	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	5477	 3482	 0.002016	 0.01285	 0.0002	 2203	 2203	 2203	 0.0	 0.0	 1	 -30.0	 30.0;
	5358	 3482	 0.027211	 0.0839	 0.001	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	5506	 3482	 0.006551	 0.019652	 0.0002	 1384	 1384	 1384	 0.0	 0.0	 1	 -30.0	 30.0;
	5557	 3482	 0.006803	 0.02066	 0.0002	 1318	 1318	 1318	 0.0	 0.0	 1	 -30.0	 30.0;
	3721	 3484	 0.077161	 0.214321	 0.0341	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 3485	 0.002686	 0.018173	 0.0324	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4229	 3485	 0.005748	 0.03836	 0.0688	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4402	 3486	 0.122222	 0.31804	 0.0041	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 3486	 0.03477	 0.095238	 0.0012	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	3546	 3488	 0.097254	 0.284455	 0.0034	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	4125	 3488	 0.039808	 0.166793	 0.0021	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 3490	 0.005562	 0.010181	 0.0001	 2546	 2546	 2546	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 3492	 0.007037	 0.023951	 0.0011	 1190	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	4456	 3493	 0.000277	 0.002588	 0.0051	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4320	 3494	 0.043739	 0.148602	 0.0017	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	4408	 3494	 0.044696	 0.118317	 0.0016	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 3494	 0.02973	 0.08516	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5484	 3494	 0.029982	 0.085664	 0.0	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	5631	 3495	 0.027715	 0.077601	 0.0009	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	4389	 3497	 0.008566	 0.055682	 0.0007	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	4751	 3497	 0.052381	 0.142605	 0.0019	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 3497	 0.007559	 0.017385	 0.0015	 1605	 1605	 1605	 0.0	 0.0	 1	 -30.0	 30.0;
	4389	 3497	 0.008566	 0.055682	 0.0007	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	3568	 3498	 0.035556	 0.097037	 0.0045	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5052	 3498	 0.024198	 0.064444	 0.0242	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	5052	 3498	 0.024198	 0.064444	 0.0242	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	5632	 3499	 0.027211	 0.062988	 0.0007	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 3500	 0.008566	 0.03477	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	3504	 1497	 2e-05	 0.000198	 0.0	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5277	 3507	 0.000252	 0.001008	 0.0	 28417	 28417	 28417	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 3508	 0.006608	 0.012096	 0.0002	 2143	 2143	 2143	 0.0	 0.0	 1	 -30.0	 30.0;
	4011	 3509	 0.067422	 0.186621	 0.0021	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	4566	 3509	 0.06198	 0.216931	 0.002	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 3509	 0.059965	 0.147896	 0.0017	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	5634	 3509	 0.003527	 0.007811	 0.0	 3446	 3446	 3446	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 3510	 0.002647	 0.011911	 0.0213	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 3511	 0.010582	 0.02973	 0.0003	 936	 936	 936	 0.0	 0.0	 1	 -30.0	 30.0;
	4788	 3512	 0.020741	 0.058272	 0.0026	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	4017	 3513	 0.014059	 0.045578	 0.0006	 620	 620	 620	 0.0	 0.0	 1	 -30.0	 30.0;
	3879	 3514	 0.108592	 0.296548	 0.0033	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	3982	 3515	 0.008272	 0.056173	 0.0028	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	4833	 3515	 0.047654	 0.197901	 0.0102	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 3515	 0.011482	 0.072099	 0.0039	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	3982	 3515	 0.007531	 0.052593	 0.0028	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	3982	 3515	 0.007778	 0.055556	 0.0029	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	4035	 3518	 0.083648	 0.239859	 0.0026	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	4035	 3518	 0.0839	 0.240615	 0.0026	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	4107	 3519	 0.001659	 0.011081	 0.0203	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4107	 3519	 0.002509	 0.011319	 0.0203	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3837	 3520	 0.012346	 0.039053	 0.0005	 743	 743	 743	 0.0	 0.0	 1	 -30.0	 30.0;
	4549	 3523	 0.008818	 0.038045	 0.0	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	5007	 3522	 0.013857	 0.047115	 0.001	 602	 602	 602	 0.0	 0.0	 1	 -30.0	 30.0;
	5385	 3523	 0.030486	 0.07735	 0.003	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	5790	 3522	 0.008818	 0.037793	 0.0	 761	 761	 761	 0.0	 0.0	 1	 -30.0	 30.0;
	4794	 3524	 0.004523	 0.026983	 0.0506	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4049	 3529	 0.000928	 0.006183	 0.0111	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5714	 3529	 0.000217	 0.001481	 0.003	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5823	 3530	 7e-06	 0.00013	 0.0029	 2694.0	 2694.0	 2694.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4425	 3531	 0.04258	 0.102797	 0.0067	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	5638	 3533	 0.001764	 0.003527	 0.0013	 7266	 7266	 7266	 0.0	 0.0	 1	 -30.0	 30.0;
	5640	 3536	 0.00068	 0.00126	 0.0	 21242	 21242	 21242	 0.0	 0.0	 1	 -30.0	 30.0;
	4174	 3537	 0.004031	 0.01285	 0.0002	 2259	 2259	 2259	 0.0	 0.0	 1	 -30.0	 30.0;
	4815	 3539	 0.001605	 0.007407	 0.0296	 4085	 4085	 4085	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 3539	 0.016173	 0.061728	 0.0005	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	5431	 3539	 0.001235	 0.004938	 0.0141	 6818	 6818	 6818	 0.0	 0.0	 1	 -30.0	 30.0;
	4105	 3540	 0.000111	 0.000741	 0.0014	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4879	 3540	 0.001857	 0.008375	 0.0142	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4104	 3540	 9.9e-05	 0.000711	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4264	 3541	 0.000198	 0.000909	 0.001	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5831	 3542	 0.070547	 0.232552	 0.0026	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	4061	 3546	 0.08642	 0.205341	 0.0029	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	4125	 3546	 0.032754	 0.137818	 0.0022	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	5422	 3546	 0.049131	 0.134039	 0.0015	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	5643	 3549	 0.019652	 0.082389	 0.0001	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 3551	 0.016377	 0.041572	 0.0005	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 3551	 0.008566	 0.027715	 0.0006	 1049	 1049	 1049	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 3551	 0.01285	 0.040816	 0.0005	 711	 711	 711	 0.0	 0.0	 1	 -30.0	 30.0;
	5644	 3553	 0.000494	 0.001358	 0.0	 20555	 20555	 20555	 0.0	 0.0	 1	 -30.0	 30.0;
	5015	 3554	 0.000252	 0.00126	 0.0012	 23000	 23000	 23000	 0.0	 0.0	 1	 -30.0	 30.0;
	4362	 3555	 0.076846	 0.15999	 0.009	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	4888	 3556	 0.039305	 0.134039	 0.0016	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5176	 3556	 0.007055	 0.0451	 0.0006	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	5477	 3556	 0.033006	 0.10456	 0.005	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	5529	 3556	 0.056689	 0.119174	 0.0099	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	5706	 3556	 0.069539	 0.23608	 0.0028	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	5180	 3556	 0.007055	 0.044596	 0.0006	 635	 635	 635	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 3559	 0.007811	 0.014297	 0.0088	 1867	 1867	 1867	 0.0	 0.0	 1	 -30.0	 30.0;
	4886	 3560	 0.015117	 0.051146	 0.003	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	4886	 3560	 0.020912	 0.056941	 0.0007	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	3880	 3561	 0.013274	 0.060326	 0.1043	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 3562	 0.000252	 0.00252	 0.001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	3566	 3563	 2e-05	 0.000198	 0.0091	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3566	 3564	 2e-05	 0.000198	 0.0051	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4018	 3567	 0.045352	 0.126984	 0.0081	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	4218	 3567	 0.114215	 0.20907	 0.0039	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	5337	 3568	 0.031605	 0.086173	 0.004	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	5129	 3569	 0.023683	 0.0645	 0.0007	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	4722	 3570	 0.022728	 0.059679	 0.0032	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	4668	 3571	 0.019136	 0.049012	 0.0023	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	4011	 3572	 0.053918	 0.133787	 0.002	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	4566	 3572	 0.023683	 0.056941	 0.001	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	4011	 3572	 0.053666	 0.133787	 0.001	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	3983	 3573	 0.105064	 0.214412	 0.002	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 3574	 0.004701	 0.030064	 0.0547	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3370	 3577	 0.105064	 0.275888	 0.0034	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	5631	 3577	 0.044596	 0.125472	 0.0013	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	4047	 3580	 0.001343	 0.007862	 0.0142	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4505	 3582	 2.8e-05	 0.000145	 0.0606	 855.0	 855.0	 855.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5645	 3581	 5e-06	 0.0001	 0.0	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3581	 1495	 1e-05	 0.0001	 0.0	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4517	 3583	 0.026455	 0.072562	 0.0008	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	5716	 3583	 0.032552	 0.067674	 0.0007	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	3846	 3585	 0.002431	 0.004449	 0.0121	 5982	 5982	 5982	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 3585	 0.052839	 0.133951	 0.0084	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	5342	 3585	 0.020123	 0.051358	 0.0123	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	5838	 3585	 0.022839	 0.058025	 0.007	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	4649	 3586	 0.000504	 0.00252	 0.0004	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 3589	 0.000252	 0.000504	 0.001	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5648	 3590	 0.000252	 0.000504	 0.001	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 3591	 0.00907	 0.0226	 0.0002	 1249	 1249	 1249	 0.0	 0.0	 1	 -30.0	 30.0;
	3887	 3591	 0.003779	 0.015873	 0.0133	 1864	 1864	 1864	 0.0	 0.0	 1	 -30.0	 30.0;
	5647	 3593	 9.9e-05	 0.000182	 0.0004	 151236	 151236	 151236	 0.0	 0.0	 1	 -30.0	 30.0;
	5479	 3594	 0.00073	 0.001335	 0.1104	 20343	 20343	 20343	 0.0	 0.0	 1	 -30.0	 30.0;
	3430	 3595	 0.002016	 0.005543	 0.0001	 5006	 5006	 5006	 0.0	 0.0	 1	 -30.0	 30.0;
	3988	 3595	 0.028975	 0.121945	 0.0015	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 3596	 0.018038	 0.057792	 0.0916	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	5456	 3596	 0.001798	 0.004543	 0.0081	 6284	 6284	 6284	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 3597	 0.015873	 0.106828	 0.0018	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	5455	 3601	 0.02973	 0.080877	 0.0009	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	5369	 3602	 0.016864	 0.057074	 0.0042	 510	 510	 510	 0.0	 0.0	 1	 -30.0	 30.0;
	5570	 3602	 0.009136	 0.029136	 0.0015	 994	 994	 994	 0.0	 0.0	 1	 -30.0	 30.0;
	4307	 3604	 0.005039	 0.03351	 0.0009	 872	 872	 872	 0.0	 0.0	 1	 -30.0	 30.0;
	5606	 3604	 0.013605	 0.056437	 0.0007	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	4190	 3607	 8e-06	 0.0001	 0.002	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4189	 3607	 8e-06	 0.0001	 0.002	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5306	 3608	 0.006543	 0.017284	 0.0008	 1641	 1641	 1641	 0.0	 0.0	 1	 -30.0	 30.0;
	4326	 3609	 0.000909	 0.003299	 0.0051	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4235	 3610	 0.058201	 0.159486	 0.0021	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4193	 3612	 0.02318	 0.078609	 0.0018	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	4615	 3612	 0.023935	 0.098765	 0.0019	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5625	 3612	 0.005039	 0.022424	 0.0005	 1476	 1476	 1476	 0.0	 0.0	 1	 -30.0	 30.0;
	5652	 3613	 0.049635	 0.125976	 0.0014	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	3395	 3616	 0.002627	 0.017284	 0.0435	 1771	 1771	 1771	 0.0	 0.0	 1	 -30.0	 30.0;
	4049	 3616	 0.002272	 0.011239	 0.0203	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 3616	 0.002574	 0.013541	 0.0349	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4640	 3614	 0.001817	 0.012207	 0.0223	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5023	 3614	 0.000375	 0.002509	 0.0051	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5394	 3616	 0.000356	 0.002311	 0.004	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5472	 3615	 0.003081	 0.020089	 0.0375	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5022	 3615	 0.000375	 0.002528	 0.0051	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5181	 3616	 0.001798	 0.010133	 0.0182	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 3616	 0.00097	 0.009481	 0.037	 720.0	 720.0	 720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 3614	 0.001067	 0.007091	 0.0132	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5184	 3616	 0.000751	 0.007423	 0.0248	 833.0	 833.0	 833.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5350	 3614	 0.001067	 0.007091	 0.0132	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3368	 3617	 0.00099	 0.007576	 0.156	 1486.0	 1486.0	 1486.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4050	 3618	 0.000298	 0.003262	 0.0693	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4600	 3618	 0.000561	 0.006288	 0.1574	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 3618	 0.000554	 0.006163	 0.1588	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4600	 3617	 0.000382	 0.005002	 0.1718	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 3617	 0.000381	 0.005	 0.1733	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4977	 3617	 0.000547	 0.006046	 0.1242	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4508	 3620	 0.040741	 0.087161	 0.004	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	5200	 3619	 0.003333	 0.008889	 0.0005	 3129	 3129	 3129	 0.0	 0.0	 1	 -30.0	 30.0;
	3406	 3621	 0.026455	 0.054674	 0.002	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	3406	 3621	 0.010859	 0.026153	 0.0501	 1043	 1043	 1043	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 3623	 0.048324	 0.129478	 0.0026	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 3623	 0.078045	 0.142861	 0.0014	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 3623	 0.048803	 0.125926	 0.0021	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	4614	 3624	 0.063492	 0.141345	 0.001	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 3625	 0.006262	 0.043595	 0.078	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 3625	 0.001659	 0.011022	 0.0203	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5265	 3625	 0.002744	 0.018746	 0.0349	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 3625	 0.001659	 0.011042	 0.0203	 538.0	 538.0	 538.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5654	 3627	 0.001764	 0.004283	 0.0001	 6375	 6375	 6375	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 3629	 0.000936	 0.001713	 0.0023	 15535	 15535	 15535	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 3628	 0.000936	 0.001713	 0.0023	 15535	 15535	 15535	 0.0	 0.0	 1	 -30.0	 30.0;
	4742	 3631	 0.022424	 0.054926	 0.0064	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	4742	 3630	 0.02318	 0.056437	 0.0066	 484	 484	 484	 0.0	 0.0	 1	 -30.0	 30.0;
	5327	 3632	 0.00284	 0.009877	 0.0018	 2951	 2951	 2951	 0.0	 0.0	 1	 -30.0	 30.0;
	5586	 3632	 0.004593	 0.011444	 0.0005	 2460	 2460	 2460	 0.0	 0.0	 1	 -30.0	 30.0;
	4470	 3632	 0.000345	 0.000632	 0.0011	 42115	 42115	 42115	 0.0	 0.0	 1	 -30.0	 30.0;
	3464	 3632	 0.001131	 0.00207	 0.0032	 12856	 12856	 12856	 0.0	 0.0	 1	 -30.0	 30.0;
	3747	 3633	 0.003694	 0.02481	 0.0456	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3907	 3633	 0.002963	 0.019793	 0.0694	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4006	 3633	 0.002647	 0.017659	 0.0324	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4828	 3633	 0.00719	 0.033264	 0.0618	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 3634	 0.016813	 0.030776	 0.0213	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	5339	 3636	 0.014361	 0.048375	 0.0006	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 3636	 0.030234	 0.092719	 0.0025	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	5812	 3638	 0.006803	 0.015621	 0.0002	 1733	 1733	 1733	 0.0	 0.0	 1	 -30.0	 30.0;
	4073	 3639	 0.054321	 0.138148	 0.0063	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5520	 3642	 0.007813	 0.014301	 0.0087	 1759	 1759	 1759	 0.0	 0.0	 1	 -30.0	 30.0;
	5519	 3643	 0.007569	 0.013855	 0.0089	 1815	 1815	 1815	 0.0	 0.0	 1	 -30.0	 30.0;
	5655	 3645	 0.000123	 0.001235	 0.0002	 23932	 23932	 23932	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 3647	 0.023935	 0.076846	 0.0009	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	5573	 3648	 0.096926	 0.251323	 0.0028	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	5208	 3649	 0.002771	 0.011842	 0.0177	 2428	 2428	 2428	 0.0	 0.0	 1	 -30.0	 30.0;
	3932	 3650	 0.003457	 0.015704	 0.0284	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4572	 3650	 0.00164	 0.021709	 0.0911	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3532	 3652	 0.006327	 0.011581	 0.0051	 2305	 2305	 2305	 0.0	 0.0	 1	 -30.0	 30.0;
	3656	 3652	 0.012572	 0.03865	 0.0009	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	3860	 3652	 0.002645	 0.01091	 0.0145	 2710	 2710	 2710	 0.0	 0.0	 1	 -30.0	 30.0;
	3656	 3652	 0.01101	 0.04447	 0.0006	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	4174	 3653	 0.022525	 0.063492	 0.0007	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	4487	 3655	 0.007307	 0.035525	 0.0005	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	4486	 3655	 0.0097	 0.039632	 0.0004	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	4182	 3657	 2e-05	 9.9e-05	 0.0121	 457.0	 457.0	 457.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 3657	 0.000435	 0.002878	 0.0051	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5564	 3659	 0.017385	 0.044344	 0.0005	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	3661	 3660	 0.00252	 0.005039	 0.0	 5241	 5241	 5241	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 3660	 0.006922	 0.012671	 0.004	 2045	 2045	 2045	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 3661	 0.001512	 0.003527	 0.0	 7695	 7695	 7695	 0.0	 0.0	 1	 -30.0	 30.0;
	5768	 3663	 0.022676	 0.041824	 0.0004	 621	 621	 621	 0.0	 0.0	 1	 -30.0	 30.0;
	3677	 3664	 0.007559	 0.020156	 0.0002	 1413	 1413	 1413	 0.0	 0.0	 1	 -30.0	 30.0;
	3678	 3664	 0.017889	 0.044344	 0.0005	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	4218	 3664	 0.03477	 0.080625	 0.022	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	4019	 3665	 0.003931	 0.020365	 0.037	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4220	 3665	 0.002805	 0.012484	 0.0319	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3700	 3666	 0.069035	 0.197531	 0.0021	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 3666	 0.000151	 0.000479	 0.0002	 58788	 58788	 58788	 0.0	 0.0	 1	 -30.0	 30.0;
	5624	 3666	 0.029226	 0.080877	 0.0009	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 3666	 0.080373	 0.238095	 0.0649	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	4184	 3667	 0.007309	 0.049876	 0.0881	 538.0	 538.0	 538.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4608	 3667	 0.006044	 0.042114	 0.0729	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4424	 3668	 0.009826	 0.020912	 0.0009	 1278	 1278	 1278	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 3668	 0.030234	 0.082389	 0.001	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 3669	 0.0052	 0.009518	 0.0	 2723	 2723	 2723	 0.0	 0.0	 1	 -30.0	 30.0;
	4688	 3670	 0.043084	 0.135047	 0.002	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	3695	 3671	 0.020864	 0.088765	 0.0064	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	3893	 3673	 0.040237	 0.102268	 0.0012	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 3675	 0.016444	 0.060815	 0.0046	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	4161	 3675	 0.000988	 0.002099	 0.0006	 13072	 13072	 13072	 0.0	 0.0	 1	 -30.0	 30.0;
	3747	 3676	 0.000612	 0.004128	 0.0081	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3981	 3676	 0.001225	 0.006854	 0.1397	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4006	 3676	 0.001738	 0.011615	 0.0213	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 3679	 0.036105	 0.110809	 0.0021	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	3310	 3680	 0.001059	 0.003597	 0.0458	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3852	 3680	 0.009699	 0.044839	 0.0749	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4399	 3680	 0.001426	 0.009276	 0.0292	 366.0	 366.0	 366.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4557	 3680	 0.014143	 0.064395	 0.1134	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 3680	 0.003502	 0.02318	 0.0547	 366.0	 366.0	 366.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 3680	 0.004543	 0.024889	 0.0435	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4847	 3682	 0.018645	 0.037037	 0.0183	 713	 713	 713	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 3684	 2e-05	 9.8e-05	 0.0	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3311	 3686	 0.02192	 0.062232	 0.0027	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	5585	 3686	 0.016125	 0.044596	 0.0005	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	5660	 3687	 0.003275	 0.00907	 0.0	 3062	 3062	 3062	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 3688	 2e-05	 0.000198	 0.001	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5420	 3689	 0.014361	 0.036029	 0.001	 762	 762	 762	 0.0	 0.0	 1	 -30.0	 30.0;
	5661	 3689	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 3689	 0.022172	 0.046107	 0.001	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	4944	 3689	 0.014555	 0.026643	 0.0004	 973	 973	 973	 0.0	 0.0	 1	 -30.0	 30.0;
	5663	 3690	 5.9e-05	 0.000356	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4615	 3691	 0.016352	 0.067347	 0.0015	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	4324	 3696	 0.065004	 0.177375	 0.002	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 3696	 0.069287	 0.190224	 0.0021	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	5558	 3697	 0.048963	 0.089626	 0.0009	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 3698	 0.119678	 0.248929	 0.0034	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 3701	 0.006803	 0.027967	 0.0073	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 3701	 0.002771	 0.009826	 0.0001	 2893	 2893	 2893	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 3701	 0.006803	 0.027967	 0.0073	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	4232	 3702	 0.012497	 0.033132	 0.0009	 834	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 3703	 0.06389	 0.11695	 0.0012	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 3704	 0.001126	 0.005037	 0.0091	 5986	 5986	 5986	 0.0	 0.0	 1	 -30.0	 30.0;
	4245	 3705	 0.004642	 0.030854	 0.0557	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5098	 3705	 0.001578	 0.010526	 0.0192	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5665	 3705	 0.000119	 0.000889	 0.002	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4547	 3711	 0.001351	 0.008986	 0.0303	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4496	 3712	 0.001512	 0.005039	 0.0123	 5613	 5613	 5613	 0.0	 0.0	 1	 -30.0	 30.0;
	4495	 3712	 0.003779	 0.014865	 0.0185	 1925	 1925	 1925	 0.0	 0.0	 1	 -30.0	 30.0;
	5211	 3713	 0.001027	 0.006123	 0.2162	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4180	 3715	 0.010741	 0.027407	 0.0013	 1010	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	4790	 3715	 0.018272	 0.047901	 0.0023	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	4315	 3716	 0.000123	 0.000247	 0.0003	 109898	 109898	 109898	 0.0	 0.0	 1	 -30.0	 30.0;
	5667	 3717	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	4915	 3719	 0.084404	 0.230234	 0.0026	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	5668	 3720	 0.000454	 0.001235	 0.0001	 21775	 21775	 21775	 0.0	 0.0	 1	 -30.0	 30.0;
	4366	 3724	 0.026455	 0.058957	 0.0092	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	5090	 3728	 0.005926	 0.013827	 0.0	 1736	 1736	 1736	 0.0	 0.0	 1	 -30.0	 30.0;
	5101	 3728	 0.059259	 0.141284	 0.0005	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5670	 3731	 0.000194	 0.000624	 0.0009	 47367	 47367	 47367	 0.0	 0.0	 1	 -30.0	 30.0;
	4331	 3732	 0.015621	 0.066264	 0.0014	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	5669	 3734	 0.019331	 0.035384	 0.0003	 711	 711	 711	 0.0	 0.0	 1	 -30.0	 30.0;
	5772	 3733	 0.062736	 0.175611	 0.0017	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	4267	 3735	 0.003333	 0.026667	 0.0959	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	5330	 3736	 0.001146	 0.007625	 0.0142	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3723	 3737	 0.00126	 0.00252	 0.0031	 10480	 10480	 10480	 0.0	 0.0	 1	 -30.0	 30.0;
	4429	 3737	 0.007811	 0.043588	 0.0154	 667	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	4537	 3737	 0.044596	 0.151927	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	4429	 3737	 0.007811	 0.04384	 0.0155	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	3727	 3739	 9.9e-05	 0.000198	 0.0142	 138682	 138682	 138682	 0.0	 0.0	 1	 -30.0	 30.0;
	3726	 3739	 9.9e-05	 0.000198	 0.0182	 138682	 138682	 138682	 0.0	 0.0	 1	 -30.0	 30.0;
	4576	 3738	 9.9e-05	 0.000988	 0.004	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3725	 3739	 0.000111	 0.000223	 0.0213	 123245	 123245	 123245	 0.0	 0.0	 1	 -30.0	 30.0;
	4795	 3742	 0.001512	 0.002771	 0.0018	 9077	 9077	 9077	 0.0	 0.0	 1	 -30.0	 30.0;
	3932	 3744	 0.003477	 0.023822	 0.0456	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3873	 3747	 0.000324	 0.000992	 0.0729	 29733	 29733	 29733	 0.0	 0.0	 1	 -30.0	 30.0;
	5403	 3748	 0.019259	 0.038642	 0.0016	 688	 688	 688	 0.0	 0.0	 1	 -30.0	 30.0;
	5671	 3751	 0.017709	 0.032416	 0.0003	 824	 824	 824	 0.0	 0.0	 1	 -30.0	 30.0;
	4103	 3752	 0.00081	 0.005472	 0.0101	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4103	 3752	 0.000751	 0.005057	 0.0127	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4574	 3753	 0.001884	 0.019197	 0.4621	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4574	 3753	 0.001891	 0.019134	 0.4621	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4809	 3754	 0.046173	 0.123827	 0.0061	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 3755	 0.029226	 0.076846	 0.0009	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 3756	 0.015667	 0.042753	 0.0019	 653	 653	 653	 0.0	 0.0	 1	 -30.0	 30.0;
	5436	 3758	 0.007889	 0.021309	 0.001	 1308	 1308	 1308	 0.0	 0.0	 1	 -30.0	 30.0;
	4489	 3759	 0.047367	 0.19224	 0.0025	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	4526	 3759	 0.083396	 0.277904	 0.0035	 102	 102	 102	 0.0	 0.0	 1	 -30.0	 30.0;
	5291	 3760	 0.001462	 0.009817	 0.0177	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 3763	 0.00126	 0.00252	 0.0024	 10170	 10170	 10170	 0.0	 0.0	 1	 -30.0	 30.0;
	3860	 3764	 0.007357	 0.027438	 0.0096	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	3876	 3764	 0.056614	 0.174528	 0.0021	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	4716	 3764	 0.021794	 0.095692	 0.012	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5060	 3764	 0.042504	 0.080071	 0.0011	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	4331	 3766	 0.03545	 0.095036	 0.0018	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	5412	 3767	 0.048148	 0.135062	 0.0062	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 3771	 0.000237	 0.001501	 0.003	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4389	 3773	 0.016377	 0.067271	 0.0008	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	4617	 3773	 0.090199	 0.224994	 0.0258	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	4389	 3773	 0.016377	 0.067271	 0.0008	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	5505	 3774	 0.015923	 0.064727	 0.0034	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 3774	 0.009574	 0.062232	 0.0008	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	4729	 3774	 0.01159	 0.073822	 0.001	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 3775	 0.000402	 0.005242	 0.1791	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4600	 3775	 0.000402	 0.005242	 0.1819	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5042	 3776	 0.057697	 0.196271	 0.0023	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	4752	 3787	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4710	 3788	 5.9e-05	 0.001126	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4709	 3787	 5.9e-05	 0.001126	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4726	 3795	 0.012099	 0.031852	 0.0015	 890	 890	 890	 0.0	 0.0	 1	 -30.0	 30.0;
	5692	 3795	 0.020617	 0.054198	 0.0026	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	4442	 3796	 0.009826	 0.032754	 0.0037	 864	 864	 864	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 3796	 0.004031	 0.013605	 0.0002	 2081	 2081	 2081	 0.0	 0.0	 1	 -30.0	 30.0;
	4454	 3797	 0.111867	 0.241875	 0.0026	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	5813	 3797	 0.02318	 0.062988	 0.0007	 454	 454	 454	 0.0	 0.0	 1	 -30.0	 30.0;
	4122	 3800	 0.023683	 0.101789	 0.0012	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 3801	 0.038801	 0.073066	 0.0008	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	4821	 3803	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	4823	 3803	 0.005795	 0.014865	 0.0	 1851	 1851	 1851	 0.0	 0.0	 1	 -30.0	 30.0;
	4820	 3803	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 3805	 0.000366	 0.000669	 0.0476	 40590	 40590	 40590	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 3804	 0.000352	 0.000645	 0.0466	 42124	 42124	 42124	 0.0	 0.0	 1	 -30.0	 30.0;
	3996	 3810	 0.003779	 0.007055	 0.0001	 3801	 3801	 3801	 0.0	 0.0	 1	 -30.0	 30.0;
	4284	 3810	 0.090627	 0.196951	 0.0022	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	4374	 3810	 0.17158	 0.354497	 0.0037	 78	 78	 78	 0.0	 0.0	 1	 -30.0	 30.0;
	5198	 3810	 0.082766	 0.238524	 0.0024	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5515	 3810	 0.066767	 0.18191	 0.002	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3996	 3810	 0.003864	 0.007073	 0.0001	 3774	 3774	 3774	 0.0	 0.0	 1	 -30.0	 30.0;
	4731	 3811	 0.003121	 0.020997	 0.0385	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 3811	 0.004602	 0.0208	 0.0365	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 3812	 0.002694	 0.028476	 0.6599	 1115	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	4992	 3814	 0.000751	 0.003417	 0.0061	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4081	 3815	 0.075107	 0.190199	 0.0033	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	3822	 3816	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	3821	 3816	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	3820	 3816	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4081	 3825	 0.041245	 0.109851	 0.0051	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 3826	 0.004233	 0.018695	 0.0293	 1495	 1495	 1495	 0.0	 0.0	 1	 -30.0	 30.0;
	4120	 3827	 0.018392	 0.117158	 0.0001	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	5678	 3828	 0.00083	 0.005491	 0.0101	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4159	 3830	 0.000375	 0.001422	 0.1893	 263.0	 263.0	 263.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4159	 3829	 0.000395	 0.001422	 0.1903	 21022	 21022	 21022	 0.0	 0.0	 1	 -30.0	 30.0;
	3886	 3832	 0.01741	 0.068582	 0.0008	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	3976	 3832	 0.013782	 0.036886	 0.0063	 773	 773	 773	 0.0	 0.0	 1	 -30.0	 30.0;
	4332	 3831	 0.00907	 0.038549	 0.0005	 768	 768	 768	 0.0	 0.0	 1	 -30.0	 30.0;
	3975	 3831	 0.013706	 0.045931	 0.0042	 635	 635	 635	 0.0	 0.0	 1	 -30.0	 30.0;
	4332	 3832	 0.00907	 0.038801	 0.0005	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	4333	 3833	 0.000494	 0.002963	 0.0051	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5065	 3836	 0.018889	 0.071482	 0.0006	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	4540	 3838	 0.129252	 0.352734	 0.005	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	5281	 3839	 0.004006	 0.010129	 0.0054	 2711	 2711	 2711	 0.0	 0.0	 1	 -30.0	 30.0;
	4998	 3840	 0.017133	 0.054674	 0.001	 516	 516	 516	 0.0	 0.0	 1	 -30.0	 30.0;
	5091	 3840	 0.078105	 0.213656	 0.002	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	5468	 3841	 0.02968	 0.124313	 0.0015	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	5513	 3841	 0.021164	 0.079365	 0.001	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	5137	 3843	 0.029554	 0.078534	 0.0013	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 3843	 0.005291	 0.011842	 0.0	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	3891	 3844	 0.037284	 0.100247	 0.0052	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	4743	 3847	 0.000435	 0.0016	 0.1974	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4743	 3847	 0.000435	 0.00162	 0.2005	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4285	 3848	 0.004111	 0.013074	 0.0006	 2168	 2168	 2168	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 3849	 0.008272	 0.022222	 0.0011	 1253	 1253	 1253	 0.0	 0.0	 1	 -30.0	 30.0;
	5451	 3851	 0.065356	 0.160494	 0.0078	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	4557	 3852	 0.006499	 0.029472	 0.0506	 301.0	 301.0	 301.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4351	 3856	 0.067271	 0.170824	 0.002	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	5796	 3856	 0.012598	 0.054674	 0.001	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	5797	 3855	 0.004283	 0.051398	 0.0	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 3857	 0.004879	 0.022479	 0.0375	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 3859	 0.017511	 0.074351	 0.0009	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	5513	 3859	 0.008541	 0.023154	 0.0007	 1197	 1197	 1197	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 3862	 9.9e-05	 0.000573	 0.0511	 53230	 53230	 53230	 0.0	 0.0	 1	 -30.0	 30.0;
	5683	 3861	 0.000138	 0.000435	 0.0445	 67824	 67824	 67824	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 3864	 0.046494	 0.092988	 0.0039	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5685	 3865	 0.001864	 0.007508	 0.0001	 3817	 3817	 3817	 0.0	 0.0	 1	 -30.0	 30.0;
	4730	 3868	 0.014198	 0.038148	 0.0018	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	3876	 3872	 0.019829	 0.137868	 0.0015	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 3874	 0.080877	 0.204334	 0.0043	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	4934	 3874	 0.038297	 0.131771	 0.0319	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	5341	 3874	 0.014613	 0.037289	 0.0025	 738	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	3932	 3875	 0.002943	 0.019773	 0.0354	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4256	 3875	 0.001679	 0.011101	 0.0203	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5686	 3878	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 3878	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	4953	 3879	 0.102545	 0.213656	 0.0023	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	4953	 3879	 0.102545	 0.213656	 0.0023	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 3880	 0.006301	 0.028622	 0.0496	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4975	 3882	 0.002746	 0.014183	 0.1868	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4976	 3883	 0.002469	 0.013827	 0.1757	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5373	 3882	 0.002094	 0.010607	 0.1822	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 3884	 0.074628	 0.18962	 0.0021	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	5688	 3885	 0.001008	 0.00252	 0.0027	 11206	 11206	 11206	 0.0	 0.0	 1	 -30.0	 30.0;
	4511	 3891	 0.035062	 0.095679	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	4617	 3892	 0.141245	 0.284127	 0.0032	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 3892	 0.065709	 0.181255	 0.002	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	4255	 3895	 0.000436	 0.000797	 0.001	 32501	 32501	 32501	 0.0	 0.0	 1	 -30.0	 30.0;
	5815	 3897	 0.007901	 0.029877	 0.0257	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 3899	 0.009323	 0.046598	 0.08	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5626	 3901	 0.06261	 0.148501	 0.0072	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5265	 3902	 0.004425	 0.029349	 0.0547	 578.0	 578.0	 578.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4586	 3904	 0.079365	 0.163517	 0.0021	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	4394	 3905	 0.069791	 0.190224	 0.0021	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	5079	 3907	 0.0032	 0.021472	 0.0385	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4637	 3908	 0.000824	 0.008373	 0.2166	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4661	 3908	 0.001211	 0.017571	 0.4563	 1811	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	4638	 3908	 0.000824	 0.008373	 0.2166	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4661	 3908	 0.001205	 0.017438	 0.4534	 1825	 1825	 1825	 0.0	 0.0	 1	 -30.0	 30.0;
	4443	 3911	 0.021244	 0.060489	 0.0193	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	5744	 3912	 0.000553	 0.003793	 0.0071	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5531	 3916	 0.033006	 0.086672	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	4101	 3917	 0.054699	 0.138675	 0.0016	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	5056	 3917	 0.000504	 0.00252	 0.0004	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 3917	 0.052406	 0.141345	 0.0021	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	5718	 3917	 0.06198	 0.157218	 0.0017	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	4107	 3918	 0.007546	 0.034173	 0.0607	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 3919	 0.068027	 0.150416	 0.0017	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	4755	 3920	 0.014613	 0.030234	 0.0	 906	 906	 906	 0.0	 0.0	 1	 -30.0	 30.0;
	4036	 3923	 0.022593	 0.058519	 0.0084	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 3923	 0.027901	 0.104444	 0.0099	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	4832	 3925	 0.079113	 0.215671	 0.0024	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	4832	 3924	 0.087679	 0.239103	 0.0027	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	5694	 3929	 0.009156	 0.040044	 0.0135	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 3931	 0.017133	 0.043336	 0.0005	 634	 634	 634	 0.0	 0.0	 1	 -30.0	 30.0;
	5117	 3931	 0.005039	 0.014109	 0.0002	 1971	 1971	 1971	 0.0	 0.0	 1	 -30.0	 30.0;
	3997	 3932	 0.000928	 0.004148	 0.0071	 7269	 7269	 7269	 0.0	 0.0	 1	 -30.0	 30.0;
	4296	 3932	 0.002844	 0.018627	 0.0334	 468.0	 468.0	 468.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 3932	 0.00257	 0.017083	 0.0314	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4065	 3938	 0.009936	 0.040059	 0.0658	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5271	 3938	 0.001679	 0.011062	 0.0203	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5463	 3938	 0.004958	 0.022716	 0.0395	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5708	 3938	 0.000166	 0.000753	 0.0012	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5740	 3945	 0.071554	 0.192996	 0.0029	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	5774	 3945	 0.045352	 0.123961	 0.0014	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 3946	 0.039808	 0.089695	 0.001	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	5696	 3950	 0.000237	 0.001541	 0.003	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5417	 3952	 0.053338	 0.12769	 0.0015	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	4015	 3955	 0.025447	 0.063996	 0.001	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	4015	 3956	 0.003117	 0.005706	 0.0001	 4542	 4542	 4542	 0.0	 0.0	 1	 -30.0	 30.0;
	5272	 3957	 0.013026	 0.0451	 0.0048	 648	 648	 648	 0.0	 0.0	 1	 -30.0	 30.0;
	3961	 3960	 0.014564	 0.026659	 0.0021	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 3960	 0.066767	 0.212648	 0.0025	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	5177	 3960	 0.007811	 0.024943	 0.0003	 1164	 1164	 1164	 0.0	 0.0	 1	 -30.0	 30.0;
	4563	 3962	 0.018392	 0.076846	 0.0073	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	4957	 3963	 0.000948	 0.009185	 0.0324	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4957	 3964	 0.000889	 0.008652	 0.0304	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4613	 3965	 0.000173	 0.001235	 0.0009	 23818	 23818	 23818	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 3965	 0.008395	 0.021235	 0.001	 1301	 1301	 1301	 0.0	 0.0	 1	 -30.0	 30.0;
	5436	 3965	 0.024161	 0.061506	 0.0029	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	5800	 3965	 2.5e-05	 0.001235	 0.0	 24046	 24046	 24046	 0.0	 0.0	 1	 -30.0	 30.0;
	5700	 3966	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	4925	 3968	 0.010617	 0.028765	 0.0013	 969	 969	 969	 0.0	 0.0	 1	 -30.0	 30.0;
	5699	 3973	 0.001008	 0.00252	 0.0	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	4907	 3977	 0.001738	 0.011595	 0.0213	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4086	 3978	 0.00037	 0.050617	 0.0	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	4086	 3978	 0.00037	 0.050617	 0.0	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	5326	 3980	 0.01321	 0.055926	 0.0029	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	5079	 3981	 0.008652	 0.039447	 0.0724	 374.0	 374.0	 374.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4200	 3982	 0.040741	 0.104444	 0.0049	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 3982	 0.015185	 0.106049	 0.0053	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	5005	 3983	 0.088939	 0.22575	 0.003	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	5702	 3987	 0.00358	 0.007284	 0.0003	 3660	 3660	 3660	 0.0	 0.0	 1	 -30.0	 30.0;
	4921	 3989	 0.073822	 0.198539	 0.0119	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5083	 3990	 0.107178	 0.196187	 0.0016	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	5530	 3991	 0.047048	 0.08612	 0.0009	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5701	 3992	 0.001067	 0.004346	 0.0182	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 3993	 0.023735	 0.043446	 0.0005	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	5703	 3994	 0.017385	 0.031998	 0.0003	 811	 811	 811	 0.0	 0.0	 1	 -30.0	 30.0;
	5353	 3995	 0.041572	 0.133283	 0.001	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5705	 4000	 0.005543	 0.012094	 0.0002	 2220	 2220	 2220	 0.0	 0.0	 1	 -30.0	 30.0;
	4699	 4001	 0.037407	 0.101605	 0.0048	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	4367	 4002	 0.037289	 0.094482	 0.001	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	5826	 4004	 0.066516	 0.139078	 0.0015	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4315	 4005	 0.025185	 0.098272	 0.0058	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	4467	 4005	 0.003457	 0.008642	 0.0023	 3258	 3258	 3258	 0.0	 0.0	 1	 -30.0	 30.0;
	5505	 4007	 0.007206	 0.029252	 0.0019	 952	 952	 952	 0.0	 0.0	 1	 -30.0	 30.0;
	4336	 4009	 0.067019	 0.169463	 0.0019	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	4370	 4009	 0.056437	 0.143613	 0.0017	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 4010	 0.008332	 0.037879	 0.0663	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5487	 4011	 0.033006	 0.072814	 0.001	 370	 370	 370	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 4012	 0.008774	 0.031285	 0.0491	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5246	 4014	 0.018395	 0.048395	 0.0023	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 4016	 0.10112	 0.1851	 0.0019	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	5707	 4019	 0.002311	 0.015467	 0.0284	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5708	 4021	 0.001264	 0.005136	 0.0091	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5708	 4021	 0.001264	 0.005136	 0.0091	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5417	 4022	 0.039557	 0.087176	 0.0013	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	4107	 4023	 0.005886	 0.031546	 0.0567	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4902	 4023	 0.011239	 0.050647	 0.0901	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5489	 4024	 0.000705	 0.001663	 0.0006	 16838	 16838	 16838	 0.0	 0.0	 1	 -30.0	 30.0;
	5576	 4024	 0.077097	 0.213656	 0.0024	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 4025	 0.084152	 0.241119	 0.0026	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 4025	 0.0839	 0.241119	 0.0027	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	5235	 4027	 0.056992	 0.23167	 0.0042	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	5132	 4028	 0.001817	 0.012089	 0.0223	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4458	 4031	 0.037339	 0.123054	 0.0015	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	5153	 4031	 0.000504	 0.00126	 0.0	 22412	 22412	 22412	 0.0	 0.0	 1	 -30.0	 30.0;
	4458	 4031	 0.037339	 0.123054	 0.0015	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 4031	 0.000504	 0.00126	 0.0	 22412	 22412	 22412	 0.0	 0.0	 1	 -30.0	 30.0;
	4685	 4032	 0.013827	 0.075309	 0.0042	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	5710	 4034	 0.000123	 0.001235	 0.0005	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 4037	 0.007785	 0.032955	 0.0036	 899	 899	 899	 0.0	 0.0	 1	 -30.0	 30.0;
	5711	 4038	 5.9e-05	 0.000403	 0.001	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4877	 4041	 0.000316	 0.001936	 0.2551	 397.0	 397.0	 397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4900	 4042	 0.146611	 0.40005	 0.0062	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	4103	 4043	 0.000221	 0.001357	 0.1974	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4547	 4044	 0.003818	 0.024421	 0.1136	 366.0	 366.0	 366.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5713	 4045	 8.6e-05	 0.001235	 0.0	 23993	 23993	 23993	 0.0	 0.0	 1	 -30.0	 30.0;
	4379	 4046	 0.003457	 0.007901	 0.0	 3027	 3027	 3027	 0.0	 0.0	 1	 -30.0	 30.0;
	5795	 4046	 0.000335	 0.000613	 0.0	 37370	 37370	 37370	 0.0	 0.0	 1	 -30.0	 30.0;
	5849	 4047	 0.00162	 0.009284	 0.0162	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4975	 4048	 0.001956	 0.009146	 0.0152	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5394	 4049	 0.001837	 0.008988	 0.0203	 403.0	 403.0	 403.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5714	 4049	 0.000672	 0.004543	 0.0167	 403.0	 403.0	 403.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4977	 4050	 0.000242	 0.002735	 0.0549	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5434	 4051	 0.003951	 0.016296	 0.0008	 1772	 1772	 1772	 0.0	 0.0	 1	 -30.0	 30.0;
	4720	 4060	 0.131519	 0.333585	 0.0038	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	5714	 4063	 0.000237	 0.000494	 0.0294	 56492	 56492	 56492	 0.0	 0.0	 1	 -30.0	 30.0;
	4310	 4064	 0.041068	 0.098765	 0.001	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	4544	 4064	 0.004535	 0.010078	 0.0	 2672	 2672	 2672	 0.0	 0.0	 1	 -30.0	 30.0;
	5788	 4064	 0.003779	 0.010582	 0.0	 2628	 2628	 2628	 0.0	 0.0	 1	 -30.0	 30.0;
	5715	 4066	 0.027715	 0.075838	 0.0009	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	5066	 4070	 0.096825	 0.303855	 0.0034	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	4602	 4071	 0.016881	 0.036684	 0.0005	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	5233	 4071	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	4231	 4075	 0.052658	 0.133283	 0.0015	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	4230	 4075	 0.05291	 0.134543	 0.0015	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	5780	 4076	 0.022099	 0.056296	 0.0026	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	4400	 4079	 0.000316	 0.001132	 0.1529	 297.0	 297.0	 297.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4400	 4079	 0.000316	 0.001132	 0.1529	 297.0	 297.0	 297.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5181	 4079	 0.000563	 0.003372	 0.0116	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5184	 4079	 0.000211	 0.002058	 0.0111	 789.0	 789.0	 789.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4234	 4081	 0.095112	 0.255404	 0.0092	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	4378	 4081	 0.061779	 0.156085	 0.02	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 4087	 0.000252	 0.125976	 0.0	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	4682	 4087	 0.000252	 0.125976	 0.0	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	4776	 4088	 0.019652	 0.043588	 0.0005	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	5717	 4091	 0.001235	 0.003333	 0.0002	 8357	 8357	 8357	 0.0	 0.0	 1	 -30.0	 30.0;
	5087	 4093	 0.017637	 0.048375	 0.0006	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	5854	 4093	 2.5e-05	 0.000252	 0.0	 116592	 116592	 116592	 0.0	 0.0	 1	 -30.0	 30.0;
	5304	 4098	 0.036936	 0.093651	 0.001	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	4618	 4099	 0.030988	 0.082716	 0.0039	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	4948	 4100	 0.066516	 0.16906	 0.0019	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	4934	 4102	 0.026707	 0.095994	 0.0264	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	5339	 4102	 0.012346	 0.041572	 0.0005	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	5501	 4102	 0.016377	 0.042076	 0.0005	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	4651	 4107	 0.002746	 0.018746	 0.0329	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5805	 4107	 0.003002	 0.015052	 0.0268	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 4108	 0.002043	 0.022929	 0.4592	 1386	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	4949	 4108	 0.000776	 0.008497	 0.1805	 1659.0	 1659.0	 1659.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4729	 4109	 0.018896	 0.120433	 0.0014	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	5838	 4111	 0.034815	 0.086914	 0.004	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 4114	 0.037541	 0.092467	 0.001	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	5722	 4115	 0.013333	 0.033951	 0.0016	 815	 815	 815	 0.0	 0.0	 1	 -30.0	 30.0;
	4931	 4116	 0.036533	 0.092719	 0.001	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	5719	 4116	 0.010834	 0.030234	 0.0004	 920	 920	 920	 0.0	 0.0	 1	 -30.0	 30.0;
	4119	 4118	 0.000512	 0.000938	 0.0	 28461	 28461	 28461	 0.0	 0.0	 1	 -30.0	 30.0;
	4339	 4120	 0.016125	 0.100277	 0.0013	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5579	 4120	 0.010078	 0.06198	 0.0008	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	5012	 4122	 0.047115	 0.198287	 0.0024	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	5723	 4124	 1e-05	 0.0001	 0.0029	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5725	 4131	 0.036785	 0.118922	 0.001	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	4247	 4133	 0.046863	 0.11867	 0.0013	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 4135	 0.003121	 0.014183	 0.0243	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4148	 4140	 0.113379	 0.253968	 0.0028	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	4540	 4141	 0.056437	 0.156966	 0.0017	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 4143	 0.01716	 0.046296	 0.0023	 605	 605	 605	 0.0	 0.0	 1	 -30.0	 30.0;
	5566	 4143	 0.044444	 0.115309	 0.0055	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	5800	 4143	 0.026543	 0.067531	 0.0032	 412	 412	 412	 0.0	 0.0	 1	 -30.0	 30.0;
	5816	 4142	 0.00242	 0.00658	 0.0003	 4237	 4237	 4237	 0.0	 0.0	 1	 -30.0	 30.0;
	4212	 4145	 0.059461	 0.146384	 0.0028	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	4850	 4145	 0.0451	 0.153187	 0.0017	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	5160	 4146	 0.003099	 0.020113	 0.0385	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5701	 4146	 0.002528	 0.016672	 0.0304	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5260	 4147	 0.001605	 0.003333	 0.0017	 8030	 8030	 8030	 0.0	 0.0	 1	 -30.0	 30.0;
	4849	 4148	 0.020962	 0.053162	 0.0006	 533	 533	 533	 0.0	 0.0	 1	 -30.0	 30.0;
	5000	 4150	 0.022928	 0.142857	 0.003	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	5796	 4150	 0.011086	 0.047871	 0.001	 601	 601	 601	 0.0	 0.0	 1	 -30.0	 30.0;
	5001	 4151	 0.001679	 0.011397	 0.0223	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5727	 4154	 0.000252	 0.00252	 0.0001	 13354	 13354	 13354	 0.0	 0.0	 1	 -30.0	 30.0;
	5726	 4155	 0.013152	 0.03487	 0.0021	 793	 793	 793	 0.0	 0.0	 1	 -30.0	 30.0;
	4473	 4157	 0.063744	 0.176367	 0.0002	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	4473	 4157	 0.063492	 0.173847	 0.0031	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	4257	 4158	 0.036029	 0.092467	 0.001	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	5728	 4158	 0.124717	 0.316201	 0.0036	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	4386	 4159	 0.00077	 0.001659	 0.2106	 16962	 16962	 16962	 0.0	 0.0	 1	 -30.0	 30.0;
	5729	 4162	 0.01159	 0.031494	 0.0003	 880	 880	 880	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 4165	 0.004157	 0.012094	 0.0002	 2379	 2379	 2379	 0.0	 0.0	 1	 -30.0	 30.0;
	4699	 4166	 0.021482	 0.058148	 0.0028	 518	 518	 518	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 4166	 0.031358	 0.131975	 0.0068	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	5730	 4168	 0.001764	 0.005039	 0.0001	 5531	 5531	 5531	 0.0	 0.0	 1	 -30.0	 30.0;
	5568	 4169	 0.014613	 0.07231	 0.0005	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	5731	 4170	 0.000227	 0.000605	 0.0	 47067	 47067	 47067	 0.0	 0.0	 1	 -30.0	 30.0;
	4323	 4172	 0.034321	 0.083827	 0.0039	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 4172	 0.030988	 0.064074	 0.003	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	5786	 4172	 0.003951	 0.025185	 0.0013	 1166	 1166	 1166	 0.0	 0.0	 1	 -30.0	 30.0;
	4323	 4172	 0.006173	 0.025679	 0.1053	 1125	 1125	 1125	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 4172	 0.024815	 0.064691	 0.0031	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	5732	 4174	 0.006299	 0.026808	 0.0003	 1105	 1105	 1105	 0.0	 0.0	 1	 -30.0	 30.0;
	5640	 4174	 0.006299	 0.013605	 0.0002	 2029	 2029	 2029	 0.0	 0.0	 1	 -30.0	 30.0;
	5391	 4176	 0.000494	 0.001728	 0.0002	 16527	 16527	 16527	 0.0	 0.0	 1	 -30.0	 30.0;
	5434	 4176	 0.004691	 0.015803	 0.0008	 1802	 1802	 1802	 0.0	 0.0	 1	 -30.0	 30.0;
	5037	 4179	 0.03963	 0.103951	 0.005	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	4668	 4180	 0.015309	 0.03963	 0.0019	 700	 700	 700	 0.0	 0.0	 1	 -30.0	 30.0;
	5182	 4183	 0.037037	 0.099773	 0.0012	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	5345	 4183	 0.014109	 0.036029	 0.0004	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	5631	 4183	 0.051398	 0.145629	 0.0033	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	5814	 4184	 0.005628	 0.038669	 0.0729	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 4185	 0.138322	 0.372386	 0.0048	 75	 75	 75	 0.0	 0.0	 1	 -30.0	 30.0;
	4332	 4186	 0.007307	 0.030335	 0.0018	 967	 967	 967	 0.0	 0.0	 1	 -30.0	 30.0;
	5735	 4186	 0.000252	 0.00252	 0.0005	 11909	 11909	 11909	 0.0	 0.0	 1	 -30.0	 30.0;
	4188	 4187	 0.004535	 0.013605	 0.0051	 2059	 2059	 2059	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 4187	 0.020156	 0.087176	 0.001	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	5736	 4191	 0.050894	 0.138574	 0.0016	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	5754	 4192	 0.021416	 0.058453	 0.0006	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	5029	 4193	 0.049635	 0.135299	 0.0041	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	4846	 4196	 0.067654	 0.145679	 0.0071	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 4196	 0.03716	 0.100247	 0.0049	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	4763	 4197	 0.000652	 0.001244	 0.1833	 22038	 22038	 22038	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 4201	 0.026296	 0.066296	 0.012	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	4963	 4203	 0.009753	 0.019506	 0.0008	 1362	 1362	 1362	 0.0	 0.0	 1	 -30.0	 30.0;
	4963	 4202	 0.009753	 0.019506	 0.0008	 1362	 1362	 1362	 0.0	 0.0	 1	 -30.0	 30.0;
	4204	 4205	 0.003731	 0.006829	 0.0	 3795	 3795	 3795	 0.0	 0.0	 1	 -30.0	 30.0;
	4577	 4209	 0.008818	 0.018141	 0.0254	 1421	 1421	 1421	 0.0	 0.0	 1	 -30.0	 30.0;
	4875	 4209	 0.018317	 0.059486	 0.0256	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	5792	 4209	 0.014361	 0.044344	 0.014	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	4877	 4211	 0.00083	 0.002588	 0.32	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4966	 4210	 0.000395	 0.002291	 0.0182	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5560	 4210	 0.001659	 0.011062	 0.0203	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 4213	 0.009956	 0.035773	 0.0572	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5518	 4213	 0.002102	 0.008286	 0.0142	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5701	 4213	 0.001185	 0.008	 0.0152	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5587	 4214	 0.000252	 0.00252	 0.0003	 11659	 11659	 11659	 0.0	 0.0	 1	 -30.0	 30.0;
	4472	 4219	 0.003117	 0.005706	 0.0028	 4678	 4678	 4678	 0.0	 0.0	 1	 -30.0	 30.0;
	4498	 4219	 0.004031	 0.009574	 0.01	 2928	 2928	 2928	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 4218	 0.013354	 0.033258	 0.0004	 849	 849	 849	 0.0	 0.0	 1	 -30.0	 30.0;
	4498	 4219	 0.005217	 0.00955	 0.0093	 2795	 2795	 2795	 0.0	 0.0	 1	 -30.0	 30.0;
	4497	 4218	 0.004975	 0.009106	 0.0087	 2932	 2932	 2932	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 4220	 0.00371	 0.01789	 0.0359	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4907	 4220	 0.001428	 0.019629	 0.0754	 638.0	 638.0	 638.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5707	 4220	 0.001244	 0.016316	 0.0699	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5711	 4220	 0.006728	 0.030596	 0.0587	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 4221	 0.000471	 0.006184	 0.2368	 954.0	 954.0	 954.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 4222	 0.021926	 0.055062	 0.0002	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	5743	 4222	 0.019753	 0.05037	 0.0	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	5307	 4228	 0.010494	 0.045185	 0.0021	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	5371	 4227	 0.010494	 0.02679	 0.0013	 1054	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 4232	 0.016503	 0.044394	 0.0027	 624	 624	 624	 0.0	 0.0	 1	 -30.0	 30.0;
	4351	 4236	 0.089695	 0.171832	 0.0018	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	5739	 4237	 0.014815	 0.04037	 0.0019	 691	 691	 691	 0.0	 0.0	 1	 -30.0	 30.0;
	5458	 4241	 3.7e-05	 0.000148	 0.0002	 194699	 194699	 194699	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 4243	 0.006299	 0.015621	 0.0202	 1753	 1753	 1753	 0.0	 0.0	 1	 -30.0	 30.0;
	4895	 4244	 0.059012	 0.159259	 0.0075	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	5164	 4244	 0.021852	 0.058765	 0.0029	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 4244	 0.040494	 0.102963	 0.0047	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	4327	 4248	 0.019652	 0.083648	 0.001	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	4678	 4250	 0.036029	 0.093222	 0.0011	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	5212	 4249	 0.008566	 0.023432	 0.0002	 1184	 1184	 1184	 0.0	 0.0	 1	 -30.0	 30.0;
	4249	 4272	 0.008062	 0.022172	 0.0002	 1252	 1252	 1252	 0.0	 0.0	 1	 -30.0	 30.0;
	5742	 4251	 0.067523	 0.184177	 0.0021	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	4831	 4252	 0.05417	 0.137314	 0.0019	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	4887	 4252	 0.03351	 0.113631	 0.0013	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	4258	 4253	 0.006084	 0.023072	 0.24	 282.0	 282.0	 282.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 4254	 0.006198	 0.011346	 0.0088	 2353	 2353	 2353	 0.0	 0.0	 1	 -30.0	 30.0;
	4842	 4257	 0.051524	 0.124313	 0.003	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	5410	 4257	 0.046863	 0.109851	 0.0012	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 4258	 0.004454	 0.01571	 0.0253	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5005	 4259	 0.057697	 0.158982	 0.0021	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 4259	 0.014025	 0.025673	 0.0	 1010	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	4823	 4260	 0.032754	 0.083396	 0.001	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	5182	 4262	 0.032502	 0.088939	 0.001	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	5740	 4262	 0.053162	 0.145377	 0.0017	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	5443	 4263	 0.009012	 0.023457	 0.001	 1183	 1183	 1183	 0.0	 0.0	 1	 -30.0	 30.0;
	5241	 4266	 0.021668	 0.066516	 0.0013	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	5241	 4265	 0.020912	 0.063996	 0.0013	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 4269	 0.002877	 0.007284	 0.0003	 3793	 3793	 3793	 0.0	 0.0	 1	 -30.0	 30.0;
	5744	 4271	 0.000375	 0.001679	 0.003	 17958	 17958	 17958	 0.0	 0.0	 1	 -30.0	 30.0;
	5025	 4273	 0.097048	 0.177645	 0.0018	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	5746	 4274	 0.029907	 0.101512	 0.0016	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5716	 4275	 0.001512	 0.004787	 0.0045	 5882	 5882	 5882	 0.0	 0.0	 1	 -30.0	 30.0;
	5694	 4278	 0.019867	 0.059067	 0.0189	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	5763	 4283	 0.018796	 0.037365	 0.0178	 728	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 4288	 2.8e-05	 0.000409	 0.0116	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 4287	 2.8e-05	 0.000422	 0.0116	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5003	 4289	 0.029982	 0.075838	 0.0	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	5377	 4291	 0.005795	 0.019652	 0.0002	 1485	 1485	 1485	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 4291	 0.04384	 0.108592	 0.0018	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	4982	 4293	 0.010667	 0.052109	 0.0901	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 4296	 0.003931	 0.026686	 0.0506	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5617	 4297	 0.011565	 0.029453	 0.0031	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 4298	 0.008395	 0.022963	 0.0011	 1241	 1241	 1241	 0.0	 0.0	 1	 -30.0	 30.0;
	4289	 4301	 0.002268	 0.006803	 0.0005	 4118	 4118	 4118	 0.0	 0.0	 1	 -30.0	 30.0;
	5749	 4302	 0.000882	 0.002973	 0.0	 9521	 9521	 9521	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 4303	 0.109851	 0.269841	 0.003	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	4568	 4303	 0.049887	 0.166767	 0.0019	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	5750	 4304	 0.008012	 0.019678	 0.0013	 1432	 1432	 1432	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 4309	 0.007811	 0.019904	 0.0002	 1423	 1423	 1423	 0.0	 0.0	 1	 -30.0	 30.0;
	5537	 4309	 0.055682	 0.141345	 0.0016	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5536	 4308	 0.055933	 0.141849	 0.0016	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4311	 4310	 0.017385	 0.039053	 0.004	 691	 691	 691	 0.0	 0.0	 1	 -30.0	 30.0;
	5392	 4312	 0.001111	 0.002963	 0.0002	 9387	 9387	 9387	 0.0	 0.0	 1	 -30.0	 30.0;
	5852	 4315	 0.027901	 0.118272	 0.0058	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	5751	 4321	 0.010247	 0.032716	 0.0016	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	5539	 4325	 0.024943	 0.053918	 0.0	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	5593	 4325	 0.057445	 0.124465	 0.001	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	4424	 4329	 0.022172	 0.057697	 0.001	 478	 478	 478	 0.0	 0.0	 1	 -30.0	 30.0;
	4621	 4332	 0.01285	 0.053968	 0.0006	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	4719	 4331	 0.06707	 0.182137	 0.0028	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	5346	 4331	 0.011842	 0.039053	 0.0006	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	5347	 4331	 0.014059	 0.037868	 0.0005	 753	 753	 753	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 4332	 0.020081	 0.087226	 0.001	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	5688	 4332	 0.021416	 0.056689	 0.0006	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	5735	 4332	 0.006551	 0.027967	 0.0003	 1059	 1059	 1059	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 4332	 0.006299	 0.026455	 0.0003	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 4333	 0.000415	 0.002785	 0.0051	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5429	 4334	 0.001225	 0.005981	 0.0111	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4907	 4333	 0.002133	 0.014289	 0.0263	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 4334	 0.000474	 0.003149	 0.0061	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5302	 4335	 0.04772	 0.162081	 0.0019	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4552	 4344	 0.007811	 0.015873	 0.01	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	4550	 4344	 0.007307	 0.0193	 0.0173	 1431	 1431	 1431	 0.0	 0.0	 1	 -30.0	 30.0;
	5320	 4345	 0.000644	 0.002929	 0.0051	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4772	 4346	 0.010494	 0.026667	 0.0171	 1037	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	5756	 4347	 0.013102	 0.025951	 0.0002	 1047	 1047	 1047	 0.0	 0.0	 1	 -30.0	 30.0;
	4894	 4348	 0.115646	 0.315445	 0.0036	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 4348	 0.007559	 0.023935	 0.0012	 1212	 1212	 1212	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 4348	 0.007559	 0.023935	 0.0012	 1212	 1212	 1212	 0.0	 0.0	 1	 -30.0	 30.0;
	4907	 4349	 0.000849	 0.005728	 0.0101	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4907	 4349	 0.000849	 0.005728	 0.0101	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4907	 4349	 0.000435	 0.002963	 0.0208	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 4350	 0.024198	 0.045679	 0.0021	 587	 587	 587	 0.0	 0.0	 1	 -30.0	 30.0;
	5402	 4351	 0.009322	 0.023935	 0.0	 1150	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 4351	 0.032502	 0.084152	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5832	 4351	 0.037541	 0.089695	 0.001	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	5757	 4354	 0.000554	 0.001109	 0.0005	 24534	 24534	 24534	 0.0	 0.0	 1	 -30.0	 30.0;
	5758	 4354	 0.001764	 0.004283	 0.0001	 6566	 6566	 6566	 0.0	 0.0	 1	 -30.0	 30.0;
	5151	 4354	 0.076594	 0.184681	 0.0017	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	5379	 4356	 0.000741	 0.002099	 0.0002	 13344	 13344	 13344	 0.0	 0.0	 1	 -30.0	 30.0;
	5759	 4357	 5.9e-05	 0.000336	 0.001	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4585	 4359	 0.049887	 0.102293	 0.0011	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 4359	 0.046611	 0.118166	 0.0013	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	5227	 4359	 0.069539	 0.191232	 0.0021	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	5418	 4361	 0.043034	 0.117309	 0.0053	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 4361	 0.043411	 0.118418	 0.0013	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	4441	 4362	 0.057697	 0.120685	 0.0013	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	4801	 4363	 0.042328	 0.167297	 0.0021	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	5239	 4365	 0.030988	 0.078765	 0.0037	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 4365	 0.020123	 0.050988	 0.0024	 542	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	4429	 4366	 0.011086	 0.045352	 0.0043	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	4429	 4366	 0.011086	 0.045603	 0.0044	 630	 630	 630	 0.0	 0.0	 1	 -30.0	 30.0;
	4720	 4370	 0.084404	 0.214664	 0.0025	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	4911	 4371	 0.046863	 0.158982	 0.002	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 4371	 0.012094	 0.033006	 0.0	 840	 840	 840	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 4372	 0.020864	 0.054691	 0.0026	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	4489	 4374	 0.105316	 0.287226	 0.0033	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	5763	 4375	 0.001008	 0.002771	 0.0001	 10315	 10315	 10315	 0.0	 0.0	 1	 -30.0	 30.0;
	5258	 4377	 0.062988	 0.17158	 0.0019	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	5380	 4380	 0.018099	 0.045877	 0.0021	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 4381	 0.070043	 0.177375	 0.002	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	5179	 4384	 0.021111	 0.042346	 0.0018	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	5817	 4385	 0.03477	 0.064752	 0.0006	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	5766	 4390	 0.003927	 0.026153	 0.0486	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5764	 4392	 0.013102	 0.03477	 0.0004	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	4890	 4395	 0.03879	 0.102605	 0.0049	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 4399	 0.002035	 0.014025	 0.0263	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4727	 4400	 0.000237	 0.00083	 0.1843	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5173	 4402	 0.051902	 0.118922	 0.0013	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	5121	 4403	 0.08642	 0.222222	 0.0	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	5767	 4405	 0.000277	 0.001285	 0.0015	 23137	 23137	 23137	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 4407	 0.00037	 0.000988	 0.0002	 30291	 30291	 30291	 0.0	 0.0	 1	 -30.0	 30.0;
	4869	 4412	 0.002394	 0.014865	 0.0002	 1961	 1961	 1961	 0.0	 0.0	 1	 -30.0	 30.0;
	5770	 4416	 0.000756	 0.001512	 0.0	 17466	 17466	 17466	 0.0	 0.0	 1	 -30.0	 30.0;
	5771	 4418	 0.000151	 0.000428	 0.0	 65055	 65055	 65055	 0.0	 0.0	 1	 -30.0	 30.0;
	4879	 4420	 0.000454	 0.002114	 0.0061	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4879	 4419	 0.000454	 0.002114	 0.004	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5009	 4425	 0.069791	 0.171328	 0.0023	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	4996	 4427	 0.103301	 0.241371	 0.003	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	5771	 4427	 0.068178	 0.17357	 0.0021	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5312	 4428	 0.007099	 0.017988	 0.0008	 1536	 1536	 1536	 0.0	 0.0	 1	 -30.0	 30.0;
	5773	 4430	 0.013481	 0.024677	 0.0002	 1019	 1019	 1019	 0.0	 0.0	 1	 -30.0	 30.0;
	5369	 4432	 0.027642	 0.093889	 0.0046	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	4688	 4434	 0.014613	 0.049383	 0.001	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	4878	 4434	 0.041572	 0.101789	 0.002	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	4688	 4434	 0.015873	 0.050643	 0.001	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	4625	 4435	 0.054343	 0.099474	 0.001	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 4437	 0.028471	 0.104308	 0.0458	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	4964	 4437	 0.085916	 0.17745	 0.0023	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	5718	 4438	 0.004031	 0.01033	 0.0001	 2743	 2743	 2743	 0.0	 0.0	 1	 -30.0	 30.0;
	4675	 4441	 0.053666	 0.303603	 0.0034	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	4675	 4441	 0.053918	 0.303855	 0.0034	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	4756	 4442	 0.000252	 0.00252	 0.0001	 11659	 11659	 11659	 0.0	 0.0	 1	 -30.0	 30.0;
	4920	 4442	 0.03933	 0.101789	 0.0025	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	4757	 4442	 0.000252	 0.00252	 0.0001	 11659	 11659	 11659	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 4444	 0.002627	 0.017778	 0.0334	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5275	 4449	 0.006047	 0.025195	 0.0	 1140	 1140	 1140	 0.0	 0.0	 1	 -30.0	 30.0;
	5775	 4451	 0.094986	 0.266566	 0.0	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	5095	 4454	 0.063265	 0.13613	 0.0015	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	5821	 4454	 0.011842	 0.033006	 0.0	 868	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	5782	 4456	 0.001462	 0.010114	 0.0182	 442.0	 442.0	 442.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 4457	 0.01033	 0.037541	 0.0005	 759	 759	 759	 0.0	 0.0	 1	 -30.0	 30.0;
	4893	 4458	 0.075334	 0.198639	 0.0041	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	5671	 4458	 0.070295	 0.145377	 0.0016	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 4458	 0.042832	 0.10834	 0.0013	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	5750	 4460	 0.061602	 0.156135	 0.0017	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	5834	 4461	 0.001008	 0.002016	 0.0	 13494	 13494	 13494	 0.0	 0.0	 1	 -30.0	 30.0;
	4534	 4462	 0.006173	 0.025145	 0.0018	 1141	 1141	 1141	 0.0	 0.0	 1	 -30.0	 30.0;
	4635	 4463	 0.022676	 0.095994	 0.001	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	5145	 4462	 0.044344	 0.189216	 0.0021	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 4463	 0.048123	 0.206349	 0.003	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 4465	 0.002749	 0.039259	 1.1855	 811	 811	 811	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 4469	 0.014321	 0.040617	 0.0	 705	 705	 705	 0.0	 0.0	 1	 -30.0	 30.0;
	4498	 4471	 0.001512	 0.003275	 0.0001	 8432	 8432	 8432	 0.0	 0.0	 1	 -30.0	 30.0;
	5778	 4473	 0.058705	 0.159738	 0.0018	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4777	 4475	 0.008314	 0.022424	 0.0	 1272	 1272	 1272	 0.0	 0.0	 1	 -30.0	 30.0;
	4486	 4481	 2.5e-05	 0.015117	 0.0	 2012	 2012	 2012	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 4485	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 4484	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 4483	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 4482	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	5012	 4489	 0.142605	 0.361804	 0.0041	 78	 78	 78	 0.0	 0.0	 1	 -30.0	 30.0;
	5515	 4489	 0.120685	 0.404888	 0.0046	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	4806	 4491	 0.006758	 0.01237	 0.0087	 2033	 2033	 2033	 0.0	 0.0	 1	 -30.0	 30.0;
	5779	 4493	 0.000454	 0.001209	 0.0013	 23415	 23415	 23415	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 4501	 0.006533	 0.022267	 0.0072	 1313	 1313	 1313	 0.0	 0.0	 1	 -30.0	 30.0;
	5256	 4501	 0.017067	 0.058356	 0.0193	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 4503	 0.100277	 0.301839	 0.004	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	4606	 4507	 0.043333	 0.092099	 0.0042	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	4808	 4511	 0.027531	 0.074074	 0.0036	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	5260	 4511	 0.031111	 0.084074	 0.004	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 4512	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	5782	 4513	 1.4e-05	 9.9e-05	 0.0002	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4054	 4514	 0.033006	 0.204838	 0.0073	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	4148	 4514	 0.039305	 0.100529	 0.0011	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	5248	 4514	 0.005669	 0.036206	 0.0087	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	5696	 4515	 0.002807	 0.014445	 0.0259	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5488	 4519	 0.046914	 0.119012	 0.0055	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5370	 4520	 0.007432	 0.025235	 0.0013	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	5784	 4521	 0.007055	 0.013102	 0.0001	 2280	 2280	 2280	 0.0	 0.0	 1	 -30.0	 30.0;
	4850	 4523	 0.114059	 0.346964	 0.004	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	4146	 4525	 0.006933	 0.033403	 0.0607	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5785	 4527	 0.004435	 0.008118	 0.0001	 3667	 3667	 3667	 0.0	 0.0	 1	 -30.0	 30.0;
	4332	 4528	 0.012346	 0.04384	 0.0006	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	4332	 4528	 0.013354	 0.0451	 0.0006	 647	 647	 647	 0.0	 0.0	 1	 -30.0	 30.0;
	5709	 4530	 0.046359	 0.117662	 0.0013	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	5384	 4531	 0.001383	 0.009343	 0.0172	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 4531	 0.001027	 0.006815	 0.0121	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4831	 4533	 0.014361	 0.039053	 0.0005	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	4887	 4533	 0.012346	 0.03351	 0.0004	 827	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	5282	 4538	 0.007307	 0.030738	 0.0019	 907	 907	 907	 0.0	 0.0	 1	 -30.0	 30.0;
	5742	 4540	 0.000995	 0.001821	 0.001	 14657	 14657	 14657	 0.0	 0.0	 1	 -30.0	 30.0;
	5751	 4541	 0.041481	 0.100494	 0.0047	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 4542	 5.9e-05	 0.000296	 0.0	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5516	 4543	 0.000504	 0.001764	 0.0014	 16578	 16578	 16578	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 4543	 0.000756	 0.001764	 0.0017	 15848	 15848	 15848	 0.0	 0.0	 1	 -30.0	 30.0;
	5789	 4546	 0.006047	 0.024691	 0.0003	 1162	 1162	 1162	 0.0	 0.0	 1	 -30.0	 30.0;
	4574	 4548	 0.00141	 0.020003	 0.4967	 1589	 1589	 1589	 0.0	 0.0	 1	 -30.0	 30.0;
	4574	 4548	 0.00141	 0.02	 0.4967	 1589	 1589	 1589	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 4553	 0.000988	 0.001852	 0.0	 14447	 14447	 14447	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 4555	 0.019778	 0.053943	 0.0006	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	5700	 4555	 0.004787	 0.021416	 0.0002	 1386	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	5824	 4555	 0.012396	 0.033837	 0.0004	 844	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	5825	 4555	 0.011414	 0.031166	 0.0004	 917	 917	 917	 0.0	 0.0	 1	 -30.0	 30.0;
	5527	 4557	 0.006696	 0.028583	 0.0496	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5610	 4569	 0.000827	 0.003815	 0.0661	 279.0	 279.0	 279.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4594	 4570	 0.000194	 0.00255	 0.0895	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 4570	 0.000194	 0.00255	 0.0895	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4927	 4573	 0.005709	 0.036049	 0.0881	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4927	 4573	 0.005748	 0.036247	 0.0997	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 4574	 0.000893	 0.008663	 0.2253	 1644.0	 1644.0	 1644.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5823	 4574	 0.001707	 0.022772	 0.7812	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 4574	 0.000893	 0.008663	 0.2253	 1644.0	 1644.0	 1644.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 4574	 0.00117	 0.010658	 0.2946	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 4574	 0.000409	 0.006946	 0.2513	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 4574	 0.000409	 0.006946	 0.2513	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5590	 4579	 0.003527	 0.00907	 0.0001	 3126	 3126	 3126	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 4580	 0.01033	 0.027463	 0.0003	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	4581	 4582	 0.009574	 0.025195	 0.0003	 1096	 1096	 1096	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 4582	 0.159234	 0.297304	 0.0033	 88	 88	 88	 0.0	 0.0	 1	 -30.0	 30.0;
	5793	 4582	 0.00907	 0.024691	 0.0002	 1123	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	5795	 4584	 0.016769	 0.030696	 0.0	 747	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	4746	 4585	 0.074931	 0.154195	 0.0023	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	5145	 4586	 0.064248	 0.133283	 0.001	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5268	 4592	 0.021728	 0.134321	 0.0075	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	4661	 4594	 0.001015	 0.014744	 0.3841	 2158	 2158	 2158	 0.0	 0.0	 1	 -30.0	 30.0;
	4661	 4593	 0.001018	 0.014778	 0.3841	 2153	 2153	 2153	 0.0	 0.0	 1	 -30.0	 30.0;
	5796	 4597	 0.001008	 0.002016	 0.0	 13100	 13100	 13100	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 4601	 0.017654	 0.048148	 0.0023	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 4603	 0.00284	 0.007901	 0.0003	 3538	 3538	 3538	 0.0	 0.0	 1	 -30.0	 30.0;
	4805	 4607	 0.014613	 0.049383	 0.0025	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 4607	 0.057445	 0.156715	 0.0017	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	5587	 4607	 0.014361	 0.036785	 0.0005	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	5635	 4607	 0.006299	 0.016881	 0.0002	 1639	 1639	 1639	 0.0	 0.0	 1	 -30.0	 30.0;
	5738	 4607	 0.01033	 0.042328	 0.0006	 678	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	5637	 4608	 0.008119	 0.054084	 0.1002	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5058	 4610	 0.003202	 0.00586	 0.0022	 4291	 4291	 4291	 0.0	 0.0	 1	 -30.0	 30.0;
	5638	 4610	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	5467	 4612	 0.024188	 0.060972	 0.0008	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	4865	 4614	 0.022676	 0.14714	 0.002	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	5323	 4614	 0.021164	 0.046359	 0.001	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	5476	 4614	 0.06324	 0.11615	 0.0	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	5625	 4615	 0.018896	 0.078357	 0.0013	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 4615	 0.005039	 0.020912	 0.0002	 1573	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	4781	 4616	 0.001067	 0.004899	 0.0081	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5663	 4616	 0.000119	 0.00077	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 4618	 0.03	 0.076543	 0.0039	 369	 369	 369	 0.0	 0.0	 1	 -30.0	 30.0;
	4642	 4619	 0.04284	 0.112716	 0.0053	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	4978	 4625	 0.066767	 0.157344	 0.0185	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	5621	 4627	 0.039136	 0.100741	 0.0045	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	5802	 4628	 0.019652	 0.040816	 0.0005	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 4629	 0.034568	 0.090123	 0.0042	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 4630	 0.02192	 0.055178	 0.0006	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 4630	 0.00708	 0.019325	 0.0002	 1393	 1393	 1393	 0.0	 0.0	 1	 -30.0	 30.0;
	5225	 4632	 0.025447	 0.066767	 0.0007	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 4633	 0.001008	 0.00252	 0.0	 11206	 11206	 11206	 0.0	 0.0	 1	 -30.0	 30.0;
	4800	 4636	 0.038148	 0.102099	 0.0049	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	4666	 4643	 0.012346	 0.032593	 0.0016	 853	 853	 853	 0.0	 0.0	 1	 -30.0	 30.0;
	4648	 4646	 0.010617	 0.065679	 0.0076	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 4646	 0.008025	 0.020988	 0.001	 1350	 1350	 1350	 0.0	 0.0	 1	 -30.0	 30.0;
	5128	 4646	 0.034938	 0.069876	 0.0032	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 4646	 0.008148	 0.021235	 0.0021	 1334	 1334	 1334	 0.0	 0.0	 1	 -30.0	 30.0;
	5805	 4650	 0.001244	 0.006301	 0.0111	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5510	 4652	 0.000252	 0.00252	 0.0001	 13395	 13395	 13395	 0.0	 0.0	 1	 -30.0	 30.0;
	4792	 4655	 0.035803	 0.092469	 0.005	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	4812	 4655	 0.038025	 0.099012	 0.0392	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5246	 4658	 0.033667	 0.090667	 0.0044	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	5330	 4660	 0.000612	 0.004069	 0.0071	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4744	 4662	 0.004938	 0.013333	 0.0	 1837	 1837	 1837	 0.0	 0.0	 1	 -30.0	 30.0;
	5808	 4664	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5811	 4674	 0.076745	 0.199622	 0.0022	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	4899	 4675	 0.053666	 0.098262	 0.001	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	4922	 4676	 0.004464	 0.030933	 0.0547	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5259	 4678	 0.05543	 0.140842	 0.0016	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	5141	 4680	 0.030612	 0.077198	 0.0024	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	5186	 4681	 0.077601	 0.212396	 0.0024	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	5210	 4681	 0.005039	 0.013857	 0.0002	 2003	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	5815	 4684	 0.00358	 0.009877	 0.0005	 2828	 2828	 2828	 0.0	 0.0	 1	 -30.0	 30.0;
	4850	 4687	 0.061728	 0.148652	 0.0017	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5812	 4688	 0.000252	 0.000504	 0.001	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	4752	 4695	 4e-05	 0.000968	 0.003	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5817	 4700	 0.009826	 0.025447	 0.0002	 1083	 1083	 1083	 0.0	 0.0	 1	 -30.0	 30.0;
	5818	 4702	 2e-05	 0.000198	 0.0	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5818	 4703	 2e-05	 0.000198	 0.0	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4752	 4711	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5819	 4714	 0.000756	 0.00252	 0.0	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	5821	 4717	 0.001008	 0.00252	 0.0	 11206	 11206	 11206	 0.0	 0.0	 1	 -30.0	 30.0;
	5144	 4720	 0.03225	 0.087931	 0.001	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	5142	 4720	 0.015369	 0.095339	 0.0012	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	5459	 4720	 0.033762	 0.140086	 0.0017	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5352	 4726	 0.010741	 0.028025	 0.0013	 1011	 1011	 1011	 0.0	 0.0	 1	 -30.0	 30.0;
	5822	 4728	 0.003527	 0.00907	 0.0001	 3126	 3126	 3126	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 4729	 0.002016	 0.013354	 0.0002	 2122	 2122	 2122	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 4731	 0.010815	 0.050299	 0.0876	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4618	 4733	 1.2e-05	 0.000123	 0.0002	 245373	 245373	 245373	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 4740	 0.001512	 0.007307	 0.0	 3957	 3957	 3957	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 4743	 0.002509	 0.015921	 0.0294	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5147	 4746	 0.065256	 0.165457	 0.0019	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5686	 4746	 0.046863	 0.100277	 0.0011	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	5775	 4749	 0.001512	 0.004031	 0.0001	 7065	 7065	 7065	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 4759	 0.169312	 0.378181	 0.0044	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	5467	 4759	 0.070295	 0.177879	 0.002	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	4976	 4762	 0.000316	 0.001971	 0.0273	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4975	 4761	 0.000245	 0.00302	 0.0061	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5212	 4764	 0.078609	 0.2129	 0.0024	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 4775	 0.016677	 0.030527	 0.0003	 875	 875	 875	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 4778	 0.009574	 0.024943	 0.001	 1106	 1106	 1106	 0.0	 0.0	 1	 -30.0	 30.0;
	4808	 4780	 0.010494	 0.028272	 0.0013	 985	 985	 985	 0.0	 0.0	 1	 -30.0	 30.0;
	5663	 4781	 0.000356	 0.00241	 0.004	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5375	 4782	 0.048879	 0.12648	 0.0014	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5669	 4782	 0.073066	 0.187957	 0.0021	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 4783	 0.000375	 0.004741	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5174	 4784	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5827	 4785	 0.000171	 0.000313	 0.0001	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	5679	 4787	 0.060494	 0.158889	 0.0073	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	5324	 4789	 0.080877	 0.209373	 0.0023	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	4812	 4791	 0.047284	 0.164691	 0.0083	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 4791	 0.001358	 0.003333	 0.0002	 8426	 8426	 8426	 0.0	 0.0	 1	 -30.0	 30.0;
	5238	 4793	 0.052028	 0.131872	 0.0017	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	5828	 4797	 0.004787	 0.010078	 0.0001	 2647	 2647	 2647	 0.0	 0.0	 1	 -30.0	 30.0;
	5660	 4799	 0.042479	 0.09035	 0.001	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	4921	 4801	 0.008818	 0.035777	 0.0005	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	4921	 4801	 0.008818	 0.035777	 0.0005	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	4993	 4802	 0.145805	 0.502746	 0.0056	 59	 59	 59	 0.0	 0.0	 1	 -30.0	 30.0;
	5830	 4804	 0.014361	 0.048879	 0.001	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	5635	 4805	 0.008314	 0.032502	 0.0023	 881	 881	 881	 0.0	 0.0	 1	 -30.0	 30.0;
	5535	 4807	 0.009801	 0.041144	 0.0005	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	5199	 4809	 0.001728	 0.004815	 0.0002	 5807	 5807	 5807	 0.0	 0.0	 1	 -30.0	 30.0;
	5780	 4809	 0.019753	 0.053333	 0.0026	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	5299	 4813	 0.070547	 0.17284	 0.002	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 4814	 0.045679	 0.115802	 0.0055	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	5077	 4827	 0.018272	 0.076667	 0.0062	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	5315	 4827	 0.00642	 0.04321	 0.0034	 695	 695	 695	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 4827	 0.026667	 0.082222	 0.0039	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	5499	 4827	 0.009259	 0.024568	 0.001	 1155	 1155	 1155	 0.0	 0.0	 1	 -30.0	 30.0;
	5079	 4829	 0.002825	 0.012998	 0.0299	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5000	 4835	 0.004283	 0.010834	 0.002	 2535	 2535	 2535	 0.0	 0.0	 1	 -30.0	 30.0;
	5000	 4835	 0.001764	 0.007559	 0.0114	 3804	 3804	 3804	 0.0	 0.0	 1	 -30.0	 30.0;
	5729	 4837	 0.029982	 0.076594	 0.0009	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	4900	 4839	 0.155732	 0.364676	 0.004	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	5812	 4843	 0.011086	 0.024943	 0.0003	 1082	 1082	 1082	 0.0	 0.0	 1	 -30.0	 30.0;
	5149	 4844	 0.001481	 0.006696	 0.0111	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4967	 4845	 0.032222	 0.135679	 0.0084	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 4845	 0.021852	 0.055309	 0.0026	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	4967	 4845	 0.032222	 0.135062	 0.0083	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 4846	 0.016914	 0.045556	 0.0023	 612	 612	 612	 0.0	 0.0	 1	 -30.0	 30.0;
	4889	 4850	 0.120937	 0.267322	 0.003	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	4851	 4852	 0.001184	 0.002167	 0.0003	 10572	 10572	 10572	 0.0	 0.0	 1	 -30.0	 30.0;
	5810	 4852	 0.036049	 0.098272	 0.0012	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	5840	 4852	 0.064198	 0.139753	 0.0012	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	4968	 4860	 0.000561	 0.005658	 0.1444	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4969	 4860	 0.000561	 0.005665	 0.1473	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5514	 4862	 0.046611	 0.099521	 0.0011	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	5137	 4864	 0.03477	 0.081381	 0.001	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	5593	 4864	 0.017637	 0.039305	 0.0	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 4867	 0.000604	 0.001106	 0.0007	 23430	 23430	 23430	 0.0	 0.0	 1	 -30.0	 30.0;
	4900	 4872	 0.05039	 0.127715	 0.0014	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	4900	 4873	 0.05039	 0.132023	 0.0015	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	5253	 4874	 0.005442	 0.023003	 0.0003	 1213	 1213	 1213	 0.0	 0.0	 1	 -30.0	 30.0;
	5083	 4878	 0.034014	 0.072814	 0.0	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 4879	 0.001501	 0.010023	 0.0182	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5291	 4884	 0.002029	 0.013533	 0.025	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5723	 4885	 0.000693	 0.007389	 0.1617	 1704.0	 1704.0	 1704.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 4897	 0.000252	 0.000504	 0.0021	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 4900	 0.176619	 0.324767	 0.0035	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 4901	 0.010864	 0.050469	 0.0845	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5240	 4904	 0.000123	 0.001235	 0.0	 23932	 23932	 23932	 0.0	 0.0	 1	 -30.0	 30.0;
	5838	 4905	 0.003457	 0.009383	 0.0005	 3033	 3033	 3033	 0.0	 0.0	 1	 -30.0	 30.0;
	5171	 4906	 0.078105	 0.19098	 0.0019	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 4907	 0.001719	 0.011457	 0.0213	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5604	 4907	 0.00079	 0.00798	 0.0284	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 4907	 0.001434	 0.009559	 0.0172	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5424	 4915	 0.027211	 0.068531	 0.0029	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	4940	 4915	 0.053893	 0.336558	 0.0056	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	4941	 4917	 0.004186	 0.02786	 0.0516	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5393	 4917	 0.002173	 0.014242	 0.0273	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 4917	 0.004109	 0.027417	 0.0486	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5766	 4917	 0.001106	 0.007407	 0.0132	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5703	 4926	 0.010582	 0.04384	 0.0006	 655	 655	 655	 0.0	 0.0	 1	 -30.0	 30.0;
	5728	 4926	 0.047871	 0.201058	 0.0068	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	5789	 4926	 0.026455	 0.109095	 0.0013	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 4928	 0.000504	 0.00252	 0.0001	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5839	 4931	 2.5e-05	 0.000252	 0.0	 116592	 116592	 116592	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 4943	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5840	 4946	 0.000988	 0.002469	 0.0	 9817	 9817	 9817	 0.0	 0.0	 1	 -30.0	 30.0;
	5645	 4947	 0.000247	 0.003489	 0.0462	 1786.0	 1786.0	 1786.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5099	 4952	 0.01159	 0.029479	 0.0	 933	 933	 933	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 4956	 0.011358	 0.034938	 0.0016	 826	 826	 826	 0.0	 0.0	 1	 -30.0	 30.0;
	5639	 4956	 0.004074	 0.017407	 0.0026	 1697	 1697	 1697	 0.0	 0.0	 1	 -30.0	 30.0;
	5710	 4956	 0.021111	 0.054568	 0.0024	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	4966	 4958	 0.00083	 0.007052	 0.0724	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5222	 4957	 0.000731	 0.003121	 0.0051	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5479	 4958	 0.001025	 0.006888	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5559	 4958	 0.000553	 0.003595	 0.0071	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5560	 4958	 0.000533	 0.003575	 0.0061	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 4958	 0.000849	 0.00796	 0.0284	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5219	 4957	 0.000731	 0.003121	 0.0051	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5683	 4957	 0.000849	 0.008237	 0.0284	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 4957	 0.000375	 0.003733	 0.0121	 833.0	 833.0	 833.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5486	 4961	 0.023086	 0.062346	 0.0031	 449	 449	 449	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 4962	 0.004109	 0.027911	 0.0516	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5285	 4963	 0.018395	 0.050247	 0.0023	 556	 556	 556	 0.0	 0.0	 1	 -30.0	 30.0;
	5454	 4963	 0.024568	 0.064691	 0.0031	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	5841	 4964	 0.055178	 0.150416	 0.0017	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	5842	 4965	 0.005795	 0.011842	 0.0002	 2174	 2174	 2174	 0.0	 0.0	 1	 -30.0	 30.0;
	5161	 4967	 0.007284	 0.019383	 0.001	 1435	 1435	 1435	 0.0	 0.0	 1	 -30.0	 30.0;
	5162	 4967	 0.007407	 0.019506	 0.001	 1424	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	5468	 4970	 0.017561	 0.072436	 0.0009	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	5313	 4971	 0.030234	 0.078105	 0.0092	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	5843	 4972	 0.000756	 0.00252	 0.0001	 12855	 12855	 12855	 0.0	 0.0	 1	 -30.0	 30.0;
	5842	 4973	 0.086168	 0.179138	 0.0019	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	5124	 4976	 0.001916	 0.009323	 0.0223	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5591	 4976	 0.000514	 0.004859	 0.0182	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5123	 4976	 0.002212	 0.010114	 0.0233	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5372	 4976	 0.000948	 0.004602	 0.0081	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5373	 4975	 0.000909	 0.004385	 0.0081	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5163	 4979	 0.022469	 0.061358	 0.0	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 4983	 0.013354	 0.03477	 0.0	 793	 793	 793	 0.0	 0.0	 1	 -30.0	 30.0;
	4991	 4989	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4991	 4988	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4992	 4987	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	5247	 4994	 0.083346	 0.172487	 0.0018	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5258	 4994	 0.028597	 0.075712	 0.001	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	5832	 5000	 0.004258	 0.011338	 0.0029	 2438	 2438	 2438	 0.0	 0.0	 1	 -30.0	 30.0;
	5844	 5002	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	5609	 5003	 0.006551	 0.043084	 0.001	 678	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	5654	 5003	 0.006803	 0.017637	 0.0	 1562	 1562	 1562	 0.0	 0.0	 1	 -30.0	 30.0;
	5397	 5003	 0.003023	 0.020156	 0.0	 1449	 1449	 1449	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 5005	 0.077118	 0.141163	 0.001	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 5005	 0.012245	 0.032527	 0.0004	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	5749	 5007	 0.034845	 0.116528	 0.0013	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	5300	 5008	 0.057447	 0.105156	 0.0011	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	5632	 5009	 0.015621	 0.066767	 0.0008	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	5845	 5013	 0.009012	 0.017975	 0.0008	 1478	 1478	 1478	 0.0	 0.0	 1	 -30.0	 30.0;
	5846	 5016	 0.003779	 0.009322	 0.0001	 3024	 3024	 3024	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 5016	 0.004031	 0.009826	 0.0001	 2864	 2864	 2864	 0.0	 0.0	 1	 -30.0	 30.0;
	5548	 5020	 0.056437	 0.116049	 0.0012	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 5021	 0.028975	 0.096498	 0.0011	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	5679	 5027	 0.001481	 0.002716	 0.0002	 9602	 9602	 9602	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 5029	 0.017889	 0.048879	 0.0006	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	5848	 5030	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 5033	 0.089191	 0.183422	 0.002	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	5143	 5034	 0.001008	 0.003023	 0.0016	 8991	 8991	 8991	 0.0	 0.0	 1	 -30.0	 30.0;
	5089	 5036	 0.020741	 0.054444	 0.0026	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 5038	 0.015369	 0.044848	 0.0061	 623	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	5809	 5039	 0.040161	 0.101815	 0.0048	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	5649	 5045	 0.000988	 0.001975	 0.0002	 13450	 13450	 13450	 0.0	 0.0	 1	 -30.0	 30.0;
	4990	 5050	 0.009826	 0.032578	 0.0038	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	5767	 5050	 0.037339	 0.126455	 0.0048	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	5522	 5054	 0.016629	 0.046107	 0.0006	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	5071	 5063	 0.001127	 0.014433	 0.3408	 2203	 2203	 2203	 0.0	 0.0	 1	 -30.0	 30.0;
	5851	 5074	 0.000217	 0.000988	 0.002	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5491	 5076	 0.055169	 0.100986	 0.001	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	5342	 5078	 0.033827	 0.084444	 0.0049	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	5853	 5078	 0.016049	 0.048765	 0.0048	 591	 591	 591	 0.0	 0.0	 1	 -30.0	 30.0;
	5852	 5084	 0.03043	 0.055702	 0.0023	 478	 478	 478	 0.0	 0.0	 1	 -30.0	 30.0;
	5855	 5088	 2.5e-05	 0.001235	 0.0	 24046	 24046	 24046	 0.0	 0.0	 1	 -30.0	 30.0;
	5773	 5093	 0.021164	 0.054674	 0.0006	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 5106	 0.015394	 0.030008	 0.0003	 902	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 5106	 0.036861	 0.075762	 0.0008	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	5753	 5114	 0.025185	 0.08	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	5583	 5119	 0.002756	 0.007867	 0.0022	 3790	 3790	 3790	 0.0	 0.0	 1	 -30.0	 30.0;
	5399	 5127	 0.006299	 0.025472	 0.0173	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	5151	 5133	 0.067523	 0.166289	 0.0017	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	5605	 5134	 0.00126	 0.004787	 0.0001	 5965	 5965	 5965	 0.0	 0.0	 1	 -30.0	 30.0;
	5757	 5165	 0.048879	 0.117158	 0.0012	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	5758	 5166	 0.048879	 0.117158	 0.0012	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 5174	 0.083144	 0.200756	 0.0019	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5855	 5200	 0.009383	 0.024938	 0.0013	 1115	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	5231	 5208	 0.021416	 0.048879	 0.0006	 554	 554	 554	 0.0	 0.0	 1	 -30.0	 30.0;
	5499	 5215	 0.002963	 0.008025	 0.0003	 3545	 3545	 3545	 0.0	 0.0	 1	 -30.0	 30.0;
	5348	 5216	 0.065004	 0.15747	 0.0016	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	5450	 5223	 0.031746	 0.083648	 0.001	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	5715	 5224	 0.000101	 0.00252	 0.0	 11707	 11707	 11707	 0.0	 0.0	 1	 -30.0	 30.0;
	5466	 5271	 0.000356	 0.00241	 0.004	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5293	 5280	 0.000252	 0.000756	 0.0	 37051	 37051	 37051	 0.0	 0.0	 1	 -30.0	 30.0;
	5242	 5298	 0.015803	 0.035679	 0.0016	 778	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	5437	 5359	 0.03284	 0.089753	 0.0042	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 5363	 0.015369	 0.039808	 0.0005	 713	 713	 713	 0.0	 0.0	 1	 -30.0	 30.0;
	5722	 5379	 0.012469	 0.031605	 0.0015	 875	 875	 875	 0.0	 0.0	 1	 -30.0	 30.0;
	5611	 5397	 0.003527	 0.022928	 0.0	 1273	 1273	 1273	 0.0	 0.0	 1	 -30.0	 30.0;
	5503	 5412	 0.004444	 0.012222	 0.0006	 2284	 2284	 2284	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 5420	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	5557	 5433	 0.002771	 0.008314	 0.0001	 3270	 3270	 3270	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 5693	 0.131796	 0.441093	 0.0047	 67	 67	 67	 0.0	 0.0	 1	 -30.0	 30.0;
	5653	 5476	 0.007559	 0.018896	 0.0002	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	5584	 5478	 0.004031	 0.016125	 0.0002	 2052	 2052	 2052	 0.0	 0.0	 1	 -30.0	 30.0;
	5732	 5489	 0.042026	 0.178735	 0.0022	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	5554	 5497	 0.040383	 0.110198	 0.0053	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	5253	 5509	 0.015923	 0.067372	 0.0008	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	5668	 5509	 0.006198	 0.021819	 0.0112	 1264	 1264	 1264	 0.0	 0.0	 1	 -30.0	 30.0;
	5785	 5510	 0.00252	 0.004787	 0.0001	 6303	 6303	 6303	 0.0	 0.0	 1	 -30.0	 30.0;
	5590	 5523	 0.043739	 0.10582	 0.001	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	5824	 5526	 0.037541	 0.082389	 0.0009	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	5453	 5543	 0.009322	 0.031494	 0.0004	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 5634	 0.163559	 0.299393	 0.003	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	5600	 5602	 0.014613	 0.029226	 0.0003	 931	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	5612	 5610	 1.2e-05	 0.000123	 0.0002	 247105	 247105	 247105	 0.0	 0.0	 1	 -30.0	 30.0;
	5769	 5620	 0.102041	 0.22323	 0.0025	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5640	 5642	 0.00126	 0.003023	 0.0	 9287	 9287	 9287	 0.0	 0.0	 1	 -30.0	 30.0;
	5817	 5652	 0.046107	 0.116906	 0.0013	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	5744	 5666	 0.000691	 0.004681	 0.0091	 503.0	 503.0	 503.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 5681	 0.008395	 0.022716	 0.0011	 1227	 1227	 1227	 0.0	 0.0	 1	 -30.0	 30.0;
	5841	 5755	 0.030234	 0.082389	 0.001	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	5843	 5785	 0.00252	 0.004787	 0.0001	 6303	 6303	 6303	 0.0	 0.0	 1	 -30.0	 30.0;
	2592	 5958	 0.001087	 0.013684	 0.3523	 1474.0	 1474.0	 1474.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6067	 5958	 0.00079	 0.008375	 0.2042	 4105	 4105	 4105	 0.0	 0.0	 1	 -30.0	 30.0;
	6055	 5959	 0.000402	 0.004307	 0.1022	 7982	 7982	 7982	 0.0	 0.0	 1	 -30.0	 30.0;
	6087	 5959	 0.000997	 0.011039	 0.2632	 3115	 3115	 3115	 0.0	 0.0	 1	 -30.0	 30.0;
	5963	 5960	 0.001593	 0.015104	 0.3904	 2274	 2274	 2274	 0.0	 0.0	 1	 -30.0	 30.0;
	5963	 5960	 0.001593	 0.015104	 0.3904	 2274	 2274	 2274	 0.0	 0.0	 1	 -30.0	 30.0;
	6046	 5960	 0.000298	 0.002805	 0.0661	 341.0	 341.0	 341.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6123	 5960	 0.001094	 0.012098	 0.277	 2843	 2843	 2843	 0.0	 0.0	 1	 -30.0	 30.0;
	6131	 5960	 0.001551	 0.01509	 0.3841	 2276	 2276	 2276	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 5960	 0.001517	 0.015533	 0.3631	 2213	 2213	 2213	 0.0	 0.0	 1	 -30.0	 30.0;
	4417	 5961	 0.001457	 0.002852	 0.0121	 10754	 10754	 10754	 0.0	 0.0	 1	 -30.0	 30.0;
	140	 5962	 0.004444	 0.028249	 0.0587	 470.0	 470.0	 470.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6082	 5962	 0.001521	 0.007467	 0.0239	 4531	 4531	 4531	 0.0	 0.0	 1	 -30.0	 30.0;
	6082	 5962	 0.001501	 0.007407	 0.024	 4569	 4569	 4569	 0.0	 0.0	 1	 -30.0	 30.0;
	6048	 5963	 0.001205	 0.011669	 0.2917	 493.0	 493.0	 493.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6155	 5963	 0.003026	 0.029875	 0.7447	 520.0	 520.0	 520.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6185	 5963	 0.003199	 0.030803	 0.8002	 564.0	 564.0	 564.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6185	 5963	 0.003199	 0.030803	 0.8002	 564.0	 564.0	 564.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6223	 5963	 0.000796	 0.007798	 0.2032	 4405	 4405	 4405	 0.0	 0.0	 1	 -30.0	 30.0;
	6223	 5963	 0.000796	 0.007798	 0.2032	 4405	 4405	 4405	 0.0	 0.0	 1	 -30.0	 30.0;
	4136	 5964	 0.000644	 0.006295	 0.2022	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6059	 5964	 0.000893	 0.009709	 0.2373	 3541	 3541	 3541	 0.0	 0.0	 1	 -30.0	 30.0;
	6096	 5964	 0.00054	 0.004979	 0.1786	 6894	 6894	 6894	 0.0	 0.0	 1	 -30.0	 30.0;
	6102	 5964	 0.00047	 0.00528	 0.1219	 6513	 6513	 6513	 0.0	 0.0	 1	 -30.0	 30.0;
	3011	 5965	 0.001562	 0.012494	 0.0213	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3140	 5965	 0.000464	 0.003712	 0.0061	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5995	 5967	 0.00204	 0.02166	 0.5788	 1587	 1587	 1587	 0.0	 0.0	 1	 -30.0	 30.0;
	2799	 5968	 0.001323	 0.016184	 0.6007	 1474.0	 1474.0	 1474.0	 0.0	 0.0	 1	 -30.0	 30.0;
	266	 5968	 0.000741	 0.009398	 0.2238	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 5968	 0.000852	 0.009017	 0.2123	 392.0	 392.0	 392.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5867	 5968	 0.00117	 0.012223	 0.3004	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 5969	 0.008312	 0.049213	 0.0872	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 5969	 0.003747	 0.022341	 0.0429	 1525	 1525	 1525	 0.0	 0.0	 1	 -30.0	 30.0;
	6239	 5969	 0.000618	 0.002706	 0.0074	 12439	 12439	 12439	 0.0	 0.0	 1	 -30.0	 30.0;
	6055	 5970	 0.001198	 0.012597	 0.2888	 308.0	 308.0	 308.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6083	 5970	 0.000596	 0.006004	 0.1374	 5723	 5723	 5723	 0.0	 0.0	 1	 -30.0	 30.0;
	5991	 5971	 0.000286	 0.004044	 0.1418	 895.0	 895.0	 895.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6146	 5971	 0.000152	 0.002175	 0.0741	 569.0	 569.0	 569.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6163	 5971	 0.000538	 0.007833	 0.2593	 1030.0	 1030.0	 1030.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6170	 5971	 0.001731	 0.01662	 0.0	 2067	 2067	 2067	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 5971	 0.00034	 0.004993	 0.1619	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6038	 5972	 0.000593	 0.070993	 0.001	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 5972	 0.000395	 0.11121	 0.001	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	6245	 5972	 0.000395	 0.083751	 0.001	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 5972	 0.000592	 0.38957	 0.001	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	6070	 5973	 0.003006	 0.026904	 0.8404	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	6075	 5973	 0.001198	 0.012396	 0.2882	 2773	 2773	 2773	 0.0	 0.0	 1	 -30.0	 30.0;
	6087	 5973	 0.001898	 0.017299	 0.5141	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 5973	 0.001219	 0.011711	 0.3408	 277.0	 277.0	 277.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6194	 5973	 0.00223	 0.022922	 0.5256	 1500	 1500	 1500	 0.0	 0.0	 1	 -30.0	 30.0;
	2716	 5975	 0.001087	 0.011378	 0.2498	 1253.0	 1253.0	 1253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4136	 5975	 0.000914	 0.010325	 0.2296	 1316.0	 1316.0	 1316.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6156	 5974	 0.000861	 0.010961	 0.0479	 3141	 3141	 3141	 0.0	 0.0	 1	 -30.0	 30.0;
	5986	 5975	 0.001053	 0.012119	 0.2726	 2839	 2839	 2839	 0.0	 0.0	 1	 -30.0	 30.0;
	6102	 5975	 0.00147	 0.01699	 0.3812	 309.0	 309.0	 309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4794	 5976	 0.001462	 0.010351	 0.0213	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 5976	 0.001681	 0.011068	 0.0203	 3084	 3084	 3084	 0.0	 0.0	 1	 -30.0	 30.0;
	6191	 5976	 0.002467	 0.014972	 0.0294	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6052	 5977	 0.008435	 0.033165	 0.1033	 1009	 1009	 1009	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 5977	 0.000593	 0.003733	 0.0119	 9134	 9134	 9134	 0.0	 0.0	 1	 -30.0	 30.0;
	6048	 5978	 0.001586	 0.015422	 0.387	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6054	 5978	 0.000796	 0.008663	 0.2079	 339.0	 339.0	 339.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6155	 5978	 0.000554	 0.005187	 0.1271	 6619	 6619	 6619	 0.0	 0.0	 1	 -30.0	 30.0;
	6176	 5978	 0.000699	 0.006801	 0.1687	 5050	 5050	 5050	 0.0	 0.0	 1	 -30.0	 30.0;
	6126	 5979	 0.001086	 0.012632	 0.2902	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6189	 5979	 0.00183	 0.02106	 0.491	 1634	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	2668	 5980	 0.010933	 0.033333	 0.005	 976	 976	 976	 0.0	 0.0	 1	 -30.0	 30.0;
	6088	 5981	 0.002943	 0.018035	 0.0333	 1890	 1890	 1890	 0.0	 0.0	 1	 -30.0	 30.0;
	6233	 5981	 0.004998	 0.030578	 0.0553	 1115	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	6185	 5982	 0.00142	 0.014529	 0.4488	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6234	 5982	 0.000741	 0.007645	 0.2343	 4495	 4495	 4495	 0.0	 0.0	 1	 -30.0	 30.0;
	5993	 5983	 0.000803	 0.008906	 0.2079	 982.0	 982.0	 982.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6101	 5983	 0.000301	 0.003384	 0.0797	 10163	 10163	 10163	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 5983	 0.000139	 0.00214	 0.0632	 848.0	 848.0	 848.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6215	 5983	 0.000215	 0.002285	 0.0522	 15043	 15043	 15043	 0.0	 0.0	 1	 -30.0	 30.0;
	6018	 5985	 0.005899	 0.068291	 0.1799	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	6018	 5984	 0.005899	 0.067267	 0.1882	 512	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	6134	 5985	 0.004081	 0.027771	 0.0474	 1230	 1230	 1230	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 5984	 0.004798	 0.032109	 0.0581	 1064	 1064	 1064	 0.0	 0.0	 1	 -30.0	 30.0;
	6101	 5986	 0.001553	 0.017918	 0.4069	 479.0	 479.0	 479.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3504	 5987	 0.008751	 0.040276	 0.0654	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6178	 5987	 0.002864	 0.011378	 0.0179	 2943	 2943	 2943	 0.0	 0.0	 1	 -30.0	 30.0;
	5993	 5988	 0.002249	 0.025153	 0.5805	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6118	 5988	 0.000353	 0.003945	 0.0915	 8717	 8717	 8717	 0.0	 0.0	 1	 -30.0	 30.0;
	6189	 5988	 0.000281	 0.003141	 0.0728	 364.0	 364.0	 364.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6189	 5988	 0.000277	 0.003137	 0.0727	 365.0	 365.0	 365.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6197	 5988	 0.000547	 0.00624	 0.1444	 5512	 5512	 5512	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 5989	 0.001648	 0.019287	 0.5958	 1784	 1784	 1784	 0.0	 0.0	 1	 -30.0	 30.0;
	6252	 5989	 0.00088	 0.00982	 0.2714	 624.0	 624.0	 624.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6134	 5990	 0.007409	 0.028518	 0.0894	 1172	 1172	 1172	 0.0	 0.0	 1	 -30.0	 30.0;
	6191	 5990	 0.0064	 0.034193	 0.0682	 993	 993	 993	 0.0	 0.0	 1	 -30.0	 30.0;
	5997	 5991	 0.000435	 0.005367	 0.1219	 6412	 6412	 6412	 0.0	 0.0	 1	 -30.0	 30.0;
	6008	 5991	 0.00022	 0.00322	 0.105	 667.0	 667.0	 667.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6057	 5991	 0.001385	 0.01108	 0.0	 791.0	 791.0	 791.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6146	 5991	 0.000194	 0.002771	 0.0952	 870.0	 870.0	 870.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6170	 5991	 0.001385	 0.014197	 0.0	 324.0	 324.0	 324.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6029	 5992	 0.000699	 0.008116	 0.2498	 4239	 4239	 4239	 0.0	 0.0	 1	 -30.0	 30.0;
	6113	 5992	 0.00097	 0.011288	 0.3483	 3048	 3048	 3048	 0.0	 0.0	 1	 -30.0	 30.0;
	6102	 5993	 0.001098	 0.012329	 0.2859	 417.0	 417.0	 417.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6118	 5993	 0.001895	 0.021197	 0.491	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6197	 5993	 0.002071	 0.023103	 0.5343	 1489	 1489	 1489	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 5994	 0.00031	 0.0032	 0.0783	 10739	 10739	 10739	 0.0	 0.0	 1	 -30.0	 30.0;
	5870	 5994	 0.00042	 0.00354	 0.0864	 9685	 9685	 9685	 0.0	 0.0	 1	 -30.0	 30.0;
	5869	 5994	 0.00034	 0.00361	 0.0884	 9522	 9522	 9522	 0.0	 0.0	 1	 -30.0	 30.0;
	6017	 5994	 0.00102	 0.01074	 0.2625	 3201	 3201	 3201	 0.0	 0.0	 1	 -30.0	 30.0;
	6011	 5995	 4e-05	 0.00045	 0.0113	 76420	 76420	 76420	 0.0	 0.0	 1	 -30.0	 30.0;
	6010	 5995	 4e-05	 0.00045	 0.0113	 76420	 76420	 76420	 0.0	 0.0	 1	 -30.0	 30.0;
	6067	 5995	 0.00095	 0.01006	 0.231	 3417	 3417	 3417	 0.0	 0.0	 1	 -30.0	 30.0;
	6067	 5995	 0.000907	 0.009626	 0.2429	 3571	 3571	 3571	 0.0	 0.0	 1	 -30.0	 30.0;
	6023	 5996	 0.004757	 0.023662	 0.0811	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6250	 5996	 0.003358	 0.01681	 0.0566	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	6190	 5997	 0.001644	 0.019926	 0.4375	 645.0	 645.0	 645.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 5998	 0.002148	 0.018414	 0.6671	 1863	 1863	 1863	 0.0	 0.0	 1	 -30.0	 30.0;
	6085	 5998	 0.002278	 0.019508	 0.7042	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6085	 5998	 0.002278	 0.019508	 0.7042	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6008	 5999	 0.000256	 0.003788	 0.1238	 415.0	 415.0	 415.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6135	 5999	 0.000425	 0.006233	 0.2037	 530.0	 530.0	 530.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6001	 6000	 0.006044	 0.04399	 0.0809	 778	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	6247	 6000	 0.003526	 0.024948	 0.0597	 1371	 1371	 1371	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 6198	 0.001521	 0.009047	 0.0172	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6007	 6002	 0.000977	 0.009199	 0.2111	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6116	 6002	 0.000672	 0.009862	 0.3233	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6158	 6002	 0.000564	 0.006641	 0.1565	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	799	 6004	 0.002171	 0.033086	 0.8404	 1033	 1033	 1033	 0.0	 0.0	 1	 -30.0	 30.0;
	6073	 6003	 0.00499	 0.029882	 0.053	 1140	 1140	 1140	 0.0	 0.0	 1	 -30.0	 30.0;
	6134	 6003	 0.011619	 0.075838	 0.1313	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 6003	 0.000168	 0.002564	 0.0077	 13437	 13437	 13437	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 6003	 0.000442	 0.003311	 0.006	 10336	 10336	 10336	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 6003	 0.000442	 0.003311	 0.006	 10336	 10336	 10336	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 6005	 0.00144	 0.007267	 0.014	 4661	 4661	 4661	 0.0	 0.0	 1	 -30.0	 30.0;
	6165	 6005	 0.001699	 0.006835	 0.0207	 4902	 4902	 4902	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 6005	 0.004595	 0.023202	 0.0448	 1460	 1460	 1460	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 6006	 0.00697	 0.028385	 0.0825	 1182	 1182	 1182	 0.0	 0.0	 1	 -30.0	 30.0;
	6191	 6006	 0.002121	 0.00944	 0.025	 3569	 3569	 3569	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 6007	 0.000208	 0.001994	 0.0458	 810.0	 810.0	 810.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6165	 6009	 0.001464	 0.005926	 0.018	 5656	 5656	 5656	 0.0	 0.0	 1	 -30.0	 30.0;
	6239	 6009	 0.001867	 0.007704	 0.0228	 4356	 4356	 4356	 0.0	 0.0	 1	 -30.0	 30.0;
	6136	 6012	 0.002765	 0.015802	 0.0284	 459.0	 459.0	 459.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6144	 6012	 0.001481	 0.008435	 0.0153	 4032	 4032	 4032	 0.0	 0.0	 1	 -30.0	 30.0;
	6179	 6012	 0.007546	 0.023803	 0.0719	 1383	 1383	 1383	 0.0	 0.0	 1	 -30.0	 30.0;
	6017	 6013	 0.000949	 0.010021	 0.2458	 514.0	 514.0	 514.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6067	 6013	 0.000693	 0.007271	 0.1793	 699.0	 699.0	 699.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6052	 6014	 0.002449	 0.009363	 0.0294	 3568	 3568	 3568	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 6014	 0.006281	 0.025146	 0.078	 1333	 1333	 1333	 0.0	 0.0	 1	 -30.0	 30.0;
	6137	 6015	 0.001018	 0.011565	 0.3581	 2974	 2974	 2974	 0.0	 0.0	 1	 -30.0	 30.0;
	6137	 6015	 0.001018	 0.011537	 0.361	 2981	 2981	 2981	 0.0	 0.0	 1	 -30.0	 30.0;
	6187	 6015	 0.000125	 0.001627	 0.0549	 21158	 21158	 21158	 0.0	 0.0	 1	 -30.0	 30.0;
	6187	 6015	 0.000125	 0.001627	 0.0549	 21158	 21158	 21158	 0.0	 0.0	 1	 -30.0	 30.0;
	1761	 6016	 0.05359	 0.118644	 0.0025	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	5473	 6016	 0.097506	 0.227891	 0.0026	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 6017	 0.00072	 0.007589	 0.1851	 4529	 4529	 4529	 0.0	 0.0	 1	 -30.0	 30.0;
	5868	 6017	 0.00027	 0.00286	 0.0702	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6065	 6017	 1e-05	 0.0001	 0.0	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6064	 6017	 1e-05	 0.0001	 0.0	 254.0	 254.0	 254.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6003	 6018	 0.002887	 0.021424	 0.0407	 1598	 1598	 1598	 0.0	 0.0	 1	 -30.0	 30.0;
	6003	 6018	 0.002887	 0.021424	 0.0407	 1598	 1598	 1598	 0.0	 0.0	 1	 -30.0	 30.0;
	6217	 6019	 0.000826	 0.012161	 0.3935	 2833	 2833	 2833	 0.0	 0.0	 1	 -30.0	 30.0;
	6236	 6019	 0.000489	 0.007064	 0.2338	 4876	 4876	 4876	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 6019	 0.000118	 0.001725	 0.057	 19968	 19968	 19968	 0.0	 0.0	 1	 -30.0	 30.0;
	6138	 6021	 0.001189	 0.010138	 0.3687	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6138	 6020	 0.001189	 0.010138	 0.3672	 343.0	 343.0	 343.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6140	 6021	 0.001236	 0.010554	 0.3821	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6140	 6020	 0.001236	 0.010554	 0.3821	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5861	 6022	 0.001165	 0.008938	 0.0484	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6036	 6025	 0.002507	 0.02106	 0.7903	 481.0	 481.0	 481.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6036	 6024	 0.002508	 0.021481	 0.7829	 538.0	 538.0	 538.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6095	 6025	 0.004181	 0.035773	 1.2967	 353.0	 353.0	 353.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6152	 6024	 0.000407	 0.006051	 0.2001	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6152	 6025	 0.000407	 0.006051	 0.2001	 814.0	 814.0	 814.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 6025	 0.000609	 0.005665	 0.2079	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5859	 6026	 0.000731	 0.003457	 0.0077	 9771	 9771	 9771	 0.0	 0.0	 1	 -30.0	 30.0;
	5858	 6026	 0.00077	 0.003457	 0.0077	 9748	 9748	 9748	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 6027	 0.024931	 0.154432	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	6072	 6027	 0.018006	 0.119806	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	6173	 6027	 0.031856	 0.161357	 0.0	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	6092	 6028	 0.000963	 0.01117	 0.3449	 3080	 3080	 3080	 0.0	 0.0	 1	 -30.0	 30.0;
	6105	 6028	 0.000838	 0.009778	 0.3018	 3518	 3518	 3518	 0.0	 0.0	 1	 -30.0	 30.0;
	6105	 6028	 0.000838	 0.009778	 0.3018	 3518	 3518	 3518	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 6028	 0.00024	 0.00296	 0.0921	 382.0	 382.0	 382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6031	 6029	 0.000769	 0.00865	 0.2718	 326.0	 326.0	 326.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6031	 6029	 0.000769	 0.00865	 0.2718	 326.0	 326.0	 326.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 6029	 0.001662	 0.019321	 0.5969	 1781	 1781	 1781	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 6030	 0.00157	 0.01564	 0.3832	 585.0	 585.0	 585.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 6030	 0.00049	 0.00518	 0.1271	 723.0	 723.0	 723.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 6030	 0.00049	 0.00518	 0.1271	 723.0	 723.0	 723.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 6030	 0.00055	 0.00474	 0.1157	 789.0	 789.0	 789.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6253	 6030	 0.00017	 0.00166	 0.0347	 526.0	 526.0	 526.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6080	 6031	 0.00099	 0.011177	 0.3515	 550.0	 550.0	 550.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6080	 6031	 0.00099	 0.011177	 0.3515	 550.0	 550.0	 550.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 6032	 0.00026	 0.00273	 0.067	 12590	 12590	 12590	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 6033	 0.00026	 0.002717	 0.067	 12649	 12649	 12649	 0.0	 0.0	 1	 -30.0	 30.0;
	4991	 6034	 0.00212	 0.011757	 0.0051	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3103	 6036	 0.000528	 0.005682	 0.1011	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6077	 6035	 0.009193	 0.044869	 0.1296	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	6078	 6034	 0.009193	 0.044869	 0.1296	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	6250	 6035	 0.002892	 0.022074	 0.1215	 1551	 1551	 1551	 0.0	 0.0	 1	 -30.0	 30.0;
	6249	 6034	 0.005687	 0.02834	 0.0952	 1195	 1195	 1195	 0.0	 0.0	 1	 -30.0	 30.0;
	6096	 6036	 0.001732	 0.014836	 0.5408	 398.0	 398.0	 398.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6095	 6036	 0.001731	 0.014547	 0.5457	 2357	 2357	 2357	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 6037	 0.00106	 0.012389	 0.3827	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 6037	 0.00106	 0.012389	 0.3827	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 6037	 0.00106	 0.012389	 0.3827	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 6037	 0.00081	 0.009439	 0.2916	 3645	 3645	 3645	 0.0	 0.0	 1	 -30.0	 30.0;
	6113	 6037	 0.00081	 0.009439	 0.2916	 3645	 3645	 3645	 0.0	 0.0	 1	 -30.0	 30.0;
	6074	 6038	 0.000593	 0.171854	 0.001	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	6086	 6038	 0.00162	 0.013057	 0.0391	 2624	 2624	 2624	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 6038	 0.000395	 0.036148	 0.001	 956	 956	 956	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 6038	 0.000592	 0.001679	 0.001	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5865	 6039	 0.000596	 0.006247	 0.2108	 695.0	 695.0	 695.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5871	 6039	 0.000769	 0.010215	 0.3422	 453.0	 453.0	 453.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6139	 6039	 0.000596	 0.006219	 0.2079	 693.0	 693.0	 693.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6218	 6039	 0.000526	 0.006881	 0.2313	 571.0	 571.0	 571.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 6043	 0.000512	 0.007112	 0.2585	 1790.0	 1790.0	 1790.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 6042	 0.000506	 0.007112	 0.2585	 1790.0	 1790.0	 1790.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5859	 6041	 0.000705	 0.003692	 0.0118	 9186	 9186	 9186	 0.0	 0.0	 1	 -30.0	 30.0;
	5858	 6041	 0.00067	 0.003579	 0.012	 9482	 9482	 9482	 0.0	 0.0	 1	 -30.0	 30.0;
	6200	 6040	 0.000119	 0.007901	 0.0	 779.0	 779.0	 779.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6221	 6043	 0.000443	 0.004077	 0.1429	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6221	 6042	 0.000443	 0.004078	 0.1429	 8417	 8417	 8417	 0.0	 0.0	 1	 -30.0	 30.0;
	6105	 6044	 0.000353	 0.004072	 0.1257	 8447	 8447	 8447	 0.0	 0.0	 1	 -30.0	 30.0;
	6105	 6044	 0.000353	 0.004072	 0.1257	 8447	 8447	 8447	 0.0	 0.0	 1	 -30.0	 30.0;
	6255	 6044	 0.00054	 0.006094	 0.1916	 5644	 5644	 5644	 0.0	 0.0	 1	 -30.0	 30.0;
	6255	 6044	 0.00054	 0.006094	 0.1916	 5644	 5644	 5644	 0.0	 0.0	 1	 -30.0	 30.0;
	5864	 6045	 0.00099	 0.007918	 0.014	 4327	 4327	 4327	 0.0	 0.0	 1	 -30.0	 30.0;
	6235	 6045	 0.003899	 0.025983	 0.0509	 1315	 1315	 1315	 0.0	 0.0	 1	 -30.0	 30.0;
	6070	 6046	 7.3e-05	 0.003959	 0.0029	 832.0	 832.0	 832.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6131	 6046	 7.3e-05	 0.003635	 0.0029	 503.0	 503.0	 503.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6122	 6047	 0.000593	 0.549393	 0.001	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	6154	 6047	 0.000593	 0.274647	 0.001	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	6214	 6047	 9.9e-05	 0.000672	 0.001	 50827	 50827	 50827	 0.0	 0.0	 1	 -30.0	 30.0;
	6160	 6049	 0.000751	 0.002609	 0.0006	 12717	 12717	 12717	 0.0	 0.0	 1	 -30.0	 30.0;
	6211	 6049	 0.00124	 0.004622	 0.0016	 7215	 7215	 7215	 0.0	 0.0	 1	 -30.0	 30.0;
	6168	 6050	 0.00111	 0.0124	 0.2946	 519.0	 519.0	 519.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6189	 6050	 0.000368	 0.004359	 0.0947	 521.0	 521.0	 521.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6057	 6051	 0.001039	 0.007479	 0.0	 4573	 4573	 4573	 0.0	 0.0	 1	 -30.0	 30.0;
	6147	 6051	 0.017313	 0.182133	 0.0	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	6170	 6051	 0.002424	 0.019391	 0.0	 1767	 1767	 1767	 0.0	 0.0	 1	 -30.0	 30.0;
	6195	 6051	 0.002424	 0.01385	 0.0	 2456	 2456	 2456	 0.0	 0.0	 1	 -30.0	 30.0;
	1068	 6129	 0.006104	 0.044405	 0.0552	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 6052	 0.001659	 0.0064	 0.0237	 5222	 5222	 5222	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 6052	 0.001659	 0.0064	 0.0237	 5222	 5222	 5222	 0.0	 0.0	 1	 -30.0	 30.0;
	6149	 6053	 0.0016	 0.011773	 0.0203	 459.0	 459.0	 459.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6169	 6053	 0.002173	 0.015388	 0.0172	 347.0	 347.0	 347.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6223	 6054	 0.001828	 0.019868	 0.4794	 523.0	 523.0	 523.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6075	 6055	 0.000796	 0.008698	 0.201	 538.0	 538.0	 538.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6092	 6056	 0.000568	 0.006586	 0.205	 377.0	 377.0	 377.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6092	 6056	 0.000568	 0.006586	 0.205	 377.0	 377.0	 377.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6252	 6056	 0.00113	 0.01283	 0.3286	 2681	 2681	 2681	 0.0	 0.0	 1	 -30.0	 30.0;
	6153	 6057	 0.000418	 0.006302	 0.1928	 5467	 5467	 5467	 0.0	 0.0	 1	 -30.0	 30.0;
	6167	 6057	 0.0016	 0.023587	 0.68	 525.0	 525.0	 525.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 6058	 0.001284	 0.014657	 0.0554	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6101	 6059	 0.000422	 0.005118	 0.1184	 652.0	 652.0	 652.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6126	 6059	 0.000637	 0.009162	 0.2316	 630.0	 630.0	 630.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6126	 6059	 0.000852	 0.009571	 0.2189	 602.0	 602.0	 602.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6062	 6061	 0.005329	 0.016298	 0.0056	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	6062	 6060	 0.005329	 0.016298	 0.0056	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	6211	 6061	 0.004529	 0.020129	 0.0072	 1674	 1674	 1674	 0.0	 0.0	 1	 -30.0	 30.0;
	6211	 6060	 0.004529	 0.020129	 0.0072	 1674	 1674	 1674	 0.0	 0.0	 1	 -30.0	 30.0;
	6128	 6062	 0.003818	 0.0204	 0.0074	 1664	 1664	 1664	 0.0	 0.0	 1	 -30.0	 30.0;
	6128	 6062	 0.003818	 0.0204	 0.0074	 1664	 1664	 1664	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 6066	 0.038781	 0.237535	 0.0	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	6147	 6066	 0.025623	 0.202909	 0.0	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	6162	 6066	 0.024931	 0.09903	 0.0	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 6066	 0.022161	 0.168283	 0.0	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 6067	 0.00087	 0.00968	 0.2313	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5868	 6067	 0.00121	 0.01281	 0.3145	 709.0	 709.0	 709.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6216	 6067	 6e-05	 0.00059	 0.0144	 441.0	 441.0	 441.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6074	 6068	 0.000395	 0.145778	 0.001	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 6070	 0.001295	 0.011302	 0.3812	 3035	 3035	 3035	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 6070	 0.000104	 0.003904	 0.0029	 8841	 8841	 8841	 0.0	 0.0	 1	 -30.0	 30.0;
	6131	 6070	 7.3e-05	 0.039586	 0.0029	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	6159	 6070	 7.3e-05	 0.016832	 0.0029	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 6070	 7.3e-05	 0.009151	 0.0029	 395.0	 395.0	 395.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6213	 6070	 7.3e-05	 0.069075	 0.0029	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	6246	 6070	 0.000547	 0.004696	 1.2794	 1279.0	 1279.0	 1279.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6072	 6071	 0.032549	 0.126731	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 6071	 0.033934	 0.182133	 0.0	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	6080	 6072	 0.000407	 0.004079	 0.1162	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6080	 6072	 0.000407	 0.004079	 0.1162	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6201	 6072	 4.8e-05	 0.001177	 0.0029	 29308	 29308	 29308	 0.0	 0.0	 1	 -30.0	 30.0;
	6134	 6073	 0.006744	 0.045697	 0.0819	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	6243	 6074	 0.000395	 0.202864	 0.001	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 6074	 0.000593	 0.087308	 0.001	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	6181	 6075	 0.000298	 0.003006	 0.0713	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6237	 6075	 0.00162	 0.016378	 0.3829	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6122	 6076	 0.000593	 0.32164	 0.001	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	6150	 6076	 0.000593	 0.023506	 0.001	 1469	 1469	 1469	 0.0	 0.0	 1	 -30.0	 30.0;
	6178	 6076	 0.010588	 0.054894	 0.1043	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6099	 6077	 0.001754	 0.012251	 0.0484	 2790	 2790	 2790	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 6078	 0.001762	 0.012148	 0.049	 2813	 2813	 2813	 0.0	 0.0	 1	 -30.0	 30.0;
	6134	 6079	 0.004508	 0.017357	 0.0537	 1926	 1926	 1926	 0.0	 0.0	 1	 -30.0	 30.0;
	6191	 6079	 0.0093	 0.045353	 0.1033	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	6255	 6080	 0.001018	 0.011454	 0.3604	 3003	 3003	 3003	 0.0	 0.0	 1	 -30.0	 30.0;
	6255	 6080	 0.001018	 0.011454	 0.3604	 3003	 3003	 3003	 0.0	 0.0	 1	 -30.0	 30.0;
	6085	 6081	 0.003133	 0.026821	 0.6166	 281.0	 281.0	 281.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6215	 6081	 0.002718	 0.024668	 0.5747	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 6081	 0.00277	 0.01662	 0.0	 2050	 2050	 2050	 0.0	 0.0	 1	 -30.0	 30.0;
	141	 6083	 0.001088	 0.01173	 0.2548	 1624.0	 1624.0	 1624.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6086	 6082	 0.004583	 0.024	 0.0701	 1413	 1413	 1413	 0.0	 0.0	 1	 -30.0	 30.0;
	6086	 6082	 0.004583	 0.025185	 0.0701	 1349	 1349	 1349	 0.0	 0.0	 1	 -30.0	 30.0;
	6087	 6083	 0.000796	 0.007999	 0.1863	 544.0	 544.0	 544.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 6084	 0.000873	 0.007825	 0.2541	 284.0	 284.0	 284.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6159	 6084	 7.3e-05	 0.058542	 0.0029	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 6084	 7.3e-05	 0.032502	 0.0029	 1063	 1063	 1063	 0.0	 0.0	 1	 -30.0	 30.0;
	6213	 6084	 7.3e-05	 0.024529	 0.0029	 1408	 1408	 1408	 0.0	 0.0	 1	 -30.0	 30.0;
	6237	 6084	 0.00153	 0.014349	 0.3379	 2393	 2393	 2393	 0.0	 0.0	 1	 -30.0	 30.0;
	6162	 6085	 0.000184	 0.002407	 0.0079	 14302	 14302	 14302	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 6085	 0.002299	 0.020665	 0.0	 486.0	 486.0	 486.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6144	 6086	 0.011477	 0.037472	 0.1077	 881	 881	 881	 0.0	 0.0	 1	 -30.0	 30.0;
	6144	 6086	 0.007763	 0.037649	 0.1241	 899	 899	 899	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 6086	 0.000573	 0.003911	 0.0071	 8735	 8735	 8735	 0.0	 0.0	 1	 -30.0	 30.0;
	6246	 6087	 0.000796	 0.0075	 0.1952	 1038.0	 1038.0	 1038.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6233	 6088	 0.007921	 0.048632	 0.0885	 701	 701	 701	 0.0	 0.0	 1	 -30.0	 30.0;
	6152	 6090	 3.7e-05	 9.3e-05	 0.0029	 344932	 344932	 344932	 0.0	 0.0	 1	 -30.0	 30.0;
	6152	 6090	 3.7e-05	 9.3e-05	 0.0029	 344932	 344932	 344932	 0.0	 0.0	 1	 -30.0	 30.0;
	6152	 6089	 8.3e-05	 0.000152	 0.0029	 199349	 199349	 199349	 0.0	 0.0	 1	 -30.0	 30.0;
	6152	 6089	 3.7e-05	 9.3e-05	 0.0029	 344932	 344932	 344932	 0.0	 0.0	 1	 -30.0	 30.0;
	5860	 6091	 6.9e-05	 0.000139	 0.0029	 222473	 222473	 222473	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 6092	 0.0012	 0.014039	 0.4369	 2451	 2451	 2451	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 6094	 0.001126	 0.005707	 0.0166	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6098	 6093	 0.001286	 0.006688	 0.0202	 5070	 5070	 5070	 0.0	 0.0	 1	 -30.0	 30.0;
	5871	 6096	 0.001066	 0.012292	 0.4641	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6101	 6095	 0.00018	 0.001517	 0.0578	 332.0	 332.0	 332.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6102	 6096	 0.00018	 0.001517	 0.0578	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6101	 6095	 0.00018	 0.001517	 0.0578	 332.0	 332.0	 332.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5861	 6097	 1.6e-05	 0.000136	 0.0007	 252116	 252116	 252116	 0.0	 0.0	 1	 -30.0	 30.0;
	4137	 6102	 0.000938	 0.010451	 0.2253	 1487.0	 1487.0	 1487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 6098	 0.005965	 0.04239	 0.1009	 807	 807	 807	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 6099	 0.003315	 0.023518	 0.0665	 1454	 1454	 1454	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 6101	 0.000202	 0.003026	 0.0921	 624.0	 624.0	 624.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6215	 6101	 0.000558	 0.004985	 0.1219	 6883	 6883	 6883	 0.0	 0.0	 1	 -30.0	 30.0;
	6218	 6102	 0.001205	 0.014626	 0.5164	 306.0	 306.0	 306.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6126	 6103	 0.002119	 0.023913	 0.0052	 604.0	 604.0	 604.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6135	 6103	 0.001177	 0.012465	 0.3177	 762.0	 762.0	 762.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 6106	 0.010317	 0.052128	 0.099	 650	 650	 650	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 6106	 0.001126	 0.010031	 0.0313	 284.0	 284.0	 284.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 6106	 0.0096	 0.078696	 0.1357	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	6157	 6107	 0.000341	 0.005024	 0.3259	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6157	 6107	 0.000341	 0.005024	 0.3259	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 6107	 0.000268	 0.003944	 0.1279	 817.0	 817.0	 817.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6134	 6108	 0.005432	 0.036524	 0.0651	 935	 935	 935	 0.0	 0.0	 1	 -30.0	 30.0;
	6119	 6110	 0.00032	 0.00305	 0.0723	 11258	 11258	 11258	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 6109	 0.00045	 0.00479	 0.1066	 7176	 7176	 7176	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 6110	 0.00045	 0.00479	 0.1066	 7176	 7176	 7176	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 6111	 0.00022	 0.00232	 0.0544	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6173	 6113	 0.001644	 0.01558	 0.4807	 905.0	 905.0	 905.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6188	 6114	 0.000693	 0.00682	 0.2072	 749.0	 749.0	 749.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6209	 6113	 0.000225	 0.002472	 0.071	 801.0	 801.0	 801.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6208	 6114	 0.000222	 0.00247	 0.0817	 1052.0	 1052.0	 1052.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6115	 0.00196	 0.020187	 0.4812	 1703	 1703	 1703	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 6115	 0.000533	 0.005305	 0.1304	 490.0	 490.0	 490.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6187	 6115	 0.001517	 0.015623	 0.3738	 377.0	 377.0	 377.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6213	 6115	 0.00196	 0.019813	 0.4881	 1735	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	6158	 6116	 0.000832	 0.012165	 0.3939	 2832	 2832	 2832	 0.0	 0.0	 1	 -30.0	 30.0;
	6248	 6116	 0.000819	 0.013667	 0.3493	 2522	 2522	 2522	 0.0	 0.0	 1	 -30.0	 30.0;
	6123	 6117	 0.000533	 0.004564	 0.1069	 7514	 7514	 7514	 0.0	 0.0	 1	 -30.0	 30.0;
	6176	 6117	 0.00286	 0.029584	 0.6931	 419.0	 419.0	 419.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6121	 6119	 0.0007	 0.007379	 0.1808	 466.0	 466.0	 466.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 6119	 0.00076	 0.008	 0.1779	 4297	 4297	 4297	 0.0	 0.0	 1	 -30.0	 30.0;
	6255	 6120	 0.001101	 0.017299	 0.7474	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6255	 6120	 0.001101	 0.017299	 0.7474	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6225	 6121	 0.001233	 0.013054	 0.3191	 1045.0	 1045.0	 1045.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6135	 6124	 0.000542	 0.007881	 0.2605	 4371	 4371	 4371	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 6124	 0.000357	 0.005187	 0.1718	 6641	 6641	 6641	 0.0	 0.0	 1	 -30.0	 30.0;
	5867	 6125	 0.00074	 0.007769	 0.1906	 580.0	 580.0	 580.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5870	 6125	 0.00041	 0.00348	 0.0846	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5869	 6125	 0.00033	 0.00352	 0.0864	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 6127	 2e-05	 9.8e-05	 0.0	 345173	 345173	 345173	 0.0	 0.0	 1	 -30.0	 30.0;
	6221	 6127	 0.000414	 0.003537	 0.2573	 9695	 9695	 9695	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 6127	 0.002424	 0.021053	 0.7624	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6130	 6128	 0.00332	 0.010222	 0.0143	 3213	 3213	 3213	 0.0	 0.0	 1	 -30.0	 30.0;
	6160	 6130	 0.003351	 0.012302	 0.0042	 2708	 2708	 2708	 0.0	 0.0	 1	 -30.0	 30.0;
	6159	 6131	 0.000155	 0.001518	 0.3148	 546.0	 546.0	 546.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5864	 6132	 0.000198	 0.001975	 0.0	 17394	 17394	 17394	 0.0	 0.0	 1	 -30.0	 30.0;
	6193	 6132	 0.004429	 0.025092	 0.0871	 1355	 1355	 1355	 0.0	 0.0	 1	 -30.0	 30.0;
	6235	 6132	 0.001414	 0.020346	 0.0707	 1693	 1693	 1693	 0.0	 0.0	 1	 -30.0	 30.0;
	6156	 6134	 0.001033	 0.013049	 0.0551	 2638	 2638	 2638	 0.0	 0.0	 1	 -30.0	 30.0;
	6144	 6136	 0.002923	 0.016731	 0.0304	 459.0	 459.0	 459.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6145	 6138	 0.000942	 0.008047	 0.2917	 4262	 4262	 4262	 0.0	 0.0	 1	 -30.0	 30.0;
	6221	 6138	 0.00194	 0.016614	 0.6003	 2064	 2064	 2064	 0.0	 0.0	 1	 -30.0	 30.0;
	5865	 6139	 3.5e-05	 0.000139	 0.0058	 240858	 240858	 240858	 0.0	 0.0	 1	 -30.0	 30.0;
	6162	 6139	 0.000807	 0.008383	 0.281	 931.0	 931.0	 931.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6148	 6140	 0.000408	 0.003572	 0.1288	 1131.0	 1131.0	 1131.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 6140	 0.000846	 0.007839	 0.2833	 4379	 4379	 4379	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 6140	 0.000846	 0.007839	 0.2823	 4379	 4379	 4379	 0.0	 0.0	 1	 -30.0	 30.0;
	6188	 6140	 0.000455	 0.00419	 0.1532	 868.0	 868.0	 868.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 6142	 0.004523	 0.022716	 0.0699	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	6196	 6142	 0.001146	 0.005669	 0.0172	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6196	 6144	 0.004405	 0.022756	 0.0697	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6221	 6145	 0.001004	 0.008546	 0.309	 4013	 4013	 4013	 0.0	 0.0	 1	 -30.0	 30.0;
	6161	 6147	 0.000554	 0.007756	 0.0	 550.0	 550.0	 550.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6170	 6147	 0.018006	 0.189058	 0.0	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 6147	 0.00277	 0.01662	 0.0	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6173	 6148	 0.00025	 0.002292	 0.0829	 1160.0	 1160.0	 1160.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 6149	 0.001561	 0.011595	 0.0172	 459.0	 459.0	 459.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6162	 6152	 0.00094	 0.012774	 0.412	 2696	 2696	 2696	 0.0	 0.0	 1	 -30.0	 30.0;
	6162	 6152	 0.00094	 0.012762	 0.411	 2698	 2698	 2698	 0.0	 0.0	 1	 -30.0	 30.0;
	6195	 6153	 0.00042	 0.006343	 0.1933	 5431	 5431	 5431	 0.0	 0.0	 1	 -30.0	 30.0;
	6185	 6155	 0.000921	 0.009017	 0.2236	 3809	 3809	 3809	 0.0	 0.0	 1	 -30.0	 30.0;
	6185	 6155	 0.000956	 0.008996	 0.2224	 3817	 3817	 3817	 0.0	 0.0	 1	 -30.0	 30.0;
	6223	 6155	 0.002424	 0.024785	 0.621	 573.0	 573.0	 573.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6234	 6155	 0.001537	 0.016662	 0.3851	 525.0	 525.0	 525.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6158	 6157	 0.000341	 0.005024	 0.3259	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6227	 6158	 0.000861	 0.009919	 0.2325	 847.0	 847.0	 847.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 6159	 7.3e-05	 0.011484	 0.0029	 3007	 3007	 3007	 0.0	 0.0	 1	 -30.0	 30.0;
	6213	 6159	 7.3e-05	 0.008668	 0.0029	 3983	 3983	 3983	 0.0	 0.0	 1	 -30.0	 30.0;
	6223	 6159	 0.003303	 0.035104	 0.7903	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	5866	 6161	 0.000945	 0.010861	 0.226	 551.0	 551.0	 551.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5865	 6162	 0.00081	 0.008386	 0.2801	 927.0	 927.0	 927.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 6162	 0.019391	 0.119806	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 6162	 0.00277	 0.16205	 0.0	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 6163	 0.000118	 0.001725	 0.057	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2240	 6164	 0.006791	 0.019711	 0.0099	 1752	 1752	 1752	 0.0	 0.0	 1	 -30.0	 30.0;
	1196	 6166	 0.011176	 0.069403	 0.1286	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6191	 6166	 0.00127	 0.019504	 0.0592	 1767	 1767	 1767	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 6166	 0.007526	 0.044761	 0.0829	 761	 761	 761	 0.0	 0.0	 1	 -30.0	 30.0;
	5866	 6167	 0.00062	 0.00665	 0.1707	 528.0	 528.0	 528.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6195	 6168	 0.000796	 0.011669	 0.3166	 392.0	 392.0	 392.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6233	 6169	 0.004978	 0.036425	 0.0648	 459.0	 459.0	 459.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5867	 6171	 0.0	 0.0005	 0.0012	 69049	 69049	 69049	 0.0	 0.0	 1	 -30.0	 30.0;
	36	 6206	 0.001724	 0.039197	 0.5453	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 6205	 0.001724	 0.039197	 0.5453	 947	 947	 947	 0.0	 0.0	 1	 -30.0	 30.0;
	6226	 6172	 0.000527	 0.008085	 0.0244	 4262	 4262	 4262	 0.0	 0.0	 1	 -30.0	 30.0;
	6232	 6172	 0.001679	 0.025659	 0.0779	 1343	 1343	 1343	 0.0	 0.0	 1	 -30.0	 30.0;
	5860	 6173	 0.000438	 0.003941	 0.1411	 1205.0	 1205.0	 1205.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6206	 6175	 2.1e-05	 0.000139	 0.0	 245589	 245589	 245589	 0.0	 0.0	 1	 -30.0	 30.0;
	6217	 6175	 0.000275	 0.004076	 0.1317	 8451	 8451	 8451	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 6175	 0.000958	 0.014044	 0.4598	 712.0	 712.0	 712.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6223	 6176	 0.002881	 0.02894	 0.7249	 479.0	 479.0	 479.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6213	 6177	 7.3e-05	 0.000789	 0.0029	 43571	 43571	 43571	 0.0	 0.0	 1	 -30.0	 30.0;
	6179	 6178	 0.015585	 0.053156	 0.1438	 624	 624	 624	 0.0	 0.0	 1	 -30.0	 30.0;
	6214	 6178	 0.007388	 0.039506	 0.0658	 860	 860	 860	 0.0	 0.0	 1	 -30.0	 30.0;
	5864	 6182	 0.004648	 0.037179	 0.0658	 922	 922	 922	 0.0	 0.0	 1	 -30.0	 30.0;
	6247	 6182	 0.000277	 0.003773	 0.0175	 390.0	 390.0	 390.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5860	 6183	 0.000241	 0.002382	 0.078	 1196.0	 1196.0	 1196.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6194	 6187	 0.001427	 0.014647	 0.3362	 2346	 2346	 2346	 0.0	 0.0	 1	 -30.0	 30.0;
	5866	 6189	 0.000855	 0.010109	 0.2201	 3404	 3404	 3404	 0.0	 0.0	 1	 -30.0	 30.0;
	6190	 6189	 0.001187	 0.012493	 0.2917	 807.0	 807.0	 807.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1195	 6191	 0.008751	 0.05361	 0.0972	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6232	 6191	 0.000689	 0.010295	 0.0336	 3347	 3347	 3347	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 6192	 0.006341	 0.033679	 0.0557	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6233	 6192	 0.005472	 0.030775	 0.0557	 326.0	 326.0	 326.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6235	 6193	 0.007955	 0.045827	 0.0843	 743	 743	 743	 0.0	 0.0	 1	 -30.0	 30.0;
	6027	 6203	 0.000474	 0.005325	 0.1567	 1316.0	 1316.0	 1316.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6027	 6202	 0.000474	 0.005325	 0.1567	 1317.0	 1317.0	 1317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6252	 6210	 4.2e-05	 0.004848	 0.0289	 825.0	 825.0	 825.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5868	 6212	 0.00016	 0.0017	 0.04	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6146	 6219	 0.00034	 0.004993	 0.1619	 623.0	 623.0	 623.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5859	 6220	 0.001884	 0.010078	 0.0338	 3368	 3368	 3368	 0.0	 0.0	 1	 -30.0	 30.0;
	5858	 6220	 0.001881	 0.01006	 0.0338	 3374	 3374	 3374	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 6221	 0.000415	 0.003543	 0.2573	 9679	 9679	 9679	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 6224	 0.000859	 0.009605	 0.2181	 802.0	 802.0	 802.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 6226	 0.002272	 0.033284	 0.1153	 1035	 1035	 1035	 0.0	 0.0	 1	 -30.0	 30.0;
	4947	 6227	 0.000665	 0.008026	 0.1256	 1316.0	 1316.0	 1316.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5870	 6229	 0.00046	 0.00479	 0.1207	 7175	 7175	 7175	 0.0	 0.0	 1	 -30.0	 30.0;
	5869	 6228	 0.00047	 0.00493	 0.1207	 6972	 6972	 6972	 0.0	 0.0	 1	 -30.0	 30.0;
	1961	 6230	 0.002785	 0.018588	 0.0354	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1961	 6230	 0.002785	 0.018607	 0.0354	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	799	 6231	 0.000125	 0.001711	 0.0462	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	325	 6234	 0.002087	 0.022763	 0.6108	 1498	 1498	 1498	 0.0	 0.0	 1	 -30.0	 30.0;
	5871	 6238	 0.000312	 0.002645	 0.1129	 12963	 12963	 12963	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 6242	 0.000395	 0.198321	 0.001	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	6236	 6248	 0.000855	 0.014271	 0.3697	 809.0	 809.0	 809.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5861	 6249	 0.002815	 0.02159	 0.1187	 355.0	 355.0	 355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 27	 0.00318	 0.114765	 0.0	 266	 266	 266	 0.967114	 0.0	 1	 -30.0	 30.0;
	26	 27	 0.003062	 0.115753	 0.0	 264	 264	 264	 0.958773	 0.0	 1	 -30.0	 30.0;
	26	 27	 0.00318	 0.117926	 0.0	 259	 259	 259	 0.956938	 0.0	 1	 -30.0	 30.0;
	31	 33	 0.001975	 0.126617	 0.0	 243	 243	 243	 0.989123	 0.0	 1	 -30.0	 30.0;
	31	 34	 0.003635	 0.123062	 0.0	 250	 250	 250	 0.976559	 0.0	 1	 -30.0	 30.0;
	32	 33	 0.003556	 0.120296	 0.0	 265	 265	 265	 0.980392	 0.0	 1	 -30.0	 30.0;
	33	 5900	 0.00018	 -0.006163	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	34	 5924	 0.00018	 -0.006163	 0.0	 1188.0	 1188.0	 1188.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	35	 5900	 0.000291	 0.030817	 0.0	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 5924	 0.000291	 0.030817	 0.0	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	50	 51	 0.00316	 0.125432	 0.0	 246	 246	 246	 1.026695	 0.0	 1	 -30.0	 30.0;
	50	 51	 0.003951	 0.125235	 0.0	 246	 246	 246	 1.026695	 0.0	 1	 -30.0	 30.0;
	50	 51	 0.00316	 0.125432	 0.0	 246	 246	 246	 1.026695	 0.0	 1	 -30.0	 30.0;
	103	 104	 0.003951	 0.110025	 0.0	 281	 281	 281	 0.96432	 0.0	 1	 -30.0	 30.0;
	103	 104	 0.00397	 0.111605	 0.0	 277	 277	 277	 0.973708	 0.0	 1	 -30.0	 30.0;
	109	 110	 0.003556	 0.119309	 0.0	 258	 258	 258	 1.053742	 0.0	 1	 -30.0	 30.0;
	109	 110	 0.00316	 0.125037	 0.0	 246	 246	 246	 1.053742	 0.0	 1	 -30.0	 30.0;
	112	 113	 0.003279	 0.11358	 0.0	 271	 271	 271	 0.974664	 0.0	 1	 -30.0	 30.0;
	112	 113	 0.00324	 0.117531	 0.0	 262	 262	 262	 0.968054	 0.0	 1	 -30.0	 30.0;
	112	 113	 0.003753	 0.112395	 0.0	 273	 273	 273	 0.96432	 0.0	 1	 -30.0	 30.0;
	128	 130	 0.003338	 0.116543	 0.0	 262	 262	 262	 0.999001	 0.0	 1	 -30.0	 30.0;
	129	 130	 0.003595	 0.128593	 0.0	 237	 237	 237	 0.999001	 0.0	 1	 -30.0	 30.0;
	137	 138	 0.002178	 0.149156	 0.0	 203	 203	 203	 0.999001	 0.0	 1	 -30.0	 30.0;
	139	 140	 0.001719	 0.122074	 0.0	 253	 253	 253	 0.978474	 0.0	 1	 -30.0	 30.0;
	140	 141	 0.000332	 0.025	 0.0	 1187.0	 1187.0	 1187.0	 1.001	 0.0	 1	 -30.0	 30.0;
	142	 143	 0.001857	 0.114963	 0.0	 269	 269	 269	 0.965246	 0.0	 1	 -30.0	 30.0;
	142	 143	 0.001936	 0.117926	 0.0	 262	 262	 262	 0.96432	 0.0	 1	 -30.0	 30.0;
	144	 145	 0.003062	 0.112593	 0.0	 285	 285	 285	 0.977517	 0.0	 1	 -30.0	 30.0;
	144	 146	 0.003158	 0.160111	 0.0	 201	 201	 201	 0.970871	 0.0	 1	 -30.0	 30.0;
	144	 146	 0.003144	 0.160319	 0.0	 201	 201	 201	 0.970871	 0.0	 1	 -30.0	 30.0;
	145	 5872	 0.000145	 -0.006302	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	145	 5925	 0.000125	 -0.006787	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	146	 5872	 0.000194	 0.031302	 0.0	 1094	 1094	 1094	 0.0	 0.0	 1	 -30.0	 30.0;
	146	 5925	 0.000215	 0.031995	 0.0	 1070	 1070	 1070	 0.0	 0.0	 1	 -30.0	 30.0;
	156	 152	 0.000252	 0.00252	 0.0003	 11659	 11659	 11659	 1.0	 -1.3	 1	 -30.0	 30.0;
	153	 154	 0.003437	 0.094815	 0.0	 324	 324	 324	 0.98912	 0.0	 1	 -30.0	 30.0;
	157	 159	 0.025195	 0.195515	 0.0	 150	 150	 150	 0.910743	 0.0	 1	 -30.0	 30.0;
	165	 168	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	166	 168	 0.00316	 0.10884	 0.0	 281	 281	 281	 0.983282	 0.0	 1	 -30.0	 30.0;
	166	 168	 0.00316	 0.11358	 0.0	 269	 269	 269	 0.983282	 0.0	 1	 -30.0	 30.0;
	166	 168	 0.00318	 0.113185	 0.0	 270	 270	 270	 0.983282	 0.0	 1	 -30.0	 30.0;
	167	 168	 0.003121	 0.116148	 0.0	 263	 263	 263	 0.985226	 0.0	 1	 -30.0	 30.0;
	171	 172	 0.003951	 0.113185	 0.0	 273	 273	 273	 0.973708	 0.0	 1	 -30.0	 30.0;
	171	 172	 0.003951	 0.113185	 0.0	 273	 273	 273	 0.985226	 0.0	 1	 -30.0	 30.0;
	180	 5901	 0.002548	 0.083951	 0.0	 412	 412	 412	 1.0	 0.0	 1	 -30.0	 30.0;
	181	 5926	 0.002153	 0.061235	 0.0	 564	 564	 564	 1.0	 0.0	 1	 -30.0	 30.0;
	182	 5901	 0.000909	 -0.006716	 0.0	 444.0	 444.0	 444.0	 1.003009	 0.0	 1	 -30.0	 30.0;
	182	 5926	 0.001304	 -0.006123	 0.0	 444.0	 444.0	 444.0	 0.98912	 0.0	 1	 -30.0	 30.0;
	183	 5901	 0.002252	 0.11358	 0.0	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	183	 5926	 0.002449	 0.127407	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	205	 206	 0.001758	 0.091062	 0.0	 346	 346	 346	 1.006036	 0.0	 1	 -30.0	 30.0;
	205	 206	 0.001758	 0.091062	 0.0	 346	 346	 346	 0.995025	 0.0	 1	 -30.0	 30.0;
	206	 207	 0.000665	 0.048338	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	206	 207	 0.000783	 0.039612	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	212	 214	 0.000277	 0.009481	 0.001	 446.0	 446.0	 446.0	 0.957854	 0.0	 1	 -30.0	 30.0;
	213	 215	 0.000277	 0.009481	 0.001	 446.0	 446.0	 446.0	 0.957854	 0.0	 1	 -30.0	 30.0;
	213	 215	 0.000277	 0.009481	 0.0	 446.0	 446.0	 446.0	 0.957854	 0.0	 1	 -30.0	 30.0;
	216	 217	 0.00324	 0.117728	 0.0	 262	 262	 262	 0.985226	 0.0	 1	 -30.0	 30.0;
	216	 217	 0.003101	 0.118321	 0.0	 261	 261	 261	 0.985226	 0.0	 1	 -30.0	 30.0;
	216	 217	 0.00324	 0.117728	 0.0	 262	 262	 262	 0.962466	 0.0	 1	 -30.0	 30.0;
	223	 224	 0.004741	 0.156049	 0.0	 197	 197	 197	 0.946073	 0.0	 1	 -30.0	 30.0;
	235	 236	 0.015309	 0.465432	 0.0	 74	 74	 74	 1.0	 0.0	 1	 -30.0	 30.0;
	248	 249	 0.004543	 0.160988	 0.0	 191	 191	 191	 0.946073	 0.0	 1	 -30.0	 30.0;
	258	 259	 0.003378	 0.105679	 0.0	 292	 292	 292	 0.956938	 0.0	 1	 -30.0	 30.0;
	261	 262	 0.014262	 0.231111	 0.0	 134	 134	 134	 0.978474	 0.0	 1	 -30.0	 30.0;
	261	 262	 0.012504	 0.325926	 0.0	 95	 95	 95	 0.957851	 0.0	 1	 -30.0	 30.0;
	264	 266	 0.000346	 0.025139	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	264	 266	 0.000339	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	265	 266	 0.000339	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	274	 275	 0.003437	 0.122469	 0.0	 249	 249	 249	 0.999001	 0.0	 1	 -30.0	 30.0;
	274	 275	 0.003733	 0.122667	 0.0	 249	 249	 249	 0.978477	 0.0	 1	 -30.0	 30.0;
	277	 278	 0.000803	 0.042452	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	279	 280	 0.003062	 0.116148	 0.0	 263	 263	 263	 0.962466	 0.0	 1	 -30.0	 30.0;
	279	 280	 0.003279	 0.110222	 0.0	 277	 277	 277	 0.96432	 0.0	 1	 -30.0	 30.0;
	315	 316	 0.003872	 0.123852	 0.0	 249	 249	 249	 0.98619	 0.0	 1	 -30.0	 30.0;
	315	 316	 0.003872	 0.123852	 0.0	 249	 249	 249	 0.956938	 0.0	 1	 -30.0	 30.0;
	323	 325	 0.002916	 0.161475	 0.0	 196	 196	 196	 1.023541	 0.0	 1	 -30.0	 30.0;
	323	 325	 0.001801	 0.100416	 0.0	 316	 316	 316	 0.984249	 0.0	 1	 -30.0	 30.0;
	323	 325	 0.002825	 0.153927	 0.0	 206	 206	 206	 1.014199	 0.0	 1	 -30.0	 30.0;
	324	 325	 0.000734	 0.045014	 0.0	 593.0	 593.0	 593.0	 0.956938	 0.0	 1	 -30.0	 30.0;
	324	 325	 0.000727	 0.044668	 0.0	 593.0	 593.0	 593.0	 0.956938	 0.0	 1	 -30.0	 30.0;
	328	 329	 0.003931	 0.12484	 0.0	 247	 247	 247	 1.023541	 0.0	 1	 -30.0	 30.0;
	328	 329	 0.004662	 0.160988	 0.0	 192	 192	 192	 0.98912	 0.0	 1	 -30.0	 30.0;
	332	 333	 0.003516	 0.12563	 0.0	 246	 246	 246	 1.0	 0.0	 1	 -30.0	 30.0;
	332	 333	 0.003536	 0.126617	 0.0	 244	 244	 244	 0.98912	 0.0	 1	 -30.0	 30.0;
	344	 345	 0.003081	 0.118123	 0.0	 261	 261	 261	 1.0	 0.0	 1	 -30.0	 30.0;
	362	 363	 0.016	 0.324444	 0.0	 97	 97	 97	 0.984252	 0.0	 1	 -30.0	 30.0;
	362	 363	 0.013333	 0.328889	 0.0	 96	 96	 96	 0.971817	 0.0	 1	 -30.0	 30.0;
	362	 363	 0.016889	 0.398222	 0.0	 79	 79	 79	 0.984252	 0.0	 1	 -30.0	 30.0;
	362	 364	 0.003852	 0.123457	 0.0	 250	 250	 250	 0.978474	 0.0	 1	 -30.0	 30.0;
	380	 381	 0.003951	 0.123457	 0.0	 249	 249	 249	 0.989123	 0.0	 1	 -30.0	 30.0;
	380	 381	 0.003753	 0.12563	 0.0	 245	 245	 245	 0.989123	 0.0	 1	 -30.0	 30.0;
	381	 382	 0.000803	 0.03892	 0.0	 600.0	 600.0	 600.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	381	 382	 0.000845	 0.03982	 0.0	 598.0	 598.0	 598.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	381	 5927	 0.000374	 -0.009003	 0.0	 600.0	 600.0	 600.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	382	 5927	 0.000471	 0.048892	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	423	 424	 0.003062	 0.117136	 0.0	 264	 264	 264	 0.978474	 0.0	 1	 -30.0	 30.0;
	423	 424	 0.003615	 0.114568	 0.0	 270	 270	 270	 0.978474	 0.0	 1	 -30.0	 30.0;
	425	 426	 0.003911	 0.111012	 0.0	 278	 278	 278	 0.953289	 0.0	 1	 -30.0	 30.0;
	425	 426	 0.003911	 0.111012	 0.0	 278	 278	 278	 0.987167	 0.0	 1	 -30.0	 30.0;
	425	 426	 0.003911	 0.111012	 0.0	 278	 278	 278	 0.986189	 0.0	 1	 -30.0	 30.0;
	446	 447	 0.00318	 0.117728	 0.0	 272	 272	 272	 1.075269	 0.0	 1	 -30.0	 30.0;
	444	 447	 0.003062	 0.115753	 0.0	 277	 277	 277	 1.060445	 0.0	 1	 -30.0	 30.0;
	445	 447	 0.002983	 0.118716	 0.0	 270	 270	 270	 1.047121	 0.0	 1	 -30.0	 30.0;
	449	 450	 0.004365	 0.168296	 0.0	 185	 185	 185	 0.956938	 0.0	 1	 -30.0	 30.0;
	449	 450	 0.004464	 0.169284	 0.0	 184	 184	 184	 0.94697	 0.0	 1	 -30.0	 30.0;
	450	 451	 0.000893	 0.043767	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	450	 451	 0.000693	 0.048615	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	453	 454	 0.001936	 0.116148	 0.0	 263	 263	 263	 0.97466	 0.0	 1	 -30.0	 30.0;
	453	 454	 0.001936	 0.117728	 0.0	 259	 259	 259	 0.97466	 0.0	 1	 -30.0	 30.0;
	458	 459	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.910747	 0.0	 1	 -30.0	 30.0;
	459	 5873	 0.000249	 -0.004501	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	459	 5902	 0.000152	 -0.00644	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	460	 5873	 6.9e-05	 0.029294	 0.0	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	460	 5902	 0.00018	 0.03151	 0.0	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	465	 466	 0.011111	 0.384074	 0.0	 93	 93	 93	 1.103753	 0.0	 1	 -30.0	 30.0;
	479	 480	 0.013354	 0.299824	 0.0	 99	 99	 99	 0.993049	 0.0	 1	 -30.0	 30.0;
	481	 482	 0.003951	 0.124444	 0.0	 247	 247	 247	 1.001002	 0.0	 1	 -30.0	 30.0;
	481	 482	 0.003753	 0.124642	 0.0	 247	 247	 247	 1.0142	 0.0	 1	 -30.0	 30.0;
	481	 482	 0.002568	 0.164346	 0.0	 187	 187	 187	 0.991081	 0.0	 1	 -30.0	 30.0;
	505	 506	 0.00397	 0.120296	 0.0	 266	 266	 266	 0.985226	 0.0	 1	 -30.0	 30.0;
	505	 506	 0.0032	 0.117333	 0.0	 273	 273	 273	 0.973708	 0.0	 1	 -30.0	 30.0;
	520	 522	 0.003951	 0.118519	 0.0	 260	 260	 260	 0.989123	 0.0	 1	 -30.0	 30.0;
	521	 522	 0.003358	 0.118519	 0.0	 260	 260	 260	 0.976559	 0.0	 1	 -30.0	 30.0;
	522	 523	 0.000319	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	522	 523	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	525	 526	 0.001679	 0.122272	 0.0	 250	 250	 250	 0.964324	 0.0	 1	 -30.0	 30.0;
	525	 526	 0.00316	 0.117333	 0.0	 260	 260	 260	 0.975606	 0.0	 1	 -30.0	 30.0;
	525	 526	 0.001679	 0.122272	 0.0	 250	 250	 250	 0.975606	 0.0	 1	 -30.0	 30.0;
	533	 534	 0.003042	 0.116148	 0.0	 263	 263	 263	 0.985226	 0.0	 1	 -30.0	 30.0;
	533	 534	 0.00316	 0.11437	 0.0	 267	 267	 267	 0.983282	 0.0	 1	 -30.0	 30.0;
	533	 534	 0.003101	 0.118321	 0.0	 258	 258	 258	 0.985226	 0.0	 1	 -30.0	 30.0;
	542	 543	 0.003516	 0.122469	 0.0	 252	 252	 252	 0.962466	 0.0	 1	 -30.0	 30.0;
	549	 550	 0.012963	 0.267901	 0.0	 114	 114	 114	 1.002005	 0.0	 1	 -30.0	 30.0;
	562	 563	 0.004899	 0.162173	 0.0	 188	 188	 188	 0.968054	 0.0	 1	 -30.0	 30.0;
	580	 578	 2e-05	 0.004741	 0.004	 935.0	 935.0	 935.0	 1.0	 4.66	 1	 -30.0	 30.0;
	580	 581	 0.000319	 0.024307	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	580	 581	 0.000319	 0.024307	 0.0	 1188.0	 1188.0	 1188.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	593	 594	 0.000886	 0.043837	 0.0	 632.0	 632.0	 632.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	601	 602	 0.003081	 0.125432	 0.0	 246	 246	 246	 0.974664	 0.0	 1	 -30.0	 30.0;
	601	 602	 0.003121	 0.125037	 0.0	 247	 247	 247	 0.974664	 0.0	 1	 -30.0	 30.0;
	606	 607	 0.004346	 0.164938	 0.0	 185	 185	 185	 0.968054	 0.0	 1	 -30.0	 30.0;
	606	 607	 0.004543	 0.162568	 0.0	 188	 188	 188	 0.968054	 0.0	 1	 -30.0	 30.0;
	609	 610	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	615	 5903	 0.000519	 -0.007825	 0.0	 606.0	 606.0	 606.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	616	 5903	 0.000277	 0.047507	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	626	 627	 0.003733	 0.175822	 0.0	 173	 173	 173	 0.967114	 0.0	 1	 -30.0	 30.0;
	652	 653	 0.00162	 0.122272	 0.0	 253	 253	 253	 1.0	 0.0	 1	 -30.0	 30.0;
	652	 653	 0.001798	 0.119506	 0.0	 258	 258	 258	 1.0	 0.0	 1	 -30.0	 30.0;
	667	 668	 0.004346	 0.169877	 0.0	 184	 184	 184	 1.012146	 0.0	 1	 -30.0	 30.0;
	676	 677	 0.001393	 0.097699	 0.0	 313	 313	 313	 1.009082	 0.0	 1	 -30.0	 30.0;
	694	 695	 0.00316	 0.112	 0.0	 281	 281	 281	 0.992064	 0.0	 1	 -30.0	 30.0;
	694	 695	 0.003931	 0.115951	 0.0	 272	 272	 272	 0.990103	 0.0	 1	 -30.0	 30.0;
	696	 699	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	697	 699	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	698	 700	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	701	 703	 0.003022	 0.115951	 0.0	 264	 264	 264	 0.984254	 0.0	 1	 -30.0	 30.0;
	701	 703	 0.003536	 0.121877	 0.0	 251	 251	 251	 0.984254	 0.0	 1	 -30.0	 30.0;
	708	 711	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	707	 711	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	706	 711	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	710	 711	 0.0032	 0.113185	 0.0	 270	 270	 270	 0.970872	 0.0	 1	 -30.0	 30.0;
	709	 711	 0.0032	 0.113185	 0.0	 270	 270	 270	 0.957856	 0.0	 1	 -30.0	 30.0;
	709	 711	 0.003062	 0.116148	 0.0	 263	 263	 263	 0.962466	 0.0	 1	 -30.0	 30.0;
	724	 726	 0.003062	 0.116741	 0.0	 268	 268	 268	 1.0	 0.0	 1	 -30.0	 30.0;
	725	 726	 0.00318	 0.115753	 0.0	 270	 270	 270	 1.002005	 0.0	 1	 -30.0	 30.0;
	724	 726	 0.003062	 0.117728	 0.0	 266	 266	 266	 1.0	 0.0	 1	 -30.0	 30.0;
	741	 742	 0.003358	 0.122469	 0.0	 252	 252	 252	 0.96432	 0.0	 1	 -30.0	 30.0;
	741	 742	 0.003358	 0.122469	 0.0	 252	 252	 252	 0.96246	 0.0	 1	 -30.0	 30.0;
	753	 5874	 0.000249	 -0.004501	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	753	 5904	 0.000152	 -0.00644	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	754	 5874	 6.9e-05	 0.029294	 0.0	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	754	 5904	 0.00018	 0.03151	 0.0	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	761	 762	 0.068027	 0.942303	 0.0	 37	 37	 37	 0.550361	 0.0	 1	 -30.0	 30.0;
	767	 768	 0.003733	 0.120296	 0.0	 254	 254	 254	 0.996016	 0.0	 1	 -30.0	 30.0;
	767	 768	 0.003081	 0.116938	 0.0	 261	 261	 261	 0.984254	 0.0	 1	 -30.0	 30.0;
	767	 768	 0.003615	 0.123654	 0.0	 247	 247	 247	 0.984254	 0.0	 1	 -30.0	 30.0;
	769	 772	 0.012346	 0.453263	 0.0	 77	 77	 77	 1.001	 0.0	 1	 -30.0	 30.0;
	770	 772	 0.012346	 0.456286	 0.0	 76	 76	 76	 1.001	 0.0	 1	 -30.0	 30.0;
	771	 772	 0.012598	 0.456034	 0.0	 76	 76	 76	 1.001	 0.0	 1	 -30.0	 30.0;
	775	 776	 0.003635	 0.119704	 0.0	 258	 258	 258	 0.97561	 0.0	 1	 -30.0	 30.0;
	786	 787	 0.03225	 0.602419	 0.0	 58	 58	 58	 1.001	 0.0	 1	 -30.0	 30.0;
	785	 788	 0.03225	 0.602419	 0.0	 58	 58	 58	 1.001	 0.0	 1	 -30.0	 30.0;
	787	 789	 0.001975	 0.124444	 0.0	 247	 247	 247	 0.989123	 0.0	 1	 -30.0	 30.0;
	788	 789	 0.00316	 0.125037	 0.001	 246	 246	 246	 0.989123	 0.0	 1	 -30.0	 30.0;
	798	 799	 0.002832	 0.155817	 0.0	 203	 203	 203	 0.962465	 0.0	 1	 -30.0	 30.0;
	802	 804	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	801	 804	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	800	 803	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	826	 827	 0.000312	 0.024979	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	848	 849	 0.003062	 0.117136	 0.0	 264	 264	 264	 0.98912	 0.0	 1	 -30.0	 30.0;
	848	 849	 0.003615	 0.114568	 0.0	 270	 270	 270	 0.98912	 0.0	 1	 -30.0	 30.0;
	848	 849	 0.004563	 0.161975	 0.0	 191	 191	 191	 0.98912	 0.0	 1	 -30.0	 30.0;
	849	 850	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	849	 850	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	851	 852	 0.003378	 0.122864	 0.0	 255	 255	 255	 0.987167	 0.0	 1	 -30.0	 30.0;
	851	 852	 0.003338	 0.122667	 0.0	 255	 255	 255	 1.0	 0.0	 1	 -30.0	 30.0;
	852	 853	 6.9e-05	 0.056094	 0.0	 566	 566	 566	 1.0	 0.0	 1	 -30.0	 30.0;
	879	 881	 0.003121	 0.12484	 0.0	 246	 246	 246	 0.96432	 0.0	 1	 -30.0	 30.0;
	880	 881	 0.003081	 0.125412	 0.0	 245	 245	 245	 0.96432	 0.0	 1	 -30.0	 30.0;
	879	 881	 0.003575	 0.126222	 0.0	 244	 244	 244	 0.942507	 0.0	 1	 -30.0	 30.0;
	889	 890	 0.006133	 0.237422	 0.0	 145	 145	 145	 0.938967	 0.0	 1	 -30.0	 30.0;
	914	 5905	 0.003366	 0.141343	 0.0	 245	 245	 245	 1.0	 0.0	 1	 -30.0	 30.0;
	916	 5875	 0.000499	 -0.008379	 0.0	 606.0	 606.0	 606.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	915	 5905	 0.000325	 -0.008726	 0.0	 557.0	 557.0	 557.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	917	 5875	 0.000298	 0.048407	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 5905	 0.000381	 0.047715	 0.0	 557.0	 557.0	 557.0	 0.0	 0.0	 1	 -30.0	 30.0;
	924	 925	 0.001814	 0.099308	 0.0	 320	 320	 320	 0.966188	 0.0	 1	 -30.0	 30.0;
	924	 925	 0.001814	 0.099308	 0.0	 320	 320	 320	 0.973709	 0.0	 1	 -30.0	 30.0;
	934	 5928	 0.001801	 0.088435	 0.0	 391	 391	 391	 0.985222	 0.0	 1	 -30.0	 30.0;
	933	 5942	 0.001807	 0.093629	 0.0	 369	 369	 369	 0.985222	 0.0	 1	 -30.0	 30.0;
	932	 5952	 0.001821	 0.092936	 0.0	 372	 372	 372	 0.985222	 0.0	 1	 -30.0	 30.0;
	936	 5876	 0.000166	 -0.005062	 0.0	 1168.0	 1168.0	 1168.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	937	 5928	 0.000166	 -0.010873	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	937	 5942	 0.000152	 -0.007756	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	936	 5952	 0.000118	 -0.007618	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	938	 5876	 0.000201	 0.026437	 0.0	 1168.0	 1168.0	 1168.0	 0.0	 0.0	 1	 -30.0	 30.0;
	939	 5928	 0.000166	 0.038296	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	938	 5942	 0.000187	 0.03518	 0.0	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	939	 5952	 0.00018	 0.034695	 0.0	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	941	 942	 0.00397	 0.11121	 0.0	 281	 281	 281	 1.012146	 0.0	 1	 -30.0	 30.0;
	941	 942	 0.003773	 0.123457	 0.0	 253	 253	 253	 1.02459	 0.0	 1	 -30.0	 30.0;
	941	 942	 0.003279	 0.118914	 0.0	 263	 263	 263	 1.012146	 0.0	 1	 -30.0	 30.0;
	952	 953	 0.003556	 0.111605	 0.0	 274	 274	 274	 0.974664	 0.0	 1	 -30.0	 30.0;
	952	 953	 0.003378	 0.121481	 0.0	 251	 251	 251	 0.977522	 0.0	 1	 -30.0	 30.0;
	957	 958	 0.001801	 0.09903	 0.0	 320	 320	 320	 0.981355	 0.0	 1	 -30.0	 30.0;
	957	 958	 0.001801	 0.099723	 0.0	 318	 318	 318	 0.991081	 0.0	 1	 -30.0	 30.0;
	964	 965	 0.001778	 0.091062	 0.0	 337	 337	 337	 0.982323	 0.0	 1	 -30.0	 30.0;
	964	 965	 0.001738	 0.092444	 0.0	 332	 332	 332	 0.982323	 0.0	 1	 -30.0	 30.0;
	964	 965	 0.001758	 0.092049	 0.0	 333	 333	 333	 0.982323	 0.0	 1	 -30.0	 30.0;
	965	 967	 0.000325	 0.026801	 0.0	 1178	 1178	 1178	 1.0	 0.0	 1	 -30.0	 30.0;
	965	 966	 0.000319	 0.026593	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	969	 970	 0.007664	 0.250785	 0.0	 137	 137	 137	 1.0	 0.0	 1	 -30.0	 30.0;
	969	 970	 0.007664	 0.250785	 0.0	 137	 137	 137	 1.0	 0.0	 1	 -30.0	 30.0;
	969	 970	 0.007664	 0.250785	 0.0	 137	 137	 137	 1.0	 0.0	 1	 -30.0	 30.0;
	972	 973	 0.001936	 0.117926	 0.0	 262	 262	 262	 0.998004	 0.0	 1	 -30.0	 30.0;
	972	 973	 0.001995	 0.118716	 0.0	 260	 260	 260	 0.998004	 0.0	 1	 -30.0	 30.0;
	978	 979	 0.001849	 0.101524	 0.0	 310	 310	 310	 0.956942	 0.0	 1	 -30.0	 30.0;
	978	 979	 0.001794	 0.100831	 0.0	 313	 313	 313	 0.966188	 0.0	 1	 -30.0	 30.0;
	980	 981	 0.001837	 0.140247	 0.0	 220	 220	 220	 0.974661	 0.0	 1	 -30.0	 30.0;
	992	 994	 0.003378	 0.105481	 0.0	 291	 291	 291	 0.94697	 0.0	 1	 -30.0	 30.0;
	992	 994	 0.003338	 0.113185	 0.0	 272	 272	 272	 0.952382	 0.0	 1	 -30.0	 30.0;
	1000	 1001	 0.001778	 0.119309	 0.0	 258	 258	 258	 0.95329	 0.0	 1	 -30.0	 30.0;
	999	 5877	 0.004224	 0.148199	 0.0	 233	 233	 233	 1.0	 0.0	 1	 -30.0	 30.0;
	1000	 1002	 0.001801	 0.101108	 0.0	 313	 313	 313	 0.981355	 0.0	 1	 -30.0	 30.0;
	1000	 1002	 0.001399	 0.101177	 0.0	 313	 313	 313	 0.971818	 0.0	 1	 -30.0	 30.0;
	1001	 5877	 0.000388	 -0.009003	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	1001	 5906	 0.00063	 -0.005194	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	1002	 5877	 0.000395	 0.049169	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1002	 5906	 3.5e-05	 0.048476	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1015	 1016	 0.003556	 0.114568	 0.0	 268	 268	 268	 0.976559	 0.0	 1	 -30.0	 30.0;
	1015	 1016	 0.003951	 0.124444	 0.0	 247	 247	 247	 0.976559	 0.0	 1	 -30.0	 30.0;
	1030	 1032	 0.003101	 0.124049	 0.0	 256	 256	 256	 1.023541	 0.0	 1	 -30.0	 30.0;
	1037	 1038	 0.001699	 0.122864	 0.0	 250	 250	 250	 0.953285	 0.0	 1	 -30.0	 30.0;
	1037	 1038	 0.001699	 0.122469	 0.0	 251	 251	 251	 0.974661	 0.0	 1	 -30.0	 30.0;
	1038	 1039	 0.000325	 0.027147	 0.0	 1168	 1168	 1168	 0.999001	 0.0	 1	 -30.0	 30.0;
	1038	 1039	 0.000319	 0.027216	 0.0	 1165	 1165	 1165	 0.999001	 0.0	 1	 -30.0	 30.0;
	1038	 5929	 0.000229	 -0.008102	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1041	 5929	 8.3e-05	 0.035734	 0.0	 959	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	1045	 1046	 0.00125	 0.11844	 0.0	 258	 258	 258	 0.975614	 0.0	 1	 -30.0	 30.0;
	1045	 1046	 0.001294	 0.118222	 0.0	 258	 258	 258	 0.980389	 0.0	 1	 -30.0	 30.0;
	1044	 1046	 0.003911	 0.110815	 0.0	 275	 275	 275	 0.97561	 0.0	 1	 -30.0	 30.0;
	1062	 1063	 0.003101	 0.117531	 0.0	 260	 260	 260	 0.973708	 0.0	 1	 -30.0	 30.0;
	1062	 1063	 0.00322	 0.11358	 0.0	 269	 269	 269	 0.974655	 0.0	 1	 -30.0	 30.0;
	1062	 1063	 0.003081	 0.115753	 0.0	 264	 264	 264	 0.992063	 0.0	 1	 -30.0	 30.0;
	1062	 1063	 0.003101	 0.115556	 0.0	 264	 264	 264	 0.983282	 0.0	 1	 -30.0	 30.0;
	1067	 1068	 0.007704	 0.229136	 0.0	 135	 135	 135	 1.001002	 0.0	 1	 -30.0	 30.0;
	1067	 1068	 0.007388	 0.234074	 0.0	 132	 132	 132	 0.989123	 0.0	 1	 -30.0	 30.0;
	1067	 1068	 0.007486	 0.229136	 0.0	 135	 135	 135	 0.976559	 0.0	 1	 -30.0	 30.0;
	1075	 1076	 0.000339	 0.027285	 0.0	 1162	 1162	 1162	 1.0	 0.0	 1	 -30.0	 30.0;
	1075	 1076	 0.000339	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	1075	 5930	 0.000132	 -0.007479	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1076	 5930	 0.000173	 0.034764	 0.0	 985	 985	 985	 0.0	 0.0	 1	 -30.0	 30.0;
	1077	 1078	 0.003773	 0.119506	 0.0	 258	 258	 258	 0.968054	 0.0	 1	 -30.0	 30.0;
	1077	 1078	 0.003516	 0.125037	 0.0	 247	 247	 247	 0.956938	 0.0	 1	 -30.0	 30.0;
	1091	 1092	 0.00316	 0.112988	 0.0	 273	 273	 273	 0.983282	 0.0	 1	 -30.0	 30.0;
	1112	 1113	 0.014568	 0.185185	 0.0	 186	 186	 186	 1.0	 0.0	 1	 -30.0	 30.0;
	1115	 1116	 0.001798	 0.118716	 0.0	 260	 260	 260	 0.98912	 0.0	 1	 -30.0	 30.0;
	1115	 1116	 0.001798	 0.118716	 0.0	 260	 260	 260	 1.048218	 0.0	 1	 -30.0	 30.0;
	1134	 1135	 0.003951	 0.113383	 0.0	 269	 269	 269	 0.973708	 0.0	 1	 -30.0	 30.0;
	1134	 1135	 0.003062	 0.118321	 0.0	 258	 258	 258	 0.973708	 0.0	 1	 -30.0	 30.0;
	1140	 1142	 0.004286	 0.164741	 0.0	 187	 187	 187	 0.956938	 0.0	 1	 -30.0	 30.0;
	1141	 1142	 0.005077	 0.17284	 0.0	 178	 178	 178	 0.94697	 0.0	 1	 -30.0	 30.0;
	1145	 1146	 0.003595	 0.120889	 0.0	 253	 253	 253	 0.97561	 0.0	 1	 -30.0	 30.0;
	1145	 1146	 0.003121	 0.130963	 0.0	 233	 233	 233	 0.97561	 0.0	 1	 -30.0	 30.0;
	1149	 1150	 0.002469	 0.533333	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	1156	 1157	 0.00316	 0.125037	 0.0	 246	 246	 246	 0.989123	 0.0	 1	 -30.0	 30.0;
	1156	 1157	 0.004741	 0.161185	 0.0	 191	 191	 191	 0.978477	 0.0	 1	 -30.0	 30.0;
	1155	 1157	 0.004938	 0.16237	 0.0	 190	 190	 190	 0.978477	 0.0	 1	 -30.0	 30.0;
	1163	 1166	 0.00162	 0.099279	 0.0	 311	 311	 311	 0.992067	 0.0	 1	 -30.0	 30.0;
	1164	 1166	 0.001679	 0.099457	 0.0	 310	 310	 310	 0.992067	 0.0	 1	 -30.0	 30.0;
	1165	 1166	 0.001659	 0.099496	 0.0	 310	 310	 310	 0.997009	 0.0	 1	 -30.0	 30.0;
	1173	 1174	 0.001778	 0.092385	 0.0	 331	 331	 331	 0.985226	 0.0	 1	 -30.0	 30.0;
	1173	 1174	 0.001817	 0.091654	 0.0	 333	 333	 333	 0.982323	 0.0	 1	 -30.0	 30.0;
	1173	 1174	 0.001798	 0.091457	 0.0	 334	 334	 334	 0.982323	 0.0	 1	 -30.0	 30.0;
	1173	 1174	 0.001817	 0.091654	 0.0	 333	 333	 333	 0.994038	 0.0	 1	 -30.0	 30.0;
	1194	 1195	 0.003556	 0.123654	 0.0	 249	 249	 249	 0.965249	 0.0	 1	 -30.0	 30.0;
	1193	 1195	 0.003753	 0.120494	 0.0	 255	 255	 255	 0.965249	 0.0	 1	 -30.0	 30.0;
	1194	 1196	 0.00316	 0.12563	 0.0	 245	 245	 245	 0.965249	 0.0	 1	 -30.0	 30.0;
	1195	 1197	 0.000325	 0.025139	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1196	 1197	 0.000325	 0.025346	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1198	 1199	 0.000332	 0.027078	 0.0	 1165	 1165	 1165	 1.0	 0.0	 1	 -30.0	 30.0;
	1198	 1199	 0.000325	 0.027355	 0.0	 1153	 1153	 1153	 0.999001	 0.0	 1	 -30.0	 30.0;
	1198	 1199	 0.000817	 0.042313	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1198	 1199	 0.000686	 0.043075	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1201	 1202	 0.001896	 0.120296	 0.0	 256	 256	 256	 0.96432	 0.0	 1	 -30.0	 30.0;
	1201	 1202	 0.002153	 0.116543	 0.0	 264	 264	 264	 0.974661	 0.0	 1	 -30.0	 30.0;
	1207	 1208	 0.00324	 0.116543	 0.0	 265	 265	 265	 0.94697	 0.0	 1	 -30.0	 30.0;
	1207	 1208	 0.001679	 0.122667	 0.0	 252	 252	 252	 0.96432	 0.0	 1	 -30.0	 30.0;
	1210	 1211	 0.003417	 0.126222	 0.0	 242	 242	 242	 0.987167	 0.0	 1	 -30.0	 30.0;
	1210	 1211	 0.003812	 0.111605	 0.0	 274	 274	 274	 0.987167	 0.0	 1	 -30.0	 30.0;
	1210	 1211	 0.002035	 0.111605	 0.0	 274	 274	 274	 0.987167	 0.0	 1	 -30.0	 30.0;
	1228	 1229	 0.003575	 0.123062	 0.0	 248	 248	 248	 0.951472	 0.0	 1	 -30.0	 30.0;
	1236	 1235	 0.000494	 0.005222	 0.0	 6597	 6597	 6597	 1.0	 0.0	 1	 -30.0	 30.0;
	1238	 1240	 0.003753	 0.122864	 0.0	 250	 250	 250	 0.965249	 0.0	 1	 -30.0	 30.0;
	1237	 1240	 0.003556	 0.127802	 0.0	 241	 241	 241	 0.95329	 0.0	 1	 -30.0	 30.0;
	1238	 1241	 0.003951	 0.125235	 0.0	 246	 246	 246	 0.965249	 0.0	 1	 -30.0	 30.0;
	1241	 1242	 0.000319	 0.024723	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1240	 1242	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1243	 1244	 0.004523	 0.16	 0.0	 193	 193	 193	 0.94697	 0.0	 1	 -30.0	 30.0;
	1246	 1247	 0.004622	 0.159012	 0.0	 194	 194	 194	 1.0	 0.0	 1	 -30.0	 30.0;
	1246	 1247	 0.004622	 0.16	 0.0	 193	 193	 193	 0.990101	 0.0	 1	 -30.0	 30.0;
	1246	 1247	 0.004286	 0.165333	 0.0	 187	 187	 187	 1.0	 0.0	 1	 -30.0	 30.0;
	1248	 1249	 0.009956	 0.365333	 0.0	 86	 86	 86	 1.020408	 0.0	 1	 -30.0	 30.0;
	1248	 1249	 0.016578	 0.457778	 0.0	 69	 69	 69	 1.037345	 0.0	 1	 -30.0	 30.0;
	1250	 1251	 0.068027	 0.942303	 0.0	 37	 37	 37	 0.550361	 0.0	 1	 -30.0	 30.0;
	1257	 1258	 0.003575	 0.121481	 0.0	 264	 264	 264	 1.009082	 0.0	 1	 -30.0	 30.0;
	1257	 1258	 0.003081	 0.115951	 0.0	 276	 276	 276	 1.009082	 0.0	 1	 -30.0	 30.0;
	1262	 1264	 0.003279	 0.117926	 0.0	 262	 262	 262	 0.98912	 0.0	 1	 -30.0	 30.0;
	1263	 1264	 0.00324	 0.116543	 0.0	 265	 265	 265	 1.0	 0.0	 1	 -30.0	 30.0;
	1262	 1264	 0.003042	 0.116938	 0.0	 264	 264	 264	 0.987167	 0.0	 1	 -30.0	 30.0;
	5953	 1264	 0.000402	 -0.007341	 0.0	 581.0	 581.0	 581.0	 1.049318	 0.0	 1	 -30.0	 30.0;
	1264	 1265	 0.000263	 0.025277	 0.0	 585.0	 585.0	 585.0	 0.959693	 0.0	 1	 -30.0	 30.0;
	1264	 1265	 0.000319	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1265	 5953	 0.000242	 0.03144	 0.0	 581.0	 581.0	 581.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1307	 1309	 0.070799	 1.73847	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	1308	 1309	 0.075586	 1.51172	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	1324	 1325	 0.003437	 0.122469	 0.0	 249	 249	 249	 0.987165	 0.0	 1	 -30.0	 30.0;
	1324	 1325	 0.004286	 0.162765	 0.0	 188	 188	 188	 0.98912	 0.0	 1	 -30.0	 30.0;
	1331	 1332	 0.004642	 0.163556	 0.0	 189	 189	 189	 0.980392	 0.0	 1	 -30.0	 30.0;
	1331	 1332	 0.004642	 0.163556	 0.0	 189	 189	 189	 0.993049	 0.0	 1	 -30.0	 30.0;
	1332	 1333	 0.000332	 0.024654	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1332	 1333	 0.000312	 0.024654	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1334	 1335	 0.012598	 0.307382	 0.0	 96	 96	 96	 0.951479	 0.0	 1	 -30.0	 30.0;
	1342	 1343	 0.002094	 0.115753	 0.0	 267	 267	 267	 0.96432	 0.0	 1	 -30.0	 30.0;
	1344	 1345	 0.003951	 0.124642	 0.0	 247	 247	 247	 0.95329	 0.0	 1	 -30.0	 30.0;
	1344	 1345	 0.001975	 0.108642	 0.0	 283	 283	 283	 0.946073	 0.0	 1	 -30.0	 30.0;
	1348	 1349	 0.006133	 0.237422	 0.0	 145	 145	 145	 0.938967	 0.0	 1	 -30.0	 30.0;
	1356	 1357	 0.001758	 0.090469	 0.0	 338	 338	 338	 0.961535	 0.0	 1	 -30.0	 30.0;
	1356	 1357	 0.001936	 0.092049	 0.0	 332	 332	 332	 0.950567	 0.0	 1	 -30.0	 30.0;
	1356	 1357	 0.001857	 0.092444	 0.0	 330	 330	 330	 0.961535	 0.0	 1	 -30.0	 30.0;
	1358	 1359	 0.004346	 0.169481	 0.0	 182	 182	 182	 1.0	 0.0	 1	 -30.0	 30.0;
	1358	 1359	 0.004247	 0.169086	 0.0	 183	 183	 183	 1.0	 0.0	 1	 -30.0	 30.0;
	1358	 1359	 0.004267	 0.169679	 0.0	 182	 182	 182	 1.0	 0.0	 1	 -30.0	 30.0;
	1378	 1379	 0.003496	 0.111407	 0.0	 288	 288	 288	 0.997009	 0.0	 1	 -30.0	 30.0;
	1384	 1385	 0.001699	 0.122469	 0.0	 251	 251	 251	 0.974661	 0.0	 1	 -30.0	 30.0;
	1384	 1385	 0.001956	 0.117531	 0.0	 262	 262	 262	 0.953285	 0.0	 1	 -30.0	 30.0;
	1384	 1385	 0.003101	 0.125235	 0.0	 245	 245	 245	 0.963389	 0.0	 1	 -30.0	 30.0;
	1405	 1406	 0.003062	 0.125432	 0.0	 245	 245	 245	 0.967121	 0.0	 1	 -30.0	 30.0;
	1407	 1409	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	1408	 1409	 0.002588	 0.115358	 0.0	 265	 265	 265	 0.996016	 0.0	 1	 -30.0	 30.0;
	1408	 1409	 0.003081	 0.115358	 0.0	 265	 265	 265	 0.984254	 0.0	 1	 -30.0	 30.0;
	1432	 1433	 0.003081	 0.117531	 0.0	 263	 263	 263	 0.953289	 0.0	 1	 -30.0	 30.0;
	1432	 1433	 0.003911	 0.111605	 0.0	 277	 277	 277	 0.96432	 0.0	 1	 -30.0	 30.0;
	1439	 1440	 0.001679	 0.122667	 0.0	 252	 252	 252	 0.974661	 0.0	 1	 -30.0	 30.0;
	1439	 1440	 0.001995	 0.118716	 0.0	 260	 260	 260	 0.986189	 0.0	 1	 -30.0	 30.0;
	1443	 1444	 0.003852	 0.12642	 0.0	 242	 242	 242	 0.987165	 0.0	 1	 -30.0	 30.0;
	1442	 1444	 0.003812	 0.12484	 0.0	 245	 245	 245	 0.975606	 0.0	 1	 -30.0	 30.0;
	1454	 1455	 0.003812	 0.146963	 0.0	 210	 210	 210	 0.952382	 0.0	 1	 -30.0	 30.0;
	1457	 1458	 0.068027	 0.942303	 0.0	 37	 37	 37	 0.550361	 0.0	 1	 -30.0	 30.0;
	1460	 1461	 0.003002	 0.115951	 0.0	 265	 265	 265	 0.919114	 0.0	 1	 -30.0	 30.0;
	1460	 1461	 0.003615	 0.123062	 0.0	 250	 250	 250	 0.919114	 0.0	 1	 -30.0	 30.0;
	1461	 5878	 0.000263	 -0.005471	 0.0	 1184.0	 1184.0	 1184.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1462	 5878	 6.2e-05	 0.032895	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	1463	 1464	 0.001358	 0.10963	 0.0	 293	 293	 293	 1.001002	 0.0	 1	 -30.0	 30.0;
	1463	 1465	 0.00324	 0.111605	 0.0	 280	 280	 280	 1.02145	 0.0	 1	 -30.0	 30.0;
	1463	 1465	 0.004148	 0.112	 0.0	 279	 279	 279	 1.012146	 0.0	 1	 -30.0	 30.0;
	1471	 1472	 0.003062	 0.117728	 0.0	 262	 262	 262	 0.999001	 0.0	 1	 -30.0	 30.0;
	1471	 1472	 0.003891	 0.129185	 0.0	 239	 239	 239	 0.999001	 0.0	 1	 -30.0	 30.0;
	1477	 1478	 0.003931	 0.125373	 0.0	 244	 244	 244	 0.98619	 0.0	 1	 -30.0	 30.0;
	1477	 1478	 0.003931	 0.125373	 0.0	 244	 244	 244	 0.98619	 0.0	 1	 -30.0	 30.0;
	1483	 1485	 0.003081	 0.117728	 0.0	 261	 261	 261	 0.950569	 0.0	 1	 -30.0	 30.0;
	1501	 1502	 0.002607	 0.115279	 0.0	 268	 268	 268	 1.090512	 0.0	 1	 -30.0	 30.0;
	1516	 1517	 0.000768	 0.089185	 0.0	 343	 343	 343	 0.971818	 0.0	 1	 -30.0	 30.0;
	1516	 1517	 0.004306	 0.158025	 0.0	 193	 193	 193	 0.968992	 0.0	 1	 -30.0	 30.0;
	1516	 1517	 0.004306	 0.159407	 0.0	 192	 192	 192	 0.968992	 0.0	 1	 -30.0	 30.0;
	1517	 1518	 0.000325	 0.027355	 0.0	 1153	 1153	 1153	 0.999001	 0.0	 1	 -30.0	 30.0;
	1517	 1518	 0.000796	 0.041551	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1517	 1518	 0.000727	 0.048753	 0.0	 607.0	 607.0	 607.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1517	 1518	 0.000325	 0.027562	 0.0	 1145	 1145	 1145	 1.0	 0.0	 1	 -30.0	 30.0;
	1523	 1525	 0.003714	 0.086361	 0.001	 403	 403	 403	 0.883392	 0.0	 1	 -30.0	 30.0;
	1522	 1525	 0.00156	 0.048494	 0.001	 717	 717	 717	 1.0101	 0.0	 1	 -30.0	 30.0;
	1521	 1524	 0.003714	 0.086361	 0.001	 403	 403	 403	 0.883392	 0.0	 1	 -30.0	 30.0;
	1520	 1524	 0.00156	 0.048494	 0.001	 717	 717	 717	 1.0101	 0.0	 1	 -30.0	 30.0;
	1526	 1527	 0.003121	 0.117531	 0.0	 260	 260	 260	 0.952382	 0.0	 1	 -30.0	 30.0;
	1526	 1527	 0.003635	 0.122469	 0.0	 249	 249	 249	 0.952382	 0.0	 1	 -30.0	 30.0;
	1533	 1535	 0.00316	 0.11516	 0.0	 265	 265	 265	 0.974655	 0.0	 1	 -30.0	 30.0;
	1534	 1535	 0.003042	 0.117728	 0.0	 260	 260	 260	 0.973708	 0.0	 1	 -30.0	 30.0;
	1533	 1535	 0.003891	 0.111407	 0.0	 274	 274	 274	 0.973708	 0.0	 1	 -30.0	 30.0;
	1533	 1536	 0.001357	 0.09973	 0.0	 316	 316	 316	 0.966188	 0.0	 1	 -30.0	 30.0;
	1535	 5943	 0.000159	 -0.007133	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1535	 5954	 0.000277	 -0.005609	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1536	 5943	 0.000173	 0.033726	 0.0	 1016	 1016	 1016	 0.0	 0.0	 1	 -30.0	 30.0;
	1536	 5954	 6.2e-05	 0.032964	 0.0	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	1541	 1542	 0.000325	 0.024792	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1543	 1544	 0.001778	 0.101333	 0.0	 305	 305	 305	 0.996016	 0.0	 1	 -30.0	 30.0;
	1543	 1544	 0.001778	 0.101136	 0.0	 305	 305	 305	 0.996016	 0.0	 1	 -30.0	 30.0;
	1564	 1565	 0.00316	 0.108049	 0.0	 286	 286	 286	 1.002004	 0.0	 1	 -30.0	 30.0;
	1564	 1565	 0.003002	 0.118519	 0.0	 260	 260	 260	 1.009082	 0.0	 1	 -30.0	 30.0;
	1564	 1565	 0.00316	 0.109037	 0.0	 283	 283	 283	 1.002004	 0.0	 1	 -30.0	 30.0;
	1585	 1586	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1585	 1586	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1588	 1589	 0.003062	 0.116543	 0.0	 275	 275	 275	 1.02145	 0.0	 1	 -30.0	 30.0;
	1588	 1589	 0.003101	 0.116938	 0.0	 274	 274	 274	 1.009082	 0.0	 1	 -30.0	 30.0;
	1598	 1600	 0.003042	 0.115753	 0.0	 265	 265	 265	 0.950573	 0.0	 1	 -30.0	 30.0;
	1599	 1600	 0.003951	 0.112395	 0.0	 272	 272	 272	 0.929369	 0.0	 1	 -30.0	 30.0;
	1597	 5879	 0.001814	 0.093837	 0.0	 368	 368	 368	 1.0	 0.0	 1	 -30.0	 30.0;
	1600	 5879	 0.000145	 -0.007548	 0.0	 1187.0	 1187.0	 1187.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1600	 5907	 0.000533	 -0.004848	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1601	 5879	 0.000187	 0.03428	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	1601	 5907	 0.000173	 0.053186	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1602	 1603	 0.00241	 0.126222	 0.0	 244	 244	 244	 0.959689	 0.0	 1	 -30.0	 30.0;
	1602	 1603	 0.003852	 0.12563	 0.0	 245	 245	 245	 0.963394	 0.0	 1	 -30.0	 30.0;
	1602	 1604	 0.003793	 0.120889	 0.0	 254	 254	 254	 0.97561	 0.0	 1	 -30.0	 30.0;
	1614	 1615	 0.005378	 0.132356	 0.0	 229	 229	 229	 0.946073	 0.0	 1	 -30.0	 30.0;
	1614	 1615	 0.004356	 0.137467	 0.0	 221	 221	 221	 0.946073	 0.0	 1	 -30.0	 30.0;
	1617	 1618	 0.00316	 0.125037	 0.0	 246	 246	 246	 1.001002	 0.0	 1	 -30.0	 30.0;
	1616	 1618	 0.003951	 0.12563	 0.0	 245	 245	 245	 1.001002	 0.0	 1	 -30.0	 30.0;
	1616	 1618	 0.001778	 0.111012	 0.0	 277	 277	 277	 0.989123	 0.0	 1	 -30.0	 30.0;
	1620	 1621	 0.011482	 0.318519	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	1638	 1639	 0.001778	 0.121481	 0.0	 251	 251	 251	 1.0	 0.0	 1	 -30.0	 30.0;
	1638	 1639	 0.001778	 0.121481	 0.0	 251	 251	 251	 1.0	 0.0	 1	 -30.0	 30.0;
	1638	 1639	 0.001778	 0.121481	 0.0	 251	 251	 251	 1.0	 0.0	 1	 -30.0	 30.0;
	1669	 1670	 0.003358	 0.121481	 0.0	 254	 254	 254	 0.976559	 0.0	 1	 -30.0	 30.0;
	1669	 1670	 0.003694	 0.120494	 0.0	 256	 256	 256	 0.976559	 0.0	 1	 -30.0	 30.0;
	1673	 1674	 0.001857	 0.114963	 0.0	 269	 269	 269	 0.954201	 0.0	 1	 -30.0	 30.0;
	1673	 1674	 0.001857	 0.115358	 0.0	 268	 268	 268	 0.987165	 0.0	 1	 -30.0	 30.0;
	1682	 1683	 0.00316	 0.125827	 0.0	 245	 245	 245	 0.989123	 0.0	 1	 -30.0	 30.0;
	1682	 1683	 0.003951	 0.124247	 0.0	 248	 248	 248	 0.989123	 0.0	 1	 -30.0	 30.0;
	1689	 1690	 0.003931	 0.111605	 0.0	 273	 273	 273	 0.978473	 0.0	 1	 -30.0	 30.0;
	1689	 1690	 0.003931	 0.111605	 0.0	 273	 273	 273	 0.978473	 0.0	 1	 -30.0	 30.0;
	1708	 1711	 0.003279	 0.110222	 0.0	 279	 279	 279	 0.956938	 0.0	 1	 -30.0	 30.0;
	1709	 1713	 0.003338	 0.113975	 0.0	 270	 270	 270	 0.96432	 0.0	 1	 -30.0	 30.0;
	1709	 1710	 0.00318	 0.125432	 0.0	 245	 245	 245	 0.96432	 0.0	 1	 -30.0	 30.0;
	1708	 1712	 0.003002	 0.107062	 0.0	 287	 287	 287	 0.947871	 0.0	 1	 -30.0	 30.0;
	1717	 1718	 0.00399	 0.113383	 0.0	 276	 276	 276	 1.02459	 0.0	 1	 -30.0	 30.0;
	1717	 1718	 0.003872	 0.110617	 0.0	 283	 283	 283	 1.037344	 0.0	 1	 -30.0	 30.0;
	1722	 1723	 0.003556	 0.122864	 0.0	 249	 249	 249	 0.950573	 0.0	 1	 -30.0	 30.0;
	1722	 1723	 0.00316	 0.112593	 0.0	 271	 271	 271	 0.957856	 0.0	 1	 -30.0	 30.0;
	1728	 1729	 0.045352	 0.942555	 0.0	 37	 37	 37	 1.001	 0.0	 1	 -30.0	 30.0;
	1735	 1736	 0.003101	 0.118519	 0.0	 261	 261	 261	 1.011122	 0.0	 1	 -30.0	 30.0;
	1735	 1736	 0.003101	 0.118914	 0.0	 260	 260	 260	 0.999001	 0.0	 1	 -30.0	 30.0;
	1748	 1751	 0.007901	 0.341728	 0.0	 101	 101	 101	 1.0	 0.0	 1	 -30.0	 30.0;
	1747	 1750	 0.007901	 0.341728	 0.0	 101	 101	 101	 1.0	 0.0	 1	 -30.0	 30.0;
	1746	 1749	 0.007901	 0.341728	 0.0	 101	 101	 101	 1.0	 0.0	 1	 -30.0	 30.0;
	1752	 1754	 0.003635	 0.123654	 0.0	 247	 247	 247	 0.974664	 0.0	 1	 -30.0	 30.0;
	1753	 1754	 0.004484	 0.118716	 0.0	 257	 257	 257	 0.97561	 0.0	 1	 -30.0	 30.0;
	1775	 1778	 0.004286	 0.165531	 0.0	 185	 185	 185	 0.978474	 0.0	 1	 -30.0	 30.0;
	1776	 1778	 0.00316	 0.112395	 0.0	 272	 272	 272	 0.992063	 0.0	 1	 -30.0	 30.0;
	1777	 1778	 0.003042	 0.116938	 0.0	 261	 261	 261	 0.997009	 0.0	 1	 -30.0	 30.0;
	1777	 1778	 0.003951	 0.111605	 0.0	 274	 274	 274	 1.009082	 0.0	 1	 -30.0	 30.0;
	1777	 1778	 0.003931	 0.112198	 0.0	 272	 272	 272	 1.009082	 0.0	 1	 -30.0	 30.0;
	1780	 1781	 0.001778	 0.100148	 0.0	 308	 308	 308	 1.006036	 0.0	 1	 -30.0	 30.0;
	1780	 1781	 0.001778	 0.100346	 0.0	 308	 308	 308	 1.006036	 0.0	 1	 -30.0	 30.0;
	1780	 1781	 0.000968	 0.105481	 0.0	 293	 293	 293	 0.994036	 0.0	 1	 -30.0	 30.0;
	1785	 1786	 0.00316	 0.12563	 0.0	 245	 245	 245	 0.989123	 0.0	 1	 -30.0	 30.0;
	1785	 1786	 0.00316	 0.125432	 0.0	 245	 245	 245	 0.989123	 0.0	 1	 -30.0	 30.0;
	1791	 1792	 0.012963	 0.267901	 0.0	 114	 114	 114	 1.020408	 0.0	 1	 -30.0	 30.0;
	1791	 1793	 0.004563	 0.161975	 0.0	 191	 191	 191	 0.978474	 0.0	 1	 -30.0	 30.0;
	1791	 1793	 0.003081	 0.106272	 0.0	 291	 291	 291	 0.968054	 0.0	 1	 -30.0	 30.0;
	1791	 1793	 0.003852	 0.116543	 0.0	 265	 265	 265	 0.98619	 0.0	 1	 -30.0	 30.0;
	1792	 1793	 0.001778	 0.12721	 0.0	 243	 243	 243	 0.996016	 0.0	 1	 -30.0	 30.0;
	1794	 1795	 0.003635	 0.118519	 0.0	 261	 261	 261	 0.974664	 0.0	 1	 -30.0	 30.0;
	1794	 1795	 0.003279	 0.125235	 0.0	 247	 247	 247	 0.963394	 0.0	 1	 -30.0	 30.0;
	1803	 1804	 0.00316	 0.125037	 0.0	 246	 246	 246	 0.989123	 0.0	 1	 -30.0	 30.0;
	1810	 1811	 0.003477	 0.145185	 0.0	 212	 212	 212	 0.984252	 0.0	 1	 -30.0	 30.0;
	1810	 1811	 0.003536	 0.147556	 0.0	 208	 208	 208	 0.96618	 0.0	 1	 -30.0	 30.0;
	1822	 1823	 0.003081	 0.125037	 0.0	 247	 247	 247	 0.974664	 0.0	 1	 -30.0	 30.0;
	1822	 1823	 0.001956	 0.126025	 0.0	 245	 245	 245	 0.963394	 0.0	 1	 -30.0	 30.0;
	1826	 1827	 0.003121	 0.125432	 0.0	 246	 246	 246	 0.96432	 0.0	 1	 -30.0	 30.0;
	1827	 1828	 0.000735	 0.044668	 0.0	 593.0	 593.0	 593.0	 0.959693	 0.0	 1	 -30.0	 30.0;
	1831	 1832	 0.001857	 0.121086	 0.0	 252	 252	 252	 1.0	 0.0	 1	 -30.0	 30.0;
	1831	 1832	 0.001857	 0.121086	 0.0	 252	 252	 252	 1.0	 0.0	 1	 -30.0	 30.0;
	1837	 1838	 0.004543	 0.112395	 0.0	 274	 274	 274	 0.989123	 0.0	 1	 -30.0	 30.0;
	1837	 1838	 0.00316	 0.116938	 0.0	 263	 263	 263	 0.989123	 0.0	 1	 -30.0	 30.0;
	1842	 1843	 0.003654	 0.122074	 0.0	 253	 253	 253	 0.998004	 0.0	 1	 -30.0	 30.0;
	1842	 1843	 0.003496	 0.122074	 0.0	 253	 253	 253	 0.98619	 0.0	 1	 -30.0	 30.0;
	1882	 1883	 0.003536	 0.122864	 0.0	 252	 252	 252	 0.929369	 0.0	 1	 -30.0	 30.0;
	1896	 1900	 0.000395	 0.238025	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	1895	 1899	 0.000395	 0.238025	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	1894	 1898	 0.000395	 0.238025	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	1893	 1897	 0.000395	 0.238025	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	1903	 1904	 0.001778	 0.122864	 0.0	 250	 250	 250	 0.998004	 0.0	 1	 -30.0	 30.0;
	1903	 1904	 0.00158	 0.122272	 0.0	 252	 252	 252	 0.998004	 0.0	 1	 -30.0	 30.0;
	1905	 1906	 0.004543	 0.163556	 0.0	 189	 189	 189	 0.944284	 0.0	 1	 -30.0	 30.0;
	1912	 1913	 0.003595	 0.126222	 0.0	 245	 245	 245	 0.96432	 0.0	 1	 -30.0	 30.0;
	1912	 1913	 0.003615	 0.125432	 0.0	 246	 246	 246	 0.96432	 0.0	 1	 -30.0	 30.0;
	1927	 1928	 0.004267	 0.165136	 0.0	 187	 187	 187	 0.989122	 0.0	 1	 -30.0	 30.0;
	1927	 1928	 0.005926	 0.23763	 0.0	 130	 130	 130	 0.989122	 0.0	 1	 -30.0	 30.0;
	1929	 1930	 0.003026	 0.155471	 0.0	 203	 203	 203	 0.948768	 0.0	 1	 -30.0	 30.0;
	1933	 5908	 0.003435	 0.08608	 0.0	 401	 401	 401	 1.0	 0.0	 1	 -30.0	 30.0;
	1934	 1935	 0.000803	 0.034418	 0.0	 605.0	 605.0	 605.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1934	 5908	 0.000277	 -0.004709	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1935	 5908	 4.8e-05	 0.029571	 0.0	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	1936	 1937	 0.001807	 0.100554	 0.0	 313	 313	 313	 0.9311	 0.0	 1	 -30.0	 30.0;
	1942	 1944	 0.00316	 0.115753	 0.0	 277	 277	 277	 1.049318	 0.0	 1	 -30.0	 30.0;
	1942	 1945	 0.001835	 0.099792	 0.0	 323	 323	 323	 0.982323	 0.0	 1	 -30.0	 30.0;
	1943	 1945	 0.001842	 0.10097	 0.0	 319	 319	 319	 1.029866	 0.0	 1	 -30.0	 30.0;
	1944	 1945	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1961	 1962	 0.000332	 0.024723	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1961	 1962	 0.000305	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1971	 1977	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	1970	 1975	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	1969	 1974	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	1968	 1973	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	1967	 1972	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	1980	 1983	 0.001975	 0.157432	 0.0	 218	 218	 218	 1.0	 0.0	 1	 -30.0	 30.0;
	1989	 1990	 0.01284	 0.265432	 0.0	 114	 114	 114	 0.968053	 0.0	 1	 -30.0	 30.0;
	1989	 1991	 0.002449	 0.118736	 0.0	 257	 257	 257	 0.939847	 0.0	 1	 -30.0	 30.0;
	1990	 1991	 0.003002	 0.116543	 0.0	 263	 263	 263	 1.009082	 0.0	 1	 -30.0	 30.0;
	1990	 1991	 0.003042	 0.116148	 0.0	 264	 264	 264	 1.009082	 0.0	 1	 -30.0	 30.0;
	1996	 1997	 0.001798	 0.122667	 0.0	 252	 252	 252	 0.952382	 0.0	 1	 -30.0	 30.0;
	1996	 1997	 0.001798	 0.119704	 0.0	 258	 258	 258	 0.963394	 0.0	 1	 -30.0	 30.0;
	1996	 1997	 0.002173	 0.119783	 0.0	 258	 258	 258	 0.964324	 0.0	 1	 -30.0	 30.0;
	2011	 2012	 0.003595	 0.119506	 0.0	 258	 258	 258	 0.963394	 0.0	 1	 -30.0	 30.0;
	2011	 2012	 0.004642	 0.160988	 0.0	 192	 192	 192	 0.968054	 0.0	 1	 -30.0	 30.0;
	2039	 2040	 0.003891	 0.124444	 0.0	 248	 248	 248	 0.926784	 0.0	 1	 -30.0	 30.0;
	2039	 2040	 0.003911	 0.11279	 0.0	 274	 274	 274	 0.937207	 0.0	 1	 -30.0	 30.0;
	2048	 2049	 0.003141	 0.110775	 0.0	 279	 279	 279	 0.97656	 0.0	 1	 -30.0	 30.0;
	2047	 2049	 0.00324	 0.116543	 0.0	 265	 265	 265	 0.968054	 0.0	 1	 -30.0	 30.0;
	2055	 2056	 0.000319	 0.02687	 0.0	 1174	 1174	 1174	 1.0	 0.0	 1	 -30.0	 30.0;
	2055	 2056	 0.000339	 0.02687	 0.0	 1174	 1174	 1174	 1.0	 0.0	 1	 -30.0	 30.0;
	2055	 2056	 0.00036	 0.027285	 0.0	 1156	 1156	 1156	 1.0	 0.0	 1	 -30.0	 30.0;
	2072	 2074	 0.002909	 0.158587	 0.0	 200	 200	 200	 1.021451	 0.0	 1	 -30.0	 30.0;
	2072	 2073	 0.002832	 0.157202	 0.0	 202	 202	 202	 1.001002	 0.0	 1	 -30.0	 30.0;
	2076	 2077	 0.003812	 0.121481	 0.0	 254	 254	 254	 0.999001	 0.0	 1	 -30.0	 30.0;
	2076	 2077	 0.004642	 0.163556	 0.0	 189	 189	 189	 1.00705	 0.0	 1	 -30.0	 30.0;
	2085	 2086	 0.003437	 0.128395	 0.0	 238	 238	 238	 0.990104	 0.0	 1	 -30.0	 30.0;
	2085	 2086	 0.003437	 0.128395	 0.0	 238	 238	 238	 0.990104	 0.0	 1	 -30.0	 30.0;
	5880	 2087	 0.000152	 -0.006163	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2087	 2088	 0.000312	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2088	 5880	 0.000159	 0.031163	 0.0	 1099	 1099	 1099	 0.0	 0.0	 1	 -30.0	 30.0;
	1494	 2094	 0.000119	 0.00796	 0.0	 418.0	 418.0	 418.0	 1.0	 -1.94	 1	 -30.0	 30.0;
	2092	 2094	 0.00322	 0.112	 0.0	 286	 286	 286	 1.034126	 0.0	 1	 -30.0	 30.0;
	2092	 2094	 0.003081	 0.116346	 0.0	 275	 275	 275	 1.034126	 0.0	 1	 -30.0	 30.0;
	2095	 2096	 0.003358	 0.122469	 0.0	 252	 252	 252	 0.974664	 0.0	 1	 -30.0	 30.0;
	2095	 2096	 0.003358	 0.122469	 0.0	 252	 252	 252	 0.963394	 0.0	 1	 -30.0	 30.0;
	2103	 2104	 0.00399	 0.110815	 0.0	 275	 275	 275	 0.96432	 0.0	 1	 -30.0	 30.0;
	2103	 2104	 0.00397	 0.110222	 0.0	 277	 277	 277	 0.96432	 0.0	 1	 -30.0	 30.0;
	2103	 2104	 0.003951	 0.111012	 0.0	 275	 275	 275	 0.96432	 0.0	 1	 -30.0	 30.0;
	2111	 2112	 0.001995	 0.125432	 0.0	 246	 246	 246	 0.953289	 0.0	 1	 -30.0	 30.0;
	2111	 2112	 0.001936	 0.117926	 0.0	 262	 262	 262	 0.963394	 0.0	 1	 -30.0	 30.0;
	2111	 2112	 0.003753	 0.123654	 0.0	 250	 250	 250	 0.963394	 0.0	 1	 -30.0	 30.0;
	2124	 2125	 0.003852	 0.126815	 0.0	 244	 244	 244	 0.999001	 0.0	 1	 -30.0	 30.0;
	2124	 2125	 0.003022	 0.116741	 0.0	 265	 265	 265	 0.999001	 0.0	 1	 -30.0	 30.0;
	2128	 2131	 0.003951	 0.124444	 0.0	 247	 247	 247	 0.989123	 0.0	 1	 -30.0	 30.0;
	2127	 2130	 0.003358	 0.118519	 0.0	 260	 260	 260	 0.976559	 0.0	 1	 -30.0	 30.0;
	2127	 2129	 0.00316	 0.112593	 0.0	 273	 273	 273	 0.976559	 0.0	 1	 -30.0	 30.0;
	2132	 2134	 0.002193	 0.126914	 0.0	 248	 248	 248	 0.997009	 0.0	 1	 -30.0	 30.0;
	2133	 2134	 0.005096	 0.143921	 0.0	 221	 221	 221	 1.0	 0.0	 1	 -30.0	 30.0;
	2133	 2134	 0.005531	 0.188247	 0.0	 169	 169	 169	 1.012149	 0.0	 1	 -30.0	 30.0;
	2136	 2137	 0.013354	 0.302343	 0.0	 98	 98	 98	 0.933703	 0.0	 1	 -30.0	 30.0;
	2136	 2137	 0.013354	 0.302343	 0.0	 98	 98	 98	 0.933703	 0.0	 1	 -30.0	 30.0;
	2136	 2138	 0.004938	 0.159012	 0.0	 197	 197	 197	 0.919114	 0.0	 1	 -30.0	 30.0;
	2136	 2138	 0.004938	 0.159012	 0.0	 197	 197	 197	 0.919114	 0.0	 1	 -30.0	 30.0;
	2142	 2143	 0.003279	 0.109827	 0.0	 281	 281	 281	 0.957856	 0.0	 1	 -30.0	 30.0;
	2142	 2143	 0.003121	 0.117728	 0.0	 262	 262	 262	 0.939847	 0.0	 1	 -30.0	 30.0;
	2147	 2148	 0.004741	 0.164148	 0.0	 188	 188	 188	 0.990101	 0.0	 1	 -30.0	 30.0;
	2147	 2148	 0.003358	 0.106667	 0.0	 288	 288	 288	 1.001002	 0.0	 1	 -30.0	 30.0;
	2148	 2149	 0.000713	 0.043283	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	2148	 2149	 0.000769	 0.043837	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	2161	 2162	 0.001877	 0.093037	 0.0	 332	 332	 332	 0.983284	 0.0	 1	 -30.0	 30.0;
	2165	 2166	 0.003259	 0.109235	 0.0	 292.0	 292.0	 292.0	 1.011122	 0.0	 1	 -30.0	 30.0;
	2165	 2166	 0.00322	 0.109235	 0.0	 292.0	 292.0	 292.0	 1.002004	 0.0	 1	 -30.0	 30.0;
	2165	 2166	 0.00316	 0.113778	 0.0	 282	 282	 282	 0.997009	 0.0	 1	 -30.0	 30.0;
	2172	 2175	 0.003832	 0.11437	 0.0	 270	 270	 270	 1.086957	 0.0	 1	 -30.0	 30.0;
	2172	 2174	 0.003832	 0.11437	 0.0	 270	 270	 270	 1.074114	 0.0	 1	 -30.0	 30.0;
	2184	 2185	 0.003635	 0.114963	 0.0	 267	 267	 267	 0.910747	 0.0	 1	 -30.0	 30.0;
	2184	 5931	 0.001343	 -0.004543	 0.0	 446.0	 446.0	 446.0	 0.937207	 0.0	 1	 -30.0	 30.0;
	2184	 5944	 0.001679	 0.012642	 0.0	 446.0	 446.0	 446.0	 0.926784	 0.0	 1	 -30.0	 30.0;
	2185	 5931	 0.001817	 0.123654	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	2185	 5944	 0.001877	 0.098765	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	2196	 2197	 0.000319	 0.027424	 0.0	 1157	 1157	 1157	 1.0	 0.0	 1	 -30.0	 30.0;
	2196	 2197	 0.000319	 0.027355	 0.0	 1160	 1160	 1160	 1.0	 0.0	 1	 -30.0	 30.0;
	2222	 2223	 0.002983	 0.115951	 0.0	 266	 266	 266	 0.945178	 0.0	 1	 -30.0	 30.0;
	2227	 2228	 0.003358	 0.109827	 0.0	 281	 281	 281	 0.985222	 0.0	 1	 -30.0	 30.0;
	2232	 2233	 0.003852	 0.11279	 0.0	 284	 284	 284	 0.997009	 0.0	 1	 -30.0	 30.0;
	2232	 2233	 0.003852	 0.11279	 0.0	 284	 284	 284	 1.004017	 0.0	 1	 -30.0	 30.0;
	2235	 2236	 0.005679	 0.116173	 0.0	 276	 276	 276	 1.001002	 0.0	 1	 -30.0	 30.0;
	2240	 2241	 0.002074	 0.161778	 0.0	 193	 193	 193	 0.7446	 0.0	 1	 -30.0	 30.0;
	2240	 2241	 0.002074	 0.161778	 0.0	 193	 193	 193	 0.875657	 0.0	 1	 -30.0	 30.0;
	2246	 5881	 0.002864	 0.068543	 0.0	 504	 504	 504	 1.0	 0.0	 1	 -30.0	 30.0;
	2247	 5881	 0.0	 0.001185	 0.0	 29046	 29046	 29046	 0.968054	 0.0	 1	 -30.0	 30.0;
	2248	 5881	 0.006499	 0.143802	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	2253	 2254	 0.001896	 0.119704	 0.0	 255	 255	 255	 0.987167	 0.0	 1	 -30.0	 30.0;
	2253	 2254	 0.001896	 0.119704	 0.0	 255	 255	 255	 0.987167	 0.0	 1	 -30.0	 30.0;
	2262	 2263	 0.009733	 0.388889	 0.0	 81	 81	 81	 1.023541	 0.0	 1	 -30.0	 30.0;
	2262	 2264	 0.003911	 0.147161	 0.0	 210	 210	 210	 0.96432	 0.0	 1	 -30.0	 30.0;
	2262	 2264	 0.003951	 0.118519	 0.0	 261	 261	 261	 0.953289	 0.0	 1	 -30.0	 30.0;
	2263	 2264	 0.005472	 0.190025	 0.0	 166	 166	 166	 1.0	 0.0	 1	 -30.0	 30.0;
	2267	 2269	 0.003338	 0.12484	 0.0	 264	 264	 264	 1.03627	 0.0	 1	 -30.0	 30.0;
	2271	 2272	 0.00316	 0.113778	 0.0	 282	 282	 282	 1.020408	 0.0	 1	 -30.0	 30.0;
	2271	 2272	 0.00316	 0.113778	 0.0	 282	 282	 282	 1.009082	 0.0	 1	 -30.0	 30.0;
	2271	 2272	 0.003635	 0.120494	 0.0	 266	 266	 266	 1.009082	 0.0	 1	 -30.0	 30.0;
	2288	 2289	 0.00295	 0.163504	 0.0	 194	 194	 194	 0.984249	 0.0	 1	 -30.0	 30.0;
	2291	 2292	 0.003951	 0.112988	 0.0	 272	 272	 272	 1.001002	 0.0	 1	 -30.0	 30.0;
	2291	 2292	 0.003951	 0.124247	 0.0	 248	 248	 248	 0.989123	 0.0	 1	 -30.0	 30.0;
	2297	 2298	 0.003121	 0.125037	 0.0	 246	 246	 246	 1.0142	 0.0	 1	 -30.0	 30.0;
	2297	 2298	 0.003556	 0.119309	 0.0	 258	 258	 258	 1.0142	 0.0	 1	 -30.0	 30.0;
	2307	 2308	 0.003338	 0.121679	 0.0	 254	 254	 254	 0.952382	 0.0	 1	 -30.0	 30.0;
	2307	 2308	 0.003279	 0.117531	 0.0	 263	 263	 263	 0.952382	 0.0	 1	 -30.0	 30.0;
	2313	 2314	 0.003635	 0.126222	 0.0	 245	 245	 245	 0.968054	 0.0	 1	 -30.0	 30.0;
	2313	 2314	 0.003635	 0.126222	 0.0	 245	 245	 245	 0.968054	 0.0	 1	 -30.0	 30.0;
	2313	 2314	 0.003101	 0.12484	 0.0	 247	 247	 247	 0.956938	 0.0	 1	 -30.0	 30.0;
	2326	 2327	 0.003496	 0.118123	 0.0	 261	 261	 261	 0.97561	 0.0	 1	 -30.0	 30.0;
	2333	 2335	 0.00397	 0.124049	 0.0	 246	 246	 246	 1.001002	 0.0	 1	 -30.0	 30.0;
	2334	 2335	 0.003062	 0.117728	 0.0	 259	 259	 259	 0.999001	 0.0	 1	 -30.0	 30.0;
	2334	 2335	 0.003101	 0.125432	 0.0	 243	 243	 243	 0.999001	 0.0	 1	 -30.0	 30.0;
	2335	 2336	 0.000319	 0.024307	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2343	 2345	 0.004543	 0.120691	 0.0	 255	 255	 255	 0.989123	 0.0	 1	 -30.0	 30.0;
	2343	 2345	 0.004346	 0.120691	 0.0	 255	 255	 255	 0.989123	 0.0	 1	 -30.0	 30.0;
	2344	 2345	 0.004741	 0.157432	 0.0	 196	 196	 196	 0.978477	 0.0	 1	 -30.0	 30.0;
	2349	 2351	 0.000693	 0.048753	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2349	 2350	 0.000796	 0.042452	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2368	 2374	 0.003951	 0.185679	 0.0	 185	 185	 185	 1.0	 0.0	 1	 -30.0	 30.0;
	2367	 2372	 0.003951	 0.185679	 0.0	 185	 185	 185	 1.0	 0.0	 1	 -30.0	 30.0;
	2366	 2371	 0.003951	 0.185679	 0.0	 185	 185	 185	 1.0	 0.0	 1	 -30.0	 30.0;
	2365	 2370	 0.003951	 0.185679	 0.0	 185	 185	 185	 1.0	 0.0	 1	 -30.0	 30.0;
	2364	 2369	 0.003951	 0.185679	 0.0	 185	 185	 185	 1.0	 0.0	 1	 -30.0	 30.0;
	2375	 2376	 0.003556	 0.111407	 0.0	 277	 277	 277	 0.952382	 0.0	 1	 -30.0	 30.0;
	2375	 2376	 0.003496	 0.122469	 0.0	 252	 252	 252	 0.94697	 0.0	 1	 -30.0	 30.0;
	2424	 2426	 0.001144	 0.13043	 0.0	 234	 234	 234	 0.973708	 0.0	 1	 -30.0	 30.0;
	2424	 2425	 0.001237	 0.119565	 0.0	 255	 255	 255	 0.973708	 0.0	 1	 -30.0	 30.0;
	2428	 2429	 0.004286	 0.168889	 0.0	 183	 183	 183	 0.968054	 0.0	 1	 -30.0	 30.0;
	2432	 2433	 0.00324	 0.116543	 0.0	 265	 265	 265	 0.968054	 0.0	 1	 -30.0	 30.0;
	2432	 2433	 0.003338	 0.111605	 0.0	 277	 277	 277	 0.974664	 0.0	 1	 -30.0	 30.0;
	2431	 2433	 0.003872	 0.11121	 0.0	 278	 278	 278	 0.987167	 0.0	 1	 -30.0	 30.0;
	2431	 2433	 0.003062	 0.116741	 0.0	 265	 265	 265	 0.97561	 0.0	 1	 -30.0	 30.0;
	2447	 2449	 0.001473	 0.177164	 0.0	 178	 178	 178	 0.902528	 0.0	 1	 -30.0	 30.0;
	2447	 2450	 0.003496	 0.10884	 0.0	 284	 284	 284	 0.974664	 0.0	 1	 -30.0	 30.0;
	2447	 2450	 0.003279	 0.111802	 0.0	 276	 276	 276	 0.974664	 0.0	 1	 -30.0	 30.0;
	2449	 2450	 0.0032	 0.124444	 0.0	 253	 253	 253	 1.020408	 0.0	 1	 -30.0	 30.0;
	2459	 2460	 0.00187	 0.104571	 0.0	 301	 301	 301	 0.966188	 0.0	 1	 -30.0	 30.0;
	2459	 2460	 0.001842	 0.099931	 0.0	 315	 315	 315	 0.966188	 0.0	 1	 -30.0	 30.0;
	2468	 2469	 0.000332	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2468	 5909	 0.000145	 -0.006371	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2467	 5932	 0.000132	 -0.006302	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2469	 5909	 0.000187	 0.031163	 0.0	 1099	 1099	 1099	 0.0	 0.0	 1	 -30.0	 30.0;
	2469	 5932	 0.000187	 0.03144	 0.0	 1089	 1089	 1089	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 2471	 0.003022	 0.115951	 0.0	 266	 266	 266	 0.997009	 0.0	 1	 -30.0	 30.0;
	2470	 2471	 0.003832	 0.111802	 0.0	 276	 276	 276	 0.997009	 0.0	 1	 -30.0	 30.0;
	2470	 2472	 0.001752	 0.102285	 0.0	 310	 310	 310	 0.956942	 0.0	 1	 -30.0	 30.0;
	2470	 2472	 0.001759	 0.101177	 0.0	 313	 313	 313	 0.966188	 0.0	 1	 -30.0	 30.0;
	2471	 2472	 0.000845	 0.042729	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2484	 2486	 0.001778	 0.091062	 0.0	 335	 335	 335	 0.961535	 0.0	 1	 -30.0	 30.0;
	2485	 2486	 0.001758	 0.092247	 0.0	 331	 331	 331	 0.981358	 0.0	 1	 -30.0	 30.0;
	2484	 2486	 0.001798	 0.092049	 0.0	 332	 332	 332	 0.960618	 0.0	 1	 -30.0	 30.0;
	2491	 2492	 0.003951	 0.124247	 0.0	 246	 246	 246	 0.98619	 0.0	 1	 -30.0	 30.0;
	2491	 2492	 0.003062	 0.124444	 0.0	 245	 245	 245	 0.987167	 0.0	 1	 -30.0	 30.0;
	2504	 2505	 0.001778	 0.118519	 0.0	 261	 261	 261	 0.968054	 0.0	 1	 -30.0	 30.0;
	2504	 2505	 0.003931	 0.12484	 0.0	 247	 247	 247	 0.968054	 0.0	 1	 -30.0	 30.0;
	2511	 2512	 0.001936	 0.115358	 0.0	 268	 268	 268	 0.98619	 0.0	 1	 -30.0	 30.0;
	2516	 2517	 0.022222	 0.37037	 0.0	 82	 82	 82	 0.970879	 0.0	 1	 -30.0	 30.0;
	2516	 2517	 0.022222	 0.37037	 0.0	 82	 82	 82	 0.973709	 0.0	 1	 -30.0	 30.0;
	2518	 2519	 0.001798	 0.122667	 0.0	 252	 252	 252	 0.974664	 0.0	 1	 -30.0	 30.0;
	2518	 2519	 0.001798	 0.122667	 0.0	 252	 252	 252	 0.999001	 0.0	 1	 -30.0	 30.0;
	2519	 2520	 0.000332	 0.024238	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	2519	 2520	 0.000332	 0.024238	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	2525	 2526	 0.00318	 0.114765	 0.0	 301	 301	 301	 1.082251	 0.0	 1	 -30.0	 30.0;
	2541	 2542	 0.001975	 0.117531	 0.0	 262	 262	 262	 1.053742	 0.0	 1	 -30.0	 30.0;
	2550	 2551	 0.003867	 0.109333	 0.0	 277	 277	 277	 1.028807	 0.0	 1	 -30.0	 30.0;
	2550	 2552	 0.001975	 0.126025	 0.0	 242	 242	 242	 0.963394	 0.0	 1	 -30.0	 30.0;
	2550	 2552	 0.003852	 0.112	 0.0	 273	 273	 273	 0.97561	 0.0	 1	 -30.0	 30.0;
	2551	 2552	 0.004543	 0.137284	 0.0	 224	 224	 224	 0.952381	 0.0	 1	 -30.0	 30.0;
	2561	 2562	 0.000636	 0.120237	 0.0	 257	 257	 257	 0.926784	 0.0	 1	 -30.0	 30.0;
	2561	 2562	 0.000636	 0.120237	 0.0	 257	 257	 257	 0.926784	 0.0	 1	 -30.0	 30.0;
	2568	 2569	 0.003714	 0.124642	 0.0	 248	 248	 248	 0.987167	 0.0	 1	 -30.0	 30.0;
	2568	 2569	 0.003081	 0.116346	 0.0	 265	 265	 265	 0.987167	 0.0	 1	 -30.0	 30.0;
	2568	 2569	 0.003121	 0.118519	 0.0	 261	 261	 261	 0.953289	 0.0	 1	 -30.0	 30.0;
	2569	 2570	 0.00081	 0.039266	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2569	 2570	 0.00081	 0.039612	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2572	 2573	 0.001778	 0.100148	 0.0	 308	 308	 308	 0.983284	 0.0	 1	 -30.0	 30.0;
	2572	 2573	 0.001778	 0.100148	 0.0	 308	 308	 308	 0.983284	 0.0	 1	 -30.0	 30.0;
	2579	 2580	 0.007055	 0.203578	 0.0	 145	 145	 145	 0.981352	 0.0	 1	 -30.0	 30.0;
	2579	 2582	 0.00322	 0.165926	 0.0	 189	 189	 189	 0.901711	 0.0	 1	 -30.0	 30.0;
	2580	 2582	 0.002686	 0.169877	 0.0	 181	 181	 181	 0.978477	 0.0	 1	 -30.0	 30.0;
	2580	 2582	 0.002686	 0.169877	 0.0	 181	 181	 181	 0.967124	 0.0	 1	 -30.0	 30.0;
	2581	 2582	 0.003338	 0.158025	 0.0	 202	 202	 202	 0.98912	 0.0	 1	 -30.0	 30.0;
	2585	 2586	 0.001778	 0.092049	 0.0	 348	 348	 348	 1.01833	 0.0	 1	 -30.0	 30.0;
	2585	 2586	 0.001837	 0.093827	 0.0	 341	 341	 341	 1.01833	 0.0	 1	 -30.0	 30.0;
	2596	 2597	 0.003951	 0.111605	 0.0	 273	 273	 273	 0.952382	 0.0	 1	 -30.0	 30.0;
	2596	 2597	 0.00316	 0.116148	 0.0	 263	 263	 263	 0.942507	 0.0	 1	 -30.0	 30.0;
	2596	 2597	 0.003279	 0.11516	 0.0	 265	 265	 265	 0.952382	 0.0	 1	 -30.0	 30.0;
	2596	 2597	 0.003081	 0.118123	 0.0	 259	 259	 259	 0.942507	 0.0	 1	 -30.0	 30.0;
	2607	 2609	 0.001842	 0.101731	 0.0	 310	 310	 310	 0.974656	 0.0	 1	 -30.0	 30.0;
	2607	 2608	 0.001821	 0.100762	 0.0	 313	 313	 313	 0.987171	 0.0	 1	 -30.0	 30.0;
	2627	 2628	 0.00399	 0.111605	 0.0	 280	 280	 280	 0.976562	 0.0	 1	 -30.0	 30.0;
	2635	 2637	 0.003615	 0.123062	 0.0	 251	 251	 251	 0.987167	 0.0	 1	 -30.0	 30.0;
	2636	 2637	 0.003141	 0.116741	 0.0	 265	 265	 265	 0.987167	 0.0	 1	 -30.0	 30.0;
	2635	 2637	 0.003516	 0.121679	 0.0	 254	 254	 254	 0.968054	 0.0	 1	 -30.0	 30.0;
	2649	 2650	 0.001956	 0.003956	 0.0	 974.0	 974.0	 974.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2656	 2657	 0.003062	 0.116741	 0.0	 268	 268	 268	 1.0	 0.0	 1	 -30.0	 30.0;
	2662	 2663	 0.003852	 0.12642	 0.0	 242	 242	 242	 0.978474	 0.0	 1	 -30.0	 30.0;
	2662	 2663	 0.003852	 0.12642	 0.0	 242	 242	 242	 0.968054	 0.0	 1	 -30.0	 30.0;
	2665	 2667	 0.002016	 0.004031	 0.0	 7637	 7637	 7637	 1.0	 0.0	 1	 -30.0	 30.0;
	2664	 5933	 0.012444	 0.152889	 0.0	 226	 226	 226	 1.0	 0.0	 1	 -30.0	 30.0;
	2666	 2668	 0.003956	 0.039511	 0.0	 863	 863	 863	 1.0	 0.0	 1	 -30.0	 30.0;
	2667	 5933	 0.000889	 0.002667	 0.0	 12244	 12244	 12244	 0.930237	 0.0	 1	 -30.0	 30.0;
	2668	 5933	 0.005333	 0.308444	 0.0	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	2669	 2670	 0.002099	 0.116049	 0.0	 256	 256	 256	 0.978469	 0.0	 1	 -30.0	 30.0;
	2671	 2672	 0.068027	 0.942303	 0.0	 37	 37	 37	 0.550361	 0.0	 1	 -30.0	 30.0;
	2677	 2678	 0.00399	 0.124642	 0.0	 248	 248	 248	 0.97561	 0.0	 1	 -30.0	 30.0;
	2677	 2678	 0.003556	 0.126025	 0.0	 245	 245	 245	 0.97561	 0.0	 1	 -30.0	 30.0;
	2677	 2678	 0.001936	 0.117926	 0.0	 262	 262	 262	 0.98619	 0.0	 1	 -30.0	 30.0;
	2686	 2687	 0.003121	 0.125235	 0.0	 247	 247	 247	 0.963394	 0.0	 1	 -30.0	 30.0;
	2705	 2706	 0.003753	 0.12879	 0.0	 239	 239	 239	 0.989123	 0.0	 1	 -30.0	 30.0;
	2705	 2706	 0.00316	 0.125235	 0.0	 246	 246	 246	 0.976559	 0.0	 1	 -30.0	 30.0;
	2707	 2709	 0.00158	 0.117531	 0.0	 262	 262	 262	 1.024591	 0.0	 1	 -30.0	 30.0;
	2707	 2709	 0.001975	 0.11358	 0.0	 271	 271	 271	 1.0142	 0.0	 1	 -30.0	 30.0;
	2708	 2709	 0.001778	 0.118716	 0.0	 259	 259	 259	 1.026695	 0.0	 1	 -30.0	 30.0;
	2715	 2716	 0.000665	 0.043075	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2715	 2716	 0.000672	 0.04356	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	5934	 2715	 0.000554	 -0.004224	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2716	 5934	 0.000118	 0.047576	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2721	 2722	 0.000679	 0.04536	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2721	 2722	 0.000686	 0.045083	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2725	 2726	 0.003259	 0.123852	 0.0	 249	 249	 249	 0.978474	 0.0	 1	 -30.0	 30.0;
	2725	 2726	 0.003081	 0.117728	 0.0	 262	 262	 262	 0.982323	 0.0	 1	 -30.0	 30.0;
	2754	 2755	 0.00316	 0.162963	 0.0	 189	 189	 189	 0.95511	 0.0	 1	 -30.0	 30.0;
	2754	 2755	 0.002765	 0.170864	 0.0	 180	 180	 180	 0.956935	 0.0	 1	 -30.0	 30.0;
	2763	 2764	 0.000332	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2763	 2764	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2763	 2764	 0.000319	 0.025139	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2770	 2771	 0.001758	 0.092247	 0.0	 331	 331	 331	 0.971818	 0.0	 1	 -30.0	 30.0;
	2769	 5882	 0.004993	 0.223892	 0.0	 155	 155	 155	 1.0	 0.0	 1	 -30.0	 30.0;
	2770	 2772	 0.001828	 0.102562	 0.0	 307	 307	 307	 0.948768	 0.0	 1	 -30.0	 30.0;
	2770	 2772	 0.001807	 0.100416	 0.0	 314	 314	 314	 0.948768	 0.0	 1	 -30.0	 30.0;
	2771	 5882	 0.000651	 -0.005055	 0.0	 547.0	 547.0	 547.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2772	 5882	 4.2e-05	 0.05374	 0.0	 547.0	 547.0	 547.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2775	 2776	 0.004938	 0.163556	 0.0	 188	 188	 188	 1.037345	 0.0	 1	 -30.0	 30.0;
	2777	 2778	 0.003654	 0.173235	 0.0	 178	 178	 178	 0.96432	 0.0	 1	 -30.0	 30.0;
	2781	 2782	 0.003378	 0.105679	 0.0	 292	 292	 292	 0.978474	 0.0	 1	 -30.0	 30.0;
	2781	 2782	 0.003299	 0.107654	 0.0	 287	 287	 287	 0.968054	 0.0	 1	 -30.0	 30.0;
	2780	 2783	 0.001807	 0.100831	 0.0	 314	 314	 314	 0.965248	 0.0	 1	 -30.0	 30.0;
	2780	 2783	 0.00178	 0.100139	 0.0	 316	 316	 316	 0.965248	 0.0	 1	 -30.0	 30.0;
	2782	 2783	 0.000759	 0.035838	 0.0	 885	 885	 885	 1.001	 0.0	 1	 -30.0	 30.0;
	2785	 5883	 0.000145	 -0.011219	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2785	 5910	 0.000139	 -0.007687	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2786	 5883	 0.000194	 0.038781	 0.0	 883	 883	 883	 0.0	 0.0	 1	 -30.0	 30.0;
	2787	 5910	 0.000187	 0.034903	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 2792	 0.002074	 0.116741	 0.0	 265	 265	 265	 0.98912	 0.0	 1	 -30.0	 30.0;
	2791	 2792	 0.001936	 0.115951	 0.0	 266	 266	 266	 0.98912	 0.0	 1	 -30.0	 30.0;
	2797	 2799	 0.001752	 0.100485	 0.0	 320	 320	 320	 1.029866	 0.0	 1	 -30.0	 30.0;
	2798	 2799	 0.000319	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2798	 2799	 0.000325	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2804	 2807	 0.003081	 0.117728	 0.0	 261	 261	 261	 0.919114	 0.0	 1	 -30.0	 30.0;
	2805	 2807	 0.004504	 0.162568	 0.0	 189	 189	 189	 0.919114	 0.0	 1	 -30.0	 30.0;
	2806	 2807	 0.003575	 0.121481	 0.0	 259	 259	 259	 1.034127	 0.0	 1	 -30.0	 30.0;
	2810	 2811	 0.003062	 0.116148	 0.0	 263	 263	 263	 0.992063	 0.0	 1	 -30.0	 30.0;
	2810	 2811	 0.003595	 0.123654	 0.0	 247	 247	 247	 0.984254	 0.0	 1	 -30.0	 30.0;
	2815	 2816	 0.003062	 0.116543	 0.0	 265	 265	 265	 1.022495	 0.0	 1	 -30.0	 30.0;
	2815	 2816	 0.003101	 0.115753	 0.0	 267	 267	 267	 1.010101	 0.0	 1	 -30.0	 30.0;
	2832	 5884	 0.000443	 -0.004848	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2832	 5911	 0.000305	 -0.007133	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2832	 2833	 0.000734	 0.024654	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2833	 5884	 0.000249	 0.047992	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2833	 5911	 0.000506	 0.046814	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2848	 2849	 0.003081	 0.12563	 0.0	 243	 243	 243	 0.964324	 0.0	 1	 -30.0	 30.0;
	2864	 2865	 0.001778	 0.099753	 0.0	 306	 306	 306	 1.009082	 0.0	 1	 -30.0	 30.0;
	2864	 2865	 0.001778	 0.098765	 0.0	 309	 309	 309	 1.033059	 0.0	 1	 -30.0	 30.0;
	2893	 5885	 0.000152	 -0.011219	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2893	 5912	 0.000443	 -0.011011	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2893	 5935	 0.000215	 -0.005194	 0.0	 1186.0	 1186.0	 1186.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2893	 5945	 0.000145	 -0.011496	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2894	 5885	 0.000187	 0.038296	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	2894	 5912	 0.000374	 0.053463	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2894	 5935	 9.7e-05	 0.032064	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	2894	 5945	 0.000194	 0.038435	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	2900	 5886	 0.002568	 0.070124	 0.0	 493	 493	 493	 1.0	 0.0	 1	 -30.0	 30.0;
	2902	 5886	 0.002765	 0.132148	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	2914	 2915	 0.003556	 0.118321	 0.0	 260	 260	 260	 0.976559	 0.0	 1	 -30.0	 30.0;
	2915	 5887	 0.000229	 -0.004571	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	2916	 5913	 0.000215	 -0.004432	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	2917	 2918	 0.000312	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	2918	 5887	 9.7e-05	 0.029363	 0.0	 1166	 1166	 1166	 0.0	 0.0	 1	 -30.0	 30.0;
	2918	 5913	 9.7e-05	 0.029086	 0.0	 1178	 1178	 1178	 0.0	 0.0	 1	 -30.0	 30.0;
	2931	 2933	 0.002983	 0.117926	 0.0	 262	 262	 262	 0.96432	 0.0	 1	 -30.0	 30.0;
	2931	 2932	 0.00322	 0.115951	 0.0	 266	 266	 266	 0.976562	 0.0	 1	 -30.0	 30.0;
	2937	 2938	 0.00316	 0.12484	 0.0	 246	 246	 246	 1.001002	 0.0	 1	 -30.0	 30.0;
	2936	 2938	 0.003753	 0.128	 0.0	 240	 240	 240	 1.001002	 0.0	 1	 -30.0	 30.0;
	2936	 2938	 0.003556	 0.121877	 0.0	 252	 252	 252	 1.001002	 0.0	 1	 -30.0	 30.0;
	2945	 2946	 0.004306	 0.159605	 0.0	 194	 194	 194	 0.974655	 0.0	 1	 -30.0	 30.0;
	2945	 2946	 0.003022	 0.115358	 0.0	 268	 268	 268	 0.973708	 0.0	 1	 -30.0	 30.0;
	2947	 2948	 0.001385	 0.099162	 0.0	 318	 318	 318	 0.939851	 0.0	 1	 -30.0	 30.0;
	2951	 2953	 0.001857	 0.115358	 0.0	 268	 268	 268	 0.987165	 0.0	 1	 -30.0	 30.0;
	2951	 2952	 0.001857	 0.115358	 0.0	 268	 268	 268	 0.987165	 0.0	 1	 -30.0	 30.0;
	2959	 2960	 0.0164	 0.342222	 0.0	 92	 92	 92	 0.971817	 0.0	 1	 -30.0	 30.0;
	2966	 5914	 0.001787	 0.089335	 0.0	 387	 387	 387	 1.0	 0.0	 1	 -30.0	 30.0;
	2968	 2970	 0.000325	 0.027355	 0.0	 1160	 1160	 1160	 1.0	 0.0	 1	 -30.0	 30.0;
	2969	 5914	 0.000152	 -0.011357	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2968	 5936	 0.000145	 -0.00741	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2968	 5946	 0.000125	 -0.007756	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2970	 5914	 0.000187	 0.038435	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	2971	 5936	 0.000194	 0.034626	 0.0	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	2971	 5946	 0.000215	 0.034903	 0.0	 981	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	2973	 2974	 0.003121	 0.125037	 0.0	 247	 247	 247	 0.968054	 0.0	 1	 -30.0	 30.0;
	2973	 2974	 0.003793	 0.12642	 0.0	 244	 244	 244	 0.978474	 0.0	 1	 -30.0	 30.0;
	2986	 2987	 0.001936	 0.116741	 0.0	 263	 263	 263	 0.96432	 0.0	 1	 -30.0	 30.0;
	2986	 2987	 0.001936	 0.116741	 0.0	 263	 263	 263	 0.96432	 0.0	 1	 -30.0	 30.0;
	2996	 2997	 0.03225	 0.602419	 0.0	 58	 58	 58	 1.001	 0.0	 1	 -30.0	 30.0;
	2997	 3000	 0.00316	 0.125037	 0.0	 246	 246	 246	 1.013172	 0.0	 1	 -30.0	 30.0;
	2998	 3000	 0.001679	 0.121679	 0.0	 253	 253	 253	 0.997009	 0.0	 1	 -30.0	 30.0;
	3001	 3002	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.97561	 0.0	 1	 -30.0	 30.0;
	3001	 3002	 0.003398	 0.118716	 0.0	 257	 257	 257	 0.975606	 0.0	 1	 -30.0	 30.0;
	3001	 3002	 0.003852	 0.11121	 0.0	 274	 274	 274	 0.97561	 0.0	 1	 -30.0	 30.0;
	3003	 3004	 0.001719	 0.122074	 0.0	 253	 253	 253	 0.98912	 0.0	 1	 -30.0	 30.0;
	3003	 3004	 0.001758	 0.122469	 0.0	 252	 252	 252	 0.98619	 0.0	 1	 -30.0	 30.0;
	3003	 3004	 0.001758	 0.122469	 0.0	 252	 252	 252	 0.978474	 0.0	 1	 -30.0	 30.0;
	3010	 3011	 0.003338	 0.11121	 0.0	 278	 278	 278	 0.963394	 0.0	 1	 -30.0	 30.0;
	3010	 3011	 0.003121	 0.119704	 0.0	 259	 259	 259	 0.963394	 0.0	 1	 -30.0	 30.0;
	3011	 3012	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	3011	 3012	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	3017	 3018	 0.003081	 0.116543	 0.0	 262	 262	 262	 1.009082	 0.0	 1	 -30.0	 30.0;
	3017	 3018	 0.003101	 0.116148	 0.0	 263	 263	 263	 1.009082	 0.0	 1	 -30.0	 30.0;
	3031	 3032	 0.004543	 0.160395	 0.0	 193	 193	 193	 0.978474	 0.0	 1	 -30.0	 30.0;
	3031	 3032	 0.002825	 0.170469	 0.0	 181	 181	 181	 0.98912	 0.0	 1	 -30.0	 30.0;
	3032	 5888	 0.00045	 -0.014404	 0.0	 567.0	 567.0	 567.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3032	 5915	 0.000471	 -0.013712	 0.0	 581.0	 581.0	 581.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3032	 3033	 0.000803	 0.034903	 0.0	 581.0	 581.0	 581.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3033	 5888	 0.000381	 0.050623	 0.0	 567.0	 567.0	 567.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3033	 5915	 0.000367	 0.050554	 0.0	 581.0	 581.0	 581.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3064	 3065	 0.003911	 0.112	 0.0	 273	 273	 273	 0.985226	 0.0	 1	 -30.0	 30.0;
	3064	 3065	 0.003062	 0.117136	 0.0	 261	 261	 261	 0.985226	 0.0	 1	 -30.0	 30.0;
	3074	 3075	 0.004346	 0.165136	 0.0	 186	 186	 186	 0.978477	 0.0	 1	 -30.0	 30.0;
	3074	 3075	 0.00316	 0.126025	 0.0	 244	 244	 244	 0.965249	 0.0	 1	 -30.0	 30.0;
	3082	 3083	 0.000395	 0.130568	 0.0	 237	 237	 237	 0.946073	 0.0	 1	 -30.0	 30.0;
	3082	 3083	 0.000395	 0.130568	 0.0	 237	 237	 237	 0.956935	 0.0	 1	 -30.0	 30.0;
	3086	 3087	 0.003279	 0.113383	 0.0	 272	 272	 272	 0.978474	 0.0	 1	 -30.0	 30.0;
	3086	 3087	 0.003931	 0.12484	 0.0	 247	 247	 247	 0.978474	 0.0	 1	 -30.0	 30.0;
	3086	 3087	 0.003891	 0.11279	 0.0	 274	 274	 274	 0.978474	 0.0	 1	 -30.0	 30.0;
	3088	 3089	 0.00316	 0.118519	 0.0	 260	 260	 260	 0.976559	 0.0	 1	 -30.0	 30.0;
	3100	 3101	 0.003753	 0.129778	 0.0	 237	 237	 237	 0.989123	 0.0	 1	 -30.0	 30.0;
	3100	 3101	 0.004741	 0.16079	 0.0	 191	 191	 191	 0.967124	 0.0	 1	 -30.0	 30.0;
	3118	 3121	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3117	 3120	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3116	 3119	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3127	 3128	 0.003067	 0.132444	 0.0	 237	 237	 237	 1.081081	 0.0	 1	 -30.0	 30.0;
	3127	 3128	 0.003067	 0.132444	 0.0	 237	 237	 237	 1.082251	 0.0	 1	 -30.0	 30.0;
	3134	 3135	 0.001918	 0.160035	 0.0	 198	 198	 198	 0.994036	 0.0	 1	 -30.0	 30.0;
	3134	 3135	 0.001918	 0.160035	 0.0	 198	 198	 198	 0.985218	 0.0	 1	 -30.0	 30.0;
	3145	 3146	 0.003812	 0.122469	 0.0	 251	 251	 251	 0.987167	 0.0	 1	 -30.0	 30.0;
	3145	 3146	 0.003812	 0.122469	 0.0	 251	 251	 251	 0.987167	 0.0	 1	 -30.0	 30.0;
	3152	 3153	 0.003158	 0.158795	 0.0	 200	 200	 200	 0.939851	 0.0	 1	 -30.0	 30.0;
	3152	 3154	 0.003137	 0.159834	 0.0	 198	 198	 198	 0.939851	 0.0	 1	 -30.0	 30.0;
	3152	 3154	 0.001364	 0.112881	 0.0	 281	 281	 281	 0.9311	 0.0	 1	 -30.0	 30.0;
	3164	 3165	 0.001995	 0.126025	 0.0	 245	 245	 245	 0.926784	 0.0	 1	 -30.0	 30.0;
	3164	 3165	 0.003951	 0.125432	 0.0	 246	 246	 246	 0.926784	 0.0	 1	 -30.0	 30.0;
	3175	 3176	 0.003081	 0.110617	 0.0	 278	 278	 278	 0.987167	 0.0	 1	 -30.0	 30.0;
	3175	 3176	 0.001995	 0.12642	 0.0	 243	 243	 243	 0.97561	 0.0	 1	 -30.0	 30.0;
	3179	 5889	 0.000235	 -0.004294	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3179	 5916	 0.000145	 -0.006233	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3180	 5889	 9e-05	 0.029086	 0.0	 1178	 1178	 1178	 0.0	 0.0	 1	 -30.0	 30.0;
	3180	 5916	 0.000194	 0.031233	 0.0	 1097	 1097	 1097	 0.0	 0.0	 1	 -30.0	 30.0;
	4575	 3199	 0.000119	 0.009086	 0.0	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3197	 3199	 0.003062	 0.116938	 0.0	 261	 261	 261	 0.973708	 0.0	 1	 -30.0	 30.0;
	3197	 3199	 0.00316	 0.109037	 0.0	 280	 280	 280	 0.974655	 0.0	 1	 -30.0	 30.0;
	3197	 3199	 0.003911	 0.111407	 0.0	 274	 274	 274	 0.973708	 0.0	 1	 -30.0	 30.0;
	3201	 3202	 0.003141	 0.115556	 0.0	 266	 266	 266	 0.988142	 0.0	 1	 -30.0	 30.0;
	3201	 3202	 0.003141	 0.115556	 0.0	 266	 266	 266	 0.988142	 0.0	 1	 -30.0	 30.0;
	3215	 3217	 0.003081	 0.116543	 0.0	 270	 270	 270	 1.02459	 0.0	 1	 -30.0	 30.0;
	3258	 3259	 0.001699	 0.099358	 0.0	 308	 308	 308	 0.971818	 0.0	 1	 -30.0	 30.0;
	3258	 3259	 0.001679	 0.098765	 0.0	 309	 309	 309	 0.971818	 0.0	 1	 -30.0	 30.0;
	3269	 3270	 0.00316	 0.116543	 0.0	 265	 265	 265	 1.012146	 0.0	 1	 -30.0	 30.0;
	3269	 3270	 0.004365	 0.167704	 0.0	 184	 184	 184	 1.0	 0.0	 1	 -30.0	 30.0;
	3269	 3270	 0.00401	 0.111012	 0.0	 278	 278	 278	 1.012146	 0.0	 1	 -30.0	 30.0;
	3278	 3279	 0.007348	 0.24	 0.0	 129	 129	 129	 0.94697	 0.0	 1	 -30.0	 30.0;
	3278	 3279	 0.003714	 0.123062	 0.0	 251	 251	 251	 0.96432	 0.0	 1	 -30.0	 30.0;
	3282	 3284	 0.015873	 0.256992	 0.0	 134	 134	 134	 1.001	 0.0	 1	 -30.0	 30.0;
	3281	 3283	 0.015873	 0.256992	 0.0	 134	 134	 134	 1.001	 0.0	 1	 -30.0	 30.0;
	3280	 3286	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3290	 3291	 0.000198	 0.118716	 0.0	 264	 264	 264	 1.006036	 0.0	 1	 -30.0	 30.0;
	3297	 3298	 0.003417	 0.116543	 0.0	 265	 265	 265	 1.0	 0.0	 1	 -30.0	 30.0;
	3311	 3312	 0.003378	 0.112988	 0.0	 273	 273	 273	 1.0	 0.0	 1	 -30.0	 30.0;
	3311	 3312	 0.003832	 0.125037	 0.0	 247	 247	 247	 1.012146	 0.0	 1	 -30.0	 30.0;
	3311	 3312	 0.003911	 0.123457	 0.0	 250	 250	 250	 1.023541	 0.0	 1	 -30.0	 30.0;
	3321	 3323	 0.004049	 0.124049	 0.0	 246	 246	 246	 0.964324	 0.0	 1	 -30.0	 30.0;
	3321	 3323	 0.003358	 0.124247	 0.0	 246	 246	 246	 0.978473	 0.0	 1	 -30.0	 30.0;
	3322	 3323	 0.001956	 0.124642	 0.0	 245	 245	 245	 0.967121	 0.0	 1	 -30.0	 30.0;
	3335	 3336	 0.00397	 0.113383	 0.0	 271	 271	 271	 0.976559	 0.0	 1	 -30.0	 30.0;
	3335	 3336	 0.003951	 0.119111	 0.0	 258	 258	 258	 0.987172	 0.0	 1	 -30.0	 30.0;
	3334	 3336	 0.001975	 0.116938	 0.0	 263	 263	 263	 0.989123	 0.0	 1	 -30.0	 30.0;
	3344	 3345	 0.013857	 0.312421	 0.0	 95	 95	 95	 0.947864	 0.0	 1	 -30.0	 30.0;
	3344	 3345	 0.02066	 0.410935	 0.0	 72	 72	 72	 0.933703	 0.0	 1	 -30.0	 30.0;
	3345	 3346	 0.004543	 0.120691	 0.001	 255	 255	 255	 0.989123	 0.0	 1	 -30.0	 30.0;
	3345	 3346	 0.003951	 0.124247	 0.0	 248	 248	 248	 0.989123	 0.0	 1	 -30.0	 30.0;
	3349	 3350	 0.003556	 0.120296	 0.0	 256	 256	 256	 0.97561	 0.0	 1	 -30.0	 30.0;
	3349	 3350	 0.003081	 0.116346	 0.0	 264	 264	 264	 0.96432	 0.0	 1	 -30.0	 30.0;
	3363	 3364	 0.001798	 0.118716	 0.0	 260	 260	 260	 0.98912	 0.0	 1	 -30.0	 30.0;
	3363	 3364	 0.001719	 0.122272	 0.0	 253	 253	 253	 0.98619	 0.0	 1	 -30.0	 30.0;
	3366	 3367	 0.00399	 0.11121	 0.0	 299	 299	 299	 1.037344	 0.0	 1	 -30.0	 30.0;
	3366	 3367	 0.00399	 0.11121	 0.0	 299	 299	 299	 1.037344	 0.0	 1	 -30.0	 30.0;
	3366	 3367	 0.003733	 0.123654	 0.0	 269	 269	 269	 1.037344	 0.0	 1	 -30.0	 30.0;
	3371	 3372	 0.001738	 0.100139	 0.0	 316	 316	 316	 0.956942	 0.0	 1	 -30.0	 30.0;
	3371	 3372	 0.001738	 0.100139	 0.0	 316	 316	 316	 0.956942	 0.0	 1	 -30.0	 30.0;
	3380	 3381	 0.004405	 0.165926	 0.0	 189	 189	 189	 0.978474	 0.0	 1	 -30.0	 30.0;
	3380	 3381	 0.004484	 0.166321	 0.0	 188	 188	 188	 0.98912	 0.0	 1	 -30.0	 30.0;
	3380	 3381	 0.003674	 0.162568	 0.0	 193	 193	 193	 0.978474	 0.0	 1	 -30.0	 30.0;
	3396	 3397	 0.003556	 0.126815	 0.0	 247	 247	 247	 1.02459	 0.0	 1	 -30.0	 30.0;
	3396	 3397	 0.003556	 0.126815	 0.0	 247	 247	 247	 1.012146	 0.0	 1	 -30.0	 30.0;
	3399	 3400	 0.003279	 0.125235	 0.0	 247	 247	 247	 1.011122	 0.0	 1	 -30.0	 30.0;
	3399	 3400	 0.003773	 0.116543	 0.0	 265	 265	 265	 1.0	 0.0	 1	 -30.0	 30.0;
	3399	 3400	 0.001141	 0.12083	 0.0	 256	 256	 256	 1.009082	 0.0	 1	 -30.0	 30.0;
	3432	 3433	 0.003047	 0.155125	 0.0	 204	 204	 204	 0.953289	 0.0	 1	 -30.0	 30.0;
	3432	 3433	 0.003186	 0.160873	 0.0	 197	 197	 197	 0.965248	 0.0	 1	 -30.0	 30.0;
	3441	 3442	 0.009556	 0.309778	 0.0	 102	 102	 102	 1.015229	 0.0	 1	 -30.0	 30.0;
	3441	 3442	 0.009911	 0.307556	 0.0	 102	 102	 102	 1.015229	 0.0	 1	 -30.0	 30.0;
	3470	 3471	 0.000284	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.046025	 0.0	 1	 -30.0	 30.0;
	3482	 3485	 0.001679	 0.122074	 0.0	 252	 252	 252	 0.953285	 0.0	 1	 -30.0	 30.0;
	3482	 3485	 0.001679	 0.122074	 0.0	 252	 252	 252	 0.974661	 0.0	 1	 -30.0	 30.0;
	3484	 3485	 0.002963	 0.085531	 0.0	 351.0	 351.0	 351.0	 1.004017	 0.0	 1	 -30.0	 30.0;
	3483	 3485	 0.003042	 0.117531	 0.0	 263	 263	 263	 0.992063	 0.0	 1	 -30.0	 30.0;
	1497	 3505	 0.003951	 0.029126	 0.0162	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3503	 3505	 0.003081	 0.125452	 0.0	 246	 246	 246	 0.98619	 0.0	 1	 -30.0	 30.0;
	3506	 3507	 0.03225	 0.602419	 0.0	 58	 58	 58	 1.001	 0.0	 1	 -30.0	 30.0;
	3509	 3510	 0.004148	 0.165531	 0.0	 186	 186	 186	 0.967124	 0.0	 1	 -30.0	 30.0;
	3515	 3517	 0.00187	 0.101731	 0.0	 310	 310	 310	 0.984249	 0.0	 1	 -30.0	 30.0;
	3515	 3516	 0.001773	 0.099862	 0.0	 316	 316	 316	 0.994033	 0.0	 1	 -30.0	 30.0;
	3518	 3519	 0.004662	 0.16	 0.0	 193	 193	 193	 0.98912	 0.0	 1	 -30.0	 30.0;
	3518	 3519	 0.00476	 0.166123	 0.0	 186	 186	 186	 0.968054	 0.0	 1	 -30.0	 30.0;
	3518	 3519	 0.004523	 0.160988	 0.0	 192	 192	 192	 0.968054	 0.0	 1	 -30.0	 30.0;
	3520	 3521	 0.005679	 0.116173	 0.0	 266	 266	 266	 1.001002	 0.0	 1	 -30.0	 30.0;
	3522	 3524	 0.00316	 0.125432	 0.0	 245	 245	 245	 1.0142	 0.0	 1	 -30.0	 30.0;
	3523	 3524	 0.00316	 0.125827	 0.0	 245	 245	 245	 1.0142	 0.0	 1	 -30.0	 30.0;
	3523	 3524	 0.001817	 0.118716	 0.0	 259	 259	 259	 0.989123	 0.0	 1	 -30.0	 30.0;
	3539	 3540	 0.00316	 0.112	 0.0	 277	 277	 277	 1.020408	 0.0	 1	 -30.0	 30.0;
	3539	 3540	 0.00316	 0.112	 0.0	 277	 277	 277	 1.011122	 0.0	 1	 -30.0	 30.0;
	3543	 3544	 0.004543	 0.163951	 0.0	 188	 188	 188	 0.978474	 0.0	 1	 -30.0	 30.0;
	3546	 3547	 0.003556	 0.111407	 0.0	 274	 274	 274	 0.999001	 0.0	 1	 -30.0	 30.0;
	3546	 3547	 0.00401	 0.110222	 0.0	 277	 277	 277	 1.010101	 0.0	 1	 -30.0	 30.0;
	3546	 3547	 0.003338	 0.109037	 0.0	 280	 280	 280	 0.999001	 0.0	 1	 -30.0	 30.0;
	3556	 3557	 0.003891	 0.12484	 0.0	 246	 246	 246	 0.974664	 0.0	 1	 -30.0	 30.0;
	3556	 3557	 0.003674	 0.124642	 0.0	 247	 247	 247	 0.952382	 0.0	 1	 -30.0	 30.0;
	3560	 3561	 0.003556	 0.111605	 0.0	 277	 277	 277	 0.974664	 0.0	 1	 -30.0	 30.0;
	3560	 3561	 0.004405	 0.165926	 0.0	 186	 186	 186	 0.968059	 0.0	 1	 -30.0	 30.0;
	3560	 3561	 0.004227	 0.169481	 0.0	 182	 182	 182	 0.968054	 0.0	 1	 -30.0	 30.0;
	3562	 3563	 0.002311	 0.119506	 0.0	 257	 257	 257	 0.963394	 0.0	 1	 -30.0	 30.0;
	3562	 3564	 0.002311	 0.119506	 0.0	 257	 257	 257	 0.96246	 0.0	 1	 -30.0	 30.0;
	3565	 3566	 0.003595	 0.126815	 0.0	 242	 242	 242	 0.953289	 0.0	 1	 -30.0	 30.0;
	3573	 3574	 0.004326	 0.167506	 0.0	 185	 185	 185	 0.978477	 0.0	 1	 -30.0	 30.0;
	3573	 3574	 0.004583	 0.162963	 0.0	 190	 190	 190	 0.978477	 0.0	 1	 -30.0	 30.0;
	1495	 3582	 4.2e-05	 0.000339	 0.0061	 1184.0	 1184.0	 1184.0	 1.0	 -9.95	 1	 -30.0	 30.0;
	3579	 3580	 0.00316	 0.125037	 0.0	 246	 246	 246	 0.967124	 0.0	 1	 -30.0	 30.0;
	3580	 3582	 0.000679	 0.042867	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	3587	 3589	 0.002016	 0.239355	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	3588	 3590	 0.002016	 0.239355	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	3595	 3596	 0.004622	 0.227951	 0.0	 134	 134	 134	 0.917431	 0.0	 1	 -30.0	 30.0;
	3597	 3598	 0.00484	 0.165926	 0.0	 184	 184	 184	 0.968054	 0.0	 1	 -30.0	 30.0;
	3602	 3603	 0.00316	 0.113185	 0.0	 273	 273	 273	 1.002004	 0.0	 1	 -30.0	 30.0;
	3604	 3605	 0.001481	 0.128395	 0.0	 238	 238	 238	 0.96432	 0.0	 1	 -30.0	 30.0;
	3610	 3611	 0.003951	 0.12484	 0.0	 246	 246	 246	 0.990101	 0.0	 1	 -30.0	 30.0;
	3614	 5890	 0.000111	 -0.007895	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3616	 5917	 0.00027	 -0.005402	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3614	 5937	 0.000152	 -0.007964	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3615	 5947	 0.000152	 -0.007271	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3616	 3617	 0.000325	 0.027078	 0.0	 1171	 1171	 1171	 1.0	 0.0	 1	 -30.0	 30.0;
	3618	 5890	 0.000222	 0.03518	 0.0	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	3618	 5917	 5.5e-05	 0.032756	 0.0	 1046	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	3617	 5937	 0.000201	 0.034764	 0.0	 985	 985	 985	 0.0	 0.0	 1	 -30.0	 30.0;
	3617	 5947	 0.000194	 0.034141	 0.0	 1003	 1003	 1003	 0.0	 0.0	 1	 -30.0	 30.0;
	3621	 3622	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.963394	 0.0	 1	 -30.0	 30.0;
	3621	 3622	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.974664	 0.0	 1	 -30.0	 30.0;
	3621	 3622	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.963394	 0.0	 1	 -30.0	 30.0;
	3625	 3626	 0.000339	 0.027285	 0.0	 1156	 1156	 1156	 1.0	 0.0	 1	 -30.0	 30.0;
	3632	 3633	 0.002983	 0.117333	 0.0	 263	 263	 263	 0.973708	 0.0	 1	 -30.0	 30.0;
	3632	 3633	 0.004444	 0.159407	 0.0	 194	 194	 194	 0.965253	 0.0	 1	 -30.0	 30.0;
	3632	 3633	 0.003694	 0.116148	 0.0	 266	 266	 266	 0.985226	 0.0	 1	 -30.0	 30.0;
	3649	 3650	 0.003437	 0.122469	 0.0	 249	 249	 249	 0.999001	 0.0	 1	 -30.0	 30.0;
	3649	 3650	 0.003437	 0.122469	 0.0	 249	 249	 249	 0.999001	 0.0	 1	 -30.0	 30.0;
	3656	 3657	 0.003081	 0.116286	 0.0	 266	 266	 266	 1.040583	 0.0	 1	 -30.0	 30.0;
	3655	 3657	 0.003081	 0.116563	 0.0	 265	 265	 265	 1.040583	 0.0	 1	 -30.0	 30.0;
	3664	 3665	 0.005926	 0.114568	 0.0	 269	 269	 269	 0.974656	 0.0	 1	 -30.0	 30.0;
	3666	 3667	 0.001956	 0.117136	 0.0	 261	 261	 261	 0.96432	 0.0	 1	 -30.0	 30.0;
	3666	 3667	 0.001896	 0.11516	 0.0	 265	 265	 265	 0.96432	 0.0	 1	 -30.0	 30.0;
	3666	 3667	 0.001916	 0.116543	 0.0	 262	 262	 262	 0.96432	 0.0	 1	 -30.0	 30.0;
	3666	 3667	 0.000766	 0.116583	 0.0	 262	 262	 262	 0.95238	 0.0	 1	 -30.0	 30.0;
	3671	 3672	 0.00316	 0.112988	 0.0	 284	 284	 284	 1.002004	 0.0	 1	 -30.0	 30.0;
	3671	 3672	 0.003951	 0.112198	 0.0	 286	 286	 286	 0.985219	 0.0	 1	 -30.0	 30.0;
	3675	 3676	 0.003259	 0.109037	 0.0	 284	 284	 284	 0.992064	 0.0	 1	 -30.0	 30.0;
	3675	 3676	 0.00316	 0.112988	 0.0	 274.0	 274.0	 274.0	 0.983282	 0.0	 1	 -30.0	 30.0;
	3675	 3676	 0.0032	 0.114568	 0.0	 270	 270	 270	 0.974655	 0.0	 1	 -30.0	 30.0;
	3679	 3680	 0.001817	 0.118716	 0.0	 260	 260	 260	 1.0	 0.0	 1	 -30.0	 30.0;
	3679	 3680	 0.001798	 0.118716	 0.0	 260	 260	 260	 1.012146	 0.0	 1	 -30.0	 30.0;
	3679	 3680	 0.001798	 0.118716	 0.0	 260	 260	 260	 1.012146	 0.0	 1	 -30.0	 30.0;
	3705	 5891	 0.000215	 -0.00554	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3705	 3706	 0.000325	 0.027355	 0.0	 1153	 1153	 1153	 1.0	 0.0	 1	 -30.0	 30.0;
	3706	 5891	 0.000125	 0.033241	 0.0	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	3710	 3711	 0.003121	 0.125432	 0.0	 246	 246	 246	 0.978474	 0.0	 1	 -30.0	 30.0;
	3712	 3713	 0.00397	 0.124049	 0.0	 246	 246	 246	 0.941619	 0.0	 1	 -30.0	 30.0;
	3712	 3713	 0.003121	 0.125827	 0.0	 243	 243	 243	 0.941619	 0.0	 1	 -30.0	 30.0;
	3728	 3729	 0.007055	 0.203578	 0.0	 145	 145	 145	 0.914916	 0.0	 1	 -30.0	 30.0;
	3728	 3730	 0.004489	 0.280756	 0.0	 117	 117	 117	 0.871841	 0.0	 1	 -30.0	 30.0;
	3729	 3731	 0.004543	 0.120691	 0.0	 255	 255	 255	 0.95329	 0.0	 1	 -30.0	 30.0;
	3735	 3736	 0.00164	 0.090864	 0.0	 340	 340	 340	 0.950567	 0.0	 1	 -30.0	 30.0;
	4576	 3739	 0.000119	 0.009086	 0.0	 473.0	 473.0	 473.0	 1.0	 -6.32	 1	 -30.0	 30.0;
	3737	 3739	 0.003062	 0.117136	 0.0	 261	 261	 261	 1.0	 0.0	 1	 -30.0	 30.0;
	3737	 3739	 0.003852	 0.123654	 0.0	 247	 247	 247	 1.0	 0.0	 1	 -30.0	 30.0;
	3737	 3739	 0.003615	 0.124444	 0.0	 245	 245	 245	 0.987165	 0.0	 1	 -30.0	 30.0;
	3737	 3739	 0.003615	 0.124444	 0.0	 245	 245	 245	 0.999001	 0.0	 1	 -30.0	 30.0;
	3743	 3744	 0.00484	 0.162568	 0.0	 188	 188	 188	 0.968054	 0.0	 1	 -30.0	 30.0;
	3746	 3747	 0.003062	 0.116741	 0.0	 265	 265	 265	 0.985226	 0.0	 1	 -30.0	 30.0;
	3746	 3747	 0.003062	 0.116741	 0.0	 265	 265	 265	 0.985226	 0.0	 1	 -30.0	 30.0;
	3752	 3753	 0.000319	 0.024307	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3752	 3753	 0.000339	 0.025	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3752	 3753	 0.000325	 0.024584	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3759	 3760	 0.003832	 0.121284	 0.0	 254	 254	 254	 0.97561	 0.0	 1	 -30.0	 30.0;
	3759	 3760	 0.004464	 0.156049	 0.0	 197	 197	 197	 0.97561	 0.0	 1	 -30.0	 30.0;
	3764	 3765	 0.003081	 0.116286	 0.0	 266	 266	 266	 0.985218	 0.0	 1	 -30.0	 30.0;
	3764	 3765	 0.003081	 0.116563	 0.0	 265	 265	 265	 0.972763	 0.0	 1	 -30.0	 30.0;
	3764	 3765	 0.003081	 0.114983	 0.0	 269	 269	 269	 0.980388	 0.0	 1	 -30.0	 30.0;
	3774	 3775	 0.001766	 0.10097	 0.0	 314	 314	 314	 0.956942	 0.0	 1	 -30.0	 30.0;
	3774	 3775	 0.001787	 0.100208	 0.0	 317	 317	 317	 0.966188	 0.0	 1	 -30.0	 30.0;
	3778	 3782	 0.00158	 0.124049	 0.0	 246	 246	 246	 0.957854	 0.0	 1	 -30.0	 30.0;
	3779	 3781	 0.00158	 0.124049	 0.0	 246	 246	 246	 0.957854	 0.0	 1	 -30.0	 30.0;
	3778	 3782	 0.00158	 0.124049	 0.0	 246	 246	 246	 0.957854	 0.0	 1	 -30.0	 30.0;
	3777	 3780	 0.00158	 0.124049	 0.0	 246	 246	 246	 0.957854	 0.0	 1	 -30.0	 30.0;
	3791	 3793	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	3790	 3793	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	3789	 3792	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	3810	 3811	 0.001837	 0.11516	 0.0	 268	 268	 268	 0.953285	 0.0	 1	 -30.0	 30.0;
	3810	 3811	 0.001817	 0.11516	 0.0	 268	 268	 268	 0.96432	 0.0	 1	 -30.0	 30.0;
	3811	 3812	 0.000817	 0.04349	 0.0	 608.0	 608.0	 608.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3811	 3812	 0.000319	 0.027978	 0.0	 1134	 1134	 1134	 1.005027	 0.0	 1	 -30.0	 30.0;
	3819	 3822	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3818	 3821	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3817	 3820	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3831	 3833	 0.000395	 0.13037	 0.0	 237	 237	 237	 0.93633	 0.0	 1	 -30.0	 30.0;
	3832	 3833	 0.000395	 0.127407	 0.0	 243	 243	 243	 0.925928	 0.0	 1	 -30.0	 30.0;
	3841	 3842	 0.003951	 0.124247	 0.0	 248	 248	 248	 0.989123	 0.0	 1	 -30.0	 30.0;
	3851	 3852	 0.00478	 0.163358	 0.0	 189	 189	 189	 0.978474	 0.0	 1	 -30.0	 30.0;
	3851	 3852	 0.004286	 0.164346	 0.0	 188	 188	 188	 0.968054	 0.0	 1	 -30.0	 30.0;
	3855	 3857	 0.00316	 0.126025	 0.0	 244	 244	 244	 1.0142	 0.0	 1	 -30.0	 30.0;
	3856	 3857	 0.00316	 0.124049	 0.0	 248	 248	 248	 1.040584	 0.0	 1	 -30.0	 30.0;
	3874	 3875	 0.003358	 0.124049	 0.0	 246	 246	 246	 0.974664	 0.0	 1	 -30.0	 30.0;
	3874	 3875	 0.003911	 0.111407	 0.0	 274	 274	 274	 0.974664	 0.0	 1	 -30.0	 30.0;
	3879	 3880	 0.004346	 0.16158	 0.0	 191	 191	 191	 0.968054	 0.0	 1	 -30.0	 30.0;
	3879	 3880	 0.004365	 0.167901	 0.0	 184	 184	 184	 0.956938	 0.0	 1	 -30.0	 30.0;
	3879	 3880	 0.004642	 0.164741	 0.0	 188	 188	 188	 0.94697	 0.0	 1	 -30.0	 30.0;
	3881	 3882	 0.003793	 0.119309	 0.0	 258	 258	 258	 0.942507	 0.0	 1	 -30.0	 30.0;
	3881	 5938	 0.001481	 0.00316	 0.0	 482.0	 482.0	 482.0	 0.94697	 0.0	 1	 -30.0	 30.0;
	3882	 5938	 0.001956	 0.108444	 0.0	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	3889	 3890	 0.002099	 0.116049	 0.0	 261	 261	 261	 0.999001	 0.0	 1	 -30.0	 30.0;
	3898	 3899	 0.003714	 0.119506	 0.0	 258	 258	 258	 0.974664	 0.0	 1	 -30.0	 30.0;
	3901	 3902	 0.001159	 0.118874	 0.0	 257	 257	 257	 0.96432	 0.0	 1	 -30.0	 30.0;
	3901	 3902	 0.001254	 0.119427	 0.0	 256	 256	 256	 0.975614	 0.0	 1	 -30.0	 30.0;
	3907	 3908	 0.000713	 0.048546	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	3906	 3908	 0.000332	 0.026939	 0.0	 1177	 1177	 1177	 1.0	 0.0	 1	 -30.0	 30.0;
	3906	 3908	 0.000319	 0.026385	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3917	 3918	 0.003635	 0.124444	 0.0	 248	 248	 248	 1.002005	 0.0	 1	 -30.0	 30.0;
	3917	 3918	 0.002983	 0.12484	 0.0	 247	 247	 247	 0.997009	 0.0	 1	 -30.0	 30.0;
	3917	 3918	 0.003674	 0.129778	 0.0	 238	 238	 238	 0.978474	 0.0	 1	 -30.0	 30.0;
	3924	 3926	 0.003556	 0.126815	 0.0	 247	 247	 247	 1.037344	 0.0	 1	 -30.0	 30.0;
	3925	 3926	 0.003635	 0.120691	 0.0	 259	 259	 259	 1.012146	 0.0	 1	 -30.0	 30.0;
	3928	 3929	 0.005911	 0.119689	 0.0	 253	 253	 253	 0.976562	 0.0	 1	 -30.0	 30.0;
	3931	 3932	 0.00164	 0.116938	 0.0	 261	 261	 261	 0.98912	 0.0	 1	 -30.0	 30.0;
	3931	 3932	 0.001699	 0.122212	 0.0	 250	 250	 250	 0.987167	 0.0	 1	 -30.0	 30.0;
	3937	 3938	 0.004286	 0.165333	 0.0	 187	 187	 187	 0.956938	 0.0	 1	 -30.0	 30.0;
	3938	 5892	 0.000519	 -0.00831	 0.0	 600.0	 600.0	 600.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	3938	 5918	 0.000471	 -0.008033	 0.0	 600.0	 600.0	 600.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	3939	 5892	 0.000277	 0.047922	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3939	 5918	 0.00036	 0.049584	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3943	 3944	 0.000796	 0.041413	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	3943	 3944	 0.000831	 0.039681	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	3970	 3971	 0.002016	 0.079113	 0.0	 438	 438	 438	 1.0	 0.0	 1	 -30.0	 30.0;
	3969	 3972	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	3979	 3981	 0.002963	 0.118321	 0.0	 261	 261	 261	 0.985226	 0.0	 1	 -30.0	 30.0;
	3980	 3981	 0.003595	 0.123654	 0.0	 250	 250	 250	 0.985226	 0.0	 1	 -30.0	 30.0;
	4005	 4006	 0.00316	 0.11437	 0.0	 270	 270	 270	 0.974655	 0.0	 1	 -30.0	 30.0;
	4005	 4006	 0.003101	 0.116543	 0.0	 265	 265	 265	 0.970872	 0.0	 1	 -30.0	 30.0;
	4009	 4010	 0.001995	 0.118123	 0.0	 261	 261	 261	 1.023541	 0.0	 1	 -30.0	 30.0;
	4009	 4010	 0.002035	 0.116741	 0.0	 265	 265	 265	 1.023541	 0.0	 1	 -30.0	 30.0;
	4011	 4012	 0.004346	 0.164543	 0.0	 187	 187	 187	 1.024591	 0.0	 1	 -30.0	 30.0;
	4018	 4019	 0.00399	 0.143407	 0.0	 215	 215	 215	 0.97561	 0.0	 1	 -30.0	 30.0;
	4018	 4019	 0.003872	 0.146173	 0.0	 211	 211	 211	 0.97561	 0.0	 1	 -30.0	 30.0;
	4027	 4028	 0.003773	 0.111802	 0.0	 276	 276	 276	 0.956938	 0.0	 1	 -30.0	 30.0;
	4027	 4028	 0.00399	 0.112988	 0.0	 273	 273	 273	 0.968054	 0.0	 1	 -30.0	 30.0;
	4028	 4029	 0.000332	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4028	 4029	 0.000332	 0.024792	 0.0	 1182.0	 1182.0	 1182.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4037	 4038	 0.004227	 0.169481	 0.0	 182	 182	 182	 0.956938	 0.0	 1	 -30.0	 30.0;
	4046	 4047	 0.004938	 0.159012	 0.0	 197	 197	 197	 0.892063	 0.0	 1	 -30.0	 30.0;
	4049	 5893	 0.000118	 -0.005956	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4048	 4050	 0.000325	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4050	 5893	 0.000187	 0.032964	 0.0	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 4065	 0.004346	 0.158025	 0.0	 195	 195	 195	 0.990101	 0.0	 1	 -30.0	 30.0;
	4068	 4069	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4078	 5894	 0.001284	 0.126973	 0.0	 276	 276	 276	 0.945179	 0.0	 1	 -30.0	 30.0;
	4077	 5919	 0.001284	 0.126973	 0.0	 276	 276	 276	 0.941619	 0.0	 1	 -30.0	 30.0;
	4079	 5894	 0.00081	 -0.007802	 0.0	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 5919	 0.00081	 -0.007802	 0.0	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4089	 4090	 0.003951	 0.115951	 0.0	 266	 266	 266	 1.016261	 0.0	 1	 -30.0	 30.0;
	4089	 4090	 0.003951	 0.117965	 0.0	 262	 262	 262	 1.016261	 0.0	 1	 -30.0	 30.0;
	4093	 4094	 0.001975	 0.126025	 0.0	 244	 244	 244	 1.022496	 0.0	 1	 -30.0	 30.0;
	4095	 4096	 0.003595	 0.123062	 0.0	 250	 250	 250	 0.921656	 0.0	 1	 -30.0	 30.0;
	4102	 4103	 0.003951	 0.125235	 0.0	 244	 244	 244	 0.999001	 0.0	 1	 -30.0	 30.0;
	4102	 4103	 0.001975	 0.126025	 0.0	 242	 242	 242	 0.987165	 0.0	 1	 -30.0	 30.0;
	4106	 5895	 0.003428	 0.084557	 0.0	 408	 408	 408	 1.0	 0.0	 1	 -30.0	 30.0;
	5895	 4107	 0.000277	 -0.00464	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4107	 4108	 0.000339	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4108	 5895	 6.2e-05	 0.029571	 0.0	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 4113	 0.00316	 0.124642	 0.0	 247	 247	 247	 0.989123	 0.0	 1	 -30.0	 30.0;
	4112	 4113	 0.004741	 0.161975	 0.0	 190	 190	 190	 0.990101	 0.0	 1	 -30.0	 30.0;
	4120	 4121	 0.003081	 0.115358	 0.0	 271	 271	 271	 0.987167	 0.0	 1	 -30.0	 30.0;
	4120	 4121	 0.003556	 0.122864	 0.0	 255	 255	 255	 1.012146	 0.0	 1	 -30.0	 30.0;
	4122	 4123	 0.005309	 0.110123	 0.0	 291	 291	 291	 1.001002	 0.0	 1	 -30.0	 30.0;
	4123	 4124	 0.002015	 0.158657	 0.0	 203	 203	 203	 1.018331	 0.0	 1	 -30.0	 30.0;
	4135	 4136	 0.001177	 0.042382	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5939	 4135	 0.000499	 -0.006925	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5948	 4135	 0.000353	 -0.010873	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4136	 5939	 0.000201	 0.055402	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4137	 5948	 0.000429	 0.05374	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4142	 4144	 0.003062	 0.116938	 0.0	 261	 261	 261	 0.973708	 0.0	 1	 -30.0	 30.0;
	4143	 4144	 0.00316	 0.116741	 0.0	 262	 262	 262	 0.985226	 0.0	 1	 -30.0	 30.0;
	4143	 4144	 0.003733	 0.115753	 0.0	 264	 264	 264	 0.985226	 0.0	 1	 -30.0	 30.0;
	4143	 4144	 0.003931	 0.111802	 0.0	 273	 273	 273	 0.985226	 0.0	 1	 -30.0	 30.0;
	4145	 4146	 0.004484	 0.168494	 0.0	 181	 181	 181	 0.956938	 0.0	 1	 -30.0	 30.0;
	4145	 4146	 0.004484	 0.168494	 0.0	 181	 181	 181	 0.968054	 0.0	 1	 -30.0	 30.0;
	4150	 4151	 0.003951	 0.12563	 0.0	 245	 245	 245	 1.0142	 0.0	 1	 -30.0	 30.0;
	4149	 4151	 0.003951	 0.118123	 0.0	 260	 260	 260	 1.0142	 0.0	 1	 -30.0	 30.0;
	4149	 4151	 0.00316	 0.12484	 0.0	 246	 246	 246	 1.0142	 0.0	 1	 -30.0	 30.0;
	4166	 4167	 0.003081	 0.116543	 0.0	 275	 275	 275	 1.02145	 0.0	 1	 -30.0	 30.0;
	4166	 4167	 0.003022	 0.116938	 0.0	 274	 274	 274	 1.02145	 0.0	 1	 -30.0	 30.0;
	4172	 4173	 0.001778	 0.098765	 0.0	 309	 309	 309	 0.939847	 0.0	 1	 -30.0	 30.0;
	4174	 4175	 0.001333	 0.002667	 0.0	 10522	 10522	 10522	 0.964319	 0.0	 1	 -30.0	 30.0;
	4183	 4184	 0.001837	 0.114765	 0.0	 266	 266	 266	 0.986189	 0.0	 1	 -30.0	 30.0;
	4183	 4184	 0.001857	 0.114963	 0.0	 266	 266	 266	 0.96432	 0.0	 1	 -30.0	 30.0;
	4209	 4211	 0.003694	 0.123852	 0.0	 248	 248	 248	 0.963394	 0.0	 1	 -30.0	 30.0;
	4209	 4211	 0.004543	 0.16	 0.0	 192	 192	 192	 0.956938	 0.0	 1	 -30.0	 30.0;
	4212	 4213	 0.003358	 0.11121	 0.0	 275	 275	 275	 0.999001	 0.0	 1	 -30.0	 30.0;
	4212	 4213	 0.003812	 0.130963	 0.0	 233	 233	 233	 0.98912	 0.0	 1	 -30.0	 30.0;
	4218	 4220	 0.003042	 0.111407	 0.0	 277	 277	 277	 0.97561	 0.0	 1	 -30.0	 30.0;
	4219	 4220	 0.005965	 0.11121	 0.0	 277	 277	 277	 0.953289	 0.0	 1	 -30.0	 30.0;
	4219	 4220	 0.002963	 0.110815	 0.0	 279	 279	 279	 0.97561	 0.0	 1	 -30.0	 30.0;
	4218	 4220	 0.00397	 0.111605	 0.0	 277	 277	 277	 0.953289	 0.0	 1	 -30.0	 30.0;
	4220	 4221	 0.000291	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4226	 4223	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4228	 4229	 0.003121	 0.114765	 0.0	 269	 269	 269	 0.992064	 0.0	 1	 -30.0	 30.0;
	4227	 4229	 0.00316	 0.115358	 0.0	 268	 268	 268	 0.992064	 0.0	 1	 -30.0	 30.0;
	4244	 4245	 0.001758	 0.100543	 0.0	 304	 304	 304	 0.950567	 0.0	 1	 -30.0	 30.0;
	4250	 4272	 0.000171	 0.000313	 0.0003	 82782	 82782	 82782	 1.0	 6.48	 1	 -30.0	 30.0;
	4252	 4253	 0.003891	 0.112198	 0.0	 272	 272	 272	 0.999001	 0.0	 1	 -30.0	 30.0;
	4252	 4253	 0.003556	 0.124642	 0.0	 245	 245	 245	 0.999001	 0.0	 1	 -30.0	 30.0;
	4255	 4256	 0.003931	 0.125373	 0.0	 244	 244	 244	 1.012146	 0.0	 1	 -30.0	 30.0;
	4257	 4258	 0.001699	 0.122469	 0.0	 252	 252	 252	 0.98912	 0.0	 1	 -30.0	 30.0;
	4257	 4258	 0.001679	 0.122469	 0.0	 252	 252	 252	 0.98912	 0.0	 1	 -30.0	 30.0;
	4276	 5896	 0.013911	 0.133333	 0.0	 258	 258	 258	 1.0	 0.0	 1	 -30.0	 30.0;
	4277	 5896	 0.008933	 0.147111	 0.0	 236	 236	 236	 1.0	 0.0	 1	 -30.0	 30.0;
	4278	 5896	 0.0036	 0.008933	 0.0	 3573	 3573	 3573	 0.0	 0.0	 1	 -30.0	 30.0;
	4292	 4293	 0.004267	 0.238617	 0.0	 138	 138	 138	 1.035197	 0.0	 1	 -30.0	 30.0;
	4291	 4293	 0.004642	 0.22321	 0.0	 139	 139	 139	 0.956938	 0.0	 1	 -30.0	 30.0;
	4291	 4293	 0.004523	 0.216296	 0.0	 143	 143	 143	 0.956938	 0.0	 1	 -30.0	 30.0;
	4291	 4293	 0.00484	 0.237037	 0.0	 131	 131	 131	 0.956938	 0.0	 1	 -30.0	 30.0;
	5955	 4293	 0.000457	 -0.005194	 0.0	 557.0	 557.0	 557.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4293	 4294	 0.000796	 0.048199	 0.0	 557.0	 557.0	 557.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4294	 5955	 0.000242	 0.047438	 0.0	 557.0	 557.0	 557.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4295	 4296	 0.003911	 0.111407	 0.0	 274	 274	 274	 0.971818	 0.0	 1	 -30.0	 30.0;
	4305	 4306	 0.002331	 0.132741	 0.0	 233	 233	 233	 0.973708	 0.0	 1	 -30.0	 30.0;
	4312	 4313	 0.002015	 0.106667	 0.0	 286	 286	 286	 0.960618	 0.0	 1	 -30.0	 30.0;
	4312	 4314	 0.001363	 0.098528	 0.0	 310	 310	 310	 0.963387	 0.0	 1	 -30.0	 30.0;
	4325	 4326	 0.004741	 0.160593	 0.0	 192	 192	 192	 0.946073	 0.0	 1	 -30.0	 30.0;
	4331	 4334	 0.003338	 0.109037	 0.0	 283	 283	 283	 0.963394	 0.0	 1	 -30.0	 30.0;
	4332	 4334	 0.003042	 0.118519	 0.0	 261	 261	 261	 0.953289	 0.0	 1	 -30.0	 30.0;
	4332	 4333	 0.003694	 0.111407	 0.0	 277	 277	 277	 0.941619	 0.0	 1	 -30.0	 30.0;
	4331	 4333	 0.004089	 0.12484	 0.0	 248	 248	 248	 0.953289	 0.0	 1	 -30.0	 30.0;
	4343	 4345	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4342	 4345	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4341	 4345	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4344	 4345	 0.00316	 0.118321	 0.0	 258	 258	 258	 0.987167	 0.0	 1	 -30.0	 30.0;
	4344	 4345	 0.00324	 0.116543	 0.0	 262	 262	 262	 0.981351	 0.0	 1	 -30.0	 30.0;
	4348	 4349	 0.003753	 0.122074	 0.0	 254	 254	 254	 0.97561	 0.0	 1	 -30.0	 30.0;
	4348	 4349	 0.00399	 0.109235	 0.0	 284	 284	 284	 0.953289	 0.0	 1	 -30.0	 30.0;
	4348	 4349	 0.00399	 0.11121	 0.0	 279	 279	 279	 0.96432	 0.0	 1	 -30.0	 30.0;
	4357	 4355	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4389	 4390	 0.00318	 0.117333	 0.0	 263	 263	 263	 0.97561	 0.0	 1	 -30.0	 30.0;
	4389	 4390	 0.003338	 0.122469	 0.0	 252	 252	 252	 0.97561	 0.0	 1	 -30.0	 30.0;
	4391	 4393	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4398	 4399	 0.003595	 0.118716	 0.0	 260	 260	 260	 0.97561	 0.0	 1	 -30.0	 30.0;
	4398	 4399	 0.003753	 0.119309	 0.0	 259	 259	 259	 0.968054	 0.0	 1	 -30.0	 30.0;
	1496	 4407	 0.055185	 0.114444	 0.0052	 239	 239	 239	 1.0	 -0.9	 1	 -30.0	 30.0;
	4421	 4423	 0.003575	 0.123457	 0.0	 250	 250	 250	 0.997009	 0.0	 1	 -30.0	 30.0;
	4422	 4423	 0.003022	 0.117728	 0.0	 262	 262	 262	 0.985226	 0.0	 1	 -30.0	 30.0;
	4442	 4444	 0.003951	 0.12484	 0.0	 245	 245	 245	 0.96432	 0.0	 1	 -30.0	 30.0;
	4442	 4444	 0.003951	 0.12484	 0.0	 245	 245	 245	 0.957851	 0.0	 1	 -30.0	 30.0;
	4443	 4444	 0.003556	 0.127407	 0.0	 241	 241	 241	 1.012146	 0.0	 1	 -30.0	 30.0;
	4454	 4456	 0.003141	 0.117136	 0.0	 264	 264	 264	 0.98619	 0.0	 1	 -30.0	 30.0;
	4458	 4459	 0.003319	 0.108444	 0.0	 285	 285	 285	 0.968054	 0.0	 1	 -30.0	 30.0;
	4458	 4459	 0.003753	 0.124642	 0.0	 248	 248	 248	 0.968054	 0.0	 1	 -30.0	 30.0;
	4458	 4459	 0.003081	 0.116346	 0.0	 265	 265	 265	 0.968054	 0.0	 1	 -30.0	 30.0;
	4463	 4464	 0.004938	 0.161383	 0.0	 191	 191	 191	 0.990101	 0.0	 1	 -30.0	 30.0;
	4463	 4464	 0.004938	 0.163951	 0.0	 188	 188	 188	 1.001002	 0.0	 1	 -30.0	 30.0;
	4462	 4464	 0.004346	 0.118914	 0.0	 259	 259	 259	 0.989123	 0.0	 1	 -30.0	 30.0;
	4473	 4474	 0.004286	 0.164938	 0.0	 187	 187	 187	 0.968054	 0.0	 1	 -30.0	 30.0;
	4473	 4474	 0.007368	 0.229136	 0.0	 135	 135	 135	 0.968054	 0.0	 1	 -30.0	 30.0;
	4476	 4481	 0.012598	 0.428319	 0.0	 81	 81	 81	 1.001	 0.0	 1	 -30.0	 30.0;
	4480	 4485	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	4479	 4484	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	4478	 4483	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	4477	 4482	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	4499	 4501	 0.004356	 0.137467	 0.0	 228	 228	 228	 1.036269	 0.0	 1	 -30.0	 30.0;
	4500	 4501	 0.008711	 0.1592	 0.0	 196	 196	 196	 1.036269	 0.0	 1	 -30.0	 30.0;
	4502	 4503	 0.019652	 0.553288	 0.0	 63	 63	 63	 1.0	 0.0	 1	 -30.0	 30.0;
	4509	 4510	 0.002016	 0.079113	 0.0	 438	 438	 438	 1.0	 0.0	 1	 -30.0	 30.0;
	4514	 4515	 0.00397	 0.118123	 0.0	 261	 261	 261	 1.0	 0.0	 1	 -30.0	 30.0;
	4514	 4515	 0.003654	 0.146765	 0.0	 211	 211	 211	 0.97561	 0.0	 1	 -30.0	 30.0;
	4523	 4525	 0.003951	 0.12484	 0.0	 245	 245	 245	 0.978474	 0.0	 1	 -30.0	 30.0;
	4524	 4525	 0.00164	 0.118519	 0.0	 259	 259	 259	 1.007049	 0.0	 1	 -30.0	 30.0;
	4531	 4532	 0.000783	 0.042936	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4531	 4532	 0.000776	 0.043075	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4535	 4536	 0.068027	 0.942303	 0.0	 37	 37	 37	 0.550361	 0.0	 1	 -30.0	 30.0;
	4540	 4541	 0.021975	 0.446914	 0.0	 68	 68	 68	 1.027749	 0.0	 1	 -30.0	 30.0;
	4540	 4541	 0.021975	 0.446914	 0.0	 68	 68	 68	 1.027749	 0.0	 1	 -30.0	 30.0;
	4540	 4542	 0.003259	 0.119506	 0.0	 258	 258	 258	 0.98912	 0.0	 1	 -30.0	 30.0;
	4547	 5897	 0.000159	 -0.006025	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4547	 5920	 0.000229	 -0.004571	 0.0	 1174.0	 1174.0	 1174.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4547	 4548	 0.000332	 0.025623	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4548	 5897	 0.000173	 0.031163	 0.0	 1099	 1099	 1099	 0.0	 0.0	 1	 -30.0	 30.0;
	4548	 5920	 9e-05	 0.029363	 0.0	 1166	 1166	 1166	 0.0	 0.0	 1	 -30.0	 30.0;
	4555	 4556	 0.001222	 0.132	 0.0	 238	 238	 238	 0.971818	 0.0	 1	 -30.0	 30.0;
	4555	 4557	 0.003911	 0.12484	 0.0	 247	 247	 247	 0.978474	 0.0	 1	 -30.0	 30.0;
	4556	 4557	 0.003186	 0.137758	 0.0	 229	 229	 229	 0.987167	 0.0	 1	 -30.0	 30.0;
	4569	 4570	 0.000996	 0.10831	 0.0	 293	 293	 293	 0.984249	 0.0	 1	 -30.0	 30.0;
	4572	 4574	 0.000686	 0.047922	 0.0	 606.0	 606.0	 606.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4573	 4574	 0.000325	 0.027493	 0.0	 1148	 1148	 1148	 1.0	 0.0	 1	 -30.0	 30.0;
	4573	 4574	 0.000325	 0.027493	 0.0	 1148	 1148	 1148	 1.0	 0.0	 1	 -30.0	 30.0;
	4592	 4594	 0.001835	 0.101524	 0.0	 312	 312	 312	 1.013171	 0.0	 1	 -30.0	 30.0;
	4592	 4593	 0.001828	 0.102078	 0.0	 310	 310	 310	 0.994033	 0.0	 1	 -30.0	 30.0;
	4595	 4596	 0.00397	 0.125235	 0.0	 244	 244	 244	 1.02459	 0.0	 1	 -30.0	 30.0;
	4595	 4596	 0.00397	 0.125235	 0.0	 244	 244	 244	 1.02459	 0.0	 1	 -30.0	 30.0;
	4598	 4599	 0.000319	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	4598	 4600	 0.000339	 0.029778	 0.0	 1065	 1065	 1065	 1.0	 0.0	 1	 -30.0	 30.0;
	4607	 4608	 0.001244	 0.137877	 0.0	 222	 222	 222	 0.973708	 0.0	 1	 -30.0	 30.0;
	4607	 4608	 0.000731	 0.153284	 0.0	 199	 199	 199	 0.973708	 0.0	 1	 -30.0	 30.0;
	4607	 4608	 0.001244	 0.137284	 0.0	 223	 223	 223	 0.975614	 0.0	 1	 -30.0	 30.0;
	4615	 4616	 0.003081	 0.115556	 0.0	 271	 271	 271	 1.012146	 0.0	 1	 -30.0	 30.0;
	4615	 4616	 0.003081	 0.115556	 0.0	 271	 271	 271	 1.012146	 0.0	 1	 -30.0	 30.0;
	4636	 4638	 0.001752	 0.102285	 0.0	 310	 310	 310	 0.974656	 0.0	 1	 -30.0	 30.0;
	4636	 4637	 0.001752	 0.102285	 0.0	 310	 310	 310	 0.984249	 0.0	 1	 -30.0	 30.0;
	4646	 4647	 0.003068	 0.155609	 0.0	 204	 204	 204	 0.984249	 0.0	 1	 -30.0	 30.0;
	4646	 4647	 0.001364	 0.100069	 0.0	 317	 317	 317	 0.974656	 0.0	 1	 -30.0	 30.0;
	4646	 4647	 0.003061	 0.156163	 0.0	 203	 203	 203	 0.974656	 0.0	 1	 -30.0	 30.0;
	4649	 4651	 0.003931	 0.124247	 0.0	 249	 249	 249	 0.96432	 0.0	 1	 -30.0	 30.0;
	4649	 4650	 0.003101	 0.124642	 0.0	 248	 248	 248	 0.96432	 0.0	 1	 -30.0	 30.0;
	4660	 5940	 0.00018	 -0.007687	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4660	 5949	 0.000125	 -0.007618	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4661	 5940	 0.000166	 0.035111	 0.0	 976	 976	 976	 0.0	 0.0	 1	 -30.0	 30.0;
	4661	 5949	 0.000201	 0.034834	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	4672	 4673	 0.002016	 0.004031	 0.0	 7637	 7637	 7637	 1.0	 0.0	 1	 -30.0	 30.0;
	4671	 4674	 0.002016	 0.004031	 0.0	 7637	 7637	 7637	 1.0	 0.0	 1	 -30.0	 30.0;
	4675	 4676	 0.001857	 0.121086	 0.0	 252	 252	 252	 0.97561	 0.0	 1	 -30.0	 30.0;
	4675	 4676	 0.003773	 0.122667	 0.0	 249	 249	 249	 0.974664	 0.0	 1	 -30.0	 30.0;
	4675	 4676	 0.001857	 0.121086	 0.0	 252	 252	 252	 0.97561	 0.0	 1	 -30.0	 30.0;
	4676	 4677	 6.2e-05	 0.031787	 0.0	 993	 993	 993	 1.0	 0.0	 1	 -30.0	 30.0;
	4676	 4677	 6.2e-05	 0.031856	 0.0	 991	 991	 991	 1.0	 0.0	 1	 -30.0	 30.0;
	4681	 4683	 0.003556	 0.112	 0.0	 273	 273	 273	 0.974664	 0.0	 1	 -30.0	 30.0;
	4681	 4683	 0.003556	 0.118519	 0.0	 258	 258	 258	 0.974664	 0.0	 1	 -30.0	 30.0;
	4681	 4683	 0.003615	 0.113185	 0.0	 270	 270	 270	 0.974664	 0.0	 1	 -30.0	 30.0;
	4681	 4683	 0.003674	 0.123062	 0.0	 248	 248	 248	 0.97561	 0.0	 1	 -30.0	 30.0;
	4688	 4689	 0.00316	 0.125432	 0.0	 245	 245	 245	 1.026695	 0.0	 1	 -30.0	 30.0;
	4688	 4689	 0.003951	 0.112988	 0.0	 272	 272	 272	 1.026695	 0.0	 1	 -30.0	 30.0;
	4712	 4713	 0.000208	 0.016413	 0.0	 1769.0	 1769.0	 1769.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	4711	 4713	 0.000208	 0.014751	 0.0	 1746.0	 1746.0	 1746.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	4710	 4713	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	4709	 4713	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	4708	 4713	 0.000208	 0.016413	 0.0	 1769.0	 1769.0	 1769.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	4707	 4713	 0.000208	 0.016413	 0.0	 1769.0	 1769.0	 1769.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	4706	 4713	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	4705	 4713	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	4704	 4713	 0.000319	 0.024307	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4720	 4721	 0.003121	 0.125827	 0.0	 245	 245	 245	 1.049318	 0.0	 1	 -30.0	 30.0;
	4720	 4721	 0.003852	 0.126815	 0.0	 244	 244	 244	 1.023541	 0.0	 1	 -30.0	 30.0;
	4742	 4743	 0.001975	 0.126025	 0.0	 242	 242	 242	 0.974664	 0.0	 1	 -30.0	 30.0;
	4742	 4743	 0.001956	 0.125037	 0.0	 244	 244	 244	 0.974664	 0.0	 1	 -30.0	 30.0;
	4742	 4743	 0.001956	 0.125037	 0.0	 244	 244	 244	 0.974664	 0.0	 1	 -30.0	 30.0;
	4744	 4745	 0.005057	 0.160988	 0.0	 194	 194	 194	 0.933709	 0.0	 1	 -30.0	 30.0;
	4744	 4745	 0.005057	 0.160988	 0.0	 194	 194	 194	 0.933709	 0.0	 1	 -30.0	 30.0;
	4765	 4766	 0.017333	 0.441333	 0.0	 69	 69	 69	 0.971818	 0.0	 1	 -30.0	 30.0;
	4772	 4773	 0.004247	 0.159407	 0.0	 192	 192	 192	 0.959693	 0.0	 1	 -30.0	 30.0;
	4771	 5898	 0.004217	 0.223476	 0.0	 155	 155	 155	 1.0	 0.0	 1	 -30.0	 30.0;
	4773	 5898	 0.000699	 -0.004709	 0.0	 654.0	 654.0	 654.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4773	 4774	 0.000686	 0.048546	 0.0	 650	 650	 650	 0.996016	 0.0	 1	 -30.0	 30.0;
	4774	 5898	 1.4e-05	 0.052839	 0.0	 649	 649	 649	 0.0	 0.0	 1	 -30.0	 30.0;
	4778	 4779	 0.00316	 0.125235	 0.0	 246	 246	 246	 1.002005	 0.0	 1	 -30.0	 30.0;
	4778	 4779	 0.001675	 0.121284	 0.0	 254	 254	 254	 0.990104	 0.0	 1	 -30.0	 30.0;
	4782	 4783	 0.003812	 0.120099	 0.0	 256	 256	 256	 0.96432	 0.0	 1	 -30.0	 30.0;
	4802	 4803	 0.003556	 0.118519	 0.0	 262	 262	 262	 0.946073	 0.0	 1	 -30.0	 30.0;
	4802	 4803	 0.003279	 0.113185	 0.0	 274	 274	 274	 0.95329	 0.0	 1	 -30.0	 30.0;
	4808	 4810	 0.001679	 0.099753	 0.0	 306	 306	 306	 0.961535	 0.0	 1	 -30.0	 30.0;
	4808	 4810	 0.001659	 0.099556	 0.0	 307	 307	 307	 0.950567	 0.0	 1	 -30.0	 30.0;
	4819	 4821	 0.002016	 0.079113	 0.0	 438	 438	 438	 1.0	 0.0	 1	 -30.0	 30.0;
	4818	 4820	 0.002016	 0.079113	 0.0	 438	 438	 438	 1.0	 0.0	 1	 -30.0	 30.0;
	4824	 4826	 0.002431	 0.093428	 0.0	 367	 367	 367	 1.0	 0.0	 1	 -30.0	 30.0;
	4825	 4826	 0.008906	 0.093352	 0.0	 366	 366	 366	 1.0	 0.0	 1	 -30.0	 30.0;
	4827	 4829	 0.003062	 0.115951	 0.0	 266	 266	 266	 0.997009	 0.0	 1	 -30.0	 30.0;
	4827	 4828	 0.004267	 0.15763	 0.0	 196	 196	 196	 1.043841	 0.0	 1	 -30.0	 30.0;
	4827	 4828	 0.003101	 0.117531	 0.0	 263	 263	 263	 0.985226	 0.0	 1	 -30.0	 30.0;
	4827	 4828	 0.003615	 0.121284	 0.0	 254	 254	 254	 0.985226	 0.0	 1	 -30.0	 30.0;
	4829	 4830	 0.000339	 0.027008	 0.0	 1174	 1174	 1174	 1.0	 0.0	 1	 -30.0	 30.0;
	4828	 4830	 0.000395	 0.027216	 0.0	 1165	 1165	 1165	 1.0	 0.0	 1	 -30.0	 30.0;
	4828	 4830	 0.000325	 0.027632	 0.0	 1148	 1148	 1148	 1.0	 0.0	 1	 -30.0	 30.0;
	4847	 4848	 0.00316	 0.110617	 0.0	 278	 278	 278	 1.001002	 0.0	 1	 -30.0	 30.0;
	4847	 4848	 0.00316	 0.118519	 0.0	 260	 260	 260	 1.001002	 0.0	 1	 -30.0	 30.0;
	4852	 4853	 0.005136	 0.160988	 0.0	 194	 194	 194	 0.872599	 0.0	 1	 -30.0	 30.0;
	4857	 4858	 0.001975	 0.165926	 0.0	 186	 186	 186	 1.00705	 0.0	 1	 -30.0	 30.0;
	4857	 4858	 0.003002	 0.173235	 0.0	 178	 178	 178	 0.968059	 0.0	 1	 -30.0	 30.0;
	4858	 4859	 0.000332	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4858	 5921	 0.000229	 -0.004363	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4859	 5921	 9.7e-05	 0.029155	 0.0	 1175	 1175	 1175	 0.0	 0.0	 1	 -30.0	 30.0;
	4862	 4863	 0.003911	 0.124642	 0.0	 248	 248	 248	 0.952386	 0.0	 1	 -30.0	 30.0;
	4862	 4863	 0.003951	 0.124247	 0.0	 249	 249	 249	 0.952386	 0.0	 1	 -30.0	 30.0;
	4862	 4863	 0.003556	 0.126222	 0.0	 245	 245	 245	 0.952386	 0.0	 1	 -30.0	 30.0;
	4880	 4881	 0.003516	 0.122667	 0.0	 249	 249	 249	 0.973708	 0.0	 1	 -30.0	 30.0;
	4880	 4881	 0.003062	 0.116741	 0.0	 262	 262	 262	 0.973708	 0.0	 1	 -30.0	 30.0;
	4884	 4885	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4884	 4885	 0.000319	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4900	 4902	 0.003062	 0.12484	 0.0	 248	 248	 248	 0.955109	 0.0	 1	 -30.0	 30.0;
	4900	 4901	 0.003121	 0.12484	 0.0	 247	 247	 247	 0.96432	 0.0	 1	 -30.0	 30.0;
	4901	 4903	 0.000803	 0.039335	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4902	 4903	 0.000325	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4901	 4903	 0.000796	 0.039266	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4907	 4909	 0.000305	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4915	 4917	 0.005037	 0.159012	 0.0	 194	 194	 194	 0.968054	 0.0	 1	 -30.0	 30.0;
	4914	 4917	 0.004523	 0.156049	 0.0	 198	 198	 198	 0.968054	 0.0	 1	 -30.0	 30.0;
	4915	 4917	 0.004919	 0.159012	 0.0	 194	 194	 194	 0.978474	 0.0	 1	 -30.0	 30.0;
	4916	 4917	 0.002212	 0.125432	 0.0	 251	 251	 251	 0.928505	 0.0	 1	 -30.0	 30.0;
	4917	 4918	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4917	 4918	 0.000325	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4921	 4922	 0.003002	 0.118716	 0.0	 257	 257	 257	 0.978474	 0.0	 1	 -30.0	 30.0;
	4921	 4922	 0.003002	 0.118716	 0.0	 257	 257	 257	 1.0	 0.0	 1	 -30.0	 30.0;
	4926	 4927	 0.003121	 0.12563	 0.0	 243	 243	 243	 1.011122	 0.0	 1	 -30.0	 30.0;
	4926	 4927	 0.003951	 0.125235	 0.0	 244	 244	 244	 0.999001	 0.0	 1	 -30.0	 30.0;
	4926	 4927	 0.003121	 0.12563	 0.0	 243	 243	 243	 0.999001	 0.0	 1	 -30.0	 30.0;
	4940	 4941	 0.003378	 0.121481	 0.0	 254	 254	 254	 0.974664	 0.0	 1	 -30.0	 30.0;
	4956	 4958	 0.00316	 0.11516	 0.0	 268	 268	 268	 0.992064	 0.0	 1	 -30.0	 30.0;
	4956	 4958	 0.003595	 0.120889	 0.0	 255	 255	 255	 1.029866	 0.0	 1	 -30.0	 30.0;
	4955	 5950	 0.001766	 0.09169	 0.0	 377	 377	 377	 1.0	 0.0	 1	 -30.0	 30.0;
	4954	 5956	 0.001821	 0.088227	 0.0	 392	 392	 392	 1.0	 0.0	 1	 -30.0	 30.0;
	4957	 5899	 0.00027	 -0.005332	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4957	 5922	 0.000249	 -0.005471	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4958	 5941	 0.000125	 -0.007687	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4957	 5950	 0.000173	 -0.007895	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4957	 5956	 0.000132	 -0.010942	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4959	 5899	 5.5e-05	 0.032756	 0.0	 1046	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 5922	 6.9e-05	 0.032895	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 5941	 0.000201	 0.034834	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 5950	 0.000166	 0.034834	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 5956	 0.000208	 0.038643	 0.0	 886	 886	 886	 0.0	 0.0	 1	 -30.0	 30.0;
	4960	 4962	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4961	 4962	 0.004207	 0.160988	 0.0	 190	 190	 190	 1.0	 0.0	 1	 -30.0	 30.0;
	4961	 4962	 0.004227	 0.159012	 0.0	 192	 192	 192	 0.98912	 0.0	 1	 -30.0	 30.0;
	4961	 4962	 0.003516	 0.121086	 0.0	 253	 253	 253	 1.009082	 0.0	 1	 -30.0	 30.0;
	4967	 4969	 0.001925	 0.101801	 0.0	 310	 310	 310	 0.939851	 0.0	 1	 -30.0	 30.0;
	4967	 4968	 0.001835	 0.101177	 0.0	 311	 311	 311	 0.956942	 0.0	 1	 -30.0	 30.0;
	4973	 4975	 0.001956	 0.126025	 0.0	 244	 244	 244	 0.97561	 0.0	 1	 -30.0	 30.0;
	4974	 4975	 0.001956	 0.125037	 0.0	 246	 246	 246	 0.97561	 0.0	 1	 -30.0	 30.0;
	4976	 5923	 0.000145	 -0.011288	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4975	 4977	 0.000319	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	4976	 5951	 0.000291	 -0.00554	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4975	 4977	 0.000693	 0.048615	 0.0	 605.0	 605.0	 605.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4975	 5957	 0.000471	 -0.005263	 0.0	 605.0	 605.0	 605.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4977	 5923	 0.000187	 0.038712	 0.0	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	4977	 5951	 2.8e-05	 0.032895	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	4977	 5957	 0.000235	 0.053324	 0.0	 605.0	 605.0	 605.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4981	 4982	 0.004563	 0.160988	 0.0	 192	 192	 192	 0.978477	 0.0	 1	 -30.0	 30.0;
	4981	 4982	 0.00721	 0.231704	 0.0	 134	 134	 134	 0.956935	 0.0	 1	 -30.0	 30.0;
	4986	 4989	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	4985	 4988	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	4984	 4987	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	4990	 4992	 0.003378	 0.121481	 0.0	 254	 254	 254	 0.964319	 0.0	 1	 -30.0	 30.0;
	4994	 4995	 0.003378	 0.121936	 0.0	 253	 253	 253	 0.942507	 0.0	 1	 -30.0	 30.0;
	4998	 4999	 0.001975	 0.115951	 0.0	 265	 265	 265	 1.040584	 0.0	 1	 -30.0	 30.0;
	5000	 5001	 0.001817	 0.118716	 0.0	 259	 259	 259	 1.0142	 0.0	 1	 -30.0	 30.0;
	5005	 5006	 0.003358	 0.12563	 0.0	 245	 245	 245	 0.989123	 0.0	 1	 -30.0	 30.0;
	5005	 5006	 0.00316	 0.116938	 0.0	 263	 263	 263	 0.976559	 0.0	 1	 -30.0	 30.0;
	5034	 5035	 0.003536	 0.12563	 0.0	 245	 245	 245	 0.953289	 0.0	 1	 -30.0	 30.0;
	5052	 5053	 0.001679	 0.089482	 0.0	 341	 341	 341	 1.006036	 0.0	 1	 -30.0	 30.0;
	5062	 5064	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5062	 5063	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5061	 5063	 0.000339	 0.024446	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5061	 5064	 0.000332	 0.025069	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5070	 5071	 0.000346	 0.025346	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5070	 5071	 0.000332	 0.025208	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5078	 5079	 0.003042	 0.118321	 0.0	 261	 261	 261	 0.997009	 0.0	 1	 -30.0	 30.0;
	5085	 5086	 0.000325	 0.027701	 0.0	 1145	 1145	 1145	 1.0	 0.0	 1	 -30.0	 30.0;
	5966	 5967	 0.000694	 0.05125	 0.0	 674	 674	 674	 1.035197	 0.0	 1	 -30.0	 30.0;
	5965	 5967	 0.000631	 0.05	 0.0	 691	 691	 691	 0.974659	 0.0	 1	 -30.0	 30.0;
	5972	 5973	 0.0006	 0.028981	 0.0	 1192	 1192	 1192	 0.980392	 0.0	 1	 -30.0	 30.0;
	5974	 5975	 0.000419	 0.025313	 0.0	 1364	 1364	 1364	 1.001	 0.0	 1	 -30.0	 30.0;
	5981	 5982	 0.000212	 0.018819	 0.0	 599.0	 599.0	 599.0	 0.929366	 0.0	 1	 -30.0	 30.0;
	5984	 5986	 0.000403	 0.025619	 0.0	 1348	 1348	 1348	 1.001	 0.0	 1	 -30.0	 30.0;
	5985	 5986	 0.000403	 0.025619	 0.0	 1348	 1348	 1348	 1.001	 0.0	 1	 -30.0	 30.0;
	6001	 6198	 0.003714	 0.012701	 0.0	 425.0	 425.0	 425.0	 1.0	 -16.6	 1	 -30.0	 30.0;
	6199	 6004	 0.000125	 0.003125	 0.0	 11039	 11039	 11039	 1.04384	 0.0	 1	 -30.0	 30.0;
	6003	 6199	 0.000198	 0.004938	 0.0	 6986	 6986	 6986	 1.126727	 -6.75	 1	 -30.0	 30.0;
	6022	 6024	 6.8e-05	 0.01825	 0.0	 1892	 1892	 1892	 0.989122	 0.0	 1	 -30.0	 30.0;
	6023	 6025	 0.000151	 0.017549	 0.0	 1968	 1968	 1968	 0.989122	 0.0	 1	 -30.0	 30.0;
	6035	 6036	 9.3e-05	 0.01825	 0.0	 1892	 1892	 1892	 1.004018	 0.0	 1	 -30.0	 30.0;
	6040	 6042	 0.0004	 0.03	 0.0	 1151	 1151	 1151	 0.971818	 0.0	 1	 -30.0	 30.0;
	6200	 6041	 0.000119	 0.013827	 0.0	 599.0	 599.0	 599.0	 1.0	 -2.9	 1	 -30.0	 30.0;
	6058	 6059	 0.000139	 0.013299	 0.0	 2596	 2596	 2596	 1.013171	 0.0	 1	 -30.0	 30.0;
	6062	 6065	 0.000719	 0.04375	 0.0	 790	 790	 790	 1.033058	 0.0	 1	 -30.0	 30.0;
	6063	 6064	 0.000719	 0.04375	 0.0	 790	 790	 790	 0.975614	 0.0	 1	 -30.0	 30.0;
	6068	 6070	 0.000125	 0.046125	 0.0	 749	 749	 749	 1.0142	 0.0	 1	 -30.0	 30.0;
	6069	 6070	 0.000125	 0.046125	 0.0	 749	 749	 749	 1.0142	 0.0	 1	 -30.0	 30.0;
	6072	 6201	 4.4e-05	 0.001063	 0.0	 1935.0	 1935.0	 1935.0	 1.0	 1.91	 1	 -30.0	 30.0;
	6074	 6075	 0.0006	 0.030687	 0.0	 1125	 1125	 1125	 0.980393	 0.0	 1	 -30.0	 30.0;
	6074	 6075	 0.000381	 0.026838	 0.0	 1287	 1287	 1287	 0.971819	 0.0	 1	 -30.0	 30.0;
	6082	 6083	 0.0005	 0.03015	 0.0	 1145	 1145	 1145	 0.980392	 0.0	 1	 -30.0	 30.0;
	6086	 6087	 0.0006	 0.030081	 0.0	 1148	 1148	 1148	 0.932835	 0.0	 1	 -30.0	 30.0;
	6086	 6087	 0.0005	 0.026231	 0.0	 1316	 1316	 1316	 0.980393	 0.0	 1	 -30.0	 30.0;
	6094	 6096	 0.000136	 0.015151	 0.0	 2279	 2279	 2279	 0.949669	 0.0	 1	 -30.0	 30.0;
	6099	 6101	 0.000313	 0.01875	 0.0	 1842	 1842	 1842	 0.990095	 0.0	 1	 -30.0	 30.0;
	6106	 6107	 0.0003	 0.027769	 0.0	 1244	 1244	 1244	 0.971821	 0.0	 1	 -30.0	 30.0;
	6203	 6120	 2.7e-05	 0.009838	 0.0	 999.0	 999.0	 999.0	 0.950029	 0.0	 1	 -30.0	 30.0;
	6202	 6120	 2.7e-05	 0.009838	 0.0	 999.0	 999.0	 999.0	 0.950029	 0.0	 1	 -30.0	 30.0;
	6122	 6123	 0.0004	 0.044413	 0.0	 778	 778	 778	 0.92937	 0.0	 1	 -30.0	 30.0;
	6204	 6129	 0.000119	 0.014321	 0.0	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6136	 6137	 0.0002	 0.0188	 0.0	 1837	 1837	 1837	 0.939853	 0.0	 1	 -30.0	 30.0;
	6150	 6151	 0.000731	 0.045162	 0.0	 765	 765	 765	 0.947864	 0.0	 1	 -30.0	 30.0;
	6150	 6151	 0.000731	 0.045231	 0.0	 764	 764	 764	 0.94877	 0.0	 1	 -30.0	 30.0;
	6154	 6155	 0.0003	 0.022881	 0.0	 1509	 1509	 1509	 0.978474	 0.0	 1	 -30.0	 30.0;
	6174	 6175	 0.000338	 0.020438	 0.0	 1689	 1689	 1689	 0.971821	 0.0	 1	 -30.0	 30.0;
	6205	 6175	 6.2e-05	 0.00675	 0.0	 1629.0	 1629.0	 1629.0	 1.133606	 -15.01	 1	 -30.0	 30.0;
	6180	 6181	 0.000554	 0.031524	 0.0	 1096	 1096	 1096	 0.961538	 0.0	 1	 -30.0	 30.0;
	6184	 6185	 0.0004	 0.025687	 0.0	 1344	 1344	 1344	 0.938964	 0.0	 1	 -30.0	 30.0;
	6184	 6185	 0.0003	 0.025487	 0.0	 1355	 1355	 1355	 0.955109	 0.0	 1	 -30.0	 30.0;
	6184	 6185	 0.0004	 0.025413	 0.0	 1359	 1359	 1359	 0.932835	 0.0	 1	 -30.0	 30.0;
	6186	 6187	 0.0005	 0.02805	 0.0	 1231	 1231	 1231	 0.980392	 0.0	 1	 -30.0	 30.0;
	6128	 6204	 2.1e-05	 0.016116	 0.0	 399.0	 399.0	 399.0	 1.012146	 0.0	 1	 -30.0	 30.0;
	6211	 6212	 0.00055	 0.04302	 0.0	 803	 803	 803	 0.990093	 0.0	 1	 -30.0	 30.0;
	6207	 6221	 6e-06	 0.000625	 0.0	 55237	 55237	 55237	 0.97561	 0.0	 1	 -30.0	 30.0;
	6207	 6220	 0.000632	 0.015684	 0.0	 2200	 2200	 2200	 1.014351	 1.32	 1	 -30.0	 30.0;
	6225	 6208	 7.5e-05	 0.007931	 0.0	 1399.0	 1399.0	 1399.0	 1.0	 -2.93	 1	 -30.0	 30.0;
	6224	 6209	 7.5e-05	 0.007931	 0.0	 1399.0	 1399.0	 1399.0	 1.0	 -2.93	 1	 -30.0	 30.0;
	6230	 6231	 0.000181	 0.01425	 0.0	 1866.0	 1866.0	 1866.0	 0.991083	 0.0	 1	 -30.0	 30.0;
	6233	 6234	 0.0012	 0.08215	 0.0	 421	 421	 421	 0.971818	 0.0	 1	 -30.0	 30.0;
	6233	 6234	 0.000397	 0.049841	 0.0	 693	 693	 693	 0.995025	 0.0	 1	 -30.0	 30.0;
	6233	 6234	 0.0002	 0.018669	 0.0	 1850	 1850	 1850	 0.956943	 0.0	 1	 -30.0	 30.0;
	6235	 6236	 0.000312	 0.028362	 0.0	 399.0	 399.0	 399.0	 0.97182	 0.0	 1	 -30.0	 30.0;
	6245	 6246	 0.000125	 0.026499	 0.0	 1303	 1303	 1303	 1.0142	 0.0	 1	 -30.0	 30.0;
	6243	 6246	 0.000125	 0.026499	 0.0	 1303	 1303	 1303	 1.0142	 0.0	 1	 -30.0	 30.0;
	6244	 6246	 0.000125	 0.026499	 0.0	 1303	 1303	 1303	 1.0142	 0.0	 1	 -30.0	 30.0;
	6242	 6246	 0.000125	 0.026499	 0.0	 1303	 1303	 1303	 1.0142	 0.0	 1	 -30.0	 30.0;
	6247	 6248	 0.00015	 0.023481	 0.0	 1471	 1471	 1471	 0.971817	 0.0	 1	 -30.0	 30.0;
	6247	 6248	 0.000287	 0.026931	 0.0	 1282	 1282	 1282	 0.971817	 0.0	 1	 -30.0	 30.0;
	6253	 6210	 3.8e-05	 0.00375	 0.0	 1399.0	 1399.0	 1399.0	 1.0	 5.86	 1	 -30.0	 30.0;
	115	 6256	 0.0	 0.019737	 0.0	 1735	 1735	 1735	 1.092105	 0.0	 1	 -30.0	 30.0;
	116	 6257	 0.0	 0.019737	 0.0	 1735	 1735	 1735	 1.092105	 0.0	 1	 -30.0	 30.0;
	202	 6258	 0.0	 0.54184	 0.0	 64	 64	 64	 1.044444	 0.0	 1	 -30.0	 30.0;
	232	 6259	 0.0	 0.142857	 0.0	 241	 241	 241	 1.111111	 0.0	 1	 -30.0	 30.0;
	232	 6260	 0.0	 0.219149	 0.0	 157	 157	 157	 1.111111	 0.0	 1	 -30.0	 30.0;
	273	 6261	 0.0	 0.366794	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	273	 6262	 0.0	 0.366794	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	272	 6263	 0.0	 0.366794	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	272	 6264	 0.0	 0.366794	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	368	 6265	 0.0	 0.128409	 0.0	 268	 268	 268	 1.048889	 0.0	 1	 -30.0	 30.0;
	368	 6266	 0.0	 0.128409	 0.0	 268	 268	 268	 1.048889	 0.0	 1	 -30.0	 30.0;
	369	 6267	 0.0	 0.15	 0.0	 229	 229	 229	 1.060526	 0.0	 1	 -30.0	 30.0;
	369	 6268	 0.0	 0.15	 0.0	 229	 229	 229	 1.060526	 0.0	 1	 -30.0	 30.0;
	370	 6269	 0.0	 0.15	 0.0	 229	 229	 229	 1.060526	 0.0	 1	 -30.0	 30.0;
	370	 6270	 0.0	 0.15	 0.0	 229	 229	 229	 1.060526	 0.0	 1	 -30.0	 30.0;
	495	 6271	 0.0	 0.012611	 0.0	 1082.0	 1082.0	 1082.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	496	 6272	 0.0	 0.012611	 0.0	 1133.0	 1133.0	 1133.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	497	 6273	 0.0	 0.012611	 0.0	 1129.0	 1129.0	 1129.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	498	 6274	 0.0	 0.012611	 0.0	 1082.0	 1082.0	 1082.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	501	 6276	 0.0	 0.048207	 0.0	 263.0	 263.0	 263.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	500	 6277	 0.0	 0.048207	 0.0	 264.0	 264.0	 264.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	502	 6278	 0.0	 0.043965	 0.0	 254.0	 254.0	 254.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	502	 6279	 0.0	 0.03442	 0.0	 995	 995	 995	 1.060526	 0.0	 1	 -30.0	 30.0;
	502	 6280	 0.0	 0.06506	 0.0	 527	 527	 527	 1.060526	 0.0	 1	 -30.0	 30.0;
	526	 6281	 0.0	 0.161429	 0.0	 213	 213	 213	 1.054667	 0.0	 1	 -30.0	 30.0;
	526	 6282	 0.0	 0.17931	 0.0	 192	 192	 192	 1.054667	 0.0	 1	 -30.0	 30.0;
	526	 6283	 0.0	 0.161429	 0.0	 213	 213	 213	 1.054667	 0.0	 1	 -30.0	 30.0;
	526	 6284	 0.0	 0.17931	 0.0	 192	 192	 192	 1.054667	 0.0	 1	 -30.0	 30.0;
	526	 6285	 0.0	 0.17931	 0.0	 192	 192	 192	 1.054667	 0.0	 1	 -30.0	 30.0;
	2798	 6286	 0.0	 0.044965	 0.0	 764	 764	 764	 1.080978	 0.0	 1	 -30.0	 30.0;
	622	 6287	 0.0	 0.33346	 0.0	 104	 104	 104	 0.985494	 0.0	 1	 -30.0	 30.0;
	623	 6288	 0.0	 0.166743	 0.0	 206	 206	 206	 1.026879	 0.0	 1	 -30.0	 30.0;
	623	 6289	 0.0	 0.300114	 0.0	 115	 115	 115	 1.020096	 0.0	 1	 -30.0	 30.0;
	666	 6290	 0.0	 0.012685	 0.0	 1087.0	 1087.0	 1087.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	665	 6291	 0.0	 0.012685	 0.0	 1078.0	 1078.0	 1078.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	664	 6292	 0.0	 0.012685	 0.0	 1065.0	 1065.0	 1065.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	663	 6293	 0.0	 0.012685	 0.0	 1019.0	 1019.0	 1019.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	684	 6294	 0.0	 0.009303	 0.0	 1481.0	 1481.0	 1481.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	686	 6295	 0.0	 0.009303	 0.0	 1481.0	 1481.0	 1481.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	693	 6296	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	693	 6297	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	693	 6298	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	692	 6299	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	692	 6300	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	692	 6301	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	714	 6302	 0.0	 0.453182	 0.0	 76	 76	 76	 1.088889	 0.0	 1	 -30.0	 30.0;
	714	 6303	 0.0	 0.453182	 0.0	 76	 76	 76	 1.088889	 0.0	 1	 -30.0	 30.0;
	895	 6304	 0.0	 0.008909	 0.0	 1539.0	 1539.0	 1539.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	897	 6305	 0.0	 0.008909	 0.0	 1483.0	 1483.0	 1483.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	898	 6306	 0.0	 0.008909	 0.0	 1511.0	 1511.0	 1511.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1006	 6307	 0.0	 0.133372	 0.0	 258	 258	 258	 1.043111	 0.0	 1	 -30.0	 30.0;
	1046	 6308	 0.0	 0.048207	 0.0	 713	 713	 713	 1.080978	 0.0	 1	 -30.0	 30.0;
	1056	 6309	 0.0	 0.012685	 0.0	 1083.0	 1083.0	 1083.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1060	 6311	 0.0	 0.012611	 0.0	 1096.0	 1096.0	 1096.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1059	 6312	 0.0	 0.012611	 0.0	 1094.0	 1094.0	 1094.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1065	 6313	 0.0	 0.009257	 0.0	 1844.0	 1844.0	 1844.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1066	 6314	 0.0	 0.009257	 0.0	 1850.0	 1850.0	 1850.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1080	 6315	 0.0	 0.009257	 0.0	 1799.0	 1799.0	 1799.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	1079	 6316	 0.0	 0.009257	 0.0	 1746.0	 1746.0	 1746.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	73	 6317	 0.0	 0.06579	 0.0	 522	 522	 522	 1.096667	 0.0	 1	 -30.0	 30.0;
	72	 6318	 0.0	 0.06579	 0.0	 522	 522	 522	 1.096667	 0.0	 1	 -30.0	 30.0;
	2106	 6319	 0.0	 0.1	 0.0	 344	 344	 344	 1.057778	 0.0	 1	 -30.0	 30.0;
	1175	 6320	 0.0	 0.01954	 0.0	 1759	 1759	 1759	 1.088844	 0.0	 1	 -30.0	 30.0;
	1176	 6321	 0.0	 0.020227	 0.0	 641.0	 641.0	 641.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	1177	 6322	 0.0	 0.01954	 0.0	 640.0	 640.0	 640.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	1178	 6324	 0.0	 0.021576	 0.0	 1588	 1588	 1588	 1.092105	 0.0	 1	 -30.0	 30.0;
	1444	 6325	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1444	 6326	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1444	 6327	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1444	 6328	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1444	 6329	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1444	 6330	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1299	 6331	 0.0	 0.012685	 0.0	 1109.0	 1109.0	 1109.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1296	 6332	 0.0	 0.012685	 0.0	 1127.0	 1127.0	 1127.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1298	 6333	 0.0	 0.012611	 0.0	 1131.0	 1131.0	 1131.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1297	 6334	 0.0	 0.012611	 0.0	 1089.0	 1089.0	 1089.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1339	 6335	 0.0	 0.181818	 0.0	 189	 189	 189	 1.044444	 0.0	 1	 -30.0	 30.0;
	1339	 6336	 0.0	 0.181818	 0.0	 189	 189	 189	 1.044444	 0.0	 1	 -30.0	 30.0;
	1364	 6337	 0.0	 0.041231	 0.0	 833	 833	 833	 1.0948	 0.0	 1	 -30.0	 30.0;
	1363	 6338	 0.0	 0.273494	 0.0	 126	 126	 126	 1.062667	 0.0	 1	 -30.0	 30.0;
	1430	 6339	 0.0	 0.032831	 0.0	 1046	 1046	 1046	 1.044444	 0.0	 1	 -30.0	 30.0;
	1578	 6340	 0.0	 0.012685	 0.0	 1064.0	 1064.0	 1064.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1579	 6341	 0.0	 0.012685	 0.0	 1064.0	 1064.0	 1064.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1580	 6342	 0.0	 0.012685	 0.0	 1072.0	 1072.0	 1072.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1581	 6343	 0.0	 0.012685	 0.0	 1090.0	 1090.0	 1090.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1608	 6344	 0.0	 0.345838	 0.0	 100	 100	 100	 1.044444	 0.0	 1	 -30.0	 30.0;
	1769	 6345	 0.0	 0.009303	 0.0	 1506.0	 1506.0	 1506.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	1768	 6346	 0.0	 0.009303	 0.0	 1444.0	 1444.0	 1444.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	1871	 6347	 0.0	 0.3396	 0.0	 103	 103	 103	 1.0	 0.0	 1	 -30.0	 30.0;
	1960	 6348	 0.0	 0.128214	 0.0	 268	 268	 268	 1.056743	 0.0	 1	 -30.0	 30.0;
	1961	 6349	 0.0	 0.128214	 0.0	 268	 268	 268	 1.056743	 0.0	 1	 -30.0	 30.0;
	1961	 6350	 0.0	 0.148375	 0.0	 232	 232	 232	 1.057778	 0.0	 1	 -30.0	 30.0;
	1960	 6351	 0.0	 0.148375	 0.0	 232	 232	 232	 1.057778	 0.0	 1	 -30.0	 30.0;
	2016	 6352	 0.0	 0.008909	 0.0	 1572.0	 1572.0	 1572.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	2017	 6353	 0.0	 0.008909	 0.0	 1494.0	 1494.0	 1494.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	2046	 6354	 0.0	 0.042476	 0.0	 809	 809	 809	 1.062222	 0.0	 1	 -30.0	 30.0;
	2053	 6355	 0.0	 0.302795	 0.0	 114	 114	 114	 1.053333	 0.0	 1	 -30.0	 30.0;
	2061	 6356	 0.0	 0.012685	 0.0	 1076.0	 1076.0	 1076.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2062	 6357	 0.0	 0.012685	 0.0	 1101.0	 1101.0	 1101.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2063	 6358	 0.0	 0.012685	 0.0	 1103.0	 1103.0	 1103.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2064	 6359	 0.0	 0.012685	 0.0	 1090.0	 1090.0	 1090.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2065	 6360	 0.0	 0.012685	 0.0	 1101.0	 1101.0	 1101.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2066	 6361	 0.0	 0.012685	 0.0	 999.0	 999.0	 999.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2134	 6362	 0.0	 0.041112	 0.0	 835	 835	 835	 1.081067	 0.0	 1	 -30.0	 30.0;
	2163	 6363	 0.0	 0.029081	 0.0	 1182	 1182	 1182	 1.080888	 0.0	 1	 -30.0	 30.0;
	2198	 6364	 0.0	 0.044965	 0.0	 273.0	 273.0	 273.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	2199	 6365	 0.0	 0.020227	 0.0	 1696	 1696	 1696	 1.088844	 0.0	 1	 -30.0	 30.0;
	2200	 6366	 0.0	 0.021197	 0.0	 1616	 1616	 1616	 1.103079	 0.0	 1	 -30.0	 30.0;
	2221	 6368	 0.0	 0.203226	 0.0	 169	 169	 169	 1.048889	 0.0	 1	 -30.0	 30.0;
	2241	 6369	 0.0	 0.372846	 0.0	 93	 93	 93	 1.076889	 0.0	 1	 -30.0	 30.0;
	2401	 6370	 0.0	 0.525174	 0.0	 66	 66	 66	 1.0	 0.0	 1	 -30.0	 30.0;
	2401	 6371	 0.0	 0.525174	 0.0	 66	 66	 66	 1.0	 0.0	 1	 -30.0	 30.0;
	2462	 6372	 0.0	 0.460144	 0.0	 75	 75	 75	 1.035556	 0.0	 1	 -30.0	 30.0;
	2663	 6373	 0.0	 0.312857	 0.0	 110	 110	 110	 1.054667	 0.0	 1	 -30.0	 30.0;
	2663	 6374	 0.0	 0.312857	 0.0	 110	 110	 110	 1.054667	 0.0	 1	 -30.0	 30.0;
	2663	 6375	 0.0	 0.312857	 0.0	 110	 110	 110	 1.054667	 0.0	 1	 -30.0	 30.0;
	2663	 6376	 0.0	 0.312857	 0.0	 110	 110	 110	 1.054667	 0.0	 1	 -30.0	 30.0;
	2619	 6377	 0.0	 0.048207	 0.0	 277.0	 277.0	 277.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	2655	 6378	 0.0	 0.220078	 0.0	 156	 156	 156	 1.07511	 0.0	 1	 -30.0	 30.0;
	2706	 6379	 0.0	 0.120375	 0.0	 286	 286	 286	 1.053333	 0.0	 1	 -30.0	 30.0;
	2706	 6380	 0.0	 0.17125	 0.0	 201	 201	 201	 1.053333	 0.0	 1	 -30.0	 30.0;
	2706	 6381	 0.0	 0.13875	 0.0	 248	 248	 248	 1.049777	 0.0	 1	 -30.0	 30.0;
	2706	 6382	 0.0	 0.120375	 0.0	 286	 286	 286	 1.053333	 0.0	 1	 -30.0	 30.0;
	2712	 6383	 0.0	 0.329412	 0.0	 105	 105	 105	 1.053333	 0.0	 1	 -30.0	 30.0;
	2712	 6384	 0.0	 0.329412	 0.0	 105	 105	 105	 1.053333	 0.0	 1	 -30.0	 30.0;
	2712	 6385	 0.0	 0.329412	 0.0	 105	 105	 105	 1.053333	 0.0	 1	 -30.0	 30.0;
	2728	 6386	 0.0	 0.181636	 0.0	 189	 189	 189	 1.088889	 0.0	 1	 -30.0	 30.0;
	2822	 6387	 0.0	 0.044965	 0.0	 257.0	 257.0	 257.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	2821	 6388	 0.0	 0.044965	 0.0	 763	 763	 763	 1.080978	 0.0	 1	 -30.0	 30.0;
	2861	 6389	 0.0	 0.482751	 0.0	 72	 72	 72	 1.137778	 0.0	 1	 -30.0	 30.0;
	381	 6390	 0.0	 0.031723	 0.0	 1082	 1082	 1082	 1.044444	 0.0	 1	 -30.0	 30.0;
	3039	 6391	 0.0	 0.25608	 0.0	 135	 135	 135	 1.072445	 0.0	 1	 -30.0	 30.0;
	3039	 6392	 0.0	 0.25608	 0.0	 135	 135	 135	 1.072445	 0.0	 1	 -30.0	 30.0;
	3056	 6393	 0.0	 0.0516	 0.0	 666	 666	 666	 1.07511	 0.0	 1	 -30.0	 30.0;
	3055	 6394	 0.0	 0.0516	 0.0	 666	 666	 666	 1.07511	 0.0	 1	 -30.0	 30.0;
	3089	 6395	 0.0	 0.15879	 0.0	 217	 217	 217	 1.052889	 0.0	 1	 -30.0	 30.0;
	3089	 6396	 0.0	 0.15879	 0.0	 217	 217	 217	 1.052889	 0.0	 1	 -30.0	 30.0;
	1744	 6397	 0.0	 0.012685	 0.0	 1121.0	 1121.0	 1121.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1743	 6398	 0.0	 0.012685	 0.0	 1055.0	 1055.0	 1055.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3149	 6399	 0.0	 0.03299	 0.0	 1041	 1041	 1041	 1.04	 0.0	 1	 -30.0	 30.0;
	3150	 6400	 0.0	 0.034269	 0.0	 1000	 1000	 1000	 1.060526	 0.0	 1	 -30.0	 30.0;
	3236	 6401	 0.0	 0.009303	 0.0	 1574.0	 1574.0	 1574.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3253	 6402	 0.0	 0.144154	 0.0	 239	 239	 239	 1.066667	 0.0	 1	 -30.0	 30.0;
	3253	 6403	 0.0	 0.144154	 0.0	 239	 239	 239	 1.066667	 0.0	 1	 -30.0	 30.0;
	3263	 6404	 0.0	 0.297059	 0.0	 116	 116	 116	 1.066667	 0.0	 1	 -30.0	 30.0;
	3318	 6405	 0.0	 0.008909	 0.0	 1564.0	 1564.0	 1564.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3319	 6406	 0.0	 0.008909	 0.0	 1605.0	 1605.0	 1605.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3320	 6407	 0.0	 0.008909	 0.0	 1546.0	 1546.0	 1546.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3317	 6408	 0.0	 0.008909	 0.0	 1590.0	 1590.0	 1590.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3346	 6409	 0.0	 0.389792	 0.0	 89	 89	 89	 1.044444	 0.0	 1	 -30.0	 30.0;
	3373	 6410	 0.0	 0.009303	 0.0	 1605.0	 1605.0	 1605.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3374	 6411	 0.0	 0.009303	 0.0	 1520.0	 1520.0	 1520.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3479	 6412	 0.0	 0.021485	 0.0	 1594	 1594	 1594	 1.103079	 0.0	 1	 -30.0	 30.0;
	3478	 6413	 0.0	 0.021485	 0.0	 1594	 1594	 1594	 1.103079	 0.0	 1	 -30.0	 30.0;
	3477	 6414	 0.0	 0.021485	 0.0	 1594	 1594	 1594	 1.103079	 0.0	 1	 -30.0	 30.0;
	3476	 6415	 0.0	 0.019737	 0.0	 1735	 1735	 1735	 1.092105	 0.0	 1	 -30.0	 30.0;
	3505	 6416	 0.0	 0.156299	 0.0	 220	 220	 220	 1.053333	 0.0	 1	 -30.0	 30.0;
	3535	 6417	 0.0	 0.044965	 0.0	 284.0	 284.0	 284.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	3534	 6418	 0.0	 0.020227	 0.0	 676.0	 676.0	 676.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	3596	 6419	 0.0	 0.214367	 0.0	 161	 161	 161	 1.026667	 0.0	 1	 -30.0	 30.0;
	3596	 6420	 0.0	 0.214367	 0.0	 161	 161	 161	 1.026667	 0.0	 1	 -30.0	 30.0;
	3609	 6421	 0.0	 0.733548	 0.0	 47	 47	 47	 1.044444	 0.0	 1	 -30.0	 30.0;
	3689	 6422	 0.0	 0.431133	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	3689	 6423	 0.0	 0.431017	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	3672	 6424	 0.0	 0.046748	 0.0	 441.0	 441.0	 441.0	 1.066667	 0.0	 1	 -30.0	 30.0;
	3727	 6425	 0.0	 0.155048	 0.0	 222	 222	 222	 1.0	 0.0	 1	 -30.0	 30.0;
	3726	 6426	 0.0	 0.155048	 0.0	 222	 222	 222	 1.0	 0.0	 1	 -30.0	 30.0;
	3725	 6427	 0.0	 0.155048	 0.0	 222	 222	 222	 1.0	 0.0	 1	 -30.0	 30.0;
	3730	 6428	 0.0	 0.327904	 0.0	 105	 105	 105	 1.05641	 0.0	 1	 -30.0	 30.0;
	3730	 6429	 0.0	 0.327904	 0.0	 105	 105	 105	 1.05641	 0.0	 1	 -30.0	 30.0;
	3730	 6430	 0.0	 0.327904	 0.0	 105	 105	 105	 1.05641	 0.0	 1	 -30.0	 30.0;
	3730	 6431	 0.0	 0.327904	 0.0	 105	 105	 105	 1.05641	 0.0	 1	 -30.0	 30.0;
	3992	 6432	 0.0	 0.317591	 0.0	 109	 109	 109	 1.022222	 0.0	 1	 -30.0	 30.0;
	3997	 6433	 0.0	 0.329412	 0.0	 105	 105	 105	 1.044444	 0.0	 1	 -30.0	 30.0;
	3997	 6434	 0.0	 0.329412	 0.0	 105	 105	 105	 1.044444	 0.0	 1	 -30.0	 30.0;
	4021	 6435	 0.0	 0.302312	 0.0	 114	 114	 114	 1.034667	 0.0	 1	 -30.0	 30.0;
	4021	 6436	 0.0	 0.290101	 0.0	 119	 119	 119	 1.04	 0.0	 1	 -30.0	 30.0;
	4047	 6437	 0.0	 0.167949	 0.0	 205	 205	 205	 1.048889	 0.0	 1	 -30.0	 30.0;
	4053	 6438	 0.0	 0.733625	 0.0	 47	 47	 47	 1.08	 0.0	 1	 -30.0	 30.0;
	4146	 6439	 0.0	 0.088828	 0.0	 387	 387	 387	 1.022222	 0.0	 1	 -30.0	 30.0;
	4146	 6440	 0.0	 0.088828	 0.0	 387	 387	 387	 1.022222	 0.0	 1	 -30.0	 30.0;
	4190	 6441	 0.0	 0.009303	 0.0	 1583.0	 1583.0	 1583.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	4189	 6442	 0.0	 0.009303	 0.0	 1553.0	 1553.0	 1553.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1699	 6443	 0.0	 0.035942	 0.0	 336.0	 336.0	 336.0	 1.081023	 0.0	 1	 -30.0	 30.0;
	1698	 6444	 0.0	 0.019697	 0.0	 681.0	 681.0	 681.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	1696	 6445	 0.0	 0.037419	 0.0	 512.0	 512.0	 512.0	 1.11579	 0.0	 1	 -30.0	 30.0;
	1695	 6446	 0.0	 0.037117	 0.0	 923	 923	 923	 1.11579	 0.0	 1	 -30.0	 30.0;
	4256	 6447	 0.0	 0.244364	 0.0	 141	 141	 141	 1.044444	 0.0	 1	 -30.0	 30.0;
	4256	 6448	 0.0	 0.244364	 0.0	 141	 141	 141	 1.044444	 0.0	 1	 -30.0	 30.0;
	4265	 6449	 0.0	 0.3396	 0.0	 103	 103	 103	 1.069841	 0.0	 1	 -30.0	 30.0;
	4271	 6450	 0.0	 0.148936	 0.0	 231	 231	 231	 1.073333	 0.0	 1	 -30.0	 30.0;
	4288	 6451	 0.0	 0.012611	 0.0	 1058.0	 1058.0	 1058.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	4287	 6452	 0.0	 0.012611	 0.0	 1048.0	 1048.0	 1048.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	4296	 6453	 0.0	 0.1992	 0.0	 173	 173	 173	 1.044444	 0.0	 1	 -30.0	 30.0;
	4296	 6454	 0.0	 0.1992	 0.0	 173	 173	 173	 1.044444	 0.0	 1	 -30.0	 30.0;
	4296	 6455	 0.0	 0.1992	 0.0	 173	 173	 173	 1.044444	 0.0	 1	 -30.0	 30.0;
	4505	 6456	 0.0	 0.092765	 0.0	 370	 370	 370	 1.065789	 0.0	 1	 -30.0	 30.0;
	4505	 6457	 0.0	 0.092765	 0.0	 370	 370	 370	 1.065789	 0.0	 1	 -30.0	 30.0;
	4525	 6458	 0.0	 0.1195	 0.0	 288	 288	 288	 1.044444	 0.0	 1	 -30.0	 30.0;
	4525	 6459	 0.0	 0.1195	 0.0	 288	 288	 288	 1.044444	 0.0	 1	 -30.0	 30.0;
	4693	 6460	 0.0	 0.012769	 0.0	 1104.0	 1104.0	 1104.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	4694	 6461	 0.0	 0.012769	 0.0	 1069.0	 1069.0	 1069.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	4695	 6462	 0.0	 0.012769	 0.0	 1123.0	 1123.0	 1123.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	4696	 6463	 0.0	 0.012769	 0.0	 1132.0	 1132.0	 1132.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	4762	 6464	 0.0	 0.050588	 0.0	 679	 679	 679	 1.048889	 0.0	 1	 -30.0	 30.0;
	4762	 6465	 0.0	 0.050588	 0.0	 679	 679	 679	 1.048889	 0.0	 1	 -30.0	 30.0;
	4761	 6466	 0.0	 0.050588	 0.0	 679	 679	 679	 1.048889	 0.0	 1	 -30.0	 30.0;
	4794	 6467	 0.0	 0.16148	 0.0	 213	 213	 213	 1.155555	 0.0	 1	 -30.0	 30.0;
	4794	 6468	 0.0	 0.16148	 0.0	 213	 213	 213	 1.155555	 0.0	 1	 -30.0	 30.0;
	4794	 6469	 0.0	 0.16148	 0.0	 213	 213	 213	 1.155555	 0.0	 1	 -30.0	 30.0;
	4939	 6470	 0.0	 0.044965	 0.0	 253.0	 253.0	 253.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	4938	 6471	 0.0	 0.044965	 0.0	 764	 764	 764	 1.080978	 0.0	 1	 -30.0	 30.0;
	4947	 6472	 0.0	 0.070769	 0.0	 484	 484	 484	 1.026316	 0.0	 1	 -30.0	 30.0;
	5006	 6473	 0.0	 0.15125	 0.0	 227	 227	 227	 1.044444	 0.0	 1	 -30.0	 30.0;
	5006	 6474	 0.0	 0.15125	 0.0	 227	 227	 227	 1.044444	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Line Capacity Model:         ub
% INFO    : Gen Active Cost Model:       stat
% INFO    : Setting Flat Start
% INFO    : Line Capacity PAB:           15.0 (deg.)
% INFO    : 
% INFO    : === Generator Classification Notes ===
% INFO    : PEL    319 -     4.96
% INFO    : NUC    23  -    16.20
% INFO    : SYNC   24  -     0.00
% INFO    : COW    233 -    56.88
% INFO    : NG     731 -    21.96
% INFO    : 
% INFO    : === Generator Active Cost Stat Model Notes ===
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 34.7191009474 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.2651180904 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.0199849342 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 125.857376118 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.274748297 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.0707512033 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 119.380030386 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 97.0793858007 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.1899619181 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.259097072 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.532072227 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.3963995749 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 18.6788893791 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.9082927798 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.9550465884 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.606676697 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.5234513801 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.6387325491 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.834409456 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.0832470863 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.792247232 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.5151963 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.1516276529 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0740897233 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.7935973252 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3570199243 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.277328936 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.4914705418 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.919519443 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9408162344 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 17.0551352142 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 17.7885337774 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.2928787174 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 53.056287102 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.368658523 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.4121419742 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.017630121 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 85.1732230943 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.1249451267 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 121.165706497 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.8412431115 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.4160926952 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 89.2181548618 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.9607569785 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.606963733 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.028871585 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 128.292720895 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.2527392534 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.6041313315 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.053546573 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.6956402056 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.917973902 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 98.5787949604 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.5491572126 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.6122194078 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 61.4437411995 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.1791747855 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.2084845506 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 1.66259172869 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.9235108835 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 126.105535931 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.5728335932 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 14.2154846189 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.0604886849 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3538764988 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.4374187365 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4042925756 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7693618129 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.5371222526 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.286590702 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.8220985166 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1862039197 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 19.1766487071 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 122.465505845 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.703695428 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.728290681 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 115.4674438 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.8602055851 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.4350208037 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7469637644 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.6288569358 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.96775542 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.652095151 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.581811927 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.2359551641 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.4685556451 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 17.7943136319 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.683734432 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.2557814059 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.8384141653 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.2546854004 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.434555068 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 98.5086581935 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.5396579229 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 101.377380818 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 130.391310955 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.2396450483 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.473273013 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.604090299 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.271036394 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.4298661709 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 94.3688141007 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 16.652288456 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6009131389 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6549248349 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.129386532 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 41.5318799416 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.0211474378 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.716028 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.7942533681 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.7645416001 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.0586390847 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1413865068 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2994138697 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 122.796126594 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.2490137658 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.0797763 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.250372322 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.1955889119 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.8536715689 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.3013673722 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.5661398164 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.43620383 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.5873323924 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.9765280067 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.6709148026 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 6.81554890114 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.5112730967 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5935214056 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 50.7202673903 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.9452909188 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.7370802573 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3409233293 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.9068740657 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 124.031387447 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.544045318 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3000554041 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.25830548 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 30.1909974699 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.450704536 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7943825953 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.788061951 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.3309616992 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.055980657 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.5470716831 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.7288759644 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 127.485754968 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.084226535 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3131390795 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.210827831 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.6043909736 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.4444369876 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 5.77139408018 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2160569419 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.0337314817 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.21685025 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.39046645 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.5376871811 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3944657184 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.2188299749 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.842194142 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.0584219495 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5513676833 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.707885502 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.3758065136 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.687688072 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.783293701 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.473965824 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0498446423 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.661349551 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.86281066 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1876257922 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 104.030831061 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 102.392307234 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 97.9268126052 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1659596751 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.8071877418 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 17.1087324455 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 100.937756385 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7647066077 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.5743964174 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4809943419 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6616779439 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.879594664 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4689636898 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7640402917 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 92.6141304187 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.769660654 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 60.6913914338 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.5947028188 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.610773928 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.4731867144 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.395905286 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.7016382749 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.084654414 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.597860464 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 29.0669003844 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.6056132224 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.8778285544 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 30.1046506789 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.058093709 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.2444053395 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 121.919626592 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.0181037894 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.0219129274 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.3945002958 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.217897027 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.310033337 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 12.7182773425 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.9382859637 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 21.9313204764 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.6276918727 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.9740067957 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.8563423216 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 89.4061433647 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 61.8333067354 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 129.631907329 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3367151795 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 19.9301875216 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.2773223813 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.5836588351 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.0998424839 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.0242821664 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.9335464787 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0227414205 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.7711258422 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.2338621196 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2812870858 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 75.8381282141 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.157014766 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 83.4913227305 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.4597421446 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6238165204 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.591489528 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.071753893 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.2789709773 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.3787380339 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 20.7678728792 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 119.490048093 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.3400761468 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.7634111711 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.758165388 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.44594409 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7504249601 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.0248023532 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 47.3789900778 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 11.5709604035 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.057614855 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.4355477995 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 4.04261780108 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.0644165134 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.5383043821 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 95.7996797726 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.737778186 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1872313107 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.334575365 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.41828311 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 17.0992503242 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.869238897 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.5389487872 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6732039825 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.420972439 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.9927374517 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0734323039 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.7055651942 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 47.392219224 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 101.63750166 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 124.470460984 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 57.6639131115 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.6220371527 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.3104635635 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.9187794956 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 115.058732909 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.4864189081 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.0588415969 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2522923452 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.85751734 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.9507514638 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9375890344 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4918179443 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 33.5070007113 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.3256202429 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.551234395 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8527990102 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 101.642065431 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.79363717 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 102.459973683 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 14.1706992761 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.9720793791 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 123.208894843 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.2453953665 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.5399160745 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.61020155 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.5652692277 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.7138405343 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.9135760527 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1451631325 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.7315388632 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.2443390497 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 125.874942529 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.927628948 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.2585686978 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.2693418273 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.747597477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.192827761 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.6075023413 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.363526094 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.8569778753 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.6729647867 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.691934224 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.5046270646 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7934271293 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5827297634 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.454068909 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.532112394 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.974242104 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 14.8388557803 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 17.0924463454 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7746633936 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.7257314866 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.1348705816 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.1460884749 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6364453046 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.3384583235 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.4098668173 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 11.7186160458 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.6303303965 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.0971980906 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.0694970687 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 18.4009653922 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.0551048538 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.2958348958 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.978318833 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1349555466 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 92.9691765869 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.5695120284 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.8474646892 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.2917538732 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 100.519448141 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.4970940645 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.6795635893 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.056468822 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6263602289 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.521958039 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.4477983719 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.6419270583 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4760061093 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8593285075 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.6728325358 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 50.9897651796 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.2076651347 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 128.150032091 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 88.2611298255 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.081120709 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 118.959227768 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 51.0311467761 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.8307977496 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 10.5494163923 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 93.7129629113 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.505530134 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5771317194 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2695131291 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4539539216 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9125729945 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.72394783 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 41.3082135845 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.4280639116 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7658019917 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.974304182 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.044426341 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9530310046 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.768252525 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 132.824014267 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.7960332748 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 94.3715280356 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.63276398529 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.049405279 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.3586050312 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.091361862 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.941307011 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.390525547 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.3885219085 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.010142162 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.65051277 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.646262751 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1689008364 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 123.957829053 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.296012023 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.6477267227 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.1265552127 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.5009637575 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7402488157 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.0369039922 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 89.5494722136 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 66.9613581536 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.1373872682 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.411589974 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.4700867503 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5627961843 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.754447022 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 33.1470725611 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8949908012 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8817442436 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.0588947381 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1598056412 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.850400512 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.419662893 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.6654169234 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.992611947 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.792298545 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9816963263 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.085309078 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 136.77787049 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3618548221 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 55.7763782249 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 15.4477395301 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.196612792 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.1521954009 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.1554067413 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.382701185 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 51.6914125477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1708773561 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.3197776042 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 104.880656038 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4596417537 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.3272905183 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.8347439051 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.32965047 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 13.2847229096 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.4766679088 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.3272880457 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0897325989 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.1041722806 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.3265075811 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9174605167 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.9503304281 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8771981432 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.7029820532 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 27.3457552115 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.9418249819 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.221652832 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 125.028176104 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.6980916032 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.41244045 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.737618691 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.9225092597 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.901768642 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.153614858 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.317318137 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 62.3895135456 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.9398050754 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.837696844 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.9800015602 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.9506888087 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.3677610724 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.0493165397 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.612703109 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.001936237 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 8.02531875137 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.7219357731 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.5593689193 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8394295602 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 56.5212356248 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 16.1736075463 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9870786597 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.936246484 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.6760582272 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.8680935141 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 50.8860945164 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2840784305 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.483214099 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 131.970508127 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.014153899 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.8154781353 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.9961970409 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7248957835 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.152429138 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.7364023576 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.8376866888 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.9301444455 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3810997002 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.729937986 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.1063252912 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.5288626493 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.0484484994 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8965450881 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.7993537692 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.3338069826 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.6221923473 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 48.3708931715 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.7796886923 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.7431491164 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3429664173 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.9172689233 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.6972529099 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4122635982 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.1431200081 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.8316583408 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 103.434462659 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.631740386 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.569447731 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.232924335 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.972175392 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.2794672376 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.120905936 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.8058836576 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 66.1605699144 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.93116131727 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.758826583 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.0952190228 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 123.123261683 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.9030358472 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.523821729 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.021766191 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.4300142412 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.3590785336 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.3196254866 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8619606116 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.6327296271 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.5264502103 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.6610291573 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.2298891649 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.8923101252 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 48.5223222544 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.0920044333 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.204097939 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.498031476 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.4849380333 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8950658409 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.0438588011 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.424151547 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.6199216434 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.4384971447 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7463646531 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 15.102008224 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.755403933 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 29.7447145297 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.6119139808 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 122.162979201 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.318772472 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7883412181 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3607417133 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.149007081 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.817969448 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.4862357715 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.194093488 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9358845449 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5843029255 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.85071693 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.180456932 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 121.027666723 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.8614792275 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.343373179 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.621052371 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.4739016034 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.1722764776 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 47.6181620871 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.3826548843 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.2086430314 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 22.2738627883 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.698568509 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.093584769 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.2394281092 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.478992234 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.7395184044 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.7078371975 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.887335732 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.47484352 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.783793923 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.4671748052 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.89544789 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 101.271781662 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.3035876669 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8456807524 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.2893460012 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.850896664 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.5736593115 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.707891632 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 115.95382729 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.602615261 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.129991209 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.3829084994 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.5234382636 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0823639268 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4333387229 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9041969495 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9249071984 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.708928497 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2694294377 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9023875169 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.0605598536 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 11.1620785162 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.8158897684 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1740885116 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.154160257 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.954907366 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.1342872706 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.0344690207 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.3287229387 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 123.761049693 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 12.8636873947 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.3672995324 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.462985584 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7823431905 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.2974821317 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.5533424663 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2030984272 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.7172378269 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.9143352771 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.184646065 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7752421001 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.77320275 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 50.391265931 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.715226008 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 119.016594409 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.5991224359 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.842299153 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.6859350599 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.3678947614 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3730732418 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.297343987 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 18.4560615173 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4772640605 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.1764546604 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.976089738 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.26128425 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.4215221475 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.435598094 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8002447534 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.5402832391 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.3844991638 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 86.4558190706 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7468630748 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.489080259 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.7398513052 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 11.130854118 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.9581931918 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 110.565928612 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.686223362 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 18.9414649425 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.78163775 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2139901342 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8677480526 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.4189026942 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.363697869 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.156266259 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.5456619406 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 5.03979413674 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 2.3565169338 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 130.742767318 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 12.8444825664 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.7152371926 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.3866192376 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.1720003092 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 18.5992806718 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.28323374 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.413783612 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.526752027 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.942982289 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 15.4536214709 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3782825078 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.897724793 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.667571285 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4904214603 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 115.266078992 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.5242300428 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.2903491712 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.6587903828 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 48.0168724814 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.62151558623 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 118.20684202 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.8590487013 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5474885264 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.5480297899 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.673507426 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.706255272 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.0569334913 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.0085210128 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.354812248 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7048149855 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4248280555 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.0498872109 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1953897775 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.11604136 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3689930421 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.8343568499 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.403263051 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 115.769033721 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.968294816 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.317726196 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.0776956886 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.292742287 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.890348898 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7667711715 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1809767878 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.867854098 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.9640376333 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 19.6654434623 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4721899932 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7083501224 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.353405037 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.411303235 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.5741405429 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.361566434 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 15.9376280864 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 32.0060624922 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.8359022136 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.077026633 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.0881639294 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.0633974076 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.491812552 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.9812073362 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.5672256084 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.5951552224 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.734120943 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.4483552924 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 44.7133760372 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.3674596683 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.054864382 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.338442748 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.508811953 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.1812847488 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.0475268792 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4489462188 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.7272833884 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.6486487681 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 102.352741903 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.862698162 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3545659043 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.5542669018 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.6740069084 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 40.9819085565 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.26932523 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.232331996 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.2391576553 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7467841064 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1879590584 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.157577173 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 86.2169010488 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 97.5604735767 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 121.510293757 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 54.4345566243 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5854266572 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.9386448508 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.9827554286 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4394107485 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2827922365 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.3861243183 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 51.1666206456 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6358321646 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.558190588 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 104.298282942 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8871466106 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.849744841 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.5450322058 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.7328997237 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.0468018509 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 16.2516700637 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.7418268476 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.7667329056 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5782842893 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1500602088 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.1393360721 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2864197681 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.5196456437 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.199405183 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 18.3998405279 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.339225828 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.4030602726 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.299490267 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 22.1114684623 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.7366766368 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2893990718 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.526352601 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1129724329 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.5308117192 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.367019704 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.103049909 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0853040209 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9646566319 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.739590418 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.340986746 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.0279120356 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.564696454 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.8460173466 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.1345404729 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.4081295909 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1957637072 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 11.190388262 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.9782919124 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.495918993 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 95.4158133124 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 97.5087495961 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.586392261 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.8514800884 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4009438021 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.9356362451 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 56.3555556539 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.3664283081 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.2261446514 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.3854833858 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.966691175 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.412235831 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.3583299083 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 31.5638139005 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.4018120557 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.434919364 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 110.417793203 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 123.303255046 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 16.0564962883 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.4856818607 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.7097256095 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.1786433482 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.468690159 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.2677760373 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.064604035 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.5486073646 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.3803955628 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3079251916 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.590833126 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.354277203 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 125.242760244 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.8836027149 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.862464938 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0773506193 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 95.3313448915 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.860172143 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.9132127626 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.4033611225 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.563256246 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.152038676 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.869878657 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2925940787 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.025412202 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5538860758 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.3312193326 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 92.4368871079 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.835465199 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.504130012 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.0911663165 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.7396037943 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.3097631866 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.348426736 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.595205516 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.786521757 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.601159091 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.836865574 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.289462293 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.429393325 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 128.735705289 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7918680846 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.6177915535 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.4164195815 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.0817643437 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.7559515675 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.687242711 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.7915918715 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.4535969929 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.0892097923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.1296090556 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.6550599529 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.3381397763 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3244774657 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.1453131797 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1050301486 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.6170409592 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7355257625 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.2209841439 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 62.6057768728 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9817051676 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.021015992 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.2994167288 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 11.5033975721 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.8939347139 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.4126524056 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.618826515 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5622849363 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 123.735178221 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 104.443701197 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.4392366942 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 8.21574835399 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 98.1351209482 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.4428509713 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.2669394324 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.4965469696 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.8256752954 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.402536267 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.52892605 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.5878415046 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.3465187713 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 53.5027091848 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 95.0155192497 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.2552374657 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.3506882838 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.0498646041 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.8638126769 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8334721053 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1533802237 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 97.720597544 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.3114055335 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.7022724568 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 126.405026023 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.1160467236 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.491931694 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.056009169 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2743081078 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2886756316 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4385874918 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8538745444 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.5934231954 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.989652001 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2583091559 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8108097726 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1150633626 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.0432121012 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.6485982614 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.2434662713 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.8772425132 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 128.858849578 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.463521664 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.1215080502 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.99778308252 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4829292547 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 12.6664881517 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 55.4170889681 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0150722762 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0339923723 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5081889842 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.451977616 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.270507066 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 58.0942427571 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.0886791738 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1421773338 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7428203733 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.2543274347 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5467579381 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6007743769 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.6149540758 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.9039490732 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.610805191 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2002381818 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.3295923967 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.027586846 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0195674222 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 125.239002022 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5379871347 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.7497929254 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 92.6861544635 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.7770305764 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.1019705171 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 110.587706211 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.9716203276 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4502907258 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1026370715 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0586080084 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.3210716759 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.2997950709 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.6458837742 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 53.7016707122 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.7857785928 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 9.29073699419 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.9296556772 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.9192845649 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 30.3483551034 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.081099321 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.6103183589 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.6632723282 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.3368440459 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 33.6307166249 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 15.1342508896 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.5309919304 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7262724654 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.3901829865 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.9747994642 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 18.2367952646 0
% INFO    : Updated Generator Cost: NUC - 0.0 2.0 0.0 -> 0 6.13583853774 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 27.5622433431 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.9212856544 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.151857345 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.411620164 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.9905767967 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.8515649051 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.7193987497 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.1629361253 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.514020391 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.1244928409 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NUC - 0.0 2.0 0.0 -> 0 6.63990494988 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 12.9137776742 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.3475696433 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 26.9239359977 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 32.9243429113 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 27.5150431157 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.5988558471 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.7514439534 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.0773082735 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.6424840816 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 26.3216608453 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.4491600533 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.8643075683 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 21.9135033949 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.3091676274 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.6450809275 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 44.0549502492 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8278538703 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.2793034869 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4753938438 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.29850217996 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 33.3807053048 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7986824456 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5809949903 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.37753206 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 20.9459157767 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.2420009284 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.61798018 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.680742554 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.6938635087 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.10561513537 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 48.8737345147 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.8172564503 0
% INFO    : Updated Generator Cost: NUC - 0.0 2.0 0.0 -> 0 6.03817888973 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 17.2783899983 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 11.6305918723 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 29.8409241893 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.8857448421 0
% INFO    : Updated Generator Cost: NUC - 0.0 2.0 0.0 -> 0 6.90635049928 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.68331068 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0005238784 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1106777248 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.4748405929 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.4666232943 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.625530816 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7712945766 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4145518752 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.9515451371 0
% INFO    : Updated Generator Cost: NUC - 0.0 2.0 0.0 -> 0 8.50492378308 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.1613995286 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.8382694394 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6506215967 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.4044207098 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4176862473 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.8735717417 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.9420726059 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.9220152417 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.0359906529 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.4653952857 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.7540723879 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2435888129 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.065957758 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.7381203065 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7432293142 0
% INFO    : Updated Generator Cost: NUC - 0.0 2.0 0.0 -> 0 7.45173495732 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 31.4364065435 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.614265298 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.5477769793 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.5566563811 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1399416726 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.763005179 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 44.4589523284 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0625068859 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9039167717 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 19.3952642267 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.9606220875 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.7226360621 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8076060167 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.8445002336 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 38.7288587176 0
% INFO    : Updated Generator Cost: NUC - 0.0 2.0 0.0 -> 0 7.06461341078 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3616875022 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 21.5761760217 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 6.53045497617 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 33.0312535495 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.8891226741 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.837149996 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 17.032006738 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.4775606988 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4895753053 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.1094448857 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8921345965 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.6814095784 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 18.418254379 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.6479295935 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.715610319 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.0978413145 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.713177747 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5090036683 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.2761339716 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.9862718689 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 10.2021173849 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.52002509776 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4619516334 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.379671929 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2477475922 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.2542940467 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7381496858 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.6578289126 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 5.04589208239 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9047470562 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 97.5825314849 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.4141039917 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.6897682524 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.0736155912 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.351244398 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.3704249328 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.9327836278 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9070823793 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.5770379697 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.8227775127 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.1265755347 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.8739509149 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9011378015 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7419370976 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.9390007329 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.6222149658 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4628702129 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 31.3780571932 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 95.0870789131 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.464125854 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.198863693 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.4741320009 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7816273498 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.049562031 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.8691422135 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8752402924 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.241712114 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.1323267887 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.7587105981 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.0048769163 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.126896991 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.49269530351 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.2366516995 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.378169608 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 125.760080755 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.134215735 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8296287018 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.801828561 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.5953211503 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.45605618 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.7262580516 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.17997349496 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.02086185535 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.2617402202 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.2249797686 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.284572039 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7548314237 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2545181875 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.2376523741 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.95561855 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.7834459437 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.8107674896 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7476005661 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.5680455027 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9466162975 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3067601487 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 47.7499326686 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7014303601 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.9156806841 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.3827963565 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.8377493826 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.4092871351 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.4988767704 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7318009554 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4340618899 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4434062041 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.4818676953 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.0407280436 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.6931870735 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.65845071509 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.6705063572 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6561697103 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 29.5795538331 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.5787758896 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.3546389769 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.55253557931 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2778715063 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.784439987 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.60011156261 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.8599661883 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.9209826296 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8123168221 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.8830508592 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4799423405 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 125.51985735 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.345790502 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 91.6391949458 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.2268841635 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.31563689 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.249466692 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.898039849 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.47142199395 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.5673155177 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.2779341173 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.2491344815 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.8663768618 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.732486423 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2400007593 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 27.7256796733 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1017514376 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 7.94568218838 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 36.5213634012 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.7323280515 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.354222233 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.8404757864 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.020158023 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.274430681 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3073473743 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7203746265 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1242933973 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.8141736755 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.8129419911 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.693241367 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.380500862 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.6070111747 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.856177326 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.3874212947 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.0224144957 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1799200868 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.560156987 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.5134957236 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9734568941 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.622309988 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.379275899 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2615757334 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2207501746 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5948315655 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 53.934070793 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 59.108565881 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.669453749 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8005155377 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5877012939 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 3.52697658644 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.0716971831 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 5.03352485578 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.6450566193 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.442104711 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8572818026 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1401029807 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8477202854 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7328205342 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.5181944537 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.9997503316 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1201401865 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.1484313697 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.4421924146 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 31.3916207927 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.2668103125 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.3534397794 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 27.1773357393 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.039667358 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.2416516812 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.2037672841 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.829637226 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.561411545 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3206586776 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.12121779 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.817182232 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.8982931186 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 46.1384828312 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.3036741541 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5289697276 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.680302431 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 12.62052126 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.726103674 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 20.0120288237 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8164801931 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.7168934725 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8098462879 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.9874540669 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.385528244 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.7958513362 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 21.8184432337 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1509300697 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3801749566 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.99699303506 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.5406254019 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.6507962823 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.8319786398 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2270636257 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.9296671499 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0069871421 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 64.463059792 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 7.15795159318 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.126737851 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.45991628844 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.8592876601 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.1662045832 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3906687 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2265175667 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.2541987517 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4048554508 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.6936447728 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9971433629 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.0691730104 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.8598798493 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.438037225 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.62911435901 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.0095998793 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 17.9634948367 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.4680591941 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2210970289 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6041191947 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8583372271 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1583310785 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9024880242 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.8141778464 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 8.37386747674 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 12.9774980412 0
% INFO    : 
% INFO    : === Generator Bounds Update Notes ===
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% WARNING : Transformer 4644-1 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5243-1 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1682-2 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1673-3 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2302-3 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 694-4 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3940-4 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5043-4 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4414-5 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2780-6 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2781-7 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2468-8 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 471-9 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 11-10 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 11-10 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 30-11 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2930-11 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2180-12 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4018-12 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4020-12 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 115-13 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2336-13 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4574-13 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 116-13 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1224-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2875-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4592-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4950-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5229-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2875-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4592-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2907-15 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4126-15 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4454-15 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 251-16 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 339-16 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5835-17 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3728-18 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5091-19 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3728-20 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1353-21 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1598-21 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1842-22 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5020-22 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1156-23 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2705-23 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3425-23 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 144-24 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1281-24 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 491-25 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2092-25 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 611-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1865-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2604-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2923-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3339-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4629-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2923-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 534-27 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2349-27 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2686-28 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3893-28 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2888-29 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3321-29 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3321-29 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 144-30 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1553-30 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4836-30 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 150-31 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3162-31 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3693-31 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4740-31 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 150-31 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3730-32 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 368-34 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1016-33 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1157-33 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2582-34 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2706-34 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4745-33 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4853-34 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5670-33 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 370-35 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1108-35 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2149-35 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3135-35 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 369-36 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2149-35 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2149-36 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5228-37 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5514-37 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 724-38 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1228-39 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5809-39 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1228-39 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2250-40 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4592-40 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 431-41 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3954-41 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1482-42 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2766-42 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2725-43 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3488-44 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4324-44 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5094-45 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1084-46 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2193-46 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3305-46 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1084-47 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5362-48 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1222-49 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2344-49 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 471-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1676-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3554-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4626-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3554-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4626-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1195-51 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1196-51 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 166-52 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5488-52 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3349-53 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2770-54 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 375-55 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2695-56 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3427-56 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5095-57 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3390-58 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3566-58 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 142-59 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1652-59 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2478-60 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3526-60 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2227-61 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2636-61 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2047-62 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2951-62 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 373-63 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3082-63 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 145-64 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5105-64 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4604-65 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4604-65 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1546-66 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2291-66 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3249-66 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3031-67 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2193-68 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2884-68 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4534-68 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5148-68 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4607-69 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5096-70 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2164-71 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3145-71 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5097-71 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3145-71 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3747-72 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3747-73 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5105-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5125-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 145-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4961-75 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2083-75 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3083-76 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3833-76 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2343-77 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 242-78 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4559-78 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 629-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1870-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2411-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4078-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 629-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4077-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4079-81 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4079-80 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 674-82 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 797-82 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2072-82 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3485-83 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2128-84 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3803-84 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5100-85 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2810-86 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3512-86 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3772-87 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4348-87 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3772-87 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1617-88 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1706-88 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3644-88 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5558-88 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2498-89 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4228-89 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5101-90 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3728-91 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 647-92 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4057-92 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5728-92 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2136-93 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3769-94 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5845-94 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 285-95 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1173-95 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5704-95 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4112-96 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3003-97 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4178-97 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4445-97 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3003-97 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1251-98 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3518-98 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4649-98 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2635-99 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2636-99 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 551-100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1193-100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1194-100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1903-101 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4449-101 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1477-102 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1963-103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2489-103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4283-103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1963-103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1670-104 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5493-104 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 265-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1559-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2094-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3540-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2207-106 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2271-106 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3262-106 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5067-106 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3002-107 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3002-107 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3980-108 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3979-108 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 632-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 671-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 759-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5201-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5205-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4739-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 482-110 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5404-110 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5508-110 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 713-111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4442-111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1167-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1656-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2295-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5313-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1168-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1655-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2295-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1654-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1032-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1075-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5263-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1032-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1075-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5262-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1075-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3522-114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3995-114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1243-117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1246-117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5408-117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5530-117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4961-118 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1000-119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4554-119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1000-119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2705-120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5233-121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5460-121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5103-122 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5103-123 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5104-124 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1263-125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1262-125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4311-126 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5737-126 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 182-127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2390-129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2747-129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4261-129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5295-129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5741-128 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2747-128 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5294-128 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2991-130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3413-130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4572-130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4573-130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4573-130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 782-131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1147-131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4043-131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4103-131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2194-132 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2735-132 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1709-133 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1189-135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1716-134 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3390-135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1884-136 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4814-136 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 625-137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3049-137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4524-138 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5183-138 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3558-139 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4750-139 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3004-140 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3004-140 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 850-141 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 188-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1652-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2217-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2218-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3892-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5724-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3892-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1674-143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4135-143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1553-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1560-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3694-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5043-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5664-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1560-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 506-145 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 695-145 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 758-145 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1049-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2722-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3372-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4599-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1049-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2722-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3372-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4600-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4599-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4978-147 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 481-148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4244-149 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1994-150 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4270-152 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4518-151 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4701-152 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 156-151 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3576-153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5483-153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5725-153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5484-153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1961-154 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5106-155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 683-157 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4744-158 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5810-157 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1727-159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2765-159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2840-159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3693-159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5070-161 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5070-160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4620-162 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4666-162 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2222-164 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2222-163 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1408-167 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1590-167 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3620-167 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3786-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4181-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4494-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5140-167 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5191-167 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5409-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3449-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5855-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3705-168 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5665-168 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3705-168 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5107-169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2572-170 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5589-170 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1563-171 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4618-171 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5801-171 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1563-171 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5677-172 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5678-172 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5110-173 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 446-174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5368-174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1943-174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2448-175 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5165-175 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5150-176 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5166-176 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4718-177 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5119-177 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 183-178 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 183-179 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 911-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1447-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1491-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3467-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4932-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4937-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5673-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 912-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1447-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1447-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4935-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4936-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 993-183 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1050-183 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1123-183 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1268-183 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2106-183 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2968-183 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4387-183 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4942-183 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5035-183 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 993-183 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2968-183 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4939-183 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4938-183 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5111-184 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4412-185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5112-186 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1035-187 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5387-188 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5113-189 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5405-190 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2247-191 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5603-191 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5114-192 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2751-193 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4833-193 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 319-194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5095-194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4096-195 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2506-196 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2781-196 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5336-196 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3215-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3215-198 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 323-199 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 572-199 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 931-199 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 323-199 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 825-200 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1759-200 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5115-201 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2457-202 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4557-202 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1379-203 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1485-203 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 394-204 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1073-204 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 828-205 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1924-205 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2068-205 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2720-205 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2994-205 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 828-205 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1924-205 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1589-206 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2721-206 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5695-206 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2722-207 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5063-207 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 394-208 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-208 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5134-208 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 562-209 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 562-209 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5586-210 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5853-210 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3931-211 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1796-213 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4834-212 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1796-213 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3875-214 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3875-215 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 524-216 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1181-216 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1418-216 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1737-216 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1884-216 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4072-216 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4910-216 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 354-217 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1135-217 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2893-217 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4622-217 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1989-218 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5419-218 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1516-219 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1582-219 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2770-220 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5118-221 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5116-222 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 257-223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2044-223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4401-223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1600-224 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2946-224 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2313-225 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4156-225 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2313-225 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5119-226 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3834-228 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3834-227 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1550-230 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1550-229 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 423-231 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3141-231 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4562-231 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 423-231 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2492-232 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 519-233 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1868-234 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4882-234 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3671-236 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3672-237 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 505-238 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1015-239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3946-239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2699-240 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5014-240 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2381-241 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4607-241 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5446-241 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5738-241 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 362-242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4558-242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 691-243 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4452-243 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5497-243 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-244 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5691-244 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3155-245 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3356-245 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1927-246 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2355-246 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5121-247 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 284-248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 480-248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 750-248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2453-248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4732-248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3580-249 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3167-250 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2114-251 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3569-251 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1271-252 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1627-252 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2262-252 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2947-253 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4014-254 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5113-254 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3518-255 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3518-255 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1117-256 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3824-256 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4639-256 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 558-257 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1687-257 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3502-258 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4171-258 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4555-258 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4557-259 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1113-260 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 762-261 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1458-261 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4982-262 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5805-262 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5122-263 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1379-265 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1629-264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2798-264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4844-265 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5416-264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1628-264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2205-264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1945-266 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2799-266 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5071-266 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2799-266 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5064-266 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 727-267 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 738-268 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1277-269 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1375-269 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3529-269 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3882-268 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1905-270 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2682-270 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 548-271 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5287-271 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2991-273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2991-272 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1412-274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1701-274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4450-274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4837-274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5254-274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5802-274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4450-274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1325-275 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2991-275 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1943-276 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1943-276 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 280-277 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1056-278 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1518-278 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2460-278 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1518-278 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2460-278 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1060-278 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1059-278 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 739-279 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 985-279 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1058-279 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 740-279 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1057-279 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1517-280 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3705-280 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2989-281 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2470-282 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4950-282 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5082-282 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2470-282 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1262-283 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5721-285 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 449-286 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2672-286 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3647-286 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5124-287 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5123-288 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 964-289 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2322-290 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2913-290 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4631-290 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5435-290 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2628-291 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2797-292 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2171-293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2633-293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3155-293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5203-293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 294-295 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 481-295 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1569-295 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1243-296 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5125-297 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1303-298 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1755-299 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4325-300 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2165-301 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2166-302 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5126-303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1344-304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1344-304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 199-305 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4591-305 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5746-305 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 199-305 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4591-305 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4831-306 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5410-306 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 689-307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4688-307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3898-308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2485-309 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4933-309 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1309-310 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4579-310 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1638-312 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1638-311 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5622-313 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3152-314 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2644-315 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5159-315 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5158-315 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 653-316 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3032-316 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1035-317 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5128-317 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2288-318 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5287-318 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5289-318 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2288-318 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3297-319 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3275-320 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5129-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1257-322 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1657-322 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 829-323 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2310-323 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3127-323 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3147-323 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4568-323 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2310-323 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3127-323 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3147-323 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3127-323 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4152-324 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4153-324 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1935-325 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1935-325 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2311-326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1682-326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 521-327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 520-327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1844-328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2612-328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2926-328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4119-328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5376-328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4119-328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1795-329 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3087-329 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1794-330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1794-330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2271-331 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2271-331 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4398-332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4653-332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4748-332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4669-333 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4858-333 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4858-333 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1366-334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3685-334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1010-335 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1615-335 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2551-335 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4766-335 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5266-336 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1137-337 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2825-338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4923-338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2506-339 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2648-339 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1700-340 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1863-340 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3297-341 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3501-341 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5804-341 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3064-342 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3385-343 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3238-344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3889-344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5407-344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5131-345 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1864-346 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4523-346 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5299-346 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 670-347 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1731-347 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1282-348 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5456-348 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4921-349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 445-350 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3382-350 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3318-351 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3372-351 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3775-352 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3908-352 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4599-351 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4830-352 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3319-351 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3372-352 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3775-351 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3908-351 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4600-352 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4830-351 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3320-352 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3317-352 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4028-353 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 557-354 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 880-355 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2697-355 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5850-355 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5133-356 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1358-357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 360-358 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1354-359 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3151-359 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3879-359 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2299-360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3031-360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5136-360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5617-360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-361 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4024-362 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4558-362 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4924-362 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5154-362 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2354-363 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2449-363 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2450-364 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 491-365 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5110-365 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5109-365 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4400-366 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4740-367 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2138-368 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 858-371 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3390-371 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 859-372 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3013-373 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3082-373 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1902-374 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2175-374 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2763-374 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3765-374 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2174-374 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3390-375 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3552-376 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3666-376 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1173-377 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1779-377 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2584-377 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2099-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2103-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2103-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 646-379 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2328-379 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2774-379 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 403-380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1256-380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1537-380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1908-380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4093-380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4896-380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5017-380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4896-380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5017-380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 470-381 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3101-381 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3943-381 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4094-381 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4999-381 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5156-381 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1937-382 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2074-382 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2772-382 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3944-382 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2073-382 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2772-382 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4294-382 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4013-383 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5279-383 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2431-384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3698-384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5424-384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 941-385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3800-385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 941-385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3800-385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2442-386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5232-386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5761-386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2931-387 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5778-387 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3032-388 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1595-389 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2945-389 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2714-390 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3539-390 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1403-391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1881-391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3855-391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4688-391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1402-391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4595-392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5729-392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1725-393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2329-393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2473-393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3941-393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5607-394 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1912-395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 397-396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1791-397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4564-397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1791-397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3872-398 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4089-398 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2400-399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3851-399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5194-400 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 848-401 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2242-402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2791-402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2305-404 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2815-404 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2775-405 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5172-405 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2297-406 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3293-406 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1083-407 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1024-408 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1866-408 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4014-408 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2362-409 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2459-409 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2819-410 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 488-411 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1062-411 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1869-412 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3197-412 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1637-413 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2047-413 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3240-413 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4081-413 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1145-414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1145-414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4195-415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5141-415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1246-416 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3673-416 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4446-416 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 543-417 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 856-418 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3679-418 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4130-418 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3742-419 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4316-420 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5144-420 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5142-420 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5142-421 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3555-422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1481-423 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1481-423 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 849-424 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2782-424 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1567-425 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3411-425 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4022-425 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4530-425 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1567-425 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4022-425 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4022-425 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2763-426 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5707-426 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5143-427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1155-428 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4681-429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3874-430 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5209-430 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3874-430 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1666-430 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1051-431 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1269-431 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3297-432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3207-433 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4009-433 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 879-434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1448-435 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5475-435 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 986-436 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3064-436 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5273-436 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2847-436 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3064-436 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3988-437 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5703-437 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2553-438 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2986-439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1673-440 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2218-440 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5008-440 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5147-441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5145-442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2759-443 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4218-443 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1558-444 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1651-446 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2031-444 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4870-446 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5338-444 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1651-446 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2031-445 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4870-446 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4844-447 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5149-447 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3595-448 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1233-449 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2908-449 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3984-449 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2908-449 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1343-450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1433-450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4803-450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5604-450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 501-450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4803-450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 500-450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2245-451 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2764-451 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4908-451 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2245-451 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4909-451 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 502-451 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5153-452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 463-453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2338-453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2701-453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3714-453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2338-453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3440-453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3547-454 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3667-454 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5154-455 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4067-457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4067-456 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4247-458 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3002-459 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3622-459 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4677-460 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4677-460 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3174-461 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4022-462 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5482-463 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5155-464 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2714-466 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5157-467 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2184-468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3481-468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3562-469 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2184-468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3480-468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3562-469 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2184-468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2989-471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 976-472 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3345-472 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3745-472 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2722-474 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2722-473 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4299-475 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4300-475 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2173-476 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3876-476 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5575-477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3764-478 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3764-478 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4046-479 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 641-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1834-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3579-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 975-481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1568-481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2147-481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2167-481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3156-481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1569-481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2168-481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2169-481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2148-482 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2013-483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2511-484 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5442-484 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5598-484 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5603-484 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 964-485 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4176-485 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3546-486 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5158-487 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1029-488 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1062-488 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 652-489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3641-489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2262-490 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2620-490 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2202-491 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5160-492 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3572-493 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5083-493 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 593-494 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 594-495 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 594-496 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 594-497 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 594-498 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2157-499 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2459-503 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2564-503 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5199-503 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3980-504 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3979-504 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 735-505 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1281-505 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1816-505 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5120-505 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5362-505 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2669-507 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4344-507 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5161-508 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5162-508 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3983-509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1564-510 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5229-510 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5619-511 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5620-511 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3002-512 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2970-513 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3153-513 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3236-513 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2971-513 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3154-513 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3237-513 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1081-514 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2589-514 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1194-515 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5455-516 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2266-517 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3213-517 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 564-518 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4200-519 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4312-519 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1405-520 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2891-520 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2927-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3674-520 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3839-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4268-520 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5657-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2927-520 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1345-522 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1406-522 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2881-522 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2892-522 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4464-522 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5441-522 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1345-522 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 958-523 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2918-523 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1131-525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1921-525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2958-525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3037-525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3316-525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4250-525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4692-525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4767-525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5555-525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5699-525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4691-525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1282-526 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1444-526 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4596-526 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4704-526 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1282-526 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3538-526 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4704-526 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 528-527 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1354-527 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1842-527 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1084-529 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 531-530 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1395-530 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1395-530 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3881-532 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3881-532 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 662-533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1355-533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2880-533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3459-533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5681-533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5682-533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 662-533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3459-533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5538-533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3259-534 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4773-534 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4773-534 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 645-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1320-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1356-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1193-536 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5385-536 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1134-537 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2100-538 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1344-539 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1345-540 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1345-541 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2090-542 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2685-542 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2988-542 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5776-542 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2893-543 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5677-543 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1685-544 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5167-544 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5577-545 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5598-545 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5165-546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5811-546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2600-547 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5130-547 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3072-548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3200-549 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1543-550 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2735-550 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3570-550 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5196-550 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1543-550 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1192-551 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1556-551 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3394-552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5706-552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4348-553 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4894-553 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4348-553 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2946-555 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2946-554 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1793-556 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3907-557 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1137-558 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3074-558 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3644-558 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4376-558 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5408-559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3003-560 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1132-561 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2470-561 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2660-562 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4799-562 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1444-563 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3089-563 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 851-564 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2983-564 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 851-564 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1014-565 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4237-565 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2448-566 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5806-566 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4533-567 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2310-568 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5028-568 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 584-569 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4219-569 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1072-570 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3324-570 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1903-571 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4866-571 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1184-573 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3891-573 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4855-573 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4904-573 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3114-573 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5702-573 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1576-574 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2044-574 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1825-575 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 653-576 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5170-577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1211-579 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1726-580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3253-580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3650-580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4444-580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 579-578 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3530-581 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5034-582 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3041-583 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1459-584 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1156-585 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4983-585 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5277-585 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2431-586 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2496-586 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5172-587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5340-588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5692-588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1525-589 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2166-589 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1524-589 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2166-589 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5173-590 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3207-591 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4009-591 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4009-591 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2645-592 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3033-594 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3517-594 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1333-594 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3516-594 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1333-594 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1333-594 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5791-595 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3518-596 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3519-597 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1516-598 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1852-599 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5730-599 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2688-600 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5352-600 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 736-601 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1888-601 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2060-601 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3854-601 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1888-601 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3364-602 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4858-602 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 607-605 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 607-604 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 607-603 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2379-606 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3945-606 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4328-606 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2785-607 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3605-607 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5265-607 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 880-608 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4369-608 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5508-610 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3339-611 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2189-612 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5375-612 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3090-613 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2264-614 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2012-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2946-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3603-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5318-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5331-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5787-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2946-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1006-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2772-616 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3939-616 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5176-618 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5180-617 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5034-619 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5034-620 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1246-621 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4898-622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5038-622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5245-622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5837-622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2706-623 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 817-624 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1107-624 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2596-624 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5183-627 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5190-628 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5181-631 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5184-630 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4233-632 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5182-633 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1262-634 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4284-634 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2463-635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2543-635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5596-635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2793-636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4567-636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5705-636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1110-637 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3982-637 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5157-638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5062-639 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3939-640 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1000-642 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1344-643 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1344-644 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1356-645 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4284-646 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1740-647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4457-647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1740-647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4926-647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5789-647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1785-648 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5187-648 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3181-649 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3578-649 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5226-649 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5188-650 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5189-651 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2005-652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2753-652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2862-652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4373-652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5159-652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5432-652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1077-652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2190-652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5158-652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3400-653 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2172-654 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3764-654 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4120-655 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1210-656 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3871-656 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1210-656 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2745-657 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3816-657 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1625-658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1432-659 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5247-659 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5641-660 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4890-661 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4466-666 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4465-665 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4466-664 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4465-663 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1821-667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2532-667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2557-667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2767-667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2229-667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3672-668 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2770-669 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4846-669 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5820-669 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4846-669 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1506-670 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2024-670 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5413-670 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1390-671 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3850-671 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4911-671 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3380-672 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3064-673 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1755-674 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1674-675 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2715-675 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2823-676 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5398-676 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5192-677 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4933-678 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2683-679 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3562-680 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3562-680 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3562-680 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1318-681 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5193-681 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3903-682 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2000-683 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5415-683 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1937-684 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4208-685 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1937-686 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2347-687 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2348-688 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5487-689 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4583-690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 886-691 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2815-691 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2335-693 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2335-692 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 735-694 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4032-694 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5580-694 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4685-694 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5207-700 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3897-702 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4319-701 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5194-702 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5721-702 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4319-701 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5264-703 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4030-704 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5415-704 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5840-704 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4852-704 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5720-705 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2618-710 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2732-710 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2913-709 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3314-709 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5435-709 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3314-709 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1723-711 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2055-711 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4144-711 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5400-711 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5195-712 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5231-713 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4444-714 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 961-715 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5004-715 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1185-715 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3038-715 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1929-716 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 715-717 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3568-718 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5816-718 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5347-719 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5531-719 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4331-719 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 965-720 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4286-720 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4737-720 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5196-721 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5633-721 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1390-722 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1903-722 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5676-722 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2848-723 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4281-723 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4742-723 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4280-723 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4742-723 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2181-725 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2455-725 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2724-724 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4140-724 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4148-724 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5507-724 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5579-724 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2181-725 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4140-724 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4588-724 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 852-726 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2467-726 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2657-726 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4121-726 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5696-726 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2468-726 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2468-726 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3349-728 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3349-727 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3349-729 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 924-730 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 924-730 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 971-731 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5197-732 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5198-733 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2161-734 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4827-737 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1562-738 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4048-738 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2535-741 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3662-741 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4776-741 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5473-741 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1674-742 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2715-742 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 744-743 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5040-743 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3668-744 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3619-745 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3429-746 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 488-747 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2011-748 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2042-748 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5051-748 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1219-749 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4093-749 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4951-749 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1475-751 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3441-751 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4688-752 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2552-753 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4743-753 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2552-753 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4743-753 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 460-754 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 460-754 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2747-755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2958-755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4388-755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5699-755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3635-756 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3882-756 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 758-757 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4167-758 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5201-760 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1846-763 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1557-764 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3311-764 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3810-765 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4033-765 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 342-766 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5118-766 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 660-767 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1301-767 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2220-767 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2316-767 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3061-767 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4117-767 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4545-767 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5411-767 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5623-767 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1301-767 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3061-767 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1535-768 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3739-768 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3793-768 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3792-768 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5759-768 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1757-772 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1877-772 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3718-772 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4847-772 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5646-772 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1877-772 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5648-772 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2301-773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 919-774 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4827-774 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 899-775 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2727-775 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3766-775 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 900-775 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5202-776 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 952-779 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 952-778 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 952-777 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5204-780 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1760-781 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2518-781 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1690-783 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5206-784 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1128-788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3424-787 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3463-788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4329-787 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4539-788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4778-787 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5808-788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5830-788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1340-788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4539-787 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 699-789 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 804-789 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 922-789 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1983-789 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4779-789 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5234-789 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5274-789 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1904-789 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5207-789 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 958-790 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1218-790 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2631-791 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2348-792 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4620-792 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4900-793 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4838-794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4900-794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 481-795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 923-795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 817-796 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3124-796 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4404-796 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1222-797 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1988-798 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3494-798 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4408-798 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1988-798 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 943-799 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1962-799 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5207-803 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3679-805 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1765-806 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3147-806 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1478-808 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1478-807 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1613-809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4921-809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 844-810 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5613-810 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5608-810 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3752-811 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4931-812 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4442-813 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4920-813 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5295-815 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5294-814 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1565-816 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3736-816 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2443-817 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 819-818 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4327-818 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1071-819 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5534-819 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1690-820 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5211-821 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4827-822 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2133-823 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4250-824 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2011-825 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3667-826 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1199-827 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2787-827 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2720-828 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3094-830 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4046-830 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4678-831 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5214-832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1678-833 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4636-833 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2235-834 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3028-834 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3380-834 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3452-835 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3659-835 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4777-835 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2959-837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5405-836 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5544-836 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5213-838 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2954-839 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4126-839 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4827-840 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5208-841 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1882-842 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1882-842 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1552-843 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5041-843 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3001-845 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3001-847 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3001-846 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1923-848 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3798-848 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3957-848 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5546-848 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5267-848 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5547-848 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2782-849 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3004-849 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3165-849 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3165-849 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4029-850 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4029-850 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1821-851 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1821-851 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3672-852 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2592-853 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2799-853 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1141-854 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5689-855 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2719-856 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3111-856 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5756-856 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2973-857 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4906-857 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3217-859 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3342-859 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2379-860 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3450-860 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3905-860 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4328-860 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4107-862 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4107-861 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5221-864 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5218-863 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4219-865 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1158-866 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5391-867 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1613-868 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2253-868 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4492-868 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2491-870 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2491-869 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4646-871 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4648-871 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4595-872 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5259-872 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4595-872 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5210-873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2669-874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4344-874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2253-876 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2253-875 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5222-877 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5219-878 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3393-879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3733-879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4760-879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5048-879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5669-880 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5773-880 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4782-879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2043-881 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2987-882 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3614-881 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4598-881 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5829-882 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4598-882 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2209-883 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5296-883 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5448-884 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5225-885 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3307-886 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4679-886 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5556-886 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2185-888 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3008-887 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4128-887 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1311-890 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2039-891 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5223-891 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2540-892 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3380-893 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4154-893 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4782-894 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4908-895 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4908-896 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4909-897 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4909-898 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5078-901 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5852-901 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4720-902 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3940-903 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4166-903 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3380-904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4154-904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3575-905 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4079-905 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5802-906 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5229-907 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3649-908 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5803-908 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2487-909 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4441-909 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1753-910 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5232-913 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2314-916 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2450-915 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2450-915 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2450-916 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2783-917 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4859-917 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2783-917 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4859-917 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5233-918 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4827-919 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1802-920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5671-920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4458-920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5168-921 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5752-921 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5561-923 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1347-924 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2563-924 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1347-924 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2563-924 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3154-925 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3368-925 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2399-926 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3840-926 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2708-927 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5323-927 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2172-928 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1791-929 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1791-929 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4122-930 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5819-931 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3485-935 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3557-935 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5423-936 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5472-935 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5474-935 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5421-936 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5364-937 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5365-937 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2894-938 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4599-938 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2894-939 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4600-939 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2813-940 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5674-940 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2117-941 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2553-941 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3211-941 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3549-941 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5478-941 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5643-941 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2553-941 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4884-942 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4884-942 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2561-944 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1533-945 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1533-945 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3338-947 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3917-947 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2464-946 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3917-946 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3307-948 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2710-949 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3321-949 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5501-949 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2213-950 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2813-950 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2599-951 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3432-951 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1044-952 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1102-952 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2361-952 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3073-952 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1046-953 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1198-953 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2663-954 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5234-954 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1516-955 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1372-956 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2300-957 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2315-957 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2914-957 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4412-957 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4635-957 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4869-957 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4412-957 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1218-958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1242-958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2149-958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2918-958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3607-958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4465-958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1242-958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2149-958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2918-958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3607-958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4466-958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4466-958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4465-958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4904-959 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5240-960 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2950-961 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1183-962 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5702-962 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2949-963 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3917-963 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4439-963 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2741-964 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3460-964 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3770-964 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4014-964 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4051-964 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5310-964 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2742-964 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3769-964 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1461-965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1461-965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1461-965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4860-967 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4860-966 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 972-968 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2950-968 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1745-970 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4135-970 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3315-971 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5786-971 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2262-972 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2606-972 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4098-972 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1851-972 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4811-972 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1247-973 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2087-973 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2087-973 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2774-974 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3052-976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3345-976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5241-977 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2961-978 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3365-978 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5717-978 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3365-978 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5361-978 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3365-978 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1518-979 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2460-979 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3706-979 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4968-979 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2460-979 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3706-979 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2244-980 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2651-980 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2774-980 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3810-980 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4033-980 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4284-980 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4728-980 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4284-980 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3811-981 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1114-982 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5552-982 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5783-982 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5005-982 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2484-983 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2823-983 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2170-984 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3839-984 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1382-986 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2718-986 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1205-987 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4423-988 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3201-989 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3469-990 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2305-991 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2296-992 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3741-992 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4796-992 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4795-992 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1123-994 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1186-993 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4912-994 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4942-994 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3560-995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3776-995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1350-996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2072-996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5237-997 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1089-998 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2111-998 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1042-1000 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1082-1000 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1255-1000 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5278-1000 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4763-1001 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2074-1002 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3607-1002 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4465-1002 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1586-1002 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2073-1002 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4466-1002 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4956-1003 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5712-1003 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4635-1004 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2127-1005 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2906-1005 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5318-1007 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1730-1008 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5354-1008 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5480-1009 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3929-1010 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5684-1012 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5683-1011 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5242-1013 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2213-1014 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2864-1014 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2864-1014 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1252-1015 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3458-1015 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5238-1015 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5357-1015 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1252-1015 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1960-1016 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5238-1017 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4790-1018 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1755-1019 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4149-1019 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2276-1020 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4291-1020 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 972-1021 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2629-1021 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 972-1021 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 972-1021 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1357-1023 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1357-1022 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5391-1024 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5243-1025 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3344-1027 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3344-1026 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4511-1028 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2158-1029 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2810-1029 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1480-1031 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1480-1030 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4096-1032 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1358-1033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4646-1034 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4646-1035 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4646-1034 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4895-1036 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2159-1037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3053-1037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4368-1037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2159-1037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3054-1037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4367-1037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3783-1037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3783-1037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1385-1038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3176-1038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3351-1038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3918-1038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5010-1038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5011-1038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1385-1038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3784-1038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3056-1038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3055-1038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1043-1039 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1076-1039 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3785-1040 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4532-1041 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4949-1040 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5244-1041 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1043-1041 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1076-1039 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2970-1040 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3154-1040 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4532-1040 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4532-1040 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1104-1045 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2277-1045 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3303-1045 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4402-1045 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4415-1045 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5173-1045 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5689-1044 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1101-1045 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5690-1044 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1103-1044 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2669-1044 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1198-1046 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2865-1046 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3757-1046 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4881-1046 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5320-1046 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5447-1046 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1228-1047 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1228-1047 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3134-1048 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4978-1048 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1945-1049 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2469-1049 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5063-1049 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1945-1049 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2469-1049 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5064-1049 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1187-1051 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1269-1051 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3168-1051 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3949-1051 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4957-1051 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5035-1050 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1268-1050 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3948-1050 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4957-1051 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4957-1051 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5512-1051 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5245-1052 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2149-1053 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2412-1054 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4425-1054 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3201-1055 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4396-1061 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2213-1062 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2813-1062 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5188-1062 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5380-1062 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1517-1063 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2811-1063 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3757-1063 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5053-1063 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1517-1063 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4994-1064 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2592-1065 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2592-1066 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2003-1067 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2266-1067 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4929-1067 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5366-1067 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2832-1068 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2832-1068 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5031-1069 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5248-1069 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2035-1070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2667-1070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5553-1070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2407-1071 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3005-1072 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5716-1073 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2219-1074 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3952-1074 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2573-1075 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2703-1075 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2573-1075 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1930-1076 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-1076 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1930-1076 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-1076 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-1076 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2249-1077 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2753-1077 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2837-1077 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5601-1077 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5602-1077 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5834-1077 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3032-1078 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4774-1080 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4774-1079 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5312-1081 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1952-1083 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2343-1083 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2297-1084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4680-1084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5552-1084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5719-1084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1786-1085 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2298-1085 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1669-1086 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4981-1087 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4981-1087 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1939-1088 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5680-1088 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1938-1088 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2743-1089 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2513-1090 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4358-1090 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1205-1091 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4290-1091 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2143-1092 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2726-1092 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2143-1092 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1470-1093 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1469-1094 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1485-1096 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1485-1095 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4260-1097 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1766-1098 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2677-1098 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2297-1099 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2297-1099 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3523-1100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3523-1100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4551-1102 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5250-1105 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5576-1106 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5577-1106 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2424-1107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2596-1107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2424-1107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3582-1108 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2747-1109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2321-1110 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3193-1110 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5253-1111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2452-1113 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4504-1113 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5080-1113 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3293-1114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3578-1115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5041-1115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5226-1115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5227-1115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5847-1115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3578-1115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3601-1115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3601-1115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1541-1116 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2125-1116 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1957-1117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2568-1118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1771-1120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2504-1119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4440-1119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4516-1120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2504-1119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3548-1121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5254-1121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1499-1122 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1918-1122 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2082-1122 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1545-1124 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4961-1124 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4961-1124 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2568-1125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2568-1126 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5256-1127 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1306-1128 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2320-1129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4529-1129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1382-1130 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3392-1130 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4686-1132 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5258-1133 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1228-1134 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2717-1134 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5503-1134 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1229-1135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5098-1135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2459-1136 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5649-1136 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3074-1137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3749-1137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5257-1137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3100-1137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2264-1138 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4901-1138 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1358-1139 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3245-1139 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1358-1139 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2803-1141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2986-1140 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5108-1141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5250-1140 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5485-1141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2467-1142 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2987-1142 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4999-1143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5259-1144 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2383-1145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2843-1145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5224-1145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5445-1145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5448-1145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5266-1145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3667-1146 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4184-1146 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3713-1147 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5261-1148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1241-1150 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2938-1150 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3336-1150 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2588-1151 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4350-1151 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1814-1152 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3560-1152 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3619-1153 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3810-1154 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2137-1155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3023-1156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3465-1156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3507-1156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5550-1155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5629-1155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5667-1155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2138-1157 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2706-1157 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3362-1158 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4742-1158 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5770-1158 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5260-1159 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2456-1160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3008-1160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5263-1161 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5262-1162 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4792-1163 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4791-1164 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4792-1165 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1565-1166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3906-1166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4660-1166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3906-1166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4563-1167 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5114-1169 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2580-1170 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4981-1171 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5594-1171 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1485-1172 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1944-1172 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2829-1173 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3091-1173 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3639-1173 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4201-1173 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4225-1173 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4684-1173 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5621-1173 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3091-1173 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4224-1173 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5704-1173 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1517-1174 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4226-1174 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5264-1174 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1517-1174 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1517-1174 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3363-1179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3609-1180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4053-1180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5698-1180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3541-1180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5019-1181 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1191-1182 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2652-1184 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5845-1183 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3227-1185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1707-1186 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3915-1188 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5403-1188 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3163-1189 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3390-1189 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5423-1189 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3163-1189 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3390-1189 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5421-1189 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3163-1189 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5364-1189 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5365-1189 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1963-1190 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4617-1190 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2142-1191 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2161-1191 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4160-1191 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4082-1193 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4320-1194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5749-1193 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4082-1192 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3524-1196 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5286-1195 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1960-1196 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1962-1197 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3135-1197 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2104-1198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3547-1198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3667-1198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4345-1198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5637-1198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1175-1198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3547-1198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5447-1198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1176-1198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1177-1198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1518-1199 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2609-1199 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1518-1199 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2608-1199 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2786-1199 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1178-1199 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3388-1200 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4004-1200 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5582-1200 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4656-1201 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5439-1201 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5438-1201 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1206-1202 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2968-1202 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4179-1204 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4980-1204 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5089-1203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5163-1203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2725-1205 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3958-1205 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3959-1205 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4421-1205 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4422-1205 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2940-1206 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3887-1207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5004-1207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1987-1207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3391-1207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1247-1208 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4902-1208 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5269-1209 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2253-1210 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3871-1210 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4138-1210 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2253-1210 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5726-1210 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1639-1211 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1917-1211 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3179-1211 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1917-1211 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3179-1211 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4606-1212 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5026-1213 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5717-1213 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5271-1214 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3039-1215 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4456-1215 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3710-1216 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4360-1216 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2662-1217 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2889-1217 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1299-1218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3607-1218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4574-1218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4713-1218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1296-1218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3607-1218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4713-1218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1298-1218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4713-1218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1297-1218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1990-1220 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1810-1221 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2752-1221 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1350-1222 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3859-1222 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3428-1223 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5082-1224 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5268-1225 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5274-1226 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1246-1227 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5412-1228 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1383-1230 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3054-1231 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4439-1231 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3496-1232 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4438-1232 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1342-1233 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1653-1233 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2430-1233 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2496-1233 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4350-1234 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4452-1234 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1777-1236 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3046-1236 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1777-1236 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3606-1238 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4282-1238 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5241-1237 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5747-1237 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5650-1237 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3606-1238 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1683-1241 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2086-1240 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2938-1241 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3336-1239 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3967-1240 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4084-1240 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4139-1241 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4525-1241 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5698-1241 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1683-1240 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3541-1240 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4084-1239 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4826-1242 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4826-1242 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5551-1243 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1827-1244 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1960-1244 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3312-1244 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1616-1245 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1855-1245 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1617-1245 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1854-1245 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2874-1246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3824-1246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5177-1246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3574-1247 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4571-1247 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5496-1247 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4291-1248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4330-1248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4291-1248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2263-1249 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4565-1252 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4623-1252 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5115-1253 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5630-1253 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5278-1254 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1657-1257 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2094-1258 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2526-1258 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5070-1258 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5070-1258 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4208-1259 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5494-1259 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2338-1260 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5280-1261 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2256-1263 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4715-1263 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4734-1262 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5548-1262 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5777-1263 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4715-1262 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4734-1263 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1843-1264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3899-1264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5131-1264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5511-1264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5659-1264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3153-1265 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3812-1265 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-1265 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4093-1266 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1510-1267 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2662-1267 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2008-1269 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3953-1269 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4645-1268 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5279-1270 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2262-1271 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4218-1272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5220-1272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5282-1273 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1962-1274 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2149-1274 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4466-1274 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1962-1275 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2149-1275 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4465-1275 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1547-1276 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3201-1276 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1774-1278 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4583-1277 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5283-1279 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3632-1280 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3980-1280 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4792-1283 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2271-1284 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2714-1284 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2272-1285 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3640-1285 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3922-1285 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4879-1285 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5070-1285 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2272-1285 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3640-1285 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3921-1285 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1838-1286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2048-1287 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3764-1287 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1633-1288 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5178-1288 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5791-1288 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5143-1289 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5813-1290 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2011-1291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2012-1292 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5216-1293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5217-1293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2306-1294 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3945-1294 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3945-1294 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2663-1295 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3449-1300 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2032-1301 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4641-1301 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5844-1302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1304-1303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4900-1303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5286-1305 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2118-1306 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2643-1308 connects the same voltage levels (20.0, 20.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5825-1309 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5147-1310 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5388-1310 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1349-1311 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1615-1311 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3911-1311 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3347-1312 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3710-1312 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4841-1312 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5289-1313 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2928-1314 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3937-1314 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5288-1315 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2621-1316 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5288-1316 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5290-1316 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1317-1318 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1986-1318 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2607-1319 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5630-1319 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2607-1319 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2942-1320 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2136-1322 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2136-1321 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3431-1323 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1383-1324 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4410-1324 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5588-1324 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5440-1325 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3679-1326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5651-1326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4046-1327 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3258-1328 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3527-1328 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2100-1329 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5242-1329 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4429-1330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1667-1331 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4273-1331 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5745-1331 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2077-1332 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3032-1332 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3065-1332 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4721-1332 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1542-1333 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3433-1333 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4029-1333 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1542-1333 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3033-1333 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4029-1333 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5102-1334 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5355-1335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5833-1335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2135-1336 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5005-1336 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4112-1337 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5172-1337 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4884-1338 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2086-1339 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5160-1339 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2087-1341 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1845-1342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1846-1342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1756-1344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5281-1344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4198-1345 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3010-1346 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2362-1352 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2362-1351 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1598-1353 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3879-1354 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1362-1355 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2359-1355 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1388-1356 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1950-1356 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2625-1356 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2693-1356 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2694-1356 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2699-1356 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1387-1356 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1461-1357 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5335-1357 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5135-1358 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3760-1359 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3811-1359 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4112-1360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4473-1361 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5359-1362 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3834-1364 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3834-1363 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2459-1365 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5770-1366 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1708-1369 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1714-1368 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1715-1367 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1798-1370 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1381-1371 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3257-1371 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5293-1371 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5295-1371 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5294-1371 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5310-1373 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2078-1372 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4005-1374 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4079-1375 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1775-1376 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2541-1377 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5296-1378 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4844-1379 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2346-1380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3707-1380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3917-1380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5237-1380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4450-1383 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5276-1383 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1665-1384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2051-1384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3275-1384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4003-1384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5520-1384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5760-1384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2539-1384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4002-1384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4945-1384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5519-1384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3438-1386 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4096-1386 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3412-1388 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2611-1387 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2754-1389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2662-1391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3050-1391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3394-1392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5529-1392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2147-1393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3866-1393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5139-1393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5297-1393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3193-1394 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4974-1395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4973-1395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4975-1396 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5298-1397 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5255-1398 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2568-1398 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5299-1399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2343-1400 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4330-1401 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5594-1401 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5300-1404 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1952-1405 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3702-1405 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3865-1405 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3865-1405 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1300-1408 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1813-1408 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4338-1408 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5098-1409 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5665-1409 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2871-1410 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3173-1410 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5571-1411 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5803-1412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5301-1413 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2237-1414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4149-1414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5797-1414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4681-1415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5768-1415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2485-1416 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2873-1416 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4627-1416 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-1417 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-1417 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2610-1419 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3235-1418 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2611-1419 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3234-1419 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3675-1420 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3675-1420 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3879-1422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3879-1421 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3608-1423 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2008-1424 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3888-1425 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5304-1425 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5305-1425 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5307-1426 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 978-1427 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5026-1427 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5094-1427 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5361-1427 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4004-1428 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5319-1428 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4051-1429 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4520-1429 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1433-1430 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2552-1431 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3002-1431 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1064-1432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4536-1432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5032-1432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1064-1432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2433-1433 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4995-1433 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 926-1434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1245-1434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1616-1434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1773-1434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2540-1434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1780-1435 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5309-1436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1684-1437 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4227-1438 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2495-1439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2736-1439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4207-1439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4697-1439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5283-1439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2495-1439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2736-1439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2495-1439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4902-1440 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5496-1440 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4901-1440 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2961-1441 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5798-1441 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1267-1443 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1323-1443 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3050-1442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3071-1443 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4582-1443 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4767-1442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5672-1443 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5793-1442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2663-1444 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4704-1444 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2663-1444 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1447-1445 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1447-1445 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5310-1446 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3985-1448 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1001-1449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4763-1449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 972-1450 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4802-1452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4802-1451 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2686-1453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5283-1453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3461-1454 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5311-1455 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3201-1456 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4331-1459 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3265-1460 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4643-1460 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4659-1460 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5014-1460 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5113-1460 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4642-1460 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5246-1460 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2144-1461 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2145-1461 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5335-1461 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1930-1462 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4860-1462 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5086-1462 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1930-1462 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4860-1462 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-1462 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1622-1463 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2748-1463 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3528-1463 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5332-1463 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3269-1463 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4882-1464 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3202-1465 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4884-1465 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2535-1466 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5019-1467 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5748-1467 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3560-1468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3560-1468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1709-1469 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3562-1470 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1709-1469 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3036-1471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4359-1471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5041-1471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3036-1471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4721-1472 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4863-1472 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2143-1473 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5278-1474 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4940-1475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3632-1476 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1889-1477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2007-1477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2702-1477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2944-1477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2943-1477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5532-1477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1754-1478 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2046-1478 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3744-1478 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3768-1478 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1754-1478 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3768-1478 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2518-1479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2518-1479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2554-1481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4178-1481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4279-1481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4445-1481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5111-1481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5272-1481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5693-1481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5267-1481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3550-1482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4578-1482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3366-1482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4738-1483 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4738-1483 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2133-1484 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2798-1485 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4848-1486 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4248-1487 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5314-1487 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2806-1488 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1673-1489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5724-1489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1717-1490 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5061-1492 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3017-1493 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4963-1493 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2607-1498 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2626-1500 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4001-1500 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2279-1501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3410-1501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4062-1501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4716-1501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5066-1501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4062-1501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2763-1502 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2281-1503 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4693-1503 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4707-1503 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5315-1504 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4827-1505 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3371-1506 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5675-1506 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3077-1507 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3042-1508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3251-1508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2422-1509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5096-1509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4212-1511 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4212-1511 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2111-1512 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3646-1512 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3737-1513 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3894-1513 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4537-1513 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3429-1514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3737-1514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3737-1514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5814-1515 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2360-1516 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2604-1516 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4045-1516 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5528-1516 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5713-1516 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4045-1516 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3259-1517 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2351-1518 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3416-1518 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2350-1518 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4791-1519 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4792-1519 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1634-1526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2415-1526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3435-1526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4127-1526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5186-1526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2415-1526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3739-1527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4683-1527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2326-1528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4915-1528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4914-1528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4429-1529 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5316-1530 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1837-1531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1780-1532 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2575-1532 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1549-1533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1566-1533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4868-1534 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4933-1533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5722-1533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4115-1533 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5447-1535 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5759-1535 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2472-1536 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2609-1536 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2948-1536 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3626-1536 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3706-1536 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2472-1536 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2608-1536 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1850-1537 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5017-1537 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5367-1537 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5854-1537 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2931-1538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5843-1538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2103-1539 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3081-1539 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3546-1539 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5185-1539 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5367-1540 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4863-1541 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2016-1542 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2520-1542 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2017-1542 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4859-1542 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1932-1543 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3608-1543 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3978-1543 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5633-1543 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3608-1543 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1736-1544 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5318-1544 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3528-1547 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2152-1548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2635-1548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2152-1548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2635-1548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4183-1550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5740-1550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4183-1550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5319-1551 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1836-1553 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5320-1554 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3244-1555 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4267-1555 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2746-1556 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3311-1557 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2522-1559 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4844-1559 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2521-1559 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4675-1561 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1848-1563 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5500-1563 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1818-1563 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1849-1563 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1833-1564 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3244-1564 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3377-1564 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3244-1564 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3244-1564 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1781-1565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4660-1565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4660-1565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2013-1567 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4377-1570 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4856-1570 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5198-1570 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5269-1571 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5321-1572 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4434-1573 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4688-1573 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5322-1574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3752-1575 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3875-1575 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3074-1576 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4337-1576 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4453-1576 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5324-1576 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3951-1577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5146-1577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5697-1577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2986-1577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4532-1578 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4532-1579 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4532-1580 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4532-1581 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1516-1582 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2552-1583 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2552-1583 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3335-1584 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5325-1584 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2004-1585 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3857-1585 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4151-1585 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2004-1585 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3607-1586 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4233-1587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4997-1587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3277-1588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3289-1588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4001-1588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5055-1588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5592-1588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3277-1588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3599-1588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5055-1588 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2721-1589 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4167-1589 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2622-1590 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5704-1591 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5326-1592 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3788-1593 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4712-1593 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4696-1593 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4538-1594 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5328-1594 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4754-1595 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5344-1595 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1612-1596 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3931-1596 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2357-1599 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4980-1598 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5403-1599 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4372-1599 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4979-1598 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2771-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2816-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3018-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3075-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3259-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4306-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4737-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2946-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2772-1601 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3433-1601 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3939-1601 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4774-1601 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4860-1601 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4774-1601 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2616-1602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3063-1602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3426-1602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4874-1602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2616-1602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3062-1602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2893-1603 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4041-1603 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4211-1604 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4861-1604 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5085-1603 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4041-1603 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5329-1605 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5330-1606 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3049-1607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4523-1607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5331-1608 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4348-1609 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4348-1609 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2630-1610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4458-1610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5153-1610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2095-1611 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2307-1611 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3321-1612 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3321-1612 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4675-1613 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2120-1614 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3513-1617 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4017-1616 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5567-1616 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5771-1616 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2292-1618 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4999-1618 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3371-1619 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5675-1619 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1946-1620 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2693-1621 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5498-1621 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5101-1623 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5743-1623 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3962-1624 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5439-1625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5438-1625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5644-1626 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2262-1627 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5333-1630 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3632-1631 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2009-1632 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5398-1633 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3429-1634 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2208-1635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5418-1635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1856-1636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5116-1636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2047-1637 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2533-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3029-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3583-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4129-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4517-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2533-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4129-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4517-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3179-1639 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4138-1640 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4363-1640 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1807-1641 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4755-1641 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3134-1642 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5334-1643 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2547-1644 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2973-1644 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4755-1644 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5335-1645 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1725-1646 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3409-1646 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4458-1646 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1942-1647 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1942-1647 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5336-1648 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2864-1650 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5337-1649 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1878-1651 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5462-1653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5338-1657 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5339-1658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2647-1659 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2803-1660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1718-1661 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2807-1661 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4781-1661 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2127-1662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3610-1662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1791-1663 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1791-1663 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2428-1664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4856-1664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5057-1664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3275-1665 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5341-1666 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5025-1667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1944-1668 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2006-1669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3027-1669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3719-1669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3740-1669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4234-1669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5049-1669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5763-1669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3026-1669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5766-1670 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2041-1671 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4729-1671 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5342-1672 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3405-1673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4088-1673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5008-1673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3405-1673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5427-1674 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1868-1675 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3152-1675 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3554-1677 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4636-1678 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5307-1678 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5502-1678 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5748-1678 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1680-1679 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4519-1679 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2485-1680 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2516-1681 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4624-1681 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3942-1682 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5533-1682 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5661-1682 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5464-1683 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3049-1684 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3658-1686 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4518-1686 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5334-1688 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5607-1689 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5605-1689 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1639-1690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1726-1690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2826-1690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3323-1690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3713-1690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3752-1690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3323-1690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5211-1690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5346-1691 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3715-1692 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5348-1693 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2459-1694 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2459-1694 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2459-1694 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4221-1696 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4221-1695 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4218-1697 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4220-1699 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4220-1698 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5336-1700 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4528-1702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5735-1702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5733-1702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4354-1703 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2791-1704 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2791-1705 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5302-1705 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5303-1705 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5349-1705 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5460-1705 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1715-1709 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2733-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3216-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3934-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4074-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1714-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3216-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3934-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3216-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3216-1708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1716-1711 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1716-1713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1716-1710 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1716-1712 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3217-1716 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4640-1716 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3217-1716 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3614-1716 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5351-1716 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5350-1716 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2235-1717 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2252-1717 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3130-1717 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4615-1717 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5727-1717 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2252-1717 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2134-1718 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5351-1720 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5350-1719 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2237-1721 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3868-1722 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4631-1722 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4730-1722 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5107-1722 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5104-1722 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2055-1723 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3111-1724 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5353-1729 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3979-1731 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5326-1731 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2806-1732 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5355-1733 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5356-1734 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1993-1735 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4016-1735 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4085-1735 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4169-1735 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5569-1735 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4085-1735 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4542-1736 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3900-1738 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3915-1738 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5359-1738 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1800-1739 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5526-1739 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1745-1742 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1745-1741 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3103-1744 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3103-1743 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1751-1745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3279-1745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4991-1745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1750-1745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1749-1745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2332-1752 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5827-1753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2331-1753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2863-1753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5532-1752 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2492-1754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3470-1754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3834-1754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3863-1754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4256-1754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3470-1754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3834-1754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2935-1755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3095-1755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3099-1755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5581-1755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1757-4134 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5357-1758 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2011-1759 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2518-1760 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2689-1761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2312-1762 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2146-1763 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2334-1763 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3269-1764 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2677-1766 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4100-1766 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5844-1766 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1783-1766 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2677-1766 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2850-1769 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2850-1768 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2850-1770 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2850-1767 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4516-1771 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5070-1772 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2707-1773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2684-1774 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3882-1774 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2321-1776 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3309-1777 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3571-1777 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3715-1777 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3867-1776 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3910-1776 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5118-1776 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3715-1777 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3032-1778 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3065-1778 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3199-1778 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4010-1778 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5400-1778 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4925-1779 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5191-1779 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2575-1780 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2984-1780 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4930-1780 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5308-1780 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2471-1781 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4622-1781 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5192-1781 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2313-1782 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2500-1782 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4948-1783 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4157-1784 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3462-1785 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4931-1785 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5187-1785 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5839-1785 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5006-1786 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5329-1787 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4649-1788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5383-1788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4308-1789 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4649-1789 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3276-1790 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4587-1790 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4972-1790 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3974-1791 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4297-1791 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3007-1792 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3032-1793 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3400-1793 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3032-1793 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3409-1794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4893-1794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4459-1795 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3566-1797 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3566-1798 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5451-1799 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1799-1800 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1801-4727 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2395-1802 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4409-1803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4468-1803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4896-1803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3842-1804 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5156-1804 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2759-1806 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2759-1805 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3376-1807 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1936-1808 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3189-1808 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3933-1808 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5419-1808 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5582-1808 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5826-1808 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2165-1809 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2165-1809 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2752-1810 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3361-1810 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5282-1810 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3361-1810 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4538-1810 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3273-1811 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5360-1812 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3441-1814 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5458-1815 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5644-1815 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4816-1817 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5371-1817 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1821-1819 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1821-1819 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5361-1820 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2483-1822 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2567-1822 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4008-1822 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4547-1823 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4547-1823 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2166-1824 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2166-1824 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3671-1825 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3671-1825 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3016-1826 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3543-1826 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1962-1828 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2716-1828 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4073-1829 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3086-1830 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3555-1831 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4413-1831 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5769-1831 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3555-1831 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4676-1832 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4676-1832 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4732-1834 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5809-1835 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5425-1836 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2021-1837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2421-1837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2855-1837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3637-1837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4864-1837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5317-1837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2479-1837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5464-1838 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5525-1838 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5364-1840 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5365-1839 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2135-1841 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2606-1841 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2022-1842 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2328-1842 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4883-1842 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5333-1843 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1943-1847 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2883-1851 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4277-1852 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2304-1853 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2504-1853 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2260-1856 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2428-1856 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4331-1856 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2779-1857 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4009-1857 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4742-1858 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3071-1859 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3077-1859 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3036-1860 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3335-1861 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4026-1861 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4289-1861 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3655-1862 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4014-1866 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4508-1867 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4132-1868 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1730-1869 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2303-1869 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3196-1869 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5139-1871 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5276-1872 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5588-1872 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1947-1873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2563-1873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1821-1874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2685-1875 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5369-1876 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3656-1879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5370-1880 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3670-1881 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3856-1881 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4747-1881 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5402-1881 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4005-1882 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4005-1882 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3747-1883 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3061-1885 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3061-1886 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4228-1887 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5372-1890 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5373-1891 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2695-1892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1902-1900 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1902-1899 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1902-1898 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1902-1897 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3876-1901 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5060-1901 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4090-1902 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3971-1903 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4217-1903 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4260-1903 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4866-1903 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5275-1903 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5475-1903 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3985-1903 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5676-1903 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3985-1903 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2915-1904 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3611-1904 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3972-1904 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5274-1904 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4456-1906 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4927-1906 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4267-1907 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5091-1908 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4782-1909 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5077-1910 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2085-1911 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5652-1911 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2085-1911 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4291-1912 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5138-1912 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5319-1912 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4293-1913 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5384-1913 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5301-1915 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5309-1914 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5726-1916 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2254-1917 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5179-1918 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3321-1919 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5301-1919 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3321-1919 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5376-1920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5126-1921 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5016-1922 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3930-1923 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2098-1924 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3835-1924 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5433-1925 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2325-1926 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2194-1927 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2355-1927 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2409-1927 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4246-1927 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4246-1927 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5331-1928 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3423-1929 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3423-1929 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1937-1930 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4532-1930 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1937-1930 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4532-1930 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3877-1931 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4120-1931 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4120-1931 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5340-1932 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2562-1934 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2974-1934 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4459-1934 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2974-1934 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3939-1935 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4548-1935 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4859-1935 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2289-1935 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4548-1935 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4294-1937 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2661-1940 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4102-1941 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2209-1942 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2930-1942 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3133-1943 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4067-1943 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5368-1943 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2209-1942 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4067-1942 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3397-1944 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4844-1944 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4844-1944 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3503-1948 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2047-1949 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2699-1950 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2891-1951 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2914-1951 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5380-1953 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3311-1954 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5285-1955 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5725-1956 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2686-1957 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3272-1958 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3311-1958 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3452-1959 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4431-1959 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2298-1961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4113-1960 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5006-1961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5286-1960 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-1962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-1962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-1962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3015-1964 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3610-1965 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3518-1966 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1979-1977 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1979-1976 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1979-1975 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1979-1974 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1979-1973 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1979-1972 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3815-1978 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4486-1978 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3816-1979 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4488-1979 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3294-1981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4114-1982 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4322-1984 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4755-1984 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4344-1985 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2247-1986 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3227-1987 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4259-1988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3933-1989 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5190-1990 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5370-1990 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5384-1991 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5389-1991 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5385-1992 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3200-1993 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5734-1994 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2304-1995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2313-1995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3203-1995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4192-1996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4516-1996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4748-1996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4192-1996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4516-1996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4516-1996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2519-1997 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2519-1997 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5387-1998 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4940-1999 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4075-2001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4872-2001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4075-2002 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4873-2002 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5366-2003 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2681-2004 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3288-2004 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2916-2004 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4151-2004 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5517-2005 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3719-2006 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4645-2009 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4163-2010 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5179-2010 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2818-2011 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5051-2011 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5214-2011 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3938-2012 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4456-2012 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4863-2012 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3410-2013 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4312-2014 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5393-2015 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5846-2018 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5847-2019 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5466-2020 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3186-2022 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4940-2022 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3616-2023 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2711-2025 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4295-2025 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2550-2026 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4742-2026 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5654-2027 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5396-2028 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5395-2029 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5398-2030 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2092-2031 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2690-2031 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3382-2031 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2945-2033 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4754-2033 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4880-2034 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5563-2035 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5564-2035 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4127-2036 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5186-2036 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5314-2037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5568-2037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5569-2037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2435-2038 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2060-2039 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2825-2039 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3750-2039 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5221-2039 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5223-2039 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5218-2039 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4456-2040 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4858-2040 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4729-2041 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3870-2042 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3614-2043 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2449-2045 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2668-2045 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2222-2048 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2234-2048 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2273-2048 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2842-2048 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2223-2049 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2745-2049 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2763-2049 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3765-2049 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4068-2049 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4182-2049 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4488-2049 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5402-2050 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2986-2052 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2986-2052 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3510-2053 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5463-2053 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4811-2054 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5305-2054 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3198-2055 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4313-2055 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5400-2055 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4314-2055 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2351-2056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3517-2056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4774-2056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2350-2056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3516-2056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4774-2056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3621-2059 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3621-2058 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3621-2057 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5064-2061 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5063-2062 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5063-2063 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5064-2064 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5063-2065 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5064-2066 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5399-2067 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2126-2069 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2736-2069 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4697-2069 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4095-2070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2916-2071 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3841-2072 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3859-2072 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5581-2072 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2806-2075 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3974-2076 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4403-2076 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2125-2077 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4967-2079 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5720-2079 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4967-2078 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5263-2081 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5262-2080 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2278-2082 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3258-2082 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4961-2083 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5405-2084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3049-2085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3613-2085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4052-2085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4523-2085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4525-2086 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2112-2087 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2678-2087 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5292-2087 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4466-2088 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-2088 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3621-2089 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3621-2089 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2734-2090 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2618-2091 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2202-2092 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2284-2094 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5851-2093 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2093-1494 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3139-2095 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2569-2096 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4992-2096 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2451-2097 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5465-2097 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2488-2100 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4305-2100 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4305-2100 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4382-2101 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4382-2101 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3113-2102 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2203-2103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3081-2103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4698-2103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5185-2103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3081-2103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4392-2103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5764-2103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4393-2104 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5637-2104 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2877-2105 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5623-2105 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2111-2108 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2111-2107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2111-2110 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2111-2109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2620-2111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3646-2111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4165-2111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5112-2111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5204-2111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2619-2112 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3901-2113 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5406-2113 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3003-2114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3666-2115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3700-2115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5407-2116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3269-2117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3015-2118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2996-2119 connects the same voltage levels (20.0, 20.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2465-2121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3175-2121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3177-2122 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3448-2122 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4185-2122 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3410-2123 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3526-2123 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2768-2124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3352-2124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3794-2124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4060-2124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5388-2124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3794-2124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5386-2124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5381-2126 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2680-2127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3610-2128 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3955-2127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4015-2128 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2004-2131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2004-2130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2004-2129 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4670-2132 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2798-2134 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4781-2134 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5818-2134 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2238-2134 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2798-2134 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2798-2134 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4194-2135 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4195-2135 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2499-2136 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3225-2136 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5252-2137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5355-2137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5522-2137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5062-2139 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5061-2140 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2431-2141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2431-2141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1910-2142 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2760-2142 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4423-2143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4828-2143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4423-2143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4828-2143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4829-2143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3195-2146 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3545-2147 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4353-2147 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5297-2147 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5561-2147 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4352-2147 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5525-2148 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4164-2150 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5739-2150 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5409-2151 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3543-2153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5410-2154 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3656-2155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3543-2156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5551-2156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1996-2157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1996-2157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2161-2160 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5315-2161 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4828-2162 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2104-2163 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2068-2165 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3208-2165 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5269-2165 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4753-2165 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2233-2166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3708-2166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3927-2166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5062-2166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5073-2166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5321-2166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5061-2166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5072-2166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5061-2166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5685-2170 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2781-2171 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4433-2171 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3410-2172 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3526-2173 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3876-2173 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3410-2172 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3526-2173 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4646-2176 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4646-2176 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2222-2178 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2222-2177 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2684-2179 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4018-2180 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2882-2181 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3877-2181 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2187-2184 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2294-2184 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3097-2184 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3296-2184 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3709-2184 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4806-2184 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2187-2184 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4806-2184 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4806-2184 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2325-2185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2852-2185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3008-2185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3963-2185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2324-2185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3964-2185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5413-2186 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5414-2188 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3924-2189 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5431-2191 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5415-2192 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2804-2195 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2198-2196 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3676-2196 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3676-2196 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2199-2196 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2200-2197 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3908-2197 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3908-2197 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3813-2201 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4928-2201 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5764-2203 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2990-2204 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3138-2205 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5416-2205 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3137-2205 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4022-2206 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3133-2209 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5419-2210 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5422-2211 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2503-2212 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2872-2214 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5176-2214 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5180-2214 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5423-2216 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5421-2215 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4807-2219 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5424-2219 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2582-2221 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2842-2222 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2469-2224 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4977-2224 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2225-1496 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4166-2225 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5425-2225 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5426-2226 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5059-2227 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5427-2228 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2501-2230 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2523-2230 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3764-2231 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3764-2231 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2994-2232 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3836-2232 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5065-2232 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5270-2232 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2586-2233 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3947-2233 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5062-2233 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5851-2233 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2586-2233 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5695-2233 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3764-2234 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2797-2236 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3521-2236 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2797-2236 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4015-2237 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4781-2238 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3489-2239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3489-2239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2859-2239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5527-2241 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4027-2242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3326-2243 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3459-2243 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2570-2245 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3153-2245 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3230-2245 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4918-2245 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3154-2245 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5334-2247 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2782-2248 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2902-2248 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2396-2249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4646-2250 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4769-2250 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5426-2251 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2487-2253 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3615-2255 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5474-2255 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3898-2256 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4829-2258 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4828-2257 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5428-2259 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2271-2261 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2620-2262 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5112-2262 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5647-2263 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2619-2264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5292-2264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4648-2265 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5612-2265 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4417-2265 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5268-2265 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4332-2268 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5429-2269 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3147-2270 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2207-2271 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2183-2272 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2205-2272 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5069-2272 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2182-2272 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2205-2272 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5068-2272 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4487-2273 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5431-2274 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4022-2275 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4022-2275 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3410-2279 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3567-2280 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3243-2282 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4706-2282 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4705-2281 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5688-2283 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4013-2285 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4592-2285 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5432-2287 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4784-2288 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3802-2288 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4859-2289 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2607-2290 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3226-2290 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2827-2291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3414-2291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4567-2291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5616-2291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2542-2292 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2828-2292 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3510-2292 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5433-2293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3292-2297 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5745-2299 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5831-2299 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5205-2300 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3308-2301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4092-2301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5300-2302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2732-2303 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2342-2305 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3869-2305 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5622-2305 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2494-2307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3104-2307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3858-2307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5059-2307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5615-2307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3858-2307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5614-2307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3401-2307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2637-2308 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3279-2308 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2286-2309 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4765-2309 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5533-2311 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3857-2312 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4151-2312 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2922-2313 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4092-2313 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5033-2313 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5033-2313 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2519-2314 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4869-2315 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3218-2316 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4129-2317 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4517-2317 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3649-2318 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5434-2319 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3363-2320 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3080-2323 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4389-2326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5393-2327 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3084-2329 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5439-2330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3195-2333 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3247-2333 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3415-2334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4612-2334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4701-2334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5571-2334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3415-2333 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4612-2333 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4253-2335 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5440-2335 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4253-2335 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4574-2336 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3064-2337 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3469-2337 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2858-2338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2428-2339 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2888-2340 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4442-2340 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2888-2340 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5821-2341 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3353-2343 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4208-2343 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4318-2344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5099-2344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2881-2345 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5441-2345 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2572-2347 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2978-2347 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4299-2347 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2572-2347 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4300-2347 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4619-2348 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2572-2347 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4018-2352 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2815-2353 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4350-2353 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2650-2354 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2901-2354 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3560-2356 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5762-2357 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4516-2358 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5195-2359 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4344-2361 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5443-2362 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5444-2363 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2376-2374 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2376-2373 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2376-2372 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2376-2371 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2376-2370 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2376-2369 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2636-2375 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3896-2375 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5426-2375 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3896-2375 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3279-2376 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4135-2376 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4183-2377 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2759-2378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4018-2378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3113-2380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3552-2380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3714-2380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5446-2381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3699-2381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5345-2382 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3666-2384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2513-2385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2593-2386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3666-2386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4900-2387 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3303-2388 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4990-2389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2753-2391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3641-2391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2393-2392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5471-2392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2910-2393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3331-2393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5546-2393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2910-2393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5547-2393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2825-2394 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4923-2395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2503-2396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2645-2397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2780-2398 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2780-2398 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3325-2400 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3851-2400 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5456-2401 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3014-2402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3679-2402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3722-2402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5651-2402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3679-2402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4704-2404 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4704-2403 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5457-2405 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2470-2406 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2984-2406 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5736-2407 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4720-2408 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2413-2409 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4541-2409 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3216-2410 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5808-2412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3931-2414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5768-2415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4836-2416 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5664-2416 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3163-2417 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3163-2418 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5349-2419 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5463-2420 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4219-2422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4219-2422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5454-2423 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2427-2424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2513-2424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3369-2424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3445-2424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5774-2424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2513-2424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2597-2426 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2785-2426 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2785-2425 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5606-2427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3010-2428 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3082-2428 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4719-2428 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4856-2428 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3011-2429 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3083-2429 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4474-2429 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4907-2429 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5429-2429 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2431-2430 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4254-2432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4741-2432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5316-2431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5462-2432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5490-2431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5491-2431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5535-2431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4254-2432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4741-2432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4254-2432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4490-2433 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5495-2433 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5711-2433 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4394-2434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4682-2434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3905-2435 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5448-2435 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5715-2435 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2968-2437 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5461-2436 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3313-2438 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5574-2438 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4915-2440 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4915-2439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3509-2441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5705-2441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3794-2442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4027-2442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4364-2442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5236-2442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5761-2442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5465-2444 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2596-2445 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2596-2446 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4777-2448 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5563-2448 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5150-2447 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5133-2447 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5130-2448 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5545-2449 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3505-2450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3901-2451 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3901-2451 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2945-2452 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5449-2454 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3420-2455 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2568-2458 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4378-2458 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2564-2459 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3093-2459 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4163-2459 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4216-2459 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5443-2459 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5679-2459 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4215-2459 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4654-2461 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5214-2461 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5466-2462 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3338-2464 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3175-2465 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3651-2466 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5039-2466 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3397-2468 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3926-2468 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4977-2469 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4242-2470 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4892-2470 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5458-2470 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3738-2471 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4570-2472 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4570-2472 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2907-2473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4455-2473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4657-2473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2835-2474 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3636-2474 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2491-2476 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2491-2475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4566-2477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4089-2478 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3853-2479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4864-2479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4862-2480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5189-2481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3743-2482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2823-2484 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4269-2484 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4611-2484 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5115-2485 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5192-2486 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5264-2486 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2729-2488 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3497-2489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4755-2490 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5524-2490 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2835-2491 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3034-2491 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2835-2491 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3470-2492 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3598-2492 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3782-2492 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4103-2492 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3781-2492 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3780-2492 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4862-2493 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5288-2493 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3592-2495 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4687-2497 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2725-2498 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2719-2501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3009-2501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4080-2501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5167-2501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5467-2502 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5449-2503 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2791-2503 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2519-2505 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3680-2505 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2781-2506 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2923-2507 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5468-2508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4199-2509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4862-2509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5228-2509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5230-2509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4862-2509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4994-2510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4994-2510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3356-2511 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2782-2512 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2837-2514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5731-2514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2836-2515 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4398-2515 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4009-2516 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4009-2516 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3251-2518 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3251-2518 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4863-2519 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4863-2519 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4859-2520 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2719-2523 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4777-2523 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5167-2523 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5720-2524 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2538-2527 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5469-2527 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3390-2528 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4808-2529 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3937-2530 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2561-2531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5348-2531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2561-2531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2931-2532 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2535-2534 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2689-2535 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3662-2535 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4817-2535 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5473-2535 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2573-2536 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4958-2536 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5472-2537 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5760-2538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5469-2539 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2708-2540 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2896-2541 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3158-2541 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3158-2541 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3943-2542 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4212-2543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3482-2544 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5477-2546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5506-2545 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2973-2547 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2973-2547 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5475-2548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5476-2549 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3685-2550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4735-2550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4840-2550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4735-2550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5694-2551 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3912-2552 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4736-2552 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4743-2552 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4178-2554 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3188-2555 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4792-2556 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4792-2556 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2767-2557 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3666-2558 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3700-2558 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3377-2559 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4910-2559 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3843-2560 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4325-2560 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3648-2561 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5572-2561 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5573-2561 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5848-2561 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2630-2561 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4459-2562 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5480-2564 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5481-2565 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5482-2566 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3941-2567 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4008-2567 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3105-2568 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3825-2568 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4081-2568 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5255-2568 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5767-2568 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5493-2569 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3103-2570 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4111-2571 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4792-2571 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5712-2572 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5710-2572 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5479-2573 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4003-2574 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4368-2574 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5190-2576 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2852-2577 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3010-2578 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3010-2578 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4340-2579 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5390-2579 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5753-2579 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5794-2579 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5256-2581 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5046-2582 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5849-2582 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5670-2582 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3436-2583 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4143-2583 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2829-2584 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2626-2585 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4397-2585 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5110-2585 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4396-2585 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5109-2585 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2739-2587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5752-2587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3169-2589 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5484-2590 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2986-2591 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2833-2592 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3012-2592 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5723-2592 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2799-2592 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2833-2592 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3012-2592 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2799-2592 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3666-2593 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3666-2593 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5382-2594 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5632-2594 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5486-2595 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4404-2596 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4414-2596 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4404-2596 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4414-2596 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2785-2597 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5401-2598 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2602-2600 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4673-2600 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5487-2601 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3113-2603 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4055-2603 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3113-2603 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5488-2605 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3573-2606 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4448-2606 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2877-2607 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3226-2607 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3348-2607 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4073-2607 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3412-2610 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3409-2612 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3621-2613 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5033-2614 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5457-2614 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4792-2615 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3360-2616 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3978-2617 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4679-2617 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3025-2618 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5816-2618 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4862-2621 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5094-2622 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5490-2623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5491-2623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2959-2624 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5806-2624 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5807-2624 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2931-2627 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4587-2627 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2832-2628 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2933-2628 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4474-2628 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2832-2628 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2932-2628 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5572-2630 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2639-2631 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3560-2631 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3892-2631 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2911-2632 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5249-2632 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5492-2634 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2790-2635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3139-2635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4604-2635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4604-2636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4135-2637 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4634-2637 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4135-2637 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2951-2638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4070-2638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3441-2639 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5232-2640 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5504-2641 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5835-2641 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5534-2642 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2646-2645 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5221-2645 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5218-2646 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3503-2647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4174-2647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3653-2647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4175-2650 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5545-2650 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5583-2650 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4993-2651 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5822-2651 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3770-2652 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3376-2653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3489-2653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4540-2654 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5189-2654 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5787-2655 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4148-2656 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4514-2656 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5356-2656 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4515-2657 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4891-2657 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3540-2658 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2719-2659 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3452-2659 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3988-2660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3689-2661 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2594-2662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3531-2662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4040-2662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5430-2662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2594-2662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4779-2663 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3491-2668 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5689-2669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5690-2669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3512-2670 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4164-2670 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4880-2670 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3573-2674 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3573-2673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4257-2675 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4887-2675 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4257-2675 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4402-2676 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5494-2677 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3884-2677 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5441-2678 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2677-2679 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4360-2682 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3017-2683 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5401-2683 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5762-2683 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3017-2683 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3483-2685 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4697-2686 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5496-2687 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5497-2688 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3762-2689 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4782-2691 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3518-2692 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2694-2693 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5498-2693 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3167-2695 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3883-2695 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4913-2695 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2835-2696 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2835-2696 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3898-2698 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4734-2698 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4827-2700 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4324-2701 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3658-2702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3438-2703 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3175-2704 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4058-2704 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4667-2704 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4059-2704 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4898-2705 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5206-2705 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5837-2705 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3346-2706 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2896-2708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3840-2707 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4614-2708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4865-2707 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5399-2707 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3943-2709 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3943-2709 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3931-2711 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3932-2712 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5502-2713 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3312-2715 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3544-2715 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3561-2715 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3312-2715 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4137-2716 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5168-2719 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5170-2719 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3030-2720 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4725-2721 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4724-2721 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4723-2721 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5064-2722 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3666-2723 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3666-2723 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3584-2725 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4816-2725 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4816-2725 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4229-2726 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3916-2727 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4444-2728 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3602-2729 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5504-2730 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4149-2731 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4227-2734 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4956-2738 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4956-2737 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3679-2739 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5650-2740 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3646-2743 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3815-2744 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4990-2744 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3121-2745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4068-2745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4992-2745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3120-2745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4992-2745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3119-2745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4626-2746 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3422-2747 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2945-2749 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2946-2750 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4730-2751 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4786-2751 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5107-2751 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4786-2751 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2846-2754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4206-2754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4426-2754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5100-2754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5737-2754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4205-2754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3510-2755 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3938-2755 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5509-2756 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3424-2757 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4804-2757 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5506-2758 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3664-2759 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5505-2761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5510-2762 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2953-2763 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3765-2763 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2952-2763 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3765-2763 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4069-2764 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4908-2764 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4625-2765 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3366-2766 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3366-2766 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5507-2767 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5687-2768 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5386-2768 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2841-2770 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3261-2770 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4285-2770 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4411-2770 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4904-2770 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5820-2770 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4285-2770 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5240-2770 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3018-2771 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4810-2771 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4532-2772 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4532-2772 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5502-2773 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5776-2773 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3904-2775 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5081-2775 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5508-2776 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3810-2777 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5135-2777 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5511-2778 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4009-2779 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2962-2780 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3330-2780 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5442-2781 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5452-2781 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5453-2781 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5599-2781 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3330-2780 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3356-2781 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3505-2782 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3483-2784 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4184-2785 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5814-2785 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5422-2788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4857-2789 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4857-2789 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4604-2790 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4071-2791 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5449-2791 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5470-2791 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5471-2791 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4071-2791 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3400-2792 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5132-2792 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4064-2793 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4956-2794 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4958-2795 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5512-2796 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3381-2798 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3672-2798 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3859-2800 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4200-2801 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4862-2802 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3799-2803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3925-2803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5251-2803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3671-2806 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3672-2807 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4924-2808 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5457-2808 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3700-2809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3512-2810 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4177-2810 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4380-2810 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4881-2811 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4257-2812 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5515-2814 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3307-2815 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4395-2815 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5037-2815 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5298-2815 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5554-2815 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5556-2815 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5570-2815 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5036-2815 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3603-2816 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2945-2817 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5751-2817 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4720-2819 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5213-2819 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5459-2819 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4348-2820 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4349-2822 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4349-2821 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4316-2824 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4336-2824 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5450-2825 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3713-2826 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3182-2830 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3848-2830 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5322-2830 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5820-2830 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5149-2831 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3809-2833 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3808-2833 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3807-2833 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3806-2833 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5673-2834 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4398-2836 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5516-2838 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5518-2839 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3345-2840 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5092-2841 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5266-2843 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5392-2844 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5520-2845 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2954-2846 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4561-2846 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5730-2848 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5521-2849 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4570-2850 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4647-2850 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4570-2850 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4647-2850 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4570-2850 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4570-2850 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5252-2851 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5522-2851 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3102-2853 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3566-2853 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5792-2854 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5525-2856 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5524-2857 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5523-2859 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5523-2860 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5527-2861 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3399-2862 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3758-2864 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5337-2864 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5786-2864 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4144-2865 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4173-2865 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2998-2868 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4847-2866 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4847-2867 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5528-2869 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4685-2870 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4448-2871 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5530-2874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4930-2875 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3276-2876 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5618-2877 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5532-2878 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5531-2879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3038-2883 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3076-2884 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3010-2885 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5317-2886 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5533-2886 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3036-2887 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5534-2887 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4295-2888 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4582-2889 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4565-2890 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2917-2892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3485-2893 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4861-2893 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5565-2893 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3212-2893 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3485-2893 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5678-2893 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3485-2893 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3479-2894 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4637-2894 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5086-2894 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3478-2894 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4638-2894 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-2894 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3477-2894 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3476-2894 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3326-2895 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5655-2895 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4017-2896 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3181-2897 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5535-2898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3845-2899 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5033-2899 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5492-2899 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3600-2901 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5537-2903 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5536-2903 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5682-2904 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4718-2905 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4134-2906 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2910-2909 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5622-2911 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3901-2912 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5406-2912 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4854-2914 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2938-2916 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3000-2916 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3611-2916 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4464-2915 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4848-2917 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5404-2915 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2999-2915 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4848-2915 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2921-2919 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3794-2920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3931-2921 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4255-2921 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5779-2921 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4914-2924 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4940-2924 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3851-2925 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3851-2925 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3086-2926 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4383-2927 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3297-2928 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5539-2929 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3213-2931 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3683-2931 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2987-2934 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3614-2934 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3099-2935 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5781-2935 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3850-2937 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4997-2936 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5609-2937 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3850-2936 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5611-2936 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5542-2939 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5290-2941 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5846-2941 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4845-2942 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3239-2945 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5024-2945 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5080-2945 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3938-2946 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4306-2946 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4406-2946 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3938-2946 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3968-2947 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4925-2947 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3706-2948 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3240-2951 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5066-2951 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5444-2951 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4426-2954 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5052-2955 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5674-2955 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4348-2956 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4244-2957 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5544-2959 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5545-2960 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4668-2963 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2969-2964 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2968-2965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4083-2968 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4159-2968 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5035-2967 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5591-2969 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4083-2967 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4159-2968 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5461-2968 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4977-2970 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5244-2971 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4977-2971 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5546-2972 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3999-2973 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4906-2973 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5217-2973 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3998-2973 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3041-2975 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5201-2975 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3983-2976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4259-2976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5548-2977 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5618-2979 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5641-2979 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3314-2980 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3604-2981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4358-2981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5465-2981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5606-2981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5643-2982 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4005-2985 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3403-2986 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4097-2986 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4369-2986 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5146-2986 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5850-2986 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4097-2986 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3484-2988 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4056-2990 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4162-2990 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5254-2990 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5741-2990 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3909-2991 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3554-2992 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4983-2993 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5667-2993 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4112-2995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4793-2995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3287-2998 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3681-2997 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4317-2997 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5542-2997 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5646-2997 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5648-2998 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3288-3000 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3389-3000 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4768-3001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5619-3001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4768-3001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3622-3002 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3174-3003 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5169-3003 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5775-3003 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3047-3003 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3174-3003 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4560-3004 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3679-3005 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3650-3006 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4596-3006 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3466-3007 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4957-3008 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4957-3008 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5044-3010 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5116-3010 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4908-3012 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4909-3012 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3082-3013 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3679-3014 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4778-3015 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4778-3015 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5454-3017 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4926-3019 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5169-3020 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5578-3020 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4790-3021 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3543-3022 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4770-3022 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5778-3024 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5784-3024 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3520-3028 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5592-3030 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5025-3031 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5136-3031 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4029-3033 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3597-3034 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3399-3035 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5343-3035 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4720-3036 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4459-3039 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3482-3040 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4462-3041 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4510-3041 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4635-3041 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4862-3042 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4862-3043 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4862-3043 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4231-3044 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4839-3044 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3311-3045 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4304-3045 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4844-3048 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5125-3048 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4813-3049 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4582-3050 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3064-3051 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3268-3053 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3496-3054 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3059-3057 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3939-3057 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3058-3057 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5558-3060 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5196-3066 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5306-3066 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3675-3067 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3979-3067 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4956-3068 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5559-3070 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5560-3069 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3679-3072 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4337-3074 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5324-3074 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5636-3074 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3101-3075 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5657-3076 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4767-3077 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5828-3077 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4798-3077 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5561-3078 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3201-3079 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4772-3080 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5437-3080 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5157-3081 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4657-3084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5230-3085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5736-3085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3710-3086 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5363-3086 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5376-3086 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3407-3087 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4547-3087 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5658-3087 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4547-3087 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3313-3088 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5660-3088 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3510-3089 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5261-3090 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3968-3091 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5141-3092 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5628-3092 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4076-3093 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5000-3095 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3562-3096 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3344-3098 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4951-3100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5257-3100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4069-3103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4136-3103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4918-3103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4137-3103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3689-3107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3689-3106 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3457-3108 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5378-3108 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5358-3108 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5565-3109 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4917-3110 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5333-3110 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3679-3111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3679-3111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3269-3112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5584-3112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3552-3113 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3761-3113 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4394-3113 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4758-3113 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5624-3113 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5481-3113 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4855-3115 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5092-3114 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5285-3115 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4963-3114 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5566-3122 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3509-3123 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5567-3125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4354-3126 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5613-3127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5746-3127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5819-3127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5608-3127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3178-3128 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2931-3129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3813-3129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4270-3131 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5117-3131 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4365-3132 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4978-3134 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5570-3136 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4609-3139 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3011-3140 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3164-3141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3930-3141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3164-3141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5360-3142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5571-3143 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3146-3144 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3903-3145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4974-3145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5097-3145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4973-3145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4048-3146 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4975-3146 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3986-3147 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5848-3147 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5779-3148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3470-3149 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3471-3150 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3879-3151 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3890-3152 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4132-3152 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5018-3152 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5047-3152 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4885-3154 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-3154 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5244-3153 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-3153 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5067-3157 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3602-3159 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4890-3159 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3258-3160 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3527-3160 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3275-3161 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3566-3163 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3936-3163 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3566-3163 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3935-3163 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3385-3164 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4433-3164 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5203-3164 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5492-3164 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5572-3166 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4522-3169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5504-3169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5574-3170 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5575-3171 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4722-3172 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5344-3172 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3673-3173 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5578-3174 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4667-3175 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4962-3176 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5626-3177 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3266-3178 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4871-3179 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4922-3179 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3753-3180 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3753-3180 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4677-3180 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3396-3183 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4111-3184 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4636-3184 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5580-3185 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5120-3185 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4883-3186 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5581-3187 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5616-3188 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5788-3188 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4291-3190 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5377-3190 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4400-3192 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4400-3191 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3515-3193 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4253-3194 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4252-3195 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4312-3196 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4690-3196 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5239-3197 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5354-3197 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4312-3196 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5053-3199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4575-3198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5562-3201 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3270-3202 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3882-3204 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3883-3205 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5500-3206 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4624-3207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5270-3208 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4219-3209 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4498-3209 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5583-3210 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3269-3211 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5565-3212 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5585-3214 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4868-3218 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5579-3219 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3826-3220 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3924-3220 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3925-3220 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4956-3221 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3300-3222 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4231-3222 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3299-3223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4230-3223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4764-3224 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5828-3224 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3823-3226 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3632-3228 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5490-3229 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3427-3233 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3427-3232 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3427-3231 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4605-3235 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4606-3234 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5444-3240 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5539-3241 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4183-3242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4694-3243 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4708-3243 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4267-3244 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5279-3244 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5332-3245 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4632-3246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5028-3246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5588-3247 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5589-3248 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4614-3249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3436-3250 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4323-3250 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5566-3250 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5841-3251 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5754-3251 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4787-3252 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5649-3252 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4146-3253 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4444-3253 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5518-3253 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3652-3255 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3652-3254 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3652-3256 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3437-3258 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4447-3258 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5195-3258 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4792-3260 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5322-3261 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4670-3262 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3580-3263 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5590-3264 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4556-3266 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3949-3267 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4238-3269 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4240-3270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4884-3270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4891-3270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4239-3270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4884-3270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4400-3271 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4770-3272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4976-3273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5591-3273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4976-3273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5111-3274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5129-3274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5543-3274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4473-3276 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3284-3278 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3654-3278 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5615-3278 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3283-3278 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3654-3278 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5614-3278 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3286-3279 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3285-3279 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4039-3287 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4333-3291 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4866-3294 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5593-3295 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3500-3297 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3870-3297 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3938-3298 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5782-3298 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4649-3300 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4649-3299 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4277-3301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3399-3302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4543-3302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3399-3302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4415-3303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5406-3304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4209-3306 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5170-3308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5756-3308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5835-3309 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4304-3311 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5381-3311 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5585-3311 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5750-3311 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3692-3312 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4822-3314 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5175-3315 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5739-3315 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5309-3321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5691-3321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3914-3322 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4103-3323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4444-3323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4103-3323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3535-3323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3534-3323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3851-3324 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3428-3326 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4285-3327 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3705-3328 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3705-3329 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5470-3331 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5575-3331 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4847-3333 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4847-3332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4289-3335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5040-3335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5325-3335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5595-3337 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5249-3339 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5034-3341 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5034-3340 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4442-3343 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5243-3344 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5353-3345 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3524-3346 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5618-3348 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3774-3349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4610-3349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5093-3349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3774-3349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5638-3349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5772-3349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4598-3350 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5600-3354 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5601-3354 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3356-3355 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5599-3356 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5598-3357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5486-3358 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4961-3358 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3934-3359 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3934-3359 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5328-3361 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4456-3364 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3487-3365 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4665-3365 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4665-3365 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4578-3366 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4349-3367 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4349-3367 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4183-3370 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4183-3370 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3373-3372 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3374-3372 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5607-3375 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5122-3376 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5225-3376 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5609-3378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5610-3379 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3837-3380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4339-3380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3837-3380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4121-3381 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4407-3382 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5541-3383 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5540-3384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5090-3386 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3901-3387 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3901-3387 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5138-3388 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4589-3390 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3887-3391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4838-3391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3924-3396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5541-3396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3925-3396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5540-3396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3926-3397 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4295-3398 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3542-3399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4335-3399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5303-3399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5516-3399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4028-3400 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4028-3400 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5614-3402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5485-3403 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3405-3404 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4133-3406 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4044-3407 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5616-3408 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4062-3411 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3913-3415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4969-3416 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5619-3417 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4455-3418 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3982-3419 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4036-3419 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3982-3419 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4148-3420 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5765-3421 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5280-3422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5555-3422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4110-3423 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4329-3424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5414-3426 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3883-3427 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5124-3427 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5123-3427 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5372-3427 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3737-3429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3894-3429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5126-3431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4350-3432 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5395-3432 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4350-3432 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5623-3434 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3525-3437 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4607-3439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5587-3439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3773-3441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4916-3442 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5624-3443 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3447-3444 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4243-3444 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4681-3444 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5774-3445 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5625-3446 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4681-3447 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4681-3448 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5140-3449 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5626-3451 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5235-3453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5236-3453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5343-3453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5801-3454 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4919-3455 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4967-3455 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4967-3455 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5627-3456 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3556-3457 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5538-3459 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4014-3460 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5777-3461 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5628-3462 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4778-3463 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5273-3466 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5629-3468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3515-3469 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3752-3470 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3752-3470 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3482-3473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3482-3475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3482-3472 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3482-3474 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4876-3481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4876-3480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5329-3482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5378-3482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5477-3482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5358-3482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5506-3482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5557-3482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3721-3484 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3557-3485 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4229-3485 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4402-3486 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4415-3486 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3546-3488 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4125-3488 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5549-3490 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5630-3492 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4456-3493 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4320-3494 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4408-3494 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5483-3494 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5484-3494 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5631-3495 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4389-3497 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4751-3497 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5103-3497 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4389-3497 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3568-3498 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5052-3498 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5052-3498 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5632-3499 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3870-3500 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3504-1497 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5277-3507 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5636-3508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4011-3509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4566-3509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5100-3509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5634-3509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4012-3510 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4607-3511 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4788-3512 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4017-3513 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3879-3514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3982-3515 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4833-3515 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5799-3515 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3982-3515 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3982-3515 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4035-3518 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4035-3518 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4107-3519 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4107-3519 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3837-3520 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4549-3523 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5007-3522 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5385-3523 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5790-3522 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4794-3524 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4049-3529 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5714-3529 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5823-3530 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4425-3531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5638-3533 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5640-3536 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4174-3537 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4815-3539 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5067-3539 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5431-3539 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4105-3540 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4879-3540 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4104-3540 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4264-3541 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5831-3542 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4061-3546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4125-3546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5422-3546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5643-3549 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4348-3551 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5075-3551 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4348-3551 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5644-3553 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5015-3554 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4362-3555 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4888-3556 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5176-3556 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5477-3556 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5529-3556 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5706-3556 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5180-3556 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4516-3559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4886-3560 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4886-3560 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3880-3561 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3565-3562 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3566-3563 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3566-3564 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4018-3567 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4218-3567 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5337-3568 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5129-3569 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4722-3570 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4668-3571 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4011-3572 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4566-3572 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4011-3572 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3983-3573 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5006-3574 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3370-3577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5631-3577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4047-3580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4505-3582 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5645-3581 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3581-1495 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4517-3583 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5716-3583 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3846-3585 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5284-3585 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5342-3585 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5838-3585 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4649-3586 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5646-3589 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5648-3590 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3391-3591 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3887-3591 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5647-3593 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5479-3594 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3430-3595 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3988-3595 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3510-3596 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5456-3596 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3743-3597 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5455-3601 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5369-3602 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5570-3602 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4307-3604 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5606-3604 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4190-3607 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4189-3607 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5306-3608 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4326-3609 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4235-3610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4193-3612 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4615-3612 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5625-3612 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5652-3613 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3395-3616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4049-3616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4079-3616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4640-3614 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5023-3614 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5394-3616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5472-3615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5022-3615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5181-3616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4079-3616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5351-3614 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5184-3616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5350-3614 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3368-3617 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4050-3618 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4600-3618 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4599-3618 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4600-3617 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4599-3617 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4977-3617 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4508-3620 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5200-3619 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3406-3621 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3406-3621 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3363-3623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5804-3623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3363-3623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4614-3624 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3902-3625 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4683-3625 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5265-3625 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4683-3625 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5654-3627 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3632-3629 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3632-3628 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4742-3631 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4742-3630 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5327-3632 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5586-3632 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4470-3632 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3464-3632 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3747-3633 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3907-3633 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4006-3633 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4828-3633 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3881-3634 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5339-3636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4102-3636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5812-3638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4073-3639 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5520-3642 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5519-3643 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5655-3645 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4802-3647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5573-3648 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5208-3649 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3932-3650 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4572-3650 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3532-3652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3656-3652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3860-3652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3656-3652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4174-3653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4487-3655 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4486-3655 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4182-3657 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4488-3657 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5564-3659 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3661-3660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3985-3660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3985-3661 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5768-3663 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3677-3664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3678-3664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4218-3664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4019-3665 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4220-3665 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3700-3666 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4436-3666 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5624-3666 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5481-3666 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4184-3667 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4608-3667 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4424-3668 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5197-3668 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5656-3669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4688-3670 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3695-3671 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3893-3673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4005-3675 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4161-3675 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3747-3676 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3981-3676 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4006-3676 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4130-3679 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3310-3680 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3852-3680 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4399-3680 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4557-3680 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4858-3680 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4858-3680 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4847-3682 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5658-3684 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3311-3686 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5585-3686 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5660-3687 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5659-3688 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5420-3689 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5661-3689 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5680-3689 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4944-3689 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5663-3690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4615-3691 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4324-3696 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4607-3696 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5558-3697 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4914-3698 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4183-3701 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5445-3701 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4183-3701 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4232-3702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4460-3703 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5666-3704 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4245-3705 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5098-3705 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5665-3705 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4547-3711 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4496-3712 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4495-3712 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5211-3713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4180-3715 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4790-3715 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4315-3716 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5667-3717 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4915-3719 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5668-3720 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4366-3724 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5090-3728 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5101-3728 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5670-3731 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4331-3732 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5669-3734 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5772-3733 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4267-3735 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5330-3736 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3723-3737 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4429-3737 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4537-3737 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4429-3737 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3727-3739 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3726-3739 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4576-3738 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3725-3739 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4795-3742 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3932-3744 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3873-3747 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5403-3748 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5671-3751 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4103-3752 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4103-3752 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4574-3753 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4574-3753 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4809-3754 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5672-3755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5188-3756 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5436-3758 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4489-3759 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4526-3759 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5291-3760 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5673-3763 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3860-3764 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3876-3764 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4716-3764 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5060-3764 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4331-3766 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5412-3767 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4803-3771 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4389-3773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4617-3773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4389-3773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5505-3774 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5836-3774 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4729-3774 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4599-3775 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4600-3775 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5042-3776 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4752-3787 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4710-3788 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4709-3787 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4726-3795 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5692-3795 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4442-3796 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5596-3796 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4454-3797 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5813-3797 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4122-3800 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5676-3801 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4821-3803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4823-3803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4820-3803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4079-3805 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4079-3804 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3996-3810 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4284-3810 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4374-3810 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5198-3810 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5515-3810 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3996-3810 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4731-3811 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5511-3811 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4909-3812 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4992-3814 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4081-3815 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3822-3816 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3821-3816 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3820-3816 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4081-3825 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5250-3826 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4120-3827 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5678-3828 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4159-3830 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4159-3829 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3886-3832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3976-3832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4332-3831 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3975-3831 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4332-3832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4333-3833 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5065-3836 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4540-3838 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5281-3839 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4998-3840 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5091-3840 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5468-3841 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5513-3841 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5137-3843 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5680-3843 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3891-3844 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4743-3847 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4743-3847 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4285-3848 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5682-3849 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5451-3851 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4557-3852 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4351-3856 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5796-3856 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5797-3855 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4689-3857 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4970-3859 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5513-3859 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5684-3862 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5683-3861 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5765-3864 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5685-3865 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4730-3868 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3876-3872 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4506-3874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4934-3874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5341-3874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3932-3875 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4256-3875 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5686-3878 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5687-3878 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4953-3879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4953-3879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5659-3880 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4975-3882 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4976-3883 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5373-3882 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4318-3884 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5688-3885 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4511-3891 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4617-3892 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5387-3892 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4255-3895 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5815-3897 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5311-3899 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5626-3901 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5265-3902 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4586-3904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4394-3905 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5079-3907 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4637-3908 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4661-3908 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4638-3908 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4661-3908 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4443-3911 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5744-3912 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5531-3916 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4101-3917 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5056-3917 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5237-3917 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5718-3917 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4107-3918 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5693-3919 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4755-3920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4036-3923 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5799-3923 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4832-3925 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4832-3924 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5694-3929 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4506-3931 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5117-3931 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3997-3932 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4296-3932 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5440-3932 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4065-3938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5271-3938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5463-3938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5708-3938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5740-3945 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5774-3945 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4112-3946 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5696-3950 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5417-3952 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4015-3955 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4015-3956 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5272-3957 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3961-3960 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4460-3960 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5177-3960 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4563-3962 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4957-3963 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4957-3964 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4613-3965 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5175-3965 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5436-3965 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5800-3965 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5700-3966 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4925-3968 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5699-3973 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4907-3977 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4086-3978 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4086-3978 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5326-3980 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5079-3981 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4200-3982 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5104-3982 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5005-3983 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5702-3987 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4921-3989 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5083-3990 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5530-3991 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5701-3992 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4926-3993 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5703-3994 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5353-3995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5705-4000 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4699-4001 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4367-4002 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5826-4004 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4315-4005 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4467-4005 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5505-4007 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4336-4009 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4370-4009 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4721-4010 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5487-4011 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4689-4012 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5246-4014 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5213-4016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5707-4019 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5708-4021 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5708-4021 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5417-4022 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4107-4023 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4902-4023 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5489-4024 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5576-4024 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4607-4025 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4607-4025 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5235-4027 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5132-4028 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4458-4031 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5153-4031 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4458-4031 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5152-4031 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4685-4032 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5710-4034 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5096-4037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5711-4038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4877-4041 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4900-4042 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4103-4043 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4547-4044 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5713-4045 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4379-4046 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5795-4046 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5849-4047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4975-4048 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5394-4049 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5714-4049 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4977-4050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5434-4051 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4720-4060 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5714-4063 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4310-4064 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4544-4064 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5788-4064 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5715-4066 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5066-4070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4602-4071 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5233-4071 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4231-4075 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4230-4075 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5780-4076 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4400-4079 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4400-4079 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5181-4079 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5184-4079 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4234-4081 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4378-4081 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4681-4087 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4682-4087 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4776-4088 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5717-4091 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5087-4093 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5854-4093 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5304-4098 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4618-4099 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4948-4100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4934-4102 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5339-4102 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5501-4102 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4651-4107 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5805-4107 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-4108 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4949-4108 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4729-4109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5838-4111 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4449-4114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5722-4115 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4931-4116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5719-4116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4119-4118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4339-4120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5579-4120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5012-4122 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5723-4124 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5725-4131 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4247-4133 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5427-4135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4148-4140 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4540-4141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5175-4143 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5566-4143 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5800-4143 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5816-4142 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4212-4145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4850-4145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5160-4146 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5701-4146 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5260-4147 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4849-4148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5000-4150 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5796-4150 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5001-4151 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5727-4154 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5726-4155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4473-4157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4473-4157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4257-4158 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5728-4158 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4386-4159 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5729-4162 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5204-4165 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4699-4166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5425-4166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5730-4168 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5568-4169 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5731-4170 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4323-4172 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4382-4172 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5786-4172 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4323-4172 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4382-4172 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5732-4174 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5640-4174 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5391-4176 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5434-4176 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5037-4179 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4668-4180 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5182-4183 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5345-4183 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5631-4183 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5814-4184 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4681-4185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4332-4186 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5735-4186 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4188-4187 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5297-4187 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5736-4191 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5754-4192 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5029-4193 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4846-4196 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5155-4196 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4763-4197 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5194-4201 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4963-4203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4963-4202 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4204-4205 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4577-4209 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4875-4209 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5792-4209 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4877-4211 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4966-4210 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5560-4210 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4444-4213 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5518-4213 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5701-4213 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5587-4214 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4472-4219 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4498-4219 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5220-4218 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4498-4219 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4497-4218 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4490-4220 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4907-4220 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5707-4220 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5711-4220 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4909-4221 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5390-4222 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5743-4222 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5307-4228 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5371-4227 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4952-4232 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4351-4236 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5739-4237 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5458-4241 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4681-4243 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4895-4244 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5164-4244 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5409-4244 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4327-4248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4678-4250 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5212-4249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4249-4272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5742-4251 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4831-4252 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4887-4252 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4258-4253 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4741-4254 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4842-4257 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5410-4257 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5658-4258 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5005-4259 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5656-4259 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4823-4260 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5182-4262 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5740-4262 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5443-4263 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5241-4266 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5241-4265 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5791-4269 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5744-4271 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5025-4273 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5746-4274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5716-4275 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5694-4278 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5763-4283 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4860-4288 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4860-4287 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5003-4289 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5377-4291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5595-4291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4982-4293 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4444-4296 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5617-4297 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5748-4298 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4289-4301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5749-4302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4322-4303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4568-4303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5750-4304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5383-4309 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5537-4309 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5536-4308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4311-4310 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5392-4312 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5852-4315 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5751-4321 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5539-4325 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5593-4325 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4424-4329 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4621-4332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4719-4331 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5346-4331 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5347-4331 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5428-4332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5688-4332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5735-4332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5733-4332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5202-4333 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5429-4334 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4907-4333 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5374-4334 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5302-4335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4552-4344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4550-4344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5320-4345 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4772-4346 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5756-4347 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4894-4348 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5075-4348 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5075-4348 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4907-4349 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4907-4349 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4907-4349 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5396-4350 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5402-4351 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5781-4351 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5832-4351 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5757-4354 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5758-4354 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5151-4354 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5379-4356 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5759-4357 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4585-4359 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5041-4359 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5227-4359 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5418-4361 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5578-4361 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4441-4362 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4801-4363 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5239-4365 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5249-4365 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4429-4366 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4429-4366 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4720-4370 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4911-4371 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5197-4371 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5401-4372 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4489-4374 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5763-4375 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5258-4377 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5380-4380 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5595-4381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5179-4384 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5817-4385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5766-4390 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5764-4392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4890-4395 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4858-4399 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4727-4400 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5173-4402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5121-4403 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5767-4405 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4590-4407 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4869-4412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5770-4416 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5771-4418 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4879-4420 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4879-4419 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5009-4425 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4996-4427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5771-4427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5312-4428 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5773-4430 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5369-4432 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4688-4434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4878-4434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4688-4434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4625-4435 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4857-4437 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4964-4437 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5718-4438 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4675-4441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4675-4441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4756-4442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4920-4442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4757-4442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5666-4444 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5275-4449 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5775-4451 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5095-4454 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5821-4454 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5782-4456 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4926-4457 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4893-4458 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5671-4458 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5152-4458 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5750-4460 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5834-4461 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4534-4462 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4635-4463 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5145-4462 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5148-4463 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-4465 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4679-4469 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4498-4471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5778-4473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4777-4475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4486-4481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4488-4485 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4488-4484 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4488-4483 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4488-4482 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5012-4489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5515-4489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4806-4491 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5779-4493 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5183-4501 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5256-4501 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5567-4503 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4606-4507 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4808-4511 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5260-4511 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5781-4512 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5782-4513 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4054-4514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4148-4514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5248-4514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5696-4515 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5488-4519 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5370-4520 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5784-4521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4850-4523 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4146-4525 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5785-4527 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4332-4528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4332-4528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5709-4530 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5384-4531 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5389-4531 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4831-4533 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4887-4533 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5282-4538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5742-4540 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5751-4541 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5787-4542 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5516-4543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5517-4543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5789-4546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4574-4548 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4574-4548 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5395-4553 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5524-4555 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5700-4555 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5824-4555 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5825-4555 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5527-4557 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5610-4569 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4594-4570 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4593-4570 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4927-4573 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4927-4573 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4713-4574 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5823-4574 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4713-4574 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4713-4574 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4713-4574 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4713-4574 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5590-4579 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5636-4580 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4581-4582 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4799-4582 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5793-4582 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5795-4584 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4746-4585 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5145-4586 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5268-4592 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4661-4594 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4661-4593 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5796-4597 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5798-4601 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5799-4603 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4805-4607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5482-4607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5587-4607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5635-4607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5738-4607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5637-4608 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5058-4610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5638-4610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5467-4612 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4865-4614 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5323-4614 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5476-4614 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5625-4615 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5662-4615 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4781-4616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5663-4616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5801-4618 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4642-4619 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4978-4625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5621-4627 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5802-4628 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5528-4629 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5108-4630 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5251-4630 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5225-4632 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5804-4633 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4800-4636 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4666-4643 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4648-4646 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4663-4646 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5128-4646 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4663-4646 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5805-4650 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5510-4652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4792-4655 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4812-4655 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5246-4658 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5330-4660 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4744-4662 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5808-4664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5811-4674 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4899-4675 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4922-4676 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5259-4678 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5141-4680 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5186-4681 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5210-4681 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5815-4684 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4850-4687 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5812-4688 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4752-4695 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5817-4700 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5818-4702 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5818-4703 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4752-4711 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5819-4714 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5821-4717 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5144-4720 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5142-4720 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5459-4720 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5352-4726 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5822-4728 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5836-4729 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4803-4731 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4618-4733 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5833-4740 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5521-4743 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5147-4746 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5686-4746 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5775-4749 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4926-4759 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5467-4759 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4976-4762 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4975-4761 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5212-4764 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5627-4775 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5549-4778 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4808-4780 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5663-4781 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5375-4782 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5669-4782 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5829-4783 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5174-4784 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5827-4785 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5679-4787 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5324-4789 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4812-4791 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5284-4791 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5238-4793 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5828-4797 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5660-4799 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4921-4801 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4921-4801 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4993-4802 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5830-4804 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5635-4805 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5535-4807 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5199-4809 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5780-4809 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5299-4813 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5308-4814 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5077-4827 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5315-4827 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5413-4827 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5499-4827 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5079-4829 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5000-4835 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5000-4835 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5729-4837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4900-4839 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5812-4843 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5149-4844 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4967-4845 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5798-4845 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4967-4845 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5155-4846 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4889-4850 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4851-4852 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5810-4852 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5840-4852 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4968-4860 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4969-4860 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5514-4862 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5137-4864 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5593-4864 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5833-4867 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4900-4872 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4900-4873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5253-4874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5083-4878 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5070-4879 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5291-4884 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5723-4885 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5837-4897 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5627-4900 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5311-4901 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5240-4904 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5838-4905 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5171-4906 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5202-4907 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5604-4907 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5374-4907 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5424-4915 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4940-4915 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4941-4917 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5393-4917 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5495-4917 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5766-4917 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5703-4926 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5728-4926 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5789-4926 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4929-4928 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5839-4931 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5672-4943 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5840-4946 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5645-4947 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5099-4952 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5589-4956 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5639-4956 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5710-4956 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4966-4958 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5222-4957 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5479-4958 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5559-4958 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5560-4958 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5684-4958 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5219-4957 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5683-4957 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5512-4957 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5486-4961 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5389-4962 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5285-4963 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5454-4963 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5841-4964 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5842-4965 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5161-4967 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5162-4967 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5468-4970 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5313-4971 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5843-4972 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5842-4973 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5124-4976 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5591-4976 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5123-4976 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5372-4976 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5373-4975 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5163-4979 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5550-4983 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4991-4989 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4991-4988 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4992-4987 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5247-4994 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5258-4994 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5832-5000 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5844-5002 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5609-5003 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5654-5003 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5397-5003 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5656-5005 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5783-5005 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5749-5007 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5300-5008 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5632-5009 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5845-5013 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5846-5016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5847-5016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5548-5020 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5097-5021 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5679-5027 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5662-5029 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5848-5030 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5261-5033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5143-5034 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5089-5036 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5245-5038 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5809-5039 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5649-5045 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4990-5050 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5767-5050 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5522-5054 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5071-5063 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5851-5074 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5491-5076 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5342-5078 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5853-5078 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5852-5084 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5855-5088 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5773-5093 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5360-5106 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5553-5106 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5753-5114 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5583-5119 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5399-5127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5151-5133 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5605-5134 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5757-5165 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5758-5166 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5289-5174 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5855-5200 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5231-5208 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5499-5215 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5348-5216 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5450-5223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5715-5224 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5466-5271 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5293-5280 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5242-5298 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5437-5359 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5597-5363 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5722-5379 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5611-5397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5503-5412 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5747-5420 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5557-5433 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5452-5693 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5653-5476 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5584-5478 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5732-5489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5554-5497 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5253-5509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5668-5509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5785-5510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5590-5523 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5824-5526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5453-5543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5574-5634 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5600-5602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5612-5610 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5769-5620 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5640-5642 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5817-5652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5744-5666 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5765-5681 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5841-5755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5843-5785 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2592-5958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6067-5958 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6055-5959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6087-5959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5963-5960 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5963-5960 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6046-5960 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6123-5960 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6131-5960 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6151-5960 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4417-5961 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 140-5962 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6082-5962 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6082-5962 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6048-5963 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6155-5963 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6185-5963 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6185-5963 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6223-5963 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6223-5963 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4136-5964 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6059-5964 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6096-5964 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6102-5964 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3011-5965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3140-5965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5995-5967 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2799-5968 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 266-5968 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5857-5968 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5867-5968 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6166-5969 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6222-5969 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6239-5969 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6055-5970 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6083-5970 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5991-5971 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6146-5971 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6163-5971 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6170-5971 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6219-5971 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6038-5972 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6069-5972 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6245-5972 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6254-5972 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6070-5973 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6075-5973 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6087-5973 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6112-5973 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6194-5973 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2716-5975 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4136-5975 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6156-5974 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5986-5975 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6102-5975 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4794-5976 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6166-5976 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6191-5976 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6052-5977 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6172-5977 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6048-5978 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6054-5978 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6155-5978 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6176-5978 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6126-5979 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6189-5979 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2668-5980 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6088-5981 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6233-5981 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6185-5982 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6234-5982 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5993-5983 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6101-5983 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6104-5983 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6215-5983 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6018-5985 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6018-5984 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6134-5985 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6141-5984 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6101-5986 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3504-5987 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6178-5987 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5993-5988 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6118-5988 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6189-5988 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6189-5988 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6197-5988 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6056-5989 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6252-5989 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6134-5990 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6191-5990 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5997-5991 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6008-5991 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6057-5991 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6146-5991 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6170-5991 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6029-5992 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6113-5992 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6102-5993 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6118-5993 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6197-5993 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5856-5994 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5870-5994 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5869-5994 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6017-5994 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6011-5995 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6010-5995 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6067-5995 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6067-5995 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6023-5996 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6250-5996 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6190-5997 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5863-5998 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6085-5998 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6085-5998 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6008-5999 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6135-5999 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6001-6000 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6247-6000 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5521-6198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6007-6002 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6116-6002 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6158-6002 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 799-6004 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6073-6003 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6134-6003 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6166-6003 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6166-6003 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6166-6003 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6133-6005 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6165-6005 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6222-6005 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6172-6006 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6191-6006 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6175-6007 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6165-6009 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6239-6009 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6136-6012 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6144-6012 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6179-6012 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6017-6013 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6067-6013 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6052-6014 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6172-6014 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6137-6015 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6137-6015 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6187-6015 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6187-6015 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1761-6016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5473-6016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5856-6017 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5868-6017 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6065-6017 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6064-6017 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6003-6018 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6003-6018 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6217-6019 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6236-6019 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6240-6019 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6138-6021 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6138-6020 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6140-6021 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6140-6020 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5861-6022 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6036-6025 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6036-6024 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6095-6025 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6152-6024 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6152-6025 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6251-6025 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5859-6026 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5858-6026 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6071-6027 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6072-6027 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6173-6027 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6092-6028 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6105-6028 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6105-6028 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6143-6028 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6031-6029 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6031-6029 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6114-6029 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5857-6030 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6125-6030 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6125-6030 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6125-6030 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6253-6030 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6080-6031 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6080-6031 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5856-6032 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5857-6033 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4991-6034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3103-6036 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6077-6035 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6078-6034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6250-6035 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6249-6034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6096-6036 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6095-6036 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6056-6037 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6056-6037 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6056-6037 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6114-6037 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6113-6037 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6074-6038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6086-6038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6244-6038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6254-6038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5865-6039 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5871-6039 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6139-6039 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6218-6039 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4908-6043 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4909-6042 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5859-6041 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5858-6041 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6200-6040 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6221-6043 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6221-6042 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6105-6044 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6105-6044 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6255-6044 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6255-6044 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5864-6045 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6235-6045 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6070-6046 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6131-6046 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6122-6047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6154-6047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6214-6047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6160-6049 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6211-6049 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6168-6050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6189-6050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6057-6051 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6147-6051 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6170-6051 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6195-6051 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1068-6129 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6230-6052 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6230-6052 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6149-6053 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6169-6053 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6223-6054 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6075-6055 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6092-6056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6092-6056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6252-6056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6153-6057 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6167-6057 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6100-6058 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6101-6059 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6126-6059 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6126-6059 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6062-6061 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6062-6060 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6211-6061 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6211-6060 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6128-6062 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6128-6062 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6071-6066 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6147-6066 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6162-6066 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6241-6066 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5862-6067 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5868-6067 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6216-6067 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6074-6068 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6084-6070 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6084-6070 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6131-6070 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6159-6070 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6177-6070 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6213-6070 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6246-6070 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6072-6071 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6183-6071 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6080-6072 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6080-6072 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6201-6072 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6134-6073 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6243-6074 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6254-6074 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6181-6075 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6237-6075 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6122-6076 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6150-6076 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6178-6076 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6099-6077 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6100-6078 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6134-6079 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6191-6079 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6255-6080 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6255-6080 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6085-6081 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6215-6081 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6241-6081 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 141-6083 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6086-6082 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6086-6082 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6087-6083 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6112-6084 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6159-6084 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6177-6084 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6213-6084 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6237-6084 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6162-6085 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6241-6085 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6144-6086 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6144-6086 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6254-6086 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6246-6087 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6233-6088 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6152-6090 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6152-6090 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6152-6089 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6152-6089 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5860-6091 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6143-6092 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6100-6094 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6098-6093 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5871-6096 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6101-6095 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6102-6096 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6101-6095 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5861-6097 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4137-6102 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6108-6098 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6141-6099 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6104-6101 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6215-6101 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6218-6102 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6126-6103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6135-6103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6133-6106 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6174-6106 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6222-6106 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6157-6107 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6157-6107 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6175-6107 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6134-6108 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6119-6110 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6125-6109 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6125-6110 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5862-6111 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6173-6113 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6188-6114 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6209-6113 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6208-6114 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6151-6115 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6177-6115 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6187-6115 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6213-6115 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6158-6116 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6248-6116 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6123-6117 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6176-6117 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6121-6119 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6125-6119 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6255-6120 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6255-6120 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6225-6121 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6135-6124 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6219-6124 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5867-6125 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5870-6125 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5869-6125 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5863-6127 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6221-6127 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6251-6127 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6130-6128 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6160-6130 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6159-6131 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5864-6132 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6193-6132 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6235-6132 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6156-6134 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6144-6136 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6145-6138 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6221-6138 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5865-6139 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6162-6139 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6148-6140 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6183-6140 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6183-6140 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6188-6140 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6186-6142 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6196-6142 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6196-6144 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6221-6145 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6161-6147 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6170-6147 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6241-6147 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6173-6148 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6184-6149 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6162-6152 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6162-6152 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6195-6153 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6185-6155 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6185-6155 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6223-6155 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6234-6155 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6158-6157 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6227-6158 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6177-6159 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6213-6159 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6223-6159 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5866-6161 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5865-6162 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6183-6162 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6241-6162 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6240-6163 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2240-6164 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1196-6166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6191-6166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6222-6166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5866-6167 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6195-6168 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6233-6169 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5867-6171 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 36-6206 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 35-6205 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6226-6172 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6232-6172 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5860-6173 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6206-6175 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6217-6175 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6219-6175 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6223-6176 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6213-6177 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6179-6178 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6214-6178 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5864-6182 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6247-6182 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5860-6183 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6194-6187 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5866-6189 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6190-6189 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1195-6191 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6232-6191 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6184-6192 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6233-6192 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6235-6193 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6027-6203 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6027-6202 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6252-6210 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5868-6212 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6146-6219 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5859-6220 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5858-6220 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5863-6221 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5862-6224 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6230-6226 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4947-6227 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5870-6229 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5869-6228 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1961-6230 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1961-6230 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 799-6231 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 325-6234 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5871-6238 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6254-6242 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6236-6248 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5861-6249 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 35-5900 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 35-5924 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 146-5872 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 146-5925 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 183-5901 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 183-5926 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 382-5927 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 460-5873 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 460-5902 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 616-5903 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 754-5874 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 754-5904 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 917-5875 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 917-5905 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 938-5876 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 939-5928 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 938-5942 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 939-5952 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1002-5877 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1002-5906 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1041-5929 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1076-5930 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1265-5953 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1462-5878 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1536-5943 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1536-5954 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1601-5879 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1601-5907 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1935-5908 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2088-5880 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2185-5931 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2185-5944 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2248-5881 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2469-5909 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2469-5932 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2668-5933 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2716-5934 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2772-5882 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2786-5883 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2787-5910 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2833-5884 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2833-5911 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2894-5885 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2894-5912 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2894-5935 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2894-5945 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2902-5886 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2918-5887 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2918-5913 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2970-5914 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2971-5936 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2971-5946 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3033-5888 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3033-5915 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3180-5889 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3180-5916 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4575-3199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1497-3505 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3618-5890 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3618-5917 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3617-5937 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3617-5947 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3706-5891 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3882-5938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3939-5892 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3939-5918 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4050-5893 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4079-5894 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4079-5919 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4108-5895 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4136-5939 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4137-5948 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4278-5896 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4294-5955 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4548-5897 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4548-5920 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4661-5940 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4661-5949 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4774-5898 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4859-5921 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-5899 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-5922 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-5941 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-5950 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-5956 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4977-5923 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4977-5951 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4977-5957 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6204-6129 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% INFO    : 
% INFO    : === Line Capacity UB Model Notes ===
% INFO    : Updated Thermal Rating: on line 4644-1 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2186
% INFO    : Updated Thermal Rating: on line 5243-1 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 910
% INFO    : Updated Thermal Rating: on line 1682-2 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2441
% INFO    : Updated Thermal Rating: on line 1673-3 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 2302-3 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 694-4 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 3940-4 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 5043-4 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 4414-5 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 2780-6 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1398
% INFO    : Updated Thermal Rating: on line 2781-7 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 884
% INFO    : Updated Thermal Rating: on line 471-9 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 11-10 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24078
% INFO    : Updated Thermal Rating: on line 11-10 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24078
% INFO    : Updated Thermal Rating: on line 30-11 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 2930-11 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 2180-12 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 4018-12 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 4020-12 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60355
% INFO    : Updated Thermal Rating: on line 1224-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 2875-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 4592-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on line 4950-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 5229-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 2875-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 4592-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 2907-15 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 4126-15 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 4454-15 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 251-16 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 339-16 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 5835-17 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 3728-18 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 5091-19 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 3728-20 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5369
% INFO    : Updated Thermal Rating: on line 1353-21 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 1598-21 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 1842-22 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 5020-22 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 1156-23 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 2705-23 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 3425-23 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 144-24 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 1281-24 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 491-25 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1048
% INFO    : Updated Thermal Rating: on line 2092-25 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 611-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 1865-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2731
% INFO    : Updated Thermal Rating: on line 2604-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 2923-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 3339-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 4629-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 2923-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 2686-28 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 3893-28 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 2888-29 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 3321-29 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 3321-29 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 144-30 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 1553-30 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 4836-30 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 150-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on line 3162-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 3693-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 4740-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1018
% INFO    : Updated Thermal Rating: on line 150-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on line 3730-32 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 4745-33 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3441
% INFO    : Updated Thermal Rating: on line 4853-34 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9629
% INFO    : Updated Thermal Rating: on line 5228-37 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5514-37 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 724-38 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4462
% INFO    : Updated Thermal Rating: on line 1228-39 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 5809-39 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 1228-39 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 2250-40 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4592-40 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 1482-42 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1465
% INFO    : Updated Thermal Rating: on line 2766-42 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3678
% INFO    : Updated Thermal Rating: on line 2725-43 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4689
% INFO    : Updated Thermal Rating: on line 3488-44 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 4324-44 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 5094-45 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38027
% INFO    : Updated Thermal Rating: on line 1084-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 2193-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 3305-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 1084-47 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 5362-48 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 1222-49 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 2344-49 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 471-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 1676-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 3554-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 4626-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on line 3554-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 4626-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 901
% INFO    : Updated Thermal Rating: on line 166-52 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 846
% INFO    : Updated Thermal Rating: on line 5488-52 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on line 3349-53 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1285
% INFO    : Updated Thermal Rating: on line 2770-54 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 375-55 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53862
% INFO    : Updated Thermal Rating: on line 5095-57 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 142-59 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on line 1652-59 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1124
% INFO    : Updated Thermal Rating: on line 2478-60 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 3526-60 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 2227-61 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 2636-61 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 2047-62 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on line 2951-62 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 996
% INFO    : Updated Thermal Rating: on line 373-63 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 3082-63 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 4604-65 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 4604-65 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 889
% INFO    : Updated Thermal Rating: on line 1546-66 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 2291-66 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on line 3249-66 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 3031-67 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1862
% INFO    : Updated Thermal Rating: on line 2193-68 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 2884-68 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 4534-68 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 5148-68 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 4607-69 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 5096-70 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303410
% INFO    : Updated Thermal Rating: on line 2164-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 3145-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 5097-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1625
% INFO    : Updated Thermal Rating: on line 3145-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 4961-75 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 2083-75 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1949
% INFO    : Updated Thermal Rating: on line 2343-77 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on line 242-78 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3471
% INFO    : Updated Thermal Rating: on line 4559-78 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90076
% INFO    : Updated Thermal Rating: on line 629-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1176
% INFO    : Updated Thermal Rating: on line 1870-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1899
% INFO    : Updated Thermal Rating: on line 2411-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1510
% INFO    : Updated Thermal Rating: on line 4078-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16079
% INFO    : Updated Thermal Rating: on line 629-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1176
% INFO    : Updated Thermal Rating: on line 4077-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18009
% INFO    : Updated Thermal Rating: on line 674-82 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 797-82 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 2072-82 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 2128-84 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 3803-84 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 5100-85 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 2810-86 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 3512-86 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 3772-87 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on line 4348-87 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 3772-87 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 1617-88 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 1706-88 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 3644-88 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 5558-88 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 2498-89 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 4228-89 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 5101-90 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21404
% INFO    : Updated Thermal Rating: on line 3728-91 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 647-92 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 4057-92 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 5728-92 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 2136-93 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on line 3769-94 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1339
% INFO    : Updated Thermal Rating: on line 5845-94 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 285-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 1173-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 5704-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1943
% INFO    : Updated Thermal Rating: on line 4112-96 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 706
% INFO    : Updated Thermal Rating: on line 3003-97 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 4178-97 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 4445-97 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 3003-97 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 1251-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 3518-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on line 4649-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 2635-99 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 2636-99 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 551-100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 1193-100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 1194-100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 1903-101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 4449-101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 1477-102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5495
% INFO    : Updated Thermal Rating: on line 1963-103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 2489-103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 4283-103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 1963-103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 2207-106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1225
% INFO    : Updated Thermal Rating: on line 2271-106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 676
% INFO    : Updated Thermal Rating: on line 3262-106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 5067-106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 3980-108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 3979-108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 632-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 671-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 759-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 5201-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 5205-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 4739-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 482-110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1479
% INFO    : Updated Thermal Rating: on line 713-111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 4442-111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 1167-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1009
% INFO    : Updated Thermal Rating: on line 1656-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 2295-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 5313-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 1168-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 1655-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 2295-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 1654-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 3522-114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 3995-114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 1243-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 1246-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on line 5408-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5530-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 4961-118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4056
% INFO    : Updated Thermal Rating: on line 1000-119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 4554-119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 1000-119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 2705-120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 5233-121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 5460-121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 5103-122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1677
% INFO    : Updated Thermal Rating: on line 5103-123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1677
% INFO    : Updated Thermal Rating: on line 5104-124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 1263-125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 1262-125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 4311-126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 5737-126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 182-127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13220
% INFO    : Updated Thermal Rating: on line 2390-129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3763
% INFO    : Updated Thermal Rating: on line 2747-129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 4261-129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 5295-129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1311
% INFO    : Updated Thermal Rating: on line 5741-128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 901
% INFO    : Updated Thermal Rating: on line 2747-128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 5294-128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1419
% INFO    : Updated Thermal Rating: on line 782-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29203
% INFO    : Updated Thermal Rating: on line 2194-132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 2735-132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 1709-133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2646
% INFO    : Updated Thermal Rating: on line 1884-136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 4814-136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 625-137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 3049-137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 4524-138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 5183-138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1408
% INFO    : Updated Thermal Rating: on line 3558-139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 4750-139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 188-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 761
% INFO    : Updated Thermal Rating: on line 1652-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 2217-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 2218-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 3892-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 5724-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 3892-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 1553-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 1560-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16510
% INFO    : Updated Thermal Rating: on line 3694-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 5043-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 915
% INFO    : Updated Thermal Rating: on line 5664-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 1560-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4881
% INFO    : Updated Thermal Rating: on line 2722-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1470
% INFO    : Updated Thermal Rating: on line 3372-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2227
% INFO    : Updated Thermal Rating: on line 4599-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2077
% INFO    : Updated Thermal Rating: on line 2722-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1470
% INFO    : Updated Thermal Rating: on line 3372-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2229
% INFO    : Updated Thermal Rating: on line 4600-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2074
% INFO    : Updated Thermal Rating: on line 4978-147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1696
% INFO    : Updated Thermal Rating: on line 481-148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2466
% INFO    : Updated Thermal Rating: on line 4244-149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 1994-150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 942
% INFO    : Updated Thermal Rating: on line 4270-152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 4518-151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 4701-152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 156-151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 3576-153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 5483-153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on line 5725-153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 520
% INFO    : Updated Thermal Rating: on line 5484-153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 5106-155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16165
% INFO    : Updated Thermal Rating: on line 683-157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 4744-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7261
% INFO    : Updated Thermal Rating: on line 5810-157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1058
% INFO    : Updated Thermal Rating: on line 1727-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 2765-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 2840-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 3693-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 4620-162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 4666-162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on line 2222-164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7864
% INFO    : Updated Thermal Rating: on line 2222-163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7864
% INFO    : Updated Thermal Rating: on line 1408-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 1590-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3620-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 3786-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 4181-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 4494-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 5140-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 5191-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on line 5409-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 3449-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 5855-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 5107-169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 632
% INFO    : Updated Thermal Rating: on line 2572-170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5167
% INFO    : Updated Thermal Rating: on line 5589-170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1501
% INFO    : Updated Thermal Rating: on line 1563-171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 4618-171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 5801-171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1032
% INFO    : Updated Thermal Rating: on line 1563-171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on line 5678-172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2348
% INFO    : Updated Thermal Rating: on line 5110-173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8279
% INFO    : Updated Thermal Rating: on line 446-174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 5368-174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1284
% INFO    : Updated Thermal Rating: on line 1943-174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 2448-175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 5165-175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3317
% INFO    : Updated Thermal Rating: on line 5150-176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 5166-176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3471
% INFO    : Updated Thermal Rating: on line 4718-177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2959
% INFO    : Updated Thermal Rating: on line 5119-177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3941
% INFO    : Updated Thermal Rating: on line 911-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11544
% INFO    : Updated Thermal Rating: on line 1447-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3780
% INFO    : Updated Thermal Rating: on line 1491-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1634
% INFO    : Updated Thermal Rating: on line 3467-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1551
% INFO    : Updated Thermal Rating: on line 4932-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2172
% INFO    : Updated Thermal Rating: on line 4937-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5543
% INFO    : Updated Thermal Rating: on line 5673-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2118
% INFO    : Updated Thermal Rating: on line 912-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9717
% INFO    : Updated Thermal Rating: on line 1447-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4305
% INFO    : Updated Thermal Rating: on line 1447-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3667
% INFO    : Updated Thermal Rating: on line 4935-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11985
% INFO    : Updated Thermal Rating: on line 4936-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14102
% INFO    : Updated Thermal Rating: on line 993-183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31961
% INFO    : Updated Thermal Rating: on line 2106-183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169660
% INFO    : Updated Thermal Rating: on line 993-183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31961
% INFO    : Updated Thermal Rating: on line 5111-184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 4412-185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16578
% INFO    : Updated Thermal Rating: on line 5112-186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 1035-187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3370
% INFO    : Updated Thermal Rating: on line 5387-188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1163
% INFO    : Updated Thermal Rating: on line 5113-189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3901
% INFO    : Updated Thermal Rating: on line 5405-190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1466
% INFO    : Updated Thermal Rating: on line 2247-191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 5603-191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 5114-192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23633
% INFO    : Updated Thermal Rating: on line 2751-193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 4833-193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 319-194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5095-194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 2506-196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 2781-196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 5336-196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3215-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3602
% INFO    : Updated Thermal Rating: on line 3215-198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3450
% INFO    : Updated Thermal Rating: on line 323-199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 572-199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53974
% INFO    : Updated Thermal Rating: on line 931-199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 323-199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 825-200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 1759-200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 5115-201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 394-204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 1073-204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 685
% INFO    : Updated Thermal Rating: on line 828-205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1051
% INFO    : Updated Thermal Rating: on line 1924-205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1030
% INFO    : Updated Thermal Rating: on line 2068-205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 2720-205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 674
% INFO    : Updated Thermal Rating: on line 2994-205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 828-205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 973
% INFO    : Updated Thermal Rating: on line 1924-205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 968
% INFO    : Updated Thermal Rating: on line 394-208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on line 1689-208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5134-208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 562-209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 562-209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 5586-210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 905
% INFO    : Updated Thermal Rating: on line 5853-210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 3931-211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1574
% INFO    : Updated Thermal Rating: on line 1796-213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 4834-212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 1796-213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 524-216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19602
% INFO    : Updated Thermal Rating: on line 1181-216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on line 1418-216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 1737-216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 1884-216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 4072-216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 4910-216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 1989-218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 5419-218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 1516-219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 1582-219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 2770-220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23039
% INFO    : Updated Thermal Rating: on line 5118-221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 739
% INFO    : Updated Thermal Rating: on line 5116-222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on line 257-223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 2044-223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 4401-223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 2313-225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on line 4156-225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 2313-225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 5119-226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24440
% INFO    : Updated Thermal Rating: on line 3834-228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17970
% INFO    : Updated Thermal Rating: on line 3834-227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17970
% INFO    : Updated Thermal Rating: on line 1550-230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 1550-229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 423-231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 3141-231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 4562-231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 423-231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 2492-232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48541
% INFO    : Updated Thermal Rating: on line 519-233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 208
% INFO    : Updated Thermal Rating: on line 1868-234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 772
% INFO    : Updated Thermal Rating: on line 4882-234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 453
% INFO    : Updated Thermal Rating: on line 3671-236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 505-238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2910
% INFO    : Updated Thermal Rating: on line 1015-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 3946-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1814
% INFO    : Updated Thermal Rating: on line 2699-240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 5014-240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 2381-241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 4607-241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 5446-241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1618
% INFO    : Updated Thermal Rating: on line 5738-241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 362-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 4558-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on line 691-243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 4452-243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 5497-243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 605
% INFO    : Updated Thermal Rating: on line 1689-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 5691-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 3155-245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 3356-245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 1927-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 2355-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 5121-247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 284-248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2780
% INFO    : Updated Thermal Rating: on line 480-248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 750-248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2322
% INFO    : Updated Thermal Rating: on line 2453-248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 4732-248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 722
% INFO    : Updated Thermal Rating: on line 2114-251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 3569-251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 1271-252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 1627-252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 2262-252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on line 2947-253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2626
% INFO    : Updated Thermal Rating: on line 4014-254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 5113-254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1070
% INFO    : Updated Thermal Rating: on line 3518-255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1500
% INFO    : Updated Thermal Rating: on line 3518-255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on line 1117-256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 3824-256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 4639-256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2181
% INFO    : Updated Thermal Rating: on line 558-257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 1687-257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 3502-258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on line 4171-258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 4555-258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 1113-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1871
% INFO    : Updated Thermal Rating: on line 762-261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 1458-261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11497
% INFO    : Updated Thermal Rating: on line 5122-263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 5064-266 : Rate A, Rate B, Rate C , 2275.0, 2275.0, 2275.0 -> 1648
% INFO    : Updated Thermal Rating: on line 727-267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7450
% INFO    : Updated Thermal Rating: on line 1905-270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 2682-270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 548-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 5287-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 1412-274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 1701-274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 4450-274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2987
% INFO    : Updated Thermal Rating: on line 4837-274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1519
% INFO    : Updated Thermal Rating: on line 5254-274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 5802-274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 4450-274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3057
% INFO    : Updated Thermal Rating: on line 1943-276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 1943-276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 739-279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on line 985-279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 1058-279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 740-279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 1057-279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 2989-281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 2470-282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 4950-282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 5082-282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 2470-282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 1262-283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 5721-285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16188
% INFO    : Updated Thermal Rating: on line 449-286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 866
% INFO    : Updated Thermal Rating: on line 2672-286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32529
% INFO    : Updated Thermal Rating: on line 3647-286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on line 5123-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306461
% INFO    : Updated Thermal Rating: on line 964-289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 2322-290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240340
% INFO    : Updated Thermal Rating: on line 2913-290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1943
% INFO    : Updated Thermal Rating: on line 4631-290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 5435-290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240340
% INFO    : Updated Thermal Rating: on line 2797-292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4503
% INFO    : Updated Thermal Rating: on line 2171-293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 2633-293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 3155-293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5203-293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 294-295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3677
% INFO    : Updated Thermal Rating: on line 481-295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 1569-295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 1243-296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1302
% INFO    : Updated Thermal Rating: on line 1303-298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 1755-299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3394
% INFO    : Updated Thermal Rating: on line 4325-300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 2165-301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8155
% INFO    : Updated Thermal Rating: on line 5126-303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 1344-304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on line 1344-304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1200
% INFO    : Updated Thermal Rating: on line 199-305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 4591-305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 5746-305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 199-305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 4591-305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 4831-306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 5410-306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 689-307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 4688-307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 3898-308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 2485-309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4933-309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 1309-310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 4579-310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 829
% INFO    : Updated Thermal Rating: on line 1638-312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2898
% INFO    : Updated Thermal Rating: on line 1638-311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2147
% INFO    : Updated Thermal Rating: on line 5622-313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3363
% INFO    : Updated Thermal Rating: on line 3152-314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24326
% INFO    : Updated Thermal Rating: on line 2644-315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2640
% INFO    : Updated Thermal Rating: on line 5159-315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 5158-315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 1035-317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 5128-317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15203
% INFO    : Updated Thermal Rating: on line 2288-318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 5287-318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5289-318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4334
% INFO    : Updated Thermal Rating: on line 2288-318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 3297-319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 3275-320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5314
% INFO    : Updated Thermal Rating: on line 5129-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22178
% INFO    : Updated Thermal Rating: on line 1257-322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 1657-322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 829-323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1681
% INFO    : Updated Thermal Rating: on line 2310-323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 3127-323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 3147-323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 4568-323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 2310-323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 3127-323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 3147-323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 3127-323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 4152-324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11556
% INFO    : Updated Thermal Rating: on line 4153-324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11556
% INFO    : Updated Thermal Rating: on line 2311-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2963
% INFO    : Updated Thermal Rating: on line 1682-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2641
% INFO    : Updated Thermal Rating: on line 521-327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 520-327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 1844-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 627
% INFO    : Updated Thermal Rating: on line 2612-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 2926-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 4119-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 5376-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 4119-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 854
% INFO    : Updated Thermal Rating: on line 1794-330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 1794-330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 2271-331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3207
% INFO    : Updated Thermal Rating: on line 2271-331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4803
% INFO    : Updated Thermal Rating: on line 4398-332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 4653-332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23670
% INFO    : Updated Thermal Rating: on line 4748-332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 1366-334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 3685-334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 1010-335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 1615-335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 2551-335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 4766-335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 5266-336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 1137-337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 2825-338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 4923-338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 871
% INFO    : Updated Thermal Rating: on line 2506-339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 2648-339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 1700-340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 1863-340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 3297-341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 3501-341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 5804-341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 3064-342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 3385-343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3238-344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 3889-344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5407-344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 1864-346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 4523-346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 5299-346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 670-347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 1731-347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 1282-348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 5456-348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 4921-349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 445-350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 3382-350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 3775-352 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2026
% INFO    : Updated Thermal Rating: on line 4599-351 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1636
% INFO    : Updated Thermal Rating: on line 3775-351 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2043
% INFO    : Updated Thermal Rating: on line 4600-352 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1634
% INFO    : Updated Thermal Rating: on line 880-355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2697-355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3014
% INFO    : Updated Thermal Rating: on line 5850-355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 5133-356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11206
% INFO    : Updated Thermal Rating: on line 1358-357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 360-358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2802
% INFO    : Updated Thermal Rating: on line 1354-359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 3151-359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 3879-359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 2299-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 3031-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5136-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5527
% INFO    : Updated Thermal Rating: on line 5617-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1680
% INFO    : Updated Thermal Rating: on line 1689-361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 4024-362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 4558-362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1216
% INFO    : Updated Thermal Rating: on line 4924-362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 5154-362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 561
% INFO    : Updated Thermal Rating: on line 2354-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 2449-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 491-365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on line 5110-365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3419
% INFO    : Updated Thermal Rating: on line 5109-365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3460
% INFO    : Updated Thermal Rating: on line 4400-366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 4740-367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12708
% INFO    : Updated Thermal Rating: on line 858-371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 3013-373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 416
% INFO    : Updated Thermal Rating: on line 3082-373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 3552-376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 3666-376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 1173-377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 1779-377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 2584-377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 2099-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 2103-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 2103-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 646-379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 2328-379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 2774-379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 403-380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 1256-380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 1537-380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on line 1908-380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 4093-380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 4896-380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 5017-380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 4896-380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 5017-380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 1937-382 : Rate A, Rate B, Rate C , 2040.0, 2040.0, 2040.0 -> 1087
% INFO    : Updated Thermal Rating: on line 2772-382 : Rate A, Rate B, Rate C , 1487.0, 1487.0, 1487.0 -> 1128
% INFO    : Updated Thermal Rating: on line 2772-382 : Rate A, Rate B, Rate C , 1487.0, 1487.0, 1487.0 -> 1127
% INFO    : Updated Thermal Rating: on line 4294-382 : Rate A, Rate B, Rate C , 2040.0, 2040.0, 2040.0 -> 1979
% INFO    : Updated Thermal Rating: on line 4013-383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 5279-383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on line 2431-384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 3698-384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 5424-384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 941-385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 3800-385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 941-385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 3800-385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 2442-386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 5232-386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5761-386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 2931-387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5778-387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 3032-388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13045
% INFO    : Updated Thermal Rating: on line 1595-389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 2945-389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on line 2714-390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 3539-390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 1403-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6238
% INFO    : Updated Thermal Rating: on line 1881-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1061
% INFO    : Updated Thermal Rating: on line 3855-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 4688-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 1402-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6629
% INFO    : Updated Thermal Rating: on line 4595-392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 5729-392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on line 1725-393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 1822-393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 2329-393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 2473-393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 3941-393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 5607-394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 1912-395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 397-396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12255
% INFO    : Updated Thermal Rating: on line 1791-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1953
% INFO    : Updated Thermal Rating: on line 4564-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3645
% INFO    : Updated Thermal Rating: on line 1791-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1958
% INFO    : Updated Thermal Rating: on line 3872-398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 4089-398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 2400-399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3851-399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 5194-400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2000
% INFO    : Updated Thermal Rating: on line 848-401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 2242-402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 2791-402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 2305-404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 2815-404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 2775-405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 5172-405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 2297-406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on line 3293-406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1859
% INFO    : Updated Thermal Rating: on line 1083-407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on line 1024-408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on line 1866-408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on line 4014-408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 794
% INFO    : Updated Thermal Rating: on line 2362-409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1257
% INFO    : Updated Thermal Rating: on line 2459-409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 2819-410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 488-411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 1062-411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2155
% INFO    : Updated Thermal Rating: on line 1869-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 3197-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 1637-413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 2047-413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 3240-413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 4081-413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 1145-414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 1145-414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 4195-415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on line 5141-415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60637
% INFO    : Updated Thermal Rating: on line 1246-416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 3673-416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 4446-416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8876
% INFO    : Updated Thermal Rating: on line 856-418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 3679-418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 4130-418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 3742-419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4316-420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 5144-420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 5142-420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on line 5142-421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2632
% INFO    : Updated Thermal Rating: on line 3555-422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8736
% INFO    : Updated Thermal Rating: on line 1481-423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 1481-423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 1567-425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 3411-425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 4022-425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 4530-425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 1567-425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 4022-425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 591
% INFO    : Updated Thermal Rating: on line 4022-425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 591
% INFO    : Updated Thermal Rating: on line 5143-427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8185
% INFO    : Updated Thermal Rating: on line 1155-428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 4681-429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on line 3874-430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1739
% INFO    : Updated Thermal Rating: on line 5209-430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4352
% INFO    : Updated Thermal Rating: on line 3874-430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1724
% INFO    : Updated Thermal Rating: on line 1666-430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on line 3297-432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 3207-433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 4009-433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 879-434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5888
% INFO    : Updated Thermal Rating: on line 1448-435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 5475-435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 986-436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 3064-436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5273-436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 665
% INFO    : Updated Thermal Rating: on line 2847-436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 3064-436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 3988-437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5703-437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 2553-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1320
% INFO    : Updated Thermal Rating: on line 2986-439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 1673-440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 2218-440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 5008-440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 5147-441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25776
% INFO    : Updated Thermal Rating: on line 5145-442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1109
% INFO    : Updated Thermal Rating: on line 2759-443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 4218-443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 1558-444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 1651-446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2031
% INFO    : Updated Thermal Rating: on line 2031-444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 4870-446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 5338-444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1672
% INFO    : Updated Thermal Rating: on line 1651-446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2031
% INFO    : Updated Thermal Rating: on line 2031-445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on line 4870-446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2767
% INFO    : Updated Thermal Rating: on line 3595-448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on line 1233-449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 2908-449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 3984-449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 2908-449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 2764-451 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 899
% INFO    : Updated Thermal Rating: on line 5153-452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 463-453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 2338-453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 2701-453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 3714-453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 2338-453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 3440-453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on line 5154-455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 4067-457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4777
% INFO    : Updated Thermal Rating: on line 4067-456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4695
% INFO    : Updated Thermal Rating: on line 4247-458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6068
% INFO    : Updated Thermal Rating: on line 3174-461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1465
% INFO    : Updated Thermal Rating: on line 4022-462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5482-463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 5155-464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3473
% INFO    : Updated Thermal Rating: on line 2714-466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4634
% INFO    : Updated Thermal Rating: on line 5157-467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11716
% INFO    : Updated Thermal Rating: on line 2184-468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5279
% INFO    : Updated Thermal Rating: on line 3481-468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 606
% INFO    : Updated Thermal Rating: on line 3562-469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 2184-468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5207
% INFO    : Updated Thermal Rating: on line 3480-468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 604
% INFO    : Updated Thermal Rating: on line 3562-469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 2184-468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5279
% INFO    : Updated Thermal Rating: on line 2989-471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 976-472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 3345-472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 3745-472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1264
% INFO    : Updated Thermal Rating: on line 4299-475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 4300-475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 2173-476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 3876-476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 5575-477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 3764-478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 883
% INFO    : Updated Thermal Rating: on line 3764-478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 883
% INFO    : Updated Thermal Rating: on line 4046-479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 641-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1032
% INFO    : Updated Thermal Rating: on line 1834-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 3579-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22978
% INFO    : Updated Thermal Rating: on line 975-481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32501
% INFO    : Updated Thermal Rating: on line 1568-481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1180
% INFO    : Updated Thermal Rating: on line 2147-481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 2167-481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2140
% INFO    : Updated Thermal Rating: on line 3156-481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2216
% INFO    : Updated Thermal Rating: on line 1569-481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 2168-481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2140
% INFO    : Updated Thermal Rating: on line 2169-481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2196
% INFO    : Updated Thermal Rating: on line 2013-483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 2511-484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 5442-484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2109
% INFO    : Updated Thermal Rating: on line 5598-484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6697
% INFO    : Updated Thermal Rating: on line 5603-484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7777
% INFO    : Updated Thermal Rating: on line 964-485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 641
% INFO    : Updated Thermal Rating: on line 4176-485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 3546-486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 5158-487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1112
% INFO    : Updated Thermal Rating: on line 1029-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 1062-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 652-489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1016
% INFO    : Updated Thermal Rating: on line 3641-489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 2262-490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 2620-490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 2202-491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 3572-493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 5083-493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 2157-499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11206
% INFO    : Updated Thermal Rating: on line 2459-503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 2564-503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5199-503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 3980-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 3979-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 735-505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 1281-505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 1816-505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1243
% INFO    : Updated Thermal Rating: on line 5120-505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27851
% INFO    : Updated Thermal Rating: on line 5362-505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1243
% INFO    : Updated Thermal Rating: on line 2669-507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 4344-507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 5161-508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on line 5162-508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 3983-509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 1564-510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 5229-510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5619-511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 5620-511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 2970-513 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 2232
% INFO    : Updated Thermal Rating: on line 2971-513 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2175
% INFO    : Updated Thermal Rating: on line 1081-514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on line 2589-514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 1194-515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 5455-516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 880
% INFO    : Updated Thermal Rating: on line 2266-517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 3213-517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 564-518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 4200-519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 4312-519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 1405-520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 2891-520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 2927-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 3674-520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1260
% INFO    : Updated Thermal Rating: on line 3839-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 4268-520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 5657-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1557
% INFO    : Updated Thermal Rating: on line 2927-520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 1131-525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 1921-525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 2958-525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 3037-525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 872
% INFO    : Updated Thermal Rating: on line 3316-525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 824
% INFO    : Updated Thermal Rating: on line 4250-525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 4692-525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 4767-525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 5555-525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 832
% INFO    : Updated Thermal Rating: on line 5699-525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 4691-525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on line 3538-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5617
% INFO    : Updated Thermal Rating: on line 528-527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3553
% INFO    : Updated Thermal Rating: on line 1354-527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 1842-527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 1084-529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3109
% INFO    : Updated Thermal Rating: on line 531-530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113138
% INFO    : Updated Thermal Rating: on line 1395-530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 1395-530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 3881-532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1527
% INFO    : Updated Thermal Rating: on line 3881-532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1549
% INFO    : Updated Thermal Rating: on line 662-533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 952
% INFO    : Updated Thermal Rating: on line 1355-533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 2880-533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39543
% INFO    : Updated Thermal Rating: on line 3459-533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 584
% INFO    : Updated Thermal Rating: on line 5681-533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 940
% INFO    : Updated Thermal Rating: on line 5682-533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2989
% INFO    : Updated Thermal Rating: on line 662-533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 966
% INFO    : Updated Thermal Rating: on line 3459-533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 5538-533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1153
% INFO    : Updated Thermal Rating: on line 645-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 1320-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 1356-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 1193-536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 5385-536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 1134-537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 2100-538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 1344-539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1745
% INFO    : Updated Thermal Rating: on line 2090-542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 2685-542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 2988-542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7234
% INFO    : Updated Thermal Rating: on line 5776-542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1798
% INFO    : Updated Thermal Rating: on line 1685-544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 5167-544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 5577-545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 5598-545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 5165-546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53974
% INFO    : Updated Thermal Rating: on line 5811-546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9545
% INFO    : Updated Thermal Rating: on line 2600-547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 5130-547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 3072-548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5697
% INFO    : Updated Thermal Rating: on line 3200-549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 1543-550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 2735-550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3570-550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 5196-550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 1543-550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on line 1192-551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 1556-551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 3394-552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 5706-552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 4348-553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 4894-553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 4348-553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 1793-556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20021
% INFO    : Updated Thermal Rating: on line 1137-558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 3074-558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 3644-558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 4376-558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2807
% INFO    : Updated Thermal Rating: on line 5408-559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3126
% INFO    : Updated Thermal Rating: on line 3003-560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 1132-561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 2470-561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 2660-562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 4799-562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 851-564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 2983-564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2826
% INFO    : Updated Thermal Rating: on line 851-564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 1014-565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 4237-565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 2448-566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 5806-566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 4533-567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 2310-568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 5028-568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 584-569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 4219-569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 1072-570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 3324-570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 1903-571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 4866-571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 1184-573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 3891-573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 4855-573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 4904-573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 3114-573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 5702-573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 1576-574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 2044-574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 1825-575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8751
% INFO    : Updated Thermal Rating: on line 653-576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19054
% INFO    : Updated Thermal Rating: on line 5170-577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4152
% INFO    : Updated Thermal Rating: on line 1211-579 : Rate A, Rate B, Rate C , 935.0, 935.0, 935.0 -> 892
% INFO    : Updated Thermal Rating: on line 5034-582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2290
% INFO    : Updated Thermal Rating: on line 3041-583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1948
% INFO    : Updated Thermal Rating: on line 1459-584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 1156-585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 4983-585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 556
% INFO    : Updated Thermal Rating: on line 5277-585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 893
% INFO    : Updated Thermal Rating: on line 2431-586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 2496-586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 5172-587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5340-588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 5692-588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 1525-589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1954
% INFO    : Updated Thermal Rating: on line 1524-589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1954
% INFO    : Updated Thermal Rating: on line 5173-590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11707
% INFO    : Updated Thermal Rating: on line 3207-591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 4009-591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 4009-591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 2645-592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 5791-595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1635
% INFO    : Updated Thermal Rating: on line 3518-596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on line 1516-598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 1852-599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5730-599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 2688-600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1022
% INFO    : Updated Thermal Rating: on line 5352-600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 736-601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 1888-601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 830
% INFO    : Updated Thermal Rating: on line 2060-601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 3854-601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7133
% INFO    : Updated Thermal Rating: on line 1888-601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 830
% INFO    : Updated Thermal Rating: on line 2379-606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 3945-606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 4328-606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 880-608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 4369-608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 5508-610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153231
% INFO    : Updated Thermal Rating: on line 3339-611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 2189-612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 5375-612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 3090-613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2772-616 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 639
% INFO    : Updated Thermal Rating: on line 5176-618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9349
% INFO    : Updated Thermal Rating: on line 5180-617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 5034-619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3851
% INFO    : Updated Thermal Rating: on line 5034-620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3667
% INFO    : Updated Thermal Rating: on line 1246-621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 4898-622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5038-622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 5245-622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2048
% INFO    : Updated Thermal Rating: on line 5837-622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 2706-623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2032
% INFO    : Updated Thermal Rating: on line 817-624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2405
% INFO    : Updated Thermal Rating: on line 1107-624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on line 2596-624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 5183-627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8880
% INFO    : Updated Thermal Rating: on line 5190-628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 5181-631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 5184-630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99170
% INFO    : Updated Thermal Rating: on line 4233-632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 5182-633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13714
% INFO    : Updated Thermal Rating: on line 1262-634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 4284-634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 2463-635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 2543-635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 5596-635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 2793-636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 4567-636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5705-636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 1110-637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 3982-637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 5157-638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26199
% INFO    : Updated Thermal Rating: on line 1000-642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 842
% INFO    : Updated Thermal Rating: on line 1344-643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1036
% INFO    : Updated Thermal Rating: on line 1344-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 1356-645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 4284-646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 1740-647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 4457-647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 1740-647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 4926-647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 5789-647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1696
% INFO    : Updated Thermal Rating: on line 1785-648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1017
% INFO    : Updated Thermal Rating: on line 5187-648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4316
% INFO    : Updated Thermal Rating: on line 3181-649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 3578-649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 5226-649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 5188-650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 5189-651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 2005-652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 2753-652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 2862-652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 4373-652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 5159-652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 5432-652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 1077-652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 2190-652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 5158-652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 2172-654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 3764-654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 4120-655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 1210-656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1090
% INFO    : Updated Thermal Rating: on line 3871-656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 1210-656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 1625-658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4374
% INFO    : Updated Thermal Rating: on line 1432-659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 5247-659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3171
% INFO    : Updated Thermal Rating: on line 5641-660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3297
% INFO    : Updated Thermal Rating: on line 4890-661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 934
% INFO    : Updated Thermal Rating: on line 4466-666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183736
% INFO    : Updated Thermal Rating: on line 4465-665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170060
% INFO    : Updated Thermal Rating: on line 4466-664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158275
% INFO    : Updated Thermal Rating: on line 4465-663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158275
% INFO    : Updated Thermal Rating: on line 1821-667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 2532-667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 2557-667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 2767-667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 2229-667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1698
% INFO    : Updated Thermal Rating: on line 2770-669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 4846-669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 5820-669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 4846-669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 1506-670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 2024-670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 5413-670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 1390-671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 3850-671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 4911-671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 3380-672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 3064-673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 1755-674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 2823-676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 5398-676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 4933-678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 807
% INFO    : Updated Thermal Rating: on line 2683-679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 3562-680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1443
% INFO    : Updated Thermal Rating: on line 3562-680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1444
% INFO    : Updated Thermal Rating: on line 3562-680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1541
% INFO    : Updated Thermal Rating: on line 1318-681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5193-681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85273
% INFO    : Updated Thermal Rating: on line 3903-682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 2000-683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 499
% INFO    : Updated Thermal Rating: on line 5415-683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 4208-685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 2347-687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27692
% INFO    : Updated Thermal Rating: on line 2348-688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30077
% INFO    : Updated Thermal Rating: on line 5487-689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 886-691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1255
% INFO    : Updated Thermal Rating: on line 2815-691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 735-694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 4032-694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 5580-694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1266
% INFO    : Updated Thermal Rating: on line 4685-694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 3897-702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 4319-701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 5194-702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 5721-702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 4319-701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 4030-704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 5415-704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 5840-704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 4852-704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 5720-705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on line 2618-710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 2732-710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 2913-709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2138
% INFO    : Updated Thermal Rating: on line 3314-709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 5435-709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 3314-709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 5195-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13344
% INFO    : Updated Thermal Rating: on line 5231-713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 4444-714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6053
% INFO    : Updated Thermal Rating: on line 961-715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5004-715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 1185-715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 3038-715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 1929-716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2340
% INFO    : Updated Thermal Rating: on line 715-717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1471
% INFO    : Updated Thermal Rating: on line 3568-718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 5816-718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 5347-719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 988
% INFO    : Updated Thermal Rating: on line 5531-719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 4331-719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 4286-720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3082
% INFO    : Updated Thermal Rating: on line 5196-721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1403
% INFO    : Updated Thermal Rating: on line 5633-721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5354
% INFO    : Updated Thermal Rating: on line 1390-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 1903-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 5676-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 2848-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 4281-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7550
% INFO    : Updated Thermal Rating: on line 4742-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 4280-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7550
% INFO    : Updated Thermal Rating: on line 4742-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 2181-725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 2455-725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 2724-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on line 4140-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 4148-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 5507-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 5579-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 2181-725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 4140-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 4588-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1086
% INFO    : Updated Thermal Rating: on line 3349-728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3349-727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 3349-729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 924-730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 640
% INFO    : Updated Thermal Rating: on line 924-730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 601
% INFO    : Updated Thermal Rating: on line 971-731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 5197-732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37051
% INFO    : Updated Thermal Rating: on line 5198-733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 2161-734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3789
% INFO    : Updated Thermal Rating: on line 4827-737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on line 1562-738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308785
% INFO    : Updated Thermal Rating: on line 2535-741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 3662-741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 462
% INFO    : Updated Thermal Rating: on line 4776-741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 5473-741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 744-743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 5040-743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 462
% INFO    : Updated Thermal Rating: on line 3668-744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 3619-745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2859
% INFO    : Updated Thermal Rating: on line 3429-746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 488-747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19914
% INFO    : Updated Thermal Rating: on line 2011-748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 2042-748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 5051-748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 1219-749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 4093-749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 4951-749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 1475-751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 3441-751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 4688-752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 2747-755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 2958-755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 4388-755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1432
% INFO    : Updated Thermal Rating: on line 5699-755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 3635-756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39366
% INFO    : Updated Thermal Rating: on line 3882-756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22986
% INFO    : Updated Thermal Rating: on line 5201-760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 1846-763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6823
% INFO    : Updated Thermal Rating: on line 1557-764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 3311-764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 3810-765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 4033-765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 342-766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 5118-766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4814
% INFO    : Updated Thermal Rating: on line 660-767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 1301-767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 2220-767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2103
% INFO    : Updated Thermal Rating: on line 2316-767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 3061-767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 4117-767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1768
% INFO    : Updated Thermal Rating: on line 4545-767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 5411-767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2192
% INFO    : Updated Thermal Rating: on line 5623-767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 1301-767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 3061-767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 1757-772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2121
% INFO    : Updated Thermal Rating: on line 1877-772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6273
% INFO    : Updated Thermal Rating: on line 3718-772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6192
% INFO    : Updated Thermal Rating: on line 4847-772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 5646-772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 1877-772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6068
% INFO    : Updated Thermal Rating: on line 5648-772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2763
% INFO    : Updated Thermal Rating: on line 2301-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 919-774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 4827-774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1350
% INFO    : Updated Thermal Rating: on line 899-775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on line 2727-775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 3766-775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 900-775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 952-779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5006
% INFO    : Updated Thermal Rating: on line 952-778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9266
% INFO    : Updated Thermal Rating: on line 952-777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5965
% INFO    : Updated Thermal Rating: on line 5204-780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 1760-781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 2518-781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 5206-784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 1128-788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 3424-787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 3463-788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 4329-787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 4539-788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 4778-787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 5808-788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 5830-788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7106
% INFO    : Updated Thermal Rating: on line 1340-788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 4539-787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 2631-791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2728
% INFO    : Updated Thermal Rating: on line 2348-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 4620-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 4900-793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on line 4838-794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 4900-794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on line 481-795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 923-795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16094
% INFO    : Updated Thermal Rating: on line 817-796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4138
% INFO    : Updated Thermal Rating: on line 3124-796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7080
% INFO    : Updated Thermal Rating: on line 4404-796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2128
% INFO    : Updated Thermal Rating: on line 1222-797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 1988-798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 3494-798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 4408-798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2555
% INFO    : Updated Thermal Rating: on line 1988-798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 3679-805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6082
% INFO    : Updated Thermal Rating: on line 1765-806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85273
% INFO    : Updated Thermal Rating: on line 3147-806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 1613-809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 4921-809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 844-810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1013
% INFO    : Updated Thermal Rating: on line 5613-810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 986
% INFO    : Updated Thermal Rating: on line 5608-810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 974
% INFO    : Updated Thermal Rating: on line 4931-812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2909
% INFO    : Updated Thermal Rating: on line 4442-813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 4920-813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 5295-815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19262
% INFO    : Updated Thermal Rating: on line 5294-814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 2443-817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 819-818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8292
% INFO    : Updated Thermal Rating: on line 4327-818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 1071-819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 5534-819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 4827-822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 2133-823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4554
% INFO    : Updated Thermal Rating: on line 4250-824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on line 2011-825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on line 1199-827 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1075
% INFO    : Updated Thermal Rating: on line 2787-827 : Rate A, Rate B, Rate C , 1987.0, 1987.0, 1987.0 -> 1524
% INFO    : Updated Thermal Rating: on line 2720-828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 941
% INFO    : Updated Thermal Rating: on line 3094-830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 4046-830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on line 4678-831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4845
% INFO    : Updated Thermal Rating: on line 5214-832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7650
% INFO    : Updated Thermal Rating: on line 1678-833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 4636-833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 2235-834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 3028-834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 3380-834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3452-835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 3659-835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 591
% INFO    : Updated Thermal Rating: on line 4777-835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1018
% INFO    : Updated Thermal Rating: on line 2959-837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 5405-836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5544-836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12012
% INFO    : Updated Thermal Rating: on line 5213-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 2954-839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 4126-839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 4827-840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 803
% INFO    : Updated Thermal Rating: on line 5208-841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27427
% INFO    : Updated Thermal Rating: on line 1882-842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10493
% INFO    : Updated Thermal Rating: on line 1882-842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10493
% INFO    : Updated Thermal Rating: on line 1552-843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 5041-843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 3001-845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1253
% INFO    : Updated Thermal Rating: on line 3001-847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1560
% INFO    : Updated Thermal Rating: on line 3001-846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1648
% INFO    : Updated Thermal Rating: on line 1923-848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3798-848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1023
% INFO    : Updated Thermal Rating: on line 3957-848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 5546-848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 929
% INFO    : Updated Thermal Rating: on line 5267-848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 5547-848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 865
% INFO    : Updated Thermal Rating: on line 3004-849 : Rate A, Rate B, Rate C , 736.0, 736.0, 736.0 -> 460
% INFO    : Updated Thermal Rating: on line 4029-850 : Rate A, Rate B, Rate C , 1932.0, 1932.0, 1932.0 -> 1807
% INFO    : Updated Thermal Rating: on line 4029-850 : Rate A, Rate B, Rate C , 1932.0, 1932.0, 1932.0 -> 1827
% INFO    : Updated Thermal Rating: on line 1821-851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 1821-851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 1141-854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 5689-855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2104
% INFO    : Updated Thermal Rating: on line 2719-856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 3111-856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 5756-856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 2973-857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on line 4906-857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3854
% INFO    : Updated Thermal Rating: on line 2379-860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 3450-860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 3905-860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 4328-860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 5221-864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5218-863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 4219-865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 1158-866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 5391-867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2340
% INFO    : Updated Thermal Rating: on line 1613-868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 2253-868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 4492-868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12351
% INFO    : Updated Thermal Rating: on line 2491-870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1532
% INFO    : Updated Thermal Rating: on line 2491-869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2339
% INFO    : Updated Thermal Rating: on line 4646-871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on line 4648-871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 4595-872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 5259-872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 4595-872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1859
% INFO    : Updated Thermal Rating: on line 5210-873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on line 2669-874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 4344-874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 2253-876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 2253-875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 3393-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3733-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 4760-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2662
% INFO    : Updated Thermal Rating: on line 5048-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 5669-880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5773-880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 4782-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 2209-883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1095
% INFO    : Updated Thermal Rating: on line 5296-883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1181
% INFO    : Updated Thermal Rating: on line 5448-884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1499
% INFO    : Updated Thermal Rating: on line 5225-885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 3307-886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on line 4679-886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 5556-886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 2185-888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21471
% INFO    : Updated Thermal Rating: on line 3008-887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27618
% INFO    : Updated Thermal Rating: on line 4128-887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42153
% INFO    : Updated Thermal Rating: on line 1311-890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4057
% INFO    : Updated Thermal Rating: on line 2039-891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 5223-891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 599
% INFO    : Updated Thermal Rating: on line 2540-892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5882
% INFO    : Updated Thermal Rating: on line 3380-893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 4154-893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 4782-894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 5078-901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on line 5852-901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11095
% INFO    : Updated Thermal Rating: on line 4720-902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 3940-903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 4166-903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 3380-904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 4154-904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 3575-905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20979
% INFO    : Updated Thermal Rating: on line 5802-906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1019
% INFO    : Updated Thermal Rating: on line 5229-907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2617
% INFO    : Updated Thermal Rating: on line 3649-908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on line 5803-908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 2487-909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 4441-909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 1753-910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 5232-913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 2783-917 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1573
% INFO    : Updated Thermal Rating: on line 4859-917 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1434
% INFO    : Updated Thermal Rating: on line 2783-917 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1578
% INFO    : Updated Thermal Rating: on line 4859-917 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1435
% INFO    : Updated Thermal Rating: on line 5233-918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 4827-919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 1802-920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 5671-920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 4458-920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5168-921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5752-921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 5561-923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 1347-924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 2563-924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 1347-924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 2563-924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 2399-926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4207
% INFO    : Updated Thermal Rating: on line 3840-926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 2708-927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 5323-927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 2172-928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1060
% INFO    : Updated Thermal Rating: on line 1791-929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 1791-929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 4122-930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 5819-931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 2813-940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 5674-940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 2117-941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 2553-941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1366
% INFO    : Updated Thermal Rating: on line 3211-941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 3549-941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 5478-941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1012
% INFO    : Updated Thermal Rating: on line 5643-941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 2553-941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1363
% INFO    : Updated Thermal Rating: on line 2561-944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 1533-945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on line 1533-945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1032
% INFO    : Updated Thermal Rating: on line 3338-947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 3917-947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 2464-946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3917-946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3307-948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2856
% INFO    : Updated Thermal Rating: on line 2710-949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3338
% INFO    : Updated Thermal Rating: on line 3321-949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 5501-949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3338
% INFO    : Updated Thermal Rating: on line 2213-950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on line 2813-950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 2599-951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 3432-951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 1044-952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 1102-952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 2361-952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 3073-952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 1516-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1281
% INFO    : Updated Thermal Rating: on line 1372-956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4421
% INFO    : Updated Thermal Rating: on line 2300-957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 2315-957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 2914-957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 4412-957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 986
% INFO    : Updated Thermal Rating: on line 4635-957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 4869-957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 4412-957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1091
% INFO    : Updated Thermal Rating: on line 1218-958 : Rate A, Rate B, Rate C , 1611.0, 1611.0, 1611.0 -> 1100
% INFO    : Updated Thermal Rating: on line 1242-958 : Rate A, Rate B, Rate C , 1567.0, 1567.0, 1567.0 -> 1311
% INFO    : Updated Thermal Rating: on line 2149-958 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2245
% INFO    : Updated Thermal Rating: on line 2149-958 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2244
% INFO    : Updated Thermal Rating: on line 4904-959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21515
% INFO    : Updated Thermal Rating: on line 5240-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31602
% INFO    : Updated Thermal Rating: on line 2950-961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3706
% INFO    : Updated Thermal Rating: on line 1183-962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 5702-962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16188
% INFO    : Updated Thermal Rating: on line 2949-963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3917-963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 4439-963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 2741-964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 3460-964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 721
% INFO    : Updated Thermal Rating: on line 3770-964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 4014-964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 4051-964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 5310-964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4437
% INFO    : Updated Thermal Rating: on line 2742-964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 959
% INFO    : Updated Thermal Rating: on line 3769-964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 972-968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1015
% INFO    : Updated Thermal Rating: on line 2950-968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 3315-971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 5786-971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 2262-972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 2606-972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on line 4098-972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 1851-972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 4811-972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 2774-974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 3052-976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41442
% INFO    : Updated Thermal Rating: on line 3345-976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 5241-977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on line 2961-978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 3365-978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 5717-978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 3365-978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 971
% INFO    : Updated Thermal Rating: on line 5361-978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3365-978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 2244-980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on line 2651-980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 2774-980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 587
% INFO    : Updated Thermal Rating: on line 3810-980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4033-980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 4284-980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on line 4728-980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 4284-980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 1114-982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 5552-982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 5783-982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 5005-982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on line 2484-983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on line 2823-983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 2170-984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1004
% INFO    : Updated Thermal Rating: on line 3839-984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 1382-986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 2718-986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1152
% INFO    : Updated Thermal Rating: on line 1205-987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8928
% INFO    : Updated Thermal Rating: on line 3201-989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on line 3469-990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 2305-991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1165
% INFO    : Updated Thermal Rating: on line 2296-992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4380
% INFO    : Updated Thermal Rating: on line 3741-992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3280
% INFO    : Updated Thermal Rating: on line 4796-992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3203
% INFO    : Updated Thermal Rating: on line 4795-992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5279
% INFO    : Updated Thermal Rating: on line 3560-995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 3776-995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 1350-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 2072-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 5237-997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 1089-998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 2111-998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 1042-1000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 1082-1000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 1255-1000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 5278-1000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2777
% INFO    : Updated Thermal Rating: on line 4956-1003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1475
% INFO    : Updated Thermal Rating: on line 5712-1003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 889
% INFO    : Updated Thermal Rating: on line 4635-1004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 2127-1005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on line 2906-1005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 1730-1008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 5354-1008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 5480-1009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1966
% INFO    : Updated Thermal Rating: on line 3929-1010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3362
% INFO    : Updated Thermal Rating: on line 5242-1013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13732
% INFO    : Updated Thermal Rating: on line 2213-1014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 2864-1014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 2864-1014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 1252-1015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2156
% INFO    : Updated Thermal Rating: on line 3458-1015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 5238-1015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 5357-1015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2280
% INFO    : Updated Thermal Rating: on line 1252-1015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1556
% INFO    : Updated Thermal Rating: on line 5238-1017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 4790-1018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 1755-1019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 4149-1019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 2276-1020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2545
% INFO    : Updated Thermal Rating: on line 4291-1020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 972-1021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 2629-1021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10350
% INFO    : Updated Thermal Rating: on line 972-1021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 972-1021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 1357-1023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154266
% INFO    : Updated Thermal Rating: on line 1357-1022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151981
% INFO    : Updated Thermal Rating: on line 5391-1024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 5243-1025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1065
% INFO    : Updated Thermal Rating: on line 3344-1027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 3344-1026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 4511-1028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 2158-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2424
% INFO    : Updated Thermal Rating: on line 2810-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 1480-1031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8853
% INFO    : Updated Thermal Rating: on line 1480-1030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7257
% INFO    : Updated Thermal Rating: on line 1358-1033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 4646-1034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1023
% INFO    : Updated Thermal Rating: on line 4646-1035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1140
% INFO    : Updated Thermal Rating: on line 4646-1034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1127
% INFO    : Updated Thermal Rating: on line 4895-1036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1105
% INFO    : Updated Thermal Rating: on line 2159-1037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 3053-1037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 4368-1037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 2159-1037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 3054-1037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 4367-1037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 3783-1037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 877
% INFO    : Updated Thermal Rating: on line 3783-1037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 3351-1038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3425
% INFO    : Updated Thermal Rating: on line 5010-1038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5192
% INFO    : Updated Thermal Rating: on line 5011-1038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5314
% INFO    : Updated Thermal Rating: on line 4532-1041 : Rate A, Rate B, Rate C , 1566.0, 1566.0, 1566.0 -> 1490
% INFO    : Updated Thermal Rating: on line 4532-1040 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1720
% INFO    : Updated Thermal Rating: on line 4532-1040 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1735
% INFO    : Updated Thermal Rating: on line 1104-1045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5823
% INFO    : Updated Thermal Rating: on line 2277-1045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 3303-1045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on line 4402-1045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 4415-1045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 5173-1045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 5689-1044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 974
% INFO    : Updated Thermal Rating: on line 1101-1045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5169
% INFO    : Updated Thermal Rating: on line 5690-1044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 979
% INFO    : Updated Thermal Rating: on line 1103-1044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6551
% INFO    : Updated Thermal Rating: on line 2669-1044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 1228-1047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 1228-1047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1001
% INFO    : Updated Thermal Rating: on line 3134-1048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 4978-1048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1828
% INFO    : Updated Thermal Rating: on line 5063-1049 : Rate A, Rate B, Rate C , 1917.0, 1917.0, 1917.0 -> 1451
% INFO    : Updated Thermal Rating: on line 5064-1049 : Rate A, Rate B, Rate C , 1917.0, 1917.0, 1917.0 -> 1451
% INFO    : Updated Thermal Rating: on line 1187-1051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9991
% INFO    : Updated Thermal Rating: on line 3168-1051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10322
% INFO    : Updated Thermal Rating: on line 5245-1052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7488
% INFO    : Updated Thermal Rating: on line 2412-1054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 4425-1054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 3201-1055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on line 4396-1061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1127
% INFO    : Updated Thermal Rating: on line 2213-1062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 2813-1062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 5188-1062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 5380-1062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on line 4994-1064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 2003-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on line 2266-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 4929-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 5366-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 5031-1069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 5248-1069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 2035-1070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 2667-1070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 5553-1070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179912
% INFO    : Updated Thermal Rating: on line 2407-1071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 3005-1072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 5716-1073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 2219-1074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 3952-1074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 2249-1077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 2753-1077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 2837-1077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 5601-1077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 5602-1077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 5834-1077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 5312-1081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24008
% INFO    : Updated Thermal Rating: on line 1952-1083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 2343-1083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 2297-1084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 4680-1084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 5552-1084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 5719-1084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 1669-1086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2144
% INFO    : Updated Thermal Rating: on line 4981-1087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 4981-1087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 1939-1088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5574
% INFO    : Updated Thermal Rating: on line 5680-1088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6551
% INFO    : Updated Thermal Rating: on line 1938-1088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37051
% INFO    : Updated Thermal Rating: on line 2743-1089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 2513-1090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 4358-1090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 1205-1091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 4290-1091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4022
% INFO    : Updated Thermal Rating: on line 1470-1093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 1469-1094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4260-1097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5788
% INFO    : Updated Thermal Rating: on line 1766-1098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 2677-1098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 2297-1099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1984
% INFO    : Updated Thermal Rating: on line 2297-1099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 920
% INFO    : Updated Thermal Rating: on line 3523-1100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 3523-1100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3036
% INFO    : Updated Thermal Rating: on line 4551-1102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1872
% INFO    : Updated Thermal Rating: on line 5250-1105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113138
% INFO    : Updated Thermal Rating: on line 5576-1106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5577-1106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 2424-1107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 2596-1107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 2424-1107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 2747-1109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1807
% INFO    : Updated Thermal Rating: on line 2321-1110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 3193-1110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3862
% INFO    : Updated Thermal Rating: on line 5253-1111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27873
% INFO    : Updated Thermal Rating: on line 2452-1113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 4504-1113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 5080-1113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 3293-1114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 3578-1115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 5041-1115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 5226-1115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1503
% INFO    : Updated Thermal Rating: on line 5227-1115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5847-1115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 3578-1115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on line 3601-1115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 3601-1115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 1957-1117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 870
% INFO    : Updated Thermal Rating: on line 2568-1118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on line 1771-1120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 2504-1119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 848
% INFO    : Updated Thermal Rating: on line 4440-1119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2826
% INFO    : Updated Thermal Rating: on line 4516-1120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 2504-1119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 848
% INFO    : Updated Thermal Rating: on line 3548-1121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 5254-1121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2753
% INFO    : Updated Thermal Rating: on line 1499-1122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on line 1918-1122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 2082-1122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 1545-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2430
% INFO    : Updated Thermal Rating: on line 4961-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 4961-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 2568-1125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on line 2568-1126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2715
% INFO    : Updated Thermal Rating: on line 5256-1127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320583
% INFO    : Updated Thermal Rating: on line 1306-1128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 2320-1129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 4529-1129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3778
% INFO    : Updated Thermal Rating: on line 1382-1130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 3392-1130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 4686-1132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5258-1133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10315
% INFO    : Updated Thermal Rating: on line 1228-1134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 2717-1134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1134
% INFO    : Updated Thermal Rating: on line 5503-1134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 2459-1136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 5649-1136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 3074-1137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 3749-1137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3356
% INFO    : Updated Thermal Rating: on line 5257-1137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7884
% INFO    : Updated Thermal Rating: on line 3100-1137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 1358-1139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 3245-1139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 1358-1139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 2803-1141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 2986-1140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 5108-1141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1642
% INFO    : Updated Thermal Rating: on line 5250-1140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 984
% INFO    : Updated Thermal Rating: on line 5485-1141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 4999-1143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2077
% INFO    : Updated Thermal Rating: on line 5259-1144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 2383-1145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 2843-1145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on line 5224-1145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 5445-1145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 5448-1145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 5266-1145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 5261-1148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 2588-1151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 4350-1151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 1814-1152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 3560-1152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 3619-1153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 3810-1154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1691
% INFO    : Updated Thermal Rating: on line 2137-1155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 3023-1156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1471
% INFO    : Updated Thermal Rating: on line 3465-1156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2805
% INFO    : Updated Thermal Rating: on line 3507-1156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5550-1155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 5629-1155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1715
% INFO    : Updated Thermal Rating: on line 5667-1155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 3362-1158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 4742-1158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 5770-1158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 5260-1159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1543
% INFO    : Updated Thermal Rating: on line 4792-1163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3672
% INFO    : Updated Thermal Rating: on line 4791-1164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3321
% INFO    : Updated Thermal Rating: on line 4792-1165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3234
% INFO    : Updated Thermal Rating: on line 4563-1167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 5114-1169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 2580-1170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 4981-1171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5594-1171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 2829-1173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 3091-1173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 3639-1173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 4201-1173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2331
% INFO    : Updated Thermal Rating: on line 4225-1173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1574
% INFO    : Updated Thermal Rating: on line 4684-1173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 5621-1173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1239
% INFO    : Updated Thermal Rating: on line 3091-1173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 4224-1173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 5704-1173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1397
% INFO    : Updated Thermal Rating: on line 3363-1179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 3609-1180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 4053-1180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8488
% INFO    : Updated Thermal Rating: on line 5698-1180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 5019-1181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 1191-1182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43410
% INFO    : Updated Thermal Rating: on line 2652-1184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 5845-1183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 3227-1185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 3915-1188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1646
% INFO    : Updated Thermal Rating: on line 5403-1188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 1963-1190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 4617-1190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 2142-1191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 2161-1191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1337
% INFO    : Updated Thermal Rating: on line 4160-1191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19301
% INFO    : Updated Thermal Rating: on line 4082-1193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 4320-1194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 5749-1193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 4082-1192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116592
% INFO    : Updated Thermal Rating: on line 3667-1198 : Rate A, Rate B, Rate C , 558.0, 558.0, 558.0 -> 297
% INFO    : Updated Thermal Rating: on line 1518-1199 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1002
% INFO    : Updated Thermal Rating: on line 1518-1199 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 996
% INFO    : Updated Thermal Rating: on line 2786-1199 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 633
% INFO    : Updated Thermal Rating: on line 3388-1200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 4004-1200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5582-1200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 4656-1201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 5439-1201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2398
% INFO    : Updated Thermal Rating: on line 5438-1201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2398
% INFO    : Updated Thermal Rating: on line 4179-1204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12326
% INFO    : Updated Thermal Rating: on line 4980-1204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 5089-1203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 5163-1203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 2725-1205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 3958-1205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 3959-1205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 4421-1205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 4422-1205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 3887-1207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 5004-1207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 208
% INFO    : Updated Thermal Rating: on line 1987-1207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 3391-1207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 5269-1209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27851
% INFO    : Updated Thermal Rating: on line 2253-1210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 3871-1210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 4138-1210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 2253-1210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 5726-1210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 4606-1212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2918
% INFO    : Updated Thermal Rating: on line 5026-1213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1097
% INFO    : Updated Thermal Rating: on line 5717-1213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 3710-1216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 665
% INFO    : Updated Thermal Rating: on line 4360-1216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 2662-1217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 2889-1217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 1990-1220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 1810-1221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 2752-1221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10890
% INFO    : Updated Thermal Rating: on line 1350-1222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3859-1222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 3428-1223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5082-1224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 5268-1225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 1246-1227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 5412-1228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 1383-1230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on line 3054-1231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 4439-1231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 3496-1232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10482
% INFO    : Updated Thermal Rating: on line 4438-1232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 1342-1233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 1653-1233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 2430-1233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 2496-1233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 4350-1234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 4452-1234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 1777-1236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 736
% INFO    : Updated Thermal Rating: on line 3046-1236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 1777-1236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 736
% INFO    : Updated Thermal Rating: on line 3606-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2368
% INFO    : Updated Thermal Rating: on line 4282-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on line 5241-1237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 5747-1237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1480
% INFO    : Updated Thermal Rating: on line 5650-1237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1450
% INFO    : Updated Thermal Rating: on line 3606-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on line 5698-1241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19617
% INFO    : Updated Thermal Rating: on line 4084-1239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 5551-1243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 1960-1244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 3312-1244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 555
% INFO    : Updated Thermal Rating: on line 1616-1245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 1855-1245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4966
% INFO    : Updated Thermal Rating: on line 1617-1245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 1854-1245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6273
% INFO    : Updated Thermal Rating: on line 2874-1246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 3824-1246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 5177-1246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 4291-1248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 4330-1248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 4291-1248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 2263-1249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 4565-1252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10014
% INFO    : Updated Thermal Rating: on line 4623-1252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10356
% INFO    : Updated Thermal Rating: on line 5115-1253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 5630-1253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 5278-1254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 1657-1257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1583
% INFO    : Updated Thermal Rating: on line 4208-1259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 5494-1259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1309
% INFO    : Updated Thermal Rating: on line 2338-1260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 5280-1261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32501
% INFO    : Updated Thermal Rating: on line 2256-1263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 4715-1263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 4734-1262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 5548-1262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5777-1263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 4715-1262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 4734-1263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 3812-1265 : Rate A, Rate B, Rate C , 1711.0, 1711.0, 1711.0 -> 1648
% INFO    : Updated Thermal Rating: on line 4903-1265 : Rate A, Rate B, Rate C , 1307.0, 1307.0, 1307.0 -> 1080
% INFO    : Updated Thermal Rating: on line 4093-1266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 1510-1267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 2662-1267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5279-1270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on line 2262-1271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 4218-1272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5220-1272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 5282-1273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1337
% INFO    : Updated Thermal Rating: on line 1547-1276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 3201-1276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 1774-1278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 5283-1279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 3632-1280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 3980-1280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 4792-1283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21546
% INFO    : Updated Thermal Rating: on line 2271-1284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on line 2714-1284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 3922-1285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27378
% INFO    : Updated Thermal Rating: on line 3921-1285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27596
% INFO    : Updated Thermal Rating: on line 1838-1286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23964
% INFO    : Updated Thermal Rating: on line 2048-1287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 3764-1287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 1633-1288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 5178-1288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4968
% INFO    : Updated Thermal Rating: on line 5791-1288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4252
% INFO    : Updated Thermal Rating: on line 5143-1289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1046
% INFO    : Updated Thermal Rating: on line 5813-1290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 2011-1291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5205
% INFO    : Updated Thermal Rating: on line 5216-1293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8292
% INFO    : Updated Thermal Rating: on line 5217-1293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 2306-1294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 3945-1294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 3945-1294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 3449-1300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 2032-1301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 4641-1301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 5844-1302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 1304-1303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 4900-1303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 2118-1306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1618
% INFO    : Updated Thermal Rating: on line 2643-1308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1236
% INFO    : Updated Thermal Rating: on line 5825-1309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 5147-1310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 941
% INFO    : Updated Thermal Rating: on line 5388-1310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 1349-1311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23302
% INFO    : Updated Thermal Rating: on line 1615-1311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 3911-1311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 3347-1312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1835
% INFO    : Updated Thermal Rating: on line 3710-1312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 4841-1312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 5289-1313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38166
% INFO    : Updated Thermal Rating: on line 2928-1314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 3937-1314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 5288-1315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2153
% INFO    : Updated Thermal Rating: on line 2621-1316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 5288-1316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5290-1316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on line 1317-1318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5399
% INFO    : Updated Thermal Rating: on line 1986-1318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 2607-1319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 5630-1319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 2607-1319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 2942-1320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 2136-1322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3887
% INFO    : Updated Thermal Rating: on line 2136-1321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5064
% INFO    : Updated Thermal Rating: on line 3431-1323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 1383-1324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 4410-1324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 5588-1324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 3679-1326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 5651-1326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5504
% INFO    : Updated Thermal Rating: on line 4046-1327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4533
% INFO    : Updated Thermal Rating: on line 3258-1328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 3527-1328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 2100-1329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 5242-1329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1345
% INFO    : Updated Thermal Rating: on line 4429-1330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11223
% INFO    : Updated Thermal Rating: on line 1667-1331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 4273-1331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 5745-1331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 1542-1333 : Rate A, Rate B, Rate C , 2280.0, 2280.0, 2280.0 -> 932
% INFO    : Updated Thermal Rating: on line 3433-1333 : Rate A, Rate B, Rate C , 1559.0, 1559.0, 1559.0 -> 944
% INFO    : Updated Thermal Rating: on line 1542-1333 : Rate A, Rate B, Rate C , 2280.0, 2280.0, 2280.0 -> 932
% INFO    : Updated Thermal Rating: on line 5102-1334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2802
% INFO    : Updated Thermal Rating: on line 5355-1335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 5833-1335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1139
% INFO    : Updated Thermal Rating: on line 2135-1336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 5005-1336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 4112-1337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 5172-1337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2759
% INFO    : Updated Thermal Rating: on line 1845-1342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 1846-1342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 1756-1344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1575
% INFO    : Updated Thermal Rating: on line 5281-1344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 4198-1345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19787
% INFO    : Updated Thermal Rating: on line 3010-1346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on line 2362-1352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21515
% INFO    : Updated Thermal Rating: on line 2362-1351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21515
% INFO    : Updated Thermal Rating: on line 1598-1353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 3879-1354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 1362-1355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 2359-1355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 1388-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 1950-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 874
% INFO    : Updated Thermal Rating: on line 2625-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2427
% INFO    : Updated Thermal Rating: on line 2693-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 2694-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 2699-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 1387-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 5135-1358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 4112-1360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1022
% INFO    : Updated Thermal Rating: on line 4473-1361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 5359-1362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 3834-1364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22551
% INFO    : Updated Thermal Rating: on line 3834-1363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23186
% INFO    : Updated Thermal Rating: on line 2459-1365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17936
% INFO    : Updated Thermal Rating: on line 5770-1366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 1708-1369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1181
% INFO    : Updated Thermal Rating: on line 1714-1368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 1715-1367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1754
% INFO    : Updated Thermal Rating: on line 1798-1370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26532
% INFO    : Updated Thermal Rating: on line 1381-1371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on line 3257-1371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7254
% INFO    : Updated Thermal Rating: on line 5293-1371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4688
% INFO    : Updated Thermal Rating: on line 5295-1371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5294-1371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 5310-1373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 499
% INFO    : Updated Thermal Rating: on line 2078-1372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 4005-1374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7767
% INFO    : Updated Thermal Rating: on line 1775-1376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 2541-1377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 5296-1378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27851
% INFO    : Updated Thermal Rating: on line 2346-1380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 3707-1380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8177
% INFO    : Updated Thermal Rating: on line 3917-1380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 5237-1380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 4450-1383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2154
% INFO    : Updated Thermal Rating: on line 5276-1383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2005
% INFO    : Updated Thermal Rating: on line 1665-1384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 2051-1384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 3275-1384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 4003-1384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 5520-1384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 5760-1384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 2539-1384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 4002-1384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 4945-1384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 5519-1384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 404
% INFO    : Updated Thermal Rating: on line 3412-1388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6474
% INFO    : Updated Thermal Rating: on line 2611-1387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 2754-1389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 2662-1391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on line 3050-1391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 3394-1392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5529-1392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on line 2147-1393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 3866-1393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 752
% INFO    : Updated Thermal Rating: on line 5139-1393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 5297-1393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 3193-1394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21515
% INFO    : Updated Thermal Rating: on line 4974-1395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 4973-1395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 5298-1397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1462
% INFO    : Updated Thermal Rating: on line 5255-1398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 2568-1398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 5299-1399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28417
% INFO    : Updated Thermal Rating: on line 2343-1400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 4330-1401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 5594-1401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 5300-1404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1093
% INFO    : Updated Thermal Rating: on line 1952-1405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 3702-1405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3865-1405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 3865-1405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 1300-1408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 1813-1408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2199
% INFO    : Updated Thermal Rating: on line 4338-1408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 2871-1410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5697
% INFO    : Updated Thermal Rating: on line 3173-1410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 5571-1411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7412
% INFO    : Updated Thermal Rating: on line 5803-1412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26199
% INFO    : Updated Thermal Rating: on line 5301-1413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16094
% INFO    : Updated Thermal Rating: on line 2237-1414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 4149-1414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 5797-1414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 4681-1415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 5768-1415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 2485-1416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 2873-1416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 4627-1416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 1822-1417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1097
% INFO    : Updated Thermal Rating: on line 1822-1417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 2610-1419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 3235-1418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 2611-1419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 3234-1419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 3675-1420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3794
% INFO    : Updated Thermal Rating: on line 3675-1420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3140
% INFO    : Updated Thermal Rating: on line 3879-1422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 663
% INFO    : Updated Thermal Rating: on line 3879-1421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 3608-1423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 2008-1424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38069
% INFO    : Updated Thermal Rating: on line 3888-1425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 5304-1425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29272
% INFO    : Updated Thermal Rating: on line 5305-1425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29272
% INFO    : Updated Thermal Rating: on line 5307-1426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12455
% INFO    : Updated Thermal Rating: on line 978-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 5026-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 5094-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 5361-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 4004-1428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 5319-1428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 4051-1429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 4520-1429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 1433-1430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309464
% INFO    : Updated Thermal Rating: on line 1064-1432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 4536-1432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11961
% INFO    : Updated Thermal Rating: on line 5032-1432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 1064-1432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 926-1434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 621
% INFO    : Updated Thermal Rating: on line 1245-1434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 632
% INFO    : Updated Thermal Rating: on line 1616-1434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 1773-1434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2467
% INFO    : Updated Thermal Rating: on line 2540-1434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1224
% INFO    : Updated Thermal Rating: on line 1780-1435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 5309-1436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16094
% INFO    : Updated Thermal Rating: on line 1684-1437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 4227-1438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1496
% INFO    : Updated Thermal Rating: on line 2495-1439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1537
% INFO    : Updated Thermal Rating: on line 2736-1439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 4207-1439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2632
% INFO    : Updated Thermal Rating: on line 4697-1439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 5283-1439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 2495-1439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2073
% INFO    : Updated Thermal Rating: on line 2736-1439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 2495-1439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1356
% INFO    : Updated Thermal Rating: on line 2961-1441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 5798-1441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 1267-1443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 1323-1443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2023
% INFO    : Updated Thermal Rating: on line 3050-1442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 3071-1443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 4582-1443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 4767-1442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 5672-1443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 5793-1442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 1447-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2231
% INFO    : Updated Thermal Rating: on line 1447-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2924
% INFO    : Updated Thermal Rating: on line 5310-1446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23584
% INFO    : Updated Thermal Rating: on line 3985-1448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8415
% INFO    : Updated Thermal Rating: on line 972-1450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 4802-1452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 4802-1451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 2686-1453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1280
% INFO    : Updated Thermal Rating: on line 5283-1453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1407
% INFO    : Updated Thermal Rating: on line 3461-1454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 3201-1456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4708
% INFO    : Updated Thermal Rating: on line 4331-1459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 3265-1460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 367
% INFO    : Updated Thermal Rating: on line 4643-1460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 4659-1460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 5014-1460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 5113-1460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3691
% INFO    : Updated Thermal Rating: on line 4642-1460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on line 5246-1460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on line 5086-1462 : Rate A, Rate B, Rate C , 1828.0, 1828.0, 1828.0 -> 1297
% INFO    : Updated Thermal Rating: on line 1622-1463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 2748-1463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 3528-1463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on line 5332-1463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 3269-1463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 4882-1464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 2535-1466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 5019-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 5748-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 3560-1468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 3560-1468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 1709-1469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 954
% INFO    : Updated Thermal Rating: on line 3562-1470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2064
% INFO    : Updated Thermal Rating: on line 1709-1469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 3036-1471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 4359-1471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5041-1471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 3036-1471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 5278-1474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 4940-1475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 3632-1476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28743
% INFO    : Updated Thermal Rating: on line 1889-1477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14533
% INFO    : Updated Thermal Rating: on line 2007-1477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20949
% INFO    : Updated Thermal Rating: on line 2702-1477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 2944-1477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21757
% INFO    : Updated Thermal Rating: on line 2943-1477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21757
% INFO    : Updated Thermal Rating: on line 5532-1477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on line 2518-1479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 2518-1479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 2554-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 4178-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 4279-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1572
% INFO    : Updated Thermal Rating: on line 4445-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 5111-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 5272-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 5693-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 5267-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 3550-1482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2721
% INFO    : Updated Thermal Rating: on line 4578-1482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1651
% INFO    : Updated Thermal Rating: on line 3366-1482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 4738-1483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3272
% INFO    : Updated Thermal Rating: on line 4738-1483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3532
% INFO    : Updated Thermal Rating: on line 2133-1484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1044
% INFO    : Updated Thermal Rating: on line 4248-1487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 5314-1487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85273
% INFO    : Updated Thermal Rating: on line 2806-1488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4650
% INFO    : Updated Thermal Rating: on line 1673-1489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 5724-1489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 1717-1490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 3017-1493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3697
% INFO    : Updated Thermal Rating: on line 4963-1493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 2607-1498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 2626-1500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 4001-1500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 2279-1501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 3410-1501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 4062-1501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 4716-1501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 5066-1501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4062-1501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 5315-1504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 4827-1505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 3371-1506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 5675-1506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on line 3077-1507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 3042-1508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 3251-1508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 2422-1509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 5096-1509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 4212-1511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 4212-1511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 2111-1512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 3646-1512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 3737-1513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 3894-1513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 4537-1513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3429-1514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 3737-1514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1500
% INFO    : Updated Thermal Rating: on line 3737-1514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1459
% INFO    : Updated Thermal Rating: on line 2360-1516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 2604-1516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4045-1516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1004
% INFO    : Updated Thermal Rating: on line 5528-1516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 5713-1516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 4045-1516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on line 3416-1518 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1517
% INFO    : Updated Thermal Rating: on line 4791-1519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 4792-1519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 1634-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 2415-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3435-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 4127-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106
% INFO    : Updated Thermal Rating: on line 5186-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 2415-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 2326-1528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 4915-1528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 4914-1528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 4429-1529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 5316-1530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 1837-1531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 1780-1532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 2575-1532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 1549-1533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 1566-1533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 4868-1534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 4933-1533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 5722-1533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 971
% INFO    : Updated Thermal Rating: on line 4115-1533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 5447-1535 : Rate A, Rate B, Rate C , 541.0, 541.0, 541.0 -> 443
% INFO    : Updated Thermal Rating: on line 2472-1536 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2406
% INFO    : Updated Thermal Rating: on line 2948-1536 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1759
% INFO    : Updated Thermal Rating: on line 3626-1536 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1245
% INFO    : Updated Thermal Rating: on line 3706-1536 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1191
% INFO    : Updated Thermal Rating: on line 2472-1536 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2405
% INFO    : Updated Thermal Rating: on line 1850-1537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 5017-1537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 5367-1537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5854-1537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 2931-1538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5843-1538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1981
% INFO    : Updated Thermal Rating: on line 2103-1539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 3081-1539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 3546-1539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 5185-1539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on line 5367-1540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 4859-1542 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1934
% INFO    : Updated Thermal Rating: on line 1932-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1292
% INFO    : Updated Thermal Rating: on line 3608-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 3978-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 5633-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on line 3608-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 3528-1547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 2152-1548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2751
% INFO    : Updated Thermal Rating: on line 2635-1548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 2152-1548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2764
% INFO    : Updated Thermal Rating: on line 2635-1548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 951
% INFO    : Updated Thermal Rating: on line 4183-1550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5740-1550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 4183-1550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5319-1551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 1836-1553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 3244-1555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 4267-1555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 703
% INFO    : Updated Thermal Rating: on line 2746-1556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 3311-1557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 4675-1561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1294
% INFO    : Updated Thermal Rating: on line 1848-1563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109898
% INFO    : Updated Thermal Rating: on line 5500-1563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 1818-1563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6227
% INFO    : Updated Thermal Rating: on line 1849-1563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109898
% INFO    : Updated Thermal Rating: on line 1833-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1984
% INFO    : Updated Thermal Rating: on line 3244-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 3377-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 3244-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 3244-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 2013-1567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 4377-1570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 4856-1570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 5198-1570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 5269-1571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 4434-1573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 4688-1573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 5322-1574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 3074-1576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 4337-1576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 4453-1576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3736
% INFO    : Updated Thermal Rating: on line 5324-1576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on line 3951-1577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 5146-1577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 5697-1577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 2986-1577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 1516-1582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 3335-1584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 5325-1584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4368
% INFO    : Updated Thermal Rating: on line 4233-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 4997-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 3277-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3108
% INFO    : Updated Thermal Rating: on line 3289-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3384
% INFO    : Updated Thermal Rating: on line 4001-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 5055-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3055
% INFO    : Updated Thermal Rating: on line 5592-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2792
% INFO    : Updated Thermal Rating: on line 3277-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3393
% INFO    : Updated Thermal Rating: on line 3599-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5554
% INFO    : Updated Thermal Rating: on line 5055-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2366
% INFO    : Updated Thermal Rating: on line 2622-1590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5704-1591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21515
% INFO    : Updated Thermal Rating: on line 5326-1592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31460
% INFO    : Updated Thermal Rating: on line 4538-1594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 5328-1594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 4754-1595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5344-1595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 1612-1596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 3931-1596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 2357-1599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 4980-1598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 5403-1599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 4372-1599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 4979-1598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 2771-1600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 2946-1600 : Rate A, Rate B, Rate C , 325.0, 325.0, 325.0 -> 273
% INFO    : Updated Thermal Rating: on line 2772-1601 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1482
% INFO    : Updated Thermal Rating: on line 3433-1601 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1546
% INFO    : Updated Thermal Rating: on line 3939-1601 : Rate A, Rate B, Rate C , 1263.0, 1263.0, 1263.0 -> 622
% INFO    : Updated Thermal Rating: on line 4774-1601 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2287
% INFO    : Updated Thermal Rating: on line 4860-1601 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 996
% INFO    : Updated Thermal Rating: on line 4774-1601 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2289
% INFO    : Updated Thermal Rating: on line 2616-1602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 3063-1602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3426-1602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 4874-1602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1830
% INFO    : Updated Thermal Rating: on line 2616-1602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 3062-1602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5329-1605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31538
% INFO    : Updated Thermal Rating: on line 3049-1607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 4523-1607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 4348-1609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 4348-1609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 2630-1610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 4458-1610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5153-1610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 2095-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 2307-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 3321-1612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 3321-1612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 4675-1613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 2120-1614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 3513-1617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 4017-1616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 5567-1616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5771-1616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 3371-1619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 5675-1619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1866
% INFO    : Updated Thermal Rating: on line 1946-1620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 2693-1621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on line 5498-1621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 5101-1623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 5743-1623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 3962-1624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 5439-1625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5438-1625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5644-1626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 2262-1627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 3632-1631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 2009-1632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85214
% INFO    : Updated Thermal Rating: on line 5398-1633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 715
% INFO    : Updated Thermal Rating: on line 3429-1634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 2208-1635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2839
% INFO    : Updated Thermal Rating: on line 5418-1635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6565
% INFO    : Updated Thermal Rating: on line 1856-1636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 5116-1636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 2047-1637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 2533-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 3029-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 3583-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on line 4129-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on line 4517-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 759
% INFO    : Updated Thermal Rating: on line 2533-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1614
% INFO    : Updated Thermal Rating: on line 4129-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on line 4517-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 4138-1640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 4363-1640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 1807-1641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 4755-1641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 453
% INFO    : Updated Thermal Rating: on line 3134-1642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 848
% INFO    : Updated Thermal Rating: on line 5334-1643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85273
% INFO    : Updated Thermal Rating: on line 2547-1644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 2973-1644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 4755-1644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 1725-1646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 3409-1646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4458-1646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 1942-1647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 1942-1647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 5336-1648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3291
% INFO    : Updated Thermal Rating: on line 2864-1650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 858
% INFO    : Updated Thermal Rating: on line 5337-1649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23993
% INFO    : Updated Thermal Rating: on line 1878-1651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7204
% INFO    : Updated Thermal Rating: on line 5462-1653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 5338-1657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 5339-1658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 520
% INFO    : Updated Thermal Rating: on line 2647-1659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1607
% INFO    : Updated Thermal Rating: on line 2803-1660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 2127-1662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 3610-1662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 1791-1663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1733
% INFO    : Updated Thermal Rating: on line 1791-1663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1808
% INFO    : Updated Thermal Rating: on line 2428-1664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on line 4856-1664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 5057-1664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3275-1665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5341-1666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12351
% INFO    : Updated Thermal Rating: on line 5025-1667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 1944-1668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41198
% INFO    : Updated Thermal Rating: on line 2006-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 3027-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28461
% INFO    : Updated Thermal Rating: on line 3719-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 3740-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 4234-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 5049-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 5763-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 707
% INFO    : Updated Thermal Rating: on line 3026-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10795
% INFO    : Updated Thermal Rating: on line 2041-1671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 4729-1671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5342-1672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5595
% INFO    : Updated Thermal Rating: on line 3405-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1343
% INFO    : Updated Thermal Rating: on line 4088-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1061
% INFO    : Updated Thermal Rating: on line 5008-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 3405-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1351
% INFO    : Updated Thermal Rating: on line 1868-1675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 3152-1675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 3554-1677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 4636-1678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5307-1678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 5502-1678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 5748-1678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 1680-1679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on line 4519-1679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 2485-1680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 2516-1681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 4624-1681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 3942-1682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3862
% INFO    : Updated Thermal Rating: on line 5533-1682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 5661-1682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 3049-1684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on line 3658-1686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 4518-1686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 5334-1688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 5607-1689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 5605-1689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 583
% INFO    : Updated Thermal Rating: on line 5346-1691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 3715-1692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240340
% INFO    : Updated Thermal Rating: on line 5348-1693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28260
% INFO    : Updated Thermal Rating: on line 2459-1694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on line 2459-1694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 2459-1694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on line 4221-1696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318139
% INFO    : Updated Thermal Rating: on line 4221-1695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318139
% INFO    : Updated Thermal Rating: on line 4218-1697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303410
% INFO    : Updated Thermal Rating: on line 4220-1699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308858
% INFO    : Updated Thermal Rating: on line 4220-1698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308909
% INFO    : Updated Thermal Rating: on line 5336-1700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 4528-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1287
% INFO    : Updated Thermal Rating: on line 5735-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2676
% INFO    : Updated Thermal Rating: on line 5733-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2708
% INFO    : Updated Thermal Rating: on line 4354-1703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 2791-1704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on line 2791-1705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 967
% INFO    : Updated Thermal Rating: on line 5302-1705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5303-1705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 5349-1705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7068
% INFO    : Updated Thermal Rating: on line 5460-1705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 1715-1709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3772
% INFO    : Updated Thermal Rating: on line 2733-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4361
% INFO    : Updated Thermal Rating: on line 3216-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1479
% INFO    : Updated Thermal Rating: on line 4074-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13439
% INFO    : Updated Thermal Rating: on line 1714-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3772
% INFO    : Updated Thermal Rating: on line 3216-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1542
% INFO    : Updated Thermal Rating: on line 3934-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 3216-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on line 3216-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 1716-1711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1716-1713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1716-1710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1716-1712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 2235-1717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 2252-1717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 739
% INFO    : Updated Thermal Rating: on line 3130-1717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11069
% INFO    : Updated Thermal Rating: on line 4615-1717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 5727-1717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 2252-1717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on line 5351-1720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25032
% INFO    : Updated Thermal Rating: on line 5350-1719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25032
% INFO    : Updated Thermal Rating: on line 2237-1721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9016
% INFO    : Updated Thermal Rating: on line 3868-1722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 4631-1722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 4730-1722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 5107-1722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 5104-1722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 3111-1724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 5353-1729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26199
% INFO    : Updated Thermal Rating: on line 3979-1731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 5326-1731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 2806-1732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4341
% INFO    : Updated Thermal Rating: on line 5355-1733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5788
% INFO    : Updated Thermal Rating: on line 5356-1734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 1993-1735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 4016-1735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 4085-1735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 4169-1735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1520
% INFO    : Updated Thermal Rating: on line 5569-1735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 4085-1735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 3900-1738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 3915-1738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 5359-1738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 1800-1739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on line 5526-1739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 1751-1745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1750-1745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1749-1745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2332-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 5827-1753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2646
% INFO    : Updated Thermal Rating: on line 2331-1753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 2863-1753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7488
% INFO    : Updated Thermal Rating: on line 5532-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 2935-1755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 3095-1755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 3099-1755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 5581-1755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 1757-4134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 5357-1758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7900
% INFO    : Updated Thermal Rating: on line 2011-1759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 2518-1760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2689-1761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 2312-1762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3869
% INFO    : Updated Thermal Rating: on line 2146-1763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 2334-1763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 3269-1764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 2677-1766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 4100-1766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 5844-1766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 1783-1766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 2677-1766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 4516-1771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 2707-1773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 2321-1776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 3309-1777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 3571-1777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 872
% INFO    : Updated Thermal Rating: on line 3715-1777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 3867-1776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 3910-1776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 5118-1776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 3715-1777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 3032-1778 : Rate A, Rate B, Rate C , 509.0, 509.0, 509.0 -> 421
% INFO    : Updated Thermal Rating: on line 3065-1778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 566
% INFO    : Updated Thermal Rating: on line 4925-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 5191-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 2575-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 2984-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 4930-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5308-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 602
% INFO    : Updated Thermal Rating: on line 2313-1782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 2500-1782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 4948-1783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 4157-1784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 3462-1785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 4931-1785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 5187-1785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 5839-1785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1337
% INFO    : Updated Thermal Rating: on line 5329-1787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4649-1788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 5383-1788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 4308-1789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4649-1789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 3276-1790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 4587-1790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320
% INFO    : Updated Thermal Rating: on line 4972-1790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 796
% INFO    : Updated Thermal Rating: on line 3974-1791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4297-1791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 3007-1792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 3409-1794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 4893-1794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 3566-1797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37106
% INFO    : Updated Thermal Rating: on line 5451-1799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2889
% INFO    : Updated Thermal Rating: on line 1799-1800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2981
% INFO    : Updated Thermal Rating: on line 2395-1802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 4409-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 4468-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 4896-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 2759-1806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1879
% INFO    : Updated Thermal Rating: on line 2759-1805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1879
% INFO    : Updated Thermal Rating: on line 3376-1807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 1936-1808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8785
% INFO    : Updated Thermal Rating: on line 3189-1808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on line 3933-1808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 5419-1808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 5582-1808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2129
% INFO    : Updated Thermal Rating: on line 5826-1808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 2165-1809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3579
% INFO    : Updated Thermal Rating: on line 2165-1809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3514
% INFO    : Updated Thermal Rating: on line 2752-1810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on line 3361-1810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 5282-1810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 3361-1810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 4538-1810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5360-1812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16165
% INFO    : Updated Thermal Rating: on line 3441-1814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 5458-1815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 5644-1815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 4816-1817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 5371-1817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 1821-1819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2468
% INFO    : Updated Thermal Rating: on line 1821-1819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2403
% INFO    : Updated Thermal Rating: on line 5361-1820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 2483-1822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 2567-1822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 4008-1822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 3671-1825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 3671-1825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 3016-1826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1306
% INFO    : Updated Thermal Rating: on line 3543-1826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 1962-1828 : Rate A, Rate B, Rate C , 1253.0, 1253.0, 1253.0 -> 1246
% INFO    : Updated Thermal Rating: on line 4073-1829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 3086-1830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 3555-1831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1170
% INFO    : Updated Thermal Rating: on line 4413-1831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 5769-1831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 3555-1831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 4732-1834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 907
% INFO    : Updated Thermal Rating: on line 5809-1835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 952
% INFO    : Updated Thermal Rating: on line 5425-1836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 2021-1837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 2421-1837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 2855-1837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 3637-1837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3938
% INFO    : Updated Thermal Rating: on line 4864-1837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 5317-1837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 2479-1837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 2135-1841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 2606-1841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 2022-1842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 2328-1842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 4883-1842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 1943-1847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 984
% INFO    : Updated Thermal Rating: on line 2883-1851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 4277-1852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 2304-1853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 2504-1853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 2260-1856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 2428-1856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 4331-1856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 2779-1857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 724
% INFO    : Updated Thermal Rating: on line 4009-1857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 4742-1858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 3071-1859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on line 3077-1859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 3036-1860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2313
% INFO    : Updated Thermal Rating: on line 3335-1861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 4026-1861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 4289-1861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 3655-1862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2495
% INFO    : Updated Thermal Rating: on line 4014-1866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1459
% INFO    : Updated Thermal Rating: on line 4508-1867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 546
% INFO    : Updated Thermal Rating: on line 4132-1868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 1730-1869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 2303-1869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 3196-1869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 5139-1871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 5276-1872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2530
% INFO    : Updated Thermal Rating: on line 5588-1872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 921
% INFO    : Updated Thermal Rating: on line 1947-1873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 2563-1873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 1821-1874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 2685-1875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1486
% INFO    : Updated Thermal Rating: on line 5369-1876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 3656-1879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 5370-1880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23584
% INFO    : Updated Thermal Rating: on line 3670-1881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 3856-1881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 4747-1881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on line 5402-1881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4005-1882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 4005-1882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 3747-1883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206750
% INFO    : Updated Thermal Rating: on line 3061-1885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 3061-1886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 4228-1887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 5373-1891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1902-1900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1902-1899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1902-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1902-1897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3876-1901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5060-1901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 3971-1903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 577
% INFO    : Updated Thermal Rating: on line 4217-1903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 4260-1903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 4866-1903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 5275-1903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 5475-1903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 3985-1903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 5676-1903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 3985-1903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 4456-1906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 4927-1906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 4267-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1592
% INFO    : Updated Thermal Rating: on line 5091-1908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 4782-1909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 5077-1910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 561
% INFO    : Updated Thermal Rating: on line 2085-1911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 5652-1911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on line 2085-1911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 4291-1912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5138-1912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 5319-1912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 5301-1915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4122
% INFO    : Updated Thermal Rating: on line 5309-1914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84779
% INFO    : Updated Thermal Rating: on line 5726-1916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1393
% INFO    : Updated Thermal Rating: on line 5179-1918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on line 3321-1919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 5301-1919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4688
% INFO    : Updated Thermal Rating: on line 3321-1919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1895
% INFO    : Updated Thermal Rating: on line 5376-1920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3052
% INFO    : Updated Thermal Rating: on line 5126-1921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13714
% INFO    : Updated Thermal Rating: on line 5016-1922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7487
% INFO    : Updated Thermal Rating: on line 3930-1923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 2098-1924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21948
% INFO    : Updated Thermal Rating: on line 3835-1924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5407
% INFO    : Updated Thermal Rating: on line 5433-1925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on line 2325-1926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59375
% INFO    : Updated Thermal Rating: on line 2194-1927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 2355-1927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 2409-1927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 4246-1927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16129
% INFO    : Updated Thermal Rating: on line 4246-1927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16129
% INFO    : Updated Thermal Rating: on line 3423-1929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 3423-1929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 1937-1930 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1998
% INFO    : Updated Thermal Rating: on line 1937-1930 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1997
% INFO    : Updated Thermal Rating: on line 3877-1931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 4120-1931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 4120-1931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 5340-1932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 3939-1935 : Rate A, Rate B, Rate C , 1695.0, 1695.0, 1695.0 -> 787
% INFO    : Updated Thermal Rating: on line 4548-1935 : Rate A, Rate B, Rate C , 2362.0, 2362.0, 2362.0 -> 1552
% INFO    : Updated Thermal Rating: on line 4859-1935 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1543
% INFO    : Updated Thermal Rating: on line 4548-1935 : Rate A, Rate B, Rate C , 2362.0, 2362.0, 2362.0 -> 1597
% INFO    : Updated Thermal Rating: on line 4294-1937 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2461
% INFO    : Updated Thermal Rating: on line 2661-1940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 4102-1941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4433
% INFO    : Updated Thermal Rating: on line 2209-1942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 2930-1942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 3133-1943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 4067-1943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1008
% INFO    : Updated Thermal Rating: on line 5368-1943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 2209-1942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 4067-1942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 3503-1948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on line 2047-1949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2981
% INFO    : Updated Thermal Rating: on line 2699-1950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2745
% INFO    : Updated Thermal Rating: on line 2891-1951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 2914-1951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 5380-1953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83671
% INFO    : Updated Thermal Rating: on line 3311-1954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 5285-1955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2664
% INFO    : Updated Thermal Rating: on line 5725-1956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 2686-1957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 404
% INFO    : Updated Thermal Rating: on line 3272-1958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 3311-1958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 3452-1959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5284
% INFO    : Updated Thermal Rating: on line 4431-1959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on line 4903-1962 : Rate A, Rate B, Rate C , 1750.0, 1750.0, 1750.0 -> 873
% INFO    : Updated Thermal Rating: on line 4903-1962 : Rate A, Rate B, Rate C , 2197.0, 2197.0, 2197.0 -> 873
% INFO    : Updated Thermal Rating: on line 4903-1962 : Rate A, Rate B, Rate C , 1192.0, 1192.0, 1192.0 -> 806
% INFO    : Updated Thermal Rating: on line 3015-1964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 3610-1965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 3518-1966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 1979-1977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1979-1976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1979-1975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1979-1974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1979-1973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1979-1972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3815-1978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4486-1978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3294-1981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4114-1982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 4322-1984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 4755-1984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 4344-1985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 2247-1986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 734
% INFO    : Updated Thermal Rating: on line 3227-1987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 4259-1988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 3933-1989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on line 5190-1990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 772
% INFO    : Updated Thermal Rating: on line 5370-1990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 5385-1992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21757
% INFO    : Updated Thermal Rating: on line 3200-1993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 5734-1994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 2304-1995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 2313-1995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 3203-1995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4192-1996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 674
% INFO    : Updated Thermal Rating: on line 4516-1996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 4748-1996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 4192-1996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 765
% INFO    : Updated Thermal Rating: on line 4516-1996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on line 4516-1996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 643
% INFO    : Updated Thermal Rating: on line 5387-1998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 4940-1999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 4075-2001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 4872-2001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 4075-2002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 4873-2002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5366-2003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13395
% INFO    : Updated Thermal Rating: on line 2681-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2747
% INFO    : Updated Thermal Rating: on line 5517-2005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 3719-2006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 4645-2009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89765
% INFO    : Updated Thermal Rating: on line 4163-2010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 5179-2010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on line 2818-2011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 5051-2011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on line 5214-2011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 4456-2012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 3410-2013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 4312-2014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7529
% INFO    : Updated Thermal Rating: on line 5846-2018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on line 5847-2019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on line 5466-2020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5010
% INFO    : Updated Thermal Rating: on line 3186-2022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 4940-2022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 2711-2025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 4295-2025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 605
% INFO    : Updated Thermal Rating: on line 2550-2026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 4742-2026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 5654-2027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 5396-2028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4107
% INFO    : Updated Thermal Rating: on line 5395-2029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4651
% INFO    : Updated Thermal Rating: on line 5398-2030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1021
% INFO    : Updated Thermal Rating: on line 2092-2031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 2690-2031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1651
% INFO    : Updated Thermal Rating: on line 3382-2031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 2945-2033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 4754-2033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 4880-2034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3711
% INFO    : Updated Thermal Rating: on line 5563-2035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5564-2035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 4127-2036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 5186-2036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 5314-2037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 5568-2037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 5569-2037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 2435-2038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 2060-2039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 2825-2039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3750-2039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 5221-2039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 5223-2039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 5218-2039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 4729-2041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 3870-2042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on line 2449-2045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 2668-2045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 992
% INFO    : Updated Thermal Rating: on line 2222-2048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 2234-2048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 2273-2048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 2842-2048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 870
% INFO    : Updated Thermal Rating: on line 2223-2049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6148
% INFO    : Updated Thermal Rating: on line 5402-2050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3779
% INFO    : Updated Thermal Rating: on line 2986-2052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on line 2986-2052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 4811-2054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 5305-2054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 3517-2056 : Rate A, Rate B, Rate C , 2368.0, 2368.0, 2368.0 -> 2335
% INFO    : Updated Thermal Rating: on line 4774-2056 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1679
% INFO    : Updated Thermal Rating: on line 3516-2056 : Rate A, Rate B, Rate C , 2368.0, 2368.0, 2368.0 -> 2335
% INFO    : Updated Thermal Rating: on line 4774-2056 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1679
% INFO    : Updated Thermal Rating: on line 3621-2059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4237
% INFO    : Updated Thermal Rating: on line 3621-2058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4237
% INFO    : Updated Thermal Rating: on line 3621-2057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4237
% INFO    : Updated Thermal Rating: on line 5399-2067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6789
% INFO    : Updated Thermal Rating: on line 2126-2069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 2736-2069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on line 4697-2069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 4095-2070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 935
% INFO    : Updated Thermal Rating: on line 3841-2072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 3859-2072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 5581-2072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 2806-2075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5731
% INFO    : Updated Thermal Rating: on line 3974-2076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 4403-2076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 4967-2079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on line 5720-2079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 4967-2078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 2278-2082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1391
% INFO    : Updated Thermal Rating: on line 3258-2082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 4961-2083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 5405-2084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15304
% INFO    : Updated Thermal Rating: on line 3049-2085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 3613-2085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 4052-2085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 4523-2085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 4466-2088 : Rate A, Rate B, Rate C , 1662.0, 1662.0, 1662.0 -> 1168
% INFO    : Updated Thermal Rating: on line 4903-2088 : Rate A, Rate B, Rate C , 1659.0, 1659.0, 1659.0 -> 1605
% INFO    : Updated Thermal Rating: on line 3621-2089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1375
% INFO    : Updated Thermal Rating: on line 3621-2089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1397
% INFO    : Updated Thermal Rating: on line 2734-2090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 2618-2091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2202-2092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 2093-1494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 3139-2095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 2451-2097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 5465-2097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 2488-2100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1378
% INFO    : Updated Thermal Rating: on line 4305-2100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2151
% INFO    : Updated Thermal Rating: on line 4305-2100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2151
% INFO    : Updated Thermal Rating: on line 4382-2101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 4382-2101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 3113-2102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1715
% INFO    : Updated Thermal Rating: on line 2203-2103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 3081-2103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 4698-2103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on line 5185-2103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on line 3081-2103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 4392-2103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 5764-2103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 404
% INFO    : Updated Thermal Rating: on line 2877-2105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 5623-2105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1095
% INFO    : Updated Thermal Rating: on line 2111-2108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1937
% INFO    : Updated Thermal Rating: on line 2111-2107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3363
% INFO    : Updated Thermal Rating: on line 2111-2110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18630
% INFO    : Updated Thermal Rating: on line 2111-2109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18082
% INFO    : Updated Thermal Rating: on line 2620-2111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 3646-2111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 4165-2111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 5112-2111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 5204-2111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 3901-2113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 5406-2113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 3003-2114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 3666-2115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 3700-2115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 5407-2116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 888
% INFO    : Updated Thermal Rating: on line 3269-2117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 3015-2118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 2996-2119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13742
% INFO    : Updated Thermal Rating: on line 2465-2121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 3175-2121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 3177-2122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 3448-2122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 4185-2122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 3410-2123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 3526-2123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 2768-2124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 3352-2124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 3794-2124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 4060-2124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 5388-2124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 3794-2124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 5386-2124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 5381-2126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 2680-2127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 3610-2128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 3955-2127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 4015-2128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 4670-2132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 848
% INFO    : Updated Thermal Rating: on line 4194-2135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5962
% INFO    : Updated Thermal Rating: on line 4195-2135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7065
% INFO    : Updated Thermal Rating: on line 2499-2136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on line 3225-2136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1217
% INFO    : Updated Thermal Rating: on line 5252-2137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1004
% INFO    : Updated Thermal Rating: on line 5355-2137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 5522-2137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 2431-2141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3993
% INFO    : Updated Thermal Rating: on line 2431-2141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3993
% INFO    : Updated Thermal Rating: on line 1910-2142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 2760-2142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41324
% INFO    : Updated Thermal Rating: on line 3195-2146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 3545-2147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 4353-2147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2805
% INFO    : Updated Thermal Rating: on line 5297-2147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 5561-2147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 4352-2147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2872
% INFO    : Updated Thermal Rating: on line 4164-2150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 5739-2150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 5409-2151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19026
% INFO    : Updated Thermal Rating: on line 3543-2153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 5410-2154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 973
% INFO    : Updated Thermal Rating: on line 3656-2155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 3543-2156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 5551-2156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 1996-2157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1682
% INFO    : Updated Thermal Rating: on line 1996-2157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 2161-2160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6326
% INFO    : Updated Thermal Rating: on line 5315-2161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 2068-2165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 3208-2165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 779
% INFO    : Updated Thermal Rating: on line 5269-2165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 4753-2165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4930
% INFO    : Updated Thermal Rating: on line 5685-2170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 2781-2171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 4433-2171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 3410-2172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 3526-2173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 3876-2173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 3410-2172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 3526-2173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4646-2176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 4646-2176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 2222-2178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2562
% INFO    : Updated Thermal Rating: on line 2222-2177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2562
% INFO    : Updated Thermal Rating: on line 2684-2179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38967
% INFO    : Updated Thermal Rating: on line 4018-2180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1633
% INFO    : Updated Thermal Rating: on line 2882-2181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 3877-2181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 2187-2184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 2294-2184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13307
% INFO    : Updated Thermal Rating: on line 3097-2184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1673
% INFO    : Updated Thermal Rating: on line 3296-2184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1379
% INFO    : Updated Thermal Rating: on line 3709-2184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6195
% INFO    : Updated Thermal Rating: on line 4806-2184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1656
% INFO    : Updated Thermal Rating: on line 2187-2184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4806-2184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1987
% INFO    : Updated Thermal Rating: on line 4806-2184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2563
% INFO    : Updated Thermal Rating: on line 2325-2185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50437
% INFO    : Updated Thermal Rating: on line 2324-2185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40928
% INFO    : Updated Thermal Rating: on line 5413-2186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 5414-2188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1207
% INFO    : Updated Thermal Rating: on line 3924-2189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 5431-2191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27888
% INFO    : Updated Thermal Rating: on line 5415-2192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9817
% INFO    : Updated Thermal Rating: on line 2804-2195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5585
% INFO    : Updated Thermal Rating: on line 3813-2201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4928-2201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 5764-2203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 2990-2204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 3138-2205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8140
% INFO    : Updated Thermal Rating: on line 3137-2205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8731
% INFO    : Updated Thermal Rating: on line 4022-2206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 3133-2209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1109
% INFO    : Updated Thermal Rating: on line 5419-2210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5422-2211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 2503-2212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 2872-2214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 5176-2214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 5180-2214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 4807-2219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 5424-2219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 2842-2222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2069
% INFO    : Updated Thermal Rating: on line 2225-1496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25273
% INFO    : Updated Thermal Rating: on line 4166-2225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 5425-2225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8499
% INFO    : Updated Thermal Rating: on line 5426-2226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2414
% INFO    : Updated Thermal Rating: on line 5059-2227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on line 2501-2230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 2523-2230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on line 3764-2231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 727
% INFO    : Updated Thermal Rating: on line 3764-2231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 727
% INFO    : Updated Thermal Rating: on line 2994-2232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 3836-2232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5065-2232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 5270-2232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 3764-2234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 2797-2236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on line 3521-2236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 2797-2236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 4015-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 3489-2239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 3489-2239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 2859-2239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 4027-2242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 3326-2243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 887
% INFO    : Updated Thermal Rating: on line 3459-2243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1388
% INFO    : Updated Thermal Rating: on line 2570-2245 : Rate A, Rate B, Rate C , 1617.0, 1617.0, 1617.0 -> 1286
% INFO    : Updated Thermal Rating: on line 3153-2245 : Rate A, Rate B, Rate C , 1828.0, 1828.0, 1828.0 -> 926
% INFO    : Updated Thermal Rating: on line 3154-2245 : Rate A, Rate B, Rate C , 1828.0, 1828.0, 1828.0 -> 926
% INFO    : Updated Thermal Rating: on line 5334-2247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2636
% INFO    : Updated Thermal Rating: on line 2902-2248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5892
% INFO    : Updated Thermal Rating: on line 2396-2249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 4646-2250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 4769-2250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 5426-2251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130845
% INFO    : Updated Thermal Rating: on line 2487-2253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 3898-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1461
% INFO    : Updated Thermal Rating: on line 4829-2258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6978
% INFO    : Updated Thermal Rating: on line 4828-2257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6978
% INFO    : Updated Thermal Rating: on line 5428-2259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3593
% INFO    : Updated Thermal Rating: on line 2271-2261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3315
% INFO    : Updated Thermal Rating: on line 2620-2262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 5112-2262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5647-2263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2205
% INFO    : Updated Thermal Rating: on line 4648-2265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 5612-2265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 4417-2265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1653
% INFO    : Updated Thermal Rating: on line 5268-2265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 953
% INFO    : Updated Thermal Rating: on line 4332-2268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 3147-2270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 2207-2271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 797
% INFO    : Updated Thermal Rating: on line 4487-2273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 5431-2274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27888
% INFO    : Updated Thermal Rating: on line 4022-2275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1548
% INFO    : Updated Thermal Rating: on line 4022-2275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1548
% INFO    : Updated Thermal Rating: on line 3410-2279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 3567-2280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 5688-2283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 4013-2285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 4592-2285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 5432-2287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 894
% INFO    : Updated Thermal Rating: on line 4784-2288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 3802-2288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 2607-2290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 3226-2290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 2827-2291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13714
% INFO    : Updated Thermal Rating: on line 3414-2291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 619
% INFO    : Updated Thermal Rating: on line 4567-2291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 5616-2291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 2828-2292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308785
% INFO    : Updated Thermal Rating: on line 5433-2293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12712
% INFO    : Updated Thermal Rating: on line 3292-2297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 5745-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 5831-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4060
% INFO    : Updated Thermal Rating: on line 5205-2300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 3308-2301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 4092-2301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 5300-2302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 2732-2303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 997
% INFO    : Updated Thermal Rating: on line 2342-2305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on line 3869-2305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on line 5622-2305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 2494-2307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 3104-2307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1978
% INFO    : Updated Thermal Rating: on line 3858-2307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1053
% INFO    : Updated Thermal Rating: on line 5059-2307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 5615-2307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 966
% INFO    : Updated Thermal Rating: on line 3858-2307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on line 5614-2307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 963
% INFO    : Updated Thermal Rating: on line 3401-2307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1578
% INFO    : Updated Thermal Rating: on line 2286-2309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 4765-2309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5533-2311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 2922-2313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 4092-2313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5033-2313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 5033-2313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 4869-2315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 3218-2316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1067
% INFO    : Updated Thermal Rating: on line 4129-2317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1907
% INFO    : Updated Thermal Rating: on line 4517-2317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on line 3649-2318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 5434-2319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 3363-2320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on line 3080-2323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4316
% INFO    : Updated Thermal Rating: on line 4389-2326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 3084-2329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 5439-2330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on line 3195-2333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3247-2333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 3415-2334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 4612-2334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 4701-2334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 5571-2334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on line 3415-2333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 4612-2333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 3064-2337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 3469-2337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2858-2338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 2428-2339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3176
% INFO    : Updated Thermal Rating: on line 2888-2340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 4442-2340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 2888-2340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 5821-2341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 3353-2343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 4208-2343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4318-2344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 601
% INFO    : Updated Thermal Rating: on line 5099-2344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 916
% INFO    : Updated Thermal Rating: on line 5441-2345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2283
% INFO    : Updated Thermal Rating: on line 2572-2347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 2978-2347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 4299-2347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 709
% INFO    : Updated Thermal Rating: on line 2572-2347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 4300-2347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 4619-2348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 2572-2347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 4018-2352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1684
% INFO    : Updated Thermal Rating: on line 2815-2353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 4350-2353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 2650-2354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 2901-2354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 3560-2356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 5762-2357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 4516-2358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3252
% INFO    : Updated Thermal Rating: on line 5195-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 977
% INFO    : Updated Thermal Rating: on line 4344-2361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 5443-2362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23932
% INFO    : Updated Thermal Rating: on line 5444-2363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 2376-2374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2376-2373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2376-2372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2376-2371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2376-2370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24882
% INFO    : Updated Thermal Rating: on line 2376-2369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2636-2375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 3896-2375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2356
% INFO    : Updated Thermal Rating: on line 5426-2375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3896-2375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 4183-2377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 974
% INFO    : Updated Thermal Rating: on line 2759-2378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 4018-2378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 3113-2380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 3552-2380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 3714-2380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 5446-2381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 3699-2381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5345-2382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 3666-2384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 2513-2385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 2593-2386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2239
% INFO    : Updated Thermal Rating: on line 3666-2386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 4900-2387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 3303-2388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10014
% INFO    : Updated Thermal Rating: on line 4990-2389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 2753-2391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1281
% INFO    : Updated Thermal Rating: on line 3641-2391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 2393-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23551
% INFO    : Updated Thermal Rating: on line 5471-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 2910-2393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 3331-2393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 5546-2393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 2910-2393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 5547-2393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 2825-2394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 4923-2395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 2503-2396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 2645-2397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 2780-2398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 2780-2398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 3325-2400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23670
% INFO    : Updated Thermal Rating: on line 3851-2400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 5456-2401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38032
% INFO    : Updated Thermal Rating: on line 3014-2402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1168
% INFO    : Updated Thermal Rating: on line 3679-2402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 3722-2402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4637
% INFO    : Updated Thermal Rating: on line 5651-2402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1383
% INFO    : Updated Thermal Rating: on line 3679-2402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on line 4704-2404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148594
% INFO    : Updated Thermal Rating: on line 4704-2403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151981
% INFO    : Updated Thermal Rating: on line 5457-2405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 2470-2406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 2984-2406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 5736-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 4720-2408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 2413-2409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77773
% INFO    : Updated Thermal Rating: on line 4541-2409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 3216-2410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3391
% INFO    : Updated Thermal Rating: on line 5808-2412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 3931-2414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 5768-2415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 4836-2416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2105
% INFO    : Updated Thermal Rating: on line 5664-2416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2632
% INFO    : Updated Thermal Rating: on line 3163-2417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184947
% INFO    : Updated Thermal Rating: on line 3163-2418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169954
% INFO    : Updated Thermal Rating: on line 5349-2419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 5463-2420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48031
% INFO    : Updated Thermal Rating: on line 4219-2422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 4219-2422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5454-2423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4599
% INFO    : Updated Thermal Rating: on line 2427-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 2513-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 3369-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2503
% INFO    : Updated Thermal Rating: on line 3445-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 5774-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 2513-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 5606-2427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 3010-2428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 3082-2428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 4719-2428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 4856-2428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 2431-2430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 4254-2432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 4741-2432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1192
% INFO    : Updated Thermal Rating: on line 5316-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 5462-2432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 5490-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 5491-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 5535-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 4254-2432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 4741-2432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1158
% INFO    : Updated Thermal Rating: on line 4254-2432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 4394-2434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 4682-2434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 3905-2435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5448-2435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 5715-2435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 3313-2438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 5574-2438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 4915-2440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 4915-2439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 3509-2441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 5705-2441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 3794-2442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 4027-2442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 4364-2442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 5236-2442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 5761-2442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5465-2444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 2596-2445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 2596-2446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 4777-2448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 5563-2448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 5150-2447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5133-2447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 5130-2448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 796
% INFO    : Updated Thermal Rating: on line 5545-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 826
% INFO    : Updated Thermal Rating: on line 3901-2451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 3901-2451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 2945-2452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 5449-2454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56971
% INFO    : Updated Thermal Rating: on line 3420-2455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 2568-2458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4378-2458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 2564-2459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 3093-2459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 4163-2459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 4216-2459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2157
% INFO    : Updated Thermal Rating: on line 5443-2459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 5679-2459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 4215-2459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2163
% INFO    : Updated Thermal Rating: on line 4654-2461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 5214-2461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2288
% INFO    : Updated Thermal Rating: on line 3338-2464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 3175-2465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 3651-2466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 5039-2466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 4977-2469 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1476
% INFO    : Updated Thermal Rating: on line 4242-2470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 4892-2470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2035
% INFO    : Updated Thermal Rating: on line 5458-2470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 4570-2472 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2130
% INFO    : Updated Thermal Rating: on line 4570-2472 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2130
% INFO    : Updated Thermal Rating: on line 2907-2473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 4455-2473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 4657-2473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 2835-2474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 3636-2474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 2491-2476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3563
% INFO    : Updated Thermal Rating: on line 2491-2475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2766
% INFO    : Updated Thermal Rating: on line 4566-2477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 4089-2478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 3853-2479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23430
% INFO    : Updated Thermal Rating: on line 4864-2479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 4862-2480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on line 5189-2481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22412
% INFO    : Updated Thermal Rating: on line 3743-2482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1514
% INFO    : Updated Thermal Rating: on line 2823-2484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 4269-2484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 4611-2484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2079
% INFO    : Updated Thermal Rating: on line 5115-2485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 2729-2488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3497-2489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 4755-2490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 5524-2490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 2835-2491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 3034-2491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 2835-2491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 3782-2492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104366
% INFO    : Updated Thermal Rating: on line 3781-2492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87644
% INFO    : Updated Thermal Rating: on line 4862-2493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5288-2493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 3592-2495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3292
% INFO    : Updated Thermal Rating: on line 4687-2497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 2725-2498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 2719-2501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 3009-2501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 4080-2501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 5167-2501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4710
% INFO    : Updated Thermal Rating: on line 5467-2502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1105
% INFO    : Updated Thermal Rating: on line 5449-2503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 2791-2503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 2781-2506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 2923-2507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 5468-2508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114924
% INFO    : Updated Thermal Rating: on line 4199-2509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 4862-2509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 5228-2509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5230-2509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 4862-2509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 4994-2510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 4994-2510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 3356-2511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 2837-2514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8065
% INFO    : Updated Thermal Rating: on line 5731-2514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 2836-2515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1359
% INFO    : Updated Thermal Rating: on line 4398-2515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1543
% INFO    : Updated Thermal Rating: on line 4009-2516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 4009-2516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 3251-2518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 3251-2518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 2719-2523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 4777-2523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 5167-2523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 5720-2524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1856
% INFO    : Updated Thermal Rating: on line 2538-2527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on line 5469-2527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 3390-2528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128083
% INFO    : Updated Thermal Rating: on line 4808-2529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3937-2530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 2561-2531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 5348-2531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 2561-2531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 2931-2532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on line 2535-2534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 2689-2535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 3662-2535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 4817-2535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 5473-2535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 5472-2537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83031
% INFO    : Updated Thermal Rating: on line 5760-2538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 5469-2539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 781
% INFO    : Updated Thermal Rating: on line 2708-2540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 491
% INFO    : Updated Thermal Rating: on line 2896-2541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1550
% INFO    : Updated Thermal Rating: on line 3158-2541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 3158-2541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 4212-2543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 3482-2544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1013
% INFO    : Updated Thermal Rating: on line 5477-2546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1893
% INFO    : Updated Thermal Rating: on line 5506-2545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3707
% INFO    : Updated Thermal Rating: on line 2973-2547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 2973-2547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 5475-2548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2082
% INFO    : Updated Thermal Rating: on line 5476-2549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 3685-2550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 4735-2550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 612
% INFO    : Updated Thermal Rating: on line 4840-2550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 4735-2550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 5694-2551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 845
% INFO    : Updated Thermal Rating: on line 3912-2552 : Rate A, Rate B, Rate C , 482.0, 482.0, 482.0 -> 455
% INFO    : Updated Thermal Rating: on line 4178-2554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3188-2555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 4792-2556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on line 4792-2556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on line 2767-2557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 3666-2558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 3700-2558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 3377-2559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 4910-2559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 3843-2560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 4325-2560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 3648-2561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 5572-2561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 5573-2561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 5848-2561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 2630-2561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 5480-2564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5481-2565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on line 5482-2566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 3941-2567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 4008-2567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 3105-2568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 3825-2568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 4081-2568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 5255-2568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 5767-2568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 4111-2571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 584
% INFO    : Updated Thermal Rating: on line 4792-2571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5712-2572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1168
% INFO    : Updated Thermal Rating: on line 5710-2572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1111
% INFO    : Updated Thermal Rating: on line 4003-2574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 4368-2574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1147
% INFO    : Updated Thermal Rating: on line 5190-2576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13013
% INFO    : Updated Thermal Rating: on line 3010-2578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 3010-2578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 4340-2579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 5390-2579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 5753-2579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2532
% INFO    : Updated Thermal Rating: on line 5794-2579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 5256-2581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on line 3436-2583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 4143-2583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 2829-2584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 2626-2585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 566
% INFO    : Updated Thermal Rating: on line 4397-2585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5342
% INFO    : Updated Thermal Rating: on line 5110-2585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 4396-2585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5342
% INFO    : Updated Thermal Rating: on line 5109-2585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 2739-2587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 5752-2587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3169-2589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 5484-2590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5531
% INFO    : Updated Thermal Rating: on line 2986-2591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 3012-2592 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1547
% INFO    : Updated Thermal Rating: on line 2799-2592 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1476
% INFO    : Updated Thermal Rating: on line 3012-2592 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1547
% INFO    : Updated Thermal Rating: on line 2799-2592 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1479
% INFO    : Updated Thermal Rating: on line 3666-2593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 3666-2593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 5382-2594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 5632-2594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33358
% INFO    : Updated Thermal Rating: on line 5486-2595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 4404-2596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 4414-2596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4404-2596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 4414-2596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 5401-2598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5979
% INFO    : Updated Thermal Rating: on line 2602-2600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62462
% INFO    : Updated Thermal Rating: on line 4673-2600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 5487-2601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 3113-2603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 4055-2603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 3113-2603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 5488-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 3573-2606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on line 4448-2606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 2877-2607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 3226-2607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 3348-2607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 4073-2607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 3412-2610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 3409-2612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 3621-2613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 5033-2614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 5457-2614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 4792-2615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 3360-2616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1161
% INFO    : Updated Thermal Rating: on line 3978-2617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 4679-2617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3025-2618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 5816-2618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 4862-2621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5094-2622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 5490-2623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 5491-2623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12845
% INFO    : Updated Thermal Rating: on line 2959-2624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5806-2624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7635
% INFO    : Updated Thermal Rating: on line 5807-2624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 2931-2627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 4587-2627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 5572-2630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1157
% INFO    : Updated Thermal Rating: on line 2639-2631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on line 3560-2631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on line 3892-2631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 2911-2632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 5249-2632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 5492-2634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1516
% INFO    : Updated Thermal Rating: on line 2790-2635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 3139-2635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 4604-2635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 4604-2636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 2951-2638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4070-2638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 3441-2639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5232-2640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5504-2641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3410
% INFO    : Updated Thermal Rating: on line 5835-2641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 5534-2642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8999
% INFO    : Updated Thermal Rating: on line 2646-2645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5221-2645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 5218-2646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 3503-2647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 4174-2647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 3653-2647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 4175-2650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2280
% INFO    : Updated Thermal Rating: on line 5545-2650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 684
% INFO    : Updated Thermal Rating: on line 5583-2650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3399
% INFO    : Updated Thermal Rating: on line 4993-2651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 5822-2651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 3770-2652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 3376-2653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 3489-2653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 4540-2654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2100
% INFO    : Updated Thermal Rating: on line 5189-2654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 4148-2656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4514-2656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 5356-2656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on line 2719-2659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 3452-2659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 3988-2660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 3689-2661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on line 2594-2662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 3531-2662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4040-2662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 5430-2662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on line 2594-2662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 3491-2668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1836
% INFO    : Updated Thermal Rating: on line 5689-2669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 5690-2669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 3512-2670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 4164-2670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1357
% INFO    : Updated Thermal Rating: on line 4880-2670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4350
% INFO    : Updated Thermal Rating: on line 3573-2674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 3573-2673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 4257-2675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 819
% INFO    : Updated Thermal Rating: on line 4887-2675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 4257-2675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 4402-2676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 5494-2677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on line 3884-2677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 2677-2679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 702
% INFO    : Updated Thermal Rating: on line 4360-2682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 3017-2683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1396
% INFO    : Updated Thermal Rating: on line 5401-2683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 5762-2683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 3017-2683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1422
% INFO    : Updated Thermal Rating: on line 3483-2685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 4697-2686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 5497-2688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2745
% INFO    : Updated Thermal Rating: on line 3762-2689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4782-2691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 3518-2692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 2694-2693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 5498-2693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24050
% INFO    : Updated Thermal Rating: on line 2835-2696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5788
% INFO    : Updated Thermal Rating: on line 2835-2696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9266
% INFO    : Updated Thermal Rating: on line 3898-2698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 4734-2698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on line 4827-2700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 861
% INFO    : Updated Thermal Rating: on line 4324-2701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 3658-2702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 967
% INFO    : Updated Thermal Rating: on line 3175-2704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 4058-2704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22736
% INFO    : Updated Thermal Rating: on line 4667-2704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 4059-2704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17760
% INFO    : Updated Thermal Rating: on line 4898-2705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 486
% INFO    : Updated Thermal Rating: on line 5206-2705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1357
% INFO    : Updated Thermal Rating: on line 5837-2705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on line 2896-2708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 3840-2707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 4614-2708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 4865-2707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 5399-2707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on line 3931-2711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 3932-2712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3468
% INFO    : Updated Thermal Rating: on line 5502-2713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 3544-2715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 5168-2719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on line 5170-2719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 3030-2720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 4725-2721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46632
% INFO    : Updated Thermal Rating: on line 4724-2721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51447
% INFO    : Updated Thermal Rating: on line 4723-2721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51447
% INFO    : Updated Thermal Rating: on line 3666-2723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 3666-2723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 3584-2725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3320
% INFO    : Updated Thermal Rating: on line 4816-2725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 4816-2725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 971
% INFO    : Updated Thermal Rating: on line 3916-2727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 3602-2729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 5504-2730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1725
% INFO    : Updated Thermal Rating: on line 4149-2731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2666
% INFO    : Updated Thermal Rating: on line 4227-2734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 4956-2738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1465
% INFO    : Updated Thermal Rating: on line 4956-2737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3204
% INFO    : Updated Thermal Rating: on line 3679-2739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 5650-2740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17478
% INFO    : Updated Thermal Rating: on line 3646-2743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 3815-2744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 4990-2744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 3121-2745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3120-2745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3119-2745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4626-2746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on line 3422-2747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 2945-2749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8159
% INFO    : Updated Thermal Rating: on line 4730-2751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 4786-2751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 5107-2751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 4786-2751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 2846-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 4206-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5525
% INFO    : Updated Thermal Rating: on line 4426-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 5100-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 5737-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2177
% INFO    : Updated Thermal Rating: on line 4205-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4439
% INFO    : Updated Thermal Rating: on line 3510-2755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 937
% INFO    : Updated Thermal Rating: on line 5509-2756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3460
% INFO    : Updated Thermal Rating: on line 3424-2757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 4804-2757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 5506-2758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27575
% INFO    : Updated Thermal Rating: on line 3664-2759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1684
% INFO    : Updated Thermal Rating: on line 5505-2761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9377
% INFO    : Updated Thermal Rating: on line 5510-2762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6271
% INFO    : Updated Thermal Rating: on line 4908-2764 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1264
% INFO    : Updated Thermal Rating: on line 4625-2765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 3366-2766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on line 3366-2766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 5507-2767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 5687-2768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5386-2768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1617
% INFO    : Updated Thermal Rating: on line 2841-2770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 624
% INFO    : Updated Thermal Rating: on line 3261-2770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 917
% INFO    : Updated Thermal Rating: on line 4285-2770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 4411-2770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 4904-2770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 5820-2770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 4285-2770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 5240-2770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 3018-2771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 5502-2773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 5776-2773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 3904-2775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 5081-2775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 3810-2777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 5135-2777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 4009-2779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 2962-2780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 3330-2780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1383
% INFO    : Updated Thermal Rating: on line 5442-2781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5452-2781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 5453-2781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 5599-2781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 3330-2780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 3356-2781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 3483-2784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1330
% INFO    : Updated Thermal Rating: on line 5422-2788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 4857-2789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 4857-2789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 4604-2790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 4071-2791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 5449-2791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 5470-2791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 5471-2791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 4071-2791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4064-2793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 4956-2794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 3859-2800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on line 4200-2801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 4862-2802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 3799-2803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 3925-2803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 5251-2803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 3671-2806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 724
% INFO    : Updated Thermal Rating: on line 4924-2808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 5457-2808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 3700-2809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10480
% INFO    : Updated Thermal Rating: on line 3512-2810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 4177-2810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 4380-2810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1659
% INFO    : Updated Thermal Rating: on line 4257-2812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 5515-2814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12969
% INFO    : Updated Thermal Rating: on line 3307-2815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 4395-2815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 5037-2815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 5298-2815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1039
% INFO    : Updated Thermal Rating: on line 5554-2815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 5556-2815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on line 5570-2815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 5036-2815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 2945-2817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5751-2817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 4720-2819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 5213-2819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5459-2819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 4348-2820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1278
% INFO    : Updated Thermal Rating: on line 4316-2824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 4336-2824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 5450-2825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 3713-2826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25728
% INFO    : Updated Thermal Rating: on line 3182-2830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 3848-2830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1415
% INFO    : Updated Thermal Rating: on line 5322-2830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 803
% INFO    : Updated Thermal Rating: on line 5820-2830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 640
% INFO    : Updated Thermal Rating: on line 5673-2834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4398-2836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1620
% INFO    : Updated Thermal Rating: on line 5516-2838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 3345-2840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5092-2841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3170
% INFO    : Updated Thermal Rating: on line 5266-2843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1862
% INFO    : Updated Thermal Rating: on line 5392-2844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5520-2845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113138
% INFO    : Updated Thermal Rating: on line 2954-2846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 4561-2846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 5730-2848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 5252-2851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 5522-2851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5792-2854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 5525-2856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309124
% INFO    : Updated Thermal Rating: on line 5524-2857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27511
% INFO    : Updated Thermal Rating: on line 5523-2859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1734
% INFO    : Updated Thermal Rating: on line 5523-2860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12072
% INFO    : Updated Thermal Rating: on line 3399-2862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 3758-2864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 5337-2864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 831
% INFO    : Updated Thermal Rating: on line 5786-2864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 2998-2868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2240
% INFO    : Updated Thermal Rating: on line 4847-2866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2357
% INFO    : Updated Thermal Rating: on line 4847-2867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2631
% INFO    : Updated Thermal Rating: on line 5528-2869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23932
% INFO    : Updated Thermal Rating: on line 4685-2870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38824
% INFO    : Updated Thermal Rating: on line 4448-2871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 5530-2874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5072
% INFO    : Updated Thermal Rating: on line 4930-2875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 3276-2876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1823
% INFO    : Updated Thermal Rating: on line 5618-2877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 5532-2878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1925
% INFO    : Updated Thermal Rating: on line 5531-2879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on line 3038-2883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 3076-2884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 3010-2885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 5317-2886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1275
% INFO    : Updated Thermal Rating: on line 5533-2886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12709
% INFO    : Updated Thermal Rating: on line 3036-2887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 5534-2887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 4295-2888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 4582-2889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 4565-2890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2138
% INFO    : Updated Thermal Rating: on line 4637-2894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2130
% INFO    : Updated Thermal Rating: on line 4638-2894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2147
% INFO    : Updated Thermal Rating: on line 3326-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1449
% INFO    : Updated Thermal Rating: on line 5655-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2579
% INFO    : Updated Thermal Rating: on line 4017-2896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 3181-2897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 5535-2898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6565
% INFO    : Updated Thermal Rating: on line 3845-2899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5033-2899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 5492-2899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 3600-2901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1594
% INFO    : Updated Thermal Rating: on line 5537-2903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7065
% INFO    : Updated Thermal Rating: on line 5536-2903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7639
% INFO    : Updated Thermal Rating: on line 5682-2904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on line 4718-2905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5259
% INFO    : Updated Thermal Rating: on line 4134-2906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 2910-2909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on line 5622-2911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1565
% INFO    : Updated Thermal Rating: on line 3901-2912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5406-2912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 4854-2914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4464-2915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on line 2921-2919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 3794-2920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3282
% INFO    : Updated Thermal Rating: on line 3931-2921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 4255-2921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 5779-2921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1602
% INFO    : Updated Thermal Rating: on line 4914-2924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4940-2924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 3851-2925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 3851-2925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 3086-2926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 4383-2927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7146
% INFO    : Updated Thermal Rating: on line 3297-2928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 5539-2929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32501
% INFO    : Updated Thermal Rating: on line 3213-2931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 3683-2931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 3099-2935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 5781-2935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3850-2937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 4997-2936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 5609-2937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1171
% INFO    : Updated Thermal Rating: on line 3850-2936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 5611-2936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 5542-2939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18526
% INFO    : Updated Thermal Rating: on line 5290-2941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 5846-2941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 4845-2942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 3239-2945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 5024-2945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2126
% INFO    : Updated Thermal Rating: on line 5080-2945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on line 3968-2947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1675
% INFO    : Updated Thermal Rating: on line 4925-2947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1964
% INFO    : Updated Thermal Rating: on line 3240-2951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 5066-2951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5444-2951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 751
% INFO    : Updated Thermal Rating: on line 4426-2954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 5052-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 5674-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 4348-2956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4244-2957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 5544-2959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 5545-2960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35735
% INFO    : Updated Thermal Rating: on line 4668-2963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1271
% INFO    : Updated Thermal Rating: on line 5546-2972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10795
% INFO    : Updated Thermal Rating: on line 3999-2973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 4906-2973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 5217-2973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 3998-2973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 3041-2975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 5201-2975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 3983-2976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 4259-2976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 5548-2977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6352
% INFO    : Updated Thermal Rating: on line 5618-2979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 5641-2979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 3314-2980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 3604-2981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 4358-2981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 5465-2981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 5606-2981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 5643-2982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1095
% INFO    : Updated Thermal Rating: on line 4005-2985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4892
% INFO    : Updated Thermal Rating: on line 3403-2986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 4097-2986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 4369-2986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 5146-2986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 5850-2986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 4097-2986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 3484-2988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 4056-2990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1082
% INFO    : Updated Thermal Rating: on line 4162-2990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 5254-2990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1412
% INFO    : Updated Thermal Rating: on line 5741-2990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 3554-2992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52449
% INFO    : Updated Thermal Rating: on line 4983-2993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 5667-2993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 4112-2995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 503
% INFO    : Updated Thermal Rating: on line 4793-2995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 3287-2998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1029
% INFO    : Updated Thermal Rating: on line 3681-2997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on line 4317-2997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5139
% INFO    : Updated Thermal Rating: on line 5542-2997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 5646-2997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1382
% INFO    : Updated Thermal Rating: on line 5648-2998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1289
% INFO    : Updated Thermal Rating: on line 4768-3001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 5619-3001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 4768-3001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 3174-3003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 5169-3003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 5775-3003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3047-3003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 3174-3003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 3679-3005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 3466-3007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 5044-3010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 5116-3010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 3082-3013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 3679-3014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 4778-3015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on line 4778-3015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on line 5454-3017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 587
% INFO    : Updated Thermal Rating: on line 4926-3019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 5169-3020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56971
% INFO    : Updated Thermal Rating: on line 5578-3020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 4790-3021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 3543-3022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4770-3022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 5778-3024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9667
% INFO    : Updated Thermal Rating: on line 5784-3024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1648
% INFO    : Updated Thermal Rating: on line 3520-3028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 5592-3030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 5025-3031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 5136-3031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 3597-3034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 3399-3035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 5343-3035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 4720-3036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on line 3482-3040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 978
% INFO    : Updated Thermal Rating: on line 4462-3041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4510-3041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 4635-3041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 4862-3042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7065
% INFO    : Updated Thermal Rating: on line 4862-3043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 4862-3043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 4231-3044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1597
% INFO    : Updated Thermal Rating: on line 4839-3044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3311-3045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 4304-3045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2337
% INFO    : Updated Thermal Rating: on line 4813-3049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 4582-3050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 613
% INFO    : Updated Thermal Rating: on line 3064-3051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 3268-3053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 3496-3054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 5558-3060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 5196-3066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5306-3066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 3675-3067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1766
% INFO    : Updated Thermal Rating: on line 3979-3067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1183
% INFO    : Updated Thermal Rating: on line 4956-3068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1326
% INFO    : Updated Thermal Rating: on line 3679-3072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 4337-3074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 5324-3074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 5636-3074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 5657-3076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 822
% INFO    : Updated Thermal Rating: on line 4767-3077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 5828-3077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6858
% INFO    : Updated Thermal Rating: on line 4798-3077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2345
% INFO    : Updated Thermal Rating: on line 5561-3078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1047
% INFO    : Updated Thermal Rating: on line 3201-3079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 4772-3080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5437-3080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240340
% INFO    : Updated Thermal Rating: on line 5157-3081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2621
% INFO    : Updated Thermal Rating: on line 4657-3084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 5230-3085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5736-3085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 3710-3086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 5363-3086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 5376-3086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 3313-3088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 5660-3088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 5261-3090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 3968-3091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 5141-3092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 5628-3092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 4076-3093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 5000-3095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 3562-3096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1162
% INFO    : Updated Thermal Rating: on line 3344-3098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 4951-3100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5257-3100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 4918-3103 : Rate A, Rate B, Rate C , 1617.0, 1617.0, 1617.0 -> 1275
% INFO    : Updated Thermal Rating: on line 3689-3107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 3689-3106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 3457-3108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 5378-3108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 5358-3108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 846
% INFO    : Updated Thermal Rating: on line 3679-3111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 3679-3111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 3269-3112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 5584-3112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 3552-3113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 3761-3113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 4394-3113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 4758-3113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 5624-3113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on line 5481-3113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4855-3115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 5092-3114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 5285-3115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 4963-3114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 5566-3122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2570
% INFO    : Updated Thermal Rating: on line 3509-3123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3688
% INFO    : Updated Thermal Rating: on line 5567-3125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 4354-3126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 5613-3127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 5746-3127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on line 5819-3127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 5608-3127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 3178-3128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 2931-3129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3813-3129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 4270-3131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5215
% INFO    : Updated Thermal Rating: on line 5117-3131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 4365-3132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 4978-3134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 5570-3136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4490
% INFO    : Updated Thermal Rating: on line 4609-3139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on line 3164-3141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 882
% INFO    : Updated Thermal Rating: on line 3930-3141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 3164-3141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 5360-3142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1975
% INFO    : Updated Thermal Rating: on line 5571-3143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7254
% INFO    : Updated Thermal Rating: on line 3146-3144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310318
% INFO    : Updated Thermal Rating: on line 3903-3145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 4974-3145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 5097-3145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 4973-3145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 3986-3147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 5848-3147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on line 5779-3148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 3879-3151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 3890-3152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 4132-3152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 208
% INFO    : Updated Thermal Rating: on line 5018-3152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 5047-3152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36728
% INFO    : Updated Thermal Rating: on line 4903-3154 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1005
% INFO    : Updated Thermal Rating: on line 4903-3153 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1006
% INFO    : Updated Thermal Rating: on line 5067-3157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3291
% INFO    : Updated Thermal Rating: on line 3602-3159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 4890-3159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 3258-3160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 3527-3160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10278
% INFO    : Updated Thermal Rating: on line 3275-3161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 486
% INFO    : Updated Thermal Rating: on line 3385-3164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 4433-3164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 5203-3164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 5492-3164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 5572-3166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2328
% INFO    : Updated Thermal Rating: on line 4522-3169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2877
% INFO    : Updated Thermal Rating: on line 5504-3169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 5574-3170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18302
% INFO    : Updated Thermal Rating: on line 5575-3171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23670
% INFO    : Updated Thermal Rating: on line 4722-3172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 5344-3172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 3673-3173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 5578-3174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23551
% INFO    : Updated Thermal Rating: on line 4667-3175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 4962-3176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on line 5626-3177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 3266-3178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 3396-3183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 4111-3184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 4636-3184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 5580-3185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5120-3185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 4883-3186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5581-3187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 5616-3188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 5788-3188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 653
% INFO    : Updated Thermal Rating: on line 4291-3190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 5377-3190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2606
% INFO    : Updated Thermal Rating: on line 4400-3191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37253
% INFO    : Updated Thermal Rating: on line 3515-3193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4252-3195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 4312-3196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 4690-3196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3321
% INFO    : Updated Thermal Rating: on line 5239-3197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 5354-3197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4312-3196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 5562-3201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1740
% INFO    : Updated Thermal Rating: on line 3882-3204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93975
% INFO    : Updated Thermal Rating: on line 3883-3205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102466
% INFO    : Updated Thermal Rating: on line 5500-3206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 4624-3207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 5270-3208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1932
% INFO    : Updated Thermal Rating: on line 4219-3209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2662
% INFO    : Updated Thermal Rating: on line 4498-3209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4328
% INFO    : Updated Thermal Rating: on line 5583-3210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42408
% INFO    : Updated Thermal Rating: on line 3269-3211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 5585-3214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 4868-3218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1295
% INFO    : Updated Thermal Rating: on line 5579-3219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 3826-3220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 3924-3220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3925-3220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 4956-3221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7828
% INFO    : Updated Thermal Rating: on line 3300-3222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 4231-3222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 3299-3223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4230-3223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 4764-3224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 5828-3224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 3823-3226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 3632-3228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1285
% INFO    : Updated Thermal Rating: on line 5490-3229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 3427-3233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64823
% INFO    : Updated Thermal Rating: on line 3427-3232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64823
% INFO    : Updated Thermal Rating: on line 3427-3231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52241
% INFO    : Updated Thermal Rating: on line 4605-3235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 4606-3234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 5444-3240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 5539-3241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 4183-3242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 914
% INFO    : Updated Thermal Rating: on line 4267-3244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 5279-3244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 774
% INFO    : Updated Thermal Rating: on line 5332-3245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 4632-3246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 5028-3246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 5588-3247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 5589-3248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7124
% INFO    : Updated Thermal Rating: on line 4614-3249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 3436-3250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 4323-3250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 5566-3250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 5841-3251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 611
% INFO    : Updated Thermal Rating: on line 5754-3251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 4787-3252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1019
% INFO    : Updated Thermal Rating: on line 5649-3252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1246
% INFO    : Updated Thermal Rating: on line 3652-3255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3058
% INFO    : Updated Thermal Rating: on line 3652-3254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3058
% INFO    : Updated Thermal Rating: on line 3652-3256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3099
% INFO    : Updated Thermal Rating: on line 3437-3258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 4447-3258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 5195-3258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 4792-3260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 5322-3261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 4670-3262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on line 5590-3264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1522
% INFO    : Updated Thermal Rating: on line 4556-3266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 3949-3267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106799
% INFO    : Updated Thermal Rating: on line 4238-3269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 864
% INFO    : Updated Thermal Rating: on line 4770-3272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 5111-3274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 5129-3274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 5543-3274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 4473-3276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 3284-3278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2012
% INFO    : Updated Thermal Rating: on line 3654-3278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1065
% INFO    : Updated Thermal Rating: on line 5615-3278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 3283-3278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2012
% INFO    : Updated Thermal Rating: on line 3654-3278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3487
% INFO    : Updated Thermal Rating: on line 5614-3278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 4039-3287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15006
% INFO    : Updated Thermal Rating: on line 4866-3294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5593-3295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1885
% INFO    : Updated Thermal Rating: on line 3500-3297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 577
% INFO    : Updated Thermal Rating: on line 3870-3297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 4649-3300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 4649-3299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 4277-3301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 910
% INFO    : Updated Thermal Rating: on line 3399-3302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 4543-3302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3284
% INFO    : Updated Thermal Rating: on line 3399-3302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 4415-3303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 643
% INFO    : Updated Thermal Rating: on line 5406-3304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 4209-3306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 5170-3308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 5756-3308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 5835-3309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23932
% INFO    : Updated Thermal Rating: on line 4304-3311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 708
% INFO    : Updated Thermal Rating: on line 5381-3311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 5585-3311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 5750-3311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 3692-3312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14024
% INFO    : Updated Thermal Rating: on line 4822-3314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3198
% INFO    : Updated Thermal Rating: on line 5175-3315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 5739-3315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5309-3321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2154
% INFO    : Updated Thermal Rating: on line 5691-3321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 691
% INFO    : Updated Thermal Rating: on line 3914-3322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on line 3535-3323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308192
% INFO    : Updated Thermal Rating: on line 3534-3323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308192
% INFO    : Updated Thermal Rating: on line 3851-3324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1417
% INFO    : Updated Thermal Rating: on line 3428-3326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 516
% INFO    : Updated Thermal Rating: on line 4285-3327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6319
% INFO    : Updated Thermal Rating: on line 5470-3331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 5575-3331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on line 4847-3333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13624
% INFO    : Updated Thermal Rating: on line 4847-3332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6991
% INFO    : Updated Thermal Rating: on line 4289-3335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 5040-3335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5325-3335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 5595-3337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 5249-3339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 5034-3341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3901
% INFO    : Updated Thermal Rating: on line 5034-3340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3901
% INFO    : Updated Thermal Rating: on line 4442-3343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5243-3344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11822
% INFO    : Updated Thermal Rating: on line 5353-3345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 5618-3348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1178
% INFO    : Updated Thermal Rating: on line 3774-3349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 4610-3349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 5093-3349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1257
% INFO    : Updated Thermal Rating: on line 3774-3349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 5638-3349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 5772-3349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 5600-3354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 5601-3354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 3356-3355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on line 5599-3356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 5598-3357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5486-3358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 789
% INFO    : Updated Thermal Rating: on line 4961-3358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 287
% INFO    : Updated Thermal Rating: on line 3934-3359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1443
% INFO    : Updated Thermal Rating: on line 3934-3359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1278
% INFO    : Updated Thermal Rating: on line 5328-3361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 3487-3365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4964
% INFO    : Updated Thermal Rating: on line 4665-3365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 4665-3365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 4578-3366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 4183-3370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 4183-3370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 5607-3375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5122-3376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 5225-3376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 503
% INFO    : Updated Thermal Rating: on line 5609-3378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1519
% INFO    : Updated Thermal Rating: on line 5610-3379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243304
% INFO    : Updated Thermal Rating: on line 3837-3380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 4339-3380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 3837-3380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 4407-3382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 5541-3383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 5540-3384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 805
% INFO    : Updated Thermal Rating: on line 5090-3386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 3901-3387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 3901-3387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 5138-3388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 3887-3391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 865
% INFO    : Updated Thermal Rating: on line 4838-3391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 3924-3396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 5541-3396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 3925-3396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 5540-3396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 4295-3398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 3542-3399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 4335-3399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 5303-3399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5516-3399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 5614-3402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3799
% INFO    : Updated Thermal Rating: on line 5485-3403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 929
% INFO    : Updated Thermal Rating: on line 3405-3404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4524
% INFO    : Updated Thermal Rating: on line 4133-3406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 5616-3408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45692
% INFO    : Updated Thermal Rating: on line 4062-3411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 3913-3415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 5619-3417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2846
% INFO    : Updated Thermal Rating: on line 4455-3418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1072
% INFO    : Updated Thermal Rating: on line 3982-3419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 979
% INFO    : Updated Thermal Rating: on line 4036-3419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 3982-3419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 979
% INFO    : Updated Thermal Rating: on line 4148-3420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 5765-3421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 5280-3422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 5555-3422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 4110-3423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 4329-3424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 5414-3426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 3737-3429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 3894-3429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 5126-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 4350-3432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 5395-3432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 4350-3432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 5623-3434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 3525-3437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 4607-3439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 5587-3439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 3773-3441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 4916-3442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 5624-3443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 3447-3444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 4243-3444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on line 4681-3444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 5774-3445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5625-3446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13401
% INFO    : Updated Thermal Rating: on line 4681-3447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 4681-3448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5140-3449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1334
% INFO    : Updated Thermal Rating: on line 5626-3451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on line 5235-3453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5236-3453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5343-3453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 5801-3454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1338
% INFO    : Updated Thermal Rating: on line 4919-3455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2162
% INFO    : Updated Thermal Rating: on line 4967-3455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1531
% INFO    : Updated Thermal Rating: on line 4967-3455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1541
% INFO    : Updated Thermal Rating: on line 5627-3456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 634
% INFO    : Updated Thermal Rating: on line 3556-3457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 5538-3459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1834
% INFO    : Updated Thermal Rating: on line 4014-3460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1378
% INFO    : Updated Thermal Rating: on line 5777-3461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 5628-3462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 4778-3463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 5273-3466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 5629-3468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10014
% INFO    : Updated Thermal Rating: on line 3515-3469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 3482-3473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6987
% INFO    : Updated Thermal Rating: on line 3482-3475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10050
% INFO    : Updated Thermal Rating: on line 3482-3472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10699
% INFO    : Updated Thermal Rating: on line 3482-3474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13403
% INFO    : Updated Thermal Rating: on line 4876-3481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3633
% INFO    : Updated Thermal Rating: on line 4876-3480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3633
% INFO    : Updated Thermal Rating: on line 5329-3482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 5378-3482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 5477-3482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2203
% INFO    : Updated Thermal Rating: on line 5358-3482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 5506-3482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1384
% INFO    : Updated Thermal Rating: on line 5557-3482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1318
% INFO    : Updated Thermal Rating: on line 3721-3484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 4402-3486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 4415-3486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 3546-3488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 4125-3488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 5549-3490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2546
% INFO    : Updated Thermal Rating: on line 5630-3492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 4320-3494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 4408-3494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5483-3494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5484-3494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 5631-3495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 4389-3497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 4751-3497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5103-3497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1605
% INFO    : Updated Thermal Rating: on line 4389-3497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 3568-3498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5052-3498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 5052-3498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 5632-3499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 3870-3500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 5277-3507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28417
% INFO    : Updated Thermal Rating: on line 5636-3508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2143
% INFO    : Updated Thermal Rating: on line 4011-3509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 4566-3509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 5100-3509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 5634-3509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3446
% INFO    : Updated Thermal Rating: on line 4607-3511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 936
% INFO    : Updated Thermal Rating: on line 4788-3512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 4017-3513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on line 3879-3514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 3982-3515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 4833-3515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 5799-3515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 3982-3515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 3982-3515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 4035-3518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 4035-3518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 3837-3520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 743
% INFO    : Updated Thermal Rating: on line 4549-3523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 5007-3522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 602
% INFO    : Updated Thermal Rating: on line 5385-3523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 5790-3522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 761
% INFO    : Updated Thermal Rating: on line 4425-3531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 5638-3533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7266
% INFO    : Updated Thermal Rating: on line 5640-3536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21242
% INFO    : Updated Thermal Rating: on line 4174-3537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2259
% INFO    : Updated Thermal Rating: on line 4815-3539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4085
% INFO    : Updated Thermal Rating: on line 5067-3539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 5431-3539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6818
% INFO    : Updated Thermal Rating: on line 5831-3542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 4061-3546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 4125-3546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 5422-3546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5643-3549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 4348-3551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 5075-3551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1049
% INFO    : Updated Thermal Rating: on line 4348-3551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on line 5644-3553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20555
% INFO    : Updated Thermal Rating: on line 5015-3554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23000
% INFO    : Updated Thermal Rating: on line 4362-3555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 4888-3556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5176-3556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 5477-3556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 5529-3556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 5706-3556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 5180-3556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on line 4516-3559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1867
% INFO    : Updated Thermal Rating: on line 4886-3560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 4886-3560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 3565-3562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4018-3567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 4218-3567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 5337-3568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 5129-3569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 4722-3570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 4668-3571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 4011-3572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 4566-3572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 4011-3572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 3983-3573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 3370-3577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 5631-3577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 4517-3583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 5716-3583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 3846-3585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5982
% INFO    : Updated Thermal Rating: on line 5284-3585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 5342-3585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 5838-3585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 4649-3586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5646-3589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5648-3590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 3391-3591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1249
% INFO    : Updated Thermal Rating: on line 3887-3591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1864
% INFO    : Updated Thermal Rating: on line 5647-3593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151236
% INFO    : Updated Thermal Rating: on line 5479-3594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20343
% INFO    : Updated Thermal Rating: on line 3430-3595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5006
% INFO    : Updated Thermal Rating: on line 3988-3595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 3510-3596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 5456-3596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6284
% INFO    : Updated Thermal Rating: on line 3743-3597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 5455-3601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 5369-3602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on line 5570-3602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 994
% INFO    : Updated Thermal Rating: on line 4307-3604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 872
% INFO    : Updated Thermal Rating: on line 5606-3604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 5306-3608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1641
% INFO    : Updated Thermal Rating: on line 4235-3610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 4193-3612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 4615-3612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5625-3612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1476
% INFO    : Updated Thermal Rating: on line 5652-3613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 3395-3616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on line 4508-3620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 5200-3619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3129
% INFO    : Updated Thermal Rating: on line 3406-3621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 3406-3621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on line 3363-3623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5804-3623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 3363-3623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 4614-3624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 5654-3627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6375
% INFO    : Updated Thermal Rating: on line 3632-3629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15535
% INFO    : Updated Thermal Rating: on line 3632-3628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15535
% INFO    : Updated Thermal Rating: on line 4742-3631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 4742-3630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on line 5327-3632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2951
% INFO    : Updated Thermal Rating: on line 5586-3632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2460
% INFO    : Updated Thermal Rating: on line 4470-3632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42115
% INFO    : Updated Thermal Rating: on line 3464-3632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12856
% INFO    : Updated Thermal Rating: on line 3881-3634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 5339-3636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 4102-3636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 5812-3638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1733
% INFO    : Updated Thermal Rating: on line 4073-3639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5520-3642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1759
% INFO    : Updated Thermal Rating: on line 5519-3643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1815
% INFO    : Updated Thermal Rating: on line 5655-3645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23932
% INFO    : Updated Thermal Rating: on line 4802-3647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 5573-3648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 5208-3649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2428
% INFO    : Updated Thermal Rating: on line 3532-3652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2305
% INFO    : Updated Thermal Rating: on line 3656-3652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 3860-3652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2710
% INFO    : Updated Thermal Rating: on line 3656-3652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 4174-3653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 4487-3655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 4486-3655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 5564-3659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on line 3661-3660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5241
% INFO    : Updated Thermal Rating: on line 3985-3660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2045
% INFO    : Updated Thermal Rating: on line 3985-3661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7695
% INFO    : Updated Thermal Rating: on line 5768-3663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 621
% INFO    : Updated Thermal Rating: on line 3677-3664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1413
% INFO    : Updated Thermal Rating: on line 3678-3664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 4218-3664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 3700-3666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 4436-3666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58788
% INFO    : Updated Thermal Rating: on line 5624-3666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 5481-3666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 4424-3668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1278
% INFO    : Updated Thermal Rating: on line 5197-3668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 5656-3669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2723
% INFO    : Updated Thermal Rating: on line 4688-3670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 3695-3671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 3893-3673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 4005-3675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 4161-3675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13072
% INFO    : Updated Thermal Rating: on line 4130-3679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 4557-3680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 4847-3682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on line 3311-3686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 5585-3686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 5660-3687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3062
% INFO    : Updated Thermal Rating: on line 5420-3689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 762
% INFO    : Updated Thermal Rating: on line 5661-3689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5680-3689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 4944-3689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 973
% INFO    : Updated Thermal Rating: on line 4615-3691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 4324-3696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 4607-3696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 5558-3697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 4914-3698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 4183-3701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 5445-3701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2893
% INFO    : Updated Thermal Rating: on line 4183-3701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 4232-3702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 4460-3703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5666-3704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5986
% INFO    : Updated Thermal Rating: on line 4496-3712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5613
% INFO    : Updated Thermal Rating: on line 4495-3712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1925
% INFO    : Updated Thermal Rating: on line 4180-3715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 4790-3715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 4315-3716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109898
% INFO    : Updated Thermal Rating: on line 5667-3717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 4915-3719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 5668-3720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21775
% INFO    : Updated Thermal Rating: on line 4366-3724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 5090-3728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1736
% INFO    : Updated Thermal Rating: on line 5101-3728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5670-3731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47367
% INFO    : Updated Thermal Rating: on line 4331-3732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 5669-3734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on line 5772-3733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 4267-3735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 3723-3737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10480
% INFO    : Updated Thermal Rating: on line 4429-3737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 4537-3737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 4429-3737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 3727-3739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138682
% INFO    : Updated Thermal Rating: on line 3726-3739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138682
% INFO    : Updated Thermal Rating: on line 3725-3739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123245
% INFO    : Updated Thermal Rating: on line 4795-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9077
% INFO    : Updated Thermal Rating: on line 3873-3747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29733
% INFO    : Updated Thermal Rating: on line 5403-3748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on line 5671-3751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 824
% INFO    : Updated Thermal Rating: on line 4809-3754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5672-3755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 5188-3756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 653
% INFO    : Updated Thermal Rating: on line 5436-3758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1308
% INFO    : Updated Thermal Rating: on line 4489-3759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 4526-3759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on line 5673-3763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10170
% INFO    : Updated Thermal Rating: on line 3860-3764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 3876-3764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 4716-3764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 5060-3764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 4331-3766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 5412-3767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 4389-3773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 4617-3773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 4389-3773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 5505-3774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 5836-3774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 4729-3774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 5042-3776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 4726-3795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 890
% INFO    : Updated Thermal Rating: on line 5692-3795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 4442-3796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 864
% INFO    : Updated Thermal Rating: on line 5596-3796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2081
% INFO    : Updated Thermal Rating: on line 4454-3797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 5813-3797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on line 4122-3800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 5676-3801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 4821-3803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 4823-3803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1851
% INFO    : Updated Thermal Rating: on line 4820-3803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 4079-3805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40590
% INFO    : Updated Thermal Rating: on line 4079-3804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42124
% INFO    : Updated Thermal Rating: on line 3996-3810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3801
% INFO    : Updated Thermal Rating: on line 4284-3810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 4374-3810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on line 5198-3810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5515-3810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3996-3810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3774
% INFO    : Updated Thermal Rating: on line 4909-3812 : Rate A, Rate B, Rate C , 1708.0, 1708.0, 1708.0 -> 1115
% INFO    : Updated Thermal Rating: on line 4081-3815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 3822-3816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3821-3816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3820-3816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4081-3825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 5250-3826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1495
% INFO    : Updated Thermal Rating: on line 4120-3827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 4159-3829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21022
% INFO    : Updated Thermal Rating: on line 3886-3832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 3976-3832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 773
% INFO    : Updated Thermal Rating: on line 4332-3831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on line 3975-3831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on line 4332-3832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 5065-3836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 4540-3838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 5281-3839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2711
% INFO    : Updated Thermal Rating: on line 4998-3840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 516
% INFO    : Updated Thermal Rating: on line 5091-3840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 5468-3841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 5513-3841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 5137-3843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 5680-3843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 3891-3844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 4285-3848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2168
% INFO    : Updated Thermal Rating: on line 5682-3849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1253
% INFO    : Updated Thermal Rating: on line 5451-3851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 4351-3856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 5796-3856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 5797-3855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 4970-3859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 5513-3859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on line 5684-3862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53230
% INFO    : Updated Thermal Rating: on line 5683-3861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67824
% INFO    : Updated Thermal Rating: on line 5765-3864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5685-3865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3817
% INFO    : Updated Thermal Rating: on line 4730-3868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 3876-3872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 4506-3874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 4934-3874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 5341-3874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 5686-3878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5687-3878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 4953-3879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 4953-3879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 4318-3884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 5688-3885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11206
% INFO    : Updated Thermal Rating: on line 4511-3891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 4617-3892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 5387-3892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 4255-3895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32501
% INFO    : Updated Thermal Rating: on line 5815-3897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 5626-3901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 4586-3904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 4394-3905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 4661-3908 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1811
% INFO    : Updated Thermal Rating: on line 4661-3908 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1825
% INFO    : Updated Thermal Rating: on line 4443-3911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 5531-3916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 4101-3917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 5056-3917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5237-3917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 5718-3917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 5693-3919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 4755-3920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 906
% INFO    : Updated Thermal Rating: on line 4036-3923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 5799-3923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 4832-3925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 4832-3924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 5694-3929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 4506-3931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 634
% INFO    : Updated Thermal Rating: on line 5117-3931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1971
% INFO    : Updated Thermal Rating: on line 3997-3932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7269
% INFO    : Updated Thermal Rating: on line 5740-3945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 5774-3945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 4112-3946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 5417-3952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 4015-3955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 4015-3956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4542
% INFO    : Updated Thermal Rating: on line 5272-3957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on line 3961-3960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on line 4460-3960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 5177-3960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1164
% INFO    : Updated Thermal Rating: on line 4563-3962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 4613-3965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23818
% INFO    : Updated Thermal Rating: on line 5175-3965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1301
% INFO    : Updated Thermal Rating: on line 5436-3965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 5800-3965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24046
% INFO    : Updated Thermal Rating: on line 5700-3966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 4925-3968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 969
% INFO    : Updated Thermal Rating: on line 5699-3973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 4086-3978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 4086-3978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 5326-3980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 4200-3982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 5104-3982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 5005-3983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 5702-3987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3660
% INFO    : Updated Thermal Rating: on line 4921-3989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5083-3990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 5530-3991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 4926-3993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 5703-3994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 811
% INFO    : Updated Thermal Rating: on line 5353-3995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5705-4000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2220
% INFO    : Updated Thermal Rating: on line 4699-4001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 4367-4002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 5826-4004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4315-4005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 4467-4005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3258
% INFO    : Updated Thermal Rating: on line 5505-4007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 952
% INFO    : Updated Thermal Rating: on line 4336-4009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 4370-4009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 5487-4011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on line 5246-4014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 5213-4016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5417-4022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 5489-4024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16838
% INFO    : Updated Thermal Rating: on line 5576-4024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 4607-4025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 4607-4025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 5235-4027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 4458-4031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 5153-4031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22412
% INFO    : Updated Thermal Rating: on line 4458-4031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 5152-4031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22412
% INFO    : Updated Thermal Rating: on line 4685-4032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 5710-4034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 5096-4037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 899
% INFO    : Updated Thermal Rating: on line 4900-4042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 5713-4045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23993
% INFO    : Updated Thermal Rating: on line 4379-4046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3027
% INFO    : Updated Thermal Rating: on line 5795-4046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37370
% INFO    : Updated Thermal Rating: on line 5434-4051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1772
% INFO    : Updated Thermal Rating: on line 4720-4060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 5714-4063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56492
% INFO    : Updated Thermal Rating: on line 4310-4064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 4544-4064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2672
% INFO    : Updated Thermal Rating: on line 5788-4064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2628
% INFO    : Updated Thermal Rating: on line 5715-4066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 5066-4070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 4602-4071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 5233-4071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 4231-4075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 4230-4075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 5780-4076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 4234-4081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 4378-4081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 4681-4087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 4682-4087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 4776-4088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 5717-4091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8357
% INFO    : Updated Thermal Rating: on line 5087-4093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 5854-4093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116592
% INFO    : Updated Thermal Rating: on line 5304-4098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 4618-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 4948-4100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 4934-4102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 5339-4102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 5501-4102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 4903-4108 : Rate A, Rate B, Rate C , 1659.0, 1659.0, 1659.0 -> 1386
% INFO    : Updated Thermal Rating: on line 4729-4109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5838-4111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 4449-4114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 5722-4115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 815
% INFO    : Updated Thermal Rating: on line 4931-4116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 5719-4116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 920
% INFO    : Updated Thermal Rating: on line 4119-4118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28461
% INFO    : Updated Thermal Rating: on line 4339-4120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5579-4120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 5012-4122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 5725-4131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 4247-4133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 4148-4140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 4540-4141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 5175-4143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 605
% INFO    : Updated Thermal Rating: on line 5566-4143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 5800-4143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on line 5816-4142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4237
% INFO    : Updated Thermal Rating: on line 4212-4145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 4850-4145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 5260-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8030
% INFO    : Updated Thermal Rating: on line 4849-4148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 533
% INFO    : Updated Thermal Rating: on line 5000-4150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 5796-4150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 601
% INFO    : Updated Thermal Rating: on line 5727-4154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13354
% INFO    : Updated Thermal Rating: on line 5726-4155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 793
% INFO    : Updated Thermal Rating: on line 4473-4157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 4473-4157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 4257-4158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 5728-4158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 4386-4159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16962
% INFO    : Updated Thermal Rating: on line 5729-4162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 880
% INFO    : Updated Thermal Rating: on line 5204-4165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2379
% INFO    : Updated Thermal Rating: on line 4699-4166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 518
% INFO    : Updated Thermal Rating: on line 5425-4166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 5730-4168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5531
% INFO    : Updated Thermal Rating: on line 5568-4169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 5731-4170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47067
% INFO    : Updated Thermal Rating: on line 4323-4172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 4382-4172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 5786-4172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1166
% INFO    : Updated Thermal Rating: on line 4323-4172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1125
% INFO    : Updated Thermal Rating: on line 4382-4172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 5732-4174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1105
% INFO    : Updated Thermal Rating: on line 5640-4174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2029
% INFO    : Updated Thermal Rating: on line 5391-4176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16527
% INFO    : Updated Thermal Rating: on line 5434-4176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1802
% INFO    : Updated Thermal Rating: on line 5037-4179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 4668-4180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on line 5182-4183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 5345-4183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 5631-4183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4681-4185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on line 4332-4186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 967
% INFO    : Updated Thermal Rating: on line 5735-4186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11909
% INFO    : Updated Thermal Rating: on line 4188-4187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2059
% INFO    : Updated Thermal Rating: on line 5297-4187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 5736-4191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5754-4192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 5029-4193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 4846-4196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 5155-4196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 4763-4197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22038
% INFO    : Updated Thermal Rating: on line 5194-4201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 4963-4203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on line 4963-4202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on line 4204-4205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3795
% INFO    : Updated Thermal Rating: on line 4577-4209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1421
% INFO    : Updated Thermal Rating: on line 4875-4209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 5792-4209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 5587-4214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on line 4472-4219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4678
% INFO    : Updated Thermal Rating: on line 4498-4219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2928
% INFO    : Updated Thermal Rating: on line 5220-4218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on line 4498-4219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2795
% INFO    : Updated Thermal Rating: on line 4497-4218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2932
% INFO    : Updated Thermal Rating: on line 5390-4222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 5743-4222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 5307-4228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 5371-4227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 4952-4232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 624
% INFO    : Updated Thermal Rating: on line 4351-4236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 5739-4237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 691
% INFO    : Updated Thermal Rating: on line 5458-4241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194699
% INFO    : Updated Thermal Rating: on line 4681-4243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1753
% INFO    : Updated Thermal Rating: on line 4895-4244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 5164-4244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 5409-4244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 4327-4248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 4678-4250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 5212-4249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1184
% INFO    : Updated Thermal Rating: on line 4249-4272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on line 5742-4251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 4831-4252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 4887-4252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 4741-4254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2353
% INFO    : Updated Thermal Rating: on line 4842-4257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 5410-4257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 5005-4259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 5656-4259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 4823-4260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 5182-4262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 5740-4262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 5443-4263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1183
% INFO    : Updated Thermal Rating: on line 5241-4266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 5241-4265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 5791-4269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3793
% INFO    : Updated Thermal Rating: on line 5744-4271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17958
% INFO    : Updated Thermal Rating: on line 5025-4273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 5746-4274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5716-4275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5882
% INFO    : Updated Thermal Rating: on line 5694-4278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 5763-4283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 5003-4289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 5377-4291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1485
% INFO    : Updated Thermal Rating: on line 5595-4291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 5617-4297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 5748-4298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1241
% INFO    : Updated Thermal Rating: on line 4289-4301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4118
% INFO    : Updated Thermal Rating: on line 5749-4302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9521
% INFO    : Updated Thermal Rating: on line 4322-4303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 4568-4303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 5750-4304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1432
% INFO    : Updated Thermal Rating: on line 5383-4309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1423
% INFO    : Updated Thermal Rating: on line 5537-4309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5536-4308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4311-4310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 691
% INFO    : Updated Thermal Rating: on line 5392-4312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9387
% INFO    : Updated Thermal Rating: on line 5852-4315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 5751-4321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 5539-4325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 5593-4325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 4424-4329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 478
% INFO    : Updated Thermal Rating: on line 4621-4332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 4719-4331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 5346-4331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 5347-4331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 753
% INFO    : Updated Thermal Rating: on line 5428-4332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 5688-4332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 5735-4332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1059
% INFO    : Updated Thermal Rating: on line 5733-4332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 5302-4335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4552-4344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 4550-4344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1431
% INFO    : Updated Thermal Rating: on line 4772-4346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 5756-4347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1047
% INFO    : Updated Thermal Rating: on line 4894-4348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 5075-4348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on line 5075-4348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on line 5396-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 587
% INFO    : Updated Thermal Rating: on line 5402-4351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 5781-4351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5832-4351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 5757-4354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24534
% INFO    : Updated Thermal Rating: on line 5758-4354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6566
% INFO    : Updated Thermal Rating: on line 5151-4354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 5379-4356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13344
% INFO    : Updated Thermal Rating: on line 4585-4359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 5041-4359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 5227-4359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 5418-4361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 5578-4361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 4441-4362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 4801-4363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 5239-4365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 5249-4365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 4429-4366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 4429-4366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on line 4720-4370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 4911-4371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 5197-4371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on line 5401-4372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 4489-4374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 5763-4375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10315
% INFO    : Updated Thermal Rating: on line 5258-4377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 5380-4380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 5595-4381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 5179-4384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 5817-4385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 5764-4392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 4890-4395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 5173-4402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 5121-4403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 5767-4405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23137
% INFO    : Updated Thermal Rating: on line 4590-4407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30291
% INFO    : Updated Thermal Rating: on line 4869-4412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1961
% INFO    : Updated Thermal Rating: on line 5770-4416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17466
% INFO    : Updated Thermal Rating: on line 5771-4418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65055
% INFO    : Updated Thermal Rating: on line 5009-4425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 4996-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 5771-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5312-4428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1536
% INFO    : Updated Thermal Rating: on line 5773-4430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1019
% INFO    : Updated Thermal Rating: on line 5369-4432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 4688-4434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 4878-4434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 4688-4434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 4625-4435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 4857-4437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 4964-4437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 5718-4438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2743
% INFO    : Updated Thermal Rating: on line 4675-4441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 4675-4441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 4756-4442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on line 4920-4442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 4757-4442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on line 5275-4449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1140
% INFO    : Updated Thermal Rating: on line 5775-4451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 5095-4454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 5821-4454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 4926-4457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 759
% INFO    : Updated Thermal Rating: on line 4893-4458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 5671-4458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 5152-4458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 5750-4460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 5834-4461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13494
% INFO    : Updated Thermal Rating: on line 4534-4462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1141
% INFO    : Updated Thermal Rating: on line 4635-4463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 5145-4462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 5148-4463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 4903-4465 : Rate A, Rate B, Rate C , 1711.0, 1711.0, 1711.0 -> 811
% INFO    : Updated Thermal Rating: on line 4679-4469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 705
% INFO    : Updated Thermal Rating: on line 4498-4471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8432
% INFO    : Updated Thermal Rating: on line 5778-4473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4777-4475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on line 4486-4481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2012
% INFO    : Updated Thermal Rating: on line 4488-4485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4488-4484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4488-4483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4488-4482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 5012-4489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on line 5515-4489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 4806-4491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2033
% INFO    : Updated Thermal Rating: on line 5779-4493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23415
% INFO    : Updated Thermal Rating: on line 5183-4501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1313
% INFO    : Updated Thermal Rating: on line 5256-4501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 5567-4503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 4606-4507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 4808-4511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 5260-4511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 5781-4512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 4054-4514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 4148-4514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 5248-4514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 926
% INFO    : Updated Thermal Rating: on line 5488-4519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5370-4520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 5784-4521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2280
% INFO    : Updated Thermal Rating: on line 4850-4523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 5785-4527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3667
% INFO    : Updated Thermal Rating: on line 4332-4528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 4332-4528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 647
% INFO    : Updated Thermal Rating: on line 5709-4530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 4831-4533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 4887-4533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 5282-4538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 907
% INFO    : Updated Thermal Rating: on line 5742-4540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14657
% INFO    : Updated Thermal Rating: on line 5751-4541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 5516-4543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16578
% INFO    : Updated Thermal Rating: on line 5517-4543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15848
% INFO    : Updated Thermal Rating: on line 5789-4546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1162
% INFO    : Updated Thermal Rating: on line 4574-4548 : Rate A, Rate B, Rate C , 2961.0, 2961.0, 2961.0 -> 1589
% INFO    : Updated Thermal Rating: on line 4574-4548 : Rate A, Rate B, Rate C , 2961.0, 2961.0, 2961.0 -> 1589
% INFO    : Updated Thermal Rating: on line 5395-4553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14447
% INFO    : Updated Thermal Rating: on line 5524-4555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 5700-4555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1386
% INFO    : Updated Thermal Rating: on line 5824-4555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 5825-4555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 917
% INFO    : Updated Thermal Rating: on line 5823-4574 : Rate A, Rate B, Rate C , 2450.0, 2450.0, 2450.0 -> 1390
% INFO    : Updated Thermal Rating: on line 5590-4579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3126
% INFO    : Updated Thermal Rating: on line 5636-4580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 4581-4582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on line 4799-4582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on line 5793-4582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 5795-4584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 4746-4585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 5145-4586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5268-4592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 4661-4594 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2158
% INFO    : Updated Thermal Rating: on line 4661-4593 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2153
% INFO    : Updated Thermal Rating: on line 5796-4597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13100
% INFO    : Updated Thermal Rating: on line 5798-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 5799-4603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3538
% INFO    : Updated Thermal Rating: on line 4805-4607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 5482-4607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 5587-4607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 5635-4607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1639
% INFO    : Updated Thermal Rating: on line 5738-4607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 5058-4610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4291
% INFO    : Updated Thermal Rating: on line 5638-4610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 5467-4612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 4865-4614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 5323-4614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 5476-4614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 5625-4615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 5662-4615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1573
% INFO    : Updated Thermal Rating: on line 5801-4618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on line 4642-4619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 4978-4625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 5621-4627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 5802-4628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 5528-4629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 5108-4630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 5251-4630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1393
% INFO    : Updated Thermal Rating: on line 5225-4632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 5804-4633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11206
% INFO    : Updated Thermal Rating: on line 4800-4636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 4666-4643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 853
% INFO    : Updated Thermal Rating: on line 4648-4646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 4663-4646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1350
% INFO    : Updated Thermal Rating: on line 5128-4646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 4663-4646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1334
% INFO    : Updated Thermal Rating: on line 5510-4652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13395
% INFO    : Updated Thermal Rating: on line 4792-4655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 4812-4655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5246-4658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 4744-4662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1837
% INFO    : Updated Thermal Rating: on line 5808-4664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5811-4674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 4899-4675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 5259-4678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 5141-4680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 5186-4681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 5210-4681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 5815-4684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2828
% INFO    : Updated Thermal Rating: on line 4850-4687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 5812-4688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5817-4700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on line 5819-4714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 5821-4717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11206
% INFO    : Updated Thermal Rating: on line 5144-4720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 5142-4720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 5459-4720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5352-4726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1011
% INFO    : Updated Thermal Rating: on line 5822-4728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3126
% INFO    : Updated Thermal Rating: on line 5836-4729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2122
% INFO    : Updated Thermal Rating: on line 4618-4733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245373
% INFO    : Updated Thermal Rating: on line 5833-4740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3957
% INFO    : Updated Thermal Rating: on line 5147-4746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5686-4746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 5775-4749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7065
% INFO    : Updated Thermal Rating: on line 4926-4759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 5467-4759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 5212-4764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 5627-4775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 875
% INFO    : Updated Thermal Rating: on line 5549-4778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1106
% INFO    : Updated Thermal Rating: on line 4808-4780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 985
% INFO    : Updated Thermal Rating: on line 5375-4782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5669-4782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 5174-4784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5827-4785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 5679-4787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 5324-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 4812-4791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 5284-4791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8426
% INFO    : Updated Thermal Rating: on line 5238-4793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 5828-4797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2647
% INFO    : Updated Thermal Rating: on line 5660-4799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 4921-4801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 4921-4801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 4993-4802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59
% INFO    : Updated Thermal Rating: on line 5830-4804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 5635-4805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on line 5535-4807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 5199-4809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5807
% INFO    : Updated Thermal Rating: on line 5780-4809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 5299-4813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5308-4814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 5077-4827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 5315-4827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on line 5413-4827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 5499-4827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1155
% INFO    : Updated Thermal Rating: on line 5000-4835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2535
% INFO    : Updated Thermal Rating: on line 5000-4835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3804
% INFO    : Updated Thermal Rating: on line 5729-4837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 4900-4839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 5812-4843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1082
% INFO    : Updated Thermal Rating: on line 4967-4845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 5798-4845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 4967-4845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 5155-4846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 612
% INFO    : Updated Thermal Rating: on line 4889-4850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 4851-4852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10572
% INFO    : Updated Thermal Rating: on line 5810-4852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 5840-4852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 5514-4862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 5137-4864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 5593-4864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 5833-4867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23430
% INFO    : Updated Thermal Rating: on line 4900-4872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 4900-4873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 5253-4874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1213
% INFO    : Updated Thermal Rating: on line 5083-4878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 5837-4897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5627-4900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 5240-4904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23932
% INFO    : Updated Thermal Rating: on line 5838-4905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3033
% INFO    : Updated Thermal Rating: on line 5171-4906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 5424-4915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 4940-4915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 5703-4926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on line 5728-4926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 5789-4926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 4929-4928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5839-4931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116592
% INFO    : Updated Thermal Rating: on line 5672-4943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5840-4946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9817
% INFO    : Updated Thermal Rating: on line 5099-4952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on line 5589-4956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 826
% INFO    : Updated Thermal Rating: on line 5639-4956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on line 5710-4956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 5486-4961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 449
% INFO    : Updated Thermal Rating: on line 5285-4963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 556
% INFO    : Updated Thermal Rating: on line 5454-4963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 5841-4964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 5842-4965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2174
% INFO    : Updated Thermal Rating: on line 5161-4967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1435
% INFO    : Updated Thermal Rating: on line 5162-4967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 5468-4970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 5313-4971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 5843-4972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12855
% INFO    : Updated Thermal Rating: on line 5842-4973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5163-4979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 5550-4983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 793
% INFO    : Updated Thermal Rating: on line 4991-4989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4991-4988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4992-4987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 5247-4994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5258-4994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 5832-5000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2438
% INFO    : Updated Thermal Rating: on line 5844-5002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 5609-5003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 5654-5003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1562
% INFO    : Updated Thermal Rating: on line 5397-5003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1449
% INFO    : Updated Thermal Rating: on line 5656-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 5783-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 5749-5007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 5300-5008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 5632-5009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 5845-5013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1478
% INFO    : Updated Thermal Rating: on line 5846-5016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3024
% INFO    : Updated Thermal Rating: on line 5847-5016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2864
% INFO    : Updated Thermal Rating: on line 5548-5020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5097-5021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 5679-5027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9602
% INFO    : Updated Thermal Rating: on line 5662-5029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 5848-5030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5261-5033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 5143-5034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8991
% INFO    : Updated Thermal Rating: on line 5089-5036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 5245-5038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 5809-5039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 5649-5045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13450
% INFO    : Updated Thermal Rating: on line 4990-5050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 894
% INFO    : Updated Thermal Rating: on line 5767-5050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 5522-5054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 5071-5063 : Rate A, Rate B, Rate C , 2275.0, 2275.0, 2275.0 -> 2203
% INFO    : Updated Thermal Rating: on line 5491-5076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 5342-5078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 5853-5078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 591
% INFO    : Updated Thermal Rating: on line 5852-5084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 478
% INFO    : Updated Thermal Rating: on line 5855-5088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24046
% INFO    : Updated Thermal Rating: on line 5773-5093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 5360-5106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 5553-5106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 5753-5114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 5583-5119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3790
% INFO    : Updated Thermal Rating: on line 5399-5127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 5151-5133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 5605-5134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5965
% INFO    : Updated Thermal Rating: on line 5757-5165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 5758-5166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 5289-5174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5855-5200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on line 5231-5208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 554
% INFO    : Updated Thermal Rating: on line 5499-5215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3545
% INFO    : Updated Thermal Rating: on line 5348-5216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 5450-5223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 5715-5224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11707
% INFO    : Updated Thermal Rating: on line 5293-5280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37051
% INFO    : Updated Thermal Rating: on line 5242-5298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 5437-5359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 5597-5363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on line 5722-5379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 875
% INFO    : Updated Thermal Rating: on line 5611-5397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1273
% INFO    : Updated Thermal Rating: on line 5503-5412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2284
% INFO    : Updated Thermal Rating: on line 5747-5420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 5557-5433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3270
% INFO    : Updated Thermal Rating: on line 5452-5693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on line 5653-5476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1451
% INFO    : Updated Thermal Rating: on line 5584-5478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2052
% INFO    : Updated Thermal Rating: on line 5732-5489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 5554-5497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 5253-5509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 5668-5509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1264
% INFO    : Updated Thermal Rating: on line 5785-5510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6303
% INFO    : Updated Thermal Rating: on line 5590-5523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 5824-5526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 5453-5543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 926
% INFO    : Updated Thermal Rating: on line 5574-5634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 5600-5602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 5612-5610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247105
% INFO    : Updated Thermal Rating: on line 5769-5620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5640-5642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9287
% INFO    : Updated Thermal Rating: on line 5817-5652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 5765-5681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on line 5841-5755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 5843-5785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6303
% INFO    : Updated Thermal Rating: on line 6067-5958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4105
% INFO    : Updated Thermal Rating: on line 6055-5959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7982
% INFO    : Updated Thermal Rating: on line 6087-5959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3115
% INFO    : Updated Thermal Rating: on line 5963-5960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2274
% INFO    : Updated Thermal Rating: on line 5963-5960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2274
% INFO    : Updated Thermal Rating: on line 6123-5960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2843
% INFO    : Updated Thermal Rating: on line 6131-5960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2276
% INFO    : Updated Thermal Rating: on line 6151-5960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2213
% INFO    : Updated Thermal Rating: on line 4417-5961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10754
% INFO    : Updated Thermal Rating: on line 6082-5962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4531
% INFO    : Updated Thermal Rating: on line 6082-5962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4569
% INFO    : Updated Thermal Rating: on line 6223-5963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4405
% INFO    : Updated Thermal Rating: on line 6223-5963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4405
% INFO    : Updated Thermal Rating: on line 6059-5964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3541
% INFO    : Updated Thermal Rating: on line 6096-5964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6894
% INFO    : Updated Thermal Rating: on line 6102-5964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6513
% INFO    : Updated Thermal Rating: on line 5995-5967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1587
% INFO    : Updated Thermal Rating: on line 6166-5969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 6222-5969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1525
% INFO    : Updated Thermal Rating: on line 6239-5969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12439
% INFO    : Updated Thermal Rating: on line 6083-5970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5723
% INFO    : Updated Thermal Rating: on line 6170-5971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2067
% INFO    : Updated Thermal Rating: on line 6038-5972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 6069-5972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 6245-5972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 6254-5972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 6070-5973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 6075-5973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2773
% INFO    : Updated Thermal Rating: on line 6194-5973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1500
% INFO    : Updated Thermal Rating: on line 6156-5974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3141
% INFO    : Updated Thermal Rating: on line 5986-5975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2839
% INFO    : Updated Thermal Rating: on line 6166-5976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3084
% INFO    : Updated Thermal Rating: on line 6052-5977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1009
% INFO    : Updated Thermal Rating: on line 6172-5977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9134
% INFO    : Updated Thermal Rating: on line 6155-5978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6619
% INFO    : Updated Thermal Rating: on line 6176-5978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5050
% INFO    : Updated Thermal Rating: on line 6189-5979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1634
% INFO    : Updated Thermal Rating: on line 2668-5980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 976
% INFO    : Updated Thermal Rating: on line 6088-5981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1890
% INFO    : Updated Thermal Rating: on line 6233-5981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on line 6234-5982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4495
% INFO    : Updated Thermal Rating: on line 6101-5983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10163
% INFO    : Updated Thermal Rating: on line 6215-5983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15043
% INFO    : Updated Thermal Rating: on line 6018-5985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 6018-5984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 6134-5985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1230
% INFO    : Updated Thermal Rating: on line 6141-5984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1064
% INFO    : Updated Thermal Rating: on line 6178-5987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2943
% INFO    : Updated Thermal Rating: on line 6118-5988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8717
% INFO    : Updated Thermal Rating: on line 6197-5988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5512
% INFO    : Updated Thermal Rating: on line 6056-5989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1784
% INFO    : Updated Thermal Rating: on line 6134-5990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1172
% INFO    : Updated Thermal Rating: on line 6191-5990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on line 5997-5991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6412
% INFO    : Updated Thermal Rating: on line 6029-5992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4239
% INFO    : Updated Thermal Rating: on line 6113-5992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3048
% INFO    : Updated Thermal Rating: on line 6197-5993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on line 5856-5994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10739
% INFO    : Updated Thermal Rating: on line 5870-5994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9685
% INFO    : Updated Thermal Rating: on line 5869-5994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9522
% INFO    : Updated Thermal Rating: on line 6017-5994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3201
% INFO    : Updated Thermal Rating: on line 6011-5995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76420
% INFO    : Updated Thermal Rating: on line 6010-5995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76420
% INFO    : Updated Thermal Rating: on line 6067-5995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3417
% INFO    : Updated Thermal Rating: on line 6067-5995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3571
% INFO    : Updated Thermal Rating: on line 6250-5996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 5863-5998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on line 6001-6000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 6247-6000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1371
% INFO    : Updated Thermal Rating: on line 799-6004 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1033
% INFO    : Updated Thermal Rating: on line 6073-6003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1140
% INFO    : Updated Thermal Rating: on line 6134-6003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 6166-6003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13437
% INFO    : Updated Thermal Rating: on line 6166-6003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10336
% INFO    : Updated Thermal Rating: on line 6166-6003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10336
% INFO    : Updated Thermal Rating: on line 6133-6005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4661
% INFO    : Updated Thermal Rating: on line 6165-6005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4902
% INFO    : Updated Thermal Rating: on line 6222-6005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1460
% INFO    : Updated Thermal Rating: on line 6172-6006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on line 6191-6006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3569
% INFO    : Updated Thermal Rating: on line 6165-6009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5656
% INFO    : Updated Thermal Rating: on line 6239-6009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4356
% INFO    : Updated Thermal Rating: on line 6144-6012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4032
% INFO    : Updated Thermal Rating: on line 6179-6012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1383
% INFO    : Updated Thermal Rating: on line 6052-6014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3568
% INFO    : Updated Thermal Rating: on line 6172-6014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1333
% INFO    : Updated Thermal Rating: on line 6137-6015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2974
% INFO    : Updated Thermal Rating: on line 6137-6015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2981
% INFO    : Updated Thermal Rating: on line 6187-6015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21158
% INFO    : Updated Thermal Rating: on line 6187-6015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21158
% INFO    : Updated Thermal Rating: on line 1761-6016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 5473-6016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 5856-6017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4529
% INFO    : Updated Thermal Rating: on line 6003-6018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1598
% INFO    : Updated Thermal Rating: on line 6003-6018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1598
% INFO    : Updated Thermal Rating: on line 6217-6019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2833
% INFO    : Updated Thermal Rating: on line 6236-6019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4876
% INFO    : Updated Thermal Rating: on line 6240-6019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19968
% INFO    : Updated Thermal Rating: on line 5859-6026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9771
% INFO    : Updated Thermal Rating: on line 5858-6026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9748
% INFO    : Updated Thermal Rating: on line 6071-6027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 6072-6027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 6173-6027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 6092-6028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3080
% INFO    : Updated Thermal Rating: on line 6105-6028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3518
% INFO    : Updated Thermal Rating: on line 6105-6028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3518
% INFO    : Updated Thermal Rating: on line 6114-6029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1781
% INFO    : Updated Thermal Rating: on line 5856-6032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12590
% INFO    : Updated Thermal Rating: on line 5857-6033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12649
% INFO    : Updated Thermal Rating: on line 6077-6035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 6078-6034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 6250-6035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1551
% INFO    : Updated Thermal Rating: on line 6249-6034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on line 6095-6036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2357
% INFO    : Updated Thermal Rating: on line 6114-6037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3645
% INFO    : Updated Thermal Rating: on line 6113-6037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3645
% INFO    : Updated Thermal Rating: on line 6074-6038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 6086-6038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2624
% INFO    : Updated Thermal Rating: on line 6244-6038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 956
% INFO    : Updated Thermal Rating: on line 5859-6041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9186
% INFO    : Updated Thermal Rating: on line 5858-6041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9482
% INFO    : Updated Thermal Rating: on line 6221-6042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8417
% INFO    : Updated Thermal Rating: on line 6105-6044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8447
% INFO    : Updated Thermal Rating: on line 6105-6044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8447
% INFO    : Updated Thermal Rating: on line 6255-6044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5644
% INFO    : Updated Thermal Rating: on line 6255-6044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5644
% INFO    : Updated Thermal Rating: on line 5864-6045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4327
% INFO    : Updated Thermal Rating: on line 6235-6045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1315
% INFO    : Updated Thermal Rating: on line 6122-6047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 6154-6047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 6214-6047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50827
% INFO    : Updated Thermal Rating: on line 6160-6049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12717
% INFO    : Updated Thermal Rating: on line 6211-6049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7215
% INFO    : Updated Thermal Rating: on line 6057-6051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4573
% INFO    : Updated Thermal Rating: on line 6147-6051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 6170-6051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1767
% INFO    : Updated Thermal Rating: on line 6195-6051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2456
% INFO    : Updated Thermal Rating: on line 6230-6052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5222
% INFO    : Updated Thermal Rating: on line 6230-6052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5222
% INFO    : Updated Thermal Rating: on line 6252-6056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2681
% INFO    : Updated Thermal Rating: on line 6153-6057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5467
% INFO    : Updated Thermal Rating: on line 6062-6061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 6062-6060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 6211-6061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1674
% INFO    : Updated Thermal Rating: on line 6211-6060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1674
% INFO    : Updated Thermal Rating: on line 6128-6062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1664
% INFO    : Updated Thermal Rating: on line 6128-6062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1664
% INFO    : Updated Thermal Rating: on line 6071-6066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 6147-6066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 6162-6066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 6241-6066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 6074-6068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 6084-6070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3035
% INFO    : Updated Thermal Rating: on line 6084-6070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8841
% INFO    : Updated Thermal Rating: on line 6131-6070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 873
% INFO    : Updated Thermal Rating: on line 6213-6070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 6072-6071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 6183-6071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 6201-6072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29308
% INFO    : Updated Thermal Rating: on line 6134-6073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 6243-6074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 6254-6074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 6122-6076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 6150-6076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1469
% INFO    : Updated Thermal Rating: on line 6099-6077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2790
% INFO    : Updated Thermal Rating: on line 6100-6078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2813
% INFO    : Updated Thermal Rating: on line 6134-6079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1926
% INFO    : Updated Thermal Rating: on line 6191-6079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 6255-6080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3003
% INFO    : Updated Thermal Rating: on line 6255-6080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3003
% INFO    : Updated Thermal Rating: on line 6241-6081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2050
% INFO    : Updated Thermal Rating: on line 6086-6082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1413
% INFO    : Updated Thermal Rating: on line 6086-6082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1349
% INFO    : Updated Thermal Rating: on line 6159-6084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 6177-6084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on line 6213-6084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1408
% INFO    : Updated Thermal Rating: on line 6237-6084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2393
% INFO    : Updated Thermal Rating: on line 6162-6085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14302
% INFO    : Updated Thermal Rating: on line 6144-6086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on line 6144-6086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 899
% INFO    : Updated Thermal Rating: on line 6254-6086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8735
% INFO    : Updated Thermal Rating: on line 6233-6088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on line 6152-6090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344932
% INFO    : Updated Thermal Rating: on line 6152-6090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344932
% INFO    : Updated Thermal Rating: on line 6152-6089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199349
% INFO    : Updated Thermal Rating: on line 6152-6089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344932
% INFO    : Updated Thermal Rating: on line 5860-6091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222473
% INFO    : Updated Thermal Rating: on line 6143-6092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2451
% INFO    : Updated Thermal Rating: on line 6098-6093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5070
% INFO    : Updated Thermal Rating: on line 5861-6097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252116
% INFO    : Updated Thermal Rating: on line 6108-6098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 807
% INFO    : Updated Thermal Rating: on line 6141-6099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1454
% INFO    : Updated Thermal Rating: on line 6215-6101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6883
% INFO    : Updated Thermal Rating: on line 6133-6106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 650
% INFO    : Updated Thermal Rating: on line 6222-6106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 6134-6108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 935
% INFO    : Updated Thermal Rating: on line 6119-6110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11258
% INFO    : Updated Thermal Rating: on line 6125-6109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7176
% INFO    : Updated Thermal Rating: on line 6125-6110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7176
% INFO    : Updated Thermal Rating: on line 6151-6115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1703
% INFO    : Updated Thermal Rating: on line 6213-6115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on line 6158-6116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2832
% INFO    : Updated Thermal Rating: on line 6248-6116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2522
% INFO    : Updated Thermal Rating: on line 6123-6117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7514
% INFO    : Updated Thermal Rating: on line 6125-6119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4297
% INFO    : Updated Thermal Rating: on line 6135-6124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4371
% INFO    : Updated Thermal Rating: on line 6219-6124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6641
% INFO    : Updated Thermal Rating: on line 5863-6127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345173
% INFO    : Updated Thermal Rating: on line 6221-6127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9695
% INFO    : Updated Thermal Rating: on line 6130-6128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3213
% INFO    : Updated Thermal Rating: on line 6160-6130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2708
% INFO    : Updated Thermal Rating: on line 5864-6132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17394
% INFO    : Updated Thermal Rating: on line 6193-6132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1355
% INFO    : Updated Thermal Rating: on line 6235-6132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1693
% INFO    : Updated Thermal Rating: on line 6156-6134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2638
% INFO    : Updated Thermal Rating: on line 6145-6138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4262
% INFO    : Updated Thermal Rating: on line 6221-6138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2064
% INFO    : Updated Thermal Rating: on line 5865-6139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240858
% INFO    : Updated Thermal Rating: on line 6183-6140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4379
% INFO    : Updated Thermal Rating: on line 6183-6140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4379
% INFO    : Updated Thermal Rating: on line 6186-6142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 6221-6145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4013
% INFO    : Updated Thermal Rating: on line 6170-6147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 6162-6152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2696
% INFO    : Updated Thermal Rating: on line 6162-6152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2698
% INFO    : Updated Thermal Rating: on line 6195-6153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5431
% INFO    : Updated Thermal Rating: on line 6185-6155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3809
% INFO    : Updated Thermal Rating: on line 6185-6155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3817
% INFO    : Updated Thermal Rating: on line 6177-6159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3007
% INFO    : Updated Thermal Rating: on line 6213-6159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3983
% INFO    : Updated Thermal Rating: on line 6223-6159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 6183-6162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 6241-6162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 2240-6164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1752
% INFO    : Updated Thermal Rating: on line 6191-6166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1767
% INFO    : Updated Thermal Rating: on line 6222-6166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 761
% INFO    : Updated Thermal Rating: on line 5867-6171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69049
% INFO    : Updated Thermal Rating: on line 36-6206 : Rate A, Rate B, Rate C , 1559.0, 1559.0, 1559.0 -> 873
% INFO    : Updated Thermal Rating: on line 35-6205 : Rate A, Rate B, Rate C , 1559.0, 1559.0, 1559.0 -> 947
% INFO    : Updated Thermal Rating: on line 6226-6172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4262
% INFO    : Updated Thermal Rating: on line 6232-6172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1343
% INFO    : Updated Thermal Rating: on line 6206-6175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245589
% INFO    : Updated Thermal Rating: on line 6217-6175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8451
% INFO    : Updated Thermal Rating: on line 6213-6177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43571
% INFO    : Updated Thermal Rating: on line 6179-6178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 624
% INFO    : Updated Thermal Rating: on line 6214-6178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on line 5864-6182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 922
% INFO    : Updated Thermal Rating: on line 6194-6187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2346
% INFO    : Updated Thermal Rating: on line 5866-6189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3404
% INFO    : Updated Thermal Rating: on line 6232-6191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3347
% INFO    : Updated Thermal Rating: on line 6235-6193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 743
% INFO    : Updated Thermal Rating: on line 5859-6220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3368
% INFO    : Updated Thermal Rating: on line 5858-6220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3374
% INFO    : Updated Thermal Rating: on line 5863-6221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9679
% INFO    : Updated Thermal Rating: on line 6230-6226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1035
% INFO    : Updated Thermal Rating: on line 5870-6229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7175
% INFO    : Updated Thermal Rating: on line 5869-6228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6972
% INFO    : Updated Thermal Rating: on line 325-6234 : Rate A, Rate B, Rate C , 1624.0, 1624.0, 1624.0 -> 1498
% INFO    : Updated Thermal Rating: on line 5871-6238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12963
% INFO    : Updated Thermal Rating: on line 6254-6242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on transformer 26-27 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 26-27 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 26-27 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 31-33 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 31-34 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 32-33 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 35-5900 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1111
% INFO    : Updated Thermal Rating: on line 35-5924 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1111
% INFO    : Updated Thermal Rating: on transformer 50-51 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 50-51 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 50-51 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 103-104 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 103-104 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 109-110 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 109-110 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 112-113 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 112-113 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 112-113 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 128-130 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 129-130 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 137-138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 139-140 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 142-143 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 142-143 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 144-145 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 285
% INFO    : Updated Thermal Rating: on transformer 144-146 : Rate A, Rate B, Rate C , 712.0, 712.0, 712.0 -> 201
% INFO    : Updated Thermal Rating: on transformer 144-146 : Rate A, Rate B, Rate C , 712.0, 712.0, 712.0 -> 201
% INFO    : Updated Thermal Rating: on line 146-5872 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1094
% INFO    : Updated Thermal Rating: on line 146-5925 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1070
% INFO    : Updated Thermal Rating: on transformer 156-152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on transformer 153-154 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 324
% INFO    : Updated Thermal Rating: on transformer 157-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 165-168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 166-168 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 166-168 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 166-168 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 167-168 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 171-172 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 171-172 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 180-5901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on transformer 181-5926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 183-5901 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 303
% INFO    : Updated Thermal Rating: on line 183-5926 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 205-206 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 346
% INFO    : Updated Thermal Rating: on transformer 205-206 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 346
% INFO    : Updated Thermal Rating: on transformer 216-217 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 216-217 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 216-217 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 223-224 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 235-236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 248-249 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 258-259 : Rate A, Rate B, Rate C , 459.0, 459.0, 459.0 -> 292
% INFO    : Updated Thermal Rating: on transformer 261-262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 261-262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 274-275 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 274-275 : Rate A, Rate B, Rate C , 447.0, 447.0, 447.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 279-280 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 279-280 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 315-316 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 315-316 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 323-325 : Rate A, Rate B, Rate C , 1020.0, 1020.0, 1020.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 323-325 : Rate A, Rate B, Rate C , 1627.0, 1627.0, 1627.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 323-325 : Rate A, Rate B, Rate C , 1016.0, 1016.0, 1016.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 328-329 : Rate A, Rate B, Rate C , 433.0, 433.0, 433.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 328-329 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 332-333 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 332-333 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 344-345 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 362-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 362-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 362-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 362-364 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 380-381 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 380-381 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 423-424 : Rate A, Rate B, Rate C , 721.0, 721.0, 721.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 423-424 : Rate A, Rate B, Rate C , 721.0, 721.0, 721.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 425-426 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 425-426 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 425-426 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 446-447 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 444-447 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 445-447 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 449-450 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 449-450 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 453-454 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 453-454 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 458-459 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 266
% INFO    : Updated Thermal Rating: on line 460-5873 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1169
% INFO    : Updated Thermal Rating: on line 460-5902 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1087
% INFO    : Updated Thermal Rating: on transformer 465-466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on transformer 479-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on transformer 481-482 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 481-482 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 481-482 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 505-506 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 505-506 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 520-522 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 521-522 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 525-526 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 525-526 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 525-526 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 533-534 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 533-534 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 267
% INFO    : Updated Thermal Rating: on transformer 533-534 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 542-543 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 549-550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 562-563 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 601-602 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 601-602 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 606-607 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 606-607 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 609-610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 626-627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 652-653 : Rate A, Rate B, Rate C , 721.0, 721.0, 721.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 652-653 : Rate A, Rate B, Rate C , 718.0, 718.0, 718.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 667-668 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 676-677 : Rate A, Rate B, Rate C , 530.0, 530.0, 530.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 694-695 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 694-695 : Rate A, Rate B, Rate C , 300.0, 300.0, 300.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 696-699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 697-699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 698-700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 701-703 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 701-703 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 708-711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 707-711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 706-711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 710-711 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 709-711 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 709-711 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 724-726 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 725-726 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 724-726 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 741-742 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 741-742 : Rate A, Rate B, Rate C , 445.0, 445.0, 445.0 -> 252
% INFO    : Updated Thermal Rating: on line 754-5874 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1169
% INFO    : Updated Thermal Rating: on line 754-5904 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1087
% INFO    : Updated Thermal Rating: on transformer 761-762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 767-768 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 767-768 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 767-768 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 769-772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 770-772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 771-772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 775-776 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 786-787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 785-788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 787-789 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 788-789 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 798-799 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 802-804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 801-804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 800-803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 848-849 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 848-849 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 848-849 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 851-852 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 851-852 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 852-853 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 566
% INFO    : Updated Thermal Rating: on transformer 879-881 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 880-881 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 879-881 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 889-890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 914-5905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 924-925 : Rate A, Rate B, Rate C , 1629.0, 1629.0, 1629.0 -> 320
% INFO    : Updated Thermal Rating: on transformer 924-925 : Rate A, Rate B, Rate C , 1629.0, 1629.0, 1629.0 -> 320
% INFO    : Updated Thermal Rating: on transformer 934-5928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on transformer 933-5942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on transformer 932-5952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 939-5928 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 894
% INFO    : Updated Thermal Rating: on line 938-5942 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 974
% INFO    : Updated Thermal Rating: on line 939-5952 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 987
% INFO    : Updated Thermal Rating: on transformer 941-942 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 941-942 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 941-942 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 952-953 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 952-953 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 957-958 : Rate A, Rate B, Rate C , 1627.0, 1627.0, 1627.0 -> 320
% INFO    : Updated Thermal Rating: on transformer 957-958 : Rate A, Rate B, Rate C , 1627.0, 1627.0, 1627.0 -> 318
% INFO    : Updated Thermal Rating: on transformer 964-965 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 337
% INFO    : Updated Thermal Rating: on transformer 964-965 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 332
% INFO    : Updated Thermal Rating: on transformer 964-965 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 965-967 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1178
% INFO    : Updated Thermal Rating: on transformer 969-970 : Rate A, Rate B, Rate C , 639.0, 639.0, 639.0 -> 137
% INFO    : Updated Thermal Rating: on transformer 969-970 : Rate A, Rate B, Rate C , 639.0, 639.0, 639.0 -> 137
% INFO    : Updated Thermal Rating: on transformer 969-970 : Rate A, Rate B, Rate C , 639.0, 639.0, 639.0 -> 137
% INFO    : Updated Thermal Rating: on transformer 972-973 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 972-973 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 978-979 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 978-979 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 980-981 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 220
% INFO    : Updated Thermal Rating: on transformer 992-994 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 291
% INFO    : Updated Thermal Rating: on transformer 992-994 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 1000-1001 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 999-5877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on transformer 1000-1002 : Rate A, Rate B, Rate C , 1627.0, 1627.0, 1627.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 1000-1002 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 1015-1016 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1015-1016 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1030-1032 : Rate A, Rate B, Rate C , 445.0, 445.0, 445.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 1037-1038 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 1037-1038 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1038-1039 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1168
% INFO    : Updated Thermal Rating: on transformer 1038-1039 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1165
% INFO    : Updated Thermal Rating: on line 1041-5929 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 959
% INFO    : Updated Thermal Rating: on transformer 1045-1046 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1045-1046 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1044-1046 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 1062-1063 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1062-1063 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 1062-1063 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1062-1063 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1067-1068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 1067-1068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on transformer 1067-1068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 1075-1076 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1162
% INFO    : Updated Thermal Rating: on transformer 1075-1076 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1159
% INFO    : Updated Thermal Rating: on line 1076-5930 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 985
% INFO    : Updated Thermal Rating: on transformer 1077-1078 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1077-1078 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1091-1092 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 1112-1113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 1115-1116 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1115-1116 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1134-1135 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 1134-1135 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1140-1142 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 1141-1142 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 1145-1146 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 1145-1146 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 233
% INFO    : Updated Thermal Rating: on transformer 1149-1150 : Rate A, Rate B, Rate C , 1038.0, 1038.0, 1038.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 1156-1157 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1156-1157 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 1155-1157 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 190
% INFO    : Updated Thermal Rating: on transformer 1163-1166 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 311
% INFO    : Updated Thermal Rating: on transformer 1164-1166 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 1165-1166 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 1173-1174 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 331
% INFO    : Updated Thermal Rating: on transformer 1173-1174 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 1173-1174 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 334
% INFO    : Updated Thermal Rating: on transformer 1173-1174 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 1194-1195 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1193-1195 : Rate A, Rate B, Rate C , 466.0, 466.0, 466.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 1194-1196 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1198-1199 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1165
% INFO    : Updated Thermal Rating: on transformer 1198-1199 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1153
% INFO    : Updated Thermal Rating: on transformer 1201-1202 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 1201-1202 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1207-1208 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1207-1208 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1210-1211 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 1210-1211 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1210-1211 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1228-1229 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 1236-1235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6597
% INFO    : Updated Thermal Rating: on transformer 1238-1240 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 1237-1240 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 241
% INFO    : Updated Thermal Rating: on transformer 1238-1241 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1243-1244 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 1246-1247 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 1246-1247 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 1246-1247 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 1248-1249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on transformer 1248-1249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on transformer 1250-1251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 1257-1258 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1257-1258 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 1262-1264 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 1263-1264 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1262-1264 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1307-1309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 1308-1309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 1324-1325 : Rate A, Rate B, Rate C , 438.0, 438.0, 438.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1324-1325 : Rate A, Rate B, Rate C , 316.0, 316.0, 316.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 1331-1332 : Rate A, Rate B, Rate C , 310.0, 310.0, 310.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1331-1332 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1334-1335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 1342-1343 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 267
% INFO    : Updated Thermal Rating: on transformer 1344-1345 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1344-1345 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 283
% INFO    : Updated Thermal Rating: on transformer 1348-1349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1356-1357 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 338
% INFO    : Updated Thermal Rating: on transformer 1356-1357 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 332
% INFO    : Updated Thermal Rating: on transformer 1356-1357 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 330
% INFO    : Updated Thermal Rating: on transformer 1358-1359 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 182
% INFO    : Updated Thermal Rating: on transformer 1358-1359 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 183
% INFO    : Updated Thermal Rating: on transformer 1358-1359 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 182
% INFO    : Updated Thermal Rating: on transformer 1378-1379 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 1384-1385 : Rate A, Rate B, Rate C , 729.0, 729.0, 729.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1384-1385 : Rate A, Rate B, Rate C , 721.0, 721.0, 721.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 1384-1385 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1405-1406 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1407-1409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 1408-1409 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1408-1409 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1432-1433 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 1432-1433 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 1439-1440 : Rate A, Rate B, Rate C , 740.0, 740.0, 740.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1439-1440 : Rate A, Rate B, Rate C , 740.0, 740.0, 740.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1443-1444 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 1442-1444 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1454-1455 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 210
% INFO    : Updated Thermal Rating: on transformer 1457-1458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 1460-1461 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1460-1461 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 250
% INFO    : Updated Thermal Rating: on line 1462-5878 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1041
% INFO    : Updated Thermal Rating: on transformer 1463-1464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on transformer 1463-1465 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 280
% INFO    : Updated Thermal Rating: on transformer 1463-1465 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 279
% INFO    : Updated Thermal Rating: on transformer 1471-1472 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 1471-1472 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 1477-1478 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 1477-1478 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 1483-1485 : Rate A, Rate B, Rate C , 545.0, 545.0, 545.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 1501-1502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1516-1517 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 343
% INFO    : Updated Thermal Rating: on transformer 1516-1517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 1516-1517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 1517-1518 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1153
% INFO    : Updated Thermal Rating: on transformer 1517-1518 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1145
% INFO    : Updated Thermal Rating: on transformer 1523-1525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on transformer 1522-1525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 1521-1524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on transformer 1520-1524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 1526-1527 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1526-1527 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1533-1535 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1534-1535 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1533-1535 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1533-1536 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 316
% INFO    : Updated Thermal Rating: on line 1536-5943 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1016
% INFO    : Updated Thermal Rating: on line 1536-5954 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1039
% INFO    : Updated Thermal Rating: on transformer 1543-1544 : Rate A, Rate B, Rate C , 530.0, 530.0, 530.0 -> 305
% INFO    : Updated Thermal Rating: on transformer 1543-1544 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 305
% INFO    : Updated Thermal Rating: on transformer 1564-1565 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 1564-1565 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1564-1565 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 283
% INFO    : Updated Thermal Rating: on transformer 1588-1589 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 1588-1589 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1598-1600 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1599-1600 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 1597-5879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 1601-5879 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 999
% INFO    : Updated Thermal Rating: on transformer 1602-1603 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 1602-1603 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1602-1604 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 1614-1615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 1614-1615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on transformer 1617-1618 : Rate A, Rate B, Rate C , 428.0, 428.0, 428.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1616-1618 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1616-1618 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 1620-1621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 1638-1639 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1638-1639 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1638-1639 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1669-1670 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 1669-1670 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 1673-1674 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 1673-1674 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1682-1683 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1682-1683 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 1689-1690 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 1689-1690 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 1708-1711 : Rate A, Rate B, Rate C , 482.0, 482.0, 482.0 -> 279
% INFO    : Updated Thermal Rating: on transformer 1709-1713 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 1709-1710 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1708-1712 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 287
% INFO    : Updated Thermal Rating: on transformer 1717-1718 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 1717-1718 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 283
% INFO    : Updated Thermal Rating: on transformer 1722-1723 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1722-1723 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 1728-1729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 1735-1736 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 1735-1736 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1748-1751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 1747-1750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 1746-1749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 1752-1754 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1753-1754 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 1775-1778 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 1776-1778 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 1777-1778 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 1777-1778 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1777-1778 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 1780-1781 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 308
% INFO    : Updated Thermal Rating: on transformer 1780-1781 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 308
% INFO    : Updated Thermal Rating: on transformer 1780-1781 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 293
% INFO    : Updated Thermal Rating: on transformer 1785-1786 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1785-1786 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1791-1792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 1791-1793 : Rate A, Rate B, Rate C , 310.0, 310.0, 310.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 1791-1793 : Rate A, Rate B, Rate C , 442.0, 442.0, 442.0 -> 291
% INFO    : Updated Thermal Rating: on transformer 1791-1793 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1792-1793 : Rate A, Rate B, Rate C , 301.0, 301.0, 301.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 1794-1795 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 1794-1795 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1803-1804 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1810-1811 : Rate A, Rate B, Rate C , 557.0, 557.0, 557.0 -> 212
% INFO    : Updated Thermal Rating: on transformer 1810-1811 : Rate A, Rate B, Rate C , 579.0, 579.0, 579.0 -> 208
% INFO    : Updated Thermal Rating: on transformer 1822-1823 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1822-1823 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1826-1827 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1831-1832 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1831-1832 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1837-1838 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1837-1838 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 1842-1843 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 1842-1843 : Rate A, Rate B, Rate C , 448.0, 448.0, 448.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 1882-1883 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1896-1900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1895-1899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1894-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1893-1897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1903-1904 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 1903-1904 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1905-1906 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1912-1913 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1912-1913 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1927-1928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 1927-1928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on transformer 1929-1930 : Rate A, Rate B, Rate C , 717.0, 717.0, 717.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 1933-5908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 1935-5908 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1158
% INFO    : Updated Thermal Rating: on transformer 1936-1937 : Rate A, Rate B, Rate C , 1011.0, 1011.0, 1011.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 1942-1944 : Rate A, Rate B, Rate C , 315.0, 315.0, 315.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 1942-1945 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 323
% INFO    : Updated Thermal Rating: on transformer 1943-1945 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 319
% INFO    : Updated Thermal Rating: on transformer 1971-1977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 1970-1975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 1969-1974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 1968-1973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 1967-1972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 1980-1983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on transformer 1989-1990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 1989-1991 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 1990-1991 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 1990-1991 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1996-1997 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1996-1997 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1996-1997 : Rate A, Rate B, Rate C , 758.0, 758.0, 758.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 2011-2012 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 2011-2012 : Rate A, Rate B, Rate C , 337.0, 337.0, 337.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 2039-2040 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2039-2040 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 2048-2049 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 279
% INFO    : Updated Thermal Rating: on transformer 2047-2049 : Rate A, Rate B, Rate C , 445.0, 445.0, 445.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2055-2056 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1174
% INFO    : Updated Thermal Rating: on transformer 2055-2056 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1174
% INFO    : Updated Thermal Rating: on transformer 2055-2056 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 2072-2074 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 200
% INFO    : Updated Thermal Rating: on transformer 2072-2073 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 202
% INFO    : Updated Thermal Rating: on transformer 2076-2077 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 2076-2077 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2085-2086 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 238
% INFO    : Updated Thermal Rating: on transformer 2085-2086 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 238
% INFO    : Updated Thermal Rating: on line 2088-5880 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1099
% INFO    : Updated Thermal Rating: on transformer 2092-2094 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 2092-2094 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 2095-2096 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2095-2096 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2103-2104 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 2103-2104 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 2103-2104 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 2111-2112 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2111-2112 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2111-2112 : Rate A, Rate B, Rate C , 445.0, 445.0, 445.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 2124-2125 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 2124-2125 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2128-2131 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2127-2130 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 2127-2129 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 2132-2134 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2133-2134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on transformer 2133-2134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on transformer 2136-2137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 2136-2137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 2136-2138 : Rate A, Rate B, Rate C , 560.0, 560.0, 560.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 2136-2138 : Rate A, Rate B, Rate C , 604.0, 604.0, 604.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 2142-2143 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 2142-2143 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2147-2148 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 2147-2148 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 2161-2162 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 332
% INFO    : Updated Thermal Rating: on transformer 2165-2166 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 282
% INFO    : Updated Thermal Rating: on transformer 2172-2175 : Rate A, Rate B, Rate C , 701.0, 701.0, 701.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 2172-2174 : Rate A, Rate B, Rate C , 701.0, 701.0, 701.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 2184-2185 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 267
% INFO    : Updated Thermal Rating: on line 2185-5931 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 278
% INFO    : Updated Thermal Rating: on line 2185-5944 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 348
% INFO    : Updated Thermal Rating: on transformer 2196-2197 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1157
% INFO    : Updated Thermal Rating: on transformer 2196-2197 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1160
% INFO    : Updated Thermal Rating: on transformer 2222-2223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 2227-2228 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 2232-2233 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 284
% INFO    : Updated Thermal Rating: on transformer 2232-2233 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 284
% INFO    : Updated Thermal Rating: on transformer 2235-2236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 2240-2241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 2240-2241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 2246-5881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on transformer 2247-5881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29046
% INFO    : Updated Thermal Rating: on line 2248-5881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 2253-2254 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 2253-2254 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 2262-2263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 2262-2264 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 210
% INFO    : Updated Thermal Rating: on transformer 2262-2264 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 2263-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on transformer 2267-2269 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 2271-2272 : Rate A, Rate B, Rate C , 316.0, 316.0, 316.0 -> 282
% INFO    : Updated Thermal Rating: on transformer 2271-2272 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 282
% INFO    : Updated Thermal Rating: on transformer 2271-2272 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 2288-2289 : Rate A, Rate B, Rate C , 1018.0, 1018.0, 1018.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 2291-2292 : Rate A, Rate B, Rate C , 428.0, 428.0, 428.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 2291-2292 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2297-2298 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2297-2298 : Rate A, Rate B, Rate C , 474.0, 474.0, 474.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 2307-2308 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 2307-2308 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2313-2314 : Rate A, Rate B, Rate C , 437.0, 437.0, 437.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 2313-2314 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 2313-2314 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2326-2327 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 2333-2335 : Rate A, Rate B, Rate C , 438.0, 438.0, 438.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2334-2335 : Rate A, Rate B, Rate C , 447.0, 447.0, 447.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 2334-2335 : Rate A, Rate B, Rate C , 438.0, 438.0, 438.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 2343-2345 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 2343-2345 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 2344-2345 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 2368-2374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 2367-2372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 2366-2371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 2365-2370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 2364-2369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 2375-2376 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 2375-2376 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2424-2426 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 234
% INFO    : Updated Thermal Rating: on transformer 2424-2425 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 2428-2429 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 183
% INFO    : Updated Thermal Rating: on transformer 2432-2433 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2432-2433 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 2431-2433 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 2431-2433 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2447-2449 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 2447-2450 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 284
% INFO    : Updated Thermal Rating: on transformer 2447-2450 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 2449-2450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 2459-2460 : Rate A, Rate B, Rate C , 1243.0, 1243.0, 1243.0 -> 301
% INFO    : Updated Thermal Rating: on transformer 2459-2460 : Rate A, Rate B, Rate C , 1243.0, 1243.0, 1243.0 -> 315
% INFO    : Updated Thermal Rating: on line 2469-5909 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1099
% INFO    : Updated Thermal Rating: on line 2469-5932 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1089
% INFO    : Updated Thermal Rating: on transformer 2470-2471 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 2470-2471 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 2470-2472 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 2470-2472 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 2484-2486 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 335
% INFO    : Updated Thermal Rating: on transformer 2485-2486 : Rate A, Rate B, Rate C , 530.0, 530.0, 530.0 -> 331
% INFO    : Updated Thermal Rating: on transformer 2484-2486 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 332
% INFO    : Updated Thermal Rating: on transformer 2491-2492 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2491-2492 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 2504-2505 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 2504-2505 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2511-2512 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 2516-2517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 2516-2517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 2518-2519 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2518-2519 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2525-2526 : Rate A, Rate B, Rate C , 437.0, 437.0, 437.0 -> 301
% INFO    : Updated Thermal Rating: on transformer 2541-2542 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2550-2551 : Rate A, Rate B, Rate C , 278.0, 278.0, 278.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 2550-2552 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 2550-2552 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 2551-2552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on transformer 2561-2562 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 2561-2562 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 2568-2569 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2568-2569 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2568-2569 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 2572-2573 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 308
% INFO    : Updated Thermal Rating: on transformer 2572-2573 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 308
% INFO    : Updated Thermal Rating: on transformer 2579-2580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 2579-2582 : Rate A, Rate B, Rate C , 453.0, 453.0, 453.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2580-2582 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 2580-2582 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 2581-2582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on transformer 2585-2586 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 348
% INFO    : Updated Thermal Rating: on transformer 2585-2586 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 341
% INFO    : Updated Thermal Rating: on transformer 2596-2597 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 2596-2597 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2596-2597 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2596-2597 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 2607-2609 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 2607-2608 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 2627-2628 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 280
% INFO    : Updated Thermal Rating: on transformer 2635-2637 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 2636-2637 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2635-2637 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 2656-2657 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 2662-2663 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 2662-2663 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 2665-2667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7637
% INFO    : Updated Thermal Rating: on transformer 2664-5933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on transformer 2666-2668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on transformer 2667-5933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12244
% INFO    : Updated Thermal Rating: on line 2668-5933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on transformer 2669-2670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 2671-2672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 2677-2678 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2677-2678 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 2677-2678 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2686-2687 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2705-2706 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 2705-2706 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2707-2709 : Rate A, Rate B, Rate C , 445.0, 445.0, 445.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2707-2709 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 2708-2709 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 2725-2726 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 2725-2726 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2754-2755 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2754-2755 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 180
% INFO    : Updated Thermal Rating: on transformer 2770-2771 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 331
% INFO    : Updated Thermal Rating: on transformer 2769-5882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on transformer 2770-2772 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 307
% INFO    : Updated Thermal Rating: on transformer 2770-2772 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 314
% INFO    : Updated Thermal Rating: on transformer 2775-2776 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 2777-2778 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 2781-2782 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 292
% INFO    : Updated Thermal Rating: on transformer 2781-2782 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 287
% INFO    : Updated Thermal Rating: on transformer 2780-2783 : Rate A, Rate B, Rate C , 1628.0, 1628.0, 1628.0 -> 314
% INFO    : Updated Thermal Rating: on transformer 2780-2783 : Rate A, Rate B, Rate C , 1628.0, 1628.0, 1628.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 2782-2783 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 885
% INFO    : Updated Thermal Rating: on line 2786-5883 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 883
% INFO    : Updated Thermal Rating: on line 2787-5910 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 982
% INFO    : Updated Thermal Rating: on transformer 2791-2792 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2791-2792 : Rate A, Rate B, Rate C , 721.0, 721.0, 721.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 2797-2799 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 320
% INFO    : Updated Thermal Rating: on transformer 2804-2807 : Rate A, Rate B, Rate C , 604.0, 604.0, 604.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 2805-2807 : Rate A, Rate B, Rate C , 342.0, 342.0, 342.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2806-2807 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 2810-2811 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2810-2811 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2815-2816 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2815-2816 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 267
% INFO    : Updated Thermal Rating: on transformer 2848-2849 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 2864-2865 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 306
% INFO    : Updated Thermal Rating: on transformer 2864-2865 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 309
% INFO    : Updated Thermal Rating: on line 2894-5885 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 894
% INFO    : Updated Thermal Rating: on line 2894-5935 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1068
% INFO    : Updated Thermal Rating: on line 2894-5945 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 891
% INFO    : Updated Thermal Rating: on transformer 2900-5886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 2902-5886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 2914-2915 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on line 2918-5887 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1166
% INFO    : Updated Thermal Rating: on line 2918-5913 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1178
% INFO    : Updated Thermal Rating: on transformer 2931-2933 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2931-2932 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 2937-2938 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2936-2938 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 240
% INFO    : Updated Thermal Rating: on transformer 2936-2938 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2945-2946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 2945-2946 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 2947-2948 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 318
% INFO    : Updated Thermal Rating: on transformer 2951-2953 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 2951-2952 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 2959-2960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on transformer 2966-5914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on transformer 2968-2970 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1160
% INFO    : Updated Thermal Rating: on line 2970-5914 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 891
% INFO    : Updated Thermal Rating: on line 2971-5936 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 989
% INFO    : Updated Thermal Rating: on line 2971-5946 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 981
% INFO    : Updated Thermal Rating: on transformer 2973-2974 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2973-2974 : Rate A, Rate B, Rate C , 469.0, 469.0, 469.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 2986-2987 : Rate A, Rate B, Rate C , 796.0, 796.0, 796.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2986-2987 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2996-2997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 2997-3000 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2998-3000 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 3001-3002 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3001-3002 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 3001-3002 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 3003-3004 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 3003-3004 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 3003-3004 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 3010-3011 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 3010-3011 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 3017-3018 : Rate A, Rate B, Rate C , 363.0, 363.0, 363.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 3017-3018 : Rate A, Rate B, Rate C , 363.0, 363.0, 363.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 3031-3032 : Rate A, Rate B, Rate C , 307.0, 307.0, 307.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 3031-3032 : Rate A, Rate B, Rate C , 307.0, 307.0, 307.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 3064-3065 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 3064-3065 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3074-3075 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 3074-3075 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 3082-3083 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3082-3083 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3086-3087 : Rate A, Rate B, Rate C , 432.0, 432.0, 432.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 3086-3087 : Rate A, Rate B, Rate C , 432.0, 432.0, 432.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3086-3087 : Rate A, Rate B, Rate C , 432.0, 432.0, 432.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 3088-3089 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 3100-3101 : Rate A, Rate B, Rate C , 378.0, 378.0, 378.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3100-3101 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 3118-3121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3117-3120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3116-3119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3127-3128 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3127-3128 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3134-3135 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 3134-3135 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 3145-3146 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 3145-3146 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 3152-3153 : Rate A, Rate B, Rate C , 712.0, 712.0, 712.0 -> 200
% INFO    : Updated Thermal Rating: on transformer 3152-3154 : Rate A, Rate B, Rate C , 712.0, 712.0, 712.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 3152-3154 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 3164-3165 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3164-3165 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3175-3176 : Rate A, Rate B, Rate C , 471.0, 471.0, 471.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 3175-3176 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 243
% INFO    : Updated Thermal Rating: on line 3180-5889 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1178
% INFO    : Updated Thermal Rating: on line 3180-5916 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1097
% INFO    : Updated Thermal Rating: on transformer 3197-3199 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3197-3199 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 280
% INFO    : Updated Thermal Rating: on transformer 3197-3199 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 3201-3202 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3201-3202 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3215-3217 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 3258-3259 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 308
% INFO    : Updated Thermal Rating: on transformer 3258-3259 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 309
% INFO    : Updated Thermal Rating: on transformer 3269-3270 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3269-3270 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 3269-3270 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 3278-3279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on transformer 3278-3279 : Rate A, Rate B, Rate C , 437.0, 437.0, 437.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 3282-3284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 3281-3283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 3280-3286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3290-3291 : Rate A, Rate B, Rate C , 420.0, 420.0, 420.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 3297-3298 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3311-3312 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 3311-3312 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3311-3312 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 3321-3323 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3321-3323 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3322-3323 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3335-3336 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 3335-3336 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 3334-3336 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 3344-3345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 3344-3345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 3345-3346 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 3345-3346 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 3349-3350 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 3349-3350 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 3363-3364 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 3363-3364 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 3366-3367 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 3366-3367 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 3366-3367 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 3371-3372 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 3371-3372 : Rate A, Rate B, Rate C , 1140.0, 1140.0, 1140.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 3380-3381 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 3380-3381 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 3380-3381 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 3396-3397 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3396-3397 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3399-3400 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3399-3400 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3399-3400 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 3432-3433 : Rate A, Rate B, Rate C , 710.0, 710.0, 710.0 -> 204
% INFO    : Updated Thermal Rating: on transformer 3432-3433 : Rate A, Rate B, Rate C , 710.0, 710.0, 710.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 3441-3442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 3441-3442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 3482-3485 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 3482-3485 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 3483-3485 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 3503-3505 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3506-3507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 3509-3510 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 3515-3517 : Rate A, Rate B, Rate C , 1230.0, 1230.0, 1230.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 3515-3516 : Rate A, Rate B, Rate C , 1230.0, 1230.0, 1230.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 3518-3519 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 3518-3519 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 3518-3519 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 3520-3521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3522-3524 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3523-3524 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3523-3524 : Rate A, Rate B, Rate C , 758.0, 758.0, 758.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 3539-3540 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 3539-3540 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 3543-3544 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 3546-3547 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 3546-3547 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 3546-3547 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 280
% INFO    : Updated Thermal Rating: on transformer 3556-3557 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3556-3557 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3560-3561 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 3560-3561 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 3560-3561 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 182
% INFO    : Updated Thermal Rating: on transformer 3562-3563 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 3562-3564 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 3565-3566 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 3573-3574 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 3573-3574 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 190
% INFO    : Updated Thermal Rating: on transformer 3579-3580 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3587-3589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 3588-3590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 3595-3596 : Rate A, Rate B, Rate C , 313.0, 313.0, 313.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 3597-3598 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 3602-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 3604-3605 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 238
% INFO    : Updated Thermal Rating: on transformer 3610-3611 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3616-3617 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1171
% INFO    : Updated Thermal Rating: on line 3618-5890 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 974
% INFO    : Updated Thermal Rating: on line 3618-5917 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1046
% INFO    : Updated Thermal Rating: on line 3617-5937 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 985
% INFO    : Updated Thermal Rating: on line 3617-5947 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1003
% INFO    : Updated Thermal Rating: on transformer 3621-3622 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3621-3622 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3621-3622 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3625-3626 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 3632-3633 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 3632-3633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 3632-3633 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3649-3650 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 3649-3650 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 3656-3657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3655-3657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3664-3665 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 3666-3667 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3666-3667 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3666-3667 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 3666-3667 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 3671-3672 : Rate A, Rate B, Rate C , 316.0, 316.0, 316.0 -> 284
% INFO    : Updated Thermal Rating: on transformer 3671-3672 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 3675-3676 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 284
% INFO    : Updated Thermal Rating: on transformer 3675-3676 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 3679-3680 : Rate A, Rate B, Rate C , 722.0, 722.0, 722.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 3679-3680 : Rate A, Rate B, Rate C , 722.0, 722.0, 722.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 3679-3680 : Rate A, Rate B, Rate C , 722.0, 722.0, 722.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 3705-3706 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1153
% INFO    : Updated Thermal Rating: on line 3706-5891 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1031
% INFO    : Updated Thermal Rating: on transformer 3710-3711 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3712-3713 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3712-3713 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 3728-3729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 3728-3730 : Rate A, Rate B, Rate C , 290.0, 290.0, 290.0 -> 117
% INFO    : Updated Thermal Rating: on transformer 3729-3731 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 3735-3736 : Rate A, Rate B, Rate C , 530.0, 530.0, 530.0 -> 340
% INFO    : Updated Thermal Rating: on transformer 3737-3739 : Rate A, Rate B, Rate C , 439.0, 439.0, 439.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3737-3739 : Rate A, Rate B, Rate C , 439.0, 439.0, 439.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3737-3739 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3737-3739 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3743-3744 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 3746-3747 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3746-3747 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3759-3760 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 3759-3760 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 3764-3765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3764-3765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3764-3765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 3774-3775 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 314
% INFO    : Updated Thermal Rating: on transformer 3774-3775 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 317
% INFO    : Updated Thermal Rating: on transformer 3778-3782 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3779-3781 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3778-3782 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3777-3780 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3791-3793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 3790-3793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 3789-3792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 3810-3811 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 3810-3811 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 3811-3812 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1134
% INFO    : Updated Thermal Rating: on transformer 3819-3822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3818-3821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3817-3820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3831-3833 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3832-3833 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 3841-3842 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 3851-3852 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 3851-3852 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 3855-3857 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 3856-3857 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 3874-3875 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3874-3875 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 3879-3880 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 3879-3880 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 3879-3880 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 3881-3882 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 258
% INFO    : Updated Thermal Rating: on line 3882-5938 : Rate A, Rate B, Rate C , 482.0, 482.0, 482.0 -> 317
% INFO    : Updated Thermal Rating: on transformer 3889-3890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3898-3899 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 3901-3902 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 3901-3902 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 3906-3908 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1177
% INFO    : Updated Thermal Rating: on transformer 3917-3918 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 3917-3918 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3917-3918 : Rate A, Rate B, Rate C , 378.0, 378.0, 378.0 -> 238
% INFO    : Updated Thermal Rating: on transformer 3924-3926 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3925-3926 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 3928-3929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 3931-3932 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3931-3932 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 3937-3938 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 3970-3971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 3969-3972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 3979-3981 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3980-3981 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 4005-4006 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 4005-4006 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 4009-4010 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 4009-4010 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 4011-4012 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 4018-4019 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 215
% INFO    : Updated Thermal Rating: on transformer 4018-4019 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 211
% INFO    : Updated Thermal Rating: on transformer 4027-4028 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 4027-4028 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 4037-4038 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 182
% INFO    : Updated Thermal Rating: on transformer 4046-4047 : Rate A, Rate B, Rate C , 453.0, 453.0, 453.0 -> 197
% INFO    : Updated Thermal Rating: on line 4050-5893 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1039
% INFO    : Updated Thermal Rating: on transformer 4064-4065 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 195
% INFO    : Updated Thermal Rating: on transformer 4078-5894 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 4077-5919 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 4089-4090 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 4089-4090 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4093-4094 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4095-4096 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 4102-4103 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4102-4103 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 4106-5895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 4108-5895 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1158
% INFO    : Updated Thermal Rating: on transformer 4112-4113 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 4112-4113 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 190
% INFO    : Updated Thermal Rating: on transformer 4120-4121 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 4120-4121 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 4122-4123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on transformer 4123-4124 : Rate A, Rate B, Rate C , 712.0, 712.0, 712.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 4142-4144 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 4143-4144 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4143-4144 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 4143-4144 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 4145-4146 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 4145-4146 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 4150-4151 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4149-4151 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 4149-4151 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 4166-4167 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 4166-4167 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 4172-4173 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 309
% INFO    : Updated Thermal Rating: on transformer 4174-4175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10522
% INFO    : Updated Thermal Rating: on transformer 4183-4184 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 4183-4184 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 4209-4211 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 4209-4211 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 4212-4213 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 4212-4213 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 233
% INFO    : Updated Thermal Rating: on transformer 4218-4220 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 4219-4220 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 4219-4220 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 279
% INFO    : Updated Thermal Rating: on transformer 4218-4220 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 4226-4223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4228-4229 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 4227-4229 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 4244-4245 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 304
% INFO    : Updated Thermal Rating: on transformer 4250-4272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on transformer 4252-4253 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 4252-4253 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4255-4256 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4257-4258 : Rate A, Rate B, Rate C , 726.0, 726.0, 726.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4257-4258 : Rate A, Rate B, Rate C , 726.0, 726.0, 726.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4276-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 4277-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 4278-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3573
% INFO    : Updated Thermal Rating: on transformer 4292-4293 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 138
% INFO    : Updated Thermal Rating: on transformer 4291-4293 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 139
% INFO    : Updated Thermal Rating: on transformer 4291-4293 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 143
% INFO    : Updated Thermal Rating: on transformer 4291-4293 : Rate A, Rate B, Rate C , 304.0, 304.0, 304.0 -> 131
% INFO    : Updated Thermal Rating: on transformer 4295-4296 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 4305-4306 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 233
% INFO    : Updated Thermal Rating: on transformer 4312-4313 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 4312-4314 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 4325-4326 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 4331-4334 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 283
% INFO    : Updated Thermal Rating: on transformer 4332-4334 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 4332-4333 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 4331-4333 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 4343-4345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4342-4345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4341-4345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4344-4345 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 4344-4345 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4348-4349 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 4348-4349 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 284
% INFO    : Updated Thermal Rating: on transformer 4348-4349 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 279
% INFO    : Updated Thermal Rating: on transformer 4357-4355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4389-4390 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 4389-4390 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4391-4393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4398-4399 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 4398-4399 : Rate A, Rate B, Rate C , 432.0, 432.0, 432.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 1496-4407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 4421-4423 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 4422-4423 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4442-4444 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4442-4444 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4443-4444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on transformer 4454-4456 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 4458-4459 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 285
% INFO    : Updated Thermal Rating: on transformer 4458-4459 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 4458-4459 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 4463-4464 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 4463-4464 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 4462-4464 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 4473-4474 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 4473-4474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 4476-4481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 4480-4485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 4479-4484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 4478-4483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 4477-4482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 4499-4501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on transformer 4500-4501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 4502-4503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 4509-4510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 4514-4515 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 4514-4515 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 211
% INFO    : Updated Thermal Rating: on transformer 4523-4525 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4524-4525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 4535-4536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 4540-4541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on transformer 4540-4541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on transformer 4540-4542 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 258
% INFO    : Updated Thermal Rating: on line 4548-5897 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1099
% INFO    : Updated Thermal Rating: on line 4548-5920 : Rate A, Rate B, Rate C , 1174.0, 1174.0, 1174.0 -> 1166
% INFO    : Updated Thermal Rating: on transformer 4555-4556 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 238
% INFO    : Updated Thermal Rating: on transformer 4555-4557 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 4556-4557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 4569-4570 : Rate A, Rate B, Rate C , 1217.0, 1217.0, 1217.0 -> 293
% INFO    : Updated Thermal Rating: on transformer 4573-4574 : Rate A, Rate B, Rate C , 1266.0, 1266.0, 1266.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 4573-4574 : Rate A, Rate B, Rate C , 1266.0, 1266.0, 1266.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 4592-4594 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 312
% INFO    : Updated Thermal Rating: on transformer 4592-4593 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 4595-4596 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4595-4596 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4598-4599 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1159
% INFO    : Updated Thermal Rating: on transformer 4598-4600 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1065
% INFO    : Updated Thermal Rating: on transformer 4607-4608 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 4607-4608 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 199
% INFO    : Updated Thermal Rating: on transformer 4607-4608 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 223
% INFO    : Updated Thermal Rating: on transformer 4615-4616 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 4615-4616 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 4636-4638 : Rate A, Rate B, Rate C , 1140.0, 1140.0, 1140.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 4636-4637 : Rate A, Rate B, Rate C , 1140.0, 1140.0, 1140.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 4646-4647 : Rate A, Rate B, Rate C , 711.0, 711.0, 711.0 -> 204
% INFO    : Updated Thermal Rating: on transformer 4646-4647 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 317
% INFO    : Updated Thermal Rating: on transformer 4646-4647 : Rate A, Rate B, Rate C , 711.0, 711.0, 711.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 4649-4651 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 4649-4650 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 248
% INFO    : Updated Thermal Rating: on line 4661-5940 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 976
% INFO    : Updated Thermal Rating: on line 4661-5949 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 983
% INFO    : Updated Thermal Rating: on transformer 4672-4673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7637
% INFO    : Updated Thermal Rating: on transformer 4671-4674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7637
% INFO    : Updated Thermal Rating: on transformer 4675-4676 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4675-4676 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 4675-4676 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4676-4677 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 993
% INFO    : Updated Thermal Rating: on transformer 4676-4677 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 991
% INFO    : Updated Thermal Rating: on transformer 4681-4683 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 4681-4683 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 4681-4683 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 4681-4683 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 4688-4689 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4688-4689 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 4710-4713 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 4709-4713 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 4706-4713 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 4705-4713 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 4720-4721 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4720-4721 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4742-4743 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 4742-4743 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4742-4743 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4744-4745 : Rate A, Rate B, Rate C , 374.0, 374.0, 374.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 4744-4745 : Rate A, Rate B, Rate C , 374.0, 374.0, 374.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 4765-4766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on transformer 4772-4773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 4771-5898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on transformer 4773-4774 : Rate A, Rate B, Rate C , 654.0, 654.0, 654.0 -> 650
% INFO    : Updated Thermal Rating: on line 4774-5898 : Rate A, Rate B, Rate C , 654.0, 654.0, 654.0 -> 649
% INFO    : Updated Thermal Rating: on transformer 4778-4779 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 4778-4779 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 4782-4783 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 4802-4803 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4802-4803 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 4808-4810 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 306
% INFO    : Updated Thermal Rating: on transformer 4808-4810 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 307
% INFO    : Updated Thermal Rating: on transformer 4819-4821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 4818-4820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 4824-4826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 367
% INFO    : Updated Thermal Rating: on transformer 4825-4826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on transformer 4827-4829 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 4827-4828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 4827-4828 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 4827-4828 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 4829-4830 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1174
% INFO    : Updated Thermal Rating: on transformer 4828-4830 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1165
% INFO    : Updated Thermal Rating: on transformer 4828-4830 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 4847-4848 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 4847-4848 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 4852-4853 : Rate A, Rate B, Rate C , 453.0, 453.0, 453.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 4857-4858 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 4857-4858 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 178
% INFO    : Updated Thermal Rating: on line 4859-5921 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1175
% INFO    : Updated Thermal Rating: on transformer 4862-4863 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 4862-4863 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 4862-4863 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4880-4881 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 4880-4881 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4900-4902 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 4900-4901 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 4915-4917 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 4914-4917 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 4915-4917 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 4916-4917 : Rate A, Rate B, Rate C , 358.0, 358.0, 358.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 4921-4922 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 4921-4922 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 4926-4927 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 4926-4927 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4926-4927 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 4940-4941 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 4956-4958 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 4956-4958 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 4955-5950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on transformer 4954-5956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 4959-5899 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1046
% INFO    : Updated Thermal Rating: on line 4959-5922 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1041
% INFO    : Updated Thermal Rating: on line 4959-5941 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 983
% INFO    : Updated Thermal Rating: on line 4959-5950 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 983
% INFO    : Updated Thermal Rating: on line 4959-5956 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 886
% INFO    : Updated Thermal Rating: on transformer 4960-4962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4961-4962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on transformer 4961-4962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 4961-4962 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 4967-4969 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 4967-4968 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 311
% INFO    : Updated Thermal Rating: on transformer 4973-4975 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4974-4975 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 4975-4977 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1159
% INFO    : Updated Thermal Rating: on line 4977-5923 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 885
% INFO    : Updated Thermal Rating: on line 4977-5951 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1041
% INFO    : Updated Thermal Rating: on transformer 4981-4982 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 4981-4982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 4986-4989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 4985-4988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 4984-4987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 4990-4992 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 4994-4995 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 4998-4999 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 5000-5001 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 5005-5006 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 5005-5006 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 5034-5035 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 5052-5053 : Rate A, Rate B, Rate C , 511.0, 511.0, 511.0 -> 341
% INFO    : Updated Thermal Rating: on transformer 5078-5079 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 5085-5086 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1145
% INFO    : Updated Thermal Rating: on transformer 5966-5967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 674
% INFO    : Updated Thermal Rating: on transformer 5965-5967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 691
% INFO    : Updated Thermal Rating: on transformer 5972-5973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1192
% INFO    : Updated Thermal Rating: on transformer 5974-5975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1364
% INFO    : Updated Thermal Rating: on transformer 5984-5986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1348
% INFO    : Updated Thermal Rating: on transformer 5985-5986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1348
% INFO    : Updated Thermal Rating: on transformer 6199-6004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11039
% INFO    : Updated Thermal Rating: on transformer 6003-6199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6986
% INFO    : Updated Thermal Rating: on transformer 6022-6024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1892
% INFO    : Updated Thermal Rating: on transformer 6023-6025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1968
% INFO    : Updated Thermal Rating: on transformer 6035-6036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1892
% INFO    : Updated Thermal Rating: on transformer 6040-6042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1151
% INFO    : Updated Thermal Rating: on transformer 6058-6059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2596
% INFO    : Updated Thermal Rating: on transformer 6062-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 6063-6064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 6068-6070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on transformer 6069-6070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on transformer 6074-6075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1125
% INFO    : Updated Thermal Rating: on transformer 6074-6075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1287
% INFO    : Updated Thermal Rating: on transformer 6082-6083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1145
% INFO    : Updated Thermal Rating: on transformer 6086-6087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 6086-6087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1316
% INFO    : Updated Thermal Rating: on transformer 6094-6096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2279
% INFO    : Updated Thermal Rating: on transformer 6099-6101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1842
% INFO    : Updated Thermal Rating: on transformer 6106-6107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on transformer 6122-6123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on transformer 6136-6137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1837
% INFO    : Updated Thermal Rating: on transformer 6150-6151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 765
% INFO    : Updated Thermal Rating: on transformer 6150-6151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 6154-6155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1509
% INFO    : Updated Thermal Rating: on transformer 6174-6175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1689
% INFO    : Updated Thermal Rating: on transformer 6180-6181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on transformer 6184-6185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1344
% INFO    : Updated Thermal Rating: on transformer 6184-6185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1355
% INFO    : Updated Thermal Rating: on transformer 6184-6185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1359
% INFO    : Updated Thermal Rating: on transformer 6186-6187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 6211-6212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 803
% INFO    : Updated Thermal Rating: on transformer 6207-6221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55237
% INFO    : Updated Thermal Rating: on transformer 6207-6220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2200
% INFO    : Updated Thermal Rating: on transformer 6233-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on transformer 6233-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on transformer 6233-6234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1850
% INFO    : Updated Thermal Rating: on transformer 6245-6246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 6243-6246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 6244-6246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 6242-6246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 6247-6248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1471
% INFO    : Updated Thermal Rating: on transformer 6247-6248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on transformer 115-6256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on transformer 116-6257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on transformer 202-6258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 232-6259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on transformer 232-6260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on transformer 273-6261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 273-6262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 272-6263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 272-6264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 368-6265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 368-6266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 369-6267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 369-6268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 370-6269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 370-6270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 502-6279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 995
% INFO    : Updated Thermal Rating: on transformer 502-6280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on transformer 526-6281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 526-6282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 526-6283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 526-6284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 526-6285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 2798-6286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 622-6287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 623-6288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 623-6289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on transformer 693-6296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 693-6297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 693-6298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 692-6299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 692-6300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 692-6301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 714-6302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 714-6303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 1006-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1046-6308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on transformer 73-6317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on transformer 72-6318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on transformer 2106-6319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on transformer 1175-6320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1759
% INFO    : Updated Thermal Rating: on transformer 1178-6324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1588
% INFO    : Updated Thermal Rating: on transformer 1444-6325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1444-6326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1444-6327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1444-6328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1444-6329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1444-6330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1339-6335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1339-6336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1364-6337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on transformer 1363-6338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on transformer 1430-6339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1046
% INFO    : Updated Thermal Rating: on transformer 1608-6344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on transformer 1871-6347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on transformer 1960-6348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1961-6349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1961-6350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on transformer 1960-6351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on transformer 2046-6354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on transformer 2053-6355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 2134-6362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on transformer 2163-6363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on transformer 2199-6365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1696
% INFO    : Updated Thermal Rating: on transformer 2200-6366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1616
% INFO    : Updated Thermal Rating: on transformer 2221-6368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on transformer 2241-6369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on transformer 2401-6370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 2401-6371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 2462-6372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 2663-6373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 2663-6374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 2663-6375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 2663-6376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 2655-6378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on transformer 2706-6379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 2706-6380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on transformer 2706-6381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2706-6382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 2712-6383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 2712-6384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 2712-6385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 2728-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2821-6388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on transformer 2861-6389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 381-6390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1082
% INFO    : Updated Thermal Rating: on transformer 3039-6391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 3039-6392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 3056-6393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on transformer 3055-6394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on transformer 3089-6395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on transformer 3089-6396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on transformer 3149-6399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1041
% INFO    : Updated Thermal Rating: on transformer 3150-6400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1000
% INFO    : Updated Thermal Rating: on transformer 3253-6402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 3253-6403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 3263-6404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on transformer 3346-6409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on transformer 3479-6412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1594
% INFO    : Updated Thermal Rating: on transformer 3478-6413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1594
% INFO    : Updated Thermal Rating: on transformer 3477-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1594
% INFO    : Updated Thermal Rating: on transformer 3476-6415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on transformer 3505-6416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on transformer 3596-6419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on transformer 3596-6420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on transformer 3609-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 3689-6422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 3689-6423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 3727-6425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 3726-6426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 3725-6427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 3730-6428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 3730-6429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 3730-6430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 3730-6431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 3992-6432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on transformer 3997-6433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 3997-6434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 4021-6435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 4021-6436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 4047-6437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on transformer 4053-6438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 4146-6439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on transformer 4146-6440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on transformer 1695-6446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 923
% INFO    : Updated Thermal Rating: on transformer 4256-6447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on transformer 4256-6448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on transformer 4265-6449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on transformer 4271-6450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on transformer 4296-6453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 4296-6454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 4296-6455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 4505-6456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on transformer 4505-6457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on transformer 4525-6458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 4525-6459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 4762-6464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on transformer 4762-6465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on transformer 4761-6466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on transformer 4794-6467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 4794-6468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 4794-6469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 4938-6471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 4947-6472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on transformer 5006-6473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on transformer 5006-6474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 1	: V=0.976135388, theta=-12.9925873 -> V=0.9444445, theta=0.0
% INFO    : Bus 2	: V=1.02642799, theta=-12.9259868 -> V=0.999999, theta=0.0
% INFO    : Bus 3	: V=1.00503432, theta=-13.9209286 -> V=1.0158755, theta=0.0
% INFO    : Bus 4	: V=1.04420421, theta=-12.9960661 -> V=1.0111115, theta=0.0
% INFO    : Bus 5	: V=1.01635584, theta=-44.9251304 -> V=1.0079355, theta=0.0
% INFO    : Bus 6	: V=1.03382845, theta=-21.1593539 -> V=1.0000025, theta=0.0
% INFO    : Bus 7	: V=1.04376781, theta=-23.4151063 -> V=1.0000025, theta=0.0
% INFO    : Bus 8	: V=1.06137161, theta=-9.10918487 -> V=0.9888895, theta=0.0
% INFO    : Bus 9	: V=1.04218491, theta=-19.692127 -> V=0.999999, theta=0.0
% INFO    : Bus 10	: V=1.03392009, theta=-13.0599476 -> V=1.000001, theta=0.0
% INFO    : Bus 11	: V=1.03391987, theta=-13.0599451 -> V=1.000001, theta=0.0
% INFO    : Bus 12	: V=1.01220507, theta=1.47719466 -> V=1.0158755, theta=0.0
% INFO    : Bus 13	: V=1.05892219, theta=-5.04317166 -> V=1.078945, theta=0.0
% INFO    : Bus 14	: V=1.06276649, theta=-23.9178904 -> V=1.027779, theta=0.0
% INFO    : Bus 15	: V=1.00803207, theta=-27.2648742 -> V=1.0000025, theta=0.0
% INFO    : Bus 16	: V=1.02765775, theta=-30.1822336 -> V=1.0000025, theta=0.0
% INFO    : Bus 17	: V=1.04678283, theta=-29.1807443 -> V=1.022224, theta=0.0
% INFO    : Bus 18	: V=0.943683152, theta=-6.22055638 -> V=0.9444445, theta=0.0
% INFO    : Bus 19	: V=1.01840923, theta=-21.4790742 -> V=0.999999, theta=0.0
% INFO    : Bus 20	: V=0.944675623, theta=-6.25041794 -> V=0.9444445, theta=0.0
% INFO    : Bus 21	: V=1.04078363, theta=-20.286675 -> V=1.022224, theta=0.0
% INFO    : Bus 22	: V=1.01396605, theta=-11.0956105 -> V=1.0158755, theta=0.0
% INFO    : Bus 23	: V=1.01094639, theta=-10.1391831 -> V=0.999999, theta=0.0
% INFO    : Bus 24	: V=1.04095062, theta=-12.3196454 -> V=1.033333, theta=0.0
% INFO    : Bus 25	: V=1.07238186, theta=-8.42135007 -> V=1.022222, theta=0.0
% INFO    : Bus 26	: V=1.02301673, theta=-21.9672988 -> V=1.022224, theta=0.0
% INFO    : Bus 27	: V=1.06710622, theta=-17.5980982 -> V=1.04444, theta=0.0
% INFO    : Bus 28	: V=1.02281412, theta=-19.085163 -> V=1.0158755, theta=0.0
% INFO    : Bus 29	: V=1.00764278, theta=-24.8565374 -> V=1.015872, theta=0.0
% INFO    : Bus 30	: V=1.03465163, theta=-13.1714919 -> V=1.0111115, theta=0.0
% INFO    : Bus 31	: V=1.02725645, theta=-9.77254236 -> V=0.999999, theta=0.0
% INFO    : Bus 32	: V=1.03648765, theta=-4.82385724 -> V=1.003335, theta=0.0
% INFO    : Bus 33	: V=1.05453305, theta=-7.49488734 -> V=1.0111115, theta=0.0
% INFO    : Bus 34	: V=1.05382682, theta=-6.60576514 -> V=1.0111115, theta=0.0
% INFO    : Bus 35	: V=1.07407438, theta=-6.15731397 -> V=1.072365, theta=0.0
% INFO    : Bus 36	: V=1.07981196, theta=-5.3255914 -> V=1.072365, theta=0.0
% INFO    : Bus 37	: V=1.00780047, theta=-25.6001306 -> V=1.0000025, theta=0.0
% INFO    : Bus 38	: V=1.05045129, theta=-12.5625758 -> V=1.015874, theta=0.0
% INFO    : Bus 39	: V=1.03860534, theta=-32.8237834 -> V=1.027779, theta=0.0
% INFO    : Bus 40	: V=1.05927182, theta=-22.0803285 -> V=1.027779, theta=0.0
% INFO    : Bus 41	: V=1.07994118, theta=-18.1118321 -> V=1.046665, theta=0.0
% INFO    : Bus 42	: V=1.12051301, theta=5.61827836 -> V=1.0424855, theta=0.0
% INFO    : Bus 43	: V=1.04594618, theta=-18.1350668 -> V=1.027779, theta=0.0
% INFO    : Bus 44	: V=1.02400675, theta=-45.3164455 -> V=1.0079355, theta=0.0
% INFO    : Bus 45	: V=1.00835368, theta=-29.0294852 -> V=1.022224, theta=0.0
% INFO    : Bus 46	: V=1.012435, theta=-16.8917768 -> V=0.999999, theta=0.0
% INFO    : Bus 47	: V=1.012, theta=-14.645547 -> V=0.999999, theta=0.0
% INFO    : Bus 48	: V=1.03402321, theta=-13.0587867 -> V=1.000001, theta=0.0
% INFO    : Bus 49	: V=1.01826244, theta=-16.2568862 -> V=0.999999, theta=0.0
% INFO    : Bus 50	: V=1.06347625, theta=-15.8365877 -> V=1.003314, theta=0.0
% INFO    : Bus 51	: V=1.05402062, theta=-11.3483204 -> V=1.0111115, theta=0.0
% INFO    : Bus 52	: V=1.03592726, theta=-30.7614811 -> V=1.022224, theta=0.0
% INFO    : Bus 53	: V=1.01729743, theta=-17.5396193 -> V=1.0000005, theta=0.0
% INFO    : Bus 54	: V=1.03781665, theta=-15.8046832 -> V=1.022224, theta=0.0
% INFO    : Bus 55	: V=1.06961297, theta=-18.9138109 -> V=1.046665, theta=0.0
% INFO    : Bus 56	: V=1.07717063, theta=-15.4534489 -> V=1.046665, theta=0.0
% INFO    : Bus 57	: V=1.051, theta=-23.8130179 -> V=1.0000025, theta=0.0
% INFO    : Bus 58	: V=1.06941541, theta=-18.9307534 -> V=1.046665, theta=0.0
% INFO    : Bus 59	: V=1.01246439, theta=-11.9419701 -> V=1.0158755, theta=0.0
% INFO    : Bus 60	: V=1.02630951, theta=-5.72230685 -> V=1.0158755, theta=0.0
% INFO    : Bus 61	: V=1.03149101, theta=-8.27970763 -> V=1.0158755, theta=0.0
% INFO    : Bus 62	: V=1.01212852, theta=-6.03185941 -> V=1.0158755, theta=0.0
% INFO    : Bus 63	: V=1.01100284, theta=1.57582423 -> V=1.0158755, theta=0.0
% INFO    : Bus 64	: V=1.07394793, theta=-6.81249347 -> V=0.9888895, theta=0.0
% INFO    : Bus 65	: V=1.04323714, theta=-8.83232685 -> V=1.0158755, theta=0.0
% INFO    : Bus 66	: V=1.02766848, theta=-25.721717 -> V=0.999999, theta=0.0
% INFO    : Bus 67	: V=1.04382543, theta=-19.3568303 -> V=1.0000025, theta=0.0
% INFO    : Bus 68	: V=1.01281042, theta=-16.3819581 -> V=0.999999, theta=0.0
% INFO    : Bus 69	: V=1.04103403, theta=-49.3963046 -> V=1.0079355, theta=0.0
% INFO    : Bus 70	: V=1.01492751, theta=2.12856808 -> V=1.0158755, theta=0.0
% INFO    : Bus 71	: V=1.02703162, theta=-19.7214799 -> V=1.0000005, theta=0.0
% INFO    : Bus 72	: V=1.08833147, theta=-12.1292789 -> V=1.047355, theta=0.0
% INFO    : Bus 73	: V=1.08830871, theta=-12.1298816 -> V=1.047345, theta=0.0
% INFO    : Bus 74	: V=1.07421562, theta=-6.6908321 -> V=0.9888895, theta=0.0
% INFO    : Bus 75	: V=1.05912762, theta=-15.2272137 -> V=1.022539, theta=0.0
% INFO    : Bus 76	: V=1.07654404, theta=4.81180688 -> V=1.0379485, theta=0.0
% INFO    : Bus 77	: V=1.01721738, theta=-16.1431001 -> V=0.999999, theta=0.0
% INFO    : Bus 78	: V=1.01713501, theta=-24.7944396 -> V=1.0000025, theta=0.0
% INFO    : Bus 79	: V=1.0233287, theta=-15.8525121 -> V=1.0000005, theta=0.0
% INFO    : Bus 80	: V=1.07788234, theta=-15.7121296 -> V=1.046665, theta=0.0
% INFO    : Bus 81	: V=1.07789352, theta=-15.712247 -> V=1.046665, theta=0.0
% INFO    : Bus 82	: V=1.01680665, theta=-17.7544069 -> V=0.999999, theta=0.0
% INFO    : Bus 83	: V=1.06117126, theta=-18.1202089 -> V=1.046665, theta=0.0
% INFO    : Bus 84	: V=1.01460966, theta=-12.8551684 -> V=0.999999, theta=0.0
% INFO    : Bus 85	: V=1.03363532, theta=-18.6243809 -> V=0.999999, theta=0.0
% INFO    : Bus 86	: V=1.02064907, theta=-38.6021117 -> V=1.022224, theta=0.0
% INFO    : Bus 87	: V=1.0187645, theta=1.31447041 -> V=1.0158755, theta=0.0
% INFO    : Bus 88	: V=1.01592598, theta=-21.6956546 -> V=0.999999, theta=0.0
% INFO    : Bus 89	: V=1.0379702, theta=-20.8685881 -> V=1.027779, theta=0.0
% INFO    : Bus 90	: V=0.94224878, theta=-7.00763458 -> V=0.9444445, theta=0.0
% INFO    : Bus 91	: V=0.943074714, theta=-6.30480653 -> V=0.9444445, theta=0.0
% INFO    : Bus 92	: V=1.00978629, theta=-20.3740289 -> V=1.015872, theta=0.0
% INFO    : Bus 93	: V=0.958656574, theta=-8.71727433 -> V=0.9444445, theta=0.0
% INFO    : Bus 94	: V=1.04379161, theta=-19.7217298 -> V=1.022224, theta=0.0
% INFO    : Bus 95	: V=1.0312211, theta=-30.4840468 -> V=1.022224, theta=0.0
% INFO    : Bus 96	: V=1.03788872, theta=-11.0788409 -> V=0.999999, theta=0.0
% INFO    : Bus 97	: V=1.06437655, theta=-25.7421539 -> V=1.0000025, theta=0.0
% INFO    : Bus 98	: V=1.03837053, theta=-15.4142215 -> V=1.0158755, theta=0.0
% INFO    : Bus 99	: V=1.03969161, theta=-7.84708686 -> V=1.0158755, theta=0.0
% INFO    : Bus 100	: V=1.00974165, theta=-16.7738896 -> V=0.999999, theta=0.0
% INFO    : Bus 101	: V=1.0068471, theta=-13.2748505 -> V=0.999999, theta=0.0
% INFO    : Bus 102	: V=1.026, theta=-20.4664045 -> V=1.0158755, theta=0.0
% INFO    : Bus 103	: V=1.02700008, theta=-6.46512627 -> V=1.0158755, theta=0.0
% INFO    : Bus 104	: V=1.06764508, theta=-3.66034483 -> V=1.0377785, theta=0.0
% INFO    : Bus 105	: V=1.05574625, theta=-6.19441787 -> V=0.9888895, theta=0.0
% INFO    : Bus 106	: V=1.0549998, theta=-10.3125909 -> V=1.022222, theta=0.0
% INFO    : Bus 107	: V=1.05344295, theta=-27.9027225 -> V=1.046665, theta=0.0
% INFO    : Bus 108	: V=1.06089799, theta=-15.8485362 -> V=1.027779, theta=0.0
% INFO    : Bus 109	: V=1.03797039, theta=-14.4512355 -> V=0.999999, theta=0.0
% INFO    : Bus 110	: V=1.02483778, theta=-10.3393883 -> V=1.0111115, theta=0.0
% INFO    : Bus 111	: V=1.00464656, theta=-23.2310562 -> V=1.015872, theta=0.0
% INFO    : Bus 112	: V=1.03104172, theta=-19.4769398 -> V=1.0000005, theta=0.0
% INFO    : Bus 113	: V=1.07137239, theta=-16.7086828 -> V=1.046665, theta=0.0
% INFO    : Bus 114	: V=1.04131933, theta=-14.515794 -> V=0.999999, theta=0.0
% INFO    : Bus 115	: V=1.05906621, theta=-5.0444808 -> V=1.078945, theta=0.0
% INFO    : Bus 116	: V=1.05893137, theta=-5.04325504 -> V=1.078945, theta=0.0
% INFO    : Bus 117	: V=1.01177151, theta=-18.5010626 -> V=1.0158755, theta=0.0
% INFO    : Bus 118	: V=1.06140338, theta=-14.9568759 -> V=1.023679, theta=0.0
% INFO    : Bus 119	: V=1.02092431, theta=-10.2131994 -> V=0.999999, theta=0.0
% INFO    : Bus 120	: V=1.01794152, theta=-9.19529036 -> V=0.999999, theta=0.0
% INFO    : Bus 121	: V=1.02798357, theta=-24.462783 -> V=1.0000025, theta=0.0
% INFO    : Bus 122	: V=1.026, theta=-7.07848147 -> V=1.0158755, theta=0.0
% INFO    : Bus 123	: V=1.02435037, theta=-7.22045701 -> V=1.0158755, theta=0.0
% INFO    : Bus 124	: V=1.03707848, theta=-25.0946664 -> V=1.022224, theta=0.0
% INFO    : Bus 125	: V=1.03689507, theta=-9.8309822 -> V=1.0158755, theta=0.0
% INFO    : Bus 126	: V=1.02949319, theta=-19.3051119 -> V=0.999999, theta=0.0
% INFO    : Bus 127	: V=1.03397146, theta=-19.3369693 -> V=1.0000005, theta=0.0
% INFO    : Bus 128	: V=1.02461147, theta=-12.4220533 -> V=1.015872, theta=0.0
% INFO    : Bus 129	: V=1.02325264, theta=-10.6875588 -> V=1.015872, theta=0.0
% INFO    : Bus 130	: V=1.04822415, theta=-10.3292151 -> V=1.046665, theta=0.0
% INFO    : Bus 131	: V=1.04604879, theta=-19.0300309 -> V=1.046665, theta=0.0
% INFO    : Bus 132	: V=1.065, theta=-22.1212095 -> V=1.000001, theta=0.0
% INFO    : Bus 133	: V=1.01877743, theta=-19.1629109 -> V=1.0000005, theta=0.0
% INFO    : Bus 134	: V=1.06237023, theta=-16.5704975 -> V=1.046665, theta=0.0
% INFO    : Bus 135	: V=1.07000739, theta=-18.7730983 -> V=1.046665, theta=0.0
% INFO    : Bus 136	: V=1.04427034, theta=-29.9688968 -> V=1.027779, theta=0.0
% INFO    : Bus 137	: V=1.032, theta=-17.2080894 -> V=1.015872, theta=0.0
% INFO    : Bus 138	: V=1.03902059, theta=-14.7661854 -> V=1.0233335, theta=0.0
% INFO    : Bus 139	: V=1.05095521, theta=-19.5598296 -> V=1.0000025, theta=0.0
% INFO    : Bus 140	: V=1.08235205, theta=-16.4504327 -> V=1.044445, theta=0.0
% INFO    : Bus 141	: V=1.08918012, theta=-13.1901619 -> V=1.078945, theta=0.0
% INFO    : Bus 142	: V=1.01633355, theta=-11.5272029 -> V=1.0158755, theta=0.0
% INFO    : Bus 143	: V=1.06497066, theta=-7.36988358 -> V=1.0377785, theta=0.0
% INFO    : Bus 144	: V=1.04710595, theta=-10.8088189 -> V=1.033333, theta=0.0
% INFO    : Bus 145	: V=1.07498756, theta=-6.54824762 -> V=1.0288895, theta=0.0
% INFO    : Bus 146	: V=1.082892, theta=-4.02229346 -> V=1.05263, theta=0.0
% INFO    : Bus 147	: V=1.03903903, theta=-15.2683972 -> V=0.999999, theta=0.0
% INFO    : Bus 148	: V=1.02578801, theta=-13.8079977 -> V=0.999999, theta=0.0
% INFO    : Bus 149	: V=1.04300695, theta=-30.1906078 -> V=1.022224, theta=0.0
% INFO    : Bus 150	: V=1.02466218, theta=-10.2265779 -> V=0.999999, theta=0.0
% INFO    : Bus 151	: V=0.988179896, theta=-26.921708 -> V=1.015872, theta=0.0
% INFO    : Bus 152	: V=0.988026042, theta=-25.6502451 -> V=1.015872, theta=0.0
% INFO    : Bus 153	: V=1.03360067, theta=-13.5219696 -> V=0.999999, theta=0.0
% INFO    : Bus 154	: V=1.06485541, theta=-9.84131996 -> V=1.0111115, theta=0.0
% INFO    : Bus 155	: V=0.973059153, theta=-24.3963974 -> V=1.0000025, theta=0.0
% INFO    : Bus 156	: V=0.988140868, theta=-26.9246626 -> V=1.015872, theta=0.0
% INFO    : Bus 157	: V=0.898621813, theta=-8.80299203 -> V=0.9444445, theta=0.0
% INFO    : Bus 158	: V=0.947, theta=-10.3100044 -> V=0.9444445, theta=0.0
% INFO    : Bus 159	: V=1.00924769, theta=-12.5289984 -> V=0.999999, theta=0.0
% INFO    : Bus 160	: V=1.06355817, theta=-4.61684596 -> V=0.9888895, theta=0.0
% INFO    : Bus 161	: V=1.06341169, theta=-4.62290462 -> V=0.9888895, theta=0.0
% INFO    : Bus 162	: V=1.02526511, theta=-18.2541106 -> V=1.022224, theta=0.0
% INFO    : Bus 163	: V=1.02136691, theta=-6.22432606 -> V=1.0158755, theta=0.0
% INFO    : Bus 164	: V=1.02136691, theta=-6.22432606 -> V=1.0158755, theta=0.0
% INFO    : Bus 165	: V=1.06958649, theta=-25.1648491 -> V=0.975, theta=0.0
% INFO    : Bus 166	: V=1.04218915, theta=-29.5709908 -> V=1.022224, theta=0.0
% INFO    : Bus 167	: V=1.03463882, theta=-29.8876265 -> V=1.022224, theta=0.0
% INFO    : Bus 168	: V=1.06967074, theta=-25.1582215 -> V=1.04444, theta=0.0
% INFO    : Bus 169	: V=1.02635835, theta=-27.5129079 -> V=1.022224, theta=0.0
% INFO    : Bus 170	: V=1.04989447, theta=-21.25518 -> V=1.027779, theta=0.0
% INFO    : Bus 171	: V=1.04571799, theta=-23.921678 -> V=1.027779, theta=0.0
% INFO    : Bus 172	: V=1.06465854, theta=-19.8892662 -> V=1.046665, theta=0.0
% INFO    : Bus 173	: V=1.06990619, theta=-6.73343649 -> V=1.0111115, theta=0.0
% INFO    : Bus 174	: V=1.06578124, theta=-11.2728218 -> V=1.033333, theta=0.0
% INFO    : Bus 175	: V=1.00313316, theta=-23.0001881 -> V=1.0000025, theta=0.0
% INFO    : Bus 176	: V=1.01288102, theta=-20.7011782 -> V=1.0000025, theta=0.0
% INFO    : Bus 177	: V=1.07314468, theta=-17.8713404 -> V=1.0, theta=0.0
% INFO    : Bus 178	: V=1.0830725, theta=-16.2722384 -> V=1.046665, theta=0.0
% INFO    : Bus 179	: V=1.08307272, theta=-16.2722396 -> V=1.046665, theta=0.0
% INFO    : Bus 180	: V=1.00374216, theta=-19.4961422 -> V=0.975, theta=0.0
% INFO    : Bus 181	: V=1.02635302, theta=-19.4481365 -> V=0.975, theta=0.0
% INFO    : Bus 182	: V=1.03407596, theta=-19.3298098 -> V=1.0000005, theta=0.0
% INFO    : Bus 183	: V=1.0830712, theta=-16.2722314 -> V=1.046665, theta=0.0
% INFO    : Bus 184	: V=1.04803579, theta=-26.3070703 -> V=1.0000025, theta=0.0
% INFO    : Bus 185	: V=1.03138099, theta=-10.647407 -> V=0.999999, theta=0.0
% INFO    : Bus 186	: V=1.01592709, theta=-15.4110518 -> V=1.0158755, theta=0.0
% INFO    : Bus 187	: V=1.06702478, theta=-18.5901086 -> V=1.027779, theta=0.0
% INFO    : Bus 188	: V=1.00764362, theta=-12.3640743 -> V=1.0158755, theta=0.0
% INFO    : Bus 189	: V=1.02544485, theta=-17.5610238 -> V=1.022224, theta=0.0
% INFO    : Bus 190	: V=1.02526044, theta=-24.3142213 -> V=1.0000025, theta=0.0
% INFO    : Bus 191	: V=1.02786229, theta=-23.8127607 -> V=1.0000025, theta=0.0
% INFO    : Bus 192	: V=0.948167592, theta=-8.50646106 -> V=0.9444445, theta=0.0
% INFO    : Bus 193	: V=1.02865291, theta=-27.5568671 -> V=1.022224, theta=0.0
% INFO    : Bus 194	: V=1.04988634, theta=-24.3324955 -> V=1.0000025, theta=0.0
% INFO    : Bus 195	: V=1.07074605, theta=-17.1657151 -> V=1.046665, theta=0.0
% INFO    : Bus 196	: V=1.037, theta=-25.5274656 -> V=1.0000025, theta=0.0
% INFO    : Bus 197	: V=1.08972445, theta=-16.6406808 -> V=1.0253755, theta=0.0
% INFO    : Bus 198	: V=1.08972593, theta=-16.6407234 -> V=1.0253755, theta=0.0
% INFO    : Bus 199	: V=1.01120807, theta=-29.4239285 -> V=1.0000025, theta=0.0
% INFO    : Bus 200	: V=1.02943998, theta=-25.1599728 -> V=1.0000025, theta=0.0
% INFO    : Bus 201	: V=1.03139799, theta=-35.5969945 -> V=1.022224, theta=0.0
% INFO    : Bus 202	: V=1.07085025, theta=-23.7657727 -> V=1.044445, theta=0.0
% INFO    : Bus 203	: V=1.05163856, theta=-6.8737545 -> V=0.9888895, theta=0.0
% INFO    : Bus 204	: V=0.994858112, theta=-29.3610009 -> V=1.015872, theta=0.0
% INFO    : Bus 205	: V=1.06135965, theta=-3.60703516 -> V=1.022222, theta=0.0
% INFO    : Bus 206	: V=1.07368512, theta=-0.369510092 -> V=1.0288895, theta=0.0
% INFO    : Bus 207	: V=1.08646264, theta=3.11960456 -> V=1.05263, theta=0.0
% INFO    : Bus 208	: V=1.00551982, theta=-27.1560447 -> V=1.015872, theta=0.0
% INFO    : Bus 209	: V=0.996089073, theta=-13.604839 -> V=1.015872, theta=0.0
% INFO    : Bus 210	: V=1.04473461, theta=-16.5361924 -> V=1.027779, theta=0.0
% INFO    : Bus 211	: V=1.02030808, theta=-21.6278906 -> V=1.015872, theta=0.0
% INFO    : Bus 212	: V=0.99918526, theta=-18.5691164 -> V=1.015872, theta=0.0
% INFO    : Bus 213	: V=0.99913751, theta=-18.4326103 -> V=1.015872, theta=0.0
% INFO    : Bus 214	: V=1.04375786, theta=-18.3663477 -> V=1.046665, theta=0.0
% INFO    : Bus 215	: V=1.04366977, theta=-18.3541162 -> V=1.046665, theta=0.0
% INFO    : Bus 216	: V=1.04835313, theta=-26.2018173 -> V=1.027779, theta=0.0
% INFO    : Bus 217	: V=1.06769262, theta=-22.848794 -> V=1.046665, theta=0.0
% INFO    : Bus 218	: V=1.00652687, theta=-12.1913988 -> V=1.0079355, theta=0.0
% INFO    : Bus 219	: V=1.01424905, theta=-26.0740352 -> V=1.022224, theta=0.0
% INFO    : Bus 220	: V=1.0377039, theta=-15.8150164 -> V=1.022224, theta=0.0
% INFO    : Bus 221	: V=1.03667419, theta=-26.4442522 -> V=1.022224, theta=0.0
% INFO    : Bus 222	: V=1.0189382, theta=1.74743884 -> V=1.0158755, theta=0.0
% INFO    : Bus 223	: V=1.03189674, theta=-19.4748379 -> V=0.999999, theta=0.0
% INFO    : Bus 224	: V=1.0837059, theta=-16.6249126 -> V=1.0111765, theta=0.0
% INFO    : Bus 225	: V=1.01333387, theta=-25.7515305 -> V=1.0000025, theta=0.0
% INFO    : Bus 226	: V=1.07309576, theta=-17.8703683 -> V=1.0, theta=0.0
% INFO    : Bus 227	: V=1.03995153, theta=-19.6320469 -> V=1.046665, theta=0.0
% INFO    : Bus 228	: V=1.03933453, theta=-19.6265917 -> V=1.046665, theta=0.0
% INFO    : Bus 229	: V=1.02467633, theta=-48.7977257 -> V=1.0079355, theta=0.0
% INFO    : Bus 230	: V=1.02225944, theta=-49.6988522 -> V=1.0079355, theta=0.0
% INFO    : Bus 231	: V=1.06006545, theta=-21.8894442 -> V=1.0000025, theta=0.0
% INFO    : Bus 232	: V=1.04175434, theta=-19.4736199 -> V=1.033334, theta=0.0
% INFO    : Bus 233	: V=1.03514665, theta=-26.2323818 -> V=1.022224, theta=0.0
% INFO    : Bus 234	: V=1.03777101, theta=-8.89348747 -> V=1.0111115, theta=0.0
% INFO    : Bus 235	: V=1.05029335, theta=-7.37307889 -> V=0.975, theta=0.0
% INFO    : Bus 236	: V=1.05029335, theta=-7.37307889 -> V=1.0111115, theta=0.0
% INFO    : Bus 237	: V=1.06350269, theta=-4.00673903 -> V=0.9888895, theta=0.0
% INFO    : Bus 238	: V=1.04591592, theta=-11.7879792 -> V=1.000001, theta=0.0
% INFO    : Bus 239	: V=1.01635278, theta=-12.8174626 -> V=0.999999, theta=0.0
% INFO    : Bus 240	: V=1.02086166, theta=-21.4959932 -> V=1.022224, theta=0.0
% INFO    : Bus 241	: V=1.01280646, theta=-54.221137 -> V=1.0079355, theta=0.0
% INFO    : Bus 242	: V=1.01720072, theta=-24.7905577 -> V=1.0000025, theta=0.0
% INFO    : Bus 243	: V=1.02705199, theta=-25.3257645 -> V=1.000001, theta=0.0
% INFO    : Bus 244	: V=1.0042467, theta=-26.4545083 -> V=1.015872, theta=0.0
% INFO    : Bus 245	: V=1.01387389, theta=-28.2337774 -> V=1.0000025, theta=0.0
% INFO    : Bus 246	: V=1.04504153, theta=-23.4298099 -> V=1.000001, theta=0.0
% INFO    : Bus 247	: V=1.02807369, theta=-25.6668099 -> V=1.0000025, theta=0.0
% INFO    : Bus 248	: V=0.99867764, theta=-6.62716414 -> V=0.999999, theta=0.0
% INFO    : Bus 249	: V=1.05286244, theta=-5.19345951 -> V=1.0111115, theta=0.0
% INFO    : Bus 250	: V=1.07676311, theta=-15.6598677 -> V=1.046665, theta=0.0
% INFO    : Bus 251	: V=1.03892461, theta=-29.524035 -> V=1.0000025, theta=0.0
% INFO    : Bus 252	: V=1.01034866, theta=-18.924385 -> V=1.0158755, theta=0.0
% INFO    : Bus 253	: V=1.02471069, theta=-28.569048 -> V=1.022224, theta=0.0
% INFO    : Bus 254	: V=1.02658308, theta=-18.1724718 -> V=1.022224, theta=0.0
% INFO    : Bus 255	: V=1.03818268, theta=-15.7051442 -> V=1.0158755, theta=0.0
% INFO    : Bus 256	: V=1.02704, theta=-18.7226235 -> V=1.0158755, theta=0.0
% INFO    : Bus 257	: V=1.01727476, theta=-21.332965 -> V=0.999999, theta=0.0
% INFO    : Bus 258	: V=1.03168787, theta=-23.9264389 -> V=1.0000025, theta=0.0
% INFO    : Bus 259	: V=1.07055072, theta=-23.8012338 -> V=1.044445, theta=0.0
% INFO    : Bus 260	: V=1.071, theta=-18.4891264 -> V=1.000001, theta=0.0
% INFO    : Bus 261	: V=1.04487603, theta=-13.8803978 -> V=1.0158755, theta=0.0
% INFO    : Bus 262	: V=1.07518406, theta=-11.9469181 -> V=1.0377785, theta=0.0
% INFO    : Bus 263	: V=0.998, theta=-30.131873 -> V=1.0000025, theta=0.0
% INFO    : Bus 264	: V=1.0706298, theta=-4.32754665 -> V=0.9888895, theta=0.0
% INFO    : Bus 265	: V=1.05733959, theta=-5.73407247 -> V=0.9888895, theta=0.0
% INFO    : Bus 266	: V=1.06916517, theta=-1.21141707 -> V=1.05921, theta=0.0
% INFO    : Bus 267	: V=1.01227765, theta=-18.3857952 -> V=1.0000005, theta=0.0
% INFO    : Bus 268	: V=1.07401812, theta=-15.5405893 -> V=1.046665, theta=0.0
% INFO    : Bus 269	: V=1.07717983, theta=-15.8976728 -> V=1.046665, theta=0.0
% INFO    : Bus 270	: V=0.98529321, theta=-20.2268963 -> V=1.0000025, theta=0.0
% INFO    : Bus 271	: V=0.996415925, theta=-30.2769741 -> V=1.0000025, theta=0.0
% INFO    : Bus 272	: V=1.04387439, theta=-12.0049937 -> V=1.033334, theta=0.0
% INFO    : Bus 273	: V=1.04398529, theta=-12.0062584 -> V=1.033334, theta=0.0
% INFO    : Bus 274	: V=1.02078336, theta=-16.3650972 -> V=1.015872, theta=0.0
% INFO    : Bus 275	: V=1.04159672, theta=-12.8903715 -> V=1.046665, theta=0.0
% INFO    : Bus 276	: V=1.06468115, theta=-11.0820783 -> V=1.022222, theta=0.0
% INFO    : Bus 277	: V=1.07474287, theta=-21.358818 -> V=1.04444, theta=0.0
% INFO    : Bus 278	: V=1.08484509, theta=-15.6367446 -> V=1.07237, theta=0.0
% INFO    : Bus 279	: V=1.03239756, theta=-24.4220317 -> V=1.022224, theta=0.0
% INFO    : Bus 280	: V=1.07449623, theta=-21.415486 -> V=1.04444, theta=0.0
% INFO    : Bus 281	: V=1.02169554, theta=-23.0416736 -> V=0.999999, theta=0.0
% INFO    : Bus 282	: V=1.04952963, theta=-27.6577956 -> V=1.027779, theta=0.0
% INFO    : Bus 283	: V=1.01615325, theta=-12.1675445 -> V=1.0158755, theta=0.0
% INFO    : Bus 284	: V=0.998678131, theta=-6.62717569 -> V=0.999999, theta=0.0
% INFO    : Bus 285	: V=1.03014003, theta=-30.7339585 -> V=1.022224, theta=0.0
% INFO    : Bus 286	: V=1.01272902, theta=1.29348937 -> V=1.0158755, theta=0.0
% INFO    : Bus 287	: V=1.07764865, theta=-15.3184269 -> V=1.046665, theta=0.0
% INFO    : Bus 288	: V=1.07759057, theta=-15.3275679 -> V=1.046665, theta=0.0
% INFO    : Bus 289	: V=1.04413826, theta=-19.6210841 -> V=1.022224, theta=0.0
% INFO    : Bus 290	: V=1.02789867, theta=-27.9986301 -> V=1.022224, theta=0.0
% INFO    : Bus 291	: V=1.07429487, theta=2.56885878 -> V=0.9888895, theta=0.0
% INFO    : Bus 292	: V=1.0774287, theta=-6.47587556 -> V=1.033333, theta=0.0
% INFO    : Bus 293	: V=1.01974454, theta=-26.3827007 -> V=1.0000025, theta=0.0
% INFO    : Bus 294	: V=1.01655769, theta=-14.8975095 -> V=0.999999, theta=0.0
% INFO    : Bus 295	: V=1.01657002, theta=-14.8978891 -> V=0.999999, theta=0.0
% INFO    : Bus 296	: V=1.01624692, theta=-13.8570441 -> V=1.0158755, theta=0.0
% INFO    : Bus 297	: V=1.06237719, theta=-6.9458869 -> V=0.9888895, theta=0.0
% INFO    : Bus 298	: V=1.01340032, theta=-17.4418694 -> V=1.0158755, theta=0.0
% INFO    : Bus 299	: V=0.992704734, theta=-20.7778211 -> V=0.999999, theta=0.0
% INFO    : Bus 300	: V=1.00249415, theta=-12.4867348 -> V=0.999999, theta=0.0
% INFO    : Bus 301	: V=1.07060618, theta=-1.56075935 -> V=1.033333, theta=0.0
% INFO    : Bus 302	: V=1.07015, theta=1.16691182 -> V=0.9888895, theta=0.0
% INFO    : Bus 303	: V=1.00078629, theta=-13.1575397 -> V=1.015872, theta=0.0
% INFO    : Bus 304	: V=1.01807893, theta=-11.6294269 -> V=0.999999, theta=0.0
% INFO    : Bus 305	: V=1.002367, theta=-30.3816446 -> V=1.0000025, theta=0.0
% INFO    : Bus 306	: V=0.995920621, theta=-24.3304234 -> V=1.015872, theta=0.0
% INFO    : Bus 307	: V=1.038, theta=-17.0089556 -> V=0.999999, theta=0.0
% INFO    : Bus 308	: V=1.01574032, theta=-12.3189387 -> V=1.0158755, theta=0.0
% INFO    : Bus 309	: V=1.01724013, theta=-36.2906052 -> V=1.022224, theta=0.0
% INFO    : Bus 310	: V=1.01840116, theta=-28.7641929 -> V=1.0000025, theta=0.0
% INFO    : Bus 311	: V=1.02285778, theta=-28.6151816 -> V=1.015872, theta=0.0
% INFO    : Bus 312	: V=1.02312291, theta=-28.637789 -> V=1.015872, theta=0.0
% INFO    : Bus 313	: V=1.01859078, theta=-28.6453999 -> V=1.022224, theta=0.0
% INFO    : Bus 314	: V=1.03107569, theta=-6.00068844 -> V=1.000001, theta=0.0
% INFO    : Bus 315	: V=1.03844683, theta=-21.0395499 -> V=1.0000025, theta=0.0
% INFO    : Bus 316	: V=1.06806644, theta=-17.4699646 -> V=1.044445, theta=0.0
% INFO    : Bus 317	: V=1.06603789, theta=-18.7797964 -> V=1.027779, theta=0.0
% INFO    : Bus 318	: V=1.01167843, theta=-27.2163282 -> V=1.0000025, theta=0.0
% INFO    : Bus 319	: V=1.05005854, theta=-24.6049022 -> V=1.0000025, theta=0.0
% INFO    : Bus 320	: V=0.998751652, theta=-20.579866 -> V=1.0000005, theta=0.0
% INFO    : Bus 321	: V=1.042, theta=-27.8101289 -> V=1.0000025, theta=0.0
% INFO    : Bus 322	: V=1.06421298, theta=-8.84839978 -> V=1.022222, theta=0.0
% INFO    : Bus 323	: V=1.03162328, theta=-25.1609147 -> V=1.0000025, theta=0.0
% INFO    : Bus 324	: V=1.0316332, theta=-15.5042849 -> V=1.044445, theta=0.0
% INFO    : Bus 325	: V=1.07019351, theta=-15.5308225 -> V=1.078945, theta=0.0
% INFO    : Bus 326	: V=1.02464124, theta=-13.1794038 -> V=0.999999, theta=0.0
% INFO    : Bus 327	: V=1.02177606, theta=-13.896882 -> V=0.999999, theta=0.0
% INFO    : Bus 328	: V=1.02507743, theta=-21.0960187 -> V=1.0000025, theta=0.0
% INFO    : Bus 329	: V=1.04443663, theta=-18.3600141 -> V=1.044445, theta=0.0
% INFO    : Bus 330	: V=1.00546956, theta=-23.7172325 -> V=1.0000025, theta=0.0
% INFO    : Bus 331	: V=1.06169618, theta=-9.66462723 -> V=1.022222, theta=0.0
% INFO    : Bus 332	: V=1.04288218, theta=-24.6990458 -> V=1.0000025, theta=0.0
% INFO    : Bus 333	: V=1.06693583, theta=-21.0391024 -> V=1.044445, theta=0.0
% INFO    : Bus 334	: V=1.02680339, theta=-30.5115154 -> V=1.015872, theta=0.0
% INFO    : Bus 335	: V=1.037, theta=-25.7229754 -> V=1.0233335, theta=0.0
% INFO    : Bus 336	: V=1.04977896, theta=-47.4190686 -> V=1.0079355, theta=0.0
% INFO    : Bus 337	: V=1.01937431, theta=-18.7018012 -> V=0.999999, theta=0.0
% INFO    : Bus 338	: V=1.013, theta=-24.3798319 -> V=1.0000025, theta=0.0
% INFO    : Bus 339	: V=1.03666453, theta=-29.2693937 -> V=1.0000025, theta=0.0
% INFO    : Bus 340	: V=1.03933002, theta=-25.271613 -> V=1.0000025, theta=0.0
% INFO    : Bus 341	: V=1.02658256, theta=-27.6181115 -> V=1.0000025, theta=0.0
% INFO    : Bus 342	: V=1.03418978, theta=-25.8853827 -> V=1.022224, theta=0.0
% INFO    : Bus 343	: V=1.06804438, theta=-25.591784 -> V=1.0000025, theta=0.0
% INFO    : Bus 344	: V=1.03215534, theta=-9.27766752 -> V=1.0158755, theta=0.0
% INFO    : Bus 345	: V=1.04788818, theta=-7.23490686 -> V=1.0377785, theta=0.0
% INFO    : Bus 346	: V=1.01443497, theta=-19.4827993 -> V=1.015872, theta=0.0
% INFO    : Bus 347	: V=1.05490704, theta=-14.7825866 -> V=1.027779, theta=0.0
% INFO    : Bus 348	: V=1.05961374, theta=-8.10085832 -> V=1.046665, theta=0.0
% INFO    : Bus 349	: V=1.02204851, theta=-28.9314982 -> V=1.015872, theta=0.0
% INFO    : Bus 350	: V=1.05594067, theta=-12.0921181 -> V=1.022222, theta=0.0
% INFO    : Bus 351	: V=1.09304786, theta=-3.26031955 -> V=1.073685, theta=0.0
% INFO    : Bus 352	: V=1.09379477, theta=-3.33320339 -> V=1.073685, theta=0.0
% INFO    : Bus 353	: V=1.07440108, theta=-16.2724378 -> V=1.044445, theta=0.0
% INFO    : Bus 354	: V=1.06873132, theta=-18.4629217 -> V=1.046665, theta=0.0
% INFO    : Bus 355	: V=1.01775633, theta=-19.2851605 -> V=1.0000005, theta=0.0
% INFO    : Bus 356	: V=1.01630725, theta=-19.1931279 -> V=1.0000025, theta=0.0
% INFO    : Bus 357	: V=1.03909392, theta=-7.7082671 -> V=1.0000025, theta=0.0
% INFO    : Bus 358	: V=1.02509519, theta=-21.2692385 -> V=1.0000025, theta=0.0
% INFO    : Bus 359	: V=0.999745038, theta=-11.8675893 -> V=1.0158755, theta=0.0
% INFO    : Bus 360	: V=1.02552736, theta=-21.2406648 -> V=1.0000025, theta=0.0
% INFO    : Bus 361	: V=1.01449877, theta=-25.3026155 -> V=1.015872, theta=0.0
% INFO    : Bus 362	: V=1.02312193, theta=-24.0367162 -> V=1.0000025, theta=0.0
% INFO    : Bus 363	: V=1.06282536, theta=-20.026759 -> V=1.0, theta=0.0
% INFO    : Bus 364	: V=1.05383787, theta=-19.5067721 -> V=1.044445, theta=0.0
% INFO    : Bus 365	: V=1.07062813, theta=-6.79086172 -> V=1.0111115, theta=0.0
% INFO    : Bus 366	: V=1.078, theta=-15.7389619 -> V=1.046665, theta=0.0
% INFO    : Bus 367	: V=1.02483581, theta=-9.84610406 -> V=0.999999, theta=0.0
% INFO    : Bus 368	: V=1.0530118, theta=-6.55989592 -> V=1.0111115, theta=0.0
% INFO    : Bus 369	: V=1.08001571, theta=-5.27821637 -> V=1.072365, theta=0.0
% INFO    : Bus 370	: V=1.07344507, theta=-6.08725656 -> V=1.072365, theta=0.0
% INFO    : Bus 371	: V=1.06990797, theta=-18.8918083 -> V=1.046665, theta=0.0
% INFO    : Bus 372	: V=1.06163098, theta=-16.7333823 -> V=1.046665, theta=0.0
% INFO    : Bus 373	: V=1.01060892, theta=1.54485222 -> V=1.0158755, theta=0.0
% INFO    : Bus 374	: V=1.04036752, theta=-2.02329568 -> V=1.0377785, theta=0.0
% INFO    : Bus 375	: V=1.06972744, theta=-18.904779 -> V=1.046665, theta=0.0
% INFO    : Bus 376	: V=0.992862274, theta=-49.7240983 -> V=1.0079355, theta=0.0
% INFO    : Bus 377	: V=1.01755062, theta=-31.461719 -> V=1.022224, theta=0.0
% INFO    : Bus 378	: V=1.02852303, theta=-38.8090559 -> V=1.0079355, theta=0.0
% INFO    : Bus 379	: V=1.00841456, theta=-8.86719426 -> V=1.0158755, theta=0.0
% INFO    : Bus 380	: V=1.03429807, theta=-17.4561113 -> V=0.999999, theta=0.0
% INFO    : Bus 381	: V=1.05273729, theta=-12.7823931 -> V=1.0111115, theta=0.0
% INFO    : Bus 382	: V=1.07506983, theta=-7.97103959 -> V=1.072365, theta=0.0
% INFO    : Bus 383	: V=1.03330504, theta=-24.3110586 -> V=1.027779, theta=0.0
% INFO    : Bus 384	: V=1.01631073, theta=-5.62252873 -> V=1.0158755, theta=0.0
% INFO    : Bus 385	: V=1.03061479, theta=-10.8429189 -> V=1.0000025, theta=0.0
% INFO    : Bus 386	: V=0.99868086, theta=-27.5097871 -> V=1.0000025, theta=0.0
% INFO    : Bus 387	: V=1.01799395, theta=-1.97799761 -> V=1.0000025, theta=0.0
% INFO    : Bus 388	: V=1.07533274, theta=-15.88219 -> V=1.044445, theta=0.0
% INFO    : Bus 389	: V=1.05628436, theta=-20.9280434 -> V=1.000001, theta=0.0
% INFO    : Bus 390	: V=1.05388895, theta=-10.7824615 -> V=1.022222, theta=0.0
% INFO    : Bus 391	: V=1.03329436, theta=-16.1635582 -> V=0.999999, theta=0.0
% INFO    : Bus 392	: V=1.02446885, theta=-16.50349 -> V=1.015872, theta=0.0
% INFO    : Bus 393	: V=1.0059878, theta=-25.3231168 -> V=1.0000025, theta=0.0
% INFO    : Bus 394	: V=1.00348379, theta=-27.7602674 -> V=1.015872, theta=0.0
% INFO    : Bus 395	: V=1.02648299, theta=-12.4526203 -> V=1.0158755, theta=0.0
% INFO    : Bus 396	: V=1.04095876, theta=-20.6221685 -> V=1.0000025, theta=0.0
% INFO    : Bus 397	: V=1.04106045, theta=-20.6160397 -> V=1.0000025, theta=0.0
% INFO    : Bus 398	: V=1.03617585, theta=-4.71334332 -> V=1.0158755, theta=0.0
% INFO    : Bus 399	: V=1.02987752, theta=-28.2550904 -> V=1.0000025, theta=0.0
% INFO    : Bus 400	: V=1.03076036, theta=-30.7106386 -> V=1.022224, theta=0.0
% INFO    : Bus 401	: V=1.07382782, theta=-20.7468835 -> V=1.0000025, theta=0.0
% INFO    : Bus 402	: V=1.0373148, theta=-22.1556044 -> V=1.0000025, theta=0.0
% INFO    : Bus 403	: V=1.03161697, theta=-17.8602669 -> V=0.999999, theta=0.0
% INFO    : Bus 404	: V=1.03857793, theta=-26.2712165 -> V=1.000001, theta=0.0
% INFO    : Bus 405	: V=1.03023869, theta=-13.2819987 -> V=0.999999, theta=0.0
% INFO    : Bus 406	: V=1.01966782, theta=-16.918623 -> V=0.999999, theta=0.0
% INFO    : Bus 407	: V=1.01632581, theta=-15.8079016 -> V=0.999999, theta=0.0
% INFO    : Bus 408	: V=1.02752471, theta=-20.4098416 -> V=1.022224, theta=0.0
% INFO    : Bus 409	: V=1.03172888, theta=-26.4622196 -> V=1.022224, theta=0.0
% INFO    : Bus 410	: V=1.063668, theta=-28.6980972 -> V=1.0000025, theta=0.0
% INFO    : Bus 411	: V=1.0266863, theta=-34.3799224 -> V=1.022224, theta=0.0
% INFO    : Bus 412	: V=1.02464743, theta=-27.3520372 -> V=1.022224, theta=0.0
% INFO    : Bus 413	: V=1.00719231, theta=-8.03967954 -> V=1.0158755, theta=0.0
% INFO    : Bus 414	: V=1.03927403, theta=-47.6474515 -> V=1.0079355, theta=0.0
% INFO    : Bus 415	: V=0.983976692, theta=-19.5411899 -> V=0.999999, theta=0.0
% INFO    : Bus 416	: V=1.02140753, theta=-19.7310262 -> V=1.0158755, theta=0.0
% INFO    : Bus 417	: V=1.07068867, theta=-19.0591841 -> V=1.046665, theta=0.0
% INFO    : Bus 418	: V=1.02395668, theta=-30.814333 -> V=1.0000025, theta=0.0
% INFO    : Bus 419	: V=1.02440533, theta=-17.2052117 -> V=1.0000005, theta=0.0
% INFO    : Bus 420	: V=1.05295477, theta=-27.9488039 -> V=1.0000025, theta=0.0
% INFO    : Bus 421	: V=1.05595304, theta=-27.5344826 -> V=1.0000025, theta=0.0
% INFO    : Bus 422	: V=1.01787687, theta=-32.8072364 -> V=1.015872, theta=0.0
% INFO    : Bus 423	: V=1.06163453, theta=-21.4604446 -> V=1.0000025, theta=0.0
% INFO    : Bus 424	: V=1.08317201, theta=-18.4152639 -> V=1.044445, theta=0.0
% INFO    : Bus 425	: V=1.03004866, theta=-2.16322813 -> V=1.0158755, theta=0.0
% INFO    : Bus 426	: V=1.06077432, theta=1.2790379 -> V=1.0377785, theta=0.0
% INFO    : Bus 427	: V=1.02820792, theta=-17.7965681 -> V=1.0000005, theta=0.0
% INFO    : Bus 428	: V=1.01454153, theta=-9.76052415 -> V=0.999999, theta=0.0
% INFO    : Bus 429	: V=1.03132614, theta=-40.1779974 -> V=1.0079355, theta=0.0
% INFO    : Bus 430	: V=1.02499864, theta=-21.5836662 -> V=1.015872, theta=0.0
% INFO    : Bus 431	: V=1.07994946, theta=-18.1068141 -> V=1.046665, theta=0.0
% INFO    : Bus 432	: V=1.04626604, theta=-25.777003 -> V=1.0000025, theta=0.0
% INFO    : Bus 433	: V=1.01867593, theta=-35.3853679 -> V=1.0000025, theta=0.0
% INFO    : Bus 434	: V=1.00742952, theta=-17.7114372 -> V=1.0000005, theta=0.0
% INFO    : Bus 435	: V=1.01271912, theta=-13.5911125 -> V=0.999999, theta=0.0
% INFO    : Bus 436	: V=1.0247405, theta=-25.2942559 -> V=1.000001, theta=0.0
% INFO    : Bus 437	: V=1.00900001, theta=-17.2575819 -> V=1.015872, theta=0.0
% INFO    : Bus 438	: V=1.04698436, theta=-10.0801856 -> V=1.000001, theta=0.0
% INFO    : Bus 439	: V=1.01176485, theta=-18.8350128 -> V=1.0000005, theta=0.0
% INFO    : Bus 440	: V=1.01336254, theta=-12.2449985 -> V=1.0158755, theta=0.0
% INFO    : Bus 441	: V=1.02061389, theta=-26.9584525 -> V=1.0000025, theta=0.0
% INFO    : Bus 442	: V=1.02631385, theta=-14.3957006 -> V=0.999999, theta=0.0
% INFO    : Bus 443	: V=1.02364548, theta=3.04922517 -> V=1.0158755, theta=0.0
% INFO    : Bus 444	: V=1.07014474, theta=-10.2672228 -> V=1.033333, theta=0.0
% INFO    : Bus 445	: V=1.06961688, theta=-10.9022484 -> V=1.033333, theta=0.0
% INFO    : Bus 446	: V=1.07983075, theta=-12.1008222 -> V=1.033333, theta=0.0
% INFO    : Bus 447	: V=1.04509627, theta=-7.29885847 -> V=1.006667, theta=0.0
% INFO    : Bus 448	: V=0.991293706, theta=-12.4192528 -> V=1.015872, theta=0.0
% INFO    : Bus 449	: V=1.01658259, theta=1.50568254 -> V=1.0158755, theta=0.0
% INFO    : Bus 450	: V=1.08005074, theta=4.914471 -> V=1.0401685, theta=0.0
% INFO    : Bus 451	: V=1.08859986, theta=6.31937994 -> V=1.072365, theta=0.0
% INFO    : Bus 452	: V=0.988755516, theta=-25.8864721 -> V=1.0000025, theta=0.0
% INFO    : Bus 453	: V=1.03213783, theta=-43.5103944 -> V=1.0079355, theta=0.0
% INFO    : Bus 454	: V=1.05808921, theta=-39.1134416 -> V=1.04444, theta=0.0
% INFO    : Bus 455	: V=1.01830425, theta=-24.9391983 -> V=1.0000025, theta=0.0
% INFO    : Bus 456	: V=1.06316337, theta=-10.5187315 -> V=1.022222, theta=0.0
% INFO    : Bus 457	: V=1.06271953, theta=-10.5637975 -> V=1.022222, theta=0.0
% INFO    : Bus 458	: V=0.973143738, theta=-29.0487347 -> V=1.015872, theta=0.0
% INFO    : Bus 459	: V=1.0540518, theta=-26.9218443 -> V=1.046665, theta=0.0
% INFO    : Bus 460	: V=1.04567855, theta=-24.5916536 -> V=1.06579, theta=0.0
% INFO    : Bus 461	: V=1.05634505, theta=-25.0106295 -> V=1.0000025, theta=0.0
% INFO    : Bus 462	: V=1.01791329, theta=-3.86440722 -> V=1.0158755, theta=0.0
% INFO    : Bus 463	: V=1.01255567, theta=-49.6545557 -> V=1.0079355, theta=0.0
% INFO    : Bus 464	: V=1.0264039, theta=-18.9540878 -> V=1.022224, theta=0.0
% INFO    : Bus 465	: V=1.171, theta=-7.85850213 -> V=0.985555, theta=0.0
% INFO    : Bus 466	: V=1.05483105, theta=-10.6780915 -> V=1.033333, theta=0.0
% INFO    : Bus 467	: V=1.042, theta=-35.0204193 -> V=1.0079355, theta=0.0
% INFO    : Bus 468	: V=0.996272084, theta=-21.3044738 -> V=1.0000005, theta=0.0
% INFO    : Bus 469	: V=1.01949495, theta=-22.8896587 -> V=1.0000005, theta=0.0
% INFO    : Bus 470	: V=1.05312205, theta=-12.7991195 -> V=1.0111115, theta=0.0
% INFO    : Bus 471	: V=1.04887868, theta=-18.7254203 -> V=0.999999, theta=0.0
% INFO    : Bus 472	: V=1.03169432, theta=-13.0931358 -> V=0.999999, theta=0.0
% INFO    : Bus 473	: V=1.08782908, theta=2.69415254 -> V=1.052629, theta=0.0
% INFO    : Bus 474	: V=1.08781795, theta=2.69367333 -> V=1.052629, theta=0.0
% INFO    : Bus 475	: V=1.03361261, theta=-23.4185513 -> V=1.027779, theta=0.0
% INFO    : Bus 476	: V=1.01785211, theta=-6.2714971 -> V=1.0158755, theta=0.0
% INFO    : Bus 477	: V=1.01913833, theta=-28.5067558 -> V=1.0000025, theta=0.0
% INFO    : Bus 478	: V=1.00726229, theta=-6.47770674 -> V=1.0158755, theta=0.0
% INFO    : Bus 479	: V=0.967557801, theta=-6.76504242 -> V=0.9444445, theta=0.0
% INFO    : Bus 480	: V=1.00283433, theta=-6.45850231 -> V=0.999999, theta=0.0
% INFO    : Bus 481	: V=1.02625567, theta=-13.7696654 -> V=0.999999, theta=0.0
% INFO    : Bus 482	: V=1.03351893, theta=-10.2792563 -> V=1.0111115, theta=0.0
% INFO    : Bus 483	: V=0.990307479, theta=-8.67530167 -> V=1.0158755, theta=0.0
% INFO    : Bus 484	: V=1.03004207, theta=-25.7208472 -> V=1.0000025, theta=0.0
% INFO    : Bus 485	: V=1.03906153, theta=-20.3931622 -> V=1.022224, theta=0.0
% INFO    : Bus 486	: V=0.98530331, theta=-44.0364337 -> V=1.0079355, theta=0.0
% INFO    : Bus 487	: V=1.0381806, theta=-21.954532 -> V=1.0000025, theta=0.0
% INFO    : Bus 488	: V=1.02104806, theta=-35.044403 -> V=1.022224, theta=0.0
% INFO    : Bus 489	: V=1.04231229, theta=-22.501842 -> V=1.0000025, theta=0.0
% INFO    : Bus 490	: V=1.0037867, theta=-17.1187171 -> V=1.0158755, theta=0.0
% INFO    : Bus 491	: V=1.07044917, theta=-7.72729071 -> V=1.0111115, theta=0.0
% INFO    : Bus 492	: V=1.05656133, theta=-13.1132781 -> V=1.033334, theta=0.0
% INFO    : Bus 493	: V=1.01791584, theta=-20.4905241 -> V=0.999999, theta=0.0
% INFO    : Bus 494	: V=1.09563305, theta=-8.09430671 -> V=1.04783, theta=0.0
% INFO    : Bus 495	: V=1.09018804, theta=-8.08724875 -> V=1.078945, theta=0.0
% INFO    : Bus 496	: V=1.09012992, theta=-8.07789914 -> V=1.078945, theta=0.0
% INFO    : Bus 497	: V=1.09017833, theta=-8.07490055 -> V=1.078945, theta=0.0
% INFO    : Bus 498	: V=1.09016783, theta=-8.07185937 -> V=1.078945, theta=0.0
% INFO    : Bus 499	: V=1.02145277, theta=-25.0429848 -> V=1.0000025, theta=0.0
% INFO    : Bus 500	: V=1.08033457, theta=5.03074917 -> V=1.0403385, theta=0.0
% INFO    : Bus 501	: V=1.08045853, theta=5.06944428 -> V=1.0404135, theta=0.0
% INFO    : Bus 502	: V=1.08877546, theta=6.35662928 -> V=1.072365, theta=0.0
% INFO    : Bus 503	: V=1.03243738, theta=-27.9586778 -> V=1.022224, theta=0.0
% INFO    : Bus 504	: V=1.06267329, theta=-16.213763 -> V=1.027779, theta=0.0
% INFO    : Bus 505	: V=1.04701492, theta=-11.6559187 -> V=1.016666, theta=0.0
% INFO    : Bus 506	: V=1.06998253, theta=-8.34993986 -> V=1.0288895, theta=0.0
% INFO    : Bus 507	: V=1.03043251, theta=-38.0835705 -> V=1.0079355, theta=0.0
% INFO    : Bus 508	: V=1.01420216, theta=-19.7925995 -> V=1.022224, theta=0.0
% INFO    : Bus 509	: V=1.00247632, theta=-18.1531807 -> V=0.999999, theta=0.0
% INFO    : Bus 510	: V=1.05553526, theta=-23.9776348 -> V=1.027779, theta=0.0
% INFO    : Bus 511	: V=1.01505969, theta=-32.7034665 -> V=1.015872, theta=0.0
% INFO    : Bus 512	: V=1.05330231, theta=-27.8647332 -> V=1.046665, theta=0.0
% INFO    : Bus 513	: V=1.09037734, theta=-5.83742485 -> V=1.072365, theta=0.0
% INFO    : Bus 514	: V=1.02551894, theta=-31.3761388 -> V=1.022224, theta=0.0
% INFO    : Bus 515	: V=0.989741095, theta=-16.8809329 -> V=0.999999, theta=0.0
% INFO    : Bus 516	: V=1.0259574, theta=-26.3707673 -> V=1.0000025, theta=0.0
% INFO    : Bus 517	: V=1.02369313, theta=-2.5375873 -> V=0.9682545, theta=0.0
% INFO    : Bus 518	: V=0.998890202, theta=-13.9021049 -> V=1.015874, theta=0.0
% INFO    : Bus 519	: V=1.03449355, theta=-25.7284393 -> V=1.022224, theta=0.0
% INFO    : Bus 520	: V=1.02646965, theta=-13.7817784 -> V=0.999999, theta=0.0
% INFO    : Bus 521	: V=1.02548077, theta=-13.4051768 -> V=0.999999, theta=0.0
% INFO    : Bus 522	: V=1.05764116, theta=-8.83686595 -> V=1.0111115, theta=0.0
% INFO    : Bus 523	: V=1.06726767, theta=-4.25693471 -> V=1.072365, theta=0.0
% INFO    : Bus 524	: V=1.04822717, theta=-26.2065146 -> V=1.027779, theta=0.0
% INFO    : Bus 525	: V=1.01798845, theta=-10.8042687 -> V=1.015872, theta=0.0
% INFO    : Bus 526	: V=1.05692386, theta=-6.42959785 -> V=1.046665, theta=0.0
% INFO    : Bus 527	: V=1.0211905, theta=-9.83101303 -> V=1.0158755, theta=0.0
% INFO    : Bus 528	: V=1.02090551, theta=-9.84847295 -> V=1.0158755, theta=0.0
% INFO    : Bus 529	: V=1.017, theta=-16.4409776 -> V=0.999999, theta=0.0
% INFO    : Bus 530	: V=1.01999059, theta=-19.1237837 -> V=1.0000005, theta=0.0
% INFO    : Bus 531	: V=1.0199694, theta=-19.1269031 -> V=1.0000005, theta=0.0
% INFO    : Bus 532	: V=1.01038056, theta=-17.1845524 -> V=1.0000005, theta=0.0
% INFO    : Bus 533	: V=1.04907629, theta=-19.9153214 -> V=1.022224, theta=0.0
% INFO    : Bus 534	: V=1.06378282, theta=-15.6154737 -> V=1.04444, theta=0.0
% INFO    : Bus 535	: V=1.0129495, theta=-23.9557976 -> V=1.022224, theta=0.0
% INFO    : Bus 536	: V=1.02417913, theta=-15.4005429 -> V=0.999999, theta=0.0
% INFO    : Bus 537	: V=1.0318181, theta=-31.4437587 -> V=1.022224, theta=0.0
% INFO    : Bus 538	: V=1.07380767, theta=-21.0482642 -> V=1.000001, theta=0.0
% INFO    : Bus 539	: V=1.01831651, theta=-11.5410275 -> V=0.999999, theta=0.0
% INFO    : Bus 540	: V=1.05885608, theta=-9.45713998 -> V=1.0111115, theta=0.0
% INFO    : Bus 541	: V=1.05880624, theta=-9.4627496 -> V=1.0111115, theta=0.0
% INFO    : Bus 542	: V=1.03739302, theta=-22.0148492 -> V=1.027779, theta=0.0
% INFO    : Bus 543	: V=1.07033348, theta=-19.0528654 -> V=1.046665, theta=0.0
% INFO    : Bus 544	: V=1.0, theta=-31.6628951 -> V=1.0000025, theta=0.0
% INFO    : Bus 545	: V=1.0237572, theta=-26.2534232 -> V=1.0000025, theta=0.0
% INFO    : Bus 546	: V=1.00366183, theta=-22.8739961 -> V=1.0000025, theta=0.0
% INFO    : Bus 547	: V=0.988407961, theta=-28.1256826 -> V=1.0000025, theta=0.0
% INFO    : Bus 548	: V=1.00653689, theta=-31.4642126 -> V=1.0000025, theta=0.0
% INFO    : Bus 549	: V=1.04937652, theta=-24.2767077 -> V=1.0000025, theta=0.0
% INFO    : Bus 550	: V=1.03719372, theta=-24.7871085 -> V=1.000001, theta=0.0
% INFO    : Bus 551	: V=1.00854258, theta=-17.5488688 -> V=0.999999, theta=0.0
% INFO    : Bus 552	: V=0.986654538, theta=-24.8832853 -> V=1.0000005, theta=0.0
% INFO    : Bus 553	: V=1.03003698, theta=2.16242851 -> V=1.0158755, theta=0.0
% INFO    : Bus 554	: V=1.08283932, theta=-17.368116 -> V=1.044445, theta=0.0
% INFO    : Bus 555	: V=1.0828413, theta=-17.3681379 -> V=1.044445, theta=0.0
% INFO    : Bus 556	: V=1.06963288, theta=-17.2676524 -> V=1.044445, theta=0.0
% INFO    : Bus 557	: V=1.07394554, theta=-15.1190773 -> V=1.046665, theta=0.0
% INFO    : Bus 558	: V=1.00464645, theta=-20.8330205 -> V=0.999999, theta=0.0
% INFO    : Bus 559	: V=1.00364733, theta=-19.419806 -> V=1.0158755, theta=0.0
% INFO    : Bus 560	: V=1.06187306, theta=-25.2174141 -> V=1.0000025, theta=0.0
% INFO    : Bus 561	: V=1.03517791, theta=-30.0820421 -> V=1.027779, theta=0.0
% INFO    : Bus 562	: V=0.999414587, theta=-13.2455665 -> V=1.015872, theta=0.0
% INFO    : Bus 563	: V=1.04685041, theta=-8.38968213 -> V=1.046665, theta=0.0
% INFO    : Bus 564	: V=1.03142474, theta=-10.4661888 -> V=1.0000025, theta=0.0
% INFO    : Bus 565	: V=1.0350675, theta=-40.6696649 -> V=1.022224, theta=0.0
% INFO    : Bus 566	: V=0.999414657, theta=-26.3023674 -> V=1.0000025, theta=0.0
% INFO    : Bus 567	: V=0.992057248, theta=-22.968461 -> V=1.015872, theta=0.0
% INFO    : Bus 568	: V=1.01834356, theta=-27.34502 -> V=1.0000025, theta=0.0
% INFO    : Bus 569	: V=1.0055528, theta=0.916894818 -> V=1.0158755, theta=0.0
% INFO    : Bus 570	: V=1.01589824, theta=-30.2011209 -> V=1.0000025, theta=0.0
% INFO    : Bus 571	: V=1.00021903, theta=-14.677851 -> V=0.999999, theta=0.0
% INFO    : Bus 572	: V=1.01120807, theta=-29.4239285 -> V=1.0000025, theta=0.0
% INFO    : Bus 573	: V=1.03838895, theta=-19.3251252 -> V=1.022224, theta=0.0
% INFO    : Bus 574	: V=1.01805833, theta=-20.3371423 -> V=0.999999, theta=0.0
% INFO    : Bus 575	: V=1.05140782, theta=-7.88349383 -> V=1.0111115, theta=0.0
% INFO    : Bus 576	: V=1.06504258, theta=-17.9052145 -> V=1.044445, theta=0.0
% INFO    : Bus 577	: V=0.996112683, theta=-30.5896709 -> V=1.0000025, theta=0.0
% INFO    : Bus 578	: V=1.05668374, theta=-20.0510964 -> V=1.046665, theta=0.0
% INFO    : Bus 579	: V=1.05659323, theta=-20.0585652 -> V=1.046665, theta=0.0
% INFO    : Bus 580	: V=1.05736411, theta=-14.9702555 -> V=1.046665, theta=0.0
% INFO    : Bus 581	: V=1.05115845, theta=-11.5233567 -> V=1.06579, theta=0.0
% INFO    : Bus 582	: V=1.029, theta=-17.7716542 -> V=1.0000005, theta=0.0
% INFO    : Bus 583	: V=1.03576964, theta=-14.2144469 -> V=0.999999, theta=0.0
% INFO    : Bus 584	: V=0.993244276, theta=-0.62007355 -> V=1.0158755, theta=0.0
% INFO    : Bus 585	: V=1.01, theta=-10.4743706 -> V=0.999999, theta=0.0
% INFO    : Bus 586	: V=1.00478269, theta=-4.13697001 -> V=1.0158755, theta=0.0
% INFO    : Bus 587	: V=1.03266082, theta=-12.1726562 -> V=0.999999, theta=0.0
% INFO    : Bus 588	: V=1.0286962, theta=-25.6300951 -> V=1.000001, theta=0.0
% INFO    : Bus 589	: V=1.07065873, theta=1.42822091 -> V=0.9888895, theta=0.0
% INFO    : Bus 590	: V=1.01967923, theta=-40.1310599 -> V=1.0079355, theta=0.0
% INFO    : Bus 591	: V=1.0245199, theta=-33.8665767 -> V=1.0000025, theta=0.0
% INFO    : Bus 592	: V=1.01111824, theta=-25.0413202 -> V=1.0000025, theta=0.0
% INFO    : Bus 593	: V=1.0956178, theta=-8.09423874 -> V=1.047825, theta=0.0
% INFO    : Bus 594	: V=1.09004493, theta=-8.14967483 -> V=1.078945, theta=0.0
% INFO    : Bus 595	: V=1.01463585, theta=-34.475068 -> V=1.022224, theta=0.0
% INFO    : Bus 596	: V=1.03962659, theta=-15.7689463 -> V=1.0158755, theta=0.0
% INFO    : Bus 597	: V=1.07154213, theta=-12.3068794 -> V=1.0377785, theta=0.0
% INFO    : Bus 598	: V=1.01892693, theta=-25.5376914 -> V=1.022224, theta=0.0
% INFO    : Bus 599	: V=1.0111845, theta=-27.6881414 -> V=1.015872, theta=0.0
% INFO    : Bus 600	: V=1.02772679, theta=-25.8070398 -> V=1.000001, theta=0.0
% INFO    : Bus 601	: V=1.03207643, theta=-23.1047306 -> V=1.0000025, theta=0.0
% INFO    : Bus 602	: V=1.06142956, theta=-21.6656802 -> V=1.044445, theta=0.0
% INFO    : Bus 603	: V=1.06907371, theta=-40.5114762 -> V=1.04444, theta=0.0
% INFO    : Bus 604	: V=1.06907371, theta=-40.5114762 -> V=1.04444, theta=0.0
% INFO    : Bus 605	: V=1.0690812, theta=-40.5116731 -> V=1.04444, theta=0.0
% INFO    : Bus 606	: V=1.04548945, theta=-43.665665 -> V=1.0079355, theta=0.0
% INFO    : Bus 607	: V=1.06907265, theta=-40.5114485 -> V=1.04444, theta=0.0
% INFO    : Bus 608	: V=1.0148553, theta=-18.6110146 -> V=1.0000005, theta=0.0
% INFO    : Bus 609	: V=1.02, theta=-8.4152724 -> V=0.975, theta=0.0
% INFO    : Bus 610	: V=1.02250079, theta=-10.2156356 -> V=1.0111115, theta=0.0
% INFO    : Bus 611	: V=1.00944492, theta=-24.781586 -> V=1.022224, theta=0.0
% INFO    : Bus 612	: V=1.00929308, theta=-19.7339538 -> V=1.0000005, theta=0.0
% INFO    : Bus 613	: V=0.976759944, theta=-33.3028244 -> V=1.0000025, theta=0.0
% INFO    : Bus 614	: V=1.05726263, theta=-11.3075266 -> V=1.0377785, theta=0.0
% INFO    : Bus 615	: V=1.08195924, theta=-17.7787448 -> V=1.044445, theta=0.0
% INFO    : Bus 616	: V=1.0868257, theta=-13.8552439 -> V=1.078945, theta=0.0
% INFO    : Bus 617	: V=0.998829351, theta=-23.6976243 -> V=1.0000005, theta=0.0
% INFO    : Bus 618	: V=0.996784482, theta=-23.7474124 -> V=1.0000005, theta=0.0
% INFO    : Bus 619	: V=1.02815981, theta=-17.7903978 -> V=1.0000005, theta=0.0
% INFO    : Bus 620	: V=1.02816902, theta=-17.7913884 -> V=1.0000005, theta=0.0
% INFO    : Bus 621	: V=1.03611579, theta=-17.4537144 -> V=1.0158755, theta=0.0
% INFO    : Bus 622	: V=1.00291195, theta=-9.09659152 -> V=0.999999, theta=0.0
% INFO    : Bus 623	: V=1.049, theta=-6.2362434 -> V=1.0111115, theta=0.0
% INFO    : Bus 624	: V=1.02008067, theta=-45.3308276 -> V=1.0079355, theta=0.0
% INFO    : Bus 625	: V=1.02865852, theta=-17.7183088 -> V=1.015872, theta=0.0
% INFO    : Bus 626	: V=0.999113093, theta=-16.1351875 -> V=1.015872, theta=0.0
% INFO    : Bus 627	: V=1.03828297, theta=-14.6279387 -> V=1.0233335, theta=0.0
% INFO    : Bus 628	: V=1.06749457, theta=-14.4435886 -> V=1.026184, theta=0.0
% INFO    : Bus 629	: V=1.02163723, theta=-16.0450023 -> V=1.0000005, theta=0.0
% INFO    : Bus 630	: V=1.07774026, theta=-15.5909039 -> V=1.046665, theta=0.0
% INFO    : Bus 631	: V=1.07799682, theta=-15.5225176 -> V=1.046665, theta=0.0
% INFO    : Bus 632	: V=1.02492094, theta=-15.2509309 -> V=0.999999, theta=0.0
% INFO    : Bus 633	: V=1.03336272, theta=-48.0282806 -> V=1.0079355, theta=0.0
% INFO    : Bus 634	: V=0.997362857, theta=-11.5146834 -> V=1.0158755, theta=0.0
% INFO    : Bus 635	: V=1.011, theta=-21.5564318 -> V=1.015872, theta=0.0
% INFO    : Bus 636	: V=1.01445107, theta=-22.29884 -> V=0.999999, theta=0.0
% INFO    : Bus 637	: V=1.04693581, theta=-23.4609093 -> V=1.022224, theta=0.0
% INFO    : Bus 638	: V=1.04173453, theta=-35.0790352 -> V=1.0079355, theta=0.0
% INFO    : Bus 639	: V=1.06965916, theta=0.674582836 -> V=0.9888895, theta=0.0
% INFO    : Bus 640	: V=1.083, theta=-13.8513533 -> V=1.078945, theta=0.0
% INFO    : Bus 641	: V=1.00286325, theta=-6.45898734 -> V=0.999999, theta=0.0
% INFO    : Bus 642	: V=1.02348407, theta=-9.19493125 -> V=0.999999, theta=0.0
% INFO    : Bus 643	: V=1.01700063, theta=-11.7164054 -> V=0.999999, theta=0.0
% INFO    : Bus 644	: V=1.01565153, theta=-11.8208814 -> V=0.999999, theta=0.0
% INFO    : Bus 645	: V=1.0141036, theta=-23.9754174 -> V=1.022224, theta=0.0
% INFO    : Bus 646	: V=0.99481196, theta=-9.51471344 -> V=1.0158755, theta=0.0
% INFO    : Bus 647	: V=1.02233822, theta=-18.2356235 -> V=1.015872, theta=0.0
% INFO    : Bus 648	: V=1.01326395, theta=-17.2884382 -> V=0.999999, theta=0.0
% INFO    : Bus 649	: V=1.04388881, theta=-24.9953864 -> V=1.0000025, theta=0.0
% INFO    : Bus 650	: V=1.01959238, theta=-35.6118522 -> V=1.022224, theta=0.0
% INFO    : Bus 651	: V=1.06320614, theta=-22.3447858 -> V=1.0000025, theta=0.0
% INFO    : Bus 652	: V=1.04401058, theta=-22.2027488 -> V=1.0000025, theta=0.0
% INFO    : Bus 653	: V=1.06516211, theta=-17.8776914 -> V=1.044445, theta=0.0
% INFO    : Bus 654	: V=1.03029401, theta=-6.19593024 -> V=1.0158755, theta=0.0
% INFO    : Bus 655	: V=1.03990937, theta=-13.3637276 -> V=1.0000025, theta=0.0
% INFO    : Bus 656	: V=1.03594422, theta=-26.812203 -> V=1.015872, theta=0.0
% INFO    : Bus 657	: V=1.06328222, theta=-0.753133709 -> V=1.0377785, theta=0.0
% INFO    : Bus 658	: V=1.02225793, theta=-20.6860554 -> V=1.0000005, theta=0.0
% INFO    : Bus 659	: V=1.01236637, theta=0.406894592 -> V=1.0158755, theta=0.0
% INFO    : Bus 660	: V=1.02096032, theta=-38.4259005 -> V=1.022224, theta=0.0
% INFO    : Bus 661	: V=1.06987546, theta=-23.0921302 -> V=1.000001, theta=0.0
% INFO    : Bus 662	: V=1.04869921, theta=-20.1403646 -> V=1.022224, theta=0.0
% INFO    : Bus 663	: V=1.07697789, theta=-2.24745147 -> V=1.072365, theta=0.0
% INFO    : Bus 664	: V=1.0760907, theta=-2.30481633 -> V=1.072365, theta=0.0
% INFO    : Bus 665	: V=1.07698323, theta=-2.24876747 -> V=1.072365, theta=0.0
% INFO    : Bus 666	: V=1.07607319, theta=-2.31533799 -> V=1.072365, theta=0.0
% INFO    : Bus 667	: V=1.06121591, theta=-9.63781762 -> V=1.000001, theta=0.0
% INFO    : Bus 668	: V=1.05957927, theta=-4.92344096 -> V=1.006667, theta=0.0
% INFO    : Bus 669	: V=1.0322287, theta=-17.4831633 -> V=1.022224, theta=0.0
% INFO    : Bus 670	: V=1.05174853, theta=-12.5912157 -> V=1.027779, theta=0.0
% INFO    : Bus 671	: V=1.00256426, theta=-16.1887619 -> V=0.999999, theta=0.0
% INFO    : Bus 672	: V=1.05255203, theta=-10.3220907 -> V=1.000001, theta=0.0
% INFO    : Bus 673	: V=1.03902412, theta=-23.8050142 -> V=1.022224, theta=0.0
% INFO    : Bus 674	: V=1.00035078, theta=-20.0873947 -> V=0.999999, theta=0.0
% INFO    : Bus 675	: V=1.06753059, theta=-7.51345605 -> V=1.0377785, theta=0.0
% INFO    : Bus 676	: V=1.04294899, theta=-33.0679888 -> V=1.022224, theta=0.0
% INFO    : Bus 677	: V=1.06469084, theta=-28.8401136 -> V=1.04444, theta=0.0
% INFO    : Bus 678	: V=1.00698469, theta=-36.4595561 -> V=1.022224, theta=0.0
% INFO    : Bus 679	: V=1.0584384, theta=-20.7001941 -> V=1.022224, theta=0.0
% INFO    : Bus 680	: V=1.01811372, theta=-22.8717624 -> V=1.0000005, theta=0.0
% INFO    : Bus 681	: V=1.03513196, theta=-21.4269653 -> V=1.0000025, theta=0.0
% INFO    : Bus 682	: V=1.00947436, theta=-23.4382284 -> V=1.0000005, theta=0.0
% INFO    : Bus 683	: V=0.89, theta=-5.24930069 -> V=0.9444445, theta=0.0
% INFO    : Bus 684	: V=1.08425848, theta=-2.36264022 -> V=1.07237, theta=0.0
% INFO    : Bus 685	: V=0.99008055, theta=-18.2549874 -> V=0.999999, theta=0.0
% INFO    : Bus 686	: V=1.08427909, theta=-2.37949326 -> V=1.07237, theta=0.0
% INFO    : Bus 687	: V=1.04173437, theta=-22.3663267 -> V=1.027779, theta=0.0
% INFO    : Bus 688	: V=1.02409382, theta=-18.1642553 -> V=1.027779, theta=0.0
% INFO    : Bus 689	: V=1.03819415, theta=-18.3628485 -> V=0.999999, theta=0.0
% INFO    : Bus 690	: V=1.07599918, theta=-16.1326176 -> V=1.046665, theta=0.0
% INFO    : Bus 691	: V=1.0315296, theta=-25.061752 -> V=1.000001, theta=0.0
% INFO    : Bus 692	: V=1.04594098, theta=-12.544183 -> V=1.033334, theta=0.0
% INFO    : Bus 693	: V=1.04600269, theta=-12.5422961 -> V=1.033334, theta=0.0
% INFO    : Bus 694	: V=1.05428542, theta=-11.7872841 -> V=1.022222, theta=0.0
% INFO    : Bus 695	: V=1.06728872, theta=-8.77960486 -> V=1.0288895, theta=0.0
% INFO    : Bus 696	: V=1.023, theta=-2.13682732 -> V=0.975, theta=0.0
% INFO    : Bus 697	: V=1.02, theta=-2.1677786 -> V=0.975, theta=0.0
% INFO    : Bus 698	: V=1.02, theta=-2.58696197 -> V=0.975, theta=0.0
% INFO    : Bus 699	: V=1.03079614, theta=-4.85424614 -> V=1.0111115, theta=0.0
% INFO    : Bus 700	: V=1.03031104, theta=-5.28350253 -> V=1.0111115, theta=0.0
% INFO    : Bus 701	: V=1.02872644, theta=-29.6874465 -> V=1.022224, theta=0.0
% INFO    : Bus 702	: V=1.03034688, theta=-30.834667 -> V=1.022224, theta=0.0
% INFO    : Bus 703	: V=1.05811859, theta=-27.0749794 -> V=1.04444, theta=0.0
% INFO    : Bus 704	: V=0.896, theta=-5.82060806 -> V=0.9444445, theta=0.0
% INFO    : Bus 705	: V=1.00276717, theta=-20.9821215 -> V=1.022224, theta=0.0
% INFO    : Bus 706	: V=1.06643464, theta=-24.6429528 -> V=0.975, theta=0.0
% INFO    : Bus 707	: V=1.06640741, theta=-24.6449395 -> V=0.975, theta=0.0
% INFO    : Bus 708	: V=1.06643167, theta=-24.6446375 -> V=0.975, theta=0.0
% INFO    : Bus 709	: V=1.02958425, theta=-27.6665489 -> V=1.022224, theta=0.0
% INFO    : Bus 710	: V=1.03433669, theta=-29.3196178 -> V=1.022224, theta=0.0
% INFO    : Bus 711	: V=1.06643786, theta=-24.6343854 -> V=1.04444, theta=0.0
% INFO    : Bus 712	: V=1.03693442, theta=-21.9976705 -> V=1.022224, theta=0.0
% INFO    : Bus 713	: V=1.01155564, theta=-21.2453293 -> V=1.015872, theta=0.0
% INFO    : Bus 714	: V=1.05935052, theta=-16.2069875 -> V=1.033334, theta=0.0
% INFO    : Bus 715	: V=0.983640563, theta=-22.8510174 -> V=1.0158755, theta=0.0
% INFO    : Bus 716	: V=1.04162405, theta=-12.7936555 -> V=1.022224, theta=0.0
% INFO    : Bus 717	: V=0.983306973, theta=-23.1596358 -> V=1.0158755, theta=0.0
% INFO    : Bus 718	: V=1.04177645, theta=-36.8325216 -> V=1.022224, theta=0.0
% INFO    : Bus 719	: V=1.00708707, theta=0.126758775 -> V=1.0158755, theta=0.0
% INFO    : Bus 720	: V=1.08469403, theta=-13.975496 -> V=1.04688, theta=0.0
% INFO    : Bus 721	: V=1.03249291, theta=-25.1036916 -> V=1.000001, theta=0.0
% INFO    : Bus 722	: V=1.00135701, theta=-15.0945471 -> V=0.999999, theta=0.0
% INFO    : Bus 723	: V=1.00299033, theta=-29.7999248 -> V=1.015872, theta=0.0
% INFO    : Bus 724	: V=1.05047024, theta=-12.5395426 -> V=1.015874, theta=0.0
% INFO    : Bus 725	: V=1.06112338, theta=-13.0860047 -> V=1.015874, theta=0.0
% INFO    : Bus 726	: V=1.06087098, theta=-9.23506497 -> V=1.0200005, theta=0.0
% INFO    : Bus 727	: V=1.01227321, theta=-18.3856579 -> V=1.0000005, theta=0.0
% INFO    : Bus 728	: V=1.01259174, theta=-18.0065088 -> V=1.0000005, theta=0.0
% INFO    : Bus 729	: V=1.00974632, theta=-18.0660174 -> V=1.0000005, theta=0.0
% INFO    : Bus 730	: V=1.03111607, theta=-13.7620131 -> V=1.0000005, theta=0.0
% INFO    : Bus 731	: V=1.04359165, theta=-41.7207611 -> V=1.022224, theta=0.0
% INFO    : Bus 732	: V=0.977, theta=-13.8718425 -> V=0.999999, theta=0.0
% INFO    : Bus 733	: V=1.00436306, theta=-5.282189 -> V=1.0158755, theta=0.0
% INFO    : Bus 734	: V=1.06185403, theta=-13.7594182 -> V=1.027779, theta=0.0
% INFO    : Bus 735	: V=1.05018811, theta=-12.3694009 -> V=1.000001, theta=0.0
% INFO    : Bus 736	: V=1.032, theta=-23.0888124 -> V=1.0000025, theta=0.0
% INFO    : Bus 737	: V=1.06306636, theta=-14.6533789 -> V=1.027779, theta=0.0
% INFO    : Bus 738	: V=1.07403214, theta=-15.4626256 -> V=1.046665, theta=0.0
% INFO    : Bus 739	: V=1.029688, theta=-24.7266157 -> V=1.022224, theta=0.0
% INFO    : Bus 740	: V=1.03223685, theta=-24.6144995 -> V=1.022224, theta=0.0
% INFO    : Bus 741	: V=1.02287275, theta=-10.3380923 -> V=1.0158755, theta=0.0
% INFO    : Bus 742	: V=1.06751437, theta=-7.71811099 -> V=1.0377785, theta=0.0
% INFO    : Bus 743	: V=0.983, theta=-13.3948977 -> V=0.999999, theta=0.0
% INFO    : Bus 744	: V=0.975, theta=-12.9619282 -> V=0.999999, theta=0.0
% INFO    : Bus 745	: V=1.011, theta=-33.4609808 -> V=1.022224, theta=0.0
% INFO    : Bus 746	: V=1.0297505, theta=-41.3234724 -> V=1.0079355, theta=0.0
% INFO    : Bus 747	: V=1.02101522, theta=-35.0462669 -> V=1.022224, theta=0.0
% INFO    : Bus 748	: V=1.03008308, theta=-24.8167115 -> V=1.0000025, theta=0.0
% INFO    : Bus 749	: V=1.01756337, theta=-20.9503963 -> V=0.999999, theta=0.0
% INFO    : Bus 750	: V=0.998678755, theta=-6.62719907 -> V=0.999999, theta=0.0
% INFO    : Bus 751	: V=1.0141123, theta=-10.2329111 -> V=1.0158755, theta=0.0
% INFO    : Bus 752	: V=1.03619748, theta=-17.0409307 -> V=0.999999, theta=0.0
% INFO    : Bus 753	: V=1.04483968, theta=-26.0238391 -> V=1.046665, theta=0.0
% INFO    : Bus 754	: V=1.04595771, theta=-25.0291156 -> V=1.06579, theta=0.0
% INFO    : Bus 755	: V=1.00401617, theta=-13.2918384 -> V=1.015872, theta=0.0
% INFO    : Bus 756	: V=1.07382759, theta=-15.6643133 -> V=1.046665, theta=0.0
% INFO    : Bus 757	: V=1.06697842, theta=-5.77518771 -> V=0.9888895, theta=0.0
% INFO    : Bus 758	: V=1.06697869, theta=-5.77498784 -> V=0.9888895, theta=0.0
% INFO    : Bus 759	: V=1.037, theta=-13.638275 -> V=0.999999, theta=0.0
% INFO    : Bus 760	: V=1.035, theta=-14.4831397 -> V=0.999999, theta=0.0
% INFO    : Bus 761	: V=0.590567935, theta=-13.5783355 -> V=0.825, theta=0.0
% INFO    : Bus 762	: V=1.0495781, theta=-13.9242448 -> V=1.0158755, theta=0.0
% INFO    : Bus 763	: V=1.01561121, theta=-0.97760622 -> V=1.0158755, theta=0.0
% INFO    : Bus 764	: V=1.02260915, theta=-18.1599885 -> V=1.0158755, theta=0.0
% INFO    : Bus 765	: V=1.02047219, theta=-6.28223312 -> V=1.0158755, theta=0.0
% INFO    : Bus 766	: V=1.03600796, theta=-26.2341859 -> V=1.022224, theta=0.0
% INFO    : Bus 767	: V=1.04266878, theta=-36.7383182 -> V=1.022224, theta=0.0
% INFO    : Bus 768	: V=1.06558052, theta=-31.1366871 -> V=1.04444, theta=0.0
% INFO    : Bus 769	: V=1.03141807, theta=-11.0299237 -> V=0.975, theta=0.0
% INFO    : Bus 770	: V=1.03141807, theta=-11.0299237 -> V=0.975, theta=0.0
% INFO    : Bus 771	: V=1.03141807, theta=-11.0299237 -> V=0.975, theta=0.0
% INFO    : Bus 772	: V=1.03038768, theta=-11.0299237 -> V=0.999999, theta=0.0
% INFO    : Bus 773	: V=0.997012537, theta=-30.6733972 -> V=1.0000025, theta=0.0
% INFO    : Bus 774	: V=1.06692832, theta=-14.3144449 -> V=1.027779, theta=0.0
% INFO    : Bus 775	: V=1.02269774, theta=0.740177382 -> V=1.0158755, theta=0.0
% INFO    : Bus 776	: V=1.07531877, theta=4.95905383 -> V=1.0377785, theta=0.0
% INFO    : Bus 777	: V=1.03223693, theta=-37.6025894 -> V=1.0079355, theta=0.0
% INFO    : Bus 778	: V=1.03213903, theta=-37.6180268 -> V=1.0079355, theta=0.0
% INFO    : Bus 779	: V=1.03257876, theta=-37.5828188 -> V=1.0079355, theta=0.0
% INFO    : Bus 780	: V=0.995774314, theta=-15.8057584 -> V=1.0158755, theta=0.0
% INFO    : Bus 781	: V=1.01878271, theta=-25.3047461 -> V=1.0000025, theta=0.0
% INFO    : Bus 782	: V=1.04596584, theta=-19.0415207 -> V=1.046665, theta=0.0
% INFO    : Bus 783	: V=1.04591782, theta=-19.3665111 -> V=1.046665, theta=0.0
% INFO    : Bus 784	: V=1.01888456, theta=-8.7998067 -> V=0.999999, theta=0.0
% INFO    : Bus 785	: V=1.00719085, theta=-11.2592176 -> V=0.975, theta=0.0
% INFO    : Bus 786	: V=1.01110346, theta=-10.4997805 -> V=0.975, theta=0.0
% INFO    : Bus 787	: V=1.01009336, theta=-10.4997805 -> V=0.999999, theta=0.0
% INFO    : Bus 788	: V=1.00618466, theta=-11.2592176 -> V=0.999999, theta=0.0
% INFO    : Bus 789	: V=1.03116462, theta=-6.36839581 -> V=1.0111115, theta=0.0
% INFO    : Bus 790	: V=1.07894324, theta=-0.230818413 -> V=1.072365, theta=0.0
% INFO    : Bus 791	: V=1.00073888, theta=-13.8502851 -> V=1.0158755, theta=0.0
% INFO    : Bus 792	: V=1.02358803, theta=-18.3213812 -> V=1.022224, theta=0.0
% INFO    : Bus 793	: V=1.03332371, theta=-14.7541766 -> V=1.0158755, theta=0.0
% INFO    : Bus 794	: V=1.02835135, theta=-15.4184378 -> V=1.0158755, theta=0.0
% INFO    : Bus 795	: V=1.02032962, theta=-14.4784432 -> V=0.999999, theta=0.0
% INFO    : Bus 796	: V=1.01860278, theta=-45.2818841 -> V=1.0079355, theta=0.0
% INFO    : Bus 797	: V=1.01321109, theta=-17.7068624 -> V=0.999999, theta=0.0
% INFO    : Bus 798	: V=1.01025242, theta=-15.2396789 -> V=0.999999, theta=0.0
% INFO    : Bus 799	: V=1.06467051, theta=-7.54967056 -> V=1.072365, theta=0.0
% INFO    : Bus 800	: V=1.02, theta=-3.37701754 -> V=0.975, theta=0.0
% INFO    : Bus 801	: V=1.022, theta=-3.59918439 -> V=0.975, theta=0.0
% INFO    : Bus 802	: V=1.021, theta=-3.63813467 -> V=0.975, theta=0.0
% INFO    : Bus 803	: V=1.03046402, theta=-5.63728415 -> V=1.0111115, theta=0.0
% INFO    : Bus 804	: V=1.0307237, theta=-5.92515975 -> V=1.0111115, theta=0.0
% INFO    : Bus 805	: V=1.04313946, theta=-28.9975506 -> V=1.0000025, theta=0.0
% INFO    : Bus 806	: V=1.00795216, theta=-29.4003658 -> V=1.0000025, theta=0.0
% INFO    : Bus 807	: V=1.03687939, theta=-19.7083665 -> V=1.046665, theta=0.0
% INFO    : Bus 808	: V=1.03743867, theta=-19.6464929 -> V=1.046665, theta=0.0
% INFO    : Bus 809	: V=1.02027463, theta=-29.8127064 -> V=1.015872, theta=0.0
% INFO    : Bus 810	: V=0.999038198, theta=-29.764145 -> V=1.0000025, theta=0.0
% INFO    : Bus 811	: V=1.04563546, theta=-18.1684158 -> V=1.046665, theta=0.0
% INFO    : Bus 812	: V=1.01545928, theta=-17.131806 -> V=0.999999, theta=0.0
% INFO    : Bus 813	: V=1.00902165, theta=-20.1709083 -> V=1.015872, theta=0.0
% INFO    : Bus 814	: V=1.023, theta=-12.239036 -> V=1.015872, theta=0.0
% INFO    : Bus 815	: V=1.024, theta=-9.96408312 -> V=1.015872, theta=0.0
% INFO    : Bus 816	: V=1.07225328, theta=-18.2909642 -> V=1.046665, theta=0.0
% INFO    : Bus 817	: V=1.01910096, theta=-45.3130461 -> V=1.0079355, theta=0.0
% INFO    : Bus 818	: V=1.03274847, theta=-30.0828597 -> V=1.0000025, theta=0.0
% INFO    : Bus 819	: V=1.03247197, theta=-30.0890102 -> V=1.0000025, theta=0.0
% INFO    : Bus 820	: V=1.04614212, theta=-19.3043743 -> V=1.046665, theta=0.0
% INFO    : Bus 821	: V=1.04625522, theta=-19.3008054 -> V=1.046665, theta=0.0
% INFO    : Bus 822	: V=1.06823914, theta=-13.8067475 -> V=1.027779, theta=0.0
% INFO    : Bus 823	: V=1.07545672, theta=-4.32424243 -> V=1.0266685, theta=0.0
% INFO    : Bus 824	: V=1.00065804, theta=-15.2379774 -> V=1.015872, theta=0.0
% INFO    : Bus 825	: V=1.042, theta=-24.2524663 -> V=1.0000025, theta=0.0
% INFO    : Bus 826	: V=1.06888925, theta=-39.6692645 -> V=1.04444, theta=0.0
% INFO    : Bus 827	: V=1.07202192, theta=-35.4780036 -> V=1.07237, theta=0.0
% INFO    : Bus 828	: V=1.05939489, theta=-4.05592778 -> V=1.022222, theta=0.0
% INFO    : Bus 829	: V=1.032, theta=-25.0639315 -> V=1.0000025, theta=0.0
% INFO    : Bus 830	: V=0.951580398, theta=-6.70189769 -> V=0.9444445, theta=0.0
% INFO    : Bus 831	: V=1.01099303, theta=-15.6981891 -> V=1.015872, theta=0.0
% INFO    : Bus 832	: V=1.04381345, theta=-22.0946867 -> V=1.0000025, theta=0.0
% INFO    : Bus 833	: V=1.04554468, theta=-20.1836464 -> V=1.027779, theta=0.0
% INFO    : Bus 834	: V=1.05881762, theta=-11.4706664 -> V=1.015874, theta=0.0
% INFO    : Bus 835	: V=0.984, theta=-28.8874682 -> V=1.0000025, theta=0.0
% INFO    : Bus 836	: V=1.02515465, theta=-24.3115584 -> V=1.0000025, theta=0.0
% INFO    : Bus 837	: V=1.02505767, theta=-24.3088715 -> V=1.0000025, theta=0.0
% INFO    : Bus 838	: V=1.04938946, theta=-27.9699582 -> V=1.0000025, theta=0.0
% INFO    : Bus 839	: V=1.00302646, theta=-26.0610738 -> V=1.0000025, theta=0.0
% INFO    : Bus 840	: V=1.06381824, theta=-14.4565685 -> V=1.027779, theta=0.0
% INFO    : Bus 841	: V=1.02779819, theta=-17.84523 -> V=1.015872, theta=0.0
% INFO    : Bus 842	: V=1.04973965, theta=-14.7510259 -> V=1.027779, theta=0.0
% INFO    : Bus 843	: V=1.02995014, theta=-27.6318964 -> V=1.0000025, theta=0.0
% INFO    : Bus 844	: V=0.996088714, theta=-30.1935938 -> V=1.0000025, theta=0.0
% INFO    : Bus 845	: V=1.01787157, theta=-31.236396 -> V=1.015872, theta=0.0
% INFO    : Bus 846	: V=1.0191391, theta=-31.2790914 -> V=1.015872, theta=0.0
% INFO    : Bus 847	: V=1.01959298, theta=-31.2099338 -> V=1.015872, theta=0.0
% INFO    : Bus 848	: V=1.07389178, theta=-20.74392 -> V=1.0000025, theta=0.0
% INFO    : Bus 849	: V=1.08736672, theta=-17.3204934 -> V=1.044445, theta=0.0
% INFO    : Bus 850	: V=1.08627846, theta=-14.2475823 -> V=1.078945, theta=0.0
% INFO    : Bus 851	: V=1.04787772, theta=-8.11718145 -> V=1.015874, theta=0.0
% INFO    : Bus 852	: V=1.06488025, theta=-4.48432552 -> V=1.0000005, theta=0.0
% INFO    : Bus 853	: V=1.07325193, theta=2.44158756 -> V=1.05263, theta=0.0
% INFO    : Bus 854	: V=1.00542659, theta=-16.6802897 -> V=1.0000005, theta=0.0
% INFO    : Bus 855	: V=1.0249804, theta=-38.3173557 -> V=1.0079355, theta=0.0
% INFO    : Bus 856	: V=1.01238719, theta=-30.6962322 -> V=1.0000025, theta=0.0
% INFO    : Bus 857	: V=1.01745484, theta=-24.7350011 -> V=1.0000025, theta=0.0
% INFO    : Bus 858	: V=1.06989473, theta=-18.8943297 -> V=1.046665, theta=0.0
% INFO    : Bus 859	: V=1.06168039, theta=-16.7291749 -> V=1.046665, theta=0.0
% INFO    : Bus 860	: V=1.04702657, theta=-47.9063736 -> V=1.0079355, theta=0.0
% INFO    : Bus 861	: V=1.07417176, theta=-11.8347758 -> V=1.0377785, theta=0.0
% INFO    : Bus 862	: V=1.07411123, theta=-11.8563364 -> V=1.0377785, theta=0.0
% INFO    : Bus 863	: V=1.00511825, theta=-24.8669348 -> V=1.0000025, theta=0.0
% INFO    : Bus 864	: V=1.006, theta=-24.9423573 -> V=1.0000025, theta=0.0
% INFO    : Bus 865	: V=1.03077933, theta=3.40555175 -> V=1.0158755, theta=0.0
% INFO    : Bus 866	: V=1.01717412, theta=-29.6211483 -> V=1.015872, theta=0.0
% INFO    : Bus 867	: V=1.03425244, theta=-21.0976168 -> V=1.022224, theta=0.0
% INFO    : Bus 868	: V=1.00115113, theta=-31.7987549 -> V=1.015872, theta=0.0
% INFO    : Bus 869	: V=1.00021786, theta=-24.1884299 -> V=1.015872, theta=0.0
% INFO    : Bus 870	: V=0.998646675, theta=-24.287667 -> V=1.015872, theta=0.0
% INFO    : Bus 871	: V=1.07020649, theta=-18.8204433 -> V=1.027779, theta=0.0
% INFO    : Bus 872	: V=1.03685307, theta=-16.1436208 -> V=1.015872, theta=0.0
% INFO    : Bus 873	: V=1.03091753, theta=-40.136615 -> V=1.0079355, theta=0.0
% INFO    : Bus 874	: V=1.02821442, theta=-38.6104828 -> V=1.0079355, theta=0.0
% INFO    : Bus 875	: V=1.01905976, theta=-28.2673026 -> V=1.015872, theta=0.0
% INFO    : Bus 876	: V=1.01761952, theta=-28.3134289 -> V=1.015872, theta=0.0
% INFO    : Bus 877	: V=1.07854535, theta=-17.5561536 -> V=1.046665, theta=0.0
% INFO    : Bus 878	: V=1.0783299, theta=-17.5535644 -> V=1.046665, theta=0.0
% INFO    : Bus 879	: V=1.00751107, theta=-17.712357 -> V=1.0000005, theta=0.0
% INFO    : Bus 880	: V=1.01596638, theta=-18.3917608 -> V=1.0000005, theta=0.0
% INFO    : Bus 881	: V=1.0653725, theta=-14.8034679 -> V=1.046665, theta=0.0
% INFO    : Bus 882	: V=1.06638517, theta=-13.8249601 -> V=1.046665, theta=0.0
% INFO    : Bus 883	: V=1.05332387, theta=-10.9097602 -> V=1.0111115, theta=0.0
% INFO    : Bus 884	: V=1.04638888, theta=-47.9749851 -> V=1.0079355, theta=0.0
% INFO    : Bus 885	: V=1.00269992, theta=-30.1269449 -> V=1.0000025, theta=0.0
% INFO    : Bus 886	: V=1.03457604, theta=-24.8605187 -> V=1.000001, theta=0.0
% INFO    : Bus 887	: V=1.07823179, theta=-18.614191 -> V=1.046665, theta=0.0
% INFO    : Bus 888	: V=1.07866507, theta=-18.5787408 -> V=1.046665, theta=0.0
% INFO    : Bus 889	: V=0.993517498, theta=-23.3787334 -> V=0.975, theta=0.0
% INFO    : Bus 890	: V=1.0567959, theta=-22.8899107 -> V=1.0233335, theta=0.0
% INFO    : Bus 891	: V=0.996094473, theta=-25.6678555 -> V=1.0000025, theta=0.0
% INFO    : Bus 892	: V=1.03329312, theta=-21.0517199 -> V=0.999999, theta=0.0
% INFO    : Bus 893	: V=1.04378095, theta=-11.6746399 -> V=1.015874, theta=0.0
% INFO    : Bus 894	: V=1.0115395, theta=-19.576861 -> V=1.0000005, theta=0.0
% INFO    : Bus 895	: V=1.08921679, theta=12.2373208 -> V=1.072365, theta=0.0
% INFO    : Bus 896	: V=1.0883362, theta=9.14963937 -> V=1.072365, theta=0.0
% INFO    : Bus 897	: V=1.09287169, theta=13.2835376 -> V=1.072365, theta=0.0
% INFO    : Bus 898	: V=1.09219247, theta=13.4060366 -> V=1.072365, theta=0.0
% INFO    : Bus 899	: V=1.022669, theta=0.740727824 -> V=1.0158755, theta=0.0
% INFO    : Bus 900	: V=1.0208779, theta=0.653840177 -> V=1.0158755, theta=0.0
% INFO    : Bus 901	: V=1.05792594, theta=-17.2720951 -> V=1.027779, theta=0.0
% INFO    : Bus 902	: V=1.05134791, theta=-29.1039975 -> V=1.0000025, theta=0.0
% INFO    : Bus 903	: V=1.05305771, theta=-11.7174484 -> V=1.022222, theta=0.0
% INFO    : Bus 904	: V=1.04590271, theta=-11.5730745 -> V=1.015874, theta=0.0
% INFO    : Bus 905	: V=1.07749703, theta=-15.7762996 -> V=1.046665, theta=0.0
% INFO    : Bus 906	: V=1.02091134, theta=-16.3690214 -> V=1.015872, theta=0.0
% INFO    : Bus 907	: V=1.05654917, theta=-24.2998053 -> V=1.027779, theta=0.0
% INFO    : Bus 908	: V=1.02272697, theta=-17.9531757 -> V=1.015872, theta=0.0
% INFO    : Bus 909	: V=1.00034028, theta=-34.7496558 -> V=1.015872, theta=0.0
% INFO    : Bus 910	: V=1.01897056, theta=-20.7643056 -> V=1.015872, theta=0.0
% INFO    : Bus 911	: V=1.0340568, theta=-19.3305021 -> V=1.0000005, theta=0.0
% INFO    : Bus 912	: V=1.03398644, theta=-19.3411206 -> V=1.0000005, theta=0.0
% INFO    : Bus 913	: V=0.995064127, theta=-28.090934 -> V=1.0000025, theta=0.0
% INFO    : Bus 914	: V=0.970877618, theta=-18.0044391 -> V=0.975, theta=0.0
% INFO    : Bus 915	: V=1.05956868, theta=-17.9213565 -> V=1.044445, theta=0.0
% INFO    : Bus 916	: V=1.06474009, theta=-18.2376646 -> V=1.044445, theta=0.0
% INFO    : Bus 917	: V=1.0825392, theta=-17.063892 -> V=1.078945, theta=0.0
% INFO    : Bus 918	: V=1.02660199, theta=-24.5745799 -> V=1.0000025, theta=0.0
% INFO    : Bus 919	: V=1.06460057, theta=-14.7061038 -> V=1.027779, theta=0.0
% INFO    : Bus 920	: V=0.997742636, theta=-25.4727771 -> V=1.0000025, theta=0.0
% INFO    : Bus 921	: V=1.00495341, theta=-30.3529165 -> V=1.0000025, theta=0.0
% INFO    : Bus 922	: V=1.0314536, theta=-6.37301932 -> V=1.0111115, theta=0.0
% INFO    : Bus 923	: V=1.02047917, theta=-14.4493951 -> V=0.999999, theta=0.0
% INFO    : Bus 924	: V=1.03593348, theta=-13.2301842 -> V=1.0000005, theta=0.0
% INFO    : Bus 925	: V=1.07738167, theta=-9.64910281 -> V=1.073685, theta=0.0
% INFO    : Bus 926	: V=1.02865467, theta=-21.3016288 -> V=0.999999, theta=0.0
% INFO    : Bus 927	: V=1.02352313, theta=-24.0803652 -> V=0.999999, theta=0.0
% INFO    : Bus 928	: V=1.06035067, theta=-5.58154217 -> V=1.0158755, theta=0.0
% INFO    : Bus 929	: V=1.0367654, theta=-21.2717549 -> V=1.0000025, theta=0.0
% INFO    : Bus 930	: V=1.04859232, theta=-7.63999117 -> V=1.0000025, theta=0.0
% INFO    : Bus 931	: V=1.00745913, theta=-30.5784985 -> V=1.0000025, theta=0.0
% INFO    : Bus 932	: V=1.00346056, theta=-18.0258927 -> V=0.975, theta=0.0
% INFO    : Bus 933	: V=1.00053138, theta=-18.2029173 -> V=0.975, theta=0.0
% INFO    : Bus 934	: V=1.0057247, theta=-18.7011444 -> V=0.975, theta=0.0
% INFO    : Bus 935	: V=1.05900129, theta=-17.8943634 -> V=1.046665, theta=0.0
% INFO    : Bus 936	: V=1.0681436, theta=-16.8689059 -> V=1.046665, theta=0.0
% INFO    : Bus 937	: V=1.06550915, theta=-16.9928833 -> V=1.046665, theta=0.0
% INFO    : Bus 938	: V=1.07021743, theta=-12.5176344 -> V=1.073685, theta=0.0
% INFO    : Bus 939	: V=1.0713268, theta=-12.5532978 -> V=1.073685, theta=0.0
% INFO    : Bus 940	: V=1.03167843, theta=-35.5917376 -> V=1.022224, theta=0.0
% INFO    : Bus 941	: V=1.04941063, theta=-9.77541117 -> V=1.000001, theta=0.0
% INFO    : Bus 942	: V=1.04947121, theta=-6.61427781 -> V=1.0088895, theta=0.0
% INFO    : Bus 943	: V=1.0646733, theta=-7.55701852 -> V=1.072365, theta=0.0
% INFO    : Bus 944	: V=0.977050783, theta=-24.4167967 -> V=1.0000025, theta=0.0
% INFO    : Bus 945	: V=1.0366469, theta=-31.9893993 -> V=1.022224, theta=0.0
% INFO    : Bus 946	: V=1.04103652, theta=-19.2165323 -> V=1.0158755, theta=0.0
% INFO    : Bus 947	: V=1.03684567, theta=-20.1289948 -> V=1.0158755, theta=0.0
% INFO    : Bus 948	: V=1.04004998, theta=-24.260105 -> V=1.000001, theta=0.0
% INFO    : Bus 949	: V=1.01560662, theta=-24.5187282 -> V=1.015872, theta=0.0
% INFO    : Bus 950	: V=1.02645341, theta=-37.2678937 -> V=1.022224, theta=0.0
% INFO    : Bus 951	: V=1.04330217, theta=-18.5340325 -> V=1.022224, theta=0.0
% INFO    : Bus 952	: V=1.03257847, theta=-37.582813 -> V=1.0079355, theta=0.0
% INFO    : Bus 953	: V=1.06828945, theta=-32.6691284 -> V=1.04444, theta=0.0
% INFO    : Bus 954	: V=1.04041943, theta=-6.65634303 -> V=1.0111115, theta=0.0
% INFO    : Bus 955	: V=1.02636755, theta=-24.8045921 -> V=1.022224, theta=0.0
% INFO    : Bus 956	: V=1.00431574, theta=-21.2562763 -> V=1.022224, theta=0.0
% INFO    : Bus 957	: V=1.03595892, theta=-10.001284 -> V=0.999999, theta=0.0
% INFO    : Bus 958	: V=1.07323383, theta=-2.91208312 -> V=1.072365, theta=0.0
% INFO    : Bus 959	: V=1.03794656, theta=-17.8078746 -> V=1.022224, theta=0.0
% INFO    : Bus 960	: V=1.03788037, theta=-17.7876465 -> V=1.022224, theta=0.0
% INFO    : Bus 961	: V=0.979610551, theta=-22.8355294 -> V=1.0158755, theta=0.0
% INFO    : Bus 962	: V=1.04058928, theta=-19.703406 -> V=1.022224, theta=0.0
% INFO    : Bus 963	: V=1.01430761, theta=-22.0446161 -> V=1.0158755, theta=0.0
% INFO    : Bus 964	: V=1.04701347, theta=-18.6806237 -> V=1.022224, theta=0.0
% INFO    : Bus 965	: V=1.0827262, theta=-13.8236233 -> V=1.045895, theta=0.0
% INFO    : Bus 966	: V=1.08585777, theta=-10.9233709 -> V=1.07237, theta=0.0
% INFO    : Bus 967	: V=1.08586925, theta=-10.9203593 -> V=1.07237, theta=0.0
% INFO    : Bus 968	: V=1.00896157, theta=-19.5628448 -> V=1.0158755, theta=0.0
% INFO    : Bus 969	: V=1.056, theta=-3.60804429 -> V=0.975, theta=0.0
% INFO    : Bus 970	: V=1.08101293, theta=-3.35120479 -> V=1.0377785, theta=0.0
% INFO    : Bus 971	: V=1.04378371, theta=-41.8926694 -> V=1.022224, theta=0.0
% INFO    : Bus 972	: V=1.01319333, theta=-19.124782 -> V=1.0158755, theta=0.0
% INFO    : Bus 973	: V=1.05482047, theta=-11.7987461 -> V=1.0377785, theta=0.0
% INFO    : Bus 974	: V=1.01259046, theta=-7.63832321 -> V=1.0158755, theta=0.0
% INFO    : Bus 975	: V=1.02624983, theta=-13.7698816 -> V=0.999999, theta=0.0
% INFO    : Bus 976	: V=1.02347142, theta=-14.2514999 -> V=0.999999, theta=0.0
% INFO    : Bus 977	: V=1.014, theta=-10.9418793 -> V=0.999999, theta=0.0
% INFO    : Bus 978	: V=1.02466824, theta=-25.332159 -> V=1.022224, theta=0.0
% INFO    : Bus 979	: V=1.0803713, theta=-18.2633746 -> V=1.07237, theta=0.0
% INFO    : Bus 980	: V=1.01523448, theta=-6.8451011 -> V=1.0158755, theta=0.0
% INFO    : Bus 981	: V=1.06544494, theta=-3.02118806 -> V=1.0377785, theta=0.0
% INFO    : Bus 982	: V=1.01832586, theta=-16.414819 -> V=0.999999, theta=0.0
% INFO    : Bus 983	: V=1.01657135, theta=-34.4055673 -> V=1.022224, theta=0.0
% INFO    : Bus 984	: V=1.01893742, theta=-13.6007298 -> V=0.999999, theta=0.0
% INFO    : Bus 985	: V=1.01894872, theta=-26.4342032 -> V=1.022224, theta=0.0
% INFO    : Bus 986	: V=1.02538139, theta=-25.9838403 -> V=1.022224, theta=0.0
% INFO    : Bus 987	: V=1.05250328, theta=-16.6300606 -> V=1.027779, theta=0.0
% INFO    : Bus 988	: V=1.07416567, theta=-12.828011 -> V=1.046665, theta=0.0
% INFO    : Bus 989	: V=1.01309511, theta=-12.056757 -> V=0.984126, theta=0.0
% INFO    : Bus 990	: V=1.04038805, theta=-24.0130176 -> V=1.022224, theta=0.0
% INFO    : Bus 991	: V=1.038, theta=-27.4126961 -> V=1.022224, theta=0.0
% INFO    : Bus 992	: V=1.02516484, theta=-17.1439759 -> V=1.0000005, theta=0.0
% INFO    : Bus 993	: V=1.08298839, theta=-16.2983807 -> V=1.046665, theta=0.0
% INFO    : Bus 994	: V=1.08301627, theta=-16.3453432 -> V=1.046665, theta=0.0
% INFO    : Bus 995	: V=1.01933515, theta=-13.4680841 -> V=1.0158755, theta=0.0
% INFO    : Bus 996	: V=1.03278114, theta=-15.7676911 -> V=0.999999, theta=0.0
% INFO    : Bus 997	: V=1.02984943, theta=-20.9243524 -> V=1.0158755, theta=0.0
% INFO    : Bus 998	: V=0.987582187, theta=-17.206071 -> V=1.0158755, theta=0.0
% INFO    : Bus 999	: V=0.976391075, theta=-6.93764142 -> V=0.975, theta=0.0
% INFO    : Bus 1000	: V=1.02578264, theta=-8.97061367 -> V=0.999999, theta=0.0
% INFO    : Bus 1001	: V=1.05669073, theta=-6.39035747 -> V=1.0111115, theta=0.0
% INFO    : Bus 1002	: V=1.07269087, theta=-3.27599249 -> V=1.072365, theta=0.0
% INFO    : Bus 1003	: V=1.05314987, theta=-21.0530802 -> V=1.027779, theta=0.0
% INFO    : Bus 1004	: V=1.02552949, theta=-12.9413216 -> V=0.999999, theta=0.0
% INFO    : Bus 1005	: V=1.02000248, theta=-11.8312991 -> V=0.999999, theta=0.0
% INFO    : Bus 1006	: V=1.08965966, theta=-17.3266663 -> V=1.047055, theta=0.0
% INFO    : Bus 1007	: V=1.07435771, theta=-18.8403108 -> V=1.044445, theta=0.0
% INFO    : Bus 1008	: V=1.01170267, theta=-28.5609234 -> V=1.022224, theta=0.0
% INFO    : Bus 1009	: V=1.02708499, theta=-29.4920465 -> V=1.022224, theta=0.0
% INFO    : Bus 1010	: V=1.0341792, theta=-25.9087073 -> V=1.0233335, theta=0.0
% INFO    : Bus 1011	: V=1.07975413, theta=-17.903904 -> V=1.046665, theta=0.0
% INFO    : Bus 1012	: V=1.06971852, theta=-17.8266353 -> V=1.046665, theta=0.0
% INFO    : Bus 1013	: V=1.064, theta=-22.1884021 -> V=1.000001, theta=0.0
% INFO    : Bus 1014	: V=1.04896317, theta=-39.3447863 -> V=1.022224, theta=0.0
% INFO    : Bus 1015	: V=1.02309433, theta=-12.0231416 -> V=0.999999, theta=0.0
% INFO    : Bus 1016	: V=1.05493746, theta=-9.22594605 -> V=1.0111115, theta=0.0
% INFO    : Bus 1017	: V=1.024, theta=-11.9367152 -> V=0.999999, theta=0.0
% INFO    : Bus 1018	: V=1.05328052, theta=-28.6236856 -> V=1.022224, theta=0.0
% INFO    : Bus 1019	: V=1.00036317, theta=-19.5261541 -> V=0.999999, theta=0.0
% INFO    : Bus 1020	: V=1.01678157, theta=-13.3141127 -> V=1.0158755, theta=0.0
% INFO    : Bus 1021	: V=1.0058578, theta=-19.7550777 -> V=1.0158755, theta=0.0
% INFO    : Bus 1022	: V=1.0731131, theta=-17.1079142 -> V=1.04444, theta=0.0
% INFO    : Bus 1023	: V=1.07311864, theta=-17.1069549 -> V=1.04444, theta=0.0
% INFO    : Bus 1024	: V=1.02863485, theta=-21.219953 -> V=1.022224, theta=0.0
% INFO    : Bus 1025	: V=0.975872366, theta=-12.9848643 -> V=0.9444445, theta=0.0
% INFO    : Bus 1026	: V=0.975852138, theta=-12.9842698 -> V=0.9444445, theta=0.0
% INFO    : Bus 1027	: V=0.975852138, theta=-12.9842698 -> V=0.9444445, theta=0.0
% INFO    : Bus 1028	: V=1.01680866, theta=-20.3728149 -> V=1.022224, theta=0.0
% INFO    : Bus 1029	: V=1.02426349, theta=-36.4882899 -> V=1.022224, theta=0.0
% INFO    : Bus 1030	: V=1.09812024, theta=-16.801164 -> V=1.0291455, theta=0.0
% INFO    : Bus 1031	: V=1.09817095, theta=-16.8017755 -> V=1.0291705, theta=0.0
% INFO    : Bus 1032	: V=1.07120471, theta=-16.7989448 -> V=1.046665, theta=0.0
% INFO    : Bus 1033	: V=1.04744388, theta=-7.29720961 -> V=1.000001, theta=0.0
% INFO    : Bus 1034	: V=1.06805426, theta=-18.4435641 -> V=1.027779, theta=0.0
% INFO    : Bus 1035	: V=1.06727878, theta=-18.5717618 -> V=1.027779, theta=0.0
% INFO    : Bus 1036	: V=1.05443565, theta=-31.1030095 -> V=1.022224, theta=0.0
% INFO    : Bus 1037	: V=1.02191164, theta=-17.8310618 -> V=1.0000005, theta=0.0
% INFO    : Bus 1038	: V=1.07286758, theta=-12.9237531 -> V=1.046665, theta=0.0
% INFO    : Bus 1039	: V=1.07835637, theta=-10.6016451 -> V=1.073685, theta=0.0
% INFO    : Bus 1040	: V=1.08789769, theta=-7.39698067 -> V=1.073685, theta=0.0
% INFO    : Bus 1041	: V=1.07868085, theta=-10.4401936 -> V=1.073685, theta=0.0
% INFO    : Bus 1042	: V=1.02265843, theta=-9.78628505 -> V=0.999999, theta=0.0
% INFO    : Bus 1043	: V=1.07851819, theta=-10.5209107 -> V=1.073685, theta=0.0
% INFO    : Bus 1044	: V=1.02946874, theta=-37.9742167 -> V=1.0079355, theta=0.0
% INFO    : Bus 1045	: V=1.03184636, theta=-38.2796263 -> V=1.0079355, theta=0.0
% INFO    : Bus 1046	: V=1.06793056, theta=-32.9065774 -> V=1.04444, theta=0.0
% INFO    : Bus 1047	: V=1.03881637, theta=-32.00111 -> V=1.027779, theta=0.0
% INFO    : Bus 1048	: V=1.04324681, theta=-14.6202271 -> V=0.999999, theta=0.0
% INFO    : Bus 1049	: V=1.07717054, theta=-3.34189323 -> V=1.05263, theta=0.0
% INFO    : Bus 1050	: V=1.0819105, theta=-16.4799592 -> V=1.046665, theta=0.0
% INFO    : Bus 1051	: V=1.08011258, theta=-18.0454982 -> V=1.046665, theta=0.0
% INFO    : Bus 1052	: V=1.00257745, theta=-9.16163987 -> V=0.999999, theta=0.0
% INFO    : Bus 1053	: V=1.07505045, theta=-5.05054671 -> V=1.072365, theta=0.0
% INFO    : Bus 1054	: V=0.978130144, theta=-15.1869176 -> V=1.015872, theta=0.0
% INFO    : Bus 1055	: V=1.01520225, theta=-11.7440673 -> V=1.000001, theta=0.0
% INFO    : Bus 1056	: V=1.08488827, theta=-15.591562 -> V=1.07237, theta=0.0
% INFO    : Bus 1057	: V=1.0274917, theta=-25.0973057 -> V=1.022224, theta=0.0
% INFO    : Bus 1058	: V=1.02943164, theta=-24.8188337 -> V=1.022224, theta=0.0
% INFO    : Bus 1059	: V=1.08493341, theta=-15.5911631 -> V=1.07237, theta=0.0
% INFO    : Bus 1060	: V=1.08492572, theta=-15.5909829 -> V=1.07237, theta=0.0
% INFO    : Bus 1061	: V=1.073, theta=-6.2768589 -> V=1.022222, theta=0.0
% INFO    : Bus 1062	: V=1.02980408, theta=-34.015328 -> V=1.022224, theta=0.0
% INFO    : Bus 1063	: V=1.0521408, theta=-29.7995013 -> V=1.04444, theta=0.0
% INFO    : Bus 1064	: V=1.00659173, theta=0.228492106 -> V=1.0158755, theta=0.0
% INFO    : Bus 1065	: V=1.09096004, theta=11.1961341 -> V=1.05263, theta=0.0
% INFO    : Bus 1066	: V=1.09122714, theta=10.8458855 -> V=1.05263, theta=0.0
% INFO    : Bus 1067	: V=1.05865267, theta=-0.127350251 -> V=1.0000025, theta=0.0
% INFO    : Bus 1068	: V=1.07476554, theta=2.53581664 -> V=0.9889295, theta=0.0
% INFO    : Bus 1069	: V=1.03171268, theta=-16.213674 -> V=0.9682545, theta=0.0
% INFO    : Bus 1070	: V=0.973, theta=-24.3947025 -> V=1.0000025, theta=0.0
% INFO    : Bus 1071	: V=1.0217412, theta=-29.8116513 -> V=1.0000025, theta=0.0
% INFO    : Bus 1072	: V=1.01635367, theta=-30.3482927 -> V=1.0000025, theta=0.0
% INFO    : Bus 1073	: V=0.996645858, theta=-29.5431138 -> V=1.015872, theta=0.0
% INFO    : Bus 1074	: V=1.00094401, theta=-6.11476652 -> V=1.0158755, theta=0.0
% INFO    : Bus 1075	: V=1.07303082, theta=-16.1973317 -> V=1.046665, theta=0.0
% INFO    : Bus 1076	: V=1.07620638, theta=-12.1457424 -> V=1.073685, theta=0.0
% INFO    : Bus 1077	: V=1.05500281, theta=-20.6930642 -> V=1.0000025, theta=0.0
% INFO    : Bus 1078	: V=1.08031569, theta=-17.4929556 -> V=1.044445, theta=0.0
% INFO    : Bus 1079	: V=1.08253668, theta=-5.8900677 -> V=1.07237, theta=0.0
% INFO    : Bus 1080	: V=1.08251353, theta=-5.90914885 -> V=1.07237, theta=0.0
% INFO    : Bus 1081	: V=1.0187555, theta=-32.0352434 -> V=1.022224, theta=0.0
% INFO    : Bus 1082	: V=1.02282575, theta=-9.87258461 -> V=0.999999, theta=0.0
% INFO    : Bus 1083	: V=1.01841885, theta=-15.7310545 -> V=0.999999, theta=0.0
% INFO    : Bus 1084	: V=1.01736806, theta=-16.4603122 -> V=0.999999, theta=0.0
% INFO    : Bus 1085	: V=1.04794206, theta=-12.1069859 -> V=1.0111115, theta=0.0
% INFO    : Bus 1086	: V=1.02655488, theta=-6.53293143 -> V=1.0158755, theta=0.0
% INFO    : Bus 1087	: V=1.03688452, theta=-14.5766175 -> V=1.0158755, theta=0.0
% INFO    : Bus 1088	: V=1.01651379, theta=-11.7339011 -> V=0.999999, theta=0.0
% INFO    : Bus 1089	: V=0.978515782, theta=-18.4830662 -> V=1.0158755, theta=0.0
% INFO    : Bus 1090	: V=1.00964714, theta=-48.5674644 -> V=1.0079355, theta=0.0
% INFO    : Bus 1091	: V=1.05410264, theta=-15.8792828 -> V=1.027779, theta=0.0
% INFO    : Bus 1092	: V=1.07373595, theta=-13.0729794 -> V=1.046665, theta=0.0
% INFO    : Bus 1093	: V=1.01847276, theta=-23.032221 -> V=1.0000005, theta=0.0
% INFO    : Bus 1094	: V=1.01607956, theta=-19.6255705 -> V=1.0000005, theta=0.0
% INFO    : Bus 1095	: V=1.05325301, theta=-6.74672844 -> V=0.9888895, theta=0.0
% INFO    : Bus 1096	: V=1.05295751, theta=-6.76028474 -> V=0.9888895, theta=0.0
% INFO    : Bus 1097	: V=1.0041547, theta=-14.0135765 -> V=0.999999, theta=0.0
% INFO    : Bus 1098	: V=0.996266324, theta=-17.6549252 -> V=1.0158755, theta=0.0
% INFO    : Bus 1099	: V=1.03398057, theta=-15.9809382 -> V=0.999999, theta=0.0
% INFO    : Bus 1100	: V=1.04541653, theta=-13.0820976 -> V=0.999999, theta=0.0
% INFO    : Bus 1101	: V=1.03162628, theta=-38.3280223 -> V=1.0079355, theta=0.0
% INFO    : Bus 1102	: V=1.02635363, theta=-38.8708488 -> V=1.0079355, theta=0.0
% INFO    : Bus 1103	: V=1.0289542, theta=-38.0144157 -> V=1.0079355, theta=0.0
% INFO    : Bus 1104	: V=1.03147467, theta=-38.3218055 -> V=1.0079355, theta=0.0
% INFO    : Bus 1105	: V=1.02441323, theta=-16.5163647 -> V=1.0000005, theta=0.0
% INFO    : Bus 1106	: V=1.0180858, theta=-26.742889 -> V=1.0000025, theta=0.0
% INFO    : Bus 1107	: V=1.02347332, theta=-44.8891914 -> V=1.0079355, theta=0.0
% INFO    : Bus 1108	: V=1.07401215, theta=-4.51986669 -> V=1.072365, theta=0.0
% INFO    : Bus 1109	: V=1.01293838, theta=-12.5521635 -> V=1.015872, theta=0.0
% INFO    : Bus 1110	: V=1.04156971, theta=-24.4632841 -> V=1.022224, theta=0.0
% INFO    : Bus 1111	: V=1.0130673, theta=-22.7410014 -> V=1.0000005, theta=0.0
% INFO    : Bus 1112	: V=1.073, theta=-17.3870948 -> V=0.975, theta=0.0
% INFO    : Bus 1113	: V=1.06938497, theta=-18.691983 -> V=1.000001, theta=0.0
% INFO    : Bus 1114	: V=1.01863992, theta=-16.6812234 -> V=0.999999, theta=0.0
% INFO    : Bus 1115	: V=1.05347436, theta=-23.3922584 -> V=1.0000025, theta=0.0
% INFO    : Bus 1116	: V=1.05714786, theta=-17.7712994 -> V=1.044445, theta=0.0
% INFO    : Bus 1117	: V=1.02761789, theta=-18.7429467 -> V=1.0158755, theta=0.0
% INFO    : Bus 1118	: V=1.02340304, theta=-7.07604914 -> V=1.0158755, theta=0.0
% INFO    : Bus 1119	: V=1.02664922, theta=-26.1410253 -> V=1.0000025, theta=0.0
% INFO    : Bus 1120	: V=1.01745993, theta=-26.2423858 -> V=1.0000025, theta=0.0
% INFO    : Bus 1121	: V=1.02161909, theta=-15.7469377 -> V=1.015872, theta=0.0
% INFO    : Bus 1122	: V=1.02054625, theta=-25.3358804 -> V=1.022224, theta=0.0
% INFO    : Bus 1123	: V=1.08304228, theta=-16.3397132 -> V=1.046665, theta=0.0
% INFO    : Bus 1124	: V=1.05694568, theta=-15.4731741 -> V=1.022224, theta=0.0
% INFO    : Bus 1125	: V=1.02228276, theta=-7.38318452 -> V=1.0158755, theta=0.0
% INFO    : Bus 1126	: V=1.0264193, theta=-7.0649562 -> V=1.0158755, theta=0.0
% INFO    : Bus 1127	: V=1.04450778, theta=-12.7543376 -> V=1.003335, theta=0.0
% INFO    : Bus 1128	: V=1.00321495, theta=-11.8735011 -> V=0.999999, theta=0.0
% INFO    : Bus 1129	: V=1.02992157, theta=-27.2524003 -> V=1.0000025, theta=0.0
% INFO    : Bus 1130	: V=1.02590138, theta=-26.4869543 -> V=1.022224, theta=0.0
% INFO    : Bus 1131	: V=1.01786189, theta=-10.8009446 -> V=1.015872, theta=0.0
% INFO    : Bus 1132	: V=1.01894356, theta=-32.7707306 -> V=1.022224, theta=0.0
% INFO    : Bus 1133	: V=0.996818264, theta=-0.997132923 -> V=1.0158755, theta=0.0
% INFO    : Bus 1134	: V=1.04797313, theta=-30.1308176 -> V=1.022224, theta=0.0
% INFO    : Bus 1135	: V=1.0676891, theta=-26.4673807 -> V=1.04444, theta=0.0
% INFO    : Bus 1136	: V=1.01566747, theta=-28.280328 -> V=1.022224, theta=0.0
% INFO    : Bus 1137	: V=1.01971552, theta=-18.6820771 -> V=0.999999, theta=0.0
% INFO    : Bus 1138	: V=1.06573759, theta=-10.9430868 -> V=1.0377785, theta=0.0
% INFO    : Bus 1139	: V=1.02752871, theta=-9.68040066 -> V=1.0000025, theta=0.0
% INFO    : Bus 1140	: V=1.02485688, theta=-16.2526027 -> V=1.0000005, theta=0.0
% INFO    : Bus 1141	: V=1.01474755, theta=-16.2572369 -> V=1.0000005, theta=0.0
% INFO    : Bus 1142	: V=1.06102174, theta=-13.3493419 -> V=1.046665, theta=0.0
% INFO    : Bus 1143	: V=1.03409961, theta=-16.3812963 -> V=1.0111115, theta=0.0
% INFO    : Bus 1144	: V=1.01847833, theta=-16.6975009 -> V=1.015872, theta=0.0
% INFO    : Bus 1145	: V=1.04779456, theta=-46.3284012 -> V=1.0079355, theta=0.0
% INFO    : Bus 1146	: V=1.06662497, theta=-42.1356758 -> V=1.04444, theta=0.0
% INFO    : Bus 1147	: V=1.04604594, theta=-19.2311665 -> V=1.046665, theta=0.0
% INFO    : Bus 1148	: V=0.988928599, theta=-32.5197825 -> V=1.0000025, theta=0.0
% INFO    : Bus 1149	: V=1.0365243, theta=-19.2141282 -> V=0.975, theta=0.0
% INFO    : Bus 1150	: V=1.04557675, theta=-10.5523188 -> V=1.0111115, theta=0.0
% INFO    : Bus 1151	: V=1.04533018, theta=-20.8344548 -> V=1.022224, theta=0.0
% INFO    : Bus 1152	: V=1.01640581, theta=-12.7839521 -> V=1.0158755, theta=0.0
% INFO    : Bus 1153	: V=1.00122572, theta=-34.6063841 -> V=1.022224, theta=0.0
% INFO    : Bus 1154	: V=1.02256338, theta=-5.73093266 -> V=1.0158755, theta=0.0
% INFO    : Bus 1155	: V=1.0145826, theta=-9.75782579 -> V=0.999999, theta=0.0
% INFO    : Bus 1156	: V=1.01708616, theta=-9.79740859 -> V=0.999999, theta=0.0
% INFO    : Bus 1157	: V=1.05013226, theta=-7.27864511 -> V=1.0111115, theta=0.0
% INFO    : Bus 1158	: V=1.01690579, theta=-29.6156137 -> V=1.015872, theta=0.0
% INFO    : Bus 1159	: V=1.0101008, theta=-21.4587236 -> V=1.022224, theta=0.0
% INFO    : Bus 1160	: V=1.07836609, theta=-18.5901481 -> V=1.046665, theta=0.0
% INFO    : Bus 1161	: V=1.07092593, theta=-16.8295478 -> V=1.046665, theta=0.0
% INFO    : Bus 1162	: V=1.07090837, theta=-16.8069308 -> V=1.046665, theta=0.0
% INFO    : Bus 1163	: V=1.05581351, theta=-20.2259134 -> V=1.027779, theta=0.0
% INFO    : Bus 1164	: V=1.05793812, theta=-19.3353641 -> V=1.027779, theta=0.0
% INFO    : Bus 1165	: V=1.05637933, theta=-20.1891184 -> V=1.027779, theta=0.0
% INFO    : Bus 1166	: V=1.07286076, theta=-16.150396 -> V=1.046665, theta=0.0
% INFO    : Bus 1167	: V=1.03567646, theta=-20.23095 -> V=1.0000005, theta=0.0
% INFO    : Bus 1168	: V=1.0295565, theta=-19.5037857 -> V=1.0000005, theta=0.0
% INFO    : Bus 1169	: V=0.948167592, theta=-8.50646106 -> V=0.9444445, theta=0.0
% INFO    : Bus 1170	: V=1.0050638, theta=-8.477127 -> V=0.999999, theta=0.0
% INFO    : Bus 1171	: V=1.03602428, theta=-16.0121563 -> V=1.0158755, theta=0.0
% INFO    : Bus 1172	: V=1.05191543, theta=-6.81737653 -> V=0.9888895, theta=0.0
% INFO    : Bus 1173	: V=1.03656443, theta=-29.9200539 -> V=1.022224, theta=0.0
% INFO    : Bus 1174	: V=1.06422823, theta=-25.7396568 -> V=1.04444, theta=0.0
% INFO    : Bus 1175	: V=1.07587495, theta=-30.8278588 -> V=1.04444, theta=0.0
% INFO    : Bus 1176	: V=1.07650885, theta=-30.6125531 -> V=1.04444, theta=0.0
% INFO    : Bus 1177	: V=1.07635301, theta=-30.658597 -> V=1.04444, theta=0.0
% INFO    : Bus 1178	: V=1.07706504, theta=-27.6111831 -> V=1.07237, theta=0.0
% INFO    : Bus 1179	: V=1.04131953, theta=-26.3397999 -> V=1.0000025, theta=0.0
% INFO    : Bus 1180	: V=1.05408237, theta=-9.77331034 -> V=1.0111115, theta=0.0
% INFO    : Bus 1181	: V=1.03092059, theta=-26.8277416 -> V=1.027779, theta=0.0
% INFO    : Bus 1182	: V=1.05465484, theta=-13.7833015 -> V=1.027779, theta=0.0
% INFO    : Bus 1183	: V=1.04210807, theta=-19.7239558 -> V=1.022224, theta=0.0
% INFO    : Bus 1184	: V=1.03938367, theta=-19.8705336 -> V=1.022224, theta=0.0
% INFO    : Bus 1185	: V=0.987983342, theta=-22.1627677 -> V=1.0158755, theta=0.0
% INFO    : Bus 1186	: V=1.08270164, theta=-16.3345154 -> V=1.046665, theta=0.0
% INFO    : Bus 1187	: V=1.08011626, theta=-18.1136489 -> V=1.046665, theta=0.0
% INFO    : Bus 1188	: V=1.03973937, theta=-18.8212162 -> V=1.022224, theta=0.0
% INFO    : Bus 1189	: V=1.06984513, theta=-18.7217166 -> V=1.046665, theta=0.0
% INFO    : Bus 1190	: V=0.992430994, theta=-10.893315 -> V=1.0158755, theta=0.0
% INFO    : Bus 1191	: V=1.05465509, theta=-13.7833092 -> V=1.027779, theta=0.0
% INFO    : Bus 1192	: V=1.02048372, theta=-16.4002387 -> V=0.999999, theta=0.0
% INFO    : Bus 1193	: V=1.02551489, theta=-14.8002201 -> V=0.999999, theta=0.0
% INFO    : Bus 1194	: V=1.01817539, theta=-14.0554206 -> V=0.999999, theta=0.0
% INFO    : Bus 1195	: V=1.06568864, theta=-10.0877964 -> V=1.0111115, theta=0.0
% INFO    : Bus 1196	: V=1.06383479, theta=-9.70672674 -> V=1.0111115, theta=0.0
% INFO    : Bus 1197	: V=1.07293586, theta=-7.78001262 -> V=1.072365, theta=0.0
% INFO    : Bus 1198	: V=1.07588365, theta=-30.8277128 -> V=1.04444, theta=0.0
% INFO    : Bus 1199	: V=1.07707133, theta=-27.6112733 -> V=1.07237, theta=0.0
% INFO    : Bus 1200	: V=1.00429508, theta=-10.8712866 -> V=1.0158755, theta=0.0
% INFO    : Bus 1201	: V=1.03896322, theta=-19.0536561 -> V=1.0000005, theta=0.0
% INFO    : Bus 1202	: V=1.08129301, theta=-15.4860527 -> V=1.046665, theta=0.0
% INFO    : Bus 1203	: V=1.04907614, theta=-20.8371203 -> V=1.000001, theta=0.0
% INFO    : Bus 1204	: V=1.04003726, theta=-22.1456646 -> V=1.000001, theta=0.0
% INFO    : Bus 1205	: V=1.05250193, theta=-16.6300351 -> V=1.027779, theta=0.0
% INFO    : Bus 1206	: V=1.08136396, theta=-15.53824 -> V=1.046665, theta=0.0
% INFO    : Bus 1207	: V=1.01479564, theta=-17.2160897 -> V=1.0158755, theta=0.0
% INFO    : Bus 1208	: V=1.0648965, theta=-13.4784079 -> V=1.0377785, theta=0.0
% INFO    : Bus 1209	: V=1.07017062, theta=-1.67084912 -> V=1.033333, theta=0.0
% INFO    : Bus 1210	: V=1.03796496, theta=-26.4609737 -> V=1.015872, theta=0.0
% INFO    : Bus 1211	: V=1.04565315, theta=-23.1004997 -> V=1.046665, theta=0.0
% INFO    : Bus 1212	: V=1.0035846, theta=-23.4113212 -> V=1.022224, theta=0.0
% INFO    : Bus 1213	: V=1.00705166, theta=-27.9645219 -> V=1.022224, theta=0.0
% INFO    : Bus 1214	: V=1.071, theta=-15.8075208 -> V=1.044445, theta=0.0
% INFO    : Bus 1215	: V=1.062, theta=-19.5091366 -> V=1.044445, theta=0.0
% INFO    : Bus 1216	: V=1.00487377, theta=-21.8474086 -> V=1.0000025, theta=0.0
% INFO    : Bus 1217	: V=1.00498799, theta=-11.14493 -> V=1.015872, theta=0.0
% INFO    : Bus 1218	: V=1.08026505, theta=1.95460737 -> V=1.078945, theta=0.0
% INFO    : Bus 1219	: V=1.01284102, theta=-21.8914667 -> V=0.999999, theta=0.0
% INFO    : Bus 1220	: V=1.07216195, theta=-13.9636388 -> V=1.028519, theta=0.0
% INFO    : Bus 1221	: V=1.02052261, theta=-21.2120827 -> V=1.0000005, theta=0.0
% INFO    : Bus 1222	: V=1.01487892, theta=-17.254813 -> V=0.999999, theta=0.0
% INFO    : Bus 1223	: V=1.04748803, theta=-20.9453251 -> V=1.022224, theta=0.0
% INFO    : Bus 1224	: V=1.04266, theta=-27.5467477 -> V=1.027779, theta=0.0
% INFO    : Bus 1225	: V=1.06518831, theta=-24.876482 -> V=1.027779, theta=0.0
% INFO    : Bus 1226	: V=1.03201909, theta=-7.28770362 -> V=1.0111115, theta=0.0
% INFO    : Bus 1227	: V=1.0301486, theta=-18.1803582 -> V=1.0158755, theta=0.0
% INFO    : Bus 1228	: V=1.04100659, theta=-31.8004054 -> V=1.022224, theta=0.0
% INFO    : Bus 1229	: V=1.0693805, theta=-27.1588004 -> V=1.04444, theta=0.0
% INFO    : Bus 1230	: V=1.01621951, theta=-17.0577386 -> V=1.015872, theta=0.0
% INFO    : Bus 1231	: V=1.01632161, theta=-20.5851029 -> V=1.0158755, theta=0.0
% INFO    : Bus 1232	: V=1.01782278, theta=-20.17359 -> V=1.0158755, theta=0.0
% INFO    : Bus 1233	: V=1.00752618, theta=-2.54299635 -> V=1.0158755, theta=0.0
% INFO    : Bus 1234	: V=1.03644858, theta=-21.5352151 -> V=1.000001, theta=0.0
% INFO    : Bus 1235	: V=1.0599696, theta=-27.4719089 -> V=0.975, theta=0.0
% INFO    : Bus 1236	: V=1.0599696, theta=-27.4719089 -> V=1.022224, theta=0.0
% INFO    : Bus 1237	: V=1.01366767, theta=-11.0686286 -> V=0.999999, theta=0.0
% INFO    : Bus 1238	: V=1.0232002, theta=-9.22567619 -> V=0.999999, theta=0.0
% INFO    : Bus 1239	: V=1.04896567, theta=-10.2893721 -> V=1.0111115, theta=0.0
% INFO    : Bus 1240	: V=1.05260751, theta=-9.60864229 -> V=1.0111115, theta=0.0
% INFO    : Bus 1241	: V=1.05272846, theta=-9.55759257 -> V=1.0111115, theta=0.0
% INFO    : Bus 1242	: V=1.06517099, theta=-4.97391366 -> V=1.072365, theta=0.0
% INFO    : Bus 1243	: V=1.01605795, theta=-13.851222 -> V=1.0158755, theta=0.0
% INFO    : Bus 1244	: V=1.05677881, theta=-9.36681008 -> V=1.0377785, theta=0.0
% INFO    : Bus 1245	: V=1.02578756, theta=-21.1378758 -> V=0.999999, theta=0.0
% INFO    : Bus 1246	: V=1.03644032, theta=-17.4123616 -> V=1.0158755, theta=0.0
% INFO    : Bus 1247	: V=1.05405179, theta=-13.9690637 -> V=1.0377785, theta=0.0
% INFO    : Bus 1248	: V=1.0133865, theta=-15.8897768 -> V=1.0158755, theta=0.0
% INFO    : Bus 1249	: V=1.00403756, theta=-14.6558499 -> V=1.0, theta=0.0
% INFO    : Bus 1250	: V=0.586552643, theta=-15.5235625 -> V=0.825, theta=0.0
% INFO    : Bus 1251	: V=1.03838459, theta=-15.4145081 -> V=1.0158755, theta=0.0
% INFO    : Bus 1252	: V=1.02155616, theta=-12.2752303 -> V=0.999999, theta=0.0
% INFO    : Bus 1253	: V=1.02468644, theta=-35.9271551 -> V=1.022224, theta=0.0
% INFO    : Bus 1254	: V=1.01907042, theta=-10.1794314 -> V=0.999999, theta=0.0
% INFO    : Bus 1255	: V=1.00620054, theta=-11.5522051 -> V=0.999999, theta=0.0
% INFO    : Bus 1256	: V=1.03413302, theta=-17.4511165 -> V=0.999999, theta=0.0
% INFO    : Bus 1257	: V=1.07005937, theta=-8.01435692 -> V=1.016666, theta=0.0
% INFO    : Bus 1258	: V=1.06139489, theta=-4.84300055 -> V=1.0111115, theta=0.0
% INFO    : Bus 1259	: V=1.0110916, theta=-15.8503155 -> V=1.0158755, theta=0.0
% INFO    : Bus 1260	: V=1.02540837, theta=-44.9513067 -> V=1.0079355, theta=0.0
% INFO    : Bus 1261	: V=1.00825468, theta=-12.6938912 -> V=1.015872, theta=0.0
% INFO    : Bus 1262	: V=1.03710488, theta=-9.45947493 -> V=1.0158755, theta=0.0
% INFO    : Bus 1263	: V=1.03683621, theta=-9.71294288 -> V=1.0158755, theta=0.0
% INFO    : Bus 1264	: V=1.05584499, theta=-6.44126977 -> V=1.0377785, theta=0.0
% INFO    : Bus 1265	: V=1.08766982, theta=-5.50374053 -> V=1.072365, theta=0.0
% INFO    : Bus 1266	: V=1.0311346, theta=-20.448393 -> V=0.999999, theta=0.0
% INFO    : Bus 1267	: V=0.989431657, theta=-14.574284 -> V=1.015872, theta=0.0
% INFO    : Bus 1268	: V=1.08208727, theta=-16.4653837 -> V=1.046665, theta=0.0
% INFO    : Bus 1269	: V=1.08010708, theta=-18.0924168 -> V=1.046665, theta=0.0
% INFO    : Bus 1270	: V=1.03977038, theta=-23.5455156 -> V=1.027779, theta=0.0
% INFO    : Bus 1271	: V=1.00835078, theta=-18.1157023 -> V=1.0158755, theta=0.0
% INFO    : Bus 1272	: V=1.02721011, theta=3.81155994 -> V=1.0158755, theta=0.0
% INFO    : Bus 1273	: V=1.01287062, theta=-22.5474226 -> V=1.0000005, theta=0.0
% INFO    : Bus 1274	: V=1.07643557, theta=-3.92474244 -> V=1.072365, theta=0.0
% INFO    : Bus 1275	: V=1.07690951, theta=-3.88827782 -> V=1.072365, theta=0.0
% INFO    : Bus 1276	: V=1.01659351, theta=-11.9252679 -> V=1.0000025, theta=0.0
% INFO    : Bus 1277	: V=1.07641765, theta=-16.0848934 -> V=1.046665, theta=0.0
% INFO    : Bus 1278	: V=1.07355909, theta=-15.6959252 -> V=1.046665, theta=0.0
% INFO    : Bus 1279	: V=1.03105514, theta=-18.213783 -> V=1.0158755, theta=0.0
% INFO    : Bus 1280	: V=1.04759618, theta=-16.7275959 -> V=1.027779, theta=0.0
% INFO    : Bus 1281	: V=1.04094674, theta=-12.3391538 -> V=1.033333, theta=0.0
% INFO    : Bus 1282	: V=1.05750584, theta=-6.5214821 -> V=1.046665, theta=0.0
% INFO    : Bus 1283	: V=1.05440124, theta=-20.5659369 -> V=1.027779, theta=0.0
% INFO    : Bus 1284	: V=1.05808399, theta=-10.1637986 -> V=1.0111115, theta=0.0
% INFO    : Bus 1285	: V=1.06265693, theta=-5.85824518 -> V=0.9888895, theta=0.0
% INFO    : Bus 1286	: V=1.04432708, theta=-10.2288534 -> V=1.0111115, theta=0.0
% INFO    : Bus 1287	: V=1.01233454, theta=-6.30629494 -> V=1.0158755, theta=0.0
% INFO    : Bus 1288	: V=1.01461755, theta=-34.4181547 -> V=1.022224, theta=0.0
% INFO    : Bus 1289	: V=1.0282574, theta=-17.7980744 -> V=1.0000005, theta=0.0
% INFO    : Bus 1290	: V=1.058, theta=-24.6978662 -> V=1.0000025, theta=0.0
% INFO    : Bus 1291	: V=1.03756216, theta=-22.5875519 -> V=1.0000025, theta=0.0
% INFO    : Bus 1292	: V=1.07204314, theta=-18.7241353 -> V=1.044445, theta=0.0
% INFO    : Bus 1293	: V=0.996706228, theta=-26.4736523 -> V=1.0000025, theta=0.0
% INFO    : Bus 1294	: V=1.02184692, theta=-49.4710451 -> V=1.0079355, theta=0.0
% INFO    : Bus 1295	: V=1.0432477, theta=-6.69452916 -> V=1.046665, theta=0.0
% INFO    : Bus 1296	: V=1.08089888, theta=2.18196248 -> V=1.078945, theta=0.0
% INFO    : Bus 1297	: V=1.08098377, theta=2.19719515 -> V=1.078945, theta=0.0
% INFO    : Bus 1298	: V=1.0810068, theta=2.20018574 -> V=1.078945, theta=0.0
% INFO    : Bus 1299	: V=1.08083329, theta=2.18216083 -> V=1.078945, theta=0.0
% INFO    : Bus 1300	: V=1.03436382, theta=-30.2871751 -> V=1.022224, theta=0.0
% INFO    : Bus 1301	: V=1.03161211, theta=-38.2411125 -> V=1.022224, theta=0.0
% INFO    : Bus 1302	: V=0.976545713, theta=-20.6371288 -> V=0.999999, theta=0.0
% INFO    : Bus 1303	: V=1.01954852, theta=-16.5049661 -> V=1.0158755, theta=0.0
% INFO    : Bus 1304	: V=1.01950413, theta=-16.5174692 -> V=1.0158755, theta=0.0
% INFO    : Bus 1305	: V=1.065183, theta=-9.86381349 -> V=1.0111115, theta=0.0
% INFO    : Bus 1306	: V=0.999308263, theta=-12.63459 -> V=0.999999, theta=0.0
% INFO    : Bus 1307	: V=1.02174528, theta=-28.2844851 -> V=0.975, theta=0.0
% INFO    : Bus 1308	: V=1.0522665, theta=-33.2366183 -> V=0.975, theta=0.0
% INFO    : Bus 1309	: V=1.02174528, theta=-28.2844851 -> V=1.0000025, theta=0.0
% INFO    : Bus 1310	: V=1.02120151, theta=-26.9493587 -> V=1.0000025, theta=0.0
% INFO    : Bus 1311	: V=1.05682841, theta=-22.8743067 -> V=1.0233335, theta=0.0
% INFO    : Bus 1312	: V=1.00285578, theta=-22.0299887 -> V=1.0000025, theta=0.0
% INFO    : Bus 1313	: V=1.01144495, theta=-27.246111 -> V=1.0000025, theta=0.0
% INFO    : Bus 1314	: V=1.05, theta=-22.2463751 -> V=1.0000025, theta=0.0
% INFO    : Bus 1315	: V=1.00089743, theta=-25.2868906 -> V=1.0000025, theta=0.0
% INFO    : Bus 1316	: V=1.0009533, theta=-25.3062149 -> V=1.0000025, theta=0.0
% INFO    : Bus 1317	: V=1.03509795, theta=-21.4259721 -> V=1.0000025, theta=0.0
% INFO    : Bus 1318	: V=1.03509795, theta=-21.4259721 -> V=1.0000025, theta=0.0
% INFO    : Bus 1319	: V=1.03440907, theta=-33.8583573 -> V=1.022224, theta=0.0
% INFO    : Bus 1320	: V=1.00742321, theta=-25.2131809 -> V=1.022224, theta=0.0
% INFO    : Bus 1321	: V=0.95815527, theta=-8.68437119 -> V=0.9444445, theta=0.0
% INFO    : Bus 1322	: V=0.9582321, theta=-8.67911806 -> V=0.9444445, theta=0.0
% INFO    : Bus 1323	: V=1.00975312, theta=-12.2745547 -> V=1.015872, theta=0.0
% INFO    : Bus 1324	: V=1.02424242, theta=-16.3385573 -> V=1.015872, theta=0.0
% INFO    : Bus 1325	: V=1.04125209, theta=-13.7500859 -> V=1.046665, theta=0.0
% INFO    : Bus 1326	: V=1.03913221, theta=-29.7197163 -> V=1.0000025, theta=0.0
% INFO    : Bus 1327	: V=0.950763387, theta=-6.64592248 -> V=0.9444445, theta=0.0
% INFO    : Bus 1328	: V=1.03187717, theta=-23.0435623 -> V=1.022224, theta=0.0
% INFO    : Bus 1329	: V=1.066, theta=-22.0108147 -> V=1.000001, theta=0.0
% INFO    : Bus 1330	: V=1.05169874, theta=-38.8064747 -> V=1.0079355, theta=0.0
% INFO    : Bus 1331	: V=1.04281462, theta=-19.8152033 -> V=1.0000025, theta=0.0
% INFO    : Bus 1332	: V=1.07616532, theta=-15.5171659 -> V=1.044445, theta=0.0
% INFO    : Bus 1333	: V=1.08773245, theta=-10.2449882 -> V=1.078945, theta=0.0
% INFO    : Bus 1334	: V=0.966483783, theta=-9.94796818 -> V=0.9444445, theta=0.0
% INFO    : Bus 1335	: V=1.02215083, theta=-9.92860905 -> V=0.999999, theta=0.0
% INFO    : Bus 1336	: V=0.979567552, theta=-20.3445625 -> V=1.0158755, theta=0.0
% INFO    : Bus 1337	: V=1.03328283, theta=-12.0384924 -> V=0.999999, theta=0.0
% INFO    : Bus 1338	: V=1.05417382, theta=-6.08135563 -> V=0.9888895, theta=0.0
% INFO    : Bus 1339	: V=1.05607815, theta=-12.9813441 -> V=1.046665, theta=0.0
% INFO    : Bus 1340	: V=1.00615559, theta=-11.2583131 -> V=0.999999, theta=0.0
% INFO    : Bus 1341	: V=1.06097642, theta=-10.7357138 -> V=1.0377785, theta=0.0
% INFO    : Bus 1342	: V=1.01612287, theta=-0.908000031 -> V=1.0158755, theta=0.0
% INFO    : Bus 1343	: V=1.07660263, theta=4.47549408 -> V=1.0384235, theta=0.0
% INFO    : Bus 1344	: V=1.01824239, theta=-11.5387491 -> V=0.999999, theta=0.0
% INFO    : Bus 1345	: V=1.05893106, theta=-9.43906195 -> V=1.0111115, theta=0.0
% INFO    : Bus 1346	: V=1.02385472, theta=2.63532463 -> V=1.0158755, theta=0.0
% INFO    : Bus 1347	: V=1.03422313, theta=-13.9096834 -> V=1.0000005, theta=0.0
% INFO    : Bus 1348	: V=1.0, theta=-22.8864379 -> V=0.975, theta=0.0
% INFO    : Bus 1349	: V=1.05687127, theta=-22.8750542 -> V=1.0233335, theta=0.0
% INFO    : Bus 1350	: V=1.0212891, theta=-17.1057027 -> V=0.999999, theta=0.0
% INFO    : Bus 1351	: V=1.02999899, theta=-26.7402563 -> V=1.022224, theta=0.0
% INFO    : Bus 1352	: V=1.02993339, theta=-26.7442679 -> V=1.022224, theta=0.0
% INFO    : Bus 1353	: V=1.03614064, theta=-20.80046 -> V=1.022224, theta=0.0
% INFO    : Bus 1354	: V=1.01224211, theta=-11.2217824 -> V=1.0158755, theta=0.0
% INFO    : Bus 1355	: V=1.04438956, theta=-20.5921323 -> V=1.022224, theta=0.0
% INFO    : Bus 1356	: V=1.02637214, theta=-21.0658683 -> V=1.022224, theta=0.0
% INFO    : Bus 1357	: V=1.07313054, theta=-17.1051083 -> V=1.04444, theta=0.0
% INFO    : Bus 1358	: V=1.04713559, theta=-7.19403251 -> V=1.0000025, theta=0.0
% INFO    : Bus 1359	: V=1.05648095, theta=-5.02854477 -> V=0.9977785, theta=0.0
% INFO    : Bus 1360	: V=1.037, theta=-10.5783728 -> V=0.999999, theta=0.0
% INFO    : Bus 1361	: V=1.04275604, theta=-0.431772516 -> V=1.000001, theta=0.0
% INFO    : Bus 1362	: V=1.03507492, theta=-21.1053377 -> V=1.022224, theta=0.0
% INFO    : Bus 1363	: V=1.04027144, theta=-19.6002631 -> V=1.033334, theta=0.0
% INFO    : Bus 1364	: V=1.04028962, theta=-19.600239 -> V=1.033334, theta=0.0
% INFO    : Bus 1365	: V=1.03430417, theta=-25.9210861 -> V=1.022224, theta=0.0
% INFO    : Bus 1366	: V=1.029, theta=-30.0229716 -> V=1.015872, theta=0.0
% INFO    : Bus 1367	: V=1.01743447, theta=-19.3590187 -> V=1.0000005, theta=0.0
% INFO    : Bus 1368	: V=1.02124493, theta=-19.4461699 -> V=1.0000005, theta=0.0
% INFO    : Bus 1369	: V=1.01950415, theta=-19.6434537 -> V=1.0000005, theta=0.0
% INFO    : Bus 1370	: V=1.06883606, theta=-18.982832 -> V=1.046665, theta=0.0
% INFO    : Bus 1371	: V=1.00824772, theta=-12.688483 -> V=1.015872, theta=0.0
% INFO    : Bus 1372	: V=1.00465171, theta=-21.2112928 -> V=1.022224, theta=0.0
% INFO    : Bus 1373	: V=1.04714912, theta=-18.6835722 -> V=1.022224, theta=0.0
% INFO    : Bus 1374	: V=1.05409803, theta=-14.879952 -> V=1.027779, theta=0.0
% INFO    : Bus 1375	: V=1.07730695, theta=-15.8827467 -> V=1.046665, theta=0.0
% INFO    : Bus 1376	: V=1.00912918, theta=-24.8303671 -> V=1.0079355, theta=0.0
% INFO    : Bus 1377	: V=1.03906944, theta=-21.9916891 -> V=0.999999, theta=0.0
% INFO    : Bus 1378	: V=1.05373904, theta=-9.99835016 -> V=1.016666, theta=0.0
% INFO    : Bus 1379	: V=1.05283732, theta=-6.70076385 -> V=1.004445, theta=0.0
% INFO    : Bus 1380	: V=1.031067, theta=-20.5587354 -> V=1.0158755, theta=0.0
% INFO    : Bus 1381	: V=1.00844621, theta=-12.694645 -> V=1.015872, theta=0.0
% INFO    : Bus 1382	: V=1.02573505, theta=-26.4832931 -> V=1.022224, theta=0.0
% INFO    : Bus 1383	: V=1.01628535, theta=-17.0589263 -> V=1.015872, theta=0.0
% INFO    : Bus 1384	: V=1.01837185, theta=-17.9850601 -> V=1.0000005, theta=0.0
% INFO    : Bus 1385	: V=1.06781067, theta=-13.7356314 -> V=1.046665, theta=0.0
% INFO    : Bus 1386	: V=1.07105018, theta=-17.167925 -> V=1.046665, theta=0.0
% INFO    : Bus 1387	: V=1.02072827, theta=-21.7577955 -> V=1.022224, theta=0.0
% INFO    : Bus 1388	: V=1.0167531, theta=-22.3638011 -> V=1.022224, theta=0.0
% INFO    : Bus 1389	: V=1.0237791, theta=-19.5743687 -> V=0.999999, theta=0.0
% INFO    : Bus 1390	: V=0.985205237, theta=-17.1179522 -> V=0.999999, theta=0.0
% INFO    : Bus 1391	: V=1.00332673, theta=-11.4205666 -> V=1.015872, theta=0.0
% INFO    : Bus 1392	: V=0.986739001, theta=-24.8288068 -> V=1.0000005, theta=0.0
% INFO    : Bus 1393	: V=1.01752369, theta=-12.9630038 -> V=0.999999, theta=0.0
% INFO    : Bus 1394	: V=1.04165683, theta=-24.3592646 -> V=1.022224, theta=0.0
% INFO    : Bus 1395	: V=1.02196227, theta=-18.9971091 -> V=1.0000005, theta=0.0
% INFO    : Bus 1396	: V=1.07349667, theta=-14.9160914 -> V=1.046665, theta=0.0
% INFO    : Bus 1397	: V=1.05916974, theta=-22.5621456 -> V=1.000001, theta=0.0
% INFO    : Bus 1398	: V=1.02135056, theta=-7.52404337 -> V=1.0158755, theta=0.0
% INFO    : Bus 1399	: V=1.01681868, theta=-19.0324644 -> V=1.015872, theta=0.0
% INFO    : Bus 1400	: V=0.995600764, theta=-18.7212561 -> V=0.999999, theta=0.0
% INFO    : Bus 1401	: V=1.02948365, theta=-17.7642645 -> V=1.0158755, theta=0.0
% INFO    : Bus 1402	: V=1.03328609, theta=-16.1633079 -> V=0.999999, theta=0.0
% INFO    : Bus 1403	: V=1.03329071, theta=-16.1634631 -> V=0.999999, theta=0.0
% INFO    : Bus 1404	: V=1.00719181, theta=-13.7611234 -> V=1.0158755, theta=0.0
% INFO    : Bus 1405	: V=1.02614072, theta=-13.9397961 -> V=0.999999, theta=0.0
% INFO    : Bus 1406	: V=1.05697082, theta=-9.15989856 -> V=1.0111115, theta=0.0
% INFO    : Bus 1407	: V=1.0678918, theta=-25.6561218 -> V=0.975, theta=0.0
% INFO    : Bus 1408	: V=1.04458062, theta=-29.3172818 -> V=1.022224, theta=0.0
% INFO    : Bus 1409	: V=1.06794406, theta=-25.6394787 -> V=1.04444, theta=0.0
% INFO    : Bus 1410	: V=0.988818873, theta=-22.6173213 -> V=1.0158755, theta=0.0
% INFO    : Bus 1411	: V=1.02106642, theta=-18.2529377 -> V=1.015872, theta=0.0
% INFO    : Bus 1412	: V=1.02164306, theta=-17.1043771 -> V=1.015872, theta=0.0
% INFO    : Bus 1413	: V=1.02065795, theta=-24.5141612 -> V=1.015872, theta=0.0
% INFO    : Bus 1414	: V=1.02745356, theta=-14.8275426 -> V=0.999999, theta=0.0
% INFO    : Bus 1415	: V=1.02367986, theta=-40.540427 -> V=1.0079355, theta=0.0
% INFO    : Bus 1416	: V=1.00597957, theta=-36.2963249 -> V=1.022224, theta=0.0
% INFO    : Bus 1417	: V=1.01730842, theta=-20.8989094 -> V=1.0000025, theta=0.0
% INFO    : Bus 1418	: V=0.998753561, theta=-32.1557153 -> V=1.022224, theta=0.0
% INFO    : Bus 1419	: V=1.00949853, theta=-22.9697511 -> V=1.022224, theta=0.0
% INFO    : Bus 1420	: V=1.06378671, theta=-14.9728771 -> V=1.027779, theta=0.0
% INFO    : Bus 1421	: V=0.998555453, theta=-11.8844975 -> V=1.0158755, theta=0.0
% INFO    : Bus 1422	: V=1.00502467, theta=-11.3663477 -> V=1.0158755, theta=0.0
% INFO    : Bus 1423	: V=1.037, theta=-23.4006459 -> V=1.000001, theta=0.0
% INFO    : Bus 1424	: V=1.07991622, theta=-18.1552146 -> V=1.046665, theta=0.0
% INFO    : Bus 1425	: V=0.977879483, theta=-23.0901861 -> V=1.0158755, theta=0.0
% INFO    : Bus 1426	: V=1.0427384, theta=-21.1856011 -> V=1.027779, theta=0.0
% INFO    : Bus 1427	: V=1.00801992, theta=-28.1273377 -> V=1.022224, theta=0.0
% INFO    : Bus 1428	: V=1.02412914, theta=-12.3124244 -> V=1.0158755, theta=0.0
% INFO    : Bus 1429	: V=1.03456352, theta=-20.4780277 -> V=1.022224, theta=0.0
% INFO    : Bus 1430	: V=1.06826573, theta=2.82082778 -> V=1.0377785, theta=0.0
% INFO    : Bus 1431	: V=1.04846688, theta=-27.0894498 -> V=1.046665, theta=0.0
% INFO    : Bus 1432	: V=1.01573969, theta=0.821899207 -> V=1.0158755, theta=0.0
% INFO    : Bus 1433	: V=1.06827032, theta=2.82077758 -> V=1.0377785, theta=0.0
% INFO    : Bus 1434	: V=1.03142945, theta=-20.9121802 -> V=0.999999, theta=0.0
% INFO    : Bus 1435	: V=1.06000996, theta=-30.3291364 -> V=1.027779, theta=0.0
% INFO    : Bus 1436	: V=1.02146142, theta=-24.4003058 -> V=1.015872, theta=0.0
% INFO    : Bus 1437	: V=1.01470919, theta=-19.2866018 -> V=1.015872, theta=0.0
% INFO    : Bus 1438	: V=1.04326508, theta=-20.8838286 -> V=1.027779, theta=0.0
% INFO    : Bus 1439	: V=1.03906827, theta=-17.8385788 -> V=1.0158755, theta=0.0
% INFO    : Bus 1440	: V=1.06628282, theta=-12.9266923 -> V=1.0377785, theta=0.0
% INFO    : Bus 1441	: V=1.00914408, theta=-25.3179186 -> V=1.022224, theta=0.0
% INFO    : Bus 1442	: V=1.0087826, theta=-11.6018492 -> V=1.015872, theta=0.0
% INFO    : Bus 1443	: V=1.01065859, theta=-12.1872702 -> V=1.015872, theta=0.0
% INFO    : Bus 1444	: V=1.05089648, theta=-6.60562625 -> V=1.046665, theta=0.0
% INFO    : Bus 1445	: V=1.03285811, theta=-19.4119796 -> V=1.0000005, theta=0.0
% INFO    : Bus 1446	: V=1.04707922, theta=-18.6820642 -> V=1.022224, theta=0.0
% INFO    : Bus 1447	: V=1.03322684, theta=-19.3898161 -> V=1.0000005, theta=0.0
% INFO    : Bus 1448	: V=1.00913628, theta=-13.4319437 -> V=0.999999, theta=0.0
% INFO    : Bus 1449	: V=1.05542365, theta=-6.88174265 -> V=1.0111115, theta=0.0
% INFO    : Bus 1450	: V=1.0116092, theta=-19.5324933 -> V=1.0158755, theta=0.0
% INFO    : Bus 1451	: V=1.02096203, theta=2.18354336 -> V=1.0158755, theta=0.0
% INFO    : Bus 1452	: V=1.02096203, theta=2.18354336 -> V=1.0158755, theta=0.0
% INFO    : Bus 1453	: V=1.02957138, theta=-18.2749577 -> V=1.0158755, theta=0.0
% INFO    : Bus 1454	: V=1.02812078, theta=-11.5264882 -> V=1.0158755, theta=0.0
% INFO    : Bus 1455	: V=1.06949858, theta=-9.5096516 -> V=1.0377785, theta=0.0
% INFO    : Bus 1456	: V=1.0148931, theta=-11.7472801 -> V=1.0000025, theta=0.0
% INFO    : Bus 1457	: V=0.585106678, theta=-13.9534582 -> V=0.825, theta=0.0
% INFO    : Bus 1458	: V=1.04492693, theta=-13.8813886 -> V=1.0158755, theta=0.0
% INFO    : Bus 1459	: V=0.995372068, theta=-0.633584797 -> V=1.0158755, theta=0.0
% INFO    : Bus 1460	: V=1.02526442, theta=-17.3742573 -> V=1.022224, theta=0.0
% INFO    : Bus 1461	: V=1.08369254, theta=-14.2252476 -> V=1.046385, theta=0.0
% INFO    : Bus 1462	: V=1.08409722, theta=-10.1073339 -> V=1.07237, theta=0.0
% INFO    : Bus 1463	: V=1.03938569, theta=-10.6811888 -> V=1.000001, theta=0.0
% INFO    : Bus 1464	: V=1.03727314, theta=-10.2330217 -> V=1.016666, theta=0.0
% INFO    : Bus 1465	: V=1.03941427, theta=-8.22970114 -> V=0.9977785, theta=0.0
% INFO    : Bus 1466	: V=1.01199297, theta=-11.5304292 -> V=1.0158755, theta=0.0
% INFO    : Bus 1467	: V=1.02260148, theta=-25.5328162 -> V=1.027779, theta=0.0
% INFO    : Bus 1468	: V=1.01810899, theta=-12.9319802 -> V=1.0158755, theta=0.0
% INFO    : Bus 1469	: V=1.01609227, theta=-19.6199922 -> V=1.0000005, theta=0.0
% INFO    : Bus 1470	: V=1.01847566, theta=-23.0322373 -> V=1.0000005, theta=0.0
% INFO    : Bus 1471	: V=1.05306635, theta=-24.4081605 -> V=1.0000025, theta=0.0
% INFO    : Bus 1472	: V=1.05398441, theta=-21.7032256 -> V=1.044445, theta=0.0
% INFO    : Bus 1473	: V=1.07529074, theta=-12.6189208 -> V=1.046665, theta=0.0
% INFO    : Bus 1474	: V=1.01330251, theta=-10.6506042 -> V=0.999999, theta=0.0
% INFO    : Bus 1475	: V=1.01773883, theta=-8.96670834 -> V=1.0158755, theta=0.0
% INFO    : Bus 1476	: V=1.04006842, theta=-16.072085 -> V=1.027779, theta=0.0
% INFO    : Bus 1477	: V=1.02592268, theta=-20.5245697 -> V=1.015872, theta=0.0
% INFO    : Bus 1478	: V=1.03745071, theta=-19.6472137 -> V=1.046665, theta=0.0
% INFO    : Bus 1479	: V=1.03793022, theta=-24.7436304 -> V=1.0000025, theta=0.0
% INFO    : Bus 1480	: V=1.09816069, theta=-16.8016607 -> V=1.0291655, theta=0.0
% INFO    : Bus 1481	: V=1.04934479, theta=-25.1043752 -> V=1.0000025, theta=0.0
% INFO    : Bus 1482	: V=1.12055785, theta=5.61727263 -> V=1.0424705, theta=0.0
% INFO    : Bus 1483	: V=0.99900946, theta=-7.07321799 -> V=1.0000015, theta=0.0
% INFO    : Bus 1484	: V=1.07571888, theta=-4.32582196 -> V=1.0266685, theta=0.0
% INFO    : Bus 1485	: V=1.05351819, theta=-6.69882474 -> V=0.9888895, theta=0.0
% INFO    : Bus 1486	: V=1.05486944, theta=-8.07108732 -> V=1.0111115, theta=0.0
% INFO    : Bus 1487	: V=1.0527456, theta=-27.5461053 -> V=1.0000025, theta=0.0
% INFO    : Bus 1488	: V=1.05989341, theta=-7.4245609 -> V=1.016666, theta=0.0
% INFO    : Bus 1489	: V=1.00745193, theta=-12.6407567 -> V=1.0158755, theta=0.0
% INFO    : Bus 1490	: V=1.05645618, theta=-10.4013965 -> V=1.0000025, theta=0.0
% INFO    : Bus 1491	: V=1.0327074, theta=-19.5116478 -> V=1.0000005, theta=0.0
% INFO    : Bus 1492	: V=1.07761766, theta=2.17927512 -> V=0.9888895, theta=0.0
% INFO    : Bus 1493	: V=1.06095592, theta=-19.4870723 -> V=1.022249, theta=0.0
% INFO    : Bus 1494	: V=1.05317817, theta=-5.28559848 -> V=0.9888895, theta=0.0
% INFO    : Bus 1495	: V=1.07461671, theta=-11.4499175 -> V=1.072365, theta=0.0
% INFO    : Bus 1496	: V=1.0566658, theta=-12.4042924 -> V=1.000001, theta=0.0
% INFO    : Bus 1497	: V=1.04970117, theta=-12.6857292 -> V=0.975, theta=0.0
% INFO    : Bus 1498	: V=1.03673443, theta=-33.0088125 -> V=1.022224, theta=0.0
% INFO    : Bus 1499	: V=1.01748675, theta=-25.5408024 -> V=1.022224, theta=0.0
% INFO    : Bus 1500	: V=1.05150223, theta=-9.23658868 -> V=1.0111115, theta=0.0
% INFO    : Bus 1501	: V=1.02578621, theta=-6.72474651 -> V=1.0158755, theta=0.0
% INFO    : Bus 1502	: V=1.0532172, theta=-1.2770982 -> V=1.0377785, theta=0.0
% INFO    : Bus 1503	: V=1.01328328, theta=3.39993558 -> V=1.013331, theta=0.0
% INFO    : Bus 1504	: V=1.06219003, theta=-13.7468019 -> V=1.027779, theta=0.0
% INFO    : Bus 1505	: V=1.06610877, theta=-14.0556987 -> V=1.027779, theta=0.0
% INFO    : Bus 1506	: V=1.04734998, theta=-8.58339056 -> V=1.027779, theta=0.0
% INFO    : Bus 1507	: V=0.97525834, theta=-19.4288288 -> V=1.015872, theta=0.0
% INFO    : Bus 1508	: V=1.02718998, theta=-23.8809665 -> V=1.0000025, theta=0.0
% INFO    : Bus 1509	: V=1.01043128, theta=1.2964122 -> V=1.0158755, theta=0.0
% INFO    : Bus 1510	: V=0.968610984, theta=-16.778005 -> V=1.015872, theta=0.0
% INFO    : Bus 1511	: V=1.04177412, theta=-19.0925115 -> V=1.015872, theta=0.0
% INFO    : Bus 1512	: V=1.00797925, theta=-16.0305329 -> V=1.0158755, theta=0.0
% INFO    : Bus 1513	: V=1.03983634, theta=-40.6642448 -> V=1.0079355, theta=0.0
% INFO    : Bus 1514	: V=1.05346065, theta=-37.8071936 -> V=1.0079355, theta=0.0
% INFO    : Bus 1515	: V=1.07148363, theta=-40.2187954 -> V=1.04444, theta=0.0
% INFO    : Bus 1516	: V=1.02671002, theta=-24.7944122 -> V=1.022224, theta=0.0
% INFO    : Bus 1517	: V=1.07163479, theta=-21.9112361 -> V=1.04444, theta=0.0
% INFO    : Bus 1518	: V=1.08085873, theta=-17.323371 -> V=1.07237, theta=0.0
% INFO    : Bus 1519	: V=1.04852513, theta=-21.1437664 -> V=1.027779, theta=0.0
% INFO    : Bus 1520	: V=1.091, theta=9.34773199 -> V=0.975, theta=0.0
% INFO    : Bus 1521	: V=0.959, theta=11.3290568 -> V=0.975, theta=0.0
% INFO    : Bus 1522	: V=1.1, theta=4.65685274 -> V=0.975, theta=0.0
% INFO    : Bus 1523	: V=0.957, theta=6.02039767 -> V=0.975, theta=0.0
% INFO    : Bus 1524	: V=1.07278078, theta=4.58552426 -> V=1.0222245, theta=0.0
% INFO    : Bus 1525	: V=1.07644, theta=2.78844696 -> V=1.0222245, theta=0.0
% INFO    : Bus 1526	: V=1.01913436, theta=-38.8225536 -> V=1.0079355, theta=0.0
% INFO    : Bus 1527	: V=1.06211613, theta=-35.9741223 -> V=1.04444, theta=0.0
% INFO    : Bus 1528	: V=1.02230683, theta=-6.51523154 -> V=1.0158755, theta=0.0
% INFO    : Bus 1529	: V=1.03111968, theta=-41.2061713 -> V=1.0079355, theta=0.0
% INFO    : Bus 1530	: V=1.01412837, theta=-3.49563026 -> V=1.0158755, theta=0.0
% INFO    : Bus 1531	: V=1.01483527, theta=-14.8915012 -> V=0.999999, theta=0.0
% INFO    : Bus 1532	: V=1.05850712, theta=-30.003256 -> V=1.027779, theta=0.0
% INFO    : Bus 1533	: V=1.04006935, theta=-31.6519521 -> V=1.022224, theta=0.0
% INFO    : Bus 1534	: V=1.04285488, theta=-34.3280672 -> V=1.022224, theta=0.0
% INFO    : Bus 1535	: V=1.07161686, theta=-29.5945517 -> V=1.04444, theta=0.0
% INFO    : Bus 1536	: V=1.07826974, theta=-25.032096 -> V=1.07237, theta=0.0
% INFO    : Bus 1537	: V=1.01246175, theta=-21.4372282 -> V=0.999999, theta=0.0
% INFO    : Bus 1538	: V=1.03745774, theta=-1.97505001 -> V=1.000001, theta=0.0
% INFO    : Bus 1539	: V=1.03312077, theta=-35.9046173 -> V=1.0079355, theta=0.0
% INFO    : Bus 1540	: V=1.00867523, theta=-21.9793233 -> V=0.999999, theta=0.0
% INFO    : Bus 1541	: V=1.07392386, theta=-14.9835261 -> V=1.044445, theta=0.0
% INFO    : Bus 1542	: V=1.08769397, theta=-9.11475762 -> V=1.078945, theta=0.0
% INFO    : Bus 1543	: V=1.04110482, theta=-24.3112346 -> V=1.000001, theta=0.0
% INFO    : Bus 1544	: V=1.06172364, theta=-20.8566646 -> V=1.044445, theta=0.0
% INFO    : Bus 1545	: V=1.05693785, theta=-15.4730189 -> V=1.022224, theta=0.0
% INFO    : Bus 1546	: V=1.0277289, theta=-27.34757 -> V=0.999999, theta=0.0
% INFO    : Bus 1547	: V=1.01817562, theta=-12.0010802 -> V=1.0000025, theta=0.0
% INFO    : Bus 1548	: V=1.04113098, theta=-7.6685428 -> V=1.0158755, theta=0.0
% INFO    : Bus 1549	: V=1.02976639, theta=-32.5270305 -> V=1.022224, theta=0.0
% INFO    : Bus 1550	: V=1.02535689, theta=-48.7220998 -> V=1.0079355, theta=0.0
% INFO    : Bus 1551	: V=1.0184961, theta=-15.9517622 -> V=1.0158755, theta=0.0
% INFO    : Bus 1552	: V=1.0272998, theta=-28.227288 -> V=1.0000025, theta=0.0
% INFO    : Bus 1553	: V=1.04144318, theta=-13.4037427 -> V=1.022222, theta=0.0
% INFO    : Bus 1554	: V=1.06420827, theta=-33.3383804 -> V=1.04444, theta=0.0
% INFO    : Bus 1555	: V=1.04362401, theta=-22.7131068 -> V=1.027779, theta=0.0
% INFO    : Bus 1556	: V=1.01976921, theta=-18.6497098 -> V=0.999999, theta=0.0
% INFO    : Bus 1557	: V=1.02639713, theta=-17.6439914 -> V=1.0158755, theta=0.0
% INFO    : Bus 1558	: V=1.06421873, theta=-11.0764535 -> V=1.022222, theta=0.0
% INFO    : Bus 1559	: V=1.05246188, theta=-6.63180234 -> V=0.9888895, theta=0.0
% INFO    : Bus 1560	: V=1.047, theta=-10.8264639 -> V=1.033333, theta=0.0
% INFO    : Bus 1561	: V=1.01983883, theta=-30.555368 -> V=1.015872, theta=0.0
% INFO    : Bus 1562	: V=1.07400828, theta=-15.4630768 -> V=1.046665, theta=0.0
% INFO    : Bus 1563	: V=1.04331477, theta=-24.4088237 -> V=1.027779, theta=0.0
% INFO    : Bus 1564	: V=1.06461322, theta=-21.5097951 -> V=1.027779, theta=0.0
% INFO    : Bus 1565	: V=1.07259001, theta=-18.1676084 -> V=1.046665, theta=0.0
% INFO    : Bus 1566	: V=1.02972722, theta=-33.1641727 -> V=1.022224, theta=0.0
% INFO    : Bus 1567	: V=1.01741518, theta=-4.00226086 -> V=1.0158755, theta=0.0
% INFO    : Bus 1568	: V=1.02290821, theta=-14.0681375 -> V=0.999999, theta=0.0
% INFO    : Bus 1569	: V=1.02226818, theta=-14.2922958 -> V=0.999999, theta=0.0
% INFO    : Bus 1570	: V=0.975752362, theta=-4.93296301 -> V=1.0158755, theta=0.0
% INFO    : Bus 1571	: V=1.0701784, theta=-1.67102349 -> V=1.005558, theta=0.0
% INFO    : Bus 1572	: V=1.06806679, theta=1.09967714 -> V=0.9888895, theta=0.0
% INFO    : Bus 1573	: V=1.03348773, theta=-17.386362 -> V=0.999999, theta=0.0
% INFO    : Bus 1574	: V=1.03198528, theta=-17.299889 -> V=1.022224, theta=0.0
% INFO    : Bus 1575	: V=1.0440266, theta=-18.3797542 -> V=1.046665, theta=0.0
% INFO    : Bus 1576	: V=1.0122523, theta=-19.8117129 -> V=0.999999, theta=0.0
% INFO    : Bus 1577	: V=1.01103819, theta=-19.6584682 -> V=1.0000005, theta=0.0
% INFO    : Bus 1578	: V=1.08762859, theta=-4.9313066 -> V=1.07237, theta=0.0
% INFO    : Bus 1579	: V=1.0876011, theta=-4.93119787 -> V=1.07237, theta=0.0
% INFO    : Bus 1580	: V=1.08757251, theta=-4.92976249 -> V=1.07237, theta=0.0
% INFO    : Bus 1581	: V=1.08757008, theta=-4.92691748 -> V=1.07237, theta=0.0
% INFO    : Bus 1582	: V=1.01777759, theta=-25.6638965 -> V=1.022224, theta=0.0
% INFO    : Bus 1583	: V=1.04603573, theta=-26.461005 -> V=1.046665, theta=0.0
% INFO    : Bus 1584	: V=1.01450471, theta=-13.6847253 -> V=0.999999, theta=0.0
% INFO    : Bus 1585	: V=1.05029066, theta=-7.71674825 -> V=1.0111115, theta=0.0
% INFO    : Bus 1586	: V=1.06959337, theta=-2.14387057 -> V=1.072365, theta=0.0
% INFO    : Bus 1587	: V=1.00964472, theta=-15.8208201 -> V=0.999999, theta=0.0
% INFO    : Bus 1588	: V=1.06949332, theta=-6.94533533 -> V=1.016666, theta=0.0
% INFO    : Bus 1589	: V=1.06629355, theta=-2.6362766 -> V=1.0288895, theta=0.0
% INFO    : Bus 1590	: V=1.02395787, theta=-30.4505022 -> V=1.022224, theta=0.0
% INFO    : Bus 1591	: V=1.03302355, theta=-30.2719375 -> V=1.022224, theta=0.0
% INFO    : Bus 1592	: V=1.05581714, theta=-16.6229585 -> V=1.027779, theta=0.0
% INFO    : Bus 1593	: V=1.01096857, theta=3.51016854 -> V=1.013331, theta=0.0
% INFO    : Bus 1594	: V=0.998409127, theta=-24.3900602 -> V=1.0000005, theta=0.0
% INFO    : Bus 1595	: V=1.04947073, theta=-22.5585422 -> V=1.000001, theta=0.0
% INFO    : Bus 1596	: V=1.00287235, theta=-25.9829366 -> V=1.015872, theta=0.0
% INFO    : Bus 1597	: V=1.02353428, theta=-16.0904229 -> V=0.975, theta=0.0
% INFO    : Bus 1598	: V=1.04444788, theta=-19.3714299 -> V=1.022224, theta=0.0
% INFO    : Bus 1599	: V=1.041, theta=-17.4928556 -> V=1.022224, theta=0.0
% INFO    : Bus 1600	: V=1.08101104, theta=-14.6517579 -> V=1.045075, theta=0.0
% INFO    : Bus 1601	: V=1.08866285, theta=-9.35051519 -> V=1.07237, theta=0.0
% INFO    : Bus 1602	: V=1.01442475, theta=-22.5522955 -> V=1.0000005, theta=0.0
% INFO    : Bus 1603	: V=1.06201019, theta=-19.4170298 -> V=1.046665, theta=0.0
% INFO    : Bus 1604	: V=1.0586305, theta=-19.6504323 -> V=1.046665, theta=0.0
% INFO    : Bus 1605	: V=1.039, theta=-21.3571779 -> V=1.0000005, theta=0.0
% INFO    : Bus 1606	: V=1.07505856, theta=-17.5243352 -> V=1.046665, theta=0.0
% INFO    : Bus 1607	: V=1.01399138, theta=-18.8331091 -> V=1.015872, theta=0.0
% INFO    : Bus 1608	: V=1.07967232, theta=-18.231278 -> V=1.044445, theta=0.0
% INFO    : Bus 1609	: V=1.02993909, theta=2.16399583 -> V=1.0158755, theta=0.0
% INFO    : Bus 1610	: V=0.984450974, theta=-26.3627446 -> V=1.0000025, theta=0.0
% INFO    : Bus 1611	: V=1.02400998, theta=-6.82001895 -> V=1.0158755, theta=0.0
% INFO    : Bus 1612	: V=1.0099732, theta=-25.5916969 -> V=1.015872, theta=0.0
% INFO    : Bus 1613	: V=1.01198593, theta=-31.4044447 -> V=1.015872, theta=0.0
% INFO    : Bus 1614	: V=0.997020272, theta=-24.6902974 -> V=1.015872, theta=0.0
% INFO    : Bus 1615	: V=1.05006017, theta=-24.3049647 -> V=1.0233335, theta=0.0
% INFO    : Bus 1616	: V=1.02797853, theta=-20.3316896 -> V=0.999999, theta=0.0
% INFO    : Bus 1617	: V=1.0285509, theta=-20.8594692 -> V=0.999999, theta=0.0
% INFO    : Bus 1618	: V=1.0327992, theta=-16.8639736 -> V=1.0111115, theta=0.0
% INFO    : Bus 1619	: V=1.05014034, theta=-6.29775998 -> V=1.027779, theta=0.0
% INFO    : Bus 1620	: V=1.01477046, theta=-23.8097994 -> V=1.0079355, theta=0.0
% INFO    : Bus 1621	: V=1.01447955, theta=-23.809207 -> V=1.022224, theta=0.0
% INFO    : Bus 1622	: V=1.02479432, theta=-13.046268 -> V=1.0000025, theta=0.0
% INFO    : Bus 1623	: V=0.941220763, theta=-7.21221467 -> V=0.9444445, theta=0.0
% INFO    : Bus 1624	: V=0.993219631, theta=-25.8251943 -> V=1.0000005, theta=0.0
% INFO    : Bus 1625	: V=1.02246474, theta=-20.667541 -> V=1.0000005, theta=0.0
% INFO    : Bus 1626	: V=1.03275129, theta=-33.0130367 -> V=1.022224, theta=0.0
% INFO    : Bus 1627	: V=1.01035593, theta=-18.67021 -> V=1.0158755, theta=0.0
% INFO    : Bus 1628	: V=1.07034041, theta=-4.38001088 -> V=0.9888895, theta=0.0
% INFO    : Bus 1629	: V=1.06994453, theta=-4.41508283 -> V=0.9888895, theta=0.0
% INFO    : Bus 1630	: V=1.059, theta=-4.07423272 -> V=1.0377785, theta=0.0
% INFO    : Bus 1631	: V=1.03956841, theta=-16.1031496 -> V=1.027779, theta=0.0
% INFO    : Bus 1632	: V=1.0814515, theta=-16.5443155 -> V=1.046665, theta=0.0
% INFO    : Bus 1633	: V=1.02284458, theta=-34.3671979 -> V=1.022224, theta=0.0
% INFO    : Bus 1634	: V=1.02204422, theta=-40.047859 -> V=1.0079355, theta=0.0
% INFO    : Bus 1635	: V=1.02349282, theta=-27.058255 -> V=1.0000025, theta=0.0
% INFO    : Bus 1636	: V=1.01451036, theta=0.986137992 -> V=1.0158755, theta=0.0
% INFO    : Bus 1637	: V=1.00210812, theta=-7.72885823 -> V=1.0158755, theta=0.0
% INFO    : Bus 1638	: V=1.02370175, theta=-28.5637216 -> V=1.015872, theta=0.0
% INFO    : Bus 1639	: V=1.04226516, theta=-22.9735945 -> V=1.046665, theta=0.0
% INFO    : Bus 1640	: V=0.98047545, theta=-34.6315297 -> V=1.015872, theta=0.0
% INFO    : Bus 1641	: V=1.02030187, theta=-29.0184151 -> V=1.0000025, theta=0.0
% INFO    : Bus 1642	: V=1.04594094, theta=-13.9074615 -> V=1.000334, theta=0.0
% INFO    : Bus 1643	: V=1.0352355, theta=-21.5054978 -> V=1.0000025, theta=0.0
% INFO    : Bus 1644	: V=1.01968843, theta=-27.3440053 -> V=1.0000025, theta=0.0
% INFO    : Bus 1645	: V=1.081, theta=-15.1144167 -> V=1.04445, theta=0.0
% INFO    : Bus 1646	: V=1.00046172, theta=-25.1452993 -> V=1.0000025, theta=0.0
% INFO    : Bus 1647	: V=1.05956756, theta=-10.2893224 -> V=1.033333, theta=0.0
% INFO    : Bus 1648	: V=1.03913389, theta=-25.2555285 -> V=1.0000025, theta=0.0
% INFO    : Bus 1649	: V=1.05779805, theta=-38.5391119 -> V=1.022224, theta=0.0
% INFO    : Bus 1650	: V=1.06515201, theta=-38.8947096 -> V=1.022284, theta=0.0
% INFO    : Bus 1651	: V=1.07883151, theta=-12.2881166 -> V=1.033333, theta=0.0
% INFO    : Bus 1652	: V=1.01193094, theta=-12.0125164 -> V=1.0158755, theta=0.0
% INFO    : Bus 1653	: V=1.00352441, theta=-3.5655231 -> V=1.0158755, theta=0.0
% INFO    : Bus 1654	: V=1.02781088, theta=-19.7380358 -> V=1.0000005, theta=0.0
% INFO    : Bus 1655	: V=1.02841418, theta=-19.6912765 -> V=1.0000005, theta=0.0
% INFO    : Bus 1656	: V=1.02745649, theta=-19.7377475 -> V=1.0000005, theta=0.0
% INFO    : Bus 1657	: V=1.06608375, theta=-8.77413481 -> V=1.022222, theta=0.0
% INFO    : Bus 1658	: V=1.01165322, theta=-24.7016025 -> V=1.015872, theta=0.0
% INFO    : Bus 1659	: V=1.02900261, theta=-16.9114467 -> V=1.0000025, theta=0.0
% INFO    : Bus 1660	: V=1.01838529, theta=-17.329812 -> V=1.0000005, theta=0.0
% INFO    : Bus 1661	: V=1.06128119, theta=-5.08402152 -> V=0.9888895, theta=0.0
% INFO    : Bus 1662	: V=1.01720248, theta=-12.6262704 -> V=0.999999, theta=0.0
% INFO    : Bus 1663	: V=1.03957167, theta=-20.6732236 -> V=1.0000025, theta=0.0
% INFO    : Bus 1664	: V=0.990070365, theta=-2.78238633 -> V=1.0158755, theta=0.0
% INFO    : Bus 1665	: V=1.00164266, theta=-20.2446616 -> V=1.0000005, theta=0.0
% INFO    : Bus 1666	: V=1.02614957, theta=-21.4640239 -> V=1.015872, theta=0.0
% INFO    : Bus 1667	: V=1.02385895, theta=-21.8745642 -> V=1.0000025, theta=0.0
% INFO    : Bus 1668	: V=1.05449356, theta=-6.61472414 -> V=0.9888895, theta=0.0
% INFO    : Bus 1669	: V=1.0266468, theta=-6.5183842 -> V=1.0158755, theta=0.0
% INFO    : Bus 1670	: V=1.06324282, theta=-3.75173973 -> V=1.0377785, theta=0.0
% INFO    : Bus 1671	: V=1.0231244, theta=-19.8696114 -> V=1.0000005, theta=0.0
% INFO    : Bus 1672	: V=1.05253206, theta=-19.005898 -> V=1.027779, theta=0.0
% INFO    : Bus 1673	: V=1.02020639, theta=-11.5563783 -> V=1.0158755, theta=0.0
% INFO    : Bus 1674	: V=1.06584713, theta=-7.4894293 -> V=1.0377785, theta=0.0
% INFO    : Bus 1675	: V=1.03950544, theta=-8.02534409 -> V=1.0111115, theta=0.0
% INFO    : Bus 1676	: V=1.04759456, theta=-17.2405454 -> V=0.999999, theta=0.0
% INFO    : Bus 1677	: V=1.05330719, theta=-17.2402334 -> V=0.999999, theta=0.0
% INFO    : Bus 1678	: V=1.04252749, theta=-21.7786851 -> V=1.027779, theta=0.0
% INFO    : Bus 1679	: V=1.02921584, theta=-35.9788155 -> V=1.022224, theta=0.0
% INFO    : Bus 1680	: V=1.02953976, theta=-36.22924 -> V=1.022224, theta=0.0
% INFO    : Bus 1681	: V=1.01067366, theta=-36.6212552 -> V=1.0000025, theta=0.0
% INFO    : Bus 1682	: V=1.02638713, theta=-12.9247408 -> V=0.999999, theta=0.0
% INFO    : Bus 1683	: V=1.05039165, theta=-9.82207009 -> V=1.0111115, theta=0.0
% INFO    : Bus 1684	: V=1.01797476, theta=-18.6468921 -> V=1.015872, theta=0.0
% INFO    : Bus 1685	: V=1.00006667, theta=-31.6647574 -> V=1.0000025, theta=0.0
% INFO    : Bus 1686	: V=1.01767101, theta=-23.6315514 -> V=1.015872, theta=0.0
% INFO    : Bus 1687	: V=1.01618771, theta=-22.0568836 -> V=0.999999, theta=0.0
% INFO    : Bus 1688	: V=1.0352355, theta=-21.5054978 -> V=1.0000025, theta=0.0
% INFO    : Bus 1689	: V=1.02325919, theta=-24.4106593 -> V=1.015872, theta=0.0
% INFO    : Bus 1690	: V=1.04639582, theta=-19.245894 -> V=1.046665, theta=0.0
% INFO    : Bus 1691	: V=1.01578201, theta=1.13958698 -> V=1.0158755, theta=0.0
% INFO    : Bus 1692	: V=1.05509609, theta=-28.0709418 -> V=1.022224, theta=0.0
% INFO    : Bus 1693	: V=0.982, theta=-26.5833033 -> V=1.0000025, theta=0.0
% INFO    : Bus 1694	: V=1.03314083, theta=-26.0927744 -> V=1.022224, theta=0.0
% INFO    : Bus 1695	: V=1.09278077, theta=10.621693 -> V=1.072365, theta=0.0
% INFO    : Bus 1696	: V=1.09300468, theta=10.6374442 -> V=1.072365, theta=0.0
% INFO    : Bus 1697	: V=1.029, theta=3.94422162 -> V=1.0158755, theta=0.0
% INFO    : Bus 1698	: V=1.0772351, theta=6.72521228 -> V=1.0379185, theta=0.0
% INFO    : Bus 1699	: V=1.07711599, theta=6.71253341 -> V=1.0378585, theta=0.0
% INFO    : Bus 1700	: V=1.03915289, theta=-25.2673058 -> V=1.0000025, theta=0.0
% INFO    : Bus 1701	: V=1.02075629, theta=-16.3644913 -> V=1.015872, theta=0.0
% INFO    : Bus 1702	: V=1.01953696, theta=3.50926723 -> V=1.0158755, theta=0.0
% INFO    : Bus 1703	: V=1.009, theta=-21.6093435 -> V=1.0000025, theta=0.0
% INFO    : Bus 1704	: V=1.04772692, theta=-22.6479664 -> V=1.0000025, theta=0.0
% INFO    : Bus 1705	: V=1.043226, theta=-23.3627027 -> V=1.0000025, theta=0.0
% INFO    : Bus 1706	: V=1.01597155, theta=-21.6964703 -> V=0.999999, theta=0.0
% INFO    : Bus 1707	: V=1.08256226, theta=-16.3498685 -> V=1.046665, theta=0.0
% INFO    : Bus 1708	: V=1.02065612, theta=-19.3464813 -> V=1.0000005, theta=0.0
% INFO    : Bus 1709	: V=1.01888754, theta=-19.1519899 -> V=1.0000005, theta=0.0
% INFO    : Bus 1710	: V=1.06253591, theta=-16.5556411 -> V=1.046665, theta=0.0
% INFO    : Bus 1711	: V=1.0625511, theta=-16.5566628 -> V=1.046665, theta=0.0
% INFO    : Bus 1712	: V=1.06256967, theta=-16.5569353 -> V=1.046665, theta=0.0
% INFO    : Bus 1713	: V=1.06253455, theta=-16.5560496 -> V=1.046665, theta=0.0
% INFO    : Bus 1714	: V=1.02098994, theta=-19.3731402 -> V=1.0000005, theta=0.0
% INFO    : Bus 1715	: V=1.0187545, theta=-19.2233959 -> V=1.0000005, theta=0.0
% INFO    : Bus 1716	: V=1.06255179, theta=-16.5515993 -> V=1.046665, theta=0.0
% INFO    : Bus 1717	: V=1.07229399, theta=-8.88121335 -> V=1.015874, theta=0.0
% INFO    : Bus 1718	: V=1.06151225, theta=-5.11238 -> V=1.015556, theta=0.0
% INFO    : Bus 1719	: V=1.06425174, theta=-16.0516049 -> V=1.046665, theta=0.0
% INFO    : Bus 1720	: V=1.06393852, theta=-16.0608489 -> V=1.046665, theta=0.0
% INFO    : Bus 1721	: V=1.01958773, theta=-14.9813906 -> V=0.999999, theta=0.0
% INFO    : Bus 1722	: V=1.03134837, theta=-25.9843791 -> V=1.022224, theta=0.0
% INFO    : Bus 1723	: V=1.06928783, theta=-22.8496569 -> V=1.04444, theta=0.0
% INFO    : Bus 1724	: V=1.03037649, theta=-30.4631906 -> V=1.0000025, theta=0.0
% INFO    : Bus 1725	: V=1.00429422, theta=-25.2661284 -> V=1.0000025, theta=0.0
% INFO    : Bus 1726	: V=1.04954052, theta=-17.4571083 -> V=1.046665, theta=0.0
% INFO    : Bus 1727	: V=0.998077206, theta=-14.2234005 -> V=0.999999, theta=0.0
% INFO    : Bus 1728	: V=1.03582304, theta=-13.025088 -> V=0.975, theta=0.0
% INFO    : Bus 1729	: V=1.03478825, theta=-13.025088 -> V=0.999999, theta=0.0
% INFO    : Bus 1730	: V=1.01302793, theta=-28.7776482 -> V=1.022224, theta=0.0
% INFO    : Bus 1731	: V=1.05315438, theta=-16.6464477 -> V=1.027779, theta=0.0
% INFO    : Bus 1732	: V=1.05983692, theta=-7.44164133 -> V=1.0111115, theta=0.0
% INFO    : Bus 1733	: V=1.018, theta=-10.0819813 -> V=0.999999, theta=0.0
% INFO    : Bus 1734	: V=1.03859199, theta=-13.6111924 -> V=1.0000025, theta=0.0
% INFO    : Bus 1735	: V=1.06693204, theta=-23.9018201 -> V=1.0000025, theta=0.0
% INFO    : Bus 1736	: V=1.06477637, theta=-20.9497407 -> V=1.044445, theta=0.0
% INFO    : Bus 1737	: V=1.04692115, theta=-26.6557648 -> V=1.027779, theta=0.0
% INFO    : Bus 1738	: V=1.02962808, theta=-20.2380051 -> V=1.022224, theta=0.0
% INFO    : Bus 1739	: V=1.039, theta=-26.980897 -> V=1.0000025, theta=0.0
% INFO    : Bus 1740	: V=1.02173736, theta=-18.5189786 -> V=1.015872, theta=0.0
% INFO    : Bus 1741	: V=1.0831132, theta=-3.04272228 -> V=1.0377785, theta=0.0
% INFO    : Bus 1742	: V=1.08310884, theta=-3.04266357 -> V=1.0377785, theta=0.0
% INFO    : Bus 1743	: V=1.10420809, theta=1.69396768 -> V=1.072365, theta=0.0
% INFO    : Bus 1744	: V=1.10446275, theta=1.69491742 -> V=1.072365, theta=0.0
% INFO    : Bus 1745	: V=1.08315132, theta=-3.0432338 -> V=1.0377785, theta=0.0
% INFO    : Bus 1746	: V=1.127, theta=1.39509187 -> V=0.975, theta=0.0
% INFO    : Bus 1747	: V=1.109, theta=3.69695849 -> V=0.975, theta=0.0
% INFO    : Bus 1748	: V=1.12, theta=3.47035346 -> V=0.975, theta=0.0
% INFO    : Bus 1749	: V=1.08328534, theta=-3.02714336 -> V=1.0377785, theta=0.0
% INFO    : Bus 1750	: V=1.08320525, theta=-3.01938291 -> V=1.0377785, theta=0.0
% INFO    : Bus 1751	: V=1.08324498, theta=-3.01990714 -> V=1.0377785, theta=0.0
% INFO    : Bus 1752	: V=1.0178293, theta=-20.6827497 -> V=1.015872, theta=0.0
% INFO    : Bus 1753	: V=1.01936571, theta=-20.7110979 -> V=1.015872, theta=0.0
% INFO    : Bus 1754	: V=1.04015312, theta=-19.5972532 -> V=1.046665, theta=0.0
% INFO    : Bus 1755	: V=0.99290997, theta=-20.7553318 -> V=0.999999, theta=0.0
% INFO    : Bus 1756	: V=1.01796899, theta=-11.5539616 -> V=0.999999, theta=0.0
% INFO    : Bus 1757	: V=1.02905215, theta=-11.2735325 -> V=0.999999, theta=0.0
% INFO    : Bus 1758	: V=1.02298613, theta=-12.0323734 -> V=0.999999, theta=0.0
% INFO    : Bus 1759	: V=1.02339143, theta=-24.9522038 -> V=1.0000025, theta=0.0
% INFO    : Bus 1760	: V=1.02744925, theta=-24.6189382 -> V=1.0000025, theta=0.0
% INFO    : Bus 1761	: V=0.971390919, theta=-15.0983011 -> V=1.0158755, theta=0.0
% INFO    : Bus 1762	: V=1.03822541, theta=-10.4136858 -> V=1.0111115, theta=0.0
% INFO    : Bus 1763	: V=1.01430445, theta=-19.2104657 -> V=1.015872, theta=0.0
% INFO    : Bus 1764	: V=1.01882241, theta=-13.1451634 -> V=1.0000025, theta=0.0
% INFO    : Bus 1765	: V=1.00795216, theta=-29.4003658 -> V=1.0000025, theta=0.0
% INFO    : Bus 1766	: V=0.997790067, theta=-17.1497149 -> V=1.0158755, theta=0.0
% INFO    : Bus 1767	: V=1.09617947, theta=-12.1681839 -> V=1.073685, theta=0.0
% INFO    : Bus 1768	: V=1.09999827, theta=-9.71711812 -> V=1.073685, theta=0.0
% INFO    : Bus 1769	: V=1.09981584, theta=-9.62632858 -> V=1.073685, theta=0.0
% INFO    : Bus 1770	: V=1.09609859, theta=-12.1679262 -> V=1.073685, theta=0.0
% INFO    : Bus 1771	: V=1.01877373, theta=-25.9952657 -> V=1.0000025, theta=0.0
% INFO    : Bus 1772	: V=1.06393986, theta=-4.54577307 -> V=0.9888895, theta=0.0
% INFO    : Bus 1773	: V=1.03394386, theta=-20.5134094 -> V=0.999999, theta=0.0
% INFO    : Bus 1774	: V=1.07358005, theta=-15.692558 -> V=1.046665, theta=0.0
% INFO    : Bus 1775	: V=1.02744399, theta=-24.1058147 -> V=1.0079355, theta=0.0
% INFO    : Bus 1776	: V=1.04560446, theta=-25.3701014 -> V=1.022224, theta=0.0
% INFO    : Bus 1777	: V=1.06299434, theta=-26.9513041 -> V=1.022224, theta=0.0
% INFO    : Bus 1778	: V=1.06422329, theta=-22.8111095 -> V=1.04444, theta=0.0
% INFO    : Bus 1779	: V=1.01759044, theta=-30.9351425 -> V=1.022224, theta=0.0
% INFO    : Bus 1780	: V=1.07150912, theta=-28.7568122 -> V=1.028979, theta=0.0
% INFO    : Bus 1781	: V=1.07337598, theta=-25.7830715 -> V=1.046665, theta=0.0
% INFO    : Bus 1782	: V=0.983369921, theta=-29.0656354 -> V=1.0000025, theta=0.0
% INFO    : Bus 1783	: V=0.996733668, theta=-17.2051979 -> V=1.0158755, theta=0.0
% INFO    : Bus 1784	: V=1.04101173, theta=-0.802975686 -> V=0.984126, theta=0.0
% INFO    : Bus 1785	: V=1.01725083, theta=-16.8241071 -> V=0.999999, theta=0.0
% INFO    : Bus 1786	: V=1.04456328, theta=-12.9310527 -> V=1.0111115, theta=0.0
% INFO    : Bus 1787	: V=1.03853008, theta=-21.3850299 -> V=1.0000005, theta=0.0
% INFO    : Bus 1788	: V=1.02174601, theta=-15.9068391 -> V=1.0158755, theta=0.0
% INFO    : Bus 1789	: V=1.02181917, theta=-15.9139471 -> V=1.0158755, theta=0.0
% INFO    : Bus 1790	: V=1.03661168, theta=-2.25949632 -> V=1.0000025, theta=0.0
% INFO    : Bus 1791	: V=1.04114655, theta=-20.5135356 -> V=1.0000025, theta=0.0
% INFO    : Bus 1792	: V=1.04833795, theta=-20.3794875 -> V=1.000001, theta=0.0
% INFO    : Bus 1793	: V=1.06989858, theta=-17.2315791 -> V=1.044445, theta=0.0
% INFO    : Bus 1794	: V=1.01307484, theta=-22.6537654 -> V=1.0000025, theta=0.0
% INFO    : Bus 1795	: V=1.04649515, theta=-19.7014271 -> V=1.044445, theta=0.0
% INFO    : Bus 1796	: V=0.999166762, theta=-18.4329134 -> V=1.015872, theta=0.0
% INFO    : Bus 1797	: V=1.06932429, theta=-18.942359 -> V=1.046665, theta=0.0
% INFO    : Bus 1798	: V=1.06916277, theta=-18.9610659 -> V=1.046665, theta=0.0
% INFO    : Bus 1799	: V=1.03845786, theta=-27.1507606 -> V=1.0000025, theta=0.0
% INFO    : Bus 1800	: V=1.03857656, theta=-27.1420157 -> V=1.0000025, theta=0.0
% INFO    : Bus 1801	: V=1.07770214, theta=-15.7851903 -> V=1.046665, theta=0.0
% INFO    : Bus 1802	: V=1.0006752, theta=-25.9704409 -> V=1.0000025, theta=0.0
% INFO    : Bus 1803	: V=1.02432183, theta=-18.3866353 -> V=0.999999, theta=0.0
% INFO    : Bus 1804	: V=1.04961782, theta=-13.5698991 -> V=1.0111115, theta=0.0
% INFO    : Bus 1805	: V=1.02420743, theta=2.90978765 -> V=1.0158755, theta=0.0
% INFO    : Bus 1806	: V=1.02272937, theta=2.81808422 -> V=1.0158755, theta=0.0
% INFO    : Bus 1807	: V=1.00748924, theta=-29.8369483 -> V=1.0000025, theta=0.0
% INFO    : Bus 1808	: V=1.01858083, theta=-7.83525042 -> V=1.0079355, theta=0.0
% INFO    : Bus 1809	: V=1.07046536, theta=-1.56697394 -> V=1.033333, theta=0.0
% INFO    : Bus 1810	: V=1.02330453, theta=-20.894863 -> V=1.0000005, theta=0.0
% INFO    : Bus 1811	: V=1.06863672, theta=-16.1261752 -> V=1.046665, theta=0.0
% INFO    : Bus 1812	: V=0.973066453, theta=-24.3966179 -> V=1.0000025, theta=0.0
% INFO    : Bus 1813	: V=1.04294501, theta=-29.4965719 -> V=1.022224, theta=0.0
% INFO    : Bus 1814	: V=1.01543082, theta=-11.6457544 -> V=1.0158755, theta=0.0
% INFO    : Bus 1815	: V=1.03444541, theta=-32.7057549 -> V=1.022224, theta=0.0
% INFO    : Bus 1816	: V=1.04631313, theta=-11.7611852 -> V=1.005558, theta=0.0
% INFO    : Bus 1817	: V=1.04074279, theta=-20.0788753 -> V=1.027779, theta=0.0
% INFO    : Bus 1818	: V=1.04327424, theta=-24.4076079 -> V=1.027779, theta=0.0
% INFO    : Bus 1819	: V=1.04186859, theta=-10.1951928 -> V=1.000001, theta=0.0
% INFO    : Bus 1820	: V=1.00855192, theta=-27.8645338 -> V=1.022224, theta=0.0
% INFO    : Bus 1821	: V=1.04203181, theta=-10.1921015 -> V=1.0000025, theta=0.0
% INFO    : Bus 1822	: V=1.01979374, theta=-20.6312742 -> V=1.0000025, theta=0.0
% INFO    : Bus 1823	: V=1.05532317, theta=-16.2409064 -> V=1.044445, theta=0.0
% INFO    : Bus 1824	: V=1.0704564, theta=1.17356285 -> V=0.9888895, theta=0.0
% INFO    : Bus 1825	: V=1.05149337, theta=-7.8714178 -> V=1.0111115, theta=0.0
% INFO    : Bus 1826	: V=1.0191832, theta=-10.6729717 -> V=1.0158755, theta=0.0
% INFO    : Bus 1827	: V=1.05421934, theta=-8.44663378 -> V=1.0377785, theta=0.0
% INFO    : Bus 1828	: V=1.08721918, theta=-5.80369085 -> V=1.072365, theta=0.0
% INFO    : Bus 1829	: V=1.00454637, theta=-34.9998877 -> V=1.022224, theta=0.0
% INFO    : Bus 1830	: V=1.01035753, theta=-22.062096 -> V=1.0000025, theta=0.0
% INFO    : Bus 1831	: V=1.02143423, theta=-32.4724661 -> V=1.015872, theta=0.0
% INFO    : Bus 1832	: V=1.0355247, theta=-26.9147844 -> V=1.046665, theta=0.0
% INFO    : Bus 1833	: V=1.06461171, theta=-21.5347418 -> V=1.027779, theta=0.0
% INFO    : Bus 1834	: V=1.00176748, theta=-6.55781444 -> V=0.999999, theta=0.0
% INFO    : Bus 1835	: V=1.02826749, theta=-34.7931541 -> V=1.022224, theta=0.0
% INFO    : Bus 1836	: V=1.04702709, theta=-13.3009684 -> V=1.0111115, theta=0.0
% INFO    : Bus 1837	: V=1.023667, theta=-12.6920468 -> V=0.999999, theta=0.0
% INFO    : Bus 1838	: V=1.04477833, theta=-10.2036528 -> V=1.0111115, theta=0.0
% INFO    : Bus 1839	: V=1.06858439, theta=-18.4291338 -> V=1.046665, theta=0.0
% INFO    : Bus 1840	: V=1.06910147, theta=-18.3813228 -> V=1.046665, theta=0.0
% INFO    : Bus 1841	: V=0.982176647, theta=-21.1518349 -> V=1.0158755, theta=0.0
% INFO    : Bus 1842	: V=1.03341077, theta=-8.12442363 -> V=1.0158755, theta=0.0
% INFO    : Bus 1843	: V=1.05384842, theta=-5.29335852 -> V=1.0377785, theta=0.0
% INFO    : Bus 1844	: V=1.0255312, theta=-21.0495574 -> V=1.0000025, theta=0.0
% INFO    : Bus 1845	: V=1.01607395, theta=-0.918211177 -> V=1.0158755, theta=0.0
% INFO    : Bus 1846	: V=1.01581109, theta=-0.941444405 -> V=1.0158755, theta=0.0
% INFO    : Bus 1847	: V=1.06899341, theta=-10.4533637 -> V=1.022222, theta=0.0
% INFO    : Bus 1848	: V=1.0433149, theta=-24.4088272 -> V=1.027779, theta=0.0
% INFO    : Bus 1849	: V=1.04331484, theta=-24.4088258 -> V=1.027779, theta=0.0
% INFO    : Bus 1850	: V=1.00764262, theta=-21.7758305 -> V=0.999999, theta=0.0
% INFO    : Bus 1851	: V=1.00280436, theta=-20.3605868 -> V=1.0158755, theta=0.0
% INFO    : Bus 1852	: V=1.02009142, theta=-27.2390048 -> V=1.015872, theta=0.0
% INFO    : Bus 1853	: V=1.012485, theta=-27.4165021 -> V=1.0000025, theta=0.0
% INFO    : Bus 1854	: V=1.02536545, theta=-21.1818903 -> V=0.999999, theta=0.0
% INFO    : Bus 1855	: V=1.02503956, theta=-21.1925977 -> V=0.999999, theta=0.0
% INFO    : Bus 1856	: V=1.01119931, theta=0.515052801 -> V=1.0158755, theta=0.0
% INFO    : Bus 1857	: V=1.03245559, theta=-31.6642368 -> V=1.0000025, theta=0.0
% INFO    : Bus 1858	: V=1.00372149, theta=-30.7367063 -> V=1.015872, theta=0.0
% INFO    : Bus 1859	: V=0.985082626, theta=-16.0389406 -> V=1.015872, theta=0.0
% INFO    : Bus 1860	: V=1.04916627, theta=-25.6739705 -> V=1.0000025, theta=0.0
% INFO    : Bus 1861	: V=1.01490088, theta=-13.5660261 -> V=0.999999, theta=0.0
% INFO    : Bus 1862	: V=1.00911449, theta=-6.99704482 -> V=1.0158755, theta=0.0
% INFO    : Bus 1863	: V=1.03940157, theta=-25.273768 -> V=1.0000025, theta=0.0
% INFO    : Bus 1864	: V=1.01038719, theta=-19.9614282 -> V=1.015872, theta=0.0
% INFO    : Bus 1865	: V=1.02254975, theta=-22.0474285 -> V=1.022224, theta=0.0
% INFO    : Bus 1866	: V=1.02775943, theta=-20.0491829 -> V=1.022224, theta=0.0
% INFO    : Bus 1867	: V=0.988870769, theta=-35.0571443 -> V=1.01866, theta=0.0
% INFO    : Bus 1868	: V=1.03873026, theta=-8.31690204 -> V=1.0111115, theta=0.0
% INFO    : Bus 1869	: V=1.02086433, theta=-28.3675978 -> V=1.022224, theta=0.0
% INFO    : Bus 1870	: V=1.026, theta=-15.5642545 -> V=1.0000005, theta=0.0
% INFO    : Bus 1871	: V=1.02280961, theta=-10.6942627 -> V=0.999999, theta=0.0
% INFO    : Bus 1872	: V=1.01382379, theta=-17.6736437 -> V=1.015872, theta=0.0
% INFO    : Bus 1873	: V=1.00233227, theta=-17.3582403 -> V=1.0000005, theta=0.0
% INFO    : Bus 1874	: V=1.03365437, theta=-11.4597957 -> V=1.0000025, theta=0.0
% INFO    : Bus 1875	: V=1.0359621, theta=-22.0996806 -> V=1.027779, theta=0.0
% INFO    : Bus 1876	: V=1.07444454, theta=-21.3457122 -> V=1.000001, theta=0.0
% INFO    : Bus 1877	: V=1.02960154, theta=-11.0860434 -> V=0.999999, theta=0.0
% INFO    : Bus 1878	: V=1.07864411, theta=-12.3052801 -> V=1.033333, theta=0.0
% INFO    : Bus 1879	: V=1.0393566, theta=-4.9954588 -> V=1.0158755, theta=0.0
% INFO    : Bus 1880	: V=1.05079328, theta=-17.251112 -> V=1.022224, theta=0.0
% INFO    : Bus 1881	: V=1.03243118, theta=-16.3244534 -> V=0.999999, theta=0.0
% INFO    : Bus 1882	: V=1.05000998, theta=-14.7338501 -> V=1.027779, theta=0.0
% INFO    : Bus 1883	: V=1.0882562, theta=-12.1573758 -> V=1.047345, theta=0.0
% INFO    : Bus 1884	: V=1.04521824, theta=-28.3429266 -> V=1.027779, theta=0.0
% INFO    : Bus 1885	: V=1.02958971, theta=-38.5987251 -> V=1.022224, theta=0.0
% INFO    : Bus 1886	: V=1.03071554, theta=-38.6097376 -> V=1.022224, theta=0.0
% INFO    : Bus 1887	: V=1.03927204, theta=-21.2164562 -> V=1.027779, theta=0.0
% INFO    : Bus 1888	: V=1.03004823, theta=-23.4111242 -> V=1.0000025, theta=0.0
% INFO    : Bus 1889	: V=1.02592168, theta=-20.524539 -> V=1.015872, theta=0.0
% INFO    : Bus 1890	: V=1.07827063, theta=-14.99369 -> V=1.046665, theta=0.0
% INFO    : Bus 1891	: V=1.07458951, theta=-15.0263347 -> V=1.046665, theta=0.0
% INFO    : Bus 1892	: V=1.07676476, theta=-15.6383642 -> V=1.046665, theta=0.0
% INFO    : Bus 1893	: V=1.036, theta=0.150109941 -> V=0.975, theta=0.0
% INFO    : Bus 1894	: V=1.035, theta=-0.162668867 -> V=0.975, theta=0.0
% INFO    : Bus 1895	: V=1.04, theta=0.195373649 -> V=0.975, theta=0.0
% INFO    : Bus 1896	: V=1.041, theta=0.127030611 -> V=0.975, theta=0.0
% INFO    : Bus 1897	: V=1.03862144, theta=-2.17011182 -> V=1.0377785, theta=0.0
% INFO    : Bus 1898	: V=1.03861755, theta=-2.17166582 -> V=1.0377785, theta=0.0
% INFO    : Bus 1899	: V=1.03864108, theta=-2.16984326 -> V=1.0377785, theta=0.0
% INFO    : Bus 1900	: V=1.03864628, theta=-2.17017103 -> V=1.0377785, theta=0.0
% INFO    : Bus 1901	: V=1.01494899, theta=-6.27528193 -> V=1.0158755, theta=0.0
% INFO    : Bus 1902	: V=1.03863812, theta=-2.18163045 -> V=1.0377785, theta=0.0
% INFO    : Bus 1903	: V=1.01463763, theta=-12.6290132 -> V=0.999999, theta=0.0
% INFO    : Bus 1904	: V=1.03596592, theta=-7.56821759 -> V=1.0111115, theta=0.0
% INFO    : Bus 1905	: V=0.996031588, theta=-18.9868845 -> V=1.0000025, theta=0.0
% INFO    : Bus 1906	: V=1.05138106, theta=-16.2462168 -> V=1.044445, theta=0.0
% INFO    : Bus 1907	: V=1.04380598, theta=-22.36989 -> V=1.027779, theta=0.0
% INFO    : Bus 1908	: V=1.02241176, theta=-20.2819981 -> V=0.999999, theta=0.0
% INFO    : Bus 1909	: V=1.01172166, theta=-18.6666506 -> V=1.0000005, theta=0.0
% INFO    : Bus 1910	: V=1.04899628, theta=-14.3692649 -> V=1.027779, theta=0.0
% INFO    : Bus 1911	: V=1.03757661, theta=-16.1453444 -> V=1.015872, theta=0.0
% INFO    : Bus 1912	: V=1.0319458, theta=-12.0280522 -> V=1.0158755, theta=0.0
% INFO    : Bus 1913	: V=1.07604073, theta=-9.45013453 -> V=1.0377785, theta=0.0
% INFO    : Bus 1914	: V=1.0214598, theta=-24.4002798 -> V=1.0158755, theta=0.0
% INFO    : Bus 1915	: V=1.02067974, theta=-24.5145106 -> V=1.0158755, theta=0.0
% INFO    : Bus 1916	: V=1.03764664, theta=-27.0745019 -> V=1.015872, theta=0.0
% INFO    : Bus 1917	: V=1.04512188, theta=-23.3635333 -> V=1.046665, theta=0.0
% INFO    : Bus 1918	: V=1.01947514, theta=-26.3447652 -> V=1.022224, theta=0.0
% INFO    : Bus 1919	: V=1.02058659, theta=-24.512993 -> V=1.015872, theta=0.0
% INFO    : Bus 1920	: V=1.01092019, theta=-21.6493255 -> V=1.0000025, theta=0.0
% INFO    : Bus 1921	: V=1.00111883, theta=-13.1109632 -> V=1.015872, theta=0.0
% INFO    : Bus 1922	: V=1.02639438, theta=-22.546132 -> V=1.0000025, theta=0.0
% INFO    : Bus 1923	: V=1.07231524, theta=-22.5782795 -> V=1.0000025, theta=0.0
% INFO    : Bus 1924	: V=1.05780401, theta=-3.80069682 -> V=1.022222, theta=0.0
% INFO    : Bus 1925	: V=1.0128516, theta=-22.7142554 -> V=1.0000005, theta=0.0
% INFO    : Bus 1926	: V=1.07852495, theta=-18.5794757 -> V=1.046665, theta=0.0
% INFO    : Bus 1927	: V=1.05971077, theta=-21.6013184 -> V=1.000001, theta=0.0
% INFO    : Bus 1928	: V=1.07740191, theta=-18.6193693 -> V=1.044445, theta=0.0
% INFO    : Bus 1929	: V=1.04227218, theta=-12.5967751 -> V=1.022224, theta=0.0
% INFO    : Bus 1930	: V=1.08298985, theta=-8.02057012 -> V=1.07237, theta=0.0
% INFO    : Bus 1931	: V=1.04334369, theta=-13.6538628 -> V=1.0000025, theta=0.0
% INFO    : Bus 1932	: V=1.03909202, theta=-24.5285854 -> V=1.000001, theta=0.0
% INFO    : Bus 1933	: V=1.00340937, theta=-18.8882235 -> V=0.975, theta=0.0
% INFO    : Bus 1934	: V=1.05772586, theta=-18.3851295 -> V=1.044445, theta=0.0
% INFO    : Bus 1935	: V=1.07144809, theta=-15.1207093 -> V=1.078945, theta=0.0
% INFO    : Bus 1936	: V=1.0188082, theta=-7.63548818 -> V=1.0079355, theta=0.0
% INFO    : Bus 1937	: V=1.08427723, theta=-2.44236521 -> V=1.07237, theta=0.0
% INFO    : Bus 1938	: V=1.01651379, theta=-11.7339011 -> V=0.999999, theta=0.0
% INFO    : Bus 1939	: V=1.01651379, theta=-11.7339011 -> V=0.999999, theta=0.0
% INFO    : Bus 1940	: V=1.01818717, theta=-11.8441776 -> V=0.999999, theta=0.0
% INFO    : Bus 1941	: V=1.01912911, theta=-23.8691128 -> V=1.015872, theta=0.0
% INFO    : Bus 1942	: V=1.06197268, theta=-10.0557829 -> V=1.016666, theta=0.0
% INFO    : Bus 1943	: V=1.06884422, theta=-10.45197 -> V=1.016666, theta=0.0
% INFO    : Bus 1944	: V=1.05465953, theta=-6.60819683 -> V=1.015556, theta=0.0
% INFO    : Bus 1945	: V=1.0721677, theta=-3.25055594 -> V=1.05263, theta=0.0
% INFO    : Bus 1946	: V=1.01480394, theta=-23.8106894 -> V=1.0000005, theta=0.0
% INFO    : Bus 1947	: V=1.00229437, theta=-17.3574471 -> V=1.0000005, theta=0.0
% INFO    : Bus 1948	: V=1.038, theta=-15.3883135 -> V=1.0000025, theta=0.0
% INFO    : Bus 1949	: V=1.01083252, theta=-5.86187852 -> V=1.0158755, theta=0.0
% INFO    : Bus 1950	: V=1.02387945, theta=-21.6005869 -> V=1.022224, theta=0.0
% INFO    : Bus 1951	: V=1.01988336, theta=-13.6954915 -> V=0.999999, theta=0.0
% INFO    : Bus 1952	: V=1.02136112, theta=-15.6194587 -> V=0.999999, theta=0.0
% INFO    : Bus 1953	: V=1.03037854, theta=-35.4319978 -> V=1.022224, theta=0.0
% INFO    : Bus 1954	: V=1.02519401, theta=-17.9157215 -> V=1.0158755, theta=0.0
% INFO    : Bus 1955	: V=1.05221087, theta=-19.4481649 -> V=1.022224, theta=0.0
% INFO    : Bus 1956	: V=1.02761178, theta=-13.7959088 -> V=0.999999, theta=0.0
% INFO    : Bus 1957	: V=1.02816246, theta=-18.7359521 -> V=1.0158755, theta=0.0
% INFO    : Bus 1958	: V=1.02714003, theta=-17.0485952 -> V=1.0158755, theta=0.0
% INFO    : Bus 1959	: V=0.988808351, theta=-29.5739727 -> V=1.0000025, theta=0.0
% INFO    : Bus 1960	: V=1.06458063, theta=-9.39744967 -> V=1.0111115, theta=0.0
% INFO    : Bus 1961	: V=1.06598908, theta=-9.7144567 -> V=1.0111115, theta=0.0
% INFO    : Bus 1962	: V=1.07685833, theta=-6.75220432 -> V=1.072365, theta=0.0
% INFO    : Bus 1963	: V=1.01523163, theta=-8.12493305 -> V=1.0158755, theta=0.0
% INFO    : Bus 1964	: V=1.00424598, theta=-12.1527189 -> V=0.999999, theta=0.0
% INFO    : Bus 1965	: V=1.01949118, theta=-12.5884113 -> V=0.999999, theta=0.0
% INFO    : Bus 1966	: V=1.01695766, theta=-20.0738181 -> V=1.0158755, theta=0.0
% INFO    : Bus 1967	: V=1.053, theta=0.509943807 -> V=0.975, theta=0.0
% INFO    : Bus 1968	: V=1.062, theta=0.465697873 -> V=0.975, theta=0.0
% INFO    : Bus 1969	: V=1.053, theta=0.659241612 -> V=0.975, theta=0.0
% INFO    : Bus 1970	: V=1.062, theta=0.582939635 -> V=0.975, theta=0.0
% INFO    : Bus 1971	: V=1.063, theta=0.521423144 -> V=0.975, theta=0.0
% INFO    : Bus 1972	: V=1.05833792, theta=-0.363136996 -> V=1.0377785, theta=0.0
% INFO    : Bus 1973	: V=1.05842993, theta=-0.363442824 -> V=1.0377785, theta=0.0
% INFO    : Bus 1974	: V=1.05833705, theta=-0.361622379 -> V=1.0377785, theta=0.0
% INFO    : Bus 1975	: V=1.05842927, theta=-0.362243314 -> V=1.0377785, theta=0.0
% INFO    : Bus 1976	: V=1.05839659, theta=-0.372044039 -> V=1.0377785, theta=0.0
% INFO    : Bus 1977	: V=1.05843982, theta=-0.362856259 -> V=1.0377785, theta=0.0
% INFO    : Bus 1978	: V=0.990803044, theta=-8.61837411 -> V=1.0158755, theta=0.0
% INFO    : Bus 1979	: V=1.05839596, theta=-0.372043982 -> V=1.0377785, theta=0.0
% INFO    : Bus 1980	: V=1.033, theta=-1.87140163 -> V=0.975, theta=0.0
% INFO    : Bus 1981	: V=1.003, theta=-9.72886754 -> V=0.999999, theta=0.0
% INFO    : Bus 1982	: V=1.017, theta=-10.4347257 -> V=0.999999, theta=0.0
% INFO    : Bus 1983	: V=1.03221497, theta=-6.06163004 -> V=1.0111115, theta=0.0
% INFO    : Bus 1984	: V=1.02439785, theta=-28.5726311 -> V=1.0000025, theta=0.0
% INFO    : Bus 1985	: V=1.01536535, theta=-40.4021956 -> V=1.0079355, theta=0.0
% INFO    : Bus 1986	: V=1.035, theta=-21.423252 -> V=1.0000025, theta=0.0
% INFO    : Bus 1987	: V=1.00898785, theta=-18.1533461 -> V=1.0158755, theta=0.0
% INFO    : Bus 1988	: V=1.00364935, theta=-16.6719058 -> V=0.999999, theta=0.0
% INFO    : Bus 1989	: V=1.01701474, theta=-11.0306829 -> V=1.0079355, theta=0.0
% INFO    : Bus 1990	: V=1.07224869, theta=-13.7005164 -> V=1.028569, theta=0.0
% INFO    : Bus 1991	: V=1.07417643, theta=-9.65678218 -> V=1.04444, theta=0.0
% INFO    : Bus 1992	: V=1.03917105, theta=-13.7453864 -> V=0.999999, theta=0.0
% INFO    : Bus 1993	: V=1.05983779, theta=-24.0562642 -> V=1.0000025, theta=0.0
% INFO    : Bus 1994	: V=1.02513614, theta=-10.2329302 -> V=0.999999, theta=0.0
% INFO    : Bus 1995	: V=0.9964984, theta=-28.8173969 -> V=1.0000025, theta=0.0
% INFO    : Bus 1996	: V=1.02230018, theta=-24.8474181 -> V=1.0000025, theta=0.0
% INFO    : Bus 1997	: V=1.06479751, theta=-20.16705 -> V=1.044445, theta=0.0
% INFO    : Bus 1998	: V=1.00072753, theta=-12.9836613 -> V=1.0158755, theta=0.0
% INFO    : Bus 1999	: V=1.01276571, theta=-7.85519967 -> V=1.0158755, theta=0.0
% INFO    : Bus 2000	: V=0.890004219, theta=-5.24942801 -> V=0.9444445, theta=0.0
% INFO    : Bus 2001	: V=1.02720529, theta=-15.4911505 -> V=1.0158755, theta=0.0
% INFO    : Bus 2002	: V=1.02699191, theta=-15.5596381 -> V=1.0158755, theta=0.0
% INFO    : Bus 2003	: V=1.05673943, theta=-0.372567448 -> V=1.0000025, theta=0.0
% INFO    : Bus 2004	: V=1.04862, theta=-8.17899463 -> V=1.0111115, theta=0.0
% INFO    : Bus 2005	: V=1.03238275, theta=-23.9401743 -> V=1.0000025, theta=0.0
% INFO    : Bus 2006	: V=1.01538796, theta=-7.37743451 -> V=1.0158755, theta=0.0
% INFO    : Bus 2007	: V=1.026, theta=-20.5069496 -> V=1.0158755, theta=0.0
% INFO    : Bus 2008	: V=1.08003539, theta=-18.1454094 -> V=1.046665, theta=0.0
% INFO    : Bus 2009	: V=1.0815157, theta=-16.5375176 -> V=1.046665, theta=0.0
% INFO    : Bus 2010	: V=1.02124724, theta=-26.6103101 -> V=1.022224, theta=0.0
% INFO    : Bus 2011	: V=1.03756186, theta=-22.5875497 -> V=1.0000025, theta=0.0
% INFO    : Bus 2012	: V=1.07204284, theta=-18.7241314 -> V=1.044445, theta=0.0
% INFO    : Bus 2013	: V=0.998847071, theta=-7.62656258 -> V=1.0158755, theta=0.0
% INFO    : Bus 2014	: V=1.03012516, theta=-23.7209231 -> V=1.022224, theta=0.0
% INFO    : Bus 2015	: V=1.0613614, theta=-2.75676678 -> V=1.0377785, theta=0.0
% INFO    : Bus 2016	: V=1.08801516, theta=-8.92424061 -> V=1.078945, theta=0.0
% INFO    : Bus 2017	: V=1.08797659, theta=-8.94798135 -> V=1.078945, theta=0.0
% INFO    : Bus 2018	: V=1.025, theta=-22.3229186 -> V=1.0000025, theta=0.0
% INFO    : Bus 2019	: V=1.029, theta=-22.0195349 -> V=1.0000025, theta=0.0
% INFO    : Bus 2020	: V=1.07128429, theta=-15.8038662 -> V=1.044445, theta=0.0
% INFO    : Bus 2021	: V=1.02125519, theta=-13.027528 -> V=0.999999, theta=0.0
% INFO    : Bus 2022	: V=1.02004744, theta=-9.21350369 -> V=1.0158755, theta=0.0
% INFO    : Bus 2023	: V=1.07769581, theta=-14.9675354 -> V=1.046665, theta=0.0
% INFO    : Bus 2024	: V=1.04964301, theta=-13.3872868 -> V=1.027779, theta=0.0
% INFO    : Bus 2025	: V=1.00149791, theta=-22.3265827 -> V=1.015872, theta=0.0
% INFO    : Bus 2026	: V=1.02489853, theta=-29.827182 -> V=1.015872, theta=0.0
% INFO    : Bus 2027	: V=1.0189572, theta=-14.4335819 -> V=0.999999, theta=0.0
% INFO    : Bus 2028	: V=1.058, theta=-18.1668609 -> V=1.000001, theta=0.0
% INFO    : Bus 2029	: V=1.05109815, theta=-17.740335 -> V=1.000001, theta=0.0
% INFO    : Bus 2030	: V=1.03020079, theta=-34.0302919 -> V=1.022224, theta=0.0
% INFO    : Bus 2031	: V=1.065547, theta=-10.9252552 -> V=1.022222, theta=0.0
% INFO    : Bus 2032	: V=1.02047578, theta=-39.9825058 -> V=1.022224, theta=0.0
% INFO    : Bus 2033	: V=1.04999, theta=-21.5585056 -> V=1.000001, theta=0.0
% INFO    : Bus 2034	: V=1.03970105, theta=-37.3069182 -> V=1.022224, theta=0.0
% INFO    : Bus 2035	: V=0.983497169, theta=-27.5079181 -> V=1.0000025, theta=0.0
% INFO    : Bus 2036	: V=1.00881371, theta=-41.0616744 -> V=1.0079355, theta=0.0
% INFO    : Bus 2037	: V=1.06014112, theta=-26.0274908 -> V=1.0000025, theta=0.0
% INFO    : Bus 2038	: V=1.05087333, theta=-49.7188215 -> V=1.0079355, theta=0.0
% INFO    : Bus 2039	: V=1.0001489, theta=-24.5411926 -> V=1.0000025, theta=0.0
% INFO    : Bus 2040	: V=1.06557534, theta=-21.5866908 -> V=1.044445, theta=0.0
% INFO    : Bus 2041	: V=1.02852322, theta=-20.9373611 -> V=1.0000005, theta=0.0
% INFO    : Bus 2042	: V=1.03421588, theta=-25.8116699 -> V=1.0000025, theta=0.0
% INFO    : Bus 2043	: V=1.06550402, theta=-15.0680341 -> V=1.046665, theta=0.0
% INFO    : Bus 2044	: V=1.01903274, theta=-20.4453985 -> V=0.999999, theta=0.0
% INFO    : Bus 2045	: V=1.07850481, theta=-18.5670214 -> V=1.004175, theta=0.0
% INFO    : Bus 2046	: V=1.03750264, theta=-19.6475572 -> V=1.033334, theta=0.0
% INFO    : Bus 2047	: V=1.01215952, theta=-5.78175285 -> V=1.0158755, theta=0.0
% INFO    : Bus 2048	: V=1.02014485, theta=-6.06169957 -> V=1.0158755, theta=0.0
% INFO    : Bus 2049	: V=1.05368212, theta=-1.38192479 -> V=1.0377785, theta=0.0
% INFO    : Bus 2050	: V=1.027, theta=-17.1941725 -> V=0.999999, theta=0.0
% INFO    : Bus 2051	: V=0.996579527, theta=-19.9806846 -> V=1.0000005, theta=0.0
% INFO    : Bus 2052	: V=1.01444849, theta=-18.4581423 -> V=1.0000005, theta=0.0
% INFO    : Bus 2053	: V=1.06607277, theta=-14.8651991 -> V=1.044445, theta=0.0
% INFO    : Bus 2054	: V=0.981941119, theta=-22.5841903 -> V=1.0158755, theta=0.0
% INFO    : Bus 2055	: V=1.07376181, theta=-18.5604112 -> V=1.04444, theta=0.0
% INFO    : Bus 2056	: V=1.07885463, theta=-12.7291865 -> V=1.07237, theta=0.0
% INFO    : Bus 2057	: V=1.01763142, theta=-30.7363102 -> V=1.015872, theta=0.0
% INFO    : Bus 2058	: V=1.01780992, theta=-30.7266871 -> V=1.015872, theta=0.0
% INFO    : Bus 2059	: V=1.01786184, theta=-30.7312817 -> V=1.015872, theta=0.0
% INFO    : Bus 2060	: V=1.01984035, theta=-24.4915978 -> V=1.0000025, theta=0.0
% INFO    : Bus 2061	: V=1.08953749, theta=5.2557672 -> V=1.05263, theta=0.0
% INFO    : Bus 2062	: V=1.08775318, theta=5.10109996 -> V=1.05263, theta=0.0
% INFO    : Bus 2063	: V=1.08775586, theta=5.10704049 -> V=1.05263, theta=0.0
% INFO    : Bus 2064	: V=1.089102, theta=5.26836908 -> V=1.05263, theta=0.0
% INFO    : Bus 2065	: V=1.08755361, theta=5.1168311 -> V=1.05263, theta=0.0
% INFO    : Bus 2066	: V=1.08969277, theta=5.20921295 -> V=1.05263, theta=0.0
% INFO    : Bus 2067	: V=1.0429665, theta=-19.2495137 -> V=0.999999, theta=0.0
% INFO    : Bus 2068	: V=1.06156679, theta=-3.37132301 -> V=1.022222, theta=0.0
% INFO    : Bus 2069	: V=1.00010623, theta=-20.8847951 -> V=1.0158755, theta=0.0
% INFO    : Bus 2070	: V=0.987697766, theta=-17.0613168 -> V=1.0000005, theta=0.0
% INFO    : Bus 2071	: V=1.04953542, theta=-7.94239847 -> V=1.0111115, theta=0.0
% INFO    : Bus 2072	: V=1.04437073, theta=-13.8611696 -> V=0.999999, theta=0.0
% INFO    : Bus 2073	: V=1.07303746, theta=-5.72459748 -> V=1.072365, theta=0.0
% INFO    : Bus 2074	: V=1.07251017, theta=-5.7889813 -> V=1.072365, theta=0.0
% INFO    : Bus 2075	: V=1.05974124, theta=-7.4233471 -> V=1.022222, theta=0.0
% INFO    : Bus 2076	: V=1.05812777, theta=-20.5127378 -> V=1.0000025, theta=0.0
% INFO    : Bus 2077	: V=1.0640918, theta=-17.6869079 -> V=1.044445, theta=0.0
% INFO    : Bus 2078	: V=1.01027602, theta=-20.3345318 -> V=1.022224, theta=0.0
% INFO    : Bus 2079	: V=1.01352833, theta=-19.7726603 -> V=1.022224, theta=0.0
% INFO    : Bus 2080	: V=1.07054665, theta=-16.9592804 -> V=1.046665, theta=0.0
% INFO    : Bus 2081	: V=1.07073781, theta=-17.0513471 -> V=1.046665, theta=0.0
% INFO    : Bus 2082	: V=1.03026293, theta=-23.259284 -> V=1.022224, theta=0.0
% INFO    : Bus 2083	: V=1.0597793, theta=-15.1536841 -> V=1.022869, theta=0.0
% INFO    : Bus 2084	: V=1.0252585, theta=-24.3141723 -> V=1.0000025, theta=0.0
% INFO    : Bus 2085	: V=1.03963502, theta=-15.9661601 -> V=1.015872, theta=0.0
% INFO    : Bus 2086	: V=1.05457638, theta=-12.8990132 -> V=1.046665, theta=0.0
% INFO    : Bus 2087	: V=1.06094094, theta=-10.7060791 -> V=1.0377785, theta=0.0
% INFO    : Bus 2088	: V=1.0716791, theta=-7.94302681 -> V=1.072365, theta=0.0
% INFO    : Bus 2089	: V=1.01566792, theta=-30.9114192 -> V=1.015872, theta=0.0
% INFO    : Bus 2090	: V=1.03536338, theta=-22.1969122 -> V=1.027779, theta=0.0
% INFO    : Bus 2091	: V=1.01697204, theta=-36.6866342 -> V=1.022224, theta=0.0
% INFO    : Bus 2092	: V=1.07771547, theta=-8.19235201 -> V=1.033333, theta=0.0
% INFO    : Bus 2093	: V=1.05317834, theta=-5.25578097 -> V=1.0000005, theta=0.0
% INFO    : Bus 2094	: V=1.05528005, theta=-4.53173165 -> V=1.0000005, theta=0.0
% INFO    : Bus 2095	: V=1.02916708, theta=-5.54668363 -> V=1.0158755, theta=0.0
% INFO    : Bus 2096	: V=1.06788408, theta=-2.56875572 -> V=1.0377785, theta=0.0
% INFO    : Bus 2097	: V=1.01764255, theta=-46.2752893 -> V=1.0079355, theta=0.0
% INFO    : Bus 2098	: V=1.058, theta=-3.78280478 -> V=1.022222, theta=0.0
% INFO    : Bus 2099	: V=1.0191768, theta=-40.5526554 -> V=1.0079355, theta=0.0
% INFO    : Bus 2100	: V=1.07466889, theta=-20.6533577 -> V=1.000001, theta=0.0
% INFO    : Bus 2101	: V=1.04012367, theta=-42.9826682 -> V=1.022224, theta=0.0
% INFO    : Bus 2102	: V=1.014, theta=-51.2097356 -> V=1.0079355, theta=0.0
% INFO    : Bus 2103	: V=1.03698631, theta=-35.2328073 -> V=1.0079355, theta=0.0
% INFO    : Bus 2104	: V=1.07725307, theta=-32.4323928 -> V=1.04444, theta=0.0
% INFO    : Bus 2105	: V=1.01838814, theta=-38.8249283 -> V=1.022224, theta=0.0
% INFO    : Bus 2106	: V=1.08309682, theta=-16.2618059 -> V=1.046665, theta=0.0
% INFO    : Bus 2107	: V=1.01803124, theta=-14.2325412 -> V=1.0158755, theta=0.0
% INFO    : Bus 2108	: V=1.01729821, theta=-14.197605 -> V=1.0158755, theta=0.0
% INFO    : Bus 2109	: V=1.0171816, theta=-14.1755006 -> V=1.0158755, theta=0.0
% INFO    : Bus 2110	: V=1.01725349, theta=-14.1731324 -> V=1.0158755, theta=0.0
% INFO    : Bus 2111	: V=1.01723782, theta=-14.1675965 -> V=1.0158755, theta=0.0
% INFO    : Bus 2112	: V=1.05723382, theta=-11.3792601 -> V=1.0377785, theta=0.0
% INFO    : Bus 2113	: V=1.02089072, theta=-45.5304275 -> V=1.0079355, theta=0.0
% INFO    : Bus 2114	: V=1.0508893, theta=-27.665521 -> V=1.0000025, theta=0.0
% INFO    : Bus 2115	: V=0.997721092, theta=-48.3299233 -> V=1.0079355, theta=0.0
% INFO    : Bus 2116	: V=1.01884579, theta=-10.1085091 -> V=1.0158755, theta=0.0
% INFO    : Bus 2117	: V=1.03751821, theta=-11.442764 -> V=1.0000025, theta=0.0
% INFO    : Bus 2118	: V=1.00041126, theta=-12.5151735 -> V=0.999999, theta=0.0
% INFO    : Bus 2119	: V=1.04249279, theta=-10.3996418 -> V=0.975, theta=0.0
% INFO    : Bus 2120	: V=0.996479002, theta=-24.9908525 -> V=1.015872, theta=0.0
% INFO    : Bus 2121	: V=1.02178757, theta=-18.3608385 -> V=1.0000005, theta=0.0
% INFO    : Bus 2122	: V=1.02943389, theta=-44.4901612 -> V=1.0079355, theta=0.0
% INFO    : Bus 2123	: V=1.0031602, theta=-7.84653563 -> V=1.0158755, theta=0.0
% INFO    : Bus 2124	: V=1.04711876, theta=-23.6495612 -> V=1.0000025, theta=0.0
% INFO    : Bus 2125	: V=1.05557275, theta=-19.1171484 -> V=1.044445, theta=0.0
% INFO    : Bus 2126	: V=1.00772545, theta=-19.8674424 -> V=1.0158755, theta=0.0
% INFO    : Bus 2127	: V=1.02331025, theta=-11.4561185 -> V=0.999999, theta=0.0
% INFO    : Bus 2128	: V=1.02509207, theta=-12.5041884 -> V=0.999999, theta=0.0
% INFO    : Bus 2129	: V=1.04858596, theta=-8.19212444 -> V=1.0111115, theta=0.0
% INFO    : Bus 2130	: V=1.04858784, theta=-8.18985084 -> V=1.0111115, theta=0.0
% INFO    : Bus 2131	: V=1.04855671, theta=-8.19167008 -> V=1.0111115, theta=0.0
% INFO    : Bus 2132	: V=1.05829682, theta=-8.7337577 -> V=1.022222, theta=0.0
% INFO    : Bus 2133	: V=1.07556854, theta=-4.32349689 -> V=1.0266685, theta=0.0
% INFO    : Bus 2134	: V=1.07022319, theta=-4.28607355 -> V=1.022223, theta=0.0
% INFO    : Bus 2135	: V=0.976600697, theta=-20.7750272 -> V=1.0158755, theta=0.0
% INFO    : Bus 2136	: V=0.958267353, theta=-8.67932798 -> V=0.9444445, theta=0.0
% INFO    : Bus 2137	: V=1.0162125, theta=-10.2564377 -> V=0.999999, theta=0.0
% INFO    : Bus 2138	: V=1.05054436, theta=-7.11922574 -> V=1.0111115, theta=0.0
% INFO    : Bus 2139	: V=1.06511717, theta=0.117238374 -> V=0.9888895, theta=0.0
% INFO    : Bus 2140	: V=1.07695082, theta=2.14995393 -> V=0.9888895, theta=0.0
% INFO    : Bus 2141	: V=1.01479752, theta=-3.40842609 -> V=1.0158755, theta=0.0
% INFO    : Bus 2142	: V=1.04254572, theta=-13.6076075 -> V=1.027779, theta=0.0
% INFO    : Bus 2143	: V=1.07551129, theta=-12.5891001 -> V=1.046665, theta=0.0
% INFO    : Bus 2144	: V=1.08364791, theta=-14.2173464 -> V=1.046355, theta=0.0
% INFO    : Bus 2145	: V=1.08266895, theta=-14.4172653 -> V=1.04587, theta=0.0
% INFO    : Bus 2146	: V=1.00104315, theta=-21.033922 -> V=1.015872, theta=0.0
% INFO    : Bus 2147	: V=1.02900068, theta=-12.636759 -> V=0.999999, theta=0.0
% INFO    : Bus 2148	: V=1.0479338, theta=-9.10430474 -> V=1.0111115, theta=0.0
% INFO    : Bus 2149	: V=1.07495293, theta=-5.04999673 -> V=1.072365, theta=0.0
% INFO    : Bus 2150	: V=1.0360233, theta=-40.0514434 -> V=1.022224, theta=0.0
% INFO    : Bus 2151	: V=1.0446747, theta=-29.9617629 -> V=1.022224, theta=0.0
% INFO    : Bus 2152	: V=1.04065663, theta=-7.72319047 -> V=1.0158755, theta=0.0
% INFO    : Bus 2153	: V=0.976837651, theta=-17.6283944 -> V=1.0158755, theta=0.0
% INFO    : Bus 2154	: V=1.00265843, theta=-23.5971516 -> V=1.0000025, theta=0.0
% INFO    : Bus 2155	: V=1.03935482, theta=-4.99541783 -> V=1.0158755, theta=0.0
% INFO    : Bus 2156	: V=1.00882156, theta=-14.2306444 -> V=1.0158755, theta=0.0
% INFO    : Bus 2157	: V=1.02145033, theta=-25.0397194 -> V=1.0000025, theta=0.0
% INFO    : Bus 2158	: V=1.02351439, theta=-36.5497933 -> V=1.022224, theta=0.0
% INFO    : Bus 2159	: V=1.01758092, theta=-18.4928084 -> V=1.0000005, theta=0.0
% INFO    : Bus 2160	: V=1.063, theta=-13.7212032 -> V=1.027779, theta=0.0
% INFO    : Bus 2161	: V=1.06205902, theta=-13.7331149 -> V=1.027779, theta=0.0
% INFO    : Bus 2162	: V=1.08083359, theta=-10.6169433 -> V=1.046665, theta=0.0
% INFO    : Bus 2163	: V=1.07765788, theta=-32.4349259 -> V=1.04444, theta=0.0
% INFO    : Bus 2164	: V=1.02703143, theta=-19.7221701 -> V=1.0000005, theta=0.0
% INFO    : Bus 2165	: V=1.0706077, theta=-1.56078043 -> V=1.033333, theta=0.0
% INFO    : Bus 2166	: V=1.07035222, theta=1.1861609 -> V=1.0288895, theta=0.0
% INFO    : Bus 2167	: V=1.02607425, theta=-13.7874755 -> V=0.999999, theta=0.0
% INFO    : Bus 2168	: V=1.02587746, theta=-13.8154517 -> V=0.999999, theta=0.0
% INFO    : Bus 2169	: V=1.02580071, theta=-13.8667174 -> V=0.999999, theta=0.0
% INFO    : Bus 2170	: V=1.02036868, theta=-13.7261804 -> V=0.999999, theta=0.0
% INFO    : Bus 2171	: V=1.02405558, theta=-25.3962385 -> V=1.0000025, theta=0.0
% INFO    : Bus 2172	: V=1.06034639, theta=-5.58145729 -> V=1.0158755, theta=0.0
% INFO    : Bus 2173	: V=1.01731304, theta=-6.40426887 -> V=1.0158755, theta=0.0
% INFO    : Bus 2174	: V=1.03806893, theta=-2.1653072 -> V=1.0377785, theta=0.0
% INFO    : Bus 2175	: V=1.03771621, theta=-2.16073363 -> V=1.0377785, theta=0.0
% INFO    : Bus 2176	: V=1.05949669, theta=-19.4930771 -> V=1.027779, theta=0.0
% INFO    : Bus 2177	: V=1.02138799, theta=-6.22498458 -> V=1.0158755, theta=0.0
% INFO    : Bus 2178	: V=1.02138799, theta=-6.22498458 -> V=1.0158755, theta=0.0
% INFO    : Bus 2179	: V=1.07322757, theta=-15.7378308 -> V=1.046665, theta=0.0
% INFO    : Bus 2180	: V=1.01506429, theta=1.71160508 -> V=1.0158755, theta=0.0
% INFO    : Bus 2181	: V=1.04854832, theta=-14.605529 -> V=1.0000025, theta=0.0
% INFO    : Bus 2182	: V=1.06214749, theta=-5.97400794 -> V=0.9888895, theta=0.0
% INFO    : Bus 2183	: V=1.06232788, theta=-5.9662835 -> V=0.9888895, theta=0.0
% INFO    : Bus 2184	: V=0.996726699, theta=-21.2348673 -> V=1.0000005, theta=0.0
% INFO    : Bus 2185	: V=1.07873474, theta=-18.5500667 -> V=1.046665, theta=0.0
% INFO    : Bus 2186	: V=1.05698219, theta=-14.4513549 -> V=1.027779, theta=0.0
% INFO    : Bus 2187	: V=0.996728081, theta=-21.2348752 -> V=1.0000005, theta=0.0
% INFO    : Bus 2188	: V=1.00479113, theta=-22.3728556 -> V=1.0000005, theta=0.0
% INFO    : Bus 2189	: V=1.01285852, theta=-18.7262968 -> V=0.9682545, theta=0.0
% INFO    : Bus 2190	: V=1.0286971, theta=-24.4835887 -> V=1.0000025, theta=0.0
% INFO    : Bus 2191	: V=1.06384956, theta=-8.61932108 -> V=1.022222, theta=0.0
% INFO    : Bus 2192	: V=0.895, theta=-5.41508178 -> V=0.9444445, theta=0.0
% INFO    : Bus 2193	: V=1.00938293, theta=-17.0824522 -> V=0.999999, theta=0.0
% INFO    : Bus 2194	: V=1.065, theta=-21.8935697 -> V=1.000001, theta=0.0
% INFO    : Bus 2195	: V=0.977070916, theta=-4.77841255 -> V=1.0000015, theta=0.0
% INFO    : Bus 2196	: V=1.08893787, theta=-11.8001361 -> V=1.047945, theta=0.0
% INFO    : Bus 2197	: V=1.08672668, theta=-10.2903526 -> V=1.073685, theta=0.0
% INFO    : Bus 2198	: V=1.08910426, theta=-11.7817483 -> V=1.04802, theta=0.0
% INFO    : Bus 2199	: V=1.08892224, theta=-11.7995504 -> V=1.047935, theta=0.0
% INFO    : Bus 2200	: V=1.08672635, theta=-10.2898511 -> V=1.073685, theta=0.0
% INFO    : Bus 2201	: V=1.04761633, theta=-2.11340759 -> V=0.984126, theta=0.0
% INFO    : Bus 2202	: V=1.07062838, theta=-9.23998524 -> V=1.022222, theta=0.0
% INFO    : Bus 2203	: V=1.02947061, theta=-36.9506389 -> V=1.0079355, theta=0.0
% INFO    : Bus 2204	: V=1.02213356, theta=-15.1991915 -> V=1.015872, theta=0.0
% INFO    : Bus 2205	: V=1.06396789, theta=-5.71437044 -> V=0.9888895, theta=0.0
% INFO    : Bus 2206	: V=1.02156351, theta=-3.09829247 -> V=1.0158755, theta=0.0
% INFO    : Bus 2207	: V=1.05631977, theta=-10.1914943 -> V=1.022222, theta=0.0
% INFO    : Bus 2208	: V=1.02343953, theta=-27.0639709 -> V=1.0000025, theta=0.0
% INFO    : Bus 2209	: V=1.05747325, theta=-11.0882577 -> V=1.022222, theta=0.0
% INFO    : Bus 2210	: V=1.00966481, theta=-11.6060067 -> V=1.0079355, theta=0.0
% INFO    : Bus 2211	: V=1.01473326, theta=-40.4335909 -> V=1.0079355, theta=0.0
% INFO    : Bus 2212	: V=1.03740147, theta=-25.5428764 -> V=1.0000025, theta=0.0
% INFO    : Bus 2213	: V=1.02829267, theta=-37.7219041 -> V=1.022224, theta=0.0
% INFO    : Bus 2214	: V=0.987372721, theta=-24.2782483 -> V=1.0000005, theta=0.0
% INFO    : Bus 2215	: V=1.06855086, theta=-17.9522657 -> V=1.046665, theta=0.0
% INFO    : Bus 2216	: V=1.06757116, theta=-18.0197587 -> V=1.046665, theta=0.0
% INFO    : Bus 2217	: V=1.01623611, theta=-11.6127161 -> V=1.0158755, theta=0.0
% INFO    : Bus 2218	: V=1.01300929, theta=-12.1691017 -> V=1.0158755, theta=0.0
% INFO    : Bus 2219	: V=0.999182101, theta=-6.94412342 -> V=1.0158755, theta=0.0
% INFO    : Bus 2220	: V=1.04154827, theta=-36.9504599 -> V=1.022224, theta=0.0
% INFO    : Bus 2221	: V=1.04303501, theta=-6.8860664 -> V=1.0111115, theta=0.0
% INFO    : Bus 2222	: V=1.02136457, theta=-6.22426695 -> V=1.0158755, theta=0.0
% INFO    : Bus 2223	: V=1.05409441, theta=-1.59436865 -> V=1.0377785, theta=0.0
% INFO    : Bus 2224	: V=1.075126, theta=-8.77721234 -> V=1.073685, theta=0.0
% INFO    : Bus 2225	: V=1.05675911, theta=-12.3942122 -> V=1.022222, theta=0.0
% INFO    : Bus 2226	: V=1.00889168, theta=-7.30466976 -> V=1.0158755, theta=0.0
% INFO    : Bus 2227	: V=1.03905001, theta=-7.63252246 -> V=1.0158755, theta=0.0
% INFO    : Bus 2228	: V=1.07443498, theta=-5.21719633 -> V=1.0377785, theta=0.0
% INFO    : Bus 2229	: V=1.06009949, theta=-9.82892511 -> V=1.0000025, theta=0.0
% INFO    : Bus 2230	: V=0.995152682, theta=-31.2143525 -> V=1.0000025, theta=0.0
% INFO    : Bus 2231	: V=1.00810551, theta=-6.49519702 -> V=1.0158755, theta=0.0
% INFO    : Bus 2232	: V=1.05877405, theta=-3.61716542 -> V=1.033333, theta=0.0
% INFO    : Bus 2233	: V=1.06439517, theta=-1.10359761 -> V=1.0288895, theta=0.0
% INFO    : Bus 2234	: V=1.01264646, theta=-6.5254143 -> V=1.0158755, theta=0.0
% INFO    : Bus 2235	: V=1.06975959, theta=-9.1861617 -> V=1.015874, theta=0.0
% INFO    : Bus 2236	: V=1.07063531, theta=-7.6985704 -> V=1.033333, theta=0.0
% INFO    : Bus 2237	: V=1.01957044, theta=-14.9790299 -> V=0.999999, theta=0.0
% INFO    : Bus 2238	: V=1.06739047, theta=-4.56791333 -> V=0.9888895, theta=0.0
% INFO    : Bus 2239	: V=1.01033156, theta=-29.865639 -> V=1.0000025, theta=0.0
% INFO    : Bus 2240	: V=0.86040348, theta=-23.941455 -> V=0.83, theta=0.0
% INFO    : Bus 2241	: V=1.07549231, theta=-23.9410757 -> V=1.044445, theta=0.0
% INFO    : Bus 2242	: V=1.04327674, theta=-20.2689146 -> V=1.0000025, theta=0.0
% INFO    : Bus 2243	: V=1.04836731, theta=-20.5037757 -> V=1.022224, theta=0.0
% INFO    : Bus 2244	: V=1.00658279, theta=-3.4809994 -> V=1.0158755, theta=0.0
% INFO    : Bus 2245	: V=1.09047244, theta=2.6231413 -> V=1.072365, theta=0.0
% INFO    : Bus 2246	: V=1.069, theta=-21.3431912 -> V=0.975, theta=0.0
% INFO    : Bus 2247	: V=1.0352355, theta=-21.5054978 -> V=1.0000025, theta=0.0
% INFO    : Bus 2248	: V=1.07268177, theta=-19.5357867 -> V=1.044445, theta=0.0
% INFO    : Bus 2249	: V=1.05753975, theta=-21.9089592 -> V=1.0000025, theta=0.0
% INFO    : Bus 2250	: V=1.05896635, theta=-20.6051708 -> V=1.027779, theta=0.0
% INFO    : Bus 2251	: V=1.01047885, theta=-7.1379503 -> V=1.0158755, theta=0.0
% INFO    : Bus 2252	: V=1.07005204, theta=-9.06724516 -> V=1.015874, theta=0.0
% INFO    : Bus 2253	: V=1.02161082, theta=-27.9319455 -> V=1.015872, theta=0.0
% INFO    : Bus 2254	: V=1.04415539, theta=-23.6760489 -> V=1.046665, theta=0.0
% INFO    : Bus 2255	: V=1.05993636, theta=-17.5810056 -> V=1.046665, theta=0.0
% INFO    : Bus 2256	: V=1.02406003, theta=-10.6912288 -> V=1.0158755, theta=0.0
% INFO    : Bus 2257	: V=1.08095654, theta=-10.4684876 -> V=1.046665, theta=0.0
% INFO    : Bus 2258	: V=1.08142758, theta=-10.9076069 -> V=1.046665, theta=0.0
% INFO    : Bus 2259	: V=1.02094716, theta=3.49084712 -> V=1.0158755, theta=0.0
% INFO    : Bus 2260	: V=1.010644, theta=0.239617755 -> V=1.0158755, theta=0.0
% INFO    : Bus 2261	: V=1.06153355, theta=-9.60683876 -> V=1.033333, theta=0.0
% INFO    : Bus 2262	: V=1.01725733, theta=-15.8312207 -> V=1.0158755, theta=0.0
% INFO    : Bus 2263	: V=1.02367025, theta=-13.9130676 -> V=1.0, theta=0.0
% INFO    : Bus 2264	: V=1.05854505, theta=-11.2026588 -> V=1.0377785, theta=0.0
% INFO    : Bus 2265	: V=1.06819931, theta=-22.6213891 -> V=1.027779, theta=0.0
% INFO    : Bus 2266	: V=1.02940878, theta=-2.22551039 -> V=0.984126, theta=0.0
% INFO    : Bus 2267	: V=1.11474326, theta=5.166199 -> V=1.0399705, theta=0.0
% INFO    : Bus 2268	: V=1.01918442, theta=3.61933348 -> V=1.0158755, theta=0.0
% INFO    : Bus 2269	: V=1.07572665, theta=5.166199 -> V=1.0377785, theta=0.0
% INFO    : Bus 2270	: V=0.990782801, theta=-30.5187501 -> V=1.0000025, theta=0.0
% INFO    : Bus 2271	: V=1.06234617, theta=-9.54913296 -> V=1.016666, theta=0.0
% INFO    : Bus 2272	: V=1.06258042, theta=-5.91524241 -> V=1.006667, theta=0.0
% INFO    : Bus 2273	: V=1.01118822, theta=-7.07823217 -> V=1.0158755, theta=0.0
% INFO    : Bus 2274	: V=1.06384956, theta=-8.61932108 -> V=1.022222, theta=0.0
% INFO    : Bus 2275	: V=1.02645362, theta=-2.85565725 -> V=1.0158755, theta=0.0
% INFO    : Bus 2276	: V=1.01678272, theta=-13.3141343 -> V=1.0158755, theta=0.0
% INFO    : Bus 2277	: V=1.03228204, theta=-38.3362265 -> V=1.0079355, theta=0.0
% INFO    : Bus 2278	: V=1.0299853, theta=-23.3147492 -> V=1.022224, theta=0.0
% INFO    : Bus 2279	: V=1.00926548, theta=-7.83992198 -> V=1.0158755, theta=0.0
% INFO    : Bus 2280	: V=1.01726562, theta=0.492126106 -> V=1.0158755, theta=0.0
% INFO    : Bus 2281	: V=1.0135811, theta=3.23682366 -> V=1.013331, theta=0.0
% INFO    : Bus 2282	: V=1.01117416, theta=3.01402729 -> V=1.013331, theta=0.0
% INFO    : Bus 2283	: V=1.01876347, theta=3.44774758 -> V=1.0158755, theta=0.0
% INFO    : Bus 2284	: V=1.05503964, theta=-4.55915312 -> V=0.9888895, theta=0.0
% INFO    : Bus 2285	: V=1.05224464, theta=-23.2580671 -> V=1.027779, theta=0.0
% INFO    : Bus 2286	: V=1.01388885, theta=-27.3789209 -> V=1.015872, theta=0.0
% INFO    : Bus 2287	: V=1.04401058, theta=-22.2027488 -> V=1.0000025, theta=0.0
% INFO    : Bus 2288	: V=1.0214804, theta=-25.5740213 -> V=1.0000025, theta=0.0
% INFO    : Bus 2289	: V=1.07407398, theta=-15.5988131 -> V=1.078945, theta=0.0
% INFO    : Bus 2290	: V=1.04086177, theta=-33.2314347 -> V=1.022224, theta=0.0
% INFO    : Bus 2291	: V=1.03101169, theta=-19.0917554 -> V=0.999999, theta=0.0
% INFO    : Bus 2292	: V=1.0372047, theta=-15.8940591 -> V=1.0111115, theta=0.0
% INFO    : Bus 2293	: V=1.01284471, theta=-22.714137 -> V=1.0000005, theta=0.0
% INFO    : Bus 2294	: V=0.997, theta=-21.2389689 -> V=1.0000005, theta=0.0
% INFO    : Bus 2295	: V=1.01399011, theta=-21.020961 -> V=1.0000005, theta=0.0
% INFO    : Bus 2296	: V=1.02518938, theta=-17.1443599 -> V=1.0000005, theta=0.0
% INFO    : Bus 2297	: V=1.03561443, theta=-15.7848153 -> V=0.999999, theta=0.0
% INFO    : Bus 2298	: V=1.04886578, theta=-11.8106755 -> V=1.0111115, theta=0.0
% INFO    : Bus 2299	: V=1.01198688, theta=-23.133202 -> V=1.0000025, theta=0.0
% INFO    : Bus 2300	: V=1.03035826, theta=-11.8253821 -> V=0.999999, theta=0.0
% INFO    : Bus 2301	: V=0.999827929, theta=-29.489255 -> V=1.0000025, theta=0.0
% INFO    : Bus 2302	: V=1.00485207, theta=-13.9777998 -> V=1.0158755, theta=0.0
% INFO    : Bus 2303	: V=1.02155047, theta=-29.9110984 -> V=1.022224, theta=0.0
% INFO    : Bus 2304	: V=1.00041521, theta=-28.6022957 -> V=1.0000025, theta=0.0
% INFO    : Bus 2305	: V=1.03740146, theta=-27.4286925 -> V=1.022224, theta=0.0
% INFO    : Bus 2306	: V=1.01939526, theta=-49.7470621 -> V=1.0079355, theta=0.0
% INFO    : Bus 2307	: V=1.01929911, theta=-6.72721256 -> V=1.0158755, theta=0.0
% INFO    : Bus 2308	: V=1.07826513, theta=-4.26167796 -> V=1.0377785, theta=0.0
% INFO    : Bus 2309	: V=1.01442368, theta=-27.0983108 -> V=1.015872, theta=0.0
% INFO    : Bus 2310	: V=1.02155286, theta=-26.8018925 -> V=1.0000025, theta=0.0
% INFO    : Bus 2311	: V=1.02374975, theta=-13.2920934 -> V=0.999999, theta=0.0
% INFO    : Bus 2312	: V=1.03841307, theta=-10.3973698 -> V=1.0111115, theta=0.0
% INFO    : Bus 2313	: V=1.01754218, theta=-25.2315617 -> V=1.0000025, theta=0.0
% INFO    : Bus 2314	: V=1.0573385, theta=-21.364574 -> V=1.044445, theta=0.0
% INFO    : Bus 2315	: V=1.01639199, theta=-12.0764724 -> V=0.999999, theta=0.0
% INFO    : Bus 2316	: V=1.03326888, theta=-36.5707796 -> V=1.022224, theta=0.0
% INFO    : Bus 2317	: V=1.01690102, theta=-29.2753631 -> V=1.015872, theta=0.0
% INFO    : Bus 2318	: V=1.02452152, theta=-17.81613 -> V=1.015872, theta=0.0
% INFO    : Bus 2319	: V=1.03195478, theta=-21.2586098 -> V=1.022224, theta=0.0
% INFO    : Bus 2320	: V=1.02947414, theta=-27.2122356 -> V=1.0000025, theta=0.0
% INFO    : Bus 2321	: V=1.04211895, theta=-25.2267542 -> V=1.022224, theta=0.0
% INFO    : Bus 2322	: V=1.02789714, theta=-27.9988238 -> V=1.022224, theta=0.0
% INFO    : Bus 2323	: V=1.03009544, theta=-19.1815324 -> V=1.022224, theta=0.0
% INFO    : Bus 2324	: V=1.07858469, theta=-18.5615013 -> V=1.046665, theta=0.0
% INFO    : Bus 2325	: V=1.07862259, theta=-18.5704982 -> V=1.046665, theta=0.0
% INFO    : Bus 2326	: V=1.02584257, theta=-5.98348834 -> V=1.0158755, theta=0.0
% INFO    : Bus 2327	: V=1.06155858, theta=-2.775067 -> V=1.0377785, theta=0.0
% INFO    : Bus 2328	: V=1.01953722, theta=-8.83669258 -> V=1.0158755, theta=0.0
% INFO    : Bus 2329	: V=1.004192, theta=-26.2798792 -> V=1.0000025, theta=0.0
% INFO    : Bus 2330	: V=1.03346856, theta=-19.8619019 -> V=1.0000005, theta=0.0
% INFO    : Bus 2331	: V=1.01927463, theta=-20.7808572 -> V=1.015872, theta=0.0
% INFO    : Bus 2332	: V=1.01708798, theta=-20.7041965 -> V=1.015872, theta=0.0
% INFO    : Bus 2333	: V=1.02208692, theta=-18.4170401 -> V=1.015872, theta=0.0
% INFO    : Bus 2334	: V=1.02396461, theta=-17.9529518 -> V=1.015872, theta=0.0
% INFO    : Bus 2335	: V=1.04499339, theta=-12.7244736 -> V=1.046665, theta=0.0
% INFO    : Bus 2336	: V=1.05682839, theta=-5.31467915 -> V=1.07877, theta=0.0
% INFO    : Bus 2337	: V=1.03927014, theta=-24.4298572 -> V=1.022224, theta=0.0
% INFO    : Bus 2338	: V=1.02461934, theta=-44.5048518 -> V=1.0079355, theta=0.0
% INFO    : Bus 2339	: V=1.01729764, theta=1.08493685 -> V=1.0158755, theta=0.0
% INFO    : Bus 2340	: V=0.997, theta=-20.2092938 -> V=1.015872, theta=0.0
% INFO    : Bus 2341	: V=1.05037857, theta=-22.8532474 -> V=1.0000025, theta=0.0
% INFO    : Bus 2342	: V=1.038, theta=-27.3933246 -> V=1.022224, theta=0.0
% INFO    : Bus 2343	: V=1.02216504, theta=-15.4194751 -> V=0.999999, theta=0.0
% INFO    : Bus 2344	: V=1.02515627, theta=-14.3093085 -> V=0.999999, theta=0.0
% INFO    : Bus 2345	: V=1.04822828, theta=-10.6244219 -> V=1.0111115, theta=0.0
% INFO    : Bus 2346	: V=1.0220228, theta=-22.2884798 -> V=1.0158755, theta=0.0
% INFO    : Bus 2347	: V=1.04174863, theta=-22.365767 -> V=1.027779, theta=0.0
% INFO    : Bus 2348	: V=1.02409862, theta=-18.1641509 -> V=1.027779, theta=0.0
% INFO    : Bus 2349	: V=1.06910238, theta=-17.3182919 -> V=1.04444, theta=0.0
% INFO    : Bus 2350	: V=1.08026862, theta=-15.8563304 -> V=1.07237, theta=0.0
% INFO    : Bus 2351	: V=1.08040556, theta=-15.8307596 -> V=1.07237, theta=0.0
% INFO    : Bus 2352	: V=1.01753656, theta=1.84426065 -> V=1.0158755, theta=0.0
% INFO    : Bus 2353	: V=1.05564365, theta=-22.5735697 -> V=1.000001, theta=0.0
% INFO    : Bus 2354	: V=1.07252082, theta=-18.1901992 -> V=1.0, theta=0.0
% INFO    : Bus 2355	: V=1.05107679, theta=-22.7546634 -> V=1.000001, theta=0.0
% INFO    : Bus 2356	: V=1.01153231, theta=-14.1776683 -> V=1.0158755, theta=0.0
% INFO    : Bus 2357	: V=1.04906161, theta=-18.7180827 -> V=1.022224, theta=0.0
% INFO    : Bus 2358	: V=1.01820669, theta=-25.9968632 -> V=1.0000025, theta=0.0
% INFO    : Bus 2359	: V=1.03738532, theta=-21.9014973 -> V=1.022224, theta=0.0
% INFO    : Bus 2360	: V=1.00364909, theta=-27.5803241 -> V=1.022224, theta=0.0
% INFO    : Bus 2361	: V=1.02588842, theta=-39.0253522 -> V=1.0079355, theta=0.0
% INFO    : Bus 2362	: V=1.03000037, theta=-26.7402947 -> V=1.022224, theta=0.0
% INFO    : Bus 2363	: V=1.01235746, theta=-6.25571117 -> V=1.0158755, theta=0.0
% INFO    : Bus 2364	: V=1.091, theta=-1.63446028 -> V=0.975, theta=0.0
% INFO    : Bus 2365	: V=1.096, theta=-1.68642432 -> V=0.975, theta=0.0
% INFO    : Bus 2366	: V=1.071, theta=-2.58166019 -> V=0.975, theta=0.0
% INFO    : Bus 2367	: V=1.091, theta=-1.89837968 -> V=0.975, theta=0.0
% INFO    : Bus 2368	: V=1.1, theta=-2.78775114 -> V=0.975, theta=0.0
% INFO    : Bus 2369	: V=1.08244997, theta=-3.81002639 -> V=1.0377785, theta=0.0
% INFO    : Bus 2370	: V=1.08248573, theta=-3.80958032 -> V=1.0377785, theta=0.0
% INFO    : Bus 2371	: V=1.0823289, theta=-3.81634695 -> V=1.0377785, theta=0.0
% INFO    : Bus 2372	: V=1.08245172, theta=-3.81171032 -> V=1.0377785, theta=0.0
% INFO    : Bus 2373	: V=1.08240565, theta=-3.82406323 -> V=1.0377785, theta=0.0
% INFO    : Bus 2374	: V=1.08251359, theta=-3.81727466 -> V=1.0377785, theta=0.0
% INFO    : Bus 2375	: V=1.0233796, theta=-5.96879257 -> V=1.0158755, theta=0.0
% INFO    : Bus 2376	: V=1.08240565, theta=-3.82406323 -> V=1.0377785, theta=0.0
% INFO    : Bus 2377	: V=1.03479583, theta=-47.0331669 -> V=1.0079355, theta=0.0
% INFO    : Bus 2378	: V=1.01586051, theta=2.00934012 -> V=1.0158755, theta=0.0
% INFO    : Bus 2379	: V=1.04188104, theta=-46.4887676 -> V=1.0079355, theta=0.0
% INFO    : Bus 2380	: V=0.999372195, theta=-51.224497 -> V=1.0079355, theta=0.0
% INFO    : Bus 2381	: V=1.00177041, theta=-56.237623 -> V=1.0079355, theta=0.0
% INFO    : Bus 2382	: V=1.03408356, theta=-47.0707806 -> V=1.0079355, theta=0.0
% INFO    : Bus 2383	: V=1.04854957, theta=-47.0378645 -> V=1.0079355, theta=0.0
% INFO    : Bus 2384	: V=1.00566033, theta=-47.4747421 -> V=1.0079355, theta=0.0
% INFO    : Bus 2385	: V=1.01444517, theta=-47.6336967 -> V=1.0079355, theta=0.0
% INFO    : Bus 2386	: V=1.00657669, theta=-46.6361265 -> V=1.0079355, theta=0.0
% INFO    : Bus 2387	: V=1.02185481, theta=-16.4853704 -> V=1.0158755, theta=0.0
% INFO    : Bus 2388	: V=0.979020842, theta=-44.1086067 -> V=1.0079355, theta=0.0
% INFO    : Bus 2389	: V=1.01294182, theta=-6.30694805 -> V=1.0158755, theta=0.0
% INFO    : Bus 2390	: V=1.02321556, theta=-10.6873579 -> V=1.015872, theta=0.0
% INFO    : Bus 2391	: V=1.04026344, theta=-23.1249694 -> V=1.0000025, theta=0.0
% INFO    : Bus 2392	: V=1.05136689, theta=-24.4435451 -> V=1.0000025, theta=0.0
% INFO    : Bus 2393	: V=1.05135907, theta=-24.4481677 -> V=1.0000025, theta=0.0
% INFO    : Bus 2394	: V=0.999061731, theta=-25.5378608 -> V=1.0000025, theta=0.0
% INFO    : Bus 2395	: V=1.01368283, theta=-25.0661356 -> V=1.0000025, theta=0.0
% INFO    : Bus 2396	: V=1.04909946, theta=-24.739396 -> V=1.0000025, theta=0.0
% INFO    : Bus 2397	: V=1.01062715, theta=-27.0566978 -> V=1.0000025, theta=0.0
% INFO    : Bus 2398	: V=1.03196577, theta=-21.326561 -> V=1.0000025, theta=0.0
% INFO    : Bus 2399	: V=1.02850792, theta=-21.3229225 -> V=0.999999, theta=0.0
% INFO    : Bus 2400	: V=1.03097321, theta=-27.7386225 -> V=1.0000025, theta=0.0
% INFO    : Bus 2401	: V=1.06081021, theta=-9.17088167 -> V=1.046665, theta=0.0
% INFO    : Bus 2402	: V=1.03856182, theta=-29.662765 -> V=1.0000025, theta=0.0
% INFO    : Bus 2403	: V=1.05749865, theta=-6.0314172 -> V=1.046665, theta=0.0
% INFO    : Bus 2404	: V=1.05750394, theta=-6.03104104 -> V=1.046665, theta=0.0
% INFO    : Bus 2405	: V=0.983890744, theta=-30.7006372 -> V=1.0000025, theta=0.0
% INFO    : Bus 2406	: V=1.05336519, theta=-28.3132368 -> V=1.027779, theta=0.0
% INFO    : Bus 2407	: V=1.01783174, theta=-29.7094456 -> V=1.0000025, theta=0.0
% INFO    : Bus 2408	: V=1.06883446, theta=-26.104763 -> V=1.0000025, theta=0.0
% INFO    : Bus 2409	: V=1.05798422, theta=-20.7713545 -> V=1.000001, theta=0.0
% INFO    : Bus 2410	: V=1.02056091, theta=-19.4272608 -> V=1.0000005, theta=0.0
% INFO    : Bus 2411	: V=1.02242463, theta=-15.9527288 -> V=1.0000005, theta=0.0
% INFO    : Bus 2412	: V=0.978014061, theta=-15.0085783 -> V=0.999999, theta=0.0
% INFO    : Bus 2413	: V=1.058, theta=-20.7697921 -> V=1.000001, theta=0.0
% INFO    : Bus 2414	: V=0.99996591, theta=-23.6515486 -> V=1.015872, theta=0.0
% INFO    : Bus 2415	: V=1.01714375, theta=-39.550988 -> V=1.0079355, theta=0.0
% INFO    : Bus 2416	: V=1.03499073, theta=-12.3171993 -> V=1.016666, theta=0.0
% INFO    : Bus 2417	: V=1.06969117, theta=-18.8288518 -> V=1.046665, theta=0.0
% INFO    : Bus 2418	: V=1.06969877, theta=-18.8282943 -> V=1.046665, theta=0.0
% INFO    : Bus 2419	: V=1.04264597, theta=-23.4164276 -> V=1.0000025, theta=0.0
% INFO    : Bus 2420	: V=1.06785213, theta=-15.1173378 -> V=1.044445, theta=0.0
% INFO    : Bus 2421	: V=1.02655391, theta=-12.4867836 -> V=0.999999, theta=0.0
% INFO    : Bus 2422	: V=1.01682229, theta=1.84532867 -> V=1.0158755, theta=0.0
% INFO    : Bus 2423	: V=1.05947602, theta=-19.4040082 -> V=1.022224, theta=0.0
% INFO    : Bus 2424	: V=1.03230263, theta=-45.0914742 -> V=1.0079355, theta=0.0
% INFO    : Bus 2425	: V=1.07088524, theta=-40.2687537 -> V=1.04444, theta=0.0
% INFO    : Bus 2426	: V=1.07101849, theta=-40.3590638 -> V=1.04444, theta=0.0
% INFO    : Bus 2427	: V=1.0199422, theta=-47.538658 -> V=1.0079355, theta=0.0
% INFO    : Bus 2428	: V=1.0172972, theta=1.08494912 -> V=1.0158755, theta=0.0
% INFO    : Bus 2429	: V=1.07599874, theta=4.98445385 -> V=1.0377785, theta=0.0
% INFO    : Bus 2430	: V=1.00514737, theta=-3.63362449 -> V=1.0158755, theta=0.0
% INFO    : Bus 2431	: V=1.01491358, theta=-3.38785965 -> V=1.0158755, theta=0.0
% INFO    : Bus 2432	: V=1.02062112, theta=-2.40807851 -> V=1.0158755, theta=0.0
% INFO    : Bus 2433	: V=1.05900331, theta=1.33332184 -> V=1.0377785, theta=0.0
% INFO    : Bus 2434	: V=1.02137513, theta=-47.565551 -> V=1.0079355, theta=0.0
% INFO    : Bus 2435	: V=1.04795627, theta=-49.1229419 -> V=1.0079355, theta=0.0
% INFO    : Bus 2436	: V=1.08284602, theta=-15.1963343 -> V=1.046665, theta=0.0
% INFO    : Bus 2437	: V=1.08263121, theta=-15.2782265 -> V=1.046665, theta=0.0
% INFO    : Bus 2438	: V=1.0258212, theta=-16.4122993 -> V=0.999999, theta=0.0
% INFO    : Bus 2439	: V=1.03232305, theta=-4.74790249 -> V=1.0158755, theta=0.0
% INFO    : Bus 2440	: V=1.0323621, theta=-4.75359265 -> V=1.0158755, theta=0.0
% INFO    : Bus 2441	: V=1.02416681, theta=-21.223909 -> V=0.999999, theta=0.0
% INFO    : Bus 2442	: V=1.01113979, theta=-26.3455404 -> V=1.0000025, theta=0.0
% INFO    : Bus 2443	: V=1.01908699, theta=-45.3144956 -> V=1.0079355, theta=0.0
% INFO    : Bus 2444	: V=1.01232975, theta=-47.7575242 -> V=1.0079355, theta=0.0
% INFO    : Bus 2445	: V=1.00912405, theta=-44.9056307 -> V=1.0079355, theta=0.0
% INFO    : Bus 2446	: V=1.02019001, theta=-43.9789412 -> V=1.0079355, theta=0.0
% INFO    : Bus 2447	: V=1.01805218, theta=-18.8747105 -> V=1.0000025, theta=0.0
% INFO    : Bus 2448	: V=0.990247969, theta=-26.8720372 -> V=1.0000025, theta=0.0
% INFO    : Bus 2449	: V=1.07804308, theta=-19.0465801 -> V=1.0, theta=0.0
% INFO    : Bus 2450	: V=1.05971914, theta=-18.0352794 -> V=1.044445, theta=0.0
% INFO    : Bus 2451	: V=1.03109864, theta=-43.7063181 -> V=1.0079355, theta=0.0
% INFO    : Bus 2452	: V=1.06409079, theta=-19.283586 -> V=1.000001, theta=0.0
% INFO    : Bus 2453	: V=0.987925413, theta=-7.90550923 -> V=0.999999, theta=0.0
% INFO    : Bus 2454	: V=1.03928174, theta=-24.5434629 -> V=1.0000025, theta=0.0
% INFO    : Bus 2455	: V=1.04846772, theta=-16.1060365 -> V=1.0000025, theta=0.0
% INFO    : Bus 2456	: V=1.07828391, theta=-18.6005526 -> V=1.046665, theta=0.0
% INFO    : Bus 2457	: V=1.07089496, theta=-23.7662869 -> V=1.044445, theta=0.0
% INFO    : Bus 2458	: V=1.00637254, theta=-8.87085386 -> V=1.0158755, theta=0.0
% INFO    : Bus 2459	: V=1.03432047, theta=-25.9194552 -> V=1.022224, theta=0.0
% INFO    : Bus 2460	: V=1.0813204, theta=-17.6844083 -> V=1.07237, theta=0.0
% INFO    : Bus 2461	: V=1.04382766, theta=-22.0950852 -> V=1.0000025, theta=0.0
% INFO    : Bus 2462	: V=1.07124946, theta=-15.8015701 -> V=1.044445, theta=0.0
% INFO    : Bus 2463	: V=1.012, theta=-21.5768206 -> V=1.015872, theta=0.0
% INFO    : Bus 2464	: V=1.03571046, theta=-20.2514143 -> V=1.0158755, theta=0.0
% INFO    : Bus 2465	: V=1.02189025, theta=-18.3322806 -> V=1.0000005, theta=0.0
% INFO    : Bus 2466	: V=1.03711469, theta=-37.7359058 -> V=1.022224, theta=0.0
% INFO    : Bus 2467	: V=1.06769453, theta=-9.79146134 -> V=0.9888895, theta=0.0
% INFO    : Bus 2468	: V=1.06251943, theta=-8.88436456 -> V=0.9888895, theta=0.0
% INFO    : Bus 2469	: V=1.07254284, theta=-7.28289199 -> V=1.05263, theta=0.0
% INFO    : Bus 2470	: V=1.05584534, theta=-26.9838227 -> V=1.027779, theta=0.0
% INFO    : Bus 2471	: V=1.06907031, theta=-27.1984973 -> V=1.046665, theta=0.0
% INFO    : Bus 2472	: V=1.08116096, theta=-20.7149649 -> V=1.073685, theta=0.0
% INFO    : Bus 2473	: V=0.998082238, theta=-28.8750751 -> V=1.0000025, theta=0.0
% INFO    : Bus 2474	: V=0.99240325, theta=-26.7391456 -> V=1.015872, theta=0.0
% INFO    : Bus 2475	: V=1.00172457, theta=-24.1663729 -> V=1.015872, theta=0.0
% INFO    : Bus 2476	: V=1.00186793, theta=-24.1647854 -> V=1.015872, theta=0.0
% INFO    : Bus 2477	: V=1.02520565, theta=-20.0907104 -> V=0.999999, theta=0.0
% INFO    : Bus 2478	: V=1.03742982, theta=-4.73179089 -> V=1.0158755, theta=0.0
% INFO    : Bus 2479	: V=1.0175782, theta=-12.5358704 -> V=0.999999, theta=0.0
% INFO    : Bus 2480	: V=1.01340364, theta=-25.9456553 -> V=1.0000025, theta=0.0
% INFO    : Bus 2481	: V=1.06320614, theta=-22.3447858 -> V=1.0000025, theta=0.0
% INFO    : Bus 2482	: V=0.989235484, theta=-23.0785734 -> V=1.015872, theta=0.0
% INFO    : Bus 2483	: V=1.01351494, theta=-21.8454923 -> V=1.0000025, theta=0.0
% INFO    : Bus 2484	: V=1.02345863, theta=-33.2301909 -> V=1.022224, theta=0.0
% INFO    : Bus 2485	: V=1.04267804, theta=-34.7159146 -> V=1.022224, theta=0.0
% INFO    : Bus 2486	: V=1.07009723, theta=-30.1311209 -> V=1.04444, theta=0.0
% INFO    : Bus 2487	: V=1.00811317, theta=-32.7544661 -> V=1.015872, theta=0.0
% INFO    : Bus 2488	: V=1.07428117, theta=-20.8985742 -> V=1.000001, theta=0.0
% INFO    : Bus 2489	: V=1.01808218, theta=-7.75457029 -> V=1.0158755, theta=0.0
% INFO    : Bus 2490	: V=1.02540368, theta=-28.9605646 -> V=1.0000025, theta=0.0
% INFO    : Bus 2491	: V=1.00227781, theta=-24.112876 -> V=1.015872, theta=0.0
% INFO    : Bus 2492	: V=1.04137457, theta=-19.4891334 -> V=1.046665, theta=0.0
% INFO    : Bus 2493	: V=1.00640964, theta=-24.6007173 -> V=1.0000025, theta=0.0
% INFO    : Bus 2494	: V=1.01716271, theta=-6.98160854 -> V=1.0158755, theta=0.0
% INFO    : Bus 2495	: V=1.0382829, theta=-18.0119887 -> V=1.0158755, theta=0.0
% INFO    : Bus 2496	: V=1.00304696, theta=-3.7564385 -> V=1.0158755, theta=0.0
% INFO    : Bus 2497	: V=1.02339953, theta=-19.2302319 -> V=1.015872, theta=0.0
% INFO    : Bus 2498	: V=1.03998862, theta=-19.857826 -> V=1.027779, theta=0.0
% INFO    : Bus 2499	: V=0.95660379, theta=-8.82462633 -> V=0.9444445, theta=0.0
% INFO    : Bus 2500	: V=0.980057987, theta=-29.4791666 -> V=1.0000025, theta=0.0
% INFO    : Bus 2501	: V=0.996586458, theta=-31.7077759 -> V=1.0000025, theta=0.0
% INFO    : Bus 2502	: V=1.00626849, theta=-19.7101831 -> V=1.015872, theta=0.0
% INFO    : Bus 2503	: V=1.04306365, theta=-24.9502383 -> V=1.0000025, theta=0.0
% INFO    : Bus 2504	: V=1.02793583, theta=-25.6350883 -> V=1.0000025, theta=0.0
% INFO    : Bus 2505	: V=1.06157443, theta=-21.3922998 -> V=1.044445, theta=0.0
% INFO    : Bus 2506	: V=1.03171454, theta=-26.8544185 -> V=1.0000025, theta=0.0
% INFO    : Bus 2507	: V=1.02300007, theta=-22.9833689 -> V=1.022224, theta=0.0
% INFO    : Bus 2508	: V=1.03041445, theta=-15.7903583 -> V=0.999999, theta=0.0
% INFO    : Bus 2509	: V=1.00962299, theta=-27.0459611 -> V=1.0000025, theta=0.0
% INFO    : Bus 2510	: V=1.00395837, theta=-0.16129124 -> V=1.0158755, theta=0.0
% INFO    : Bus 2511	: V=1.03447594, theta=-25.3161391 -> V=1.0000025, theta=0.0
% INFO    : Bus 2512	: V=1.06973953, theta=-19.8152618 -> V=1.044445, theta=0.0
% INFO    : Bus 2513	: V=1.01893841, theta=-47.1223362 -> V=1.0079355, theta=0.0
% INFO    : Bus 2514	: V=1.05521227, theta=-21.1846269 -> V=1.0000025, theta=0.0
% INFO    : Bus 2515	: V=1.03238535, theta=-25.2167532 -> V=1.0000025, theta=0.0
% INFO    : Bus 2516	: V=1.02935077, theta=-32.0656097 -> V=1.0000025, theta=0.0
% INFO    : Bus 2517	: V=1.05868488, theta=-32.0656097 -> V=1.000001, theta=0.0
% INFO    : Bus 2518	: V=1.04314158, theta=-23.3695791 -> V=1.0000025, theta=0.0
% INFO    : Bus 2519	: V=1.06907056, theta=-18.8373473 -> V=1.044445, theta=0.0
% INFO    : Bus 2520	: V=1.07536304, theta=-14.145464 -> V=1.078945, theta=0.0
% INFO    : Bus 2521	: V=1.05230394, theta=-6.64276186 -> V=0.9888895, theta=0.0
% INFO    : Bus 2522	: V=1.05225804, theta=-6.64684845 -> V=0.9888895, theta=0.0
% INFO    : Bus 2523	: V=0.993940925, theta=-30.778728 -> V=1.0000025, theta=0.0
% INFO    : Bus 2524	: V=1.00602, theta=-20.588013 -> V=1.022224, theta=0.0
% INFO    : Bus 2525	: V=1.153, theta=-5.22067825 -> V=1.054343, theta=0.0
% INFO    : Bus 2526	: V=1.06138942, theta=-4.88879784 -> V=0.9888895, theta=0.0
% INFO    : Bus 2527	: V=1.00336142, theta=-20.5490798 -> V=1.0000005, theta=0.0
% INFO    : Bus 2528	: V=1.06985071, theta=-18.8821161 -> V=1.046665, theta=0.0
% INFO    : Bus 2529	: V=1.02085348, theta=-18.5452236 -> V=1.022224, theta=0.0
% INFO    : Bus 2530	: V=1.03847434, theta=-18.8546127 -> V=1.0000025, theta=0.0
% INFO    : Bus 2531	: V=0.973947879, theta=-26.7762276 -> V=1.0000025, theta=0.0
% INFO    : Bus 2532	: V=1.04317946, theta=-7.48042073 -> V=1.0000025, theta=0.0
% INFO    : Bus 2533	: V=1.02242466, theta=-28.7209837 -> V=1.015872, theta=0.0
% INFO    : Bus 2534	: V=1.013, theta=-11.3885646 -> V=1.0158755, theta=0.0
% INFO    : Bus 2535	: V=1.01198274, theta=-11.530113 -> V=1.0158755, theta=0.0
% INFO    : Bus 2536	: V=1.07033519, theta=-17.0829419 -> V=1.046665, theta=0.0
% INFO    : Bus 2537	: V=1.05939683, theta=-17.5946372 -> V=1.046665, theta=0.0
% INFO    : Bus 2538	: V=1.0059728, theta=-20.1016382 -> V=1.0000005, theta=0.0
% INFO    : Bus 2539	: V=1.00831972, theta=-20.1213059 -> V=1.0000005, theta=0.0
% INFO    : Bus 2540	: V=1.03338959, theta=-21.0364595 -> V=0.999999, theta=0.0
% INFO    : Bus 2541	: V=1.04862, theta=-20.9155247 -> V=0.999999, theta=0.0
% INFO    : Bus 2542	: V=1.0387967, theta=-14.7629789 -> V=1.0111115, theta=0.0
% INFO    : Bus 2543	: V=1.02226337, theta=-20.6263233 -> V=1.015872, theta=0.0
% INFO    : Bus 2544	: V=1.00935794, theta=-22.9530321 -> V=1.0000005, theta=0.0
% INFO    : Bus 2545	: V=1.01177532, theta=-22.8893617 -> V=1.0000005, theta=0.0
% INFO    : Bus 2546	: V=1.01033717, theta=-22.9050772 -> V=1.0000005, theta=0.0
% INFO    : Bus 2547	: V=1.01435048, theta=-26.6294582 -> V=1.0000025, theta=0.0
% INFO    : Bus 2548	: V=1.01409384, theta=-13.1337165 -> V=0.999999, theta=0.0
% INFO    : Bus 2549	: V=1.02500301, theta=-24.8982781 -> V=0.999999, theta=0.0
% INFO    : Bus 2550	: V=1.0400596, theta=-28.9489394 -> V=1.015872, theta=0.0
% INFO    : Bus 2551	: V=1.02243808, theta=-26.4267763 -> V=1.0233335, theta=0.0
% INFO    : Bus 2552	: V=1.0462806, theta=-26.397527 -> V=1.046665, theta=0.0
% INFO    : Bus 2553	: V=1.04686195, theta=-10.0638787 -> V=1.0000025, theta=0.0
% INFO    : Bus 2554	: V=1.0476813, theta=-27.8649779 -> V=1.0000025, theta=0.0
% INFO    : Bus 2555	: V=1.03623476, theta=-20.4821402 -> V=0.999999, theta=0.0
% INFO    : Bus 2556	: V=1.05075004, theta=-21.1247696 -> V=1.027779, theta=0.0
% INFO    : Bus 2557	: V=1.05805863, theta=-11.9990681 -> V=1.0000025, theta=0.0
% INFO    : Bus 2558	: V=0.998607292, theta=-48.4972264 -> V=1.0079355, theta=0.0
% INFO    : Bus 2559	: V=1.04572486, theta=-25.5792441 -> V=1.027779, theta=0.0
% INFO    : Bus 2560	: V=1.016, theta=-11.6847706 -> V=0.999999, theta=0.0
% INFO    : Bus 2561	: V=0.978075583, theta=-24.1938553 -> V=1.0000025, theta=0.0
% INFO    : Bus 2562	: V=1.05399035, theta=-19.5877473 -> V=1.044445, theta=0.0
% INFO    : Bus 2563	: V=1.02860493, theta=-14.742365 -> V=1.0000005, theta=0.0
% INFO    : Bus 2564	: V=1.02890939, theta=-28.6966633 -> V=1.022224, theta=0.0
% INFO    : Bus 2565	: V=1.01864825, theta=-49.4422013 -> V=1.0079355, theta=0.0
% INFO    : Bus 2566	: V=1.02147441, theta=-49.8503119 -> V=1.0079355, theta=0.0
% INFO    : Bus 2567	: V=1.01117739, theta=-22.6834088 -> V=1.0000025, theta=0.0
% INFO    : Bus 2568	: V=1.02722422, theta=-6.93223441 -> V=1.0158755, theta=0.0
% INFO    : Bus 2569	: V=1.07590396, theta=-2.39061379 -> V=1.0377785, theta=0.0
% INFO    : Bus 2570	: V=1.09506383, theta=1.0078481 -> V=1.072365, theta=0.0
% INFO    : Bus 2571	: V=1.03542541, theta=-21.8956481 -> V=1.027779, theta=0.0
% INFO    : Bus 2572	: V=1.05068096, theta=-21.1207146 -> V=1.027779, theta=0.0
% INFO    : Bus 2573	: V=1.07170184, theta=-16.6848987 -> V=1.046665, theta=0.0
% INFO    : Bus 2574	: V=1.01136796, theta=-18.9938459 -> V=1.0000005, theta=0.0
% INFO    : Bus 2575	: V=1.05582599, theta=-30.1719168 -> V=1.027779, theta=0.0
% INFO    : Bus 2576	: V=1.06743319, theta=-14.4423788 -> V=1.026154, theta=0.0
% INFO    : Bus 2577	: V=1.0785117, theta=-18.6398937 -> V=1.046665, theta=0.0
% INFO    : Bus 2578	: V=1.02710767, theta=2.59283861 -> V=1.0158755, theta=0.0
% INFO    : Bus 2579	: V=0.950232857, theta=-8.11198703 -> V=0.9444445, theta=0.0
% INFO    : Bus 2580	: V=0.997218333, theta=-8.00738801 -> V=0.999999, theta=0.0
% INFO    : Bus 2581	: V=1.04609758, theta=-11.6862761 -> V=1.003335, theta=0.0
% INFO    : Bus 2582	: V=1.04305103, theta=-6.89341906 -> V=1.0111115, theta=0.0
% INFO    : Bus 2583	: V=1.04751566, theta=-42.0579381 -> V=1.022224, theta=0.0
% INFO    : Bus 2584	: V=1.01074943, theta=-32.2125925 -> V=1.022224, theta=0.0
% INFO    : Bus 2585	: V=1.07235701, theta=-6.20138853 -> V=1.016666, theta=0.0
% INFO    : Bus 2586	: V=1.0618974, theta=-1.59905537 -> V=1.0288895, theta=0.0
% INFO    : Bus 2587	: V=1.02174461, theta=-29.7780191 -> V=1.0000025, theta=0.0
% INFO    : Bus 2588	: V=1.03905936, theta=-22.4344505 -> V=1.022224, theta=0.0
% INFO    : Bus 2589	: V=1.03351256, theta=-30.618735 -> V=1.022224, theta=0.0
% INFO    : Bus 2590	: V=1.02606593, theta=-14.1193268 -> V=0.999999, theta=0.0
% INFO    : Bus 2591	: V=1.00858886, theta=-18.5376028 -> V=1.0000005, theta=0.0
% INFO    : Bus 2592	: V=1.08121003, theta=6.12455347 -> V=1.05263, theta=0.0
% INFO    : Bus 2593	: V=1.0074831, theta=-46.5352062 -> V=1.0079355, theta=0.0
% INFO    : Bus 2594	: V=1.00098915, theta=-12.0371887 -> V=0.975, theta=0.0
% INFO    : Bus 2595	: V=1.0556361, theta=-15.9222506 -> V=1.022224, theta=0.0
% INFO    : Bus 2596	: V=1.0199571, theta=-43.803397 -> V=1.0079355, theta=0.0
% INFO    : Bus 2597	: V=1.07103598, theta=-41.2354425 -> V=1.04444, theta=0.0
% INFO    : Bus 2598	: V=1.05256295, theta=-19.4315431 -> V=1.022224, theta=0.0
% INFO    : Bus 2599	: V=1.03889084, theta=-19.0031441 -> V=1.022224, theta=0.0
% INFO    : Bus 2600	: V=0.987334829, theta=-28.8137299 -> V=1.0000025, theta=0.0
% INFO    : Bus 2601	: V=1.03699175, theta=-18.5329735 -> V=0.999999, theta=0.0
% INFO    : Bus 2602	: V=0.987329397, theta=-28.8149583 -> V=1.0000025, theta=0.0
% INFO    : Bus 2603	: V=1.01510213, theta=-53.3366563 -> V=1.0079355, theta=0.0
% INFO    : Bus 2604	: V=1.01946531, theta=-24.2424835 -> V=1.022224, theta=0.0
% INFO    : Bus 2605	: V=1.02431893, theta=-32.8109609 -> V=1.022224, theta=0.0
% INFO    : Bus 2606	: V=0.985428409, theta=-21.4284387 -> V=1.0158755, theta=0.0
% INFO    : Bus 2607	: V=1.04366246, theta=-32.7442392 -> V=1.022224, theta=0.0
% INFO    : Bus 2608	: V=1.07718138, theta=-26.5715097 -> V=1.07237, theta=0.0
% INFO    : Bus 2609	: V=1.07788856, theta=-26.5738563 -> V=1.07237, theta=0.0
% INFO    : Bus 2610	: V=1.0094199, theta=-23.0769633 -> V=1.022224, theta=0.0
% INFO    : Bus 2611	: V=1.01440179, theta=-22.4557025 -> V=1.022224, theta=0.0
% INFO    : Bus 2612	: V=1.01204042, theta=-23.1720587 -> V=1.0000025, theta=0.0
% INFO    : Bus 2613	: V=1.00925561, theta=-31.9158474 -> V=1.015872, theta=0.0
% INFO    : Bus 2614	: V=1.00010247, theta=-29.5288219 -> V=1.0000025, theta=0.0
% INFO    : Bus 2615	: V=1.04829636, theta=-21.8724176 -> V=1.027779, theta=0.0
% INFO    : Bus 2616	: V=0.996499856, theta=-24.7582665 -> V=1.0000005, theta=0.0
% INFO    : Bus 2617	: V=1.02338114, theta=-26.3778101 -> V=1.000001, theta=0.0
% INFO    : Bus 2618	: V=1.01941739, theta=-35.8031893 -> V=1.022224, theta=0.0
% INFO    : Bus 2619	: V=1.05727675, theta=-10.3630361 -> V=1.0377785, theta=0.0
% INFO    : Bus 2620	: V=1.00766203, theta=-16.8076683 -> V=1.0158755, theta=0.0
% INFO    : Bus 2621	: V=1.00102777, theta=-25.4183605 -> V=1.0000025, theta=0.0
% INFO    : Bus 2622	: V=1.01025272, theta=-29.6816517 -> V=1.022224, theta=0.0
% INFO    : Bus 2623	: V=1.00833973, theta=-3.96636882 -> V=1.0158755, theta=0.0
% INFO    : Bus 2624	: V=1.00945732, theta=-25.6906522 -> V=1.0000025, theta=0.0
% INFO    : Bus 2625	: V=1.02630234, theta=-21.158229 -> V=1.022224, theta=0.0
% INFO    : Bus 2626	: V=1.06038846, theta=-7.62601083 -> V=1.0111115, theta=0.0
% INFO    : Bus 2627	: V=1.04326389, theta=-0.692166714 -> V=1.000001, theta=0.0
% INFO    : Bus 2628	: V=1.07457276, theta=2.62406328 -> V=1.0288895, theta=0.0
% INFO    : Bus 2629	: V=1.006, theta=-19.7443531 -> V=1.0158755, theta=0.0
% INFO    : Bus 2630	: V=0.973698191, theta=-25.3863156 -> V=1.0000025, theta=0.0
% INFO    : Bus 2631	: V=1.00162384, theta=-13.8053057 -> V=1.0158755, theta=0.0
% INFO    : Bus 2632	: V=1.01548269, theta=-28.4836022 -> V=1.022224, theta=0.0
% INFO    : Bus 2633	: V=1.0195653, theta=-26.3771991 -> V=1.0000025, theta=0.0
% INFO    : Bus 2634	: V=1.02657409, theta=-26.0155851 -> V=1.0000025, theta=0.0
% INFO    : Bus 2635	: V=1.04395051, theta=-7.33352398 -> V=1.0158755, theta=0.0
% INFO    : Bus 2636	: V=1.04357096, theta=-7.43310498 -> V=1.0158755, theta=0.0
% INFO    : Bus 2637	: V=1.07771872, theta=-4.46608928 -> V=1.0377785, theta=0.0
% INFO    : Bus 2638	: V=1.01459004, theta=-6.26346458 -> V=1.0158755, theta=0.0
% INFO    : Bus 2639	: V=1.00873391, theta=-12.9482894 -> V=1.0158755, theta=0.0
% INFO    : Bus 2640	: V=0.995064127, theta=-28.090934 -> V=1.0000025, theta=0.0
% INFO    : Bus 2641	: V=1.04331879, theta=-29.6244879 -> V=1.022224, theta=0.0
% INFO    : Bus 2642	: V=1.04000164, theta=-28.9928339 -> V=1.0000025, theta=0.0
% INFO    : Bus 2643	: V=1.05219377, theta=-33.3317069 -> V=0.975, theta=0.0
% INFO    : Bus 2644	: V=1.03627508, theta=-21.2733391 -> V=1.0000025, theta=0.0
% INFO    : Bus 2645	: V=1.01111824, theta=-25.0413202 -> V=1.0000025, theta=0.0
% INFO    : Bus 2646	: V=1.011, theta=-25.02941 -> V=1.0000025, theta=0.0
% INFO    : Bus 2647	: V=1.029, theta=-16.9113731 -> V=1.0000025, theta=0.0
% INFO    : Bus 2648	: V=1.0666037, theta=-29.043919 -> V=1.0000025, theta=0.0
% INFO    : Bus 2649	: V=1.07170826, theta=-18.1096691 -> V=0.975, theta=0.0
% INFO    : Bus 2650	: V=1.0718197, theta=-18.0986168 -> V=1.0, theta=0.0
% INFO    : Bus 2651	: V=1.01106042, theta=-5.72393356 -> V=1.0158755, theta=0.0
% INFO    : Bus 2652	: V=1.03977451, theta=-19.9598043 -> V=1.022224, theta=0.0
% INFO    : Bus 2653	: V=1.00458844, theta=-30.5659504 -> V=1.0000025, theta=0.0
% INFO    : Bus 2654	: V=1.066, theta=-22.0704178 -> V=1.0000025, theta=0.0
% INFO    : Bus 2655	: V=1.0723179, theta=-19.3877276 -> V=1.044445, theta=0.0
% INFO    : Bus 2656	: V=1.04954438, theta=-12.4542244 -> V=1.015874, theta=0.0
% INFO    : Bus 2657	: V=1.05520957, theta=-9.83224064 -> V=0.9888895, theta=0.0
% INFO    : Bus 2658	: V=1.05927769, theta=-6.4422139 -> V=0.9888895, theta=0.0
% INFO    : Bus 2659	: V=0.990616615, theta=-29.9021255 -> V=1.0000025, theta=0.0
% INFO    : Bus 2660	: V=0.988135432, theta=-14.6763642 -> V=1.015872, theta=0.0
% INFO    : Bus 2661	: V=1.018, theta=-11.8401555 -> V=0.999999, theta=0.0
% INFO    : Bus 2662	: V=1.009, theta=-10.5148689 -> V=1.015872, theta=0.0
% INFO    : Bus 2663	: V=1.04325491, theta=-6.69279351 -> V=1.046665, theta=0.0
% INFO    : Bus 2664	: V=1.061, theta=-21.9219795 -> V=0.975, theta=0.0
% INFO    : Bus 2665	: V=0.993, theta=-22.0425743 -> V=0.975, theta=0.0
% INFO    : Bus 2666	: V=1.078, theta=-18.3404475 -> V=0.975, theta=0.0
% INFO    : Bus 2667	: V=0.993, theta=-22.0425743 -> V=1.0000025, theta=0.0
% INFO    : Bus 2668	: V=1.07824924, theta=-18.3362656 -> V=1.006045, theta=0.0
% INFO    : Bus 2669	: V=1.02461998, theta=-38.532587 -> V=1.0079355, theta=0.0
% INFO    : Bus 2670	: V=1.03995956, theta=-37.5588165 -> V=1.022224, theta=0.0
% INFO    : Bus 2671	: V=0.557366887, theta=1.29348091 -> V=0.825, theta=0.0
% INFO    : Bus 2672	: V=1.01272962, theta=1.29348091 -> V=1.0158755, theta=0.0
% INFO    : Bus 2673	: V=1.0201538, theta=-17.4294344 -> V=1.0158755, theta=0.0
% INFO    : Bus 2674	: V=1.0201538, theta=-17.4294344 -> V=1.0158755, theta=0.0
% INFO    : Bus 2675	: V=1.01032961, theta=-22.2268044 -> V=1.0000025, theta=0.0
% INFO    : Bus 2676	: V=0.996290503, theta=-42.656401 -> V=1.0079355, theta=0.0
% INFO    : Bus 2677	: V=1.01559353, theta=-15.2642161 -> V=1.0158755, theta=0.0
% INFO    : Bus 2678	: V=1.05106761, theta=-11.5950201 -> V=1.0377785, theta=0.0
% INFO    : Bus 2679	: V=1.00547095, theta=-16.204558 -> V=1.0158755, theta=0.0
% INFO    : Bus 2680	: V=1.02307375, theta=-11.7026938 -> V=0.999999, theta=0.0
% INFO    : Bus 2681	: V=1.04758867, theta=-8.22046987 -> V=1.0111115, theta=0.0
% INFO    : Bus 2682	: V=0.992622603, theta=-21.2166474 -> V=1.0000025, theta=0.0
% INFO    : Bus 2683	: V=1.05943222, theta=-19.5952203 -> V=1.022224, theta=0.0
% INFO    : Bus 2684	: V=1.07338684, theta=-15.7249176 -> V=1.046665, theta=0.0
% INFO    : Bus 2685	: V=1.03602157, theta=-22.0865745 -> V=1.027779, theta=0.0
% INFO    : Bus 2686	: V=1.03009499, theta=-17.9880671 -> V=1.0158755, theta=0.0
% INFO    : Bus 2687	: V=1.06224945, theta=-13.5124539 -> V=1.0377785, theta=0.0
% INFO    : Bus 2688	: V=1.0276336, theta=-25.7289984 -> V=1.000001, theta=0.0
% INFO    : Bus 2689	: V=0.995786024, theta=-13.1884354 -> V=1.0158755, theta=0.0
% INFO    : Bus 2690	: V=1.06436263, theta=-11.0891046 -> V=1.033333, theta=0.0
% INFO    : Bus 2691	: V=1.01838805, theta=-18.9395195 -> V=1.0000005, theta=0.0
% INFO    : Bus 2692	: V=1.03363707, theta=-16.7732043 -> V=1.0158755, theta=0.0
% INFO    : Bus 2693	: V=1.01635337, theta=-23.39872 -> V=1.022224, theta=0.0
% INFO    : Bus 2694	: V=1.0228575, theta=-21.9392469 -> V=1.022224, theta=0.0
% INFO    : Bus 2695	: V=1.07702207, theta=-15.6057004 -> V=1.046665, theta=0.0
% INFO    : Bus 2696	: V=0.9944128, theta=-25.7339599 -> V=1.015872, theta=0.0
% INFO    : Bus 2697	: V=1.018, theta=-19.2564111 -> V=1.0000005, theta=0.0
% INFO    : Bus 2698	: V=1.02969244, theta=-10.455561 -> V=1.0158755, theta=0.0
% INFO    : Bus 2699	: V=1.0236344, theta=-21.6203082 -> V=1.022224, theta=0.0
% INFO    : Bus 2700	: V=1.0668351, theta=-13.9830441 -> V=1.027779, theta=0.0
% INFO    : Bus 2701	: V=1.02299534, theta=-45.6022725 -> V=1.0079355, theta=0.0
% INFO    : Bus 2702	: V=1.02151416, theta=-22.2068917 -> V=1.015872, theta=0.0
% INFO    : Bus 2703	: V=1.07110422, theta=-16.9797177 -> V=1.046665, theta=0.0
% INFO    : Bus 2704	: V=1.01651506, theta=-20.8189032 -> V=1.0000005, theta=0.0
% INFO    : Bus 2705	: V=1.01888027, theta=-8.79973642 -> V=0.999999, theta=0.0
% INFO    : Bus 2706	: V=1.05361465, theta=-6.56527843 -> V=1.0111115, theta=0.0
% INFO    : Bus 2707	: V=1.04464709, theta=-18.8765075 -> V=0.999999, theta=0.0
% INFO    : Bus 2708	: V=1.04470931, theta=-20.24579 -> V=0.999999, theta=0.0
% INFO    : Bus 2709	: V=1.04195733, theta=-14.108636 -> V=1.0111115, theta=0.0
% INFO    : Bus 2710	: V=1.01526451, theta=-24.5430964 -> V=1.015872, theta=0.0
% INFO    : Bus 2711	: V=1.0068474, theta=-23.1257466 -> V=1.015872, theta=0.0
% INFO    : Bus 2712	: V=1.05043828, theta=-15.8629763 -> V=1.033334, theta=0.0
% INFO    : Bus 2713	: V=1.02516682, theta=-24.2899858 -> V=1.027779, theta=0.0
% INFO    : Bus 2714	: V=1.05429277, theta=-10.7203227 -> V=1.0111115, theta=0.0
% INFO    : Bus 2715	: V=1.07147478, theta=-7.51709635 -> V=1.0377785, theta=0.0
% INFO    : Bus 2716	: V=1.08490538, theta=-4.24120658 -> V=1.072365, theta=0.0
% INFO    : Bus 2717	: V=1.04341948, theta=-30.5193569 -> V=1.022224, theta=0.0
% INFO    : Bus 2718	: V=1.02539323, theta=-25.9841692 -> V=1.022224, theta=0.0
% INFO    : Bus 2719	: V=0.995780087, theta=-30.6584898 -> V=1.0000025, theta=0.0
% INFO    : Bus 2720	: V=1.0594034, theta=-4.29327006 -> V=1.016666, theta=0.0
% INFO    : Bus 2721	: V=1.07608568, theta=-0.259998147 -> V=0.9888895, theta=0.0
% INFO    : Bus 2722	: V=1.08791192, theta=2.6851005 -> V=1.05263, theta=0.0
% INFO    : Bus 2723	: V=1.01139448, theta=-46.0804604 -> V=1.0079355, theta=0.0
% INFO    : Bus 2724	: V=1.03008801, theta=-17.2652666 -> V=1.0000025, theta=0.0
% INFO    : Bus 2725	: V=1.04610472, theta=-18.1245837 -> V=1.027779, theta=0.0
% INFO    : Bus 2726	: V=1.06846855, theta=-14.7718478 -> V=1.046665, theta=0.0
% INFO    : Bus 2727	: V=1.01215152, theta=-0.213116245 -> V=1.0158755, theta=0.0
% INFO    : Bus 2728	: V=1.06076966, theta=-16.1377532 -> V=1.033334, theta=0.0
% INFO    : Bus 2729	: V=1.07563073, theta=-21.3058153 -> V=1.000001, theta=0.0
% INFO    : Bus 2730	: V=1.04155537, theta=-29.8804418 -> V=1.022224, theta=0.0
% INFO    : Bus 2731	: V=1.04426795, theta=-13.4748386 -> V=0.999999, theta=0.0
% INFO    : Bus 2732	: V=1.02108026, theta=-30.1726768 -> V=1.022224, theta=0.0
% INFO    : Bus 2733	: V=1.0203752, theta=-19.3658767 -> V=1.0000005, theta=0.0
% INFO    : Bus 2734	: V=1.03987721, theta=-21.780269 -> V=1.027779, theta=0.0
% INFO    : Bus 2735	: V=1.06, theta=-22.5856089 -> V=1.000001, theta=0.0
% INFO    : Bus 2736	: V=1.0242313, theta=-19.2656888 -> V=1.0158755, theta=0.0
% INFO    : Bus 2737	: V=1.05869434, theta=-20.6309648 -> V=1.027779, theta=0.0
% INFO    : Bus 2738	: V=1.05649351, theta=-20.5933316 -> V=1.027779, theta=0.0
% INFO    : Bus 2739	: V=1.03449727, theta=-29.3448259 -> V=1.0000025, theta=0.0
% INFO    : Bus 2740	: V=1.01332183, theta=-11.0764897 -> V=0.999999, theta=0.0
% INFO    : Bus 2741	: V=1.04662341, theta=-18.8774795 -> V=1.022224, theta=0.0
% INFO    : Bus 2742	: V=1.0453225, theta=-18.940849 -> V=1.022224, theta=0.0
% INFO    : Bus 2743	: V=0.980346275, theta=-18.1669596 -> V=1.0158755, theta=0.0
% INFO    : Bus 2744	: V=0.994812287, theta=-8.42065962 -> V=1.0158755, theta=0.0
% INFO    : Bus 2745	: V=1.06380476, theta=-0.80340417 -> V=1.0377785, theta=0.0
% INFO    : Bus 2746	: V=1.05060727, theta=-16.7364908 -> V=0.999999, theta=0.0
% INFO    : Bus 2747	: V=1.01332509, theta=-12.5225009 -> V=1.015872, theta=0.0
% INFO    : Bus 2748	: V=1.03806846, theta=-10.7721638 -> V=1.000001, theta=0.0
% INFO    : Bus 2749	: V=1.06101122, theta=-19.4689945 -> V=1.000001, theta=0.0
% INFO    : Bus 2750	: V=1.08275222, theta=-17.3670932 -> V=1.044445, theta=0.0
% INFO    : Bus 2751	: V=1.02589655, theta=-28.0809121 -> V=1.022224, theta=0.0
% INFO    : Bus 2752	: V=1.02074771, theta=-21.1846191 -> V=1.0000005, theta=0.0
% INFO    : Bus 2753	: V=1.04042579, theta=-23.1400829 -> V=1.0000025, theta=0.0
% INFO    : Bus 2754	: V=1.02833452, theta=-18.8109803 -> V=0.999999, theta=0.0
% INFO    : Bus 2755	: V=1.06150518, theta=-15.4986589 -> V=1.0111115, theta=0.0
% INFO    : Bus 2756	: V=1.0146018, theta=-22.7621714 -> V=1.0000005, theta=0.0
% INFO    : Bus 2757	: V=0.993217463, theta=-12.4976694 -> V=0.999999, theta=0.0
% INFO    : Bus 2758	: V=1.01177495, theta=-22.8893545 -> V=1.0000005, theta=0.0
% INFO    : Bus 2759	: V=1.02418719, theta=2.94905539 -> V=1.0158755, theta=0.0
% INFO    : Bus 2760	: V=1.04253748, theta=-13.6086782 -> V=1.027779, theta=0.0
% INFO    : Bus 2761	: V=1.02308786, theta=-15.6846658 -> V=1.0000005, theta=0.0
% INFO    : Bus 2762	: V=1.03696275, theta=-2.08671105 -> V=1.0000025, theta=0.0
% INFO    : Bus 2763	: V=1.05867055, theta=-0.495228146 -> V=1.0377785, theta=0.0
% INFO    : Bus 2764	: V=1.07347781, theta=2.20534033 -> V=1.072365, theta=0.0
% INFO    : Bus 2765	: V=1.00935992, theta=-13.4841258 -> V=0.999999, theta=0.0
% INFO    : Bus 2766	: V=1.12040041, theta=5.61967046 -> V=1.0424455, theta=0.0
% INFO    : Bus 2767	: V=1.04782041, theta=-12.432127 -> V=1.0000025, theta=0.0
% INFO    : Bus 2768	: V=1.0401449, theta=-24.4887171 -> V=1.0000025, theta=0.0
% INFO    : Bus 2769	: V=0.943138968, theta=-14.1140083 -> V=0.975, theta=0.0
% INFO    : Bus 2770	: V=1.03770745, theta=-15.8139294 -> V=1.022224, theta=0.0
% INFO    : Bus 2771	: V=1.07010521, theta=-13.7592914 -> V=1.04444, theta=0.0
% INFO    : Bus 2772	: V=1.08777469, theta=-8.66293254 -> V=1.07237, theta=0.0
% INFO    : Bus 2773	: V=1.0328522, theta=-22.9986185 -> V=1.027779, theta=0.0
% INFO    : Bus 2774	: V=1.0126313, theta=-7.63918068 -> V=1.0158755, theta=0.0
% INFO    : Bus 2775	: V=1.03790373, theta=-13.0918333 -> V=0.999999, theta=0.0
% INFO    : Bus 2776	: V=1.02231396, theta=-10.2345125 -> V=1.0111115, theta=0.0
% INFO    : Bus 2777	: V=1.03211583, theta=-6.81162904 -> V=1.0158755, theta=0.0
% INFO    : Bus 2778	: V=1.06464368, theta=-4.20334923 -> V=1.0377785, theta=0.0
% INFO    : Bus 2779	: V=1.03253901, theta=-31.6879645 -> V=1.0000025, theta=0.0
% INFO    : Bus 2780	: V=1.03522155, theta=-21.0238944 -> V=1.0000025, theta=0.0
% INFO    : Bus 2781	: V=1.04405508, theta=-23.3979213 -> V=1.0000025, theta=0.0
% INFO    : Bus 2782	: V=1.07445739, theta=-19.1672677 -> V=1.044445, theta=0.0
% INFO    : Bus 2783	: V=1.08343581, theta=-18.0039416 -> V=1.078945, theta=0.0
% INFO    : Bus 2784	: V=1.03593939, theta=-21.3162015 -> V=1.027779, theta=0.0
% INFO    : Bus 2785	: V=1.07157919, theta=-40.1549806 -> V=1.04444, theta=0.0
% INFO    : Bus 2786	: V=1.07548782, theta=-35.7347797 -> V=1.07237, theta=0.0
% INFO    : Bus 2787	: V=1.0724759, theta=-37.5146774 -> V=1.07237, theta=0.0
% INFO    : Bus 2788	: V=1.00920394, theta=-41.1457879 -> V=1.0079355, theta=0.0
% INFO    : Bus 2789	: V=1.05558635, theta=-23.8938494 -> V=1.0000025, theta=0.0
% INFO    : Bus 2790	: V=1.03906824, theta=-8.61849769 -> V=1.0158755, theta=0.0
% INFO    : Bus 2791	: V=1.04835578, theta=-22.5304269 -> V=1.0000025, theta=0.0
% INFO    : Bus 2792	: V=1.06768917, theta=-17.6215684 -> V=1.044445, theta=0.0
% INFO    : Bus 2793	: V=1.02473486, theta=-21.2781207 -> V=0.999999, theta=0.0
% INFO    : Bus 2794	: V=1.0589945, theta=-20.60918 -> V=1.027779, theta=0.0
% INFO    : Bus 2795	: V=1.06957112, theta=-17.453161 -> V=1.046665, theta=0.0
% INFO    : Bus 2796	: V=1.07873213, theta=-17.8948746 -> V=1.046665, theta=0.0
% INFO    : Bus 2797	: V=1.07768319, theta=-6.45370197 -> V=1.016666, theta=0.0
% INFO    : Bus 2798	: V=1.07146259, theta=-4.09523704 -> V=1.022223, theta=0.0
% INFO    : Bus 2799	: V=1.07041751, theta=-0.123465722 -> V=1.05263, theta=0.0
% INFO    : Bus 2800	: V=1.02688594, theta=-16.040135 -> V=0.999999, theta=0.0
% INFO    : Bus 2801	: V=1.03491403, theta=-26.0166976 -> V=1.022224, theta=0.0
% INFO    : Bus 2802	: V=0.998235565, theta=-26.1114123 -> V=1.0000025, theta=0.0
% INFO    : Bus 2803	: V=1.02550663, theta=-16.4105631 -> V=1.0000005, theta=0.0
% INFO    : Bus 2804	: V=0.977115438, theta=-4.75814255 -> V=1.0000015, theta=0.0
% INFO    : Bus 2805	: V=0.97525353, theta=-4.65744276 -> V=1.0000015, theta=0.0
% INFO    : Bus 2806	: V=1.060187, theta=-7.38921125 -> V=1.022222, theta=0.0
% INFO    : Bus 2807	: V=1.06153855, theta=-4.38500989 -> V=0.9888895, theta=0.0
% INFO    : Bus 2808	: V=1.00420547, theta=-28.8999646 -> V=1.0000025, theta=0.0
% INFO    : Bus 2809	: V=1.00150474, theta=-48.4041886 -> V=1.0079355, theta=0.0
% INFO    : Bus 2810	: V=1.037354, theta=-35.7912285 -> V=1.022224, theta=0.0
% INFO    : Bus 2811	: V=1.05344966, theta=-31.8535031 -> V=1.04444, theta=0.0
% INFO    : Bus 2812	: V=1.00537051, theta=-23.1322466 -> V=1.0000025, theta=0.0
% INFO    : Bus 2813	: V=1.02615833, theta=-36.0461669 -> V=1.022224, theta=0.0
% INFO    : Bus 2814	: V=1.01926127, theta=-7.08152759 -> V=0.984126, theta=0.0
% INFO    : Bus 2815	: V=1.05562936, theta=-22.8427868 -> V=1.000001, theta=0.0
% INFO    : Bus 2816	: V=1.06051017, theta=-18.805041 -> V=1.044445, theta=0.0
% INFO    : Bus 2817	: V=1.05586613, theta=-19.9014797 -> V=1.000001, theta=0.0
% INFO    : Bus 2818	: V=1.03084472, theta=-23.5156268 -> V=1.0000025, theta=0.0
% INFO    : Bus 2819	: V=1.06365993, theta=-27.227447 -> V=1.0000025, theta=0.0
% INFO    : Bus 2820	: V=1.02993624, theta=2.16402281 -> V=1.0158755, theta=0.0
% INFO    : Bus 2821	: V=1.07881352, theta=6.08879557 -> V=1.0390685, theta=0.0
% INFO    : Bus 2822	: V=1.07878743, theta=6.09158283 -> V=1.0390585, theta=0.0
% INFO    : Bus 2823	: V=1.02936043, theta=-33.9807536 -> V=1.022224, theta=0.0
% INFO    : Bus 2824	: V=1.02021283, theta=-32.6580418 -> V=1.0000025, theta=0.0
% INFO    : Bus 2825	: V=1.00262248, theta=-25.2840317 -> V=1.0000025, theta=0.0
% INFO    : Bus 2826	: V=1.04579727, theta=-19.3426131 -> V=1.046665, theta=0.0
% INFO    : Bus 2827	: V=1.03101169, theta=-19.0917554 -> V=0.999999, theta=0.0
% INFO    : Bus 2828	: V=1.03718766, theta=-15.8952361 -> V=1.0111115, theta=0.0
% INFO    : Bus 2829	: V=1.01692426, theta=-31.6579193 -> V=1.022224, theta=0.0
% INFO    : Bus 2830	: V=1.02842089, theta=-17.5304904 -> V=1.022224, theta=0.0
% INFO    : Bus 2831	: V=1.04808036, theta=-7.07951297 -> V=0.9888895, theta=0.0
% INFO    : Bus 2832	: V=1.07862308, theta=3.52009696 -> V=0.9907595, theta=0.0
% INFO    : Bus 2833	: V=1.08041162, theta=5.88332032 -> V=1.05263, theta=0.0
% INFO    : Bus 2834	: V=1.035, theta=-19.3532106 -> V=1.0000005, theta=0.0
% INFO    : Bus 2835	: V=0.994669524, theta=-25.7216487 -> V=1.015872, theta=0.0
% INFO    : Bus 2836	: V=1.03268966, theta=-25.1774015 -> V=1.0000025, theta=0.0
% INFO    : Bus 2837	: V=1.05524247, theta=-21.1706427 -> V=1.0000025, theta=0.0
% INFO    : Bus 2838	: V=1.03919981, theta=-23.7245849 -> V=1.0000025, theta=0.0
% INFO    : Bus 2839	: V=1.05978841, theta=-15.0820989 -> V=1.033334, theta=0.0
% INFO    : Bus 2840	: V=1.01276356, theta=-14.4165374 -> V=0.999999, theta=0.0
% INFO    : Bus 2841	: V=1.04140571, theta=-16.8725643 -> V=1.022224, theta=0.0
% INFO    : Bus 2842	: V=1.024885, theta=-6.57084826 -> V=1.0158755, theta=0.0
% INFO    : Bus 2843	: V=1.04872185, theta=-46.7489983 -> V=1.0079355, theta=0.0
% INFO    : Bus 2844	: V=1.00840085, theta=-26.9520602 -> V=1.022224, theta=0.0
% INFO    : Bus 2845	: V=1.01556749, theta=-18.3375307 -> V=1.0000005, theta=0.0
% INFO    : Bus 2846	: V=1.01459133, theta=-24.3315341 -> V=0.999999, theta=0.0
% INFO    : Bus 2847	: V=1.01588454, theta=-26.2175284 -> V=1.000001, theta=0.0
% INFO    : Bus 2848	: V=1.00094287, theta=-27.9306233 -> V=1.015872, theta=0.0
% INFO    : Bus 2849	: V=1.02384186, theta=-23.0113919 -> V=1.046665, theta=0.0
% INFO    : Bus 2850	: V=1.0956381, theta=-12.1620734 -> V=1.073685, theta=0.0
% INFO    : Bus 2851	: V=1.00970776, theta=-11.8842394 -> V=0.999999, theta=0.0
% INFO    : Bus 2852	: V=1.07859849, theta=-18.602855 -> V=1.046665, theta=0.0
% INFO    : Bus 2853	: V=1.06911358, theta=-19.0012064 -> V=1.046665, theta=0.0
% INFO    : Bus 2854	: V=1.00971221, theta=-22.1339345 -> V=1.0000005, theta=0.0
% INFO    : Bus 2855	: V=1.02340885, theta=-12.68815 -> V=0.999999, theta=0.0
% INFO    : Bus 2856	: V=1.04691656, theta=-9.69072006 -> V=1.0111115, theta=0.0
% INFO    : Bus 2857	: V=1.03336868, theta=-26.3413611 -> V=1.0000025, theta=0.0
% INFO    : Bus 2858	: V=1.02904902, theta=-45.3402896 -> V=1.0079355, theta=0.0
% INFO    : Bus 2859	: V=1.01201104, theta=-29.6407357 -> V=1.0000025, theta=0.0
% INFO    : Bus 2860	: V=1.01253914, theta=-29.5735513 -> V=1.0000025, theta=0.0
% INFO    : Bus 2861	: V=1.07450839, theta=-23.8876214 -> V=1.044445, theta=0.0
% INFO    : Bus 2862	: V=1.04094007, theta=-23.3268213 -> V=1.0000025, theta=0.0
% INFO    : Bus 2863	: V=1.01936155, theta=-20.7131691 -> V=1.015872, theta=0.0
% INFO    : Bus 2864	: V=1.06587621, theta=-38.7132154 -> V=1.022654, theta=0.0
% INFO    : Bus 2865	: V=1.07817946, theta=-35.5260603 -> V=1.04444, theta=0.0
% INFO    : Bus 2866	: V=1.04128807, theta=-10.7755569 -> V=0.999999, theta=0.0
% INFO    : Bus 2867	: V=1.03992782, theta=-10.7864824 -> V=0.999999, theta=0.0
% INFO    : Bus 2868	: V=1.0328478, theta=-10.7104921 -> V=0.999999, theta=0.0
% INFO    : Bus 2869	: V=1.01852993, theta=-24.891762 -> V=1.022224, theta=0.0
% INFO    : Bus 2870	: V=1.05206866, theta=-12.6799285 -> V=1.000001, theta=0.0
% INFO    : Bus 2871	: V=0.988664208, theta=-22.5881689 -> V=1.0158755, theta=0.0
% INFO    : Bus 2872	: V=0.988854395, theta=-23.9965646 -> V=1.0000005, theta=0.0
% INFO    : Bus 2873	: V=0.997816997, theta=-37.1431429 -> V=1.022224, theta=0.0
% INFO    : Bus 2874	: V=1.0150563, theta=-18.7781564 -> V=1.0158755, theta=0.0
% INFO    : Bus 2875	: V=1.05969258, theta=-24.9003652 -> V=1.027779, theta=0.0
% INFO    : Bus 2876	: V=1.03616888, theta=-1.98940003 -> V=1.0000025, theta=0.0
% INFO    : Bus 2877	: V=1.01693936, theta=-37.5728741 -> V=1.022224, theta=0.0
% INFO    : Bus 2878	: V=1.02170734, theta=-20.6828035 -> V=1.015872, theta=0.0
% INFO    : Bus 2879	: V=1.00207887, theta=-0.652161211 -> V=1.0158755, theta=0.0
% INFO    : Bus 2880	: V=1.04907092, theta=-19.918761 -> V=1.022224, theta=0.0
% INFO    : Bus 2881	: V=1.0527922, theta=-9.68595403 -> V=1.0111115, theta=0.0
% INFO    : Bus 2882	: V=1.0485893, theta=-14.6076323 -> V=1.0000025, theta=0.0
% INFO    : Bus 2883	: V=0.985891541, theta=-22.5468686 -> V=1.0158755, theta=0.0
% INFO    : Bus 2884	: V=1.0076533, theta=-16.4596713 -> V=0.999999, theta=0.0
% INFO    : Bus 2885	: V=1.02612408, theta=2.56602882 -> V=1.0158755, theta=0.0
% INFO    : Bus 2886	: V=1.02310605, theta=-13.403194 -> V=0.999999, theta=0.0
% INFO    : Bus 2887	: V=1.04501693, theta=-28.282978 -> V=1.0000025, theta=0.0
% INFO    : Bus 2888	: V=0.999590003, theta=-21.9895483 -> V=1.015872, theta=0.0
% INFO    : Bus 2889	: V=1.00428829, theta=-11.3720058 -> V=1.015872, theta=0.0
% INFO    : Bus 2890	: V=1.02149698, theta=-12.2791911 -> V=0.999999, theta=0.0
% INFO    : Bus 2891	: V=1.02279453, theta=-14.1143976 -> V=0.999999, theta=0.0
% INFO    : Bus 2892	: V=1.05735235, theta=-8.43274237 -> V=1.0111115, theta=0.0
% INFO    : Bus 2893	: V=1.06414672, theta=-17.8303124 -> V=1.046665, theta=0.0
% INFO    : Bus 2894	: V=1.07160826, theta=-13.547562 -> V=1.073685, theta=0.0
% INFO    : Bus 2895	: V=1.04673131, theta=-20.9985278 -> V=1.022224, theta=0.0
% INFO    : Bus 2896	: V=1.04184895, theta=-21.3939542 -> V=0.999999, theta=0.0
% INFO    : Bus 2897	: V=1.0377308, theta=-26.5809038 -> V=1.0000025, theta=0.0
% INFO    : Bus 2898	: V=1.00439938, theta=-4.77948794 -> V=1.0158755, theta=0.0
% INFO    : Bus 2899	: V=1.02230402, theta=-28.6268574 -> V=1.0000025, theta=0.0
% INFO    : Bus 2900	: V=1.066, theta=-18.6866651 -> V=0.975, theta=0.0
% INFO    : Bus 2901	: V=1.07844765, theta=-16.763632 -> V=1.001385, theta=0.0
% INFO    : Bus 2902	: V=1.07260634, theta=-19.5133594 -> V=1.044445, theta=0.0
% INFO    : Bus 2903	: V=1.00152681, theta=-18.3234638 -> V=1.0158755, theta=0.0
% INFO    : Bus 2904	: V=1.04720981, theta=-20.123571 -> V=1.022224, theta=0.0
% INFO    : Bus 2905	: V=1.07318772, theta=-17.8719966 -> V=1.0, theta=0.0
% INFO    : Bus 2906	: V=1.01075579, theta=-13.1529158 -> V=0.999999, theta=0.0
% INFO    : Bus 2907	: V=0.998321709, theta=-29.1465298 -> V=1.0000025, theta=0.0
% INFO    : Bus 2908	: V=1.0146468, theta=1.22100056 -> V=1.0158755, theta=0.0
% INFO    : Bus 2909	: V=1.03708301, theta=-27.0767453 -> V=1.0000025, theta=0.0
% INFO    : Bus 2910	: V=1.03928929, theta=-26.8448883 -> V=1.0000025, theta=0.0
% INFO    : Bus 2911	: V=1.01676144, theta=-28.7481018 -> V=1.022224, theta=0.0
% INFO    : Bus 2912	: V=1.02176066, theta=-45.4126636 -> V=1.0079355, theta=0.0
% INFO    : Bus 2913	: V=1.02813359, theta=-27.9186313 -> V=1.022224, theta=0.0
% INFO    : Bus 2914	: V=1.02295146, theta=-12.2421597 -> V=0.999999, theta=0.0
% INFO    : Bus 2915	: V=1.05378115, theta=-7.81917135 -> V=1.0111115, theta=0.0
% INFO    : Bus 2916	: V=1.04992479, theta=-7.8889839 -> V=1.0111115, theta=0.0
% INFO    : Bus 2917	: V=1.05820903, theta=-7.63906728 -> V=1.0111115, theta=0.0
% INFO    : Bus 2918	: V=1.06895273, theta=-3.71135274 -> V=1.072365, theta=0.0
% INFO    : Bus 2919	: V=1.02732459, theta=-22.4390836 -> V=1.015872, theta=0.0
% INFO    : Bus 2920	: V=1.02698886, theta=-25.1181521 -> V=1.0000025, theta=0.0
% INFO    : Bus 2921	: V=1.02733677, theta=-22.4383974 -> V=1.015872, theta=0.0
% INFO    : Bus 2922	: V=1.01077721, theta=-26.7894803 -> V=1.0000025, theta=0.0
% INFO    : Bus 2923	: V=1.02055828, theta=-22.7500694 -> V=1.022224, theta=0.0
% INFO    : Bus 2924	: V=1.0151778, theta=-6.9812391 -> V=1.0158755, theta=0.0
% INFO    : Bus 2925	: V=1.03040076, theta=-27.867979 -> V=1.0000025, theta=0.0
% INFO    : Bus 2926	: V=1.02323535, theta=-20.5360816 -> V=1.0000025, theta=0.0
% INFO    : Bus 2927	: V=1.02240013, theta=-14.3157808 -> V=0.999999, theta=0.0
% INFO    : Bus 2928	: V=1.04966761, theta=-23.3740704 -> V=1.0000025, theta=0.0
% INFO    : Bus 2929	: V=1.0055557, theta=-12.0601599 -> V=0.999999, theta=0.0
% INFO    : Bus 2930	: V=1.04476786, theta=-11.499954 -> V=1.000001, theta=0.0
% INFO    : Bus 2931	: V=1.04043298, theta=-1.15119767 -> V=1.0000025, theta=0.0
% INFO    : Bus 2932	: V=1.07383042, theta=2.48387431 -> V=0.9888895, theta=0.0
% INFO    : Bus 2933	: V=1.0742599, theta=2.5124007 -> V=0.9888895, theta=0.0
% INFO    : Bus 2934	: V=1.06363198, theta=-15.4082243 -> V=1.046665, theta=0.0
% INFO    : Bus 2935	: V=0.976615455, theta=-22.7601447 -> V=0.999999, theta=0.0
% INFO    : Bus 2936	: V=1.0278631, theta=-13.7187179 -> V=0.999999, theta=0.0
% INFO    : Bus 2937	: V=1.02627215, theta=-14.0688051 -> V=0.999999, theta=0.0
% INFO    : Bus 2938	: V=1.04400187, theta=-10.446758 -> V=1.0111115, theta=0.0
% INFO    : Bus 2939	: V=1.03966635, theta=-10.5842534 -> V=0.999999, theta=0.0
% INFO    : Bus 2940	: V=1.08167071, theta=-15.5415944 -> V=1.046665, theta=0.0
% INFO    : Bus 2941	: V=1.00913012, theta=-24.3297571 -> V=1.0000025, theta=0.0
% INFO    : Bus 2942	: V=1.00792662, theta=-24.4821476 -> V=1.022224, theta=0.0
% INFO    : Bus 2943	: V=1.0257851, theta=-20.5318412 -> V=1.015872, theta=0.0
% INFO    : Bus 2944	: V=1.02578019, theta=-20.5325273 -> V=1.015872, theta=0.0
% INFO    : Bus 2945	: V=1.06101532, theta=-19.4680747 -> V=1.000001, theta=0.0
% INFO    : Bus 2946	: V=1.08275222, theta=-17.3670932 -> V=1.044445, theta=0.0
% INFO    : Bus 2947	: V=1.02484406, theta=-28.5302084 -> V=1.022224, theta=0.0
% INFO    : Bus 2948	: V=1.08107014, theta=-22.8552879 -> V=1.07237, theta=0.0
% INFO    : Bus 2949	: V=1.00812355, theta=-22.9553012 -> V=1.0158755, theta=0.0
% INFO    : Bus 2950	: V=0.979431297, theta=-22.8385961 -> V=1.0158755, theta=0.0
% INFO    : Bus 2951	: V=1.01206858, theta=-6.15913713 -> V=1.0158755, theta=0.0
% INFO    : Bus 2952	: V=1.05453188, theta=-0.940853832 -> V=1.0377785, theta=0.0
% INFO    : Bus 2953	: V=1.05455248, theta=-0.938751342 -> V=1.0377785, theta=0.0
% INFO    : Bus 2954	: V=1.01115582, theta=-24.6745713 -> V=0.999999, theta=0.0
% INFO    : Bus 2955	: V=1.04364698, theta=-34.4387588 -> V=1.022224, theta=0.0
% INFO    : Bus 2956	: V=0.989655027, theta=-0.783269038 -> V=1.0158755, theta=0.0
% INFO    : Bus 2957	: V=1.04717482, theta=-30.4839719 -> V=1.022224, theta=0.0
% INFO    : Bus 2958	: V=1.00838973, theta=-12.3490842 -> V=1.015872, theta=0.0
% INFO    : Bus 2959	: V=1.02503971, theta=-24.3083231 -> V=1.0000025, theta=0.0
% INFO    : Bus 2960	: V=1.07260029, theta=-18.9317093 -> V=1.0, theta=0.0
% INFO    : Bus 2961	: V=1.017109, theta=-25.6947164 -> V=1.022224, theta=0.0
% INFO    : Bus 2962	: V=1.0261424, theta=-21.5145604 -> V=1.0000025, theta=0.0
% INFO    : Bus 2963	: V=1.05642585, theta=-28.1114303 -> V=1.022224, theta=0.0
% INFO    : Bus 2964	: V=1.07694886, theta=-13.9687685 -> V=1.046665, theta=0.0
% INFO    : Bus 2965	: V=1.08366416, theta=-15.0703554 -> V=1.04695, theta=0.0
% INFO    : Bus 2966	: V=1.03256618, theta=-15.4613945 -> V=0.975, theta=0.0
% INFO    : Bus 2967	: V=1.08417197, theta=-15.8900093 -> V=1.04679, theta=0.0
% INFO    : Bus 2968	: V=1.08367413, theta=-15.0678518 -> V=1.046955, theta=0.0
% INFO    : Bus 2969	: V=1.07693432, theta=-13.9673091 -> V=1.046665, theta=0.0
% INFO    : Bus 2970	: V=1.07962141, theta=-10.2411287 -> V=1.073685, theta=0.0
% INFO    : Bus 2971	: V=1.07852179, theta=-10.7886685 -> V=1.073685, theta=0.0
% INFO    : Bus 2972	: V=1.07007422, theta=-21.3228733 -> V=1.0000025, theta=0.0
% INFO    : Bus 2973	: V=1.02005455, theta=-24.2930278 -> V=1.0000025, theta=0.0
% INFO    : Bus 2974	: V=1.05412168, theta=-19.1584658 -> V=1.044445, theta=0.0
% INFO    : Bus 2975	: V=1.02630929, theta=-15.4606038 -> V=0.999999, theta=0.0
% INFO    : Bus 2976	: V=0.984270797, theta=-19.2691442 -> V=0.999999, theta=0.0
% INFO    : Bus 2977	: V=1.02655775, theta=-10.3360399 -> V=1.0158755, theta=0.0
% INFO    : Bus 2978	: V=1.0358356, theta=-23.1199034 -> V=1.027779, theta=0.0
% INFO    : Bus 2979	: V=1.01596374, theta=-38.3517217 -> V=1.022224, theta=0.0
% INFO    : Bus 2980	: V=1.02809873, theta=-29.0462734 -> V=1.022224, theta=0.0
% INFO    : Bus 2981	: V=1.01941692, theta=-47.3738129 -> V=1.0079355, theta=0.0
% INFO    : Bus 2982	: V=1.04713573, theta=-10.0358431 -> V=1.0000025, theta=0.0
% INFO    : Bus 2983	: V=1.03161044, theta=-10.4886281 -> V=1.0000025, theta=0.0
% INFO    : Bus 2984	: V=1.05589234, theta=-29.2201076 -> V=1.027779, theta=0.0
% INFO    : Bus 2985	: V=1.05345386, theta=-14.9199719 -> V=1.027779, theta=0.0
% INFO    : Bus 2986	: V=1.01552919, theta=-18.1920917 -> V=1.0000005, theta=0.0
% INFO    : Bus 2987	: V=1.06097793, theta=-14.4324224 -> V=1.046665, theta=0.0
% INFO    : Bus 2988	: V=1.03764017, theta=-22.0413477 -> V=1.027779, theta=0.0
% INFO    : Bus 2989	: V=1.02273876, theta=-22.6330323 -> V=0.999999, theta=0.0
% INFO    : Bus 2990	: V=1.02259546, theta=-15.1758979 -> V=1.015872, theta=0.0
% INFO    : Bus 2991	: V=1.04369362, theta=-12.0373168 -> V=1.046665, theta=0.0
% INFO    : Bus 2992	: V=1.05737649, theta=-16.7631352 -> V=1.000239, theta=0.0
% INFO    : Bus 2993	: V=1.00642645, theta=-10.7009043 -> V=0.999999, theta=0.0
% INFO    : Bus 2994	: V=1.05758943, theta=-3.94850378 -> V=1.022222, theta=0.0
% INFO    : Bus 2995	: V=1.033, theta=-11.19488 -> V=0.999999, theta=0.0
% INFO    : Bus 2996	: V=1.04249279, theta=-10.3996418 -> V=0.975, theta=0.0
% INFO    : Bus 2997	: V=1.04145134, theta=-10.3996418 -> V=0.999999, theta=0.0
% INFO    : Bus 2998	: V=1.03337085, theta=-10.6031716 -> V=0.999999, theta=0.0
% INFO    : Bus 2999	: V=1.05390363, theta=-7.81985107 -> V=1.0111115, theta=0.0
% INFO    : Bus 3000	: V=1.04705372, theta=-8.57857839 -> V=1.0111115, theta=0.0
% INFO    : Bus 3001	: V=1.01992538, theta=-31.091834 -> V=1.015872, theta=0.0
% INFO    : Bus 3002	: V=1.0532785, theta=-27.8224297 -> V=1.046665, theta=0.0
% INFO    : Bus 3003	: V=1.06976464, theta=-23.5684955 -> V=1.0000025, theta=0.0
% INFO    : Bus 3004	: V=1.08177745, theta=-17.028835 -> V=1.044445, theta=0.0
% INFO    : Bus 3005	: V=1.01773292, theta=-30.6542598 -> V=1.0000025, theta=0.0
% INFO    : Bus 3006	: V=1.04367532, theta=-13.2109724 -> V=1.046665, theta=0.0
% INFO    : Bus 3007	: V=1.03246454, theta=-22.660338 -> V=1.000001, theta=0.0
% INFO    : Bus 3008	: V=1.07865079, theta=-18.5483384 -> V=1.046665, theta=0.0
% INFO    : Bus 3009	: V=0.995743625, theta=-31.6900127 -> V=1.0000025, theta=0.0
% INFO    : Bus 3010	: V=1.02931984, theta=2.88567748 -> V=1.0158755, theta=0.0
% INFO    : Bus 3011	: V=1.07843788, theta=5.85740673 -> V=1.0385535, theta=0.0
% INFO    : Bus 3012	: V=1.08557659, theta=7.90923286 -> V=1.072365, theta=0.0
% INFO    : Bus 3013	: V=1.00680512, theta=1.29145275 -> V=1.0158755, theta=0.0
% INFO    : Bus 3014	: V=1.03855498, theta=-29.8386448 -> V=1.0000025, theta=0.0
% INFO    : Bus 3015	: V=1.00424598, theta=-12.1527189 -> V=0.999999, theta=0.0
% INFO    : Bus 3016	: V=1.01919252, theta=-10.7069388 -> V=1.0158755, theta=0.0
% INFO    : Bus 3017	: V=1.06219534, theta=-19.3876886 -> V=1.022829, theta=0.0
% INFO    : Bus 3018	: V=1.06572106, theta=-15.7280049 -> V=1.04444, theta=0.0
% INFO    : Bus 3019	: V=1.01207974, theta=-19.1626631 -> V=1.015872, theta=0.0
% INFO    : Bus 3020	: V=1.06686309, theta=-23.8728187 -> V=1.0000025, theta=0.0
% INFO    : Bus 3021	: V=1.05442705, theta=-28.3116603 -> V=1.022224, theta=0.0
% INFO    : Bus 3022	: V=1.00257468, theta=-16.1450522 -> V=1.0158755, theta=0.0
% INFO    : Bus 3023	: V=1.016, theta=-9.90844535 -> V=0.999999, theta=0.0
% INFO    : Bus 3024	: V=1.02161302, theta=-1.68941359 -> V=1.0000025, theta=0.0
% INFO    : Bus 3025	: V=1.02198203, theta=-35.9939507 -> V=1.022224, theta=0.0
% INFO    : Bus 3026	: V=1.02666967, theta=-6.5224469 -> V=1.0158755, theta=0.0
% INFO    : Bus 3027	: V=1.02664704, theta=-6.51839154 -> V=1.0158755, theta=0.0
% INFO    : Bus 3028	: V=1.04752368, theta=-12.3210805 -> V=1.0000025, theta=0.0
% INFO    : Bus 3029	: V=1.02373495, theta=-28.564737 -> V=1.015872, theta=0.0
% INFO    : Bus 3030	: V=1.06289395, theta=-6.8138845 -> V=1.022222, theta=0.0
% INFO    : Bus 3031	: V=1.04382391, theta=-19.3567884 -> V=1.0000025, theta=0.0
% INFO    : Bus 3032	: V=1.07576438, theta=-15.8357994 -> V=1.044445, theta=0.0
% INFO    : Bus 3033	: V=1.08508807, theta=-10.8433401 -> V=1.078945, theta=0.0
% INFO    : Bus 3034	: V=0.999330656, theta=-24.0300681 -> V=1.015872, theta=0.0
% INFO    : Bus 3035	: V=1.01920272, theta=-25.3873726 -> V=1.0000025, theta=0.0
% INFO    : Bus 3036	: V=1.04906834, theta=-25.6723661 -> V=1.0000025, theta=0.0
% INFO    : Bus 3037	: V=1.01656294, theta=-11.2937036 -> V=1.015872, theta=0.0
% INFO    : Bus 3038	: V=0.981298635, theta=-23.1597533 -> V=1.0158755, theta=0.0
% INFO    : Bus 3039	: V=1.06341601, theta=-19.3492606 -> V=1.044445, theta=0.0
% INFO    : Bus 3040	: V=1.01367068, theta=-22.5542441 -> V=1.0000005, theta=0.0
% INFO    : Bus 3041	: V=1.03534498, theta=-14.1965114 -> V=0.999999, theta=0.0
% INFO    : Bus 3042	: V=1.01706164, theta=-23.3366736 -> V=1.0000025, theta=0.0
% INFO    : Bus 3043	: V=1.01352016, theta=-23.8960537 -> V=1.0000025, theta=0.0
% INFO    : Bus 3044	: V=1.01526443, theta=-17.262726 -> V=1.0158755, theta=0.0
% INFO    : Bus 3045	: V=1.03252734, theta=-16.9027192 -> V=1.0158755, theta=0.0
% INFO    : Bus 3046	: V=1.05863411, theta=-28.2384585 -> V=1.022224, theta=0.0
% INFO    : Bus 3047	: V=1.06214596, theta=-25.1549536 -> V=1.0000025, theta=0.0
% INFO    : Bus 3048	: V=1.05328418, theta=-6.85212911 -> V=0.9888895, theta=0.0
% INFO    : Bus 3049	: V=1.01868287, theta=-18.4983276 -> V=1.015872, theta=0.0
% INFO    : Bus 3050	: V=0.996872932, theta=-12.6662498 -> V=1.015872, theta=0.0
% INFO    : Bus 3051	: V=1.04022695, theta=-24.0129252 -> V=1.022224, theta=0.0
% INFO    : Bus 3052	: V=1.02347148, theta=-14.2515019 -> V=0.999999, theta=0.0
% INFO    : Bus 3053	: V=1.00380413, theta=-19.4134722 -> V=1.0000005, theta=0.0
% INFO    : Bus 3054	: V=1.01753273, theta=-19.1914456 -> V=1.0000005, theta=0.0
% INFO    : Bus 3055	: V=1.07289341, theta=-12.9239956 -> V=1.046665, theta=0.0
% INFO    : Bus 3056	: V=1.07289363, theta=-12.923998 -> V=1.046665, theta=0.0
% INFO    : Bus 3057	: V=1.08429548, theta=-13.9054344 -> V=1.078945, theta=0.0
% INFO    : Bus 3058	: V=1.08430343, theta=-13.9055038 -> V=1.078945, theta=0.0
% INFO    : Bus 3059	: V=1.08430333, theta=-13.905503 -> V=1.078945, theta=0.0
% INFO    : Bus 3060	: V=1.01596424, theta=-21.6952501 -> V=0.999999, theta=0.0
% INFO    : Bus 3061	: V=1.03349502, theta=-38.0608708 -> V=1.022224, theta=0.0
% INFO    : Bus 3062	: V=1.0032817, theta=-23.3350577 -> V=1.0000005, theta=0.0
% INFO    : Bus 3063	: V=1.0014433, theta=-24.5296414 -> V=1.0000005, theta=0.0
% INFO    : Bus 3064	: V=1.04071279, theta=-23.5371911 -> V=1.022224, theta=0.0
% INFO    : Bus 3065	: V=1.06363403, theta=-19.5061997 -> V=1.04444, theta=0.0
% INFO    : Bus 3066	: V=1.03504334, theta=-24.7118869 -> V=1.000001, theta=0.0
% INFO    : Bus 3067	: V=1.06469309, theta=-15.1852933 -> V=1.027779, theta=0.0
% INFO    : Bus 3068	: V=1.05885709, theta=-20.607046 -> V=1.027779, theta=0.0
% INFO    : Bus 3069	: V=1.06999233, theta=-17.3687411 -> V=1.046665, theta=0.0
% INFO    : Bus 3070	: V=1.06983025, theta=-17.3824031 -> V=1.046665, theta=0.0
% INFO    : Bus 3071	: V=0.991655721, theta=-14.9305703 -> V=1.015872, theta=0.0
% INFO    : Bus 3072	: V=1.00736279, theta=-31.4038609 -> V=1.0000025, theta=0.0
% INFO    : Bus 3073	: V=1.02968595, theta=-38.2694844 -> V=1.0079355, theta=0.0
% INFO    : Bus 3074	: V=1.01853241, theta=-18.7110305 -> V=0.999999, theta=0.0
% INFO    : Bus 3075	: V=1.05507223, theta=-15.3825931 -> V=1.0111115, theta=0.0
% INFO    : Bus 3076	: V=1.02175338, theta=-14.2070773 -> V=0.999999, theta=0.0
% INFO    : Bus 3077	: V=0.975987642, theta=-17.5479454 -> V=1.015872, theta=0.0
% INFO    : Bus 3078	: V=1.02658777, theta=-13.1906927 -> V=0.999999, theta=0.0
% INFO    : Bus 3079	: V=0.993109699, theta=-14.1434249 -> V=0.984126, theta=0.0
% INFO    : Bus 3080	: V=1.03053468, theta=-19.1152953 -> V=1.022224, theta=0.0
% INFO    : Bus 3081	: V=1.03863647, theta=-35.2575455 -> V=1.0079355, theta=0.0
% INFO    : Bus 3082	: V=1.01576236, theta=2.10362128 -> V=1.0158755, theta=0.0
% INFO    : Bus 3083	: V=1.07454852, theta=4.61938353 -> V=1.0377785, theta=0.0
% INFO    : Bus 3084	: V=1.00105733, theta=-27.4616987 -> V=1.0000025, theta=0.0
% INFO    : Bus 3085	: V=1.01365833, theta=-28.5157076 -> V=1.0000025, theta=0.0
% INFO    : Bus 3086	: V=1.02169956, theta=-20.1110098 -> V=1.0000025, theta=0.0
% INFO    : Bus 3087	: V=1.05081053, theta=-16.7373597 -> V=1.044445, theta=0.0
% INFO    : Bus 3088	: V=1.02146574, theta=-11.906757 -> V=0.999999, theta=0.0
% INFO    : Bus 3089	: V=1.04725315, theta=-9.17500969 -> V=1.0111115, theta=0.0
% INFO    : Bus 3090	: V=0.98268297, theta=-32.5483485 -> V=1.0000025, theta=0.0
% INFO    : Bus 3091	: V=1.03124625, theta=-30.2646658 -> V=1.022224, theta=0.0
% INFO    : Bus 3092	: V=0.976818486, theta=-20.1204494 -> V=0.999999, theta=0.0
% INFO    : Bus 3093	: V=1.02508195, theta=-28.7608728 -> V=1.022224, theta=0.0
% INFO    : Bus 3094	: V=0.952890524, theta=-6.78583594 -> V=0.9444445, theta=0.0
% INFO    : Bus 3095	: V=1.00968374, theta=-19.0093094 -> V=0.999999, theta=0.0
% INFO    : Bus 3096	: V=1.02024487, theta=-22.8059792 -> V=1.0000005, theta=0.0
% INFO    : Bus 3097	: V=0.995640256, theta=-21.3353306 -> V=1.0000005, theta=0.0
% INFO    : Bus 3098	: V=0.975900908, theta=-12.9856393 -> V=0.9444445, theta=0.0
% INFO    : Bus 3099	: V=0.971801633, theta=-22.8338162 -> V=0.999999, theta=0.0
% INFO    : Bus 3100	: V=1.02539847, theta=-17.8388953 -> V=0.999999, theta=0.0
% INFO    : Bus 3101	: V=1.05325063, theta=-14.9048218 -> V=1.0111115, theta=0.0
% INFO    : Bus 3102	: V=1.06895113, theta=-19.0371888 -> V=1.046665, theta=0.0
% INFO    : Bus 3103	: V=1.10403418, theta=1.64384729 -> V=1.072365, theta=0.0
% INFO    : Bus 3104	: V=1.01788129, theta=-6.92604395 -> V=1.0158755, theta=0.0
% INFO    : Bus 3105	: V=1.01094645, theta=-8.1942593 -> V=1.0158755, theta=0.0
% INFO    : Bus 3106	: V=1.00997786, theta=-12.8217871 -> V=0.999999, theta=0.0
% INFO    : Bus 3107	: V=1.01311957, theta=-12.5112556 -> V=0.999999, theta=0.0
% INFO    : Bus 3108	: V=0.999145888, theta=-24.4680504 -> V=1.0000005, theta=0.0
% INFO    : Bus 3109	: V=1.0613075, theta=-18.4803978 -> V=1.046665, theta=0.0
% INFO    : Bus 3110	: V=1.06315631, theta=-3.3619417 -> V=1.0377785, theta=0.0
% INFO    : Bus 3111	: V=1.02988584, theta=-30.4001934 -> V=1.0000025, theta=0.0
% INFO    : Bus 3112	: V=1.03775096, theta=-10.7779928 -> V=1.0000025, theta=0.0
% INFO    : Bus 3113	: V=1.01266713, theta=-51.2553401 -> V=1.0079355, theta=0.0
% INFO    : Bus 3114	: V=1.04408242, theta=-18.2949743 -> V=1.022224, theta=0.0
% INFO    : Bus 3115	: V=1.04756216, theta=-19.4492229 -> V=1.022224, theta=0.0
% INFO    : Bus 3116	: V=1.056, theta=5.8977275 -> V=0.975, theta=0.0
% INFO    : Bus 3117	: V=1.092, theta=4.55327318 -> V=0.975, theta=0.0
% INFO    : Bus 3118	: V=1.093, theta=4.72979918 -> V=0.975, theta=0.0
% INFO    : Bus 3119	: V=1.0637421, theta=-0.781464862 -> V=1.0377785, theta=0.0
% INFO    : Bus 3120	: V=1.06387188, theta=-0.785053895 -> V=1.0377785, theta=0.0
% INFO    : Bus 3121	: V=1.06387377, theta=-0.784434353 -> V=1.0377785, theta=0.0
% INFO    : Bus 3122	: V=1.0411144, theta=-42.1946644 -> V=1.022224, theta=0.0
% INFO    : Bus 3123	: V=1.032, theta=-17.9380228 -> V=0.999999, theta=0.0
% INFO    : Bus 3124	: V=1.01843549, theta=-45.2960489 -> V=1.0079355, theta=0.0
% INFO    : Bus 3125	: V=1.02069441, theta=-21.6048908 -> V=0.999999, theta=0.0
% INFO    : Bus 3126	: V=1.00915539, theta=-21.6128207 -> V=1.0000025, theta=0.0
% INFO    : Bus 3127	: V=1.02096765, theta=-27.46718 -> V=1.0000025, theta=0.0
% INFO    : Bus 3128	: V=0.968281843, theta=-25.9017726 -> V=1.0, theta=0.0
% INFO    : Bus 3129	: V=1.02649308, theta=-3.08251823 -> V=0.984126, theta=0.0
% INFO    : Bus 3130	: V=1.07224008, theta=-8.88924887 -> V=1.0021525, theta=0.0
% INFO    : Bus 3131	: V=0.990875772, theta=-25.6754669 -> V=1.015872, theta=0.0
% INFO    : Bus 3132	: V=1.01558875, theta=-28.2470427 -> V=1.022224, theta=0.0
% INFO    : Bus 3133	: V=1.05945558, theta=-11.2436023 -> V=1.022222, theta=0.0
% INFO    : Bus 3134	: V=1.04874055, theta=-13.3780904 -> V=1.001709, theta=0.0
% INFO    : Bus 3135	: V=1.07284737, theta=-7.21609101 -> V=1.072365, theta=0.0
% INFO    : Bus 3136	: V=1.072, theta=-21.5982989 -> V=1.000001, theta=0.0
% INFO    : Bus 3137	: V=1.06351215, theta=-5.79446329 -> V=0.9888895, theta=0.0
% INFO    : Bus 3138	: V=1.06409335, theta=-5.78245121 -> V=0.9888895, theta=0.0
% INFO    : Bus 3139	: V=1.03350136, theta=-6.81742682 -> V=1.0158755, theta=0.0
% INFO    : Bus 3140	: V=1.07454827, theta=5.61105142 -> V=1.0377785, theta=0.0
% INFO    : Bus 3141	: V=1.02988437, theta=-23.1076785 -> V=1.0000025, theta=0.0
% INFO    : Bus 3142	: V=0.97306711, theta=-24.3966391 -> V=1.0000025, theta=0.0
% INFO    : Bus 3143	: V=1.02132072, theta=-18.2253937 -> V=1.015872, theta=0.0
% INFO    : Bus 3144	: V=1.07240393, theta=-15.0699128 -> V=1.046665, theta=0.0
% INFO    : Bus 3145	: V=1.03658861, theta=-18.7501352 -> V=1.0000005, theta=0.0
% INFO    : Bus 3146	: V=1.07241243, theta=-15.069535 -> V=1.046665, theta=0.0
% INFO    : Bus 3147	: V=1.005657, theta=-28.5755549 -> V=1.0000025, theta=0.0
% INFO    : Bus 3148	: V=1.02599961, theta=-22.5356256 -> V=1.015872, theta=0.0
% INFO    : Bus 3149	: V=1.04180358, theta=-19.3782847 -> V=1.033334, theta=0.0
% INFO    : Bus 3150	: V=0.99609674, theta=-19.3781251 -> V=1.04802, theta=0.0
% INFO    : Bus 3151	: V=0.998445768, theta=-11.9924191 -> V=1.0158755, theta=0.0
% INFO    : Bus 3152	: V=1.03102472, theta=-6.01204922 -> V=1.0277795, theta=0.0
% INFO    : Bus 3153	: V=1.08943647, theta=-5.90311872 -> V=1.072365, theta=0.0
% INFO    : Bus 3154	: V=1.08852835, theta=-5.57365383 -> V=1.072365, theta=0.0
% INFO    : Bus 3155	: V=1.01507597, theta=-27.422064 -> V=1.0000025, theta=0.0
% INFO    : Bus 3156	: V=1.02509644, theta=-13.9679851 -> V=0.999999, theta=0.0
% INFO    : Bus 3157	: V=1.059, theta=-9.42994296 -> V=1.0111115, theta=0.0
% INFO    : Bus 3158	: V=1.04289223, theta=-21.5747417 -> V=0.999999, theta=0.0
% INFO    : Bus 3159	: V=1.074, theta=-22.3948624 -> V=1.000001, theta=0.0
% INFO    : Bus 3160	: V=1.03122839, theta=-23.0765415 -> V=1.022224, theta=0.0
% INFO    : Bus 3161	: V=0.993714396, theta=-21.1686356 -> V=1.0000005, theta=0.0
% INFO    : Bus 3162	: V=1.02725851, theta=-9.77253878 -> V=0.999999, theta=0.0
% INFO    : Bus 3163	: V=1.06972194, theta=-18.8279934 -> V=1.046665, theta=0.0
% INFO    : Bus 3164	: V=1.02792952, theta=-22.5544146 -> V=1.0000025, theta=0.0
% INFO    : Bus 3165	: V=1.08958979, theta=-18.3659194 -> V=1.044445, theta=0.0
% INFO    : Bus 3166	: V=0.97502462, theta=-24.9801844 -> V=1.0000025, theta=0.0
% INFO    : Bus 3167	: V=1.07684302, theta=-15.6498139 -> V=1.046665, theta=0.0
% INFO    : Bus 3168	: V=1.08035003, theta=-18.1055487 -> V=1.046665, theta=0.0
% INFO    : Bus 3169	: V=1.03839088, theta=-30.1560597 -> V=1.022224, theta=0.0
% INFO    : Bus 3170	: V=1.02649118, theta=-16.5222743 -> V=0.999999, theta=0.0
% INFO    : Bus 3171	: V=1.01913833, theta=-28.5067558 -> V=1.0000025, theta=0.0
% INFO    : Bus 3172	: V=1.03383642, theta=-25.1460419 -> V=1.000001, theta=0.0
% INFO    : Bus 3173	: V=1.00242766, theta=-21.654736 -> V=1.0158755, theta=0.0
% INFO    : Bus 3174	: V=1.05748543, theta=-24.8387387 -> V=1.0000025, theta=0.0
% INFO    : Bus 3175	: V=1.0282546, theta=-17.7005889 -> V=1.0000005, theta=0.0
% INFO    : Bus 3176	: V=1.06286061, theta=-13.5757848 -> V=1.046665, theta=0.0
% INFO    : Bus 3177	: V=1.03056065, theta=-44.675257 -> V=1.0079355, theta=0.0
% INFO    : Bus 3178	: V=1.01559185, theta=-24.2262784 -> V=1.0, theta=0.0
% INFO    : Bus 3179	: V=1.04604083, theta=-22.5042396 -> V=1.046665, theta=0.0
% INFO    : Bus 3180	: V=1.04047544, theta=-19.5850535 -> V=1.06579, theta=0.0
% INFO    : Bus 3181	: V=1.03763948, theta=-26.2177148 -> V=1.0000025, theta=0.0
% INFO    : Bus 3182	: V=1.00173268, theta=-19.9905514 -> V=1.022224, theta=0.0
% INFO    : Bus 3183	: V=1.06604849, theta=-12.4130574 -> V=0.990526, theta=0.0
% INFO    : Bus 3184	: V=1.04482979, theta=-19.9581005 -> V=1.027779, theta=0.0
% INFO    : Bus 3185	: V=1.04442983, theta=-13.5051961 -> V=1.000001, theta=0.0
% INFO    : Bus 3186	: V=1.00899048, theta=-10.5399343 -> V=1.0158755, theta=0.0
% INFO    : Bus 3187	: V=1.01067232, theta=-18.1172981 -> V=0.999999, theta=0.0
% INFO    : Bus 3188	: V=1.03891516, theta=-19.9303431 -> V=0.999999, theta=0.0
% INFO    : Bus 3189	: V=1.01898346, theta=-7.84168163 -> V=1.0079355, theta=0.0
% INFO    : Bus 3190	: V=1.02186832, theta=-13.0618073 -> V=1.0158755, theta=0.0
% INFO    : Bus 3191	: V=1.07789726, theta=-15.754719 -> V=1.046665, theta=0.0
% INFO    : Bus 3192	: V=1.07787887, theta=-15.7569307 -> V=1.046665, theta=0.0
% INFO    : Bus 3193	: V=1.04171096, theta=-24.3566776 -> V=1.022224, theta=0.0
% INFO    : Bus 3194	: V=1.0401148, theta=-14.4829483 -> V=1.046665, theta=0.0
% INFO    : Bus 3195	: V=1.0076888, theta=-20.5839967 -> V=1.015872, theta=0.0
% INFO    : Bus 3196	: V=1.0215847, theta=-25.0467195 -> V=1.022224, theta=0.0
% INFO    : Bus 3197	: V=1.03005457, theta=-25.8327543 -> V=1.022224, theta=0.0
% INFO    : Bus 3198	: V=1.06341501, theta=-21.8017824 -> V=1.04444, theta=0.0
% INFO    : Bus 3199	: V=1.06318384, theta=-23.4185442 -> V=1.04444, theta=0.0
% INFO    : Bus 3200	: V=1.05523844, theta=-24.1555068 -> V=1.0000025, theta=0.0
% INFO    : Bus 3201	: V=1.01535534, theta=-11.7201614 -> V=0.984126, theta=0.0
% INFO    : Bus 3202	: V=1.03829503, theta=-8.86373452 -> V=0.995556, theta=0.0
% INFO    : Bus 3203	: V=0.991191246, theta=-29.8793906 -> V=1.0000025, theta=0.0
% INFO    : Bus 3204	: V=1.07392456, theta=-15.6147633 -> V=1.046665, theta=0.0
% INFO    : Bus 3205	: V=1.07725414, theta=-15.5396799 -> V=1.046665, theta=0.0
% INFO    : Bus 3206	: V=1.0386374, theta=-25.2312818 -> V=1.027779, theta=0.0
% INFO    : Bus 3207	: V=1.01670876, theta=-35.8727769 -> V=1.0000025, theta=0.0
% INFO    : Bus 3208	: V=1.06605054, theta=-2.37607715 -> V=1.022222, theta=0.0
% INFO    : Bus 3209	: V=1.03077132, theta=3.32791073 -> V=1.0158755, theta=0.0
% INFO    : Bus 3210	: V=1.073, theta=-17.8697382 -> V=1.0, theta=0.0
% INFO    : Bus 3211	: V=1.04589257, theta=-10.7136703 -> V=1.0000025, theta=0.0
% INFO    : Bus 3212	: V=1.06056172, theta=-18.4911685 -> V=1.046665, theta=0.0
% INFO    : Bus 3213	: V=1.02870943, theta=-2.21252111 -> V=0.9682545, theta=0.0
% INFO    : Bus 3214	: V=1.03527001, theta=-16.5249674 -> V=1.0158755, theta=0.0
% INFO    : Bus 3215	: V=1.08970061, theta=-16.6399961 -> V=1.0253605, theta=0.0
% INFO    : Bus 3216	: V=1.02068923, theta=-19.3840821 -> V=1.0000005, theta=0.0
% INFO    : Bus 3217	: V=1.06205157, theta=-16.6378614 -> V=1.046665, theta=0.0
% INFO    : Bus 3218	: V=1.03277988, theta=-36.3374458 -> V=1.022224, theta=0.0
% INFO    : Bus 3219	: V=1.04436727, theta=-14.6062661 -> V=1.0000025, theta=0.0
% INFO    : Bus 3220	: V=1.0328087, theta=-16.5036761 -> V=1.0000005, theta=0.0
% INFO    : Bus 3221	: V=1.05882708, theta=-20.6185487 -> V=1.027779, theta=0.0
% INFO    : Bus 3222	: V=1.02341008, theta=-16.128102 -> V=1.0158755, theta=0.0
% INFO    : Bus 3223	: V=1.02945676, theta=-15.2121188 -> V=1.0158755, theta=0.0
% INFO    : Bus 3224	: V=0.965291191, theta=-20.5546902 -> V=1.01565, theta=0.0
% INFO    : Bus 3225	: V=0.958148339, theta=-8.7068675 -> V=0.9444445, theta=0.0
% INFO    : Bus 3226	: V=1.03934175, theta=-34.2817746 -> V=1.022224, theta=0.0
% INFO    : Bus 3227	: V=0.991929528, theta=-21.46223 -> V=1.0158755, theta=0.0
% INFO    : Bus 3228	: V=1.03832033, theta=-16.0972324 -> V=1.027779, theta=0.0
% INFO    : Bus 3229	: V=1.00895118, theta=-3.91808951 -> V=1.0158755, theta=0.0
% INFO    : Bus 3230	: V=1.09141599, theta=2.57759912 -> V=1.072365, theta=0.0
% INFO    : Bus 3231	: V=1.07742324, theta=-15.3790866 -> V=1.046665, theta=0.0
% INFO    : Bus 3232	: V=1.07746309, theta=-15.3764318 -> V=1.046665, theta=0.0
% INFO    : Bus 3233	: V=1.07747815, theta=-15.374721 -> V=1.046665, theta=0.0
% INFO    : Bus 3234	: V=1.00744594, theta=-23.1451399 -> V=1.022224, theta=0.0
% INFO    : Bus 3235	: V=0.991658026, theta=-33.2673823 -> V=1.022224, theta=0.0
% INFO    : Bus 3236	: V=1.09059748, theta=-5.74334052 -> V=1.072365, theta=0.0
% INFO    : Bus 3237	: V=1.09037423, theta=-5.83759006 -> V=1.072365, theta=0.0
% INFO    : Bus 3238	: V=1.0199697, theta=-10.5683367 -> V=1.0158755, theta=0.0
% INFO    : Bus 3239	: V=1.06102569, theta=-19.4760096 -> V=1.000001, theta=0.0
% INFO    : Bus 3240	: V=1.01052834, theta=-6.82953735 -> V=1.0158755, theta=0.0
% INFO    : Bus 3241	: V=1.00557762, theta=-12.0607208 -> V=0.999999, theta=0.0
% INFO    : Bus 3242	: V=1.03285035, theta=-47.135487 -> V=1.0079355, theta=0.0
% INFO    : Bus 3243	: V=1.01154072, theta=3.23934847 -> V=1.013331, theta=0.0
% INFO    : Bus 3244	: V=1.04946247, theta=-22.4530399 -> V=1.027779, theta=0.0
% INFO    : Bus 3245	: V=1.01885972, theta=-11.7880063 -> V=1.0000025, theta=0.0
% INFO    : Bus 3246	: V=1.00488166, theta=-29.7714154 -> V=1.0000025, theta=0.0
% INFO    : Bus 3247	: V=1.01136966, theta=-19.082216 -> V=1.015872, theta=0.0
% INFO    : Bus 3248	: V=1.05309476, theta=-21.0656274 -> V=1.027779, theta=0.0
% INFO    : Bus 3249	: V=1.02492266, theta=-25.7236613 -> V=0.999999, theta=0.0
% INFO    : Bus 3250	: V=1.03511322, theta=-43.3115451 -> V=1.022224, theta=0.0
% INFO    : Bus 3251	: V=1.03719568, theta=-24.3851305 -> V=1.0000025, theta=0.0
% INFO    : Bus 3252	: V=1.01802444, theta=-28.0637287 -> V=1.022224, theta=0.0
% INFO    : Bus 3253	: V=1.06126525, theta=-15.0253326 -> V=1.046665, theta=0.0
% INFO    : Bus 3254	: V=1.02825885, theta=-5.50344503 -> V=1.0158755, theta=0.0
% INFO    : Bus 3255	: V=1.02825885, theta=-5.50344503 -> V=1.0158755, theta=0.0
% INFO    : Bus 3256	: V=1.02825901, theta=-5.5035275 -> V=1.0158755, theta=0.0
% INFO    : Bus 3257	: V=1.00824792, theta=-12.6884873 -> V=1.015872, theta=0.0
% INFO    : Bus 3258	: V=1.03541631, theta=-22.387525 -> V=1.022224, theta=0.0
% INFO    : Bus 3259	: V=1.06611151, theta=-18.3500126 -> V=1.04444, theta=0.0
% INFO    : Bus 3260	: V=1.0471946, theta=-21.8254947 -> V=1.027779, theta=0.0
% INFO    : Bus 3261	: V=1.03291019, theta=-16.7294975 -> V=1.022224, theta=0.0
% INFO    : Bus 3262	: V=1.04051961, theta=-11.5315476 -> V=1.0111115, theta=0.0
% INFO    : Bus 3263	: V=1.05298851, theta=-5.112662 -> V=1.0111115, theta=0.0
% INFO    : Bus 3264	: V=1.01623121, theta=-29.1112374 -> V=1.0000025, theta=0.0
% INFO    : Bus 3265	: V=1.03546233, theta=-17.293941 -> V=1.022224, theta=0.0
% INFO    : Bus 3266	: V=1.051, theta=-22.9959004 -> V=1.0, theta=0.0
% INFO    : Bus 3267	: V=1.07972911, theta=-18.1046469 -> V=1.046665, theta=0.0
% INFO    : Bus 3268	: V=0.955080523, theta=-24.2351601 -> V=0.996216, theta=0.0
% INFO    : Bus 3269	: V=1.04731346, theta=-10.0869862 -> V=1.0000025, theta=0.0
% INFO    : Bus 3270	: V=1.04819709, theta=-7.63834993 -> V=1.002223, theta=0.0
% INFO    : Bus 3271	: V=1.07763802, theta=-15.7854577 -> V=1.046665, theta=0.0
% INFO    : Bus 3272	: V=1.00357058, theta=-18.7710509 -> V=1.0158755, theta=0.0
% INFO    : Bus 3273	: V=1.07915274, theta=-14.7879059 -> V=1.046665, theta=0.0
% INFO    : Bus 3274	: V=1.04367327, theta=-27.3434274 -> V=1.0000025, theta=0.0
% INFO    : Bus 3275	: V=0.999326502, theta=-20.5502505 -> V=1.0000005, theta=0.0
% INFO    : Bus 3276	: V=1.03616731, theta=-1.9893599 -> V=1.0000025, theta=0.0
% INFO    : Bus 3277	: V=1.06909739, theta=-7.07381374 -> V=1.033333, theta=0.0
% INFO    : Bus 3278	: V=1.02545797, theta=-4.5682798 -> V=1.0158755, theta=0.0
% INFO    : Bus 3279	: V=1.08059692, theta=-3.78455962 -> V=1.0377785, theta=0.0
% INFO    : Bus 3280	: V=1.116, theta=1.87284482 -> V=0.975, theta=0.0
% INFO    : Bus 3281	: V=1.048, theta=0.618105356 -> V=0.975, theta=0.0
% INFO    : Bus 3282	: V=1.025, theta=0.706820874 -> V=0.975, theta=0.0
% INFO    : Bus 3283	: V=1.02612702, theta=-4.27265284 -> V=1.0158755, theta=0.0
% INFO    : Bus 3284	: V=1.02485303, theta=-4.27787394 -> V=1.0158755, theta=0.0
% INFO    : Bus 3285	: V=1.08059692, theta=-3.78455962 -> V=1.0377785, theta=0.0
% INFO    : Bus 3286	: V=1.08068491, theta=-3.76503863 -> V=1.0377785, theta=0.0
% INFO    : Bus 3287	: V=1.0330885, theta=-10.6268889 -> V=0.999999, theta=0.0
% INFO    : Bus 3288	: V=1.04708185, theta=-8.58576188 -> V=1.0111115, theta=0.0
% INFO    : Bus 3289	: V=1.06968767, theta=-6.94990923 -> V=1.033333, theta=0.0
% INFO    : Bus 3290	: V=1.08306022, theta=4.93887214 -> V=1.0240655, theta=0.0
% INFO    : Bus 3291	: V=1.0765621, theta=4.93887214 -> V=1.0379535, theta=0.0
% INFO    : Bus 3292	: V=1.01976426, theta=-17.4931181 -> V=0.999999, theta=0.0
% INFO    : Bus 3293	: V=1.01875542, theta=-16.9391522 -> V=0.999999, theta=0.0
% INFO    : Bus 3294	: V=1.00105925, theta=-11.8963888 -> V=0.999999, theta=0.0
% INFO    : Bus 3295	: V=1.01308384, theta=-12.3263695 -> V=0.999999, theta=0.0
% INFO    : Bus 3296	: V=0.995163272, theta=-21.3212415 -> V=1.0000005, theta=0.0
% INFO    : Bus 3297	: V=1.05244655, theta=-24.6721537 -> V=1.0000025, theta=0.0
% INFO    : Bus 3298	: V=1.06335215, theta=-18.8475677 -> V=1.044445, theta=0.0
% INFO    : Bus 3299	: V=1.03213933, theta=-14.8760146 -> V=1.0158755, theta=0.0
% INFO    : Bus 3300	: V=1.02927266, theta=-15.3646108 -> V=1.0158755, theta=0.0
% INFO    : Bus 3301	: V=1.02437679, theta=-27.0228335 -> V=1.015872, theta=0.0
% INFO    : Bus 3302	: V=1.04033488, theta=-23.6891991 -> V=1.0000025, theta=0.0
% INFO    : Bus 3303	: V=0.979101255, theta=-44.1054422 -> V=1.0079355, theta=0.0
% INFO    : Bus 3304	: V=1.00781297, theta=-47.3544366 -> V=1.0079355, theta=0.0
% INFO    : Bus 3305	: V=1.01147169, theta=-17.0324788 -> V=0.999999, theta=0.0
% INFO    : Bus 3306	: V=1.01321128, theta=-21.7436217 -> V=1.0000005, theta=0.0
% INFO    : Bus 3307	: V=1.04027134, theta=-24.2625018 -> V=1.000001, theta=0.0
% INFO    : Bus 3308	: V=1.0, theta=-30.1784905 -> V=1.0000025, theta=0.0
% INFO    : Bus 3309	: V=1.04943047, theta=-28.7721292 -> V=1.022224, theta=0.0
% INFO    : Bus 3310	: V=1.06081548, theta=-22.182147 -> V=1.044445, theta=0.0
% INFO    : Bus 3311	: V=1.03712665, theta=-16.3198673 -> V=1.0158755, theta=0.0
% INFO    : Bus 3312	: V=1.04927291, theta=-10.2995942 -> V=1.0377785, theta=0.0
% INFO    : Bus 3313	: V=1.02414806, theta=-13.8767058 -> V=0.999999, theta=0.0
% INFO    : Bus 3314	: V=1.0292588, theta=-28.2406182 -> V=1.022224, theta=0.0
% INFO    : Bus 3315	: V=1.04929492, theta=-40.7407511 -> V=1.022224, theta=0.0
% INFO    : Bus 3316	: V=1.01708035, theta=-10.8680203 -> V=1.015872, theta=0.0
% INFO    : Bus 3317	: V=1.10321877, theta=0.68029392 -> V=1.074325, theta=0.0
% INFO    : Bus 3318	: V=1.10071111, theta=0.798808454 -> V=1.073685, theta=0.0
% INFO    : Bus 3319	: V=1.10522983, theta=0.719125527 -> V=1.075165, theta=0.0
% INFO    : Bus 3320	: V=1.10652819, theta=0.440158795 -> V=1.075815, theta=0.0
% INFO    : Bus 3321	: V=1.02205981, theta=-24.2704758 -> V=1.015872, theta=0.0
% INFO    : Bus 3322	: V=1.01386349, theta=-21.1880893 -> V=1.015872, theta=0.0
% INFO    : Bus 3323	: V=1.05077543, theta=-17.9125568 -> V=1.046665, theta=0.0
% INFO    : Bus 3324	: V=1.03127623, theta=-27.4358094 -> V=1.0000025, theta=0.0
% INFO    : Bus 3325	: V=1.0309622, theta=-27.7427385 -> V=1.0000025, theta=0.0
% INFO    : Bus 3326	: V=1.04733093, theta=-20.8403526 -> V=1.022224, theta=0.0
% INFO    : Bus 3327	: V=1.03131754, theta=-16.9689304 -> V=1.022224, theta=0.0
% INFO    : Bus 3328	: V=1.0719025, theta=-24.9060858 -> V=1.04444, theta=0.0
% INFO    : Bus 3329	: V=1.07060989, theta=-25.0303519 -> V=1.04444, theta=0.0
% INFO    : Bus 3330	: V=1.03413432, theta=-21.1253561 -> V=1.0000025, theta=0.0
% INFO    : Bus 3331	: V=1.02748014, theta=-27.3533492 -> V=1.0000025, theta=0.0
% INFO    : Bus 3332	: V=1.04123901, theta=-10.7084058 -> V=0.999999, theta=0.0
% INFO    : Bus 3333	: V=1.04178361, theta=-10.6662891 -> V=0.999999, theta=0.0
% INFO    : Bus 3334	: V=1.02535337, theta=-13.533859 -> V=0.999999, theta=0.0
% INFO    : Bus 3335	: V=1.01679389, theta=-13.289508 -> V=0.999999, theta=0.0
% INFO    : Bus 3336	: V=1.04545258, theta=-10.5958487 -> V=1.0111115, theta=0.0
% INFO    : Bus 3337	: V=1.01835502, theta=-13.6484885 -> V=1.0158755, theta=0.0
% INFO    : Bus 3338	: V=1.03236369, theta=-20.9826792 -> V=1.0158755, theta=0.0
% INFO    : Bus 3339	: V=1.00342608, theta=-25.6432321 -> V=1.022224, theta=0.0
% INFO    : Bus 3340	: V=1.02725901, theta=-17.8264299 -> V=1.0000005, theta=0.0
% INFO    : Bus 3341	: V=1.02824152, theta=-17.7836905 -> V=1.0000005, theta=0.0
% INFO    : Bus 3342	: V=1.06150892, theta=-16.7417753 -> V=1.046665, theta=0.0
% INFO    : Bus 3343	: V=1.00830036, theta=-19.5633377 -> V=1.015872, theta=0.0
% INFO    : Bus 3344	: V=0.975852138, theta=-12.9842698 -> V=0.9444445, theta=0.0
% INFO    : Bus 3345	: V=1.03468226, theta=-12.7030315 -> V=0.999999, theta=0.0
% INFO    : Bus 3346	: V=1.05107424, theta=-9.12019436 -> V=1.0111115, theta=0.0
% INFO    : Bus 3347	: V=1.00193998, theta=-22.094676 -> V=1.0000025, theta=0.0
% INFO    : Bus 3348	: V=1.01837434, theta=-37.3260284 -> V=1.022224, theta=0.0
% INFO    : Bus 3349	: V=1.01731781, theta=-17.5081192 -> V=1.0000005, theta=0.0
% INFO    : Bus 3350	: V=1.06180248, theta=-14.3287306 -> V=1.046665, theta=0.0
% INFO    : Bus 3351	: V=1.07407205, theta=-13.127516 -> V=1.046665, theta=0.0
% INFO    : Bus 3352	: V=1.04660711, theta=-23.7246147 -> V=1.0000025, theta=0.0
% INFO    : Bus 3353	: V=1.01606925, theta=-16.3789154 -> V=0.999999, theta=0.0
% INFO    : Bus 3354	: V=1.04958321, theta=-21.2758618 -> V=1.0000025, theta=0.0
% INFO    : Bus 3355	: V=1.02136235, theta=-26.8234236 -> V=1.0000025, theta=0.0
% INFO    : Bus 3356	: V=1.02445868, theta=-26.4514319 -> V=1.0000025, theta=0.0
% INFO    : Bus 3357	: V=1.02969603, theta=-25.7522443 -> V=1.0000025, theta=0.0
% INFO    : Bus 3358	: V=1.05738345, theta=-15.6122854 -> V=1.022224, theta=0.0
% INFO    : Bus 3359	: V=1.01574828, theta=-20.1336923 -> V=1.0000005, theta=0.0
% INFO    : Bus 3360	: V=0.992691897, theta=-25.0579216 -> V=1.0000005, theta=0.0
% INFO    : Bus 3361	: V=1.01484727, theta=-22.3688253 -> V=1.0000005, theta=0.0
% INFO    : Bus 3362	: V=1.01839323, theta=-29.692412 -> V=1.015872, theta=0.0
% INFO    : Bus 3363	: V=1.0436837, theta=-25.5825659 -> V=1.0000025, theta=0.0
% INFO    : Bus 3364	: V=1.05931886, theta=-21.862558 -> V=1.044445, theta=0.0
% INFO    : Bus 3365	: V=1.01977817, theta=-26.3694221 -> V=1.022224, theta=0.0
% INFO    : Bus 3366	: V=1.1199739, theta=5.62648458 -> V=1.0422755, theta=0.0
% INFO    : Bus 3367	: V=1.07809035, theta=5.62933363 -> V=1.0386535, theta=0.0
% INFO    : Bus 3368	: V=1.07711499, theta=-9.77574481 -> V=1.073685, theta=0.0
% INFO    : Bus 3369	: V=1.03210835, theta=-45.1213055 -> V=1.0079355, theta=0.0
% INFO    : Bus 3370	: V=1.02557261, theta=-48.0913706 -> V=1.0079355, theta=0.0
% INFO    : Bus 3371	: V=1.05318324, theta=-4.52878589 -> V=1.027779, theta=0.0
% INFO    : Bus 3372	: V=1.10058629, theta=-0.578924941 -> V=1.073685, theta=0.0
% INFO    : Bus 3373	: V=1.10124789, theta=-0.370695028 -> V=1.073825, theta=0.0
% INFO    : Bus 3374	: V=1.10128618, theta=-0.388189163 -> V=1.07384, theta=0.0
% INFO    : Bus 3375	: V=1.01373877, theta=-25.7354784 -> V=1.015872, theta=0.0
% INFO    : Bus 3376	: V=0.999948676, theta=-30.4845265 -> V=1.0000025, theta=0.0
% INFO    : Bus 3377	: V=1.05222482, theta=-24.0350448 -> V=1.027779, theta=0.0
% INFO    : Bus 3378	: V=1.02161721, theta=-14.2937213 -> V=0.999999, theta=0.0
% INFO    : Bus 3379	: V=1.07553993, theta=-19.222595 -> V=1.029674, theta=0.0
% INFO    : Bus 3380	: V=1.0539014, theta=-10.291681 -> V=1.000001, theta=0.0
% INFO    : Bus 3381	: V=1.07321589, theta=-7.09008405 -> V=0.9888895, theta=0.0
% INFO    : Bus 3382	: V=1.05463366, theta=-12.2644576 -> V=1.0111115, theta=0.0
% INFO    : Bus 3383	: V=1.06703964, theta=-12.8416287 -> V=1.0000025, theta=0.0
% INFO    : Bus 3384	: V=1.06230265, theta=-13.1316154 -> V=1.0000025, theta=0.0
% INFO    : Bus 3385	: V=1.05263446, theta=-24.5393663 -> V=1.0000025, theta=0.0
% INFO    : Bus 3386	: V=0.946524769, theta=-6.31381718 -> V=0.9444445, theta=0.0
% INFO    : Bus 3387	: V=1.0295797, theta=-43.9812361 -> V=1.0079355, theta=0.0
% INFO    : Bus 3388	: V=1.00966812, theta=-11.9130844 -> V=1.0158755, theta=0.0
% INFO    : Bus 3389	: V=1.04699469, theta=-8.60761335 -> V=1.0111115, theta=0.0
% INFO    : Bus 3390	: V=1.06990063, theta=-18.877732 -> V=1.046665, theta=0.0
% INFO    : Bus 3391	: V=1.01262176, theta=-17.6493344 -> V=1.0158755, theta=0.0
% INFO    : Bus 3392	: V=1.02590732, theta=-26.4871202 -> V=1.022224, theta=0.0
% INFO    : Bus 3393	: V=0.965925656, theta=-21.7064868 -> V=1.0000005, theta=0.0
% INFO    : Bus 3394	: V=0.982512978, theta=-25.2172764 -> V=1.0000005, theta=0.0
% INFO    : Bus 3395	: V=1.07674415, theta=-15.2669872 -> V=1.046665, theta=0.0
% INFO    : Bus 3396	: V=1.06948511, theta=-12.1001747 -> V=1.000001, theta=0.0
% INFO    : Bus 3397	: V=1.05795395, theta=-9.14126584 -> V=1.024445, theta=0.0
% INFO    : Bus 3398	: V=0.987626172, theta=-24.0579057 -> V=1.015872, theta=0.0
% INFO    : Bus 3399	: V=1.04905016, theta=-22.5165666 -> V=1.0000025, theta=0.0
% INFO    : Bus 3400	: V=1.06678374, theta=-17.5129937 -> V=1.044445, theta=0.0
% INFO    : Bus 3401	: V=1.01397868, theta=-7.08052662 -> V=1.0158755, theta=0.0
% INFO    : Bus 3402	: V=1.02068505, theta=-6.20374232 -> V=1.0158755, theta=0.0
% INFO    : Bus 3403	: V=1.00666842, theta=-18.4182215 -> V=1.0000005, theta=0.0
% INFO    : Bus 3404	: V=1.02000033, theta=-11.5474747 -> V=1.0158755, theta=0.0
% INFO    : Bus 3405	: V=1.02, theta=-11.5474703 -> V=1.0158755, theta=0.0
% INFO    : Bus 3406	: V=1.01286577, theta=-30.9326171 -> V=1.015872, theta=0.0
% INFO    : Bus 3407	: V=1.05086849, theta=-16.9235744 -> V=1.044445, theta=0.0
% INFO    : Bus 3408	: V=1.034, theta=-19.5330275 -> V=0.999999, theta=0.0
% INFO    : Bus 3409	: V=1.00393148, theta=-24.6189439 -> V=1.0000025, theta=0.0
% INFO    : Bus 3410	: V=0.996868782, theta=-8.51094301 -> V=1.0158755, theta=0.0
% INFO    : Bus 3411	: V=1.01093561, theta=-5.67506556 -> V=1.0158755, theta=0.0
% INFO    : Bus 3412	: V=1.01627503, theta=-22.430885 -> V=1.022224, theta=0.0
% INFO    : Bus 3413	: V=1.04816402, theta=-10.3492543 -> V=1.033334, theta=0.0
% INFO    : Bus 3414	: V=1.0303537, theta=-19.1597556 -> V=0.999999, theta=0.0
% INFO    : Bus 3415	: V=1.01352251, theta=-19.5617112 -> V=1.015872, theta=0.0
% INFO    : Bus 3416	: V=1.08634997, theta=-13.2313905 -> V=1.07237, theta=0.0
% INFO    : Bus 3417	: V=1.01533902, theta=-32.7278685 -> V=1.015872, theta=0.0
% INFO    : Bus 3418	: V=1.006, theta=-28.8825593 -> V=1.0000025, theta=0.0
% INFO    : Bus 3419	: V=1.04824995, theta=-23.0510002 -> V=1.022224, theta=0.0
% INFO    : Bus 3420	: V=1.04284788, theta=-15.5732065 -> V=1.0000025, theta=0.0
% INFO    : Bus 3421	: V=1.04276183, theta=-20.8907263 -> V=1.022224, theta=0.0
% INFO    : Bus 3422	: V=1.00821552, theta=-12.7379991 -> V=1.015872, theta=0.0
% INFO    : Bus 3423	: V=1.04516638, theta=-13.2730887 -> V=1.022224, theta=0.0
% INFO    : Bus 3424	: V=0.997, theta=-12.1306437 -> V=0.999999, theta=0.0
% INFO    : Bus 3425	: V=1.00938658, theta=-10.3852241 -> V=0.999999, theta=0.0
% INFO    : Bus 3426	: V=1.01188747, theta=-22.5047422 -> V=1.0000005, theta=0.0
% INFO    : Bus 3427	: V=1.07756068, theta=-15.3682845 -> V=1.046665, theta=0.0
% INFO    : Bus 3428	: V=1.04765332, theta=-20.8599097 -> V=1.022224, theta=0.0
% INFO    : Bus 3429	: V=1.03718732, theta=-40.3809642 -> V=1.0079355, theta=0.0
% INFO    : Bus 3430	: V=0.992003116, theta=-12.4268487 -> V=1.015872, theta=0.0
% INFO    : Bus 3431	: V=1.00072466, theta=-13.1649427 -> V=1.015872, theta=0.0
% INFO    : Bus 3432	: V=1.05358338, theta=-17.3580956 -> V=1.000001, theta=0.0
% INFO    : Bus 3433	: V=1.09381576, theta=-10.792538 -> V=1.078945, theta=0.0
% INFO    : Bus 3434	: V=1.02187123, theta=-38.3648928 -> V=1.022224, theta=0.0
% INFO    : Bus 3435	: V=1.00696917, theta=-40.8976205 -> V=1.0079355, theta=0.0
% INFO    : Bus 3436	: V=1.03555739, theta=-43.3903648 -> V=1.022224, theta=0.0
% INFO    : Bus 3437	: V=1.044558, theta=-22.8890838 -> V=1.022224, theta=0.0
% INFO    : Bus 3438	: V=1.07084025, theta=-17.1683846 -> V=1.046665, theta=0.0
% INFO    : Bus 3439	: V=1.03651882, theta=-49.1925276 -> V=1.0079355, theta=0.0
% INFO    : Bus 3440	: V=1.03084592, theta=-43.9119151 -> V=1.0079355, theta=0.0
% INFO    : Bus 3441	: V=1.02640891, theta=-10.421464 -> V=1.0158755, theta=0.0
% INFO    : Bus 3442	: V=0.997836771, theta=-6.69504579 -> V=0.95, theta=0.0
% INFO    : Bus 3443	: V=1.00820689, theta=-46.9293728 -> V=1.0079355, theta=0.0
% INFO    : Bus 3444	: V=1.02899297, theta=-40.4993939 -> V=1.0079355, theta=0.0
% INFO    : Bus 3445	: V=1.02566274, theta=-46.1982967 -> V=1.0079355, theta=0.0
% INFO    : Bus 3446	: V=1.06010081, theta=-9.68645133 -> V=0.988046, theta=0.0
% INFO    : Bus 3447	: V=1.01778087, theta=-42.2056229 -> V=1.0079355, theta=0.0
% INFO    : Bus 3448	: V=1.02758633, theta=-42.2544052 -> V=1.0079355, theta=0.0
% INFO    : Bus 3449	: V=1.03499272, theta=-30.1720055 -> V=1.022224, theta=0.0
% INFO    : Bus 3450	: V=1.0531762, theta=-48.320904 -> V=1.0079355, theta=0.0
% INFO    : Bus 3451	: V=1.02925511, theta=-44.5015397 -> V=1.0079355, theta=0.0
% INFO    : Bus 3452	: V=0.988765921, theta=-29.5737627 -> V=1.0000025, theta=0.0
% INFO    : Bus 3453	: V=1.01863664, theta=-24.9204654 -> V=1.0000025, theta=0.0
% INFO    : Bus 3454	: V=1.0445914, theta=-24.5827879 -> V=1.027779, theta=0.0
% INFO    : Bus 3455	: V=1.01809045, theta=-19.4487933 -> V=1.022224, theta=0.0
% INFO    : Bus 3456	: V=1.0137242, theta=-16.7782748 -> V=1.0158755, theta=0.0
% INFO    : Bus 3457	: V=0.983997603, theta=-26.0506552 -> V=1.0000005, theta=0.0
% INFO    : Bus 3458	: V=1.01937847, theta=-12.4837218 -> V=0.999999, theta=0.0
% INFO    : Bus 3459	: V=1.04888859, theta=-20.287517 -> V=1.022224, theta=0.0
% INFO    : Bus 3460	: V=1.03525384, theta=-19.3122648 -> V=1.022224, theta=0.0
% INFO    : Bus 3461	: V=1.01371552, theta=-12.704084 -> V=1.0158755, theta=0.0
% INFO    : Bus 3462	: V=1.00720591, theta=-17.8313036 -> V=0.999999, theta=0.0
% INFO    : Bus 3463	: V=0.999714829, theta=-12.2465818 -> V=0.999999, theta=0.0
% INFO    : Bus 3464	: V=1.03963633, theta=-16.0828581 -> V=1.027779, theta=0.0
% INFO    : Bus 3465	: V=1.01473588, theta=-9.94255322 -> V=0.999999, theta=0.0
% INFO    : Bus 3466	: V=1.01664563, theta=-25.0979704 -> V=1.000001, theta=0.0
% INFO    : Bus 3467	: V=1.03332435, theta=-19.3952817 -> V=1.0000005, theta=0.0
% INFO    : Bus 3468	: V=1.014, theta=-9.64054862 -> V=0.999999, theta=0.0
% INFO    : Bus 3469	: V=1.04391673, theta=-23.5169417 -> V=1.022224, theta=0.0
% INFO    : Bus 3470	: V=1.04179143, theta=-19.3780261 -> V=1.046665, theta=0.0
% INFO    : Bus 3471	: V=0.996095939, theta=-19.3781205 -> V=1.04802, theta=0.0
% INFO    : Bus 3472	: V=1.01378572, theta=-22.5471476 -> V=1.0000005, theta=0.0
% INFO    : Bus 3473	: V=1.01376819, theta=-22.5478721 -> V=1.0000005, theta=0.0
% INFO    : Bus 3474	: V=1.01380162, theta=-22.5458001 -> V=1.0000005, theta=0.0
% INFO    : Bus 3475	: V=1.01371634, theta=-22.554216 -> V=1.0000005, theta=0.0
% INFO    : Bus 3476	: V=1.07162253, theta=-13.5476342 -> V=1.073685, theta=0.0
% INFO    : Bus 3477	: V=1.07162195, theta=-13.5476342 -> V=1.073685, theta=0.0
% INFO    : Bus 3478	: V=1.07162177, theta=-13.5476342 -> V=1.073685, theta=0.0
% INFO    : Bus 3479	: V=1.07162177, theta=-13.5476342 -> V=1.073685, theta=0.0
% INFO    : Bus 3480	: V=0.997008516, theta=-21.3276125 -> V=1.0000005, theta=0.0
% INFO    : Bus 3481	: V=0.997007537, theta=-21.3275841 -> V=1.0000005, theta=0.0
% INFO    : Bus 3482	: V=1.01381581, theta=-22.5456952 -> V=1.0000005, theta=0.0
% INFO    : Bus 3483	: V=1.03976395, theta=-21.2171576 -> V=1.027779, theta=0.0
% INFO    : Bus 3484	: V=1.05020918, theta=-21.1828043 -> V=1.027779, theta=0.0
% INFO    : Bus 3485	: V=1.06164784, theta=-18.0777266 -> V=1.046665, theta=0.0
% INFO    : Bus 3486	: V=0.966836007, theta=-45.5286846 -> V=1.0054535, theta=0.0
% INFO    : Bus 3487	: V=1.01871503, theta=-26.519421 -> V=1.022224, theta=0.0
% INFO    : Bus 3488	: V=1.02611606, theta=-43.3640654 -> V=1.0079355, theta=0.0
% INFO    : Bus 3489	: V=1.00798913, theta=-30.1013156 -> V=1.0000025, theta=0.0
% INFO    : Bus 3490	: V=1.00977765, theta=-11.2442 -> V=0.999999, theta=0.0
% INFO    : Bus 3491	: V=1.08, theta=-18.0395856 -> V=1.00713, theta=0.0
% INFO    : Bus 3492	: V=1.02712734, theta=-35.0238909 -> V=1.022224, theta=0.0
% INFO    : Bus 3493	: V=1.06158819, theta=-19.8024906 -> V=1.044445, theta=0.0
% INFO    : Bus 3494	: V=1.01459819, theta=-14.9945086 -> V=0.999999, theta=0.0
% INFO    : Bus 3495	: V=1.02431529, theta=-49.1715312 -> V=1.0079355, theta=0.0
% INFO    : Bus 3496	: V=1.01757899, theta=-20.1883235 -> V=1.0158755, theta=0.0
% INFO    : Bus 3497	: V=1.02591831, theta=-7.15066386 -> V=1.0158755, theta=0.0
% INFO    : Bus 3498	: V=1.04889911, theta=-34.8050194 -> V=1.022224, theta=0.0
% INFO    : Bus 3499	: V=1.00098875, theta=-12.044629 -> V=1.015872, theta=0.0
% INFO    : Bus 3500	: V=1.0467856, theta=-25.4958493 -> V=1.0000025, theta=0.0
% INFO    : Bus 3501	: V=1.02568582, theta=-28.2766237 -> V=1.0000025, theta=0.0
% INFO    : Bus 3502	: V=1.03163072, theta=-23.9333155 -> V=1.0000025, theta=0.0
% INFO    : Bus 3503	: V=1.03473677, theta=-15.8130154 -> V=1.0000025, theta=0.0
% INFO    : Bus 3504	: V=1.04962894, theta=-12.6687536 -> V=1.044445, theta=0.0
% INFO    : Bus 3505	: V=1.05956236, theta=-15.1867125 -> V=1.044445, theta=0.0
% INFO    : Bus 3506	: V=1.012928, theta=-10.2561273 -> V=0.975, theta=0.0
% INFO    : Bus 3507	: V=1.01191609, theta=-10.2561273 -> V=0.999999, theta=0.0
% INFO    : Bus 3508	: V=1.02301941, theta=-18.0316217 -> V=0.999999, theta=0.0
% INFO    : Bus 3509	: V=1.03171791, theta=-17.9319456 -> V=0.999999, theta=0.0
% INFO    : Bus 3510	: V=1.05018794, theta=-13.5917036 -> V=1.0111115, theta=0.0
% INFO    : Bus 3511	: V=1.04248727, theta=-48.1092948 -> V=1.0079355, theta=0.0
% INFO    : Bus 3512	: V=1.0261133, theta=-38.3554191 -> V=1.022224, theta=0.0
% INFO    : Bus 3513	: V=1.01757388, theta=-22.6982305 -> V=0.999999, theta=0.0
% INFO    : Bus 3514	: V=1.02208454, theta=-11.5298293 -> V=1.0158755, theta=0.0
% INFO    : Bus 3515	: V=1.05391877, theta=-20.8148395 -> V=1.022224, theta=0.0
% INFO    : Bus 3516	: V=1.08345, theta=-10.6513211 -> V=1.07237, theta=0.0
% INFO    : Bus 3517	: V=1.08405864, theta=-10.648259 -> V=1.07237, theta=0.0
% INFO    : Bus 3518	: V=1.04003008, theta=-15.4440706 -> V=1.0158755, theta=0.0
% INFO    : Bus 3519	: V=1.07200353, theta=-12.2420734 -> V=1.0377785, theta=0.0
% INFO    : Bus 3520	: V=1.05369924, theta=-11.227385 -> V=1.0000025, theta=0.0
% INFO    : Bus 3521	: V=1.06329327, theta=-8.8853601 -> V=1.0111115, theta=0.0
% INFO    : Bus 3522	: V=1.05188247, theta=-13.6774451 -> V=0.999999, theta=0.0
% INFO    : Bus 3523	: V=1.04688452, theta=-12.9276595 -> V=0.999999, theta=0.0
% INFO    : Bus 3524	: V=1.05721882, theta=-9.71687236 -> V=1.0111115, theta=0.0
% INFO    : Bus 3525	: V=1.04404597, theta=-23.6336994 -> V=1.022224, theta=0.0
% INFO    : Bus 3526	: V=1.0166959, theta=-6.62296766 -> V=1.0158755, theta=0.0
% INFO    : Bus 3527	: V=1.031353, theta=-23.0703934 -> V=1.022224, theta=0.0
% INFO    : Bus 3528	: V=1.02630932, theta=-11.536086 -> V=1.0000025, theta=0.0
% INFO    : Bus 3529	: V=1.0774461, theta=-15.5054055 -> V=1.046665, theta=0.0
% INFO    : Bus 3530	: V=1.05170251, theta=-11.0605224 -> V=1.06579, theta=0.0
% INFO    : Bus 3531	: V=0.988406827, theta=-13.5471784 -> V=1.015872, theta=0.0
% INFO    : Bus 3532	: V=1.02827476, theta=-5.50400694 -> V=1.0158755, theta=0.0
% INFO    : Bus 3533	: V=1.01218376, theta=-18.251674 -> V=1.0000005, theta=0.0
% INFO    : Bus 3534	: V=1.05101397, theta=-17.886413 -> V=1.033334, theta=0.0
% INFO    : Bus 3535	: V=1.05093648, theta=-17.9046677 -> V=1.033334, theta=0.0
% INFO    : Bus 3536	: V=1.03077273, theta=-18.1394791 -> V=1.0000025, theta=0.0
% INFO    : Bus 3537	: V=1.03098457, theta=-18.1352144 -> V=1.0000025, theta=0.0
% INFO    : Bus 3538	: V=1.05678336, theta=-6.44577624 -> V=1.046665, theta=0.0
% INFO    : Bus 3539	: V=1.06344791, theta=-8.69706778 -> V=1.0111115, theta=0.0
% INFO    : Bus 3540	: V=1.05928213, theta=-6.44009781 -> V=1.0088895, theta=0.0
% INFO    : Bus 3541	: V=1.05387181, theta=-9.73510633 -> V=1.0111115, theta=0.0
% INFO    : Bus 3542	: V=1.03008715, theta=-23.7278952 -> V=1.0000025, theta=0.0
% INFO    : Bus 3543	: V=1.00728298, theta=-14.2942558 -> V=1.0158755, theta=0.0
% INFO    : Bus 3544	: V=1.05425212, theta=-9.4156155 -> V=1.0377785, theta=0.0
% INFO    : Bus 3545	: V=1.03, theta=-12.5918568 -> V=0.999999, theta=0.0
% INFO    : Bus 3546	: V=1.04786015, theta=-37.107501 -> V=1.0079355, theta=0.0
% INFO    : Bus 3547	: V=1.06496564, theta=-32.9169023 -> V=1.04444, theta=0.0
% INFO    : Bus 3548	: V=1.02161914, theta=-15.7469392 -> V=1.015872, theta=0.0
% INFO    : Bus 3549	: V=1.04644552, theta=-10.2127255 -> V=1.0000025, theta=0.0
% INFO    : Bus 3550	: V=1.12059596, theta=5.61644977 -> V=1.0424305, theta=0.0
% INFO    : Bus 3551	: V=1.0299516, theta=2.16375684 -> V=1.0158755, theta=0.0
% INFO    : Bus 3552	: V=0.996667157, theta=-51.5875878 -> V=1.0079355, theta=0.0
% INFO    : Bus 3553	: V=1.0326881, theta=-33.0117379 -> V=1.022224, theta=0.0
% INFO    : Bus 3554	: V=1.05742882, theta=-16.7600331 -> V=1.000264, theta=0.0
% INFO    : Bus 3555	: V=1.01787487, theta=-32.8071801 -> V=1.015872, theta=0.0
% INFO    : Bus 3556	: V=1.0011149, theta=-23.0746 -> V=1.0000005, theta=0.0
% INFO    : Bus 3557	: V=1.05758543, theta=-18.2552141 -> V=1.046665, theta=0.0
% INFO    : Bus 3558	: V=1.01725822, theta=-23.4052856 -> V=1.0000025, theta=0.0
% INFO    : Bus 3559	: V=1.02007657, theta=-25.8091833 -> V=1.0000025, theta=0.0
% INFO    : Bus 3560	: V=1.02035986, theta=-12.5863359 -> V=1.0158755, theta=0.0
% INFO    : Bus 3561	: V=1.05670877, theta=-10.1483544 -> V=1.0377785, theta=0.0
% INFO    : Bus 3562	: V=1.02071033, theta=-22.6616003 -> V=1.0000005, theta=0.0
% INFO    : Bus 3563	: V=1.06930915, theta=-18.9368541 -> V=1.046665, theta=0.0
% INFO    : Bus 3564	: V=1.06931042, theta=-18.9368651 -> V=1.046665, theta=0.0
% INFO    : Bus 3565	: V=1.02073733, theta=-22.5814753 -> V=1.0000005, theta=0.0
% INFO    : Bus 3566	: V=1.0693375, theta=-18.9308164 -> V=1.046665, theta=0.0
% INFO    : Bus 3567	: V=1.00970375, theta=1.38760624 -> V=1.0158755, theta=0.0
% INFO    : Bus 3568	: V=1.04428488, theta=-37.335256 -> V=1.022224, theta=0.0
% INFO    : Bus 3569	: V=1.04108252, theta=-28.4299365 -> V=1.0000025, theta=0.0
% INFO    : Bus 3570	: V=1.03408891, theta=-25.1440587 -> V=1.000001, theta=0.0
% INFO    : Bus 3571	: V=1.06021533, theta=-27.4029908 -> V=1.022224, theta=0.0
% INFO    : Bus 3572	: V=1.02395471, theta=-19.945184 -> V=0.999999, theta=0.0
% INFO    : Bus 3573	: V=1.02015367, theta=-17.4294337 -> V=1.0158755, theta=0.0
% INFO    : Bus 3574	: V=1.04940076, theta=-13.9833676 -> V=1.0377785, theta=0.0
% INFO    : Bus 3575	: V=1.077097, theta=-15.8088832 -> V=1.046665, theta=0.0
% INFO    : Bus 3576	: V=1.03354843, theta=-13.5209119 -> V=0.999999, theta=0.0
% INFO    : Bus 3577	: V=1.00916378, theta=-50.7596216 -> V=1.0079355, theta=0.0
% INFO    : Bus 3578	: V=1.04921622, theta=-24.0156302 -> V=1.0000025, theta=0.0
% INFO    : Bus 3579	: V=1.00304287, theta=-6.44550557 -> V=0.999999, theta=0.0
% INFO    : Bus 3580	: V=1.05297314, theta=-5.11419093 -> V=1.0111115, theta=0.0
% INFO    : Bus 3581	: V=1.07468849, theta=-11.4309753 -> V=1.072365, theta=0.0
% INFO    : Bus 3582	: V=1.07434406, theta=-1.56398772 -> V=1.072365, theta=0.0
% INFO    : Bus 3583	: V=1.01250427, theta=-29.6957048 -> V=1.015872, theta=0.0
% INFO    : Bus 3584	: V=1.04591909, theta=-18.1443632 -> V=1.027779, theta=0.0
% INFO    : Bus 3585	: V=1.04804253, theta=-20.3166371 -> V=1.027779, theta=0.0
% INFO    : Bus 3586	: V=1.03492465, theta=-14.5094401 -> V=1.0158755, theta=0.0
% INFO    : Bus 3587	: V=1.028, theta=-8.26983643 -> V=0.975, theta=0.0
% INFO    : Bus 3588	: V=1.019, theta=-6.45688202 -> V=0.975, theta=0.0
% INFO    : Bus 3589	: V=1.03451868, theta=-10.7015424 -> V=0.999999, theta=0.0
% INFO    : Bus 3590	: V=1.03123812, theta=-10.7527181 -> V=0.999999, theta=0.0
% INFO    : Bus 3591	: V=1.01112607, theta=-17.8963079 -> V=1.0158755, theta=0.0
% INFO    : Bus 3592	: V=1.03782326, theta=-18.0766936 -> V=1.0158755, theta=0.0
% INFO    : Bus 3593	: V=1.02245826, theta=-13.9458461 -> V=1.0, theta=0.0
% INFO    : Bus 3594	: V=1.07143125, theta=-16.9032081 -> V=1.046665, theta=0.0
% INFO    : Bus 3595	: V=0.991291683, theta=-12.4192067 -> V=1.015872, theta=0.0
% INFO    : Bus 3596	: V=1.06041776, theta=-9.41727567 -> V=1.046665, theta=0.0
% INFO    : Bus 3597	: V=1.00126512, theta=-23.5677848 -> V=1.015872, theta=0.0
% INFO    : Bus 3598	: V=1.04068902, theta=-19.6505526 -> V=1.046665, theta=0.0
% INFO    : Bus 3599	: V=1.06944906, theta=-6.94801517 -> V=1.016666, theta=0.0
% INFO    : Bus 3600	: V=1.08, theta=-16.4481655 -> V=1.002375, theta=0.0
% INFO    : Bus 3601	: V=1.0450598, theta=-24.5025989 -> V=1.0000025, theta=0.0
% INFO    : Bus 3602	: V=1.0744597, theta=-21.2621442 -> V=1.000001, theta=0.0
% INFO    : Bus 3603	: V=1.06831061, theta=-18.8735922 -> V=1.044445, theta=0.0
% INFO    : Bus 3604	: V=1.02519448, theta=-45.880404 -> V=1.0079355, theta=0.0
% INFO    : Bus 3605	: V=1.06677207, theta=-41.1356058 -> V=1.04444, theta=0.0
% INFO    : Bus 3606	: V=1.025, theta=-9.11949535 -> V=0.999999, theta=0.0
% INFO    : Bus 3607	: V=1.07590508, theta=-0.0514563448 -> V=1.072365, theta=0.0
% INFO    : Bus 3608	: V=1.03666603, theta=-23.9739925 -> V=1.000001, theta=0.0
% INFO    : Bus 3609	: V=1.05405188, theta=-10.0829949 -> V=1.0111115, theta=0.0
% INFO    : Bus 3610	: V=1.02013754, theta=-12.4892166 -> V=0.999999, theta=0.0
% INFO    : Bus 3611	: V=1.04202772, theta=-8.04852553 -> V=1.0111115, theta=0.0
% INFO    : Bus 3612	: V=1.05855123, theta=-9.96618031 -> V=1.0000025, theta=0.0
% INFO    : Bus 3613	: V=1.03429038, theta=-16.8569295 -> V=1.015872, theta=0.0
% INFO    : Bus 3614	: V=1.06587108, theta=-15.3580715 -> V=1.046665, theta=0.0
% INFO    : Bus 3615	: V=1.06494859, theta=-15.9319367 -> V=1.046665, theta=0.0
% INFO    : Bus 3616	: V=1.07807511, theta=-14.9607795 -> V=1.046665, theta=0.0
% INFO    : Bus 3617	: V=1.07462349, theta=-10.6255228 -> V=1.073685, theta=0.0
% INFO    : Bus 3618	: V=1.07457522, theta=-10.8659981 -> V=1.073685, theta=0.0
% INFO    : Bus 3619	: V=1.01133472, theta=-33.4102575 -> V=1.022224, theta=0.0
% INFO    : Bus 3620	: V=1.01510114, theta=-32.2464605 -> V=1.022224, theta=0.0
% INFO    : Bus 3621	: V=1.0181249, theta=-30.6753601 -> V=1.015872, theta=0.0
% INFO    : Bus 3622	: V=1.05345301, theta=-27.7706396 -> V=1.046665, theta=0.0
% INFO    : Bus 3623	: V=1.03607889, theta=-26.5075054 -> V=1.0000025, theta=0.0
% INFO    : Bus 3624	: V=1.0133538, theta=-24.834512 -> V=0.999999, theta=0.0
% INFO    : Bus 3625	: V=1.06658207, theta=-36.3171011 -> V=1.04444, theta=0.0
% INFO    : Bus 3626	: V=1.06723338, theta=-30.4500314 -> V=1.07237, theta=0.0
% INFO    : Bus 3627	: V=1.01895614, theta=-14.433558 -> V=0.999999, theta=0.0
% INFO    : Bus 3628	: V=1.04006493, theta=-16.0734337 -> V=1.027779, theta=0.0
% INFO    : Bus 3629	: V=1.04008293, theta=-16.071619 -> V=1.027779, theta=0.0
% INFO    : Bus 3630	: V=1.01210797, theta=-29.5045671 -> V=1.015872, theta=0.0
% INFO    : Bus 3631	: V=1.01201671, theta=-29.5284261 -> V=1.015872, theta=0.0
% INFO    : Bus 3632	: V=1.04009139, theta=-16.0696352 -> V=1.027779, theta=0.0
% INFO    : Bus 3633	: V=1.07913792, theta=-12.8155847 -> V=1.046665, theta=0.0
% INFO    : Bus 3634	: V=1.01068969, theta=-17.2296546 -> V=1.0000005, theta=0.0
% INFO    : Bus 3635	: V=1.0738377, theta=-15.6646082 -> V=1.046665, theta=0.0
% INFO    : Bus 3636	: V=1.00354133, theta=-25.842235 -> V=1.015872, theta=0.0
% INFO    : Bus 3637	: V=1.0236339, theta=-12.6957065 -> V=0.999999, theta=0.0
% INFO    : Bus 3638	: V=1.04402267, theta=-16.2518033 -> V=0.999999, theta=0.0
% INFO    : Bus 3639	: V=1.01876014, theta=-32.2742932 -> V=1.022224, theta=0.0
% INFO    : Bus 3640	: V=1.06252214, theta=-5.90990359 -> V=0.9888895, theta=0.0
% INFO    : Bus 3641	: V=1.03958497, theta=-23.0500862 -> V=1.0000025, theta=0.0
% INFO    : Bus 3642	: V=1.01573648, theta=-18.4457075 -> V=1.0000005, theta=0.0
% INFO    : Bus 3643	: V=1.0062155, theta=-19.0080899 -> V=1.0000005, theta=0.0
% INFO    : Bus 3644	: V=1.0079619, theta=-21.2865049 -> V=0.999999, theta=0.0
% INFO    : Bus 3645	: V=1.04644176, theta=-21.0907299 -> V=1.022224, theta=0.0
% INFO    : Bus 3646	: V=1.00123046, theta=-16.3429777 -> V=1.0158755, theta=0.0
% INFO    : Bus 3647	: V=1.01163725, theta=1.33141014 -> V=1.0158755, theta=0.0
% INFO    : Bus 3648	: V=0.959953838, theta=-26.8110159 -> V=1.0000025, theta=0.0
% INFO    : Bus 3649	: V=1.02856722, theta=-17.5771404 -> V=1.015872, theta=0.0
% INFO    : Bus 3650	: V=1.04662347, theta=-13.8386789 -> V=1.046665, theta=0.0
% INFO    : Bus 3651	: V=1.03822127, theta=-38.2328032 -> V=1.022224, theta=0.0
% INFO    : Bus 3652	: V=1.02824439, theta=-5.50308251 -> V=1.0158755, theta=0.0
% INFO    : Bus 3653	: V=1.03, theta=-17.4505374 -> V=1.0000025, theta=0.0
% INFO    : Bus 3654	: V=1.02495788, theta=-4.62845601 -> V=1.0158755, theta=0.0
% INFO    : Bus 3655	: V=1.00902474, theta=-6.99616879 -> V=1.0158755, theta=0.0
% INFO    : Bus 3656	: V=1.03934907, theta=-4.99524457 -> V=1.0158755, theta=0.0
% INFO    : Bus 3657	: V=1.04834249, theta=-1.42424982 -> V=1.0377785, theta=0.0
% INFO    : Bus 3658	: V=1.01989246, theta=-22.7954341 -> V=1.015872, theta=0.0
% INFO    : Bus 3659	: V=0.983598182, theta=-28.1892524 -> V=1.0000025, theta=0.0
% INFO    : Bus 3660	: V=1.00866817, theta=-13.4814448 -> V=0.999999, theta=0.0
% INFO    : Bus 3661	: V=1.00833035, theta=-13.4579922 -> V=0.999999, theta=0.0
% INFO    : Bus 3662	: V=1.01689131, theta=-11.1777849 -> V=1.0158755, theta=0.0
% INFO    : Bus 3663	: V=1.02021967, theta=-40.0531561 -> V=1.0079355, theta=0.0
% INFO    : Bus 3664	: V=1.02774744, theta=3.28858255 -> V=1.0158755, theta=0.0
% INFO    : Bus 3665	: V=1.07059515, theta=5.75180659 -> V=1.0377785, theta=0.0
% INFO    : Bus 3666	: V=1.01764193, theta=-45.1830376 -> V=1.0079355, theta=0.0
% INFO    : Bus 3667	: V=1.06803646, theta=-40.0227332 -> V=1.04444, theta=0.0
% INFO    : Bus 3668	: V=0.979686493, theta=-12.9666236 -> V=0.999999, theta=0.0
% INFO    : Bus 3669	: V=1.00219335, theta=-17.2914092 -> V=0.999999, theta=0.0
% INFO    : Bus 3670	: V=1.03265125, theta=-16.699499 -> V=0.999999, theta=0.0
% INFO    : Bus 3671	: V=1.0547038, theta=-7.05398213 -> V=1.016666, theta=0.0
% INFO    : Bus 3672	: V=1.06375889, theta=-3.97459638 -> V=1.006667, theta=0.0
% INFO    : Bus 3673	: V=1.01023101, theta=-21.1036008 -> V=1.0158755, theta=0.0
% INFO    : Bus 3674	: V=1.02395712, theta=-14.1010651 -> V=0.999999, theta=0.0
% INFO    : Bus 3675	: V=1.06482584, theta=-14.8609577 -> V=1.027779, theta=0.0
% INFO    : Bus 3676	: V=1.08801445, theta=-12.0400186 -> V=1.047445, theta=0.0
% INFO    : Bus 3677	: V=1.02640352, theta=3.14553542 -> V=1.0158755, theta=0.0
% INFO    : Bus 3678	: V=1.02651035, theta=3.24079059 -> V=1.0158755, theta=0.0
% INFO    : Bus 3679	: V=1.04347656, theta=-28.9746621 -> V=1.0000025, theta=0.0
% INFO    : Bus 3680	: V=1.06085815, theta=-22.1589434 -> V=1.044445, theta=0.0
% INFO    : Bus 3681	: V=1.04030251, theta=-10.7023586 -> V=0.999999, theta=0.0
% INFO    : Bus 3682	: V=1.04212473, theta=-10.8719266 -> V=0.999999, theta=0.0
% INFO    : Bus 3683	: V=1.03659528, theta=-1.87805295 -> V=1.0000025, theta=0.0
% INFO    : Bus 3684	: V=1.0475853, theta=-16.7731962 -> V=1.044445, theta=0.0
% INFO    : Bus 3685	: V=1.03005359, theta=-30.509942 -> V=1.015872, theta=0.0
% INFO    : Bus 3686	: V=1.03215775, theta=-16.8763164 -> V=1.0158755, theta=0.0
% INFO    : Bus 3687	: V=1.016, theta=-12.3064136 -> V=0.999999, theta=0.0
% INFO    : Bus 3688	: V=1.05605568, theta=-8.62017613 -> V=1.0377785, theta=0.0
% INFO    : Bus 3689	: V=1.01740924, theta=-11.9039154 -> V=0.999999, theta=0.0
% INFO    : Bus 3690	: V=1.06044475, theta=-5.37921369 -> V=0.9888895, theta=0.0
% INFO    : Bus 3691	: V=1.06139542, theta=-9.53411501 -> V=1.0000025, theta=0.0
% INFO    : Bus 3692	: V=1.04914761, theta=-10.312743 -> V=1.0377785, theta=0.0
% INFO    : Bus 3693	: V=1.015, theta=-11.4736665 -> V=0.999999, theta=0.0
% INFO    : Bus 3694	: V=1.03752576, theta=-12.4763211 -> V=1.022222, theta=0.0
% INFO    : Bus 3695	: V=1.04436064, theta=-8.27959831 -> V=1.0111115, theta=0.0
% INFO    : Bus 3696	: V=1.02827539, theta=-48.1647524 -> V=1.0079355, theta=0.0
% INFO    : Bus 3697	: V=1.0159778, theta=-21.695824 -> V=0.999999, theta=0.0
% INFO    : Bus 3698	: V=1.01076591, theta=-6.35948642 -> V=1.0158755, theta=0.0
% INFO    : Bus 3699	: V=0.995132788, theta=-57.4593519 -> V=1.0079355, theta=0.0
% INFO    : Bus 3700	: V=1.00172141, theta=-48.3905951 -> V=1.0079355, theta=0.0
% INFO    : Bus 3701	: V=1.03401112, theta=-47.3649646 -> V=1.0079355, theta=0.0
% INFO    : Bus 3702	: V=1.02220239, theta=-14.7815262 -> V=0.999999, theta=0.0
% INFO    : Bus 3703	: V=1.00572074, theta=-19.3547722 -> V=1.0158755, theta=0.0
% INFO    : Bus 3704	: V=1.05731561, theta=-18.044862 -> V=1.033334, theta=0.0
% INFO    : Bus 3705	: V=1.07135937, theta=-24.8912798 -> V=1.04444, theta=0.0
% INFO    : Bus 3706	: V=1.07916659, theta=-21.3121217 -> V=1.07237, theta=0.0
% INFO    : Bus 3707	: V=1.03089548, theta=-20.5672669 -> V=1.0158755, theta=0.0
% INFO    : Bus 3708	: V=1.06785643, theta=0.628192702 -> V=0.9888895, theta=0.0
% INFO    : Bus 3709	: V=0.996523288, theta=-21.2464169 -> V=1.0000005, theta=0.0
% INFO    : Bus 3710	: V=1.01045648, theta=-21.2136735 -> V=1.0000025, theta=0.0
% INFO    : Bus 3711	: V=1.0540031, theta=-16.2377092 -> V=1.044445, theta=0.0
% INFO    : Bus 3712	: V=0.980183117, theta=-21.2946416 -> V=1.015872, theta=0.0
% INFO    : Bus 3713	: V=1.04598799, theta=-19.3092519 -> V=1.046665, theta=0.0
% INFO    : Bus 3714	: V=1.0132695, theta=-45.9656276 -> V=1.0079355, theta=0.0
% INFO    : Bus 3715	: V=1.05509932, theta=-28.0704476 -> V=1.022224, theta=0.0
% INFO    : Bus 3716	: V=1.062, theta=-15.6949385 -> V=1.027779, theta=0.0
% INFO    : Bus 3717	: V=1.01205727, theta=-10.0536803 -> V=0.999999, theta=0.0
% INFO    : Bus 3718	: V=1.031, theta=-10.9270141 -> V=0.999999, theta=0.0
% INFO    : Bus 3719	: V=1.02056361, theta=-7.02929744 -> V=1.0158755, theta=0.0
% INFO    : Bus 3720	: V=1.01469045, theta=-22.763037 -> V=1.0000005, theta=0.0
% INFO    : Bus 3721	: V=0.998173044, theta=-26.8333647 -> V=1.027779, theta=0.0
% INFO    : Bus 3722	: V=1.03858544, theta=-29.6634768 -> V=1.0000025, theta=0.0
% INFO    : Bus 3723	: V=1.05599788, theta=-37.5212736 -> V=1.0079355, theta=0.0
% INFO    : Bus 3724	: V=1.04954462, theta=-39.5050475 -> V=1.0079355, theta=0.0
% INFO    : Bus 3725	: V=1.05948427, theta=-33.4040047 -> V=1.04444, theta=0.0
% INFO    : Bus 3726	: V=1.05947978, theta=-33.4038568 -> V=1.04444, theta=0.0
% INFO    : Bus 3727	: V=1.05947426, theta=-33.4037076 -> V=1.04444, theta=0.0
% INFO    : Bus 3728	: V=0.943683152, theta=-6.22055638 -> V=0.9444445, theta=0.0
% INFO    : Bus 3729	: V=1.01291437, theta=-6.89240981 -> V=0.999999, theta=0.0
% INFO    : Bus 3730	: V=1.04100461, theta=-4.0465761 -> V=1.003335, theta=0.0
% INFO    : Bus 3731	: V=1.05211525, theta=-7.26298976 -> V=1.0111115, theta=0.0
% INFO    : Bus 3732	: V=1.01406876, theta=0.733998988 -> V=1.0158755, theta=0.0
% INFO    : Bus 3733	: V=0.991387195, theta=-19.4132648 -> V=1.0000005, theta=0.0
% INFO    : Bus 3734	: V=1.01015003, theta=-19.3218668 -> V=1.0000005, theta=0.0
% INFO    : Bus 3735	: V=1.03964717, theta=-21.3293622 -> V=1.027779, theta=0.0
% INFO    : Bus 3736	: V=1.07320647, theta=-18.2048703 -> V=1.046665, theta=0.0
% INFO    : Bus 3737	: V=1.0560391, theta=-37.522068 -> V=1.0079355, theta=0.0
% INFO    : Bus 3738	: V=1.05254764, theta=-37.8422084 -> V=1.04444, theta=0.0
% INFO    : Bus 3739	: V=1.05944713, theta=-33.402725 -> V=1.04444, theta=0.0
% INFO    : Bus 3740	: V=1.02269748, theta=-6.64331484 -> V=1.0158755, theta=0.0
% INFO    : Bus 3741	: V=1.02489078, theta=-17.1681794 -> V=1.0000005, theta=0.0
% INFO    : Bus 3742	: V=1.0245184, theta=-17.18917 -> V=1.0000005, theta=0.0
% INFO    : Bus 3743	: V=0.989225315, theta=-23.0782529 -> V=1.015872, theta=0.0
% INFO    : Bus 3744	: V=1.03928222, theta=-18.6348057 -> V=1.046665, theta=0.0
% INFO    : Bus 3745	: V=1.03169644, theta=-13.0932 -> V=0.999999, theta=0.0
% INFO    : Bus 3746	: V=1.06259172, theta=-14.3171936 -> V=1.027779, theta=0.0
% INFO    : Bus 3747	: V=1.08823241, theta=-12.1533721 -> V=1.047335, theta=0.0
% INFO    : Bus 3748	: V=1.04039397, theta=-17.8496343 -> V=1.022224, theta=0.0
% INFO    : Bus 3749	: V=1.02, theta=-18.6751319 -> V=0.999999, theta=0.0
% INFO    : Bus 3750	: V=0.995405176, theta=-25.8397047 -> V=1.0000025, theta=0.0
% INFO    : Bus 3751	: V=0.999175153, theta=-25.2606004 -> V=1.0000025, theta=0.0
% INFO    : Bus 3752	: V=1.04562866, theta=-18.16046 -> V=1.046665, theta=0.0
% INFO    : Bus 3753	: V=1.04128572, theta=-14.8317393 -> V=1.06579, theta=0.0
% INFO    : Bus 3754	: V=1.04837798, theta=-28.6522848 -> V=1.022224, theta=0.0
% INFO    : Bus 3755	: V=1.0101934, theta=-12.257106 -> V=1.015872, theta=0.0
% INFO    : Bus 3756	: V=1.01960943, theta=-35.6122169 -> V=1.022224, theta=0.0
% INFO    : Bus 3757	: V=1.05906868, theta=-31.4240524 -> V=1.04444, theta=0.0
% INFO    : Bus 3758	: V=1.06163208, theta=-39.4938001 -> V=1.022224, theta=0.0
% INFO    : Bus 3759	: V=1.02043971, theta=-7.96317149 -> V=0.984126, theta=0.0
% INFO    : Bus 3760	: V=1.05350126, theta=-5.86204163 -> V=0.9888895, theta=0.0
% INFO    : Bus 3761	: V=1.01245267, theta=-51.4391759 -> V=1.0079355, theta=0.0
% INFO    : Bus 3762	: V=0.998, theta=-12.7920307 -> V=1.0158755, theta=0.0
% INFO    : Bus 3763	: V=1.03452728, theta=-19.373536 -> V=1.0000005, theta=0.0
% INFO    : Bus 3764	: V=1.00725554, theta=-6.47761435 -> V=1.0158755, theta=0.0
% INFO    : Bus 3765	: V=1.04985336, theta=-1.52439553 -> V=1.0377785, theta=0.0
% INFO    : Bus 3766	: V=1.01579552, theta=0.620379692 -> V=1.0158755, theta=0.0
% INFO    : Bus 3767	: V=1.02319067, theta=-33.1760509 -> V=1.027779, theta=0.0
% INFO    : Bus 3768	: V=1.03713534, theta=-19.6759223 -> V=1.046665, theta=0.0
% INFO    : Bus 3769	: V=1.0445584, theta=-19.5078319 -> V=1.022224, theta=0.0
% INFO    : Bus 3770	: V=1.04390986, theta=-19.2718722 -> V=1.022224, theta=0.0
% INFO    : Bus 3771	: V=1.07867949, theta=4.21265668 -> V=1.0396535, theta=0.0
% INFO    : Bus 3772	: V=1.01654609, theta=1.20346485 -> V=1.0158755, theta=0.0
% INFO    : Bus 3773	: V=1.02454902, theta=-8.04604464 -> V=1.0158755, theta=0.0
% INFO    : Bus 3774	: V=1.03142736, theta=-13.8605254 -> V=1.0000005, theta=0.0
% INFO    : Bus 3775	: V=1.08051883, theta=-8.11682236 -> V=1.073685, theta=0.0
% INFO    : Bus 3776	: V=1.02023966, theta=-13.483055 -> V=1.0158755, theta=0.0
% INFO    : Bus 3777	: V=0.986727118, theta=-21.0333704 -> V=1.015872, theta=0.0
% INFO    : Bus 3778	: V=0.982228817, theta=-21.0619806 -> V=1.015872, theta=0.0
% INFO    : Bus 3779	: V=1.0130188, theta=-20.821879 -> V=1.015872, theta=0.0
% INFO    : Bus 3780	: V=1.04135662, theta=-19.4901586 -> V=1.046665, theta=0.0
% INFO    : Bus 3781	: V=1.04140369, theta=-19.4935428 -> V=1.046665, theta=0.0
% INFO    : Bus 3782	: V=1.04126284, theta=-19.4947638 -> V=1.046665, theta=0.0
% INFO    : Bus 3783	: V=1.02084154, theta=-17.8832195 -> V=1.0000005, theta=0.0
% INFO    : Bus 3784	: V=1.07284057, theta=-12.9249666 -> V=1.046665, theta=0.0
% INFO    : Bus 3785	: V=1.08788032, theta=-7.39517711 -> V=1.073685, theta=0.0
% INFO    : Bus 3786	: V=1.03354141, theta=-30.0809504 -> V=1.022224, theta=0.0
% INFO    : Bus 3787	: V=1.01207847, theta=3.04924707 -> V=1.046665, theta=0.0
% INFO    : Bus 3788	: V=1.01068279, theta=3.26875522 -> V=1.046665, theta=0.0
% INFO    : Bus 3789	: V=1.0652851, theta=-31.1803777 -> V=0.975, theta=0.0
% INFO    : Bus 3790	: V=1.06513973, theta=-31.2466361 -> V=0.975, theta=0.0
% INFO    : Bus 3791	: V=1.06513973, theta=-31.2466361 -> V=0.975, theta=0.0
% INFO    : Bus 3792	: V=1.06532417, theta=-31.1725704 -> V=1.04444, theta=0.0
% INFO    : Bus 3793	: V=1.06513973, theta=-31.2466361 -> V=1.04444, theta=0.0
% INFO    : Bus 3794	: V=1.02675985, theta=-25.1283843 -> V=1.0000025, theta=0.0
% INFO    : Bus 3795	: V=1.02635413, theta=-25.9415113 -> V=1.000001, theta=0.0
% INFO    : Bus 3796	: V=1.00963538, theta=-20.2939487 -> V=1.015872, theta=0.0
% INFO    : Bus 3797	: V=1.05425014, theta=-24.6870165 -> V=1.0000025, theta=0.0
% INFO    : Bus 3798	: V=1.07367297, theta=-20.8473551 -> V=1.0000025, theta=0.0
% INFO    : Bus 3799	: V=1.02552771, theta=-16.4321739 -> V=1.0000005, theta=0.0
% INFO    : Bus 3800	: V=1.03446354, theta=-9.97952659 -> V=1.0000025, theta=0.0
% INFO    : Bus 3801	: V=1.01399938, theta=-13.8360467 -> V=0.999999, theta=0.0
% INFO    : Bus 3802	: V=1.01149446, theta=-27.2714794 -> V=1.0000025, theta=0.0
% INFO    : Bus 3803	: V=1.01204942, theta=-12.9494344 -> V=0.999999, theta=0.0
% INFO    : Bus 3804	: V=1.07789586, theta=-15.7106318 -> V=1.046665, theta=0.0
% INFO    : Bus 3805	: V=1.0778564, theta=-15.7159654 -> V=1.046665, theta=0.0
% INFO    : Bus 3806	: V=1.08041518, theta=5.88329506 -> V=1.05263, theta=0.0
% INFO    : Bus 3807	: V=1.08041509, theta=5.88329506 -> V=1.05263, theta=0.0
% INFO    : Bus 3808	: V=1.08041509, theta=5.88329506 -> V=1.05263, theta=0.0
% INFO    : Bus 3809	: V=1.08041509, theta=5.88329506 -> V=1.05263, theta=0.0
% INFO    : Bus 3810	: V=1.0231229, theta=-5.65780561 -> V=1.0158755, theta=0.0
% INFO    : Bus 3811	: V=1.06857515, theta=-2.69484001 -> V=1.0377785, theta=0.0
% INFO    : Bus 3812	: V=1.0752678, theta=-0.534539111 -> V=1.072365, theta=0.0
% INFO    : Bus 3813	: V=1.03793717, theta=-2.93515508 -> V=0.984126, theta=0.0
% INFO    : Bus 3814	: V=1.06298474, theta=-1.52617267 -> V=1.0377785, theta=0.0
% INFO    : Bus 3815	: V=0.986755365, theta=-9.30583091 -> V=1.0158755, theta=0.0
% INFO    : Bus 3816	: V=1.06171867, theta=-0.286058358 -> V=1.0377785, theta=0.0
% INFO    : Bus 3817	: V=1.07, theta=6.06042743 -> V=0.975, theta=0.0
% INFO    : Bus 3818	: V=1.056, theta=5.54092358 -> V=0.975, theta=0.0
% INFO    : Bus 3819	: V=1.087, theta=5.19479084 -> V=0.975, theta=0.0
% INFO    : Bus 3820	: V=1.06171209, theta=-0.264868312 -> V=1.0377785, theta=0.0
% INFO    : Bus 3821	: V=1.06167043, theta=-0.266922439 -> V=1.0377785, theta=0.0
% INFO    : Bus 3822	: V=1.06177527, theta=-0.26735308 -> V=1.0377785, theta=0.0
% INFO    : Bus 3823	: V=1.03726492, theta=-34.8909736 -> V=1.022224, theta=0.0
% INFO    : Bus 3824	: V=1.03418789, theta=-17.6992505 -> V=1.0158755, theta=0.0
% INFO    : Bus 3825	: V=1.00390896, theta=-8.93894289 -> V=1.0158755, theta=0.0
% INFO    : Bus 3826	: V=1.02575387, theta=-16.5064377 -> V=1.0000005, theta=0.0
% INFO    : Bus 3827	: V=1.04478826, theta=-13.1432088 -> V=1.0000025, theta=0.0
% INFO    : Bus 3828	: V=1.0635594, theta=-19.3560225 -> V=1.046665, theta=0.0
% INFO    : Bus 3829	: V=1.08437519, theta=-15.2278578 -> V=1.0473, theta=0.0
% INFO    : Bus 3830	: V=1.0842383, theta=-15.2370819 -> V=1.04723, theta=0.0
% INFO    : Bus 3831	: V=1.0160148, theta=3.63038657 -> V=1.0158755, theta=0.0
% INFO    : Bus 3832	: V=1.01531068, theta=3.91969579 -> V=1.0158755, theta=0.0
% INFO    : Bus 3833	: V=1.07692586, theta=4.87149858 -> V=1.0381385, theta=0.0
% INFO    : Bus 3834	: V=1.04014606, theta=-19.5994383 -> V=1.046665, theta=0.0
% INFO    : Bus 3835	: V=1.05652351, theta=-3.87185546 -> V=1.033333, theta=0.0
% INFO    : Bus 3836	: V=1.05236317, theta=-5.42122722 -> V=1.033333, theta=0.0
% INFO    : Bus 3837	: V=1.0506024, theta=-11.4038979 -> V=1.0000025, theta=0.0
% INFO    : Bus 3838	: V=1.05087556, theta=-24.1777856 -> V=1.0000025, theta=0.0
% INFO    : Bus 3839	: V=1.01883697, theta=-13.3264245 -> V=0.999999, theta=0.0
% INFO    : Bus 3840	: V=1.03148411, theta=-20.921723 -> V=0.999999, theta=0.0
% INFO    : Bus 3841	: V=1.03404352, theta=-15.492136 -> V=0.999999, theta=0.0
% INFO    : Bus 3842	: V=1.04889793, theta=-14.0406167 -> V=1.0111115, theta=0.0
% INFO    : Bus 3843	: V=1.016, theta=-11.7228562 -> V=0.999999, theta=0.0
% INFO    : Bus 3844	: V=1.02405684, theta=-21.8062904 -> V=1.022224, theta=0.0
% INFO    : Bus 3845	: V=1.01773037, theta=-29.3302509 -> V=1.0000025, theta=0.0
% INFO    : Bus 3846	: V=1.0479884, theta=-20.3240619 -> V=1.027779, theta=0.0
% INFO    : Bus 3847	: V=1.04168107, theta=-25.9877615 -> V=1.046665, theta=0.0
% INFO    : Bus 3848	: V=1.0302965, theta=-17.1945851 -> V=1.022224, theta=0.0
% INFO    : Bus 3849	: V=1.04720712, theta=-20.123408 -> V=1.022224, theta=0.0
% INFO    : Bus 3850	: V=1.01964248, theta=-14.6907246 -> V=0.999999, theta=0.0
% INFO    : Bus 3851	: V=1.0327, theta=-27.2256609 -> V=1.0000025, theta=0.0
% INFO    : Bus 3852	: V=1.06360521, theta=-23.8684711 -> V=1.044445, theta=0.0
% INFO    : Bus 3853	: V=1.0175603, theta=-12.5367501 -> V=0.999999, theta=0.0
% INFO    : Bus 3854	: V=1.032, theta=-23.092294 -> V=1.0000025, theta=0.0
% INFO    : Bus 3855	: V=1.03783355, theta=-14.2635553 -> V=0.999999, theta=0.0
% INFO    : Bus 3856	: V=1.04950785, theta=-14.7636787 -> V=1.001254, theta=0.0
% INFO    : Bus 3857	: V=1.03873578, theta=-10.4513878 -> V=1.0111115, theta=0.0
% INFO    : Bus 3858	: V=1.01913845, theta=-6.77812501 -> V=1.0158755, theta=0.0
% INFO    : Bus 3859	: V=1.03030692, theta=-15.8808925 -> V=0.999999, theta=0.0
% INFO    : Bus 3860	: V=1.0224507, theta=-5.78214981 -> V=1.0158755, theta=0.0
% INFO    : Bus 3861	: V=1.07970323, theta=-17.8998165 -> V=1.046665, theta=0.0
% INFO    : Bus 3862	: V=1.069854, theta=-17.8063919 -> V=1.046665, theta=0.0
% INFO    : Bus 3863	: V=1.03898892, theta=-19.7203438 -> V=1.046665, theta=0.0
% INFO    : Bus 3864	: V=1.04172289, theta=-21.0267883 -> V=1.022224, theta=0.0
% INFO    : Bus 3865	: V=1.02508389, theta=-14.0973865 -> V=0.999999, theta=0.0
% INFO    : Bus 3866	: V=1.01144365, theta=-13.2212111 -> V=0.999999, theta=0.0
% INFO    : Bus 3867	: V=1.03267503, theta=-26.819504 -> V=1.022224, theta=0.0
% INFO    : Bus 3868	: V=1.0273692, theta=-26.8634683 -> V=1.022224, theta=0.0
% INFO    : Bus 3869	: V=1.04, theta=-27.3522979 -> V=1.022224, theta=0.0
% INFO    : Bus 3870	: V=1.04573403, theta=-25.7461306 -> V=1.0000025, theta=0.0
% INFO    : Bus 3871	: V=1.03635544, theta=-26.8401821 -> V=1.015872, theta=0.0
% INFO    : Bus 3872	: V=1.02916975, theta=-5.23732139 -> V=1.0158755, theta=0.0
% INFO    : Bus 3873	: V=1.08822033, theta=-12.1551828 -> V=1.047325, theta=0.0
% INFO    : Bus 3874	: V=1.02700886, theta=-21.3867546 -> V=1.015872, theta=0.0
% INFO    : Bus 3875	: V=1.0440657, theta=-18.3194109 -> V=1.046665, theta=0.0
% INFO    : Bus 3876	: V=1.01817717, theta=-6.16236121 -> V=1.0158755, theta=0.0
% INFO    : Bus 3877	: V=1.03996535, theta=-15.4750195 -> V=1.0000025, theta=0.0
% INFO    : Bus 3878	: V=1.01912609, theta=-26.6504854 -> V=1.0000025, theta=0.0
% INFO    : Bus 3879	: V=1.00763258, theta=-11.1348576 -> V=1.0158755, theta=0.0
% INFO    : Bus 3880	: V=1.05489387, theta=-9.64721962 -> V=1.0377785, theta=0.0
% INFO    : Bus 3881	: V=1.01238609, theta=-17.0223291 -> V=1.0000005, theta=0.0
% INFO    : Bus 3882	: V=1.07396794, theta=-15.6122802 -> V=1.046665, theta=0.0
% INFO    : Bus 3883	: V=1.07726859, theta=-15.5399983 -> V=1.046665, theta=0.0
% INFO    : Bus 3884	: V=1.01869127, theta=-14.9320027 -> V=1.0158755, theta=0.0
% INFO    : Bus 3885	: V=1.01873737, theta=3.44832214 -> V=1.0158755, theta=0.0
% INFO    : Bus 3886	: V=1.01528812, theta=3.9240764 -> V=1.0158755, theta=0.0
% INFO    : Bus 3887	: V=1.01130398, theta=-17.9026365 -> V=1.0158755, theta=0.0
% INFO    : Bus 3888	: V=0.956212081, theta=-25.2561709 -> V=1.0158085, theta=0.0
% INFO    : Bus 3889	: V=1.03257162, theta=-7.984754 -> V=1.0158755, theta=0.0
% INFO    : Bus 3890	: V=1.03071833, theta=-7.15757443 -> V=1.0277795, theta=0.0
% INFO    : Bus 3891	: V=1.02235669, theta=-21.0884548 -> V=1.022224, theta=0.0
% INFO    : Bus 3892	: V=1.00578511, theta=-12.7332222 -> V=1.0158755, theta=0.0
% INFO    : Bus 3893	: V=1.01529298, theta=-20.2861536 -> V=1.0158755, theta=0.0
% INFO    : Bus 3894	: V=1.03223968, theta=-41.7698703 -> V=1.0079355, theta=0.0
% INFO    : Bus 3895	: V=1.03915833, theta=-21.1093165 -> V=1.015872, theta=0.0
% INFO    : Bus 3896	: V=1.02193273, theta=-6.11914222 -> V=1.0158755, theta=0.0
% INFO    : Bus 3897	: V=1.02911854, theta=-31.1007779 -> V=1.022224, theta=0.0
% INFO    : Bus 3898	: V=1.02746054, theta=-10.4176666 -> V=1.0158755, theta=0.0
% INFO    : Bus 3899	: V=1.05942833, theta=-7.81993753 -> V=1.0377785, theta=0.0
% INFO    : Bus 3900	: V=1.02947115, theta=-20.2937133 -> V=1.022224, theta=0.0
% INFO    : Bus 3901	: V=1.03384152, theta=-43.1569089 -> V=1.0079355, theta=0.0
% INFO    : Bus 3902	: V=1.06372487, theta=-38.6258864 -> V=1.04444, theta=0.0
% INFO    : Bus 3903	: V=1.01735372, theta=-22.0872053 -> V=1.0000005, theta=0.0
% INFO    : Bus 3904	: V=1.03093469, theta=-13.8898343 -> V=0.999999, theta=0.0
% INFO    : Bus 3905	: V=1.04098009, theta=-48.8373228 -> V=1.0079355, theta=0.0
% INFO    : Bus 3906	: V=1.08294508, theta=-12.3688903 -> V=1.04676, theta=0.0
% INFO    : Bus 3907	: V=1.07786028, theta=-13.3276165 -> V=1.046665, theta=0.0
% INFO    : Bus 3908	: V=1.08514014, theta=-9.6501367 -> V=1.073685, theta=0.0
% INFO    : Bus 3909	: V=1.04305355, theta=-12.0619017 -> V=1.046665, theta=0.0
% INFO    : Bus 3910	: V=1.04434533, theta=-25.6367003 -> V=1.022224, theta=0.0
% INFO    : Bus 3911	: V=1.05975183, theta=-21.1909556 -> V=1.0233335, theta=0.0
% INFO    : Bus 3912	: V=1.05622407, theta=-18.9737709 -> V=1.046665, theta=0.0
% INFO    : Bus 3913	: V=1.01557741, theta=-20.2701701 -> V=1.015872, theta=0.0
% INFO    : Bus 3914	: V=1.00724957, theta=-22.3581332 -> V=1.015872, theta=0.0
% INFO    : Bus 3915	: V=1.03941002, theta=-19.0180069 -> V=1.022224, theta=0.0
% INFO    : Bus 3916	: V=1.00232408, theta=-0.72706946 -> V=1.0158755, theta=0.0
% INFO    : Bus 3917	: V=1.04739446, theta=-18.2716947 -> V=1.0158755, theta=0.0
% INFO    : Bus 3918	: V=1.06344028, theta=-14.0710983 -> V=1.0377785, theta=0.0
% INFO    : Bus 3919	: V=1.04217449, theta=-26.1627341 -> V=1.0000025, theta=0.0
% INFO    : Bus 3920	: V=1.024, theta=-28.7090283 -> V=1.0000025, theta=0.0
% INFO    : Bus 3921	: V=1.06252861, theta=-5.87957774 -> V=0.9888895, theta=0.0
% INFO    : Bus 3922	: V=1.06251688, theta=-5.87500453 -> V=0.9888895, theta=0.0
% INFO    : Bus 3923	: V=1.03730763, theta=-24.540449 -> V=1.022224, theta=0.0
% INFO    : Bus 3924	: V=1.06116875, theta=-13.8532359 -> V=1.015874, theta=0.0
% INFO    : Bus 3925	: V=1.05213649, theta=-13.7183123 -> V=1.015874, theta=0.0
% INFO    : Bus 3926	: V=1.05746716, theta=-9.35132008 -> V=1.026667, theta=0.0
% INFO    : Bus 3927	: V=1.07015735, theta=1.17450432 -> V=0.9888895, theta=0.0
% INFO    : Bus 3928	: V=1.01065091, theta=-26.1691736 -> V=1.015872, theta=0.0
% INFO    : Bus 3929	: V=1.03322801, theta=-25.9781209 -> V=1.0233335, theta=0.0
% INFO    : Bus 3930	: V=1.05804021, theta=-24.0427324 -> V=1.0000025, theta=0.0
% INFO    : Bus 3931	: V=1.0204602, theta=-21.5991762 -> V=1.015872, theta=0.0
% INFO    : Bus 3932	: V=1.04597516, theta=-16.0976418 -> V=1.046665, theta=0.0
% INFO    : Bus 3933	: V=1.0179746, theta=-10.2908744 -> V=1.0079355, theta=0.0
% INFO    : Bus 3934	: V=1.01809017, theta=-19.9248316 -> V=1.0000005, theta=0.0
% INFO    : Bus 3935	: V=1.06970215, theta=-18.8574779 -> V=1.046665, theta=0.0
% INFO    : Bus 3936	: V=1.06955834, theta=-18.8702738 -> V=1.046665, theta=0.0
% INFO    : Bus 3937	: V=1.03803729, theta=-18.8471781 -> V=1.0000025, theta=0.0
% INFO    : Bus 3938	: V=1.07443321, theta=-16.1155212 -> V=1.044445, theta=0.0
% INFO    : Bus 3939	: V=1.08378423, theta=-13.9038815 -> V=1.078945, theta=0.0
% INFO    : Bus 3940	: V=1.04219746, theta=-13.1246961 -> V=1.000001, theta=0.0
% INFO    : Bus 3941	: V=1.00724656, theta=-24.3862052 -> V=1.0000025, theta=0.0
% INFO    : Bus 3942	: V=1.02635413, theta=-12.9240467 -> V=0.999999, theta=0.0
% INFO    : Bus 3943	: V=1.04412137, theta=-13.8157309 -> V=1.0111115, theta=0.0
% INFO    : Bus 3944	: V=1.06582076, theta=-9.78975898 -> V=1.072365, theta=0.0
% INFO    : Bus 3945	: V=1.02518509, theta=-47.7095561 -> V=1.0079355, theta=0.0
% INFO    : Bus 3946	: V=1.01916168, theta=-12.5661289 -> V=0.999999, theta=0.0
% INFO    : Bus 3947	: V=1.06438608, theta=-1.10789151 -> V=0.9888895, theta=0.0
% INFO    : Bus 3948	: V=1.08078922, theta=-16.5799117 -> V=1.046665, theta=0.0
% INFO    : Bus 3949	: V=1.07975383, theta=-18.1026548 -> V=1.046665, theta=0.0
% INFO    : Bus 3950	: V=1.05756385, theta=-9.82693096 -> V=0.9888895, theta=0.0
% INFO    : Bus 3951	: V=1.01240209, theta=-20.1889265 -> V=1.0000005, theta=0.0
% INFO    : Bus 3952	: V=1.01058493, theta=-4.67862944 -> V=1.0158755, theta=0.0
% INFO    : Bus 3953	: V=1.08006678, theta=-18.1023301 -> V=1.046665, theta=0.0
% INFO    : Bus 3954	: V=1.07993325, theta=-18.1124266 -> V=1.046665, theta=0.0
% INFO    : Bus 3955	: V=1.01743221, theta=-14.1607464 -> V=0.999999, theta=0.0
% INFO    : Bus 3956	: V=1.01712172, theta=-14.7714933 -> V=0.999999, theta=0.0
% INFO    : Bus 3957	: V=1.06385142, theta=-22.7196983 -> V=1.0000025, theta=0.0
% INFO    : Bus 3958	: V=1.05050449, theta=-16.9259544 -> V=1.027779, theta=0.0
% INFO    : Bus 3959	: V=1.04423771, theta=-17.3331876 -> V=1.027779, theta=0.0
% INFO    : Bus 3960	: V=1.02696407, theta=-17.9683991 -> V=1.0158755, theta=0.0
% INFO    : Bus 3961	: V=1.02677789, theta=-17.9740097 -> V=1.0158755, theta=0.0
% INFO    : Bus 3962	: V=1.02061842, theta=-22.9683717 -> V=1.0000005, theta=0.0
% INFO    : Bus 3963	: V=1.07892525, theta=-18.3268799 -> V=1.046665, theta=0.0
% INFO    : Bus 3964	: V=1.07934924, theta=-18.3899497 -> V=1.046665, theta=0.0
% INFO    : Bus 3965	: V=1.06077957, theta=-39.7260503 -> V=1.022224, theta=0.0
% INFO    : Bus 3966	: V=1.03574857, theta=-25.636834 -> V=1.0000025, theta=0.0
% INFO    : Bus 3967	: V=1.05138655, theta=-9.72642385 -> V=1.0111115, theta=0.0
% INFO    : Bus 3968	: V=1.02455749, theta=-28.9583785 -> V=1.022224, theta=0.0
% INFO    : Bus 3969	: V=1.035, theta=-4.35911757 -> V=0.975, theta=0.0
% INFO    : Bus 3970	: V=1.016, theta=-7.28188488 -> V=0.975, theta=0.0
% INFO    : Bus 3971	: V=1.016909, theta=-10.5299574 -> V=0.999999, theta=0.0
% INFO    : Bus 3972	: V=1.03618431, theta=-7.41148326 -> V=1.0111115, theta=0.0
% INFO    : Bus 3973	: V=1.00384714, theta=-13.2848278 -> V=1.015872, theta=0.0
% INFO    : Bus 3974	: V=1.04395702, theta=-21.3945968 -> V=1.0000025, theta=0.0
% INFO    : Bus 3975	: V=1.01173784, theta=3.05464933 -> V=1.0158755, theta=0.0
% INFO    : Bus 3976	: V=1.01532358, theta=3.75813127 -> V=1.0158755, theta=0.0
% INFO    : Bus 3977	: V=1.08185315, theta=5.89909343 -> V=1.0405385, theta=0.0
% INFO    : Bus 3978	: V=1.02868252, theta=-25.5040963 -> V=1.000001, theta=0.0
% INFO    : Bus 3979	: V=1.06462712, theta=-15.3072398 -> V=1.027779, theta=0.0
% INFO    : Bus 3980	: V=1.05986897, theta=-15.8941461 -> V=1.027779, theta=0.0
% INFO    : Bus 3981	: V=1.08557217, theta=-12.3647262 -> V=1.046665, theta=0.0
% INFO    : Bus 3982	: V=1.04993197, theta=-22.6572331 -> V=1.022224, theta=0.0
% INFO    : Bus 3983	: V=1.00244592, theta=-18.1522315 -> V=0.999999, theta=0.0
% INFO    : Bus 3984	: V=1.01447465, theta=1.43588071 -> V=1.0158755, theta=0.0
% INFO    : Bus 3985	: V=1.00904982, theta=-13.4284663 -> V=0.999999, theta=0.0
% INFO    : Bus 3986	: V=1.00137009, theta=-29.2061247 -> V=1.0000025, theta=0.0
% INFO    : Bus 3987	: V=1.04050672, theta=-19.6980824 -> V=1.022224, theta=0.0
% INFO    : Bus 3988	: V=0.998, theta=-14.8644455 -> V=1.015872, theta=0.0
% INFO    : Bus 3989	: V=1.00234111, theta=-31.6235739 -> V=1.015872, theta=0.0
% INFO    : Bus 3990	: V=1.00932998, theta=-20.7888469 -> V=0.999999, theta=0.0
% INFO    : Bus 3991	: V=1.00946281, theta=-19.4512395 -> V=1.0158755, theta=0.0
% INFO    : Bus 3992	: V=1.05876162, theta=-14.5567558 -> V=1.033334, theta=0.0
% INFO    : Bus 3993	: V=1.0300165, theta=-16.8499816 -> V=1.015872, theta=0.0
% INFO    : Bus 3994	: V=1.02794714, theta=-16.8244171 -> V=1.015872, theta=0.0
% INFO    : Bus 3995	: V=1.03637219, theta=-14.6581082 -> V=0.999999, theta=0.0
% INFO    : Bus 3996	: V=1.02302986, theta=-5.66748387 -> V=1.0158755, theta=0.0
% INFO    : Bus 3997	: V=1.04749889, theta=-15.9937045 -> V=1.033334, theta=0.0
% INFO    : Bus 3998	: V=1.02457053, theta=-24.2896327 -> V=1.0000025, theta=0.0
% INFO    : Bus 3999	: V=1.02041288, theta=-25.2135018 -> V=1.0000025, theta=0.0
% INFO    : Bus 4000	: V=1.0192951, theta=-21.7659527 -> V=0.999999, theta=0.0
% INFO    : Bus 4001	: V=1.05717675, theta=-9.01235274 -> V=1.022222, theta=0.0
% INFO    : Bus 4002	: V=1.00280747, theta=-19.502918 -> V=1.0000005, theta=0.0
% INFO    : Bus 4003	: V=1.01251104, theta=-18.7299782 -> V=1.0000005, theta=0.0
% INFO    : Bus 4004	: V=1.00750059, theta=-11.3460734 -> V=1.0079355, theta=0.0
% INFO    : Bus 4005	: V=1.05421248, theta=-14.8675951 -> V=1.027779, theta=0.0
% INFO    : Bus 4006	: V=1.08390455, theta=-12.6204626 -> V=1.046665, theta=0.0
% INFO    : Bus 4007	: V=1.02311614, theta=-15.685056 -> V=1.0000005, theta=0.0
% INFO    : Bus 4008	: V=1.01453627, theta=-21.6620315 -> V=1.0000025, theta=0.0
% INFO    : Bus 4009	: V=1.04209115, theta=-30.6423355 -> V=1.0000025, theta=0.0
% INFO    : Bus 4010	: V=1.03620725, theta=-24.6468114 -> V=1.044445, theta=0.0
% INFO    : Bus 4011	: V=1.04039384, theta=-18.294996 -> V=0.999999, theta=0.0
% INFO    : Bus 4012	: V=1.04327223, theta=-13.5352558 -> V=1.0111115, theta=0.0
% INFO    : Bus 4013	: V=1.03969113, theta=-24.1765231 -> V=1.027779, theta=0.0
% INFO    : Bus 4014	: V=1.0309254, theta=-19.4441866 -> V=1.022224, theta=0.0
% INFO    : Bus 4015	: V=1.01712143, theta=-14.7714844 -> V=0.999999, theta=0.0
% INFO    : Bus 4016	: V=1.03754203, theta=-27.5817518 -> V=1.0000025, theta=0.0
% INFO    : Bus 4017	: V=1.0207962, theta=-22.6525027 -> V=0.999999, theta=0.0
% INFO    : Bus 4018	: V=1.01825291, theta=1.92524348 -> V=1.0158755, theta=0.0
% INFO    : Bus 4019	: V=1.06500888, theta=4.60225111 -> V=1.0377785, theta=0.0
% INFO    : Bus 4020	: V=1.01214285, theta=1.47427133 -> V=1.0158755, theta=0.0
% INFO    : Bus 4021	: V=1.0745417, theta=-16.0476351 -> V=1.044445, theta=0.0
% INFO    : Bus 4022	: V=1.02620765, theta=-2.83597041 -> V=1.0158755, theta=0.0
% INFO    : Bus 4023	: V=1.0786952, theta=-11.8566471 -> V=1.0383635, theta=0.0
% INFO    : Bus 4024	: V=1.01961702, theta=-23.9911203 -> V=1.0000025, theta=0.0
% INFO    : Bus 4025	: V=1.03833501, theta=-49.3205924 -> V=1.0079355, theta=0.0
% INFO    : Bus 4026	: V=1.015, theta=-13.5154837 -> V=0.999999, theta=0.0
% INFO    : Bus 4027	: V=1.0396686, theta=-19.2713061 -> V=1.0000025, theta=0.0
% INFO    : Bus 4028	: V=1.07474617, theta=-16.2177311 -> V=1.044445, theta=0.0
% INFO    : Bus 4029	: V=1.08407584, theta=-12.5449362 -> V=1.078945, theta=0.0
% INFO    : Bus 4030	: V=0.896084961, theta=-5.82315478 -> V=0.9444445, theta=0.0
% INFO    : Bus 4031	: V=0.988845892, theta=-25.8770911 -> V=1.0000025, theta=0.0
% INFO    : Bus 4032	: V=1.05355318, theta=-12.1684323 -> V=1.0111115, theta=0.0
% INFO    : Bus 4033	: V=1.01704363, theta=-6.7441503 -> V=1.0158755, theta=0.0
% INFO    : Bus 4034	: V=1.05142176, theta=-21.0841646 -> V=1.027779, theta=0.0
% INFO    : Bus 4035	: V=1.0331493, theta=-16.7322741 -> V=1.0158755, theta=0.0
% INFO    : Bus 4036	: V=1.03862193, theta=-24.5116335 -> V=1.022224, theta=0.0
% INFO    : Bus 4037	: V=1.01658679, theta=2.38264036 -> V=1.0158755, theta=0.0
% INFO    : Bus 4038	: V=1.06565031, theta=3.60449887 -> V=1.0377785, theta=0.0
% INFO    : Bus 4039	: V=1.03308921, theta=-10.6269105 -> V=0.999999, theta=0.0
% INFO    : Bus 4040	: V=1.00900666, theta=-10.5150392 -> V=1.015872, theta=0.0
% INFO    : Bus 4041	: V=1.05986954, theta=-19.978509 -> V=1.046665, theta=0.0
% INFO    : Bus 4042	: V=1.02384817, theta=-18.3249683 -> V=1.0158755, theta=0.0
% INFO    : Bus 4043	: V=1.04618813, theta=-18.8645969 -> V=1.046665, theta=0.0
% INFO    : Bus 4044	: V=1.05103345, theta=-16.9004125 -> V=1.044445, theta=0.0
% INFO    : Bus 4045	: V=1.02508199, theta=-25.0358393 -> V=1.022224, theta=0.0
% INFO    : Bus 4046	: V=0.950763387, theta=-6.64592248 -> V=0.9444445, theta=0.0
% INFO    : Bus 4047	: V=1.04902682, theta=-5.68659251 -> V=1.0111115, theta=0.0
% INFO    : Bus 4048	: V=1.07414767, theta=-14.9440754 -> V=1.046665, theta=0.0
% INFO    : Bus 4049	: V=1.07791142, theta=-15.0581242 -> V=1.046665, theta=0.0
% INFO    : Bus 4050	: V=1.07481437, theta=-11.3321306 -> V=1.073685, theta=0.0
% INFO    : Bus 4051	: V=1.03532904, theta=-20.5502304 -> V=1.022224, theta=0.0
% INFO    : Bus 4052	: V=1.0373961, theta=-17.520162 -> V=0.975, theta=0.0
% INFO    : Bus 4053	: V=1.05408908, theta=-9.77438604 -> V=1.0111115, theta=0.0
% INFO    : Bus 4054	: V=1.03301106, theta=-15.4046258 -> V=0.984126, theta=0.0
% INFO    : Bus 4055	: V=1.01627844, theta=-53.5737091 -> V=1.0079355, theta=0.0
% INFO    : Bus 4056	: V=1.027, theta=-14.5909896 -> V=1.015872, theta=0.0
% INFO    : Bus 4057	: V=1.00556837, theta=-21.014976 -> V=1.015872, theta=0.0
% INFO    : Bus 4058	: V=1.0165154, theta=-20.8189136 -> V=1.0000005, theta=0.0
% INFO    : Bus 4059	: V=1.01651557, theta=-20.8189187 -> V=1.0000005, theta=0.0
% INFO    : Bus 4060	: V=1.0437266, theta=-26.387538 -> V=1.0000025, theta=0.0
% INFO    : Bus 4061	: V=1.02991414, theta=-39.2397429 -> V=1.0079355, theta=0.0
% INFO    : Bus 4062	: V=1.00625776, theta=-7.0776398 -> V=1.0158755, theta=0.0
% INFO    : Bus 4063	: V=1.07756147, theta=-15.4023849 -> V=1.046665, theta=0.0
% INFO    : Bus 4064	: V=1.04288737, theta=-19.6902471 -> V=0.999999, theta=0.0
% INFO    : Bus 4065	: V=1.06857105, theta=-16.8056468 -> V=1.0111115, theta=0.0
% INFO    : Bus 4066	: V=1.03626909, theta=-48.9425384 -> V=1.0079355, theta=0.0
% INFO    : Bus 4067	: V=1.06341321, theta=-10.4908249 -> V=1.016666, theta=0.0
% INFO    : Bus 4068	: V=1.06869288, theta=-0.356103614 -> V=1.0377785, theta=0.0
% INFO    : Bus 4069	: V=1.08113108, theta=1.6987384 -> V=1.072365, theta=0.0
% INFO    : Bus 4070	: V=1.01591696, theta=-6.3203178 -> V=1.0158755, theta=0.0
% INFO    : Bus 4071	: V=1.0308054, theta=-24.1753184 -> V=1.0000025, theta=0.0
% INFO    : Bus 4072	: V=1.03977586, theta=-27.8867625 -> V=1.027779, theta=0.0
% INFO    : Bus 4073	: V=1.00841489, theta=-34.4208913 -> V=1.022224, theta=0.0
% INFO    : Bus 4074	: V=1.02050876, theta=-19.356395 -> V=1.0000005, theta=0.0
% INFO    : Bus 4075	: V=1.02413546, theta=-15.9217284 -> V=1.0158755, theta=0.0
% INFO    : Bus 4076	: V=1.02879086, theta=-29.3818005 -> V=1.022224, theta=0.0
% INFO    : Bus 4077	: V=1.02321595, theta=-15.8492943 -> V=1.0000005, theta=0.0
% INFO    : Bus 4078	: V=1.02326391, theta=-15.849713 -> V=1.0000005, theta=0.0
% INFO    : Bus 4079	: V=1.07791317, theta=-15.7097718 -> V=1.046665, theta=0.0
% INFO    : Bus 4080	: V=0.996723941, theta=-31.7111388 -> V=1.0000025, theta=0.0
% INFO    : Bus 4081	: V=0.992814109, theta=-9.73628293 -> V=1.0158755, theta=0.0
% INFO    : Bus 4082	: V=1.02049614, theta=-16.3976059 -> V=0.999999, theta=0.0
% INFO    : Bus 4083	: V=1.08424229, theta=-15.8816793 -> V=1.046825, theta=0.0
% INFO    : Bus 4084	: V=1.04902508, theta=-10.2811555 -> V=1.0111115, theta=0.0
% INFO    : Bus 4085	: V=1.06693204, theta=-23.9018201 -> V=1.0000025, theta=0.0
% INFO    : Bus 4086	: V=1.02868252, theta=-25.5040963 -> V=1.000001, theta=0.0
% INFO    : Bus 4087	: V=1.03321833, theta=-42.1427075 -> V=1.0079355, theta=0.0
% INFO    : Bus 4088	: V=1.01682193, theta=-11.6994522 -> V=1.0158755, theta=0.0
% INFO    : Bus 4089	: V=1.04349181, theta=-4.16856289 -> V=1.0158755, theta=0.0
% INFO    : Bus 4090	: V=1.03312193, theta=-3.38765793 -> V=1.0377785, theta=0.0
% INFO    : Bus 4091	: V=1.01458787, theta=-26.6925695 -> V=1.022224, theta=0.0
% INFO    : Bus 4092	: V=1.00643525, theta=-27.6442157 -> V=1.0000025, theta=0.0
% INFO    : Bus 4093	: V=1.03425762, theta=-19.5465449 -> V=0.999999, theta=0.0
% INFO    : Bus 4094	: V=1.04126715, theta=-14.08222 -> V=1.0111115, theta=0.0
% INFO    : Bus 4095	: V=0.988106279, theta=-17.0968084 -> V=1.0000005, theta=0.0
% INFO    : Bus 4096	: V=1.0707992, theta=-17.1623425 -> V=1.046665, theta=0.0
% INFO    : Bus 4097	: V=1.00868145, theta=-19.5127578 -> V=1.0000005, theta=0.0
% INFO    : Bus 4098	: V=0.991423621, theta=-21.4680814 -> V=1.0158755, theta=0.0
% INFO    : Bus 4099	: V=1.04772614, theta=-25.3909484 -> V=1.027779, theta=0.0
% INFO    : Bus 4100	: V=0.996631434, theta=-17.1873807 -> V=1.0158755, theta=0.0
% INFO    : Bus 4101	: V=1.02916791, theta=-21.249231 -> V=1.0158755, theta=0.0
% INFO    : Bus 4102	: V=1.01940751, theta=-23.7860482 -> V=1.015872, theta=0.0
% INFO    : Bus 4103	: V=1.04628334, theta=-18.6993521 -> V=1.046665, theta=0.0
% INFO    : Bus 4104	: V=1.05906227, theta=-6.46924094 -> V=0.9888895, theta=0.0
% INFO    : Bus 4105	: V=1.05923807, theta=-6.45026401 -> V=0.9888895, theta=0.0
% INFO    : Bus 4106	: V=1.02152223, theta=-12.1121179 -> V=0.975, theta=0.0
% INFO    : Bus 4107	: V=1.0740866, theta=-11.83693 -> V=1.0377785, theta=0.0
% INFO    : Bus 4108	: V=1.08267875, theta=-9.68891772 -> V=1.072365, theta=0.0
% INFO    : Bus 4109	: V=1.02761799, theta=-16.0767728 -> V=1.0000005, theta=0.0
% INFO    : Bus 4110	: V=1.04403578, theta=-13.5439642 -> V=1.022224, theta=0.0
% INFO    : Bus 4111	: V=1.03831736, theta=-21.3344401 -> V=1.027779, theta=0.0
% INFO    : Bus 4112	: V=1.03774141, theta=-11.0426192 -> V=0.999999, theta=0.0
% INFO    : Bus 4113	: V=1.06066624, theta=-9.68808149 -> V=1.0111115, theta=0.0
% INFO    : Bus 4114	: V=1.01003163, theta=-11.6249494 -> V=0.999999, theta=0.0
% INFO    : Bus 4115	: V=1.03318598, theta=-32.2158889 -> V=1.022224, theta=0.0
% INFO    : Bus 4116	: V=1.01004418, theta=-17.4468357 -> V=0.999999, theta=0.0
% INFO    : Bus 4117	: V=1.04198779, theta=-36.7941866 -> V=1.022224, theta=0.0
% INFO    : Bus 4118	: V=1.02335838, theta=-21.4349084 -> V=1.0000025, theta=0.0
% INFO    : Bus 4119	: V=1.02335422, theta=-21.4341151 -> V=1.0000025, theta=0.0
% INFO    : Bus 4120	: V=1.05012247, theta=-12.3228233 -> V=1.000001, theta=0.0
% INFO    : Bus 4121	: V=1.06231606, theta=-8.83733711 -> V=1.0111115, theta=0.0
% INFO    : Bus 4122	: V=1.04919941, theta=-7.61176972 -> V=1.000001, theta=0.0
% INFO    : Bus 4123	: V=1.0629984, theta=-4.01736397 -> V=1.016666, theta=0.0
% INFO    : Bus 4124	: V=1.06963483, theta=1.19223701 -> V=1.05263, theta=0.0
% INFO    : Bus 4125	: V=1.03446106, theta=-40.5011224 -> V=1.0079355, theta=0.0
% INFO    : Bus 4126	: V=0.997996298, theta=-26.9032271 -> V=1.0000025, theta=0.0
% INFO    : Bus 4127	: V=1.01523513, theta=-40.7030078 -> V=1.0079355, theta=0.0
% INFO    : Bus 4128	: V=1.07795, theta=-18.6369861 -> V=1.046665, theta=0.0
% INFO    : Bus 4129	: V=1.01806461, theta=-29.1316189 -> V=1.015872, theta=0.0
% INFO    : Bus 4130	: V=1.03070523, theta=-30.5368678 -> V=1.0000025, theta=0.0
% INFO    : Bus 4131	: V=1.015, theta=-14.4398869 -> V=0.999999, theta=0.0
% INFO    : Bus 4132	: V=1.03238147, theta=-8.17528451 -> V=1.0111115, theta=0.0
% INFO    : Bus 4133	: V=0.988689645, theta=-30.9909424 -> V=1.015872, theta=0.0
% INFO    : Bus 4134	: V=1.02393819, theta=-11.7587844 -> V=0.999999, theta=0.0
% INFO    : Bus 4135	: V=1.08247381, theta=-3.86105589 -> V=1.0377785, theta=0.0
% INFO    : Bus 4136	: V=1.09644501, theta=-0.873011091 -> V=1.072365, theta=0.0
% INFO    : Bus 4137	: V=1.09774056, theta=-0.662680117 -> V=1.072365, theta=0.0
% INFO    : Bus 4138	: V=1.00509243, theta=-31.4318413 -> V=1.015872, theta=0.0
% INFO    : Bus 4139	: V=1.05290209, theta=-9.6544398 -> V=1.0111115, theta=0.0
% INFO    : Bus 4140	: V=1.04381361, theta=-13.598929 -> V=1.015874, theta=0.0
% INFO    : Bus 4141	: V=1.05397408, theta=-23.0177731 -> V=1.0000025, theta=0.0
% INFO    : Bus 4142	: V=1.0421264, theta=-35.9167435 -> V=1.022224, theta=0.0
% INFO    : Bus 4143	: V=1.06764085, theta=-38.7078248 -> V=1.023774, theta=0.0
% INFO    : Bus 4144	: V=1.07964616, theta=-34.5037584 -> V=1.04444, theta=0.0
% INFO    : Bus 4145	: V=1.02695381, theta=-16.0192391 -> V=1.015872, theta=0.0
% INFO    : Bus 4146	: V=1.05847112, theta=-13.7683217 -> V=1.046665, theta=0.0
% INFO    : Bus 4147	: V=1.01009637, theta=-21.4586462 -> V=1.022224, theta=0.0
% INFO    : Bus 4148	: V=1.04113608, theta=-14.3391274 -> V=1.0000025, theta=0.0
% INFO    : Bus 4149	: V=1.04401351, theta=-13.470517 -> V=0.999999, theta=0.0
% INFO    : Bus 4150	: V=1.04337211, theta=-14.0347705 -> V=0.999999, theta=0.0
% INFO    : Bus 4151	: V=1.03984575, theta=-9.90489295 -> V=1.0111115, theta=0.0
% INFO    : Bus 4152	: V=1.03190415, theta=-15.5060646 -> V=1.044445, theta=0.0
% INFO    : Bus 4153	: V=1.03190242, theta=-15.5060389 -> V=1.044445, theta=0.0
% INFO    : Bus 4154	: V=1.04664924, theta=-11.3776611 -> V=1.015874, theta=0.0
% INFO    : Bus 4155	: V=1.02407448, theta=-27.4413551 -> V=1.015872, theta=0.0
% INFO    : Bus 4156	: V=1.01388379, theta=-25.7633365 -> V=1.0000025, theta=0.0
% INFO    : Bus 4157	: V=1.04099196, theta=-0.802577249 -> V=1.0000025, theta=0.0
% INFO    : Bus 4158	: V=1.00613326, theta=-22.3854895 -> V=1.015872, theta=0.0
% INFO    : Bus 4159	: V=1.08436054, theta=-15.2097292 -> V=1.047295, theta=0.0
% INFO    : Bus 4160	: V=1.05465306, theta=-13.7832489 -> V=1.027779, theta=0.0
% INFO    : Bus 4161	: V=1.06478012, theta=-14.8662783 -> V=1.027779, theta=0.0
% INFO    : Bus 4162	: V=1.01615271, theta=-16.8339875 -> V=1.015872, theta=0.0
% INFO    : Bus 4163	: V=1.02342091, theta=-26.8103082 -> V=1.022224, theta=0.0
% INFO    : Bus 4164	: V=1.03834787, theta=-38.3610464 -> V=1.022224, theta=0.0
% INFO    : Bus 4165	: V=0.995806555, theta=-15.8353758 -> V=1.0158755, theta=0.0
% INFO    : Bus 4166	: V=1.06815906, theta=-9.89042658 -> V=1.033333, theta=0.0
% INFO    : Bus 4167	: V=1.05949456, theta=-5.10953809 -> V=1.0288895, theta=0.0
% INFO    : Bus 4168	: V=1.00716021, theta=-27.9167615 -> V=1.015872, theta=0.0
% INFO    : Bus 4169	: V=1.06623762, theta=-24.1103505 -> V=1.0000025, theta=0.0
% INFO    : Bus 4170	: V=1.05283326, theta=-22.1680053 -> V=1.0000025, theta=0.0
% INFO    : Bus 4171	: V=1.038, theta=-23.0951256 -> V=1.0000025, theta=0.0
% INFO    : Bus 4172	: V=1.04293697, theta=-41.7091164 -> V=1.022224, theta=0.0
% INFO    : Bus 4173	: V=1.08305364, theta=-37.2128587 -> V=1.044535, theta=0.0
% INFO    : Bus 4174	: V=1.03098325, theta=-18.1351913 -> V=1.0000025, theta=0.0
% INFO    : Bus 4175	: V=1.06962308, theta=-18.1316335 -> V=1.0, theta=0.0
% INFO    : Bus 4176	: V=1.03354158, theta=-21.0727104 -> V=1.022224, theta=0.0
% INFO    : Bus 4177	: V=1.03469731, theta=-36.128943 -> V=1.022224, theta=0.0
% INFO    : Bus 4178	: V=1.05388294, theta=-27.1248537 -> V=1.0000025, theta=0.0
% INFO    : Bus 4179	: V=1.04002214, theta=-22.1901085 -> V=1.000001, theta=0.0
% INFO    : Bus 4180	: V=1.05252143, theta=-28.3121809 -> V=1.022224, theta=0.0
% INFO    : Bus 4181	: V=1.04137005, theta=-29.6187648 -> V=1.022224, theta=0.0
% INFO    : Bus 4182	: V=1.0483898, theta=-1.42450078 -> V=1.0377785, theta=0.0
% INFO    : Bus 4183	: V=1.03496913, theta=-47.0233283 -> V=1.0079355, theta=0.0
% INFO    : Bus 4184	: V=1.06660743, theta=-41.7301131 -> V=1.04444, theta=0.0
% INFO    : Bus 4185	: V=1.02092541, theta=-44.5004946 -> V=1.0079355, theta=0.0
% INFO    : Bus 4186	: V=1.02318721, theta=3.48126133 -> V=1.0158735, theta=0.0
% INFO    : Bus 4187	: V=1.01425515, theta=-14.3045356 -> V=0.999999, theta=0.0
% INFO    : Bus 4188	: V=1.01431268, theta=-14.3140382 -> V=0.999999, theta=0.0
% INFO    : Bus 4189	: V=1.07601575, theta=0.0120355587 -> V=1.072365, theta=0.0
% INFO    : Bus 4190	: V=1.07601466, theta=0.0133351379 -> V=1.072365, theta=0.0
% INFO    : Bus 4191	: V=1.01573822, theta=-29.6921467 -> V=1.0000025, theta=0.0
% INFO    : Bus 4192	: V=1.02124972, theta=-25.4113549 -> V=1.0000025, theta=0.0
% INFO    : Bus 4193	: V=1.04670466, theta=-11.0896427 -> V=1.0000025, theta=0.0
% INFO    : Bus 4194	: V=0.976600931, theta=-20.7750323 -> V=1.0158755, theta=0.0
% INFO    : Bus 4195	: V=0.976793379, theta=-20.7437724 -> V=1.0158755, theta=0.0
% INFO    : Bus 4196	: V=1.02089532, theta=-19.9694138 -> V=1.022224, theta=0.0
% INFO    : Bus 4197	: V=1.05478395, theta=-6.9520367 -> V=1.0111115, theta=0.0
% INFO    : Bus 4198	: V=1.05876296, theta=-9.48426765 -> V=1.0111115, theta=0.0
% INFO    : Bus 4199	: V=1.01364756, theta=-28.2259371 -> V=1.0000025, theta=0.0
% INFO    : Bus 4200	: V=1.0395747, theta=-25.183494 -> V=1.022224, theta=0.0
% INFO    : Bus 4201	: V=1.03451543, theta=-30.1899785 -> V=1.022224, theta=0.0
% INFO    : Bus 4202	: V=1.05590623, theta=-19.3878729 -> V=1.022224, theta=0.0
% INFO    : Bus 4203	: V=1.05551789, theta=-19.4274824 -> V=1.022224, theta=0.0
% INFO    : Bus 4204	: V=1.0282856, theta=-18.8541417 -> V=0.999999, theta=0.0
% INFO    : Bus 4205	: V=1.0282856, theta=-18.8541417 -> V=0.999999, theta=0.0
% INFO    : Bus 4206	: V=1.02835605, theta=-18.8292885 -> V=0.999999, theta=0.0
% INFO    : Bus 4207	: V=1.03774378, theta=-18.0733354 -> V=1.0158755, theta=0.0
% INFO    : Bus 4208	: V=0.990082438, theta=-18.2548096 -> V=0.999999, theta=0.0
% INFO    : Bus 4209	: V=1.01371887, theta=-21.6193091 -> V=1.0000005, theta=0.0
% INFO    : Bus 4210	: V=1.07037133, theta=-17.3597263 -> V=1.046665, theta=0.0
% INFO    : Bus 4211	: V=1.0587996, theta=-20.2316355 -> V=1.046665, theta=0.0
% INFO    : Bus 4212	: V=1.04187358, theta=-17.2929041 -> V=1.015872, theta=0.0
% INFO    : Bus 4213	: V=1.05824815, theta=-15.1234877 -> V=1.046665, theta=0.0
% INFO    : Bus 4214	: V=1.04125985, theta=-48.4240137 -> V=1.0079355, theta=0.0
% INFO    : Bus 4215	: V=1.03390328, theta=-26.1625294 -> V=1.022224, theta=0.0
% INFO    : Bus 4216	: V=1.03367586, theta=-26.0042397 -> V=1.022224, theta=0.0
% INFO    : Bus 4217	: V=1.02134953, theta=-12.7757928 -> V=0.999999, theta=0.0
% INFO    : Bus 4218	: V=1.02899834, theta=3.94402191 -> V=1.0158755, theta=0.0
% INFO    : Bus 4219	: V=1.03087814, theta=3.40267506 -> V=1.0158755, theta=0.0
% INFO    : Bus 4220	: V=1.07699045, theta=6.70045159 -> V=1.0377935, theta=0.0
% INFO    : Bus 4221	: V=1.09275924, theta=10.6223086 -> V=1.072365, theta=0.0
% INFO    : Bus 4222	: V=0.933428093, theta=-8.61622707 -> V=0.9444445, theta=0.0
% INFO    : Bus 4223	: V=1.06396966, theta=-25.7918507 -> V=0.975, theta=0.0
% INFO    : Bus 4224	: V=1.03650326, theta=-29.9166383 -> V=1.022224, theta=0.0
% INFO    : Bus 4225	: V=1.0360382, theta=-30.0051756 -> V=1.022224, theta=0.0
% INFO    : Bus 4226	: V=1.06401727, theta=-25.7809938 -> V=1.04444, theta=0.0
% INFO    : Bus 4227	: V=1.04500103, theta=-20.6704949 -> V=1.027779, theta=0.0
% INFO    : Bus 4228	: V=1.04369874, theta=-20.7019318 -> V=1.027779, theta=0.0
% INFO    : Bus 4229	: V=1.06055269, theta=-17.3322582 -> V=1.046665, theta=0.0
% INFO    : Bus 4230	: V=1.02693906, theta=-15.5596458 -> V=1.0158755, theta=0.0
% INFO    : Bus 4231	: V=1.01680096, theta=-17.0017724 -> V=1.0158755, theta=0.0
% INFO    : Bus 4232	: V=1.02113174, theta=-14.9424762 -> V=0.999999, theta=0.0
% INFO    : Bus 4233	: V=1.02, theta=-15.2900489 -> V=0.999999, theta=0.0
% INFO    : Bus 4234	: V=1.00714565, theta=-8.8030785 -> V=1.0158755, theta=0.0
% INFO    : Bus 4235	: V=1.00902796, theta=-14.161859 -> V=0.999999, theta=0.0
% INFO    : Bus 4236	: V=1.01041707, theta=-19.0655987 -> V=0.999999, theta=0.0
% INFO    : Bus 4237	: V=1.03575883, theta=-40.7300627 -> V=1.022224, theta=0.0
% INFO    : Bus 4238	: V=1.04295676, theta=-10.6157325 -> V=1.0000025, theta=0.0
% INFO    : Bus 4239	: V=1.0478899, theta=-7.68284802 -> V=0.9888895, theta=0.0
% INFO    : Bus 4240	: V=1.04777095, theta=-7.71484575 -> V=0.9888895, theta=0.0
% INFO    : Bus 4241	: V=1.04103735, theta=-30.2160485 -> V=1.022224, theta=0.0
% INFO    : Bus 4242	: V=1.04553504, theta=-28.1314127 -> V=1.022224, theta=0.0
% INFO    : Bus 4243	: V=1.02902672, theta=-40.467214 -> V=1.0079355, theta=0.0
% INFO    : Bus 4244	: V=1.05028509, theta=-29.6967702 -> V=1.022224, theta=0.0
% INFO    : Bus 4245	: V=1.07709907, theta=-26.0961435 -> V=1.04444, theta=0.0
% INFO    : Bus 4246	: V=1.05971183, theta=-21.6013428 -> V=1.000001, theta=0.0
% INFO    : Bus 4247	: V=0.973196139, theta=-29.1635899 -> V=1.015872, theta=0.0
% INFO    : Bus 4248	: V=1.0422923, theta=-28.9897507 -> V=1.0000025, theta=0.0
% INFO    : Bus 4249	: V=0.998411417, theta=-21.8249248 -> V=1.015872, theta=0.0
% INFO    : Bus 4250	: V=1.00065582, theta=-15.2379312 -> V=1.015872, theta=0.0
% INFO    : Bus 4251	: V=1.05679292, theta=-23.3122501 -> V=1.0000025, theta=0.0
% INFO    : Bus 4252	: V=1.01835863, theta=-19.4897056 -> V=1.015872, theta=0.0
% INFO    : Bus 4253	: V=1.04029292, theta=-14.4685264 -> V=1.046665, theta=0.0
% INFO    : Bus 4254	: V=1.01840426, theta=-2.80808086 -> V=1.0158755, theta=0.0
% INFO    : Bus 4255	: V=1.03917103, theta=-21.1095895 -> V=1.015872, theta=0.0
% INFO    : Bus 4256	: V=1.04563849, theta=-18.489766 -> V=1.046665, theta=0.0
% INFO    : Bus 4257	: V=1.01691316, theta=-21.666111 -> V=1.0000025, theta=0.0
% INFO    : Bus 4258	: V=1.03977019, theta=-16.5878713 -> V=1.044445, theta=0.0
% INFO    : Bus 4259	: V=0.998848042, theta=-17.5172969 -> V=0.999999, theta=0.0
% INFO    : Bus 4260	: V=1.00415446, theta=-14.0135714 -> V=0.999999, theta=0.0
% INFO    : Bus 4261	: V=1.0232241, theta=-10.6866887 -> V=1.015872, theta=0.0
% INFO    : Bus 4262	: V=1.03454686, theta=-48.4243307 -> V=1.0079355, theta=0.0
% INFO    : Bus 4263	: V=1.03016477, theta=-26.739637 -> V=1.022224, theta=0.0
% INFO    : Bus 4264	: V=1.05387229, theta=-9.735112 -> V=1.0111115, theta=0.0
% INFO    : Bus 4265	: V=1.01467178, theta=-10.1670073 -> V=0.999999, theta=0.0
% INFO    : Bus 4266	: V=1.01373619, theta=-11.0640159 -> V=0.999999, theta=0.0
% INFO    : Bus 4267	: V=1.04339086, theta=-22.3540088 -> V=1.027779, theta=0.0
% INFO    : Bus 4268	: V=1.02153351, theta=-15.0839706 -> V=0.999999, theta=0.0
% INFO    : Bus 4269	: V=1.01560549, theta=-34.3350142 -> V=1.022224, theta=0.0
% INFO    : Bus 4270	: V=0.990786723, theta=-25.6820384 -> V=1.015872, theta=0.0
% INFO    : Bus 4271	: V=1.05738847, theta=-18.4978322 -> V=1.033334, theta=0.0
% INFO    : Bus 4272	: V=1.00061868, theta=-21.7192228 -> V=1.015872, theta=0.0
% INFO    : Bus 4273	: V=1.02807021, theta=-21.1779071 -> V=1.0000025, theta=0.0
% INFO    : Bus 4274	: V=0.999210017, theta=-30.8354708 -> V=1.0000025, theta=0.0
% INFO    : Bus 4275	: V=1.00175923, theta=-30.1412309 -> V=1.015872, theta=0.0
% INFO    : Bus 4276	: V=1.033, theta=-25.2743458 -> V=0.975, theta=0.0
% INFO    : Bus 4277	: V=1.02437242, theta=-27.0226997 -> V=1.015872, theta=0.0
% INFO    : Bus 4278	: V=1.0287387, theta=-26.17068 -> V=1.0233335, theta=0.0
% INFO    : Bus 4279	: V=1.049304, theta=-25.1089185 -> V=1.0000025, theta=0.0
% INFO    : Bus 4280	: V=1.00299147, theta=-29.7999421 -> V=1.015872, theta=0.0
% INFO    : Bus 4281	: V=1.0023414, theta=-29.8684838 -> V=1.015872, theta=0.0
% INFO    : Bus 4282	: V=1.0209756, theta=-9.42622929 -> V=0.999999, theta=0.0
% INFO    : Bus 4283	: V=1.0189361, theta=-7.29453011 -> V=1.0158755, theta=0.0
% INFO    : Bus 4284	: V=1.01037146, theta=-7.58342212 -> V=1.0158755, theta=0.0
% INFO    : Bus 4285	: V=1.03133862, theta=-16.9640026 -> V=1.022224, theta=0.0
% INFO    : Bus 4286	: V=1.08477796, theta=-13.9826246 -> V=1.046925, theta=0.0
% INFO    : Bus 4287	: V=1.0874767, theta=-10.1993691 -> V=1.07237, theta=0.0
% INFO    : Bus 4288	: V=1.08747729, theta=-10.2032541 -> V=1.07237, theta=0.0
% INFO    : Bus 4289	: V=1.0139389, theta=-13.7699454 -> V=0.999999, theta=0.0
% INFO    : Bus 4290	: V=1.0533511, theta=-15.8968698 -> V=1.027779, theta=0.0
% INFO    : Bus 4291	: V=1.02480418, theta=-12.7092916 -> V=1.0158755, theta=0.0
% INFO    : Bus 4292	: V=1.11523332, theta=-9.05553841 -> V=1.0381705, theta=0.0
% INFO    : Bus 4293	: V=1.07731507, theta=-9.05553841 -> V=1.0377785, theta=0.0
% INFO    : Bus 4294	: V=1.08036489, theta=-5.90694743 -> V=1.072365, theta=0.0
% INFO    : Bus 4295	: V=1.00850266, theta=-21.2753394 -> V=1.015872, theta=0.0
% INFO    : Bus 4296	: V=1.05566348, theta=-16.1368586 -> V=1.046665, theta=0.0
% INFO    : Bus 4297	: V=1.0256431, theta=-21.4541531 -> V=1.0000025, theta=0.0
% INFO    : Bus 4298	: V=1.02665193, theta=-24.4339071 -> V=1.027779, theta=0.0
% INFO    : Bus 4299	: V=1.0373394, theta=-22.939353 -> V=1.027779, theta=0.0
% INFO    : Bus 4300	: V=1.03686017, theta=-22.9493792 -> V=1.027779, theta=0.0
% INFO    : Bus 4301	: V=1.014, theta=-13.6907395 -> V=0.999999, theta=0.0
% INFO    : Bus 4302	: V=1.03265559, theta=-14.7972847 -> V=0.999999, theta=0.0
% INFO    : Bus 4303	: V=1.02736473, theta=-28.1129717 -> V=1.0000025, theta=0.0
% INFO    : Bus 4304	: V=1.03144422, theta=-17.1001898 -> V=1.0158755, theta=0.0
% INFO    : Bus 4305	: V=1.07491234, theta=-20.4176922 -> V=1.000001, theta=0.0
% INFO    : Bus 4306	: V=1.08398669, theta=-16.294608 -> V=1.044445, theta=0.0
% INFO    : Bus 4307	: V=1.0242996, theta=-46.1403418 -> V=1.0079355, theta=0.0
% INFO    : Bus 4308	: V=1.0111719, theta=-17.0986755 -> V=1.0158755, theta=0.0
% INFO    : Bus 4309	: V=1.01166052, theta=-17.089701 -> V=1.0158755, theta=0.0
% INFO    : Bus 4310	: V=1.03528852, theta=-20.2300411 -> V=0.999999, theta=0.0
% INFO    : Bus 4311	: V=1.03210541, theta=-20.4494543 -> V=0.999999, theta=0.0
% INFO    : Bus 4312	: V=1.03028538, theta=-23.7151162 -> V=1.022224, theta=0.0
% INFO    : Bus 4313	: V=1.07301901, theta=-18.8009324 -> V=1.04444, theta=0.0
% INFO    : Bus 4314	: V=1.0716777, theta=-19.0482792 -> V=1.04444, theta=0.0
% INFO    : Bus 4315	: V=1.06196383, theta=-15.6959179 -> V=1.027779, theta=0.0
% INFO    : Bus 4316	: V=1.02387827, theta=-31.5803808 -> V=1.0000025, theta=0.0
% INFO    : Bus 4317	: V=1.043, theta=-10.2874269 -> V=0.999999, theta=0.0
% INFO    : Bus 4318	: V=1.02320728, theta=-14.4290964 -> V=0.999999, theta=0.0
% INFO    : Bus 4319	: V=1.02140282, theta=-30.4418227 -> V=1.022224, theta=0.0
% INFO    : Bus 4320	: V=0.99947222, theta=-16.2158476 -> V=0.999999, theta=0.0
% INFO    : Bus 4321	: V=1.063, theta=-18.9047335 -> V=1.000001, theta=0.0
% INFO    : Bus 4322	: V=1.02475335, theta=-28.4686743 -> V=1.0000025, theta=0.0
% INFO    : Bus 4323	: V=1.04115856, theta=-42.4578301 -> V=1.022224, theta=0.0
% INFO    : Bus 4324	: V=1.0285801, theta=-46.663798 -> V=1.0079355, theta=0.0
% INFO    : Bus 4325	: V=1.00524797, theta=-12.0891441 -> V=0.999999, theta=0.0
% INFO    : Bus 4326	: V=1.05403982, theta=-10.1262273 -> V=1.0111115, theta=0.0
% INFO    : Bus 4327	: V=1.03569042, theta=-30.0003348 -> V=1.0000025, theta=0.0
% INFO    : Bus 4328	: V=1.047, theta=-44.7623699 -> V=1.0079355, theta=0.0
% INFO    : Bus 4329	: V=0.996, theta=-11.7758 -> V=0.999999, theta=0.0
% INFO    : Bus 4330	: V=1.0214609, theta=-17.6844733 -> V=1.0158755, theta=0.0
% INFO    : Bus 4331	: V=1.01580694, theta=1.13918754 -> V=1.0158755, theta=0.0
% INFO    : Bus 4332	: V=1.01995128, theta=3.6656221 -> V=1.0158755, theta=0.0
% INFO    : Bus 4333	: V=1.07675039, theta=4.98517556 -> V=1.0380485, theta=0.0
% INFO    : Bus 4334	: V=1.07542418, theta=5.21138779 -> V=1.0377785, theta=0.0
% INFO    : Bus 4335	: V=1.04212738, theta=-24.4677533 -> V=1.0000025, theta=0.0
% INFO    : Bus 4336	: V=1.02622109, theta=-32.258756 -> V=1.0000025, theta=0.0
% INFO    : Bus 4337	: V=1.01337987, theta=-19.5262244 -> V=0.999999, theta=0.0
% INFO    : Bus 4338	: V=1.02604184, theta=-31.0270733 -> V=1.022224, theta=0.0
% INFO    : Bus 4339	: V=1.0427692, theta=-12.776217 -> V=1.0000025, theta=0.0
% INFO    : Bus 4340	: V=0.949997575, theta=-8.16409651 -> V=0.9444445, theta=0.0
% INFO    : Bus 4341	: V=1.06356573, theta=-33.3924905 -> V=0.975, theta=0.0
% INFO    : Bus 4342	: V=1.06356498, theta=-33.3929139 -> V=0.975, theta=0.0
% INFO    : Bus 4343	: V=1.06359126, theta=-33.3964652 -> V=0.975, theta=0.0
% INFO    : Bus 4344	: V=1.03500706, theta=-37.7774727 -> V=1.0079355, theta=0.0
% INFO    : Bus 4345	: V=1.0635947, theta=-33.3836663 -> V=1.04444, theta=0.0
% INFO    : Bus 4346	: V=1.03545137, theta=-17.2049647 -> V=1.022224, theta=0.0
% INFO    : Bus 4347	: V=1.012, theta=-29.8722224 -> V=1.0000025, theta=0.0
% INFO    : Bus 4348	: V=1.02993409, theta=2.16408822 -> V=1.0158755, theta=0.0
% INFO    : Bus 4349	: V=1.07877073, theta=5.98454789 -> V=1.0390285, theta=0.0
% INFO    : Bus 4350	: V=1.05009546, theta=-18.6756268 -> V=1.000001, theta=0.0
% INFO    : Bus 4351	: V=1.02068037, theta=-17.8041066 -> V=0.999999, theta=0.0
% INFO    : Bus 4352	: V=1.02814181, theta=-12.7426566 -> V=0.999999, theta=0.0
% INFO    : Bus 4353	: V=1.0279525, theta=-12.7469339 -> V=0.999999, theta=0.0
% INFO    : Bus 4354	: V=1.00915539, theta=-21.6128207 -> V=1.0000025, theta=0.0
% INFO    : Bus 4355	: V=1.06797292, theta=-30.5009591 -> V=0.975, theta=0.0
% INFO    : Bus 4356	: V=1.03522347, theta=-32.0839315 -> V=1.022224, theta=0.0
% INFO    : Bus 4357	: V=1.06806956, theta=-30.4779772 -> V=1.04444, theta=0.0
% INFO    : Bus 4358	: V=1.00822859, theta=-49.0191385 -> V=1.0079355, theta=0.0
% INFO    : Bus 4359	: V=1.03724961, theta=-25.6015415 -> V=1.0000025, theta=0.0
% INFO    : Bus 4360	: V=0.995975327, theta=-22.1608365 -> V=1.0000025, theta=0.0
% INFO    : Bus 4361	: V=1.04073471, theta=-25.9175219 -> V=1.0000025, theta=0.0
% INFO    : Bus 4362	: V=1.00140738, theta=-35.263067 -> V=1.015872, theta=0.0
% INFO    : Bus 4363	: V=0.981089993, theta=-34.4079294 -> V=1.015872, theta=0.0
% INFO    : Bus 4364	: V=1.01094733, theta=-26.3677537 -> V=1.0000025, theta=0.0
% INFO    : Bus 4365	: V=1.01598036, theta=-27.7193487 -> V=1.022224, theta=0.0
% INFO    : Bus 4366	: V=1.04925999, theta=-39.4980732 -> V=1.0079355, theta=0.0
% INFO    : Bus 4367	: V=1.01736708, theta=-18.3953771 -> V=1.0000005, theta=0.0
% INFO    : Bus 4368	: V=1.01423738, theta=-18.675301 -> V=1.0000005, theta=0.0
% INFO    : Bus 4369	: V=1.01438833, theta=-18.5870954 -> V=1.0000005, theta=0.0
% INFO    : Bus 4370	: V=1.0512642, theta=-29.1037122 -> V=1.0000025, theta=0.0
% INFO    : Bus 4371	: V=0.973332326, theta=-14.812519 -> V=0.999999, theta=0.0
% INFO    : Bus 4372	: V=1.04758396, theta=-19.2389142 -> V=1.022224, theta=0.0
% INFO    : Bus 4373	: V=1.04185464, theta=-22.3174383 -> V=1.0000025, theta=0.0
% INFO    : Bus 4374	: V=1.01198034, theta=-9.10719448 -> V=1.0000025, theta=0.0
% INFO    : Bus 4375	: V=1.02182544, theta=-7.06236644 -> V=1.0158755, theta=0.0
% INFO    : Bus 4376	: V=1.00383261, theta=-20.8939974 -> V=0.999999, theta=0.0
% INFO    : Bus 4377	: V=0.976570926, theta=-3.4861666 -> V=1.0158755, theta=0.0
% INFO    : Bus 4378	: V=0.994735619, theta=-9.8971742 -> V=1.0158755, theta=0.0
% INFO    : Bus 4379	: V=0.950763387, theta=-6.64592248 -> V=0.9444445, theta=0.0
% INFO    : Bus 4380	: V=1.03407165, theta=-35.8891342 -> V=1.022224, theta=0.0
% INFO    : Bus 4381	: V=1.01851844, theta=-13.6521472 -> V=1.0158755, theta=0.0
% INFO    : Bus 4382	: V=1.04103096, theta=-42.4933618 -> V=1.022224, theta=0.0
% INFO    : Bus 4383	: V=1.02170619, theta=-14.3436057 -> V=0.999999, theta=0.0
% INFO    : Bus 4384	: V=1.01927675, theta=-26.5580187 -> V=1.022224, theta=0.0
% INFO    : Bus 4385	: V=1.03241147, theta=-16.9844674 -> V=1.015872, theta=0.0
% INFO    : Bus 4386	: V=1.08427571, theta=-15.2415532 -> V=1.04725, theta=0.0
% INFO    : Bus 4387	: V=1.08284194, theta=-16.3637781 -> V=1.046665, theta=0.0
% INFO    : Bus 4388	: V=1.00402073, theta=-13.2919791 -> V=1.015872, theta=0.0
% INFO    : Bus 4389	: V=1.02890454, theta=-6.70684288 -> V=1.0158755, theta=0.0
% INFO    : Bus 4390	: V=1.06182269, theta=-3.56288213 -> V=1.0377785, theta=0.0
% INFO    : Bus 4391	: V=1.07608385, theta=-32.6805568 -> V=0.975, theta=0.0
% INFO    : Bus 4392	: V=1.03379682, theta=-35.8054656 -> V=1.0079355, theta=0.0
% INFO    : Bus 4393	: V=1.07614681, theta=-32.657503 -> V=1.04444, theta=0.0
% INFO    : Bus 4394	: V=1.02329344, theta=-49.5231433 -> V=1.0079355, theta=0.0
% INFO    : Bus 4395	: V=1.05740975, theta=-23.0646834 -> V=1.000001, theta=0.0
% INFO    : Bus 4396	: V=1.07254921, theta=-6.21360595 -> V=1.022222, theta=0.0
% INFO    : Bus 4397	: V=1.0710908, theta=-6.33202113 -> V=1.022222, theta=0.0
% INFO    : Bus 4398	: V=1.03464238, theta=-24.8141371 -> V=1.0000025, theta=0.0
% INFO    : Bus 4399	: V=1.06333774, theta=-21.7800336 -> V=1.044445, theta=0.0
% INFO    : Bus 4400	: V=1.07792725, theta=-15.7512959 -> V=1.046665, theta=0.0
% INFO    : Bus 4401	: V=1.03032133, theta=-19.7420107 -> V=0.999999, theta=0.0
% INFO    : Bus 4402	: V=1.00262337, theta=-41.7164446 -> V=1.0079355, theta=0.0
% INFO    : Bus 4403	: V=1.03894139, theta=-22.8333646 -> V=1.0000025, theta=0.0
% INFO    : Bus 4404	: V=1.01798347, theta=-45.1686935 -> V=1.0079355, theta=0.0
% INFO    : Bus 4405	: V=1.02362613, theta=-6.80858754 -> V=1.0158755, theta=0.0
% INFO    : Bus 4406	: V=1.08275275, theta=-17.3670991 -> V=1.044445, theta=0.0
% INFO    : Bus 4407	: V=1.04795594, theta=-12.5619477 -> V=1.000001, theta=0.0
% INFO    : Bus 4408	: V=1.00854261, theta=-15.4714735 -> V=0.999999, theta=0.0
% INFO    : Bus 4409	: V=1.01305613, theta=-19.6497049 -> V=0.999999, theta=0.0
% INFO    : Bus 4410	: V=1.02194475, theta=-16.8374242 -> V=1.015872, theta=0.0
% INFO    : Bus 4411	: V=1.02873187, theta=-17.3143503 -> V=1.022224, theta=0.0
% INFO    : Bus 4412	: V=1.03155991, theta=-10.6353481 -> V=0.999999, theta=0.0
% INFO    : Bus 4413	: V=0.995552148, theta=-35.1120403 -> V=1.015872, theta=0.0
% INFO    : Bus 4414	: V=1.01878892, theta=-44.5517491 -> V=1.0079355, theta=0.0
% INFO    : Bus 4415	: V=0.973881625, theta=-44.8097267 -> V=1.0079355, theta=0.0
% INFO    : Bus 4416	: V=1.02533284, theta=-29.878548 -> V=1.015872, theta=0.0
% INFO    : Bus 4417	: V=1.06736699, theta=-23.3699575 -> V=1.027779, theta=0.0
% INFO    : Bus 4418	: V=1.0103189, theta=-23.2714892 -> V=0.999999, theta=0.0
% INFO    : Bus 4419	: V=1.06138901, theta=-5.79172927 -> V=0.9888895, theta=0.0
% INFO    : Bus 4420	: V=1.06156817, theta=-5.78817801 -> V=0.9888895, theta=0.0
% INFO    : Bus 4421	: V=1.05271336, theta=-16.5920182 -> V=1.027779, theta=0.0
% INFO    : Bus 4422	: V=1.05259524, theta=-16.5892225 -> V=1.027779, theta=0.0
% INFO    : Bus 4423	: V=1.07417109, theta=-12.823732 -> V=1.046665, theta=0.0
% INFO    : Bus 4424	: V=0.982497774, theta=-12.7282499 -> V=0.999999, theta=0.0
% INFO    : Bus 4425	: V=0.984016576, theta=-14.074087 -> V=1.015872, theta=0.0
% INFO    : Bus 4426	: V=1.01932286, theta=-21.4479872 -> V=0.999999, theta=0.0
% INFO    : Bus 4427	: V=0.997571397, theta=-25.2924082 -> V=0.999999, theta=0.0
% INFO    : Bus 4428	: V=1.0187261, theta=-32.0346175 -> V=1.022224, theta=0.0
% INFO    : Bus 4429	: V=1.05169835, theta=-38.8064682 -> V=1.0079355, theta=0.0
% INFO    : Bus 4430	: V=1.00609068, theta=-18.7404197 -> V=1.0000005, theta=0.0
% INFO    : Bus 4431	: V=0.989, theta=-29.5758863 -> V=1.0000025, theta=0.0
% INFO    : Bus 4432	: V=1.07467775, theta=-21.3487427 -> V=1.000001, theta=0.0
% INFO    : Bus 4433	: V=1.0239754, theta=-24.2730595 -> V=1.0000025, theta=0.0
% INFO    : Bus 4434	: V=1.03736643, theta=-17.15637 -> V=0.999999, theta=0.0
% INFO    : Bus 4435	: V=0.998390851, theta=-17.4715808 -> V=0.999999, theta=0.0
% INFO    : Bus 4436	: V=1.01763476, theta=-45.1850664 -> V=1.0079355, theta=0.0
% INFO    : Bus 4437	: V=1.04964191, theta=-25.1595996 -> V=1.0000025, theta=0.0
% INFO    : Bus 4438	: V=1.03222989, theta=-19.2600707 -> V=1.0158755, theta=0.0
% INFO    : Bus 4439	: V=1.01473754, theta=-21.6697575 -> V=1.0158755, theta=0.0
% INFO    : Bus 4440	: V=1.02664974, theta=-26.1410362 -> V=1.0000025, theta=0.0
% INFO    : Bus 4441	: V=0.998726503, theta=-35.0770071 -> V=1.015872, theta=0.0
% INFO    : Bus 4442	: V=1.01289077, theta=-19.4298011 -> V=1.015872, theta=0.0
% INFO    : Bus 4443	: V=1.06939124, theta=-19.6038719 -> V=1.0248635, theta=0.0
% INFO    : Bus 4444	: V=1.05831536, theta=-16.2209992 -> V=1.046665, theta=0.0
% INFO    : Bus 4445	: V=1.06203384, theta=-25.6370071 -> V=1.0000025, theta=0.0
% INFO    : Bus 4446	: V=1.02135639, theta=-19.7340816 -> V=1.0158755, theta=0.0
% INFO    : Bus 4447	: V=1.0282196, theta=-22.7583374 -> V=1.022224, theta=0.0
% INFO    : Bus 4448	: V=0.981204463, theta=-21.6511303 -> V=1.0158755, theta=0.0
% INFO    : Bus 4449	: V=1.00434902, theta=-13.0910338 -> V=0.999999, theta=0.0
% INFO    : Bus 4450	: V=1.01901292, theta=-16.6016838 -> V=1.015872, theta=0.0
% INFO    : Bus 4451	: V=1.04559296, theta=-26.8762882 -> V=1.0000025, theta=0.0
% INFO    : Bus 4452	: V=1.02727004, theta=-24.2075536 -> V=1.000001, theta=0.0
% INFO    : Bus 4453	: V=1.01223964, theta=-19.8113212 -> V=0.999999, theta=0.0
% INFO    : Bus 4454	: V=1.05016904, theta=-22.883099 -> V=1.0000025, theta=0.0
% INFO    : Bus 4455	: V=1.00372761, theta=-29.0005337 -> V=1.0000025, theta=0.0
% INFO    : Bus 4456	: V=1.06158119, theta=-19.8024501 -> V=1.044445, theta=0.0
% INFO    : Bus 4457	: V=1.02359356, theta=-17.9835726 -> V=1.015872, theta=0.0
% INFO    : Bus 4458	: V=1.00620131, theta=-24.126833 -> V=1.0000025, theta=0.0
% INFO    : Bus 4459	: V=1.0512663, theta=-20.0536214 -> V=1.044445, theta=0.0
% INFO    : Bus 4460	: V=1.00576645, theta=-19.3561949 -> V=1.0158755, theta=0.0
% INFO    : Bus 4461	: V=1.04874751, theta=-23.109691 -> V=1.0000025, theta=0.0
% INFO    : Bus 4462	: V=1.0286936, theta=-13.6411624 -> V=0.999999, theta=0.0
% INFO    : Bus 4463	: V=1.0378027, theta=-11.8157597 -> V=0.999999, theta=0.0
% INFO    : Bus 4464	: V=1.05167343, theta=-9.1900785 -> V=1.0111115, theta=0.0
% INFO    : Bus 4465	: V=1.07688504, theta=-2.33154109 -> V=1.072365, theta=0.0
% INFO    : Bus 4466	: V=1.07597459, theta=-2.39264521 -> V=1.072365, theta=0.0
% INFO    : Bus 4467	: V=1.05266919, theta=-14.9210068 -> V=1.027779, theta=0.0
% INFO    : Bus 4468	: V=1.00940897, theta=-20.4144943 -> V=0.999999, theta=0.0
% INFO    : Bus 4469	: V=1.02050619, theta=-27.0546306 -> V=1.000001, theta=0.0
% INFO    : Bus 4470	: V=1.04003653, theta=-16.074025 -> V=1.027779, theta=0.0
% INFO    : Bus 4471	: V=1.0308217, theta=3.36279804 -> V=1.0158755, theta=0.0
% INFO    : Bus 4472	: V=1.03087419, theta=3.36683902 -> V=1.0158755, theta=0.0
% INFO    : Bus 4473	: V=1.04311507, theta=-0.21632833 -> V=1.0000025, theta=0.0
% INFO    : Bus 4474	: V=1.07504344, theta=3.10687509 -> V=1.0288895, theta=0.0
% INFO    : Bus 4475	: V=0.984149116, theta=-29.0449816 -> V=1.0000025, theta=0.0
% INFO    : Bus 4476	: V=1.014, theta=-3.2208353 -> V=0.975, theta=0.0
% INFO    : Bus 4477	: V=1.052, theta=-0.216442824 -> V=0.975, theta=0.0
% INFO    : Bus 4478	: V=1.052, theta=-0.0960255506 -> V=0.975, theta=0.0
% INFO    : Bus 4479	: V=1.049, theta=-0.0913816244 -> V=0.975, theta=0.0
% INFO    : Bus 4480	: V=1.052, theta=-0.0954234623 -> V=0.975, theta=0.0
% INFO    : Bus 4481	: V=1.00669892, theta=-6.86077273 -> V=1.0158755, theta=0.0
% INFO    : Bus 4482	: V=1.05080072, theta=-1.21541135 -> V=1.0377785, theta=0.0
% INFO    : Bus 4483	: V=1.05079999, theta=-1.2141822 -> V=1.0377785, theta=0.0
% INFO    : Bus 4484	: V=1.05076937, theta=-1.21419138 -> V=1.0377785, theta=0.0
% INFO    : Bus 4485	: V=1.05079998, theta=-1.21417606 -> V=1.0377785, theta=0.0
% INFO    : Bus 4486	: V=1.00661475, theta=-6.99009743 -> V=1.0158755, theta=0.0
% INFO    : Bus 4487	: V=1.0096215, theta=-7.01931278 -> V=1.0158755, theta=0.0
% INFO    : Bus 4488	: V=1.05079276, theta=-1.22572573 -> V=1.0377785, theta=0.0
% INFO    : Bus 4489	: V=1.02472299, theta=-9.02229003 -> V=0.984126, theta=0.0
% INFO    : Bus 4490	: V=1.07024339, theta=4.87926173 -> V=1.0377785, theta=0.0
% INFO    : Bus 4491	: V=0.994396754, theta=-21.4092311 -> V=1.0000005, theta=0.0
% INFO    : Bus 4492	: V=1.00115113, theta=-31.8030766 -> V=1.015872, theta=0.0
% INFO    : Bus 4493	: V=1.02716653, theta=-22.4573042 -> V=1.0158755, theta=0.0
% INFO    : Bus 4494	: V=1.03869242, theta=-30.2127006 -> V=1.022224, theta=0.0
% INFO    : Bus 4495	: V=0.978803585, theta=-21.5313365 -> V=1.015872, theta=0.0
% INFO    : Bus 4496	: V=0.979420199, theta=-21.3904473 -> V=1.015872, theta=0.0
% INFO    : Bus 4497	: V=1.02840343, theta=3.92370611 -> V=1.0158755, theta=0.0
% INFO    : Bus 4498	: V=1.03082154, theta=3.36280237 -> V=1.0158755, theta=0.0
% INFO    : Bus 4499	: V=1.07721367, theta=-14.2423357 -> V=1.032807, theta=0.0
% INFO    : Bus 4500	: V=1.07721367, theta=-14.2423357 -> V=1.032807, theta=0.0
% INFO    : Bus 4501	: V=1.03951162, theta=-14.2423357 -> V=1.0233335, theta=0.0
% INFO    : Bus 4502	: V=1.02133242, theta=-21.6135754 -> V=0.975, theta=0.0
% INFO    : Bus 4503	: V=1.02133242, theta=-21.6135754 -> V=0.999999, theta=0.0
% INFO    : Bus 4504	: V=1.07014033, theta=-18.7063724 -> V=1.000001, theta=0.0
% INFO    : Bus 4505	: V=1.07436673, theta=-1.54415367 -> V=1.072365, theta=0.0
% INFO    : Bus 4506	: V=1.00910194, theta=-22.7045568 -> V=1.015872, theta=0.0
% INFO    : Bus 4507	: V=1.00416869, theta=-23.381516 -> V=1.022224, theta=0.0
% INFO    : Bus 4508	: V=0.998216994, theta=-34.0548889 -> V=1.022224, theta=0.0
% INFO    : Bus 4509	: V=1.037, theta=-12.3073027 -> V=0.975, theta=0.0
% INFO    : Bus 4510	: V=1.03778139, theta=-13.3290269 -> V=0.999999, theta=0.0
% INFO    : Bus 4511	: V=1.01723746, theta=-20.334754 -> V=1.022224, theta=0.0
% INFO    : Bus 4512	: V=1.0019513, theta=-19.8205783 -> V=0.999999, theta=0.0
% INFO    : Bus 4513	: V=1.061, theta=-19.5211452 -> V=1.044445, theta=0.0
% INFO    : Bus 4514	: V=1.04471459, theta=-13.0449299 -> V=1.0000025, theta=0.0
% INFO    : Bus 4515	: V=1.05541666, theta=-10.1052781 -> V=1.013334, theta=0.0
% INFO    : Bus 4516	: V=1.01947553, theta=-25.8418639 -> V=1.0000025, theta=0.0
% INFO    : Bus 4517	: V=1.01725376, theta=-29.1939722 -> V=1.015872, theta=0.0
% INFO    : Bus 4518	: V=1.01645465, theta=-24.1257168 -> V=1.015872, theta=0.0
% INFO    : Bus 4519	: V=1.02778201, theta=-34.8194266 -> V=1.022224, theta=0.0
% INFO    : Bus 4520	: V=1.04619565, theta=-18.237108 -> V=1.022224, theta=0.0
% INFO    : Bus 4521	: V=1.01842241, theta=-1.87175066 -> V=1.0000025, theta=0.0
% INFO    : Bus 4522	: V=1.03839302, theta=-30.1634593 -> V=1.022224, theta=0.0
% INFO    : Bus 4523	: V=1.02640298, theta=-16.3246649 -> V=1.015872, theta=0.0
% INFO    : Bus 4524	: V=1.0541742, theta=-13.9453131 -> V=1.0233335, theta=0.0
% INFO    : Bus 4525	: V=1.05523554, theta=-12.8584379 -> V=1.046665, theta=0.0
% INFO    : Bus 4526	: V=1.00438458, theta=-9.8872855 -> V=0.9682545, theta=0.0
% INFO    : Bus 4527	: V=1.03696168, theta=-2.08668044 -> V=1.0000025, theta=0.0
% INFO    : Bus 4528	: V=1.01953368, theta=3.50993087 -> V=1.0158755, theta=0.0
% INFO    : Bus 4529	: V=1.02992157, theta=-27.2524003 -> V=1.0000025, theta=0.0
% INFO    : Bus 4530	: V=1.01398327, theta=-3.40684487 -> V=1.0158755, theta=0.0
% INFO    : Bus 4531	: V=1.07672234, theta=-8.93612781 -> V=1.04444, theta=0.0
% INFO    : Bus 4532	: V=1.08749538, theta=-5.09794106 -> V=1.07237, theta=0.0
% INFO    : Bus 4533	: V=0.992307741, theta=-22.9539993 -> V=1.015872, theta=0.0
% INFO    : Bus 4534	: V=1.02462983, theta=-14.3547549 -> V=0.999999, theta=0.0
% INFO    : Bus 4535	: V=0.559024918, theta=0.82184765 -> V=0.825, theta=0.0
% INFO    : Bus 4536	: V=1.01574224, theta=0.82184765 -> V=1.0158755, theta=0.0
% INFO    : Bus 4537	: V=1.04344592, theta=-40.0734802 -> V=1.0079355, theta=0.0
% INFO    : Bus 4538	: V=1.01082918, theta=-22.618485 -> V=1.0000005, theta=0.0
% INFO    : Bus 4539	: V=1.00126666, theta=-11.7501715 -> V=0.999999, theta=0.0
% INFO    : Bus 4540	: V=1.06608498, theta=-21.9647649 -> V=1.0000025, theta=0.0
% INFO    : Bus 4541	: V=1.05532805, theta=-20.5321066 -> V=1.000001, theta=0.0
% INFO    : Bus 4542	: V=1.07222588, theta=-19.4271196 -> V=1.044445, theta=0.0
% INFO    : Bus 4543	: V=1.03908187, theta=-23.7489018 -> V=1.0000025, theta=0.0
% INFO    : Bus 4544	: V=1.04288834, theta=-19.6915478 -> V=0.999999, theta=0.0
% INFO    : Bus 4545	: V=1.04105765, theta=-36.9433883 -> V=1.022224, theta=0.0
% INFO    : Bus 4546	: V=1.02327747, theta=-18.0422375 -> V=1.015872, theta=0.0
% INFO    : Bus 4547	: V=1.05761189, theta=-15.5554198 -> V=1.044445, theta=0.0
% INFO    : Bus 4548	: V=1.05962919, theta=-11.9856738 -> V=1.078945, theta=0.0
% INFO    : Bus 4549	: V=1.04421226, theta=-13.4574466 -> V=0.999999, theta=0.0
% INFO    : Bus 4550	: V=1.03316811, theta=-37.9340975 -> V=1.0079355, theta=0.0
% INFO    : Bus 4551	: V=1.02485782, theta=-39.0915742 -> V=1.0079355, theta=0.0
% INFO    : Bus 4552	: V=1.03552607, theta=-37.869646 -> V=1.0079355, theta=0.0
% INFO    : Bus 4553	: V=1.05109718, theta=-17.740317 -> V=1.000001, theta=0.0
% INFO    : Bus 4554	: V=1.01427479, theta=-12.8204599 -> V=0.999999, theta=0.0
% INFO    : Bus 4555	: V=1.03584862, theta=-25.6112411 -> V=1.0000025, theta=0.0
% INFO    : Bus 4556	: V=1.05387361, theta=-23.9092644 -> V=1.0, theta=0.0
% INFO    : Bus 4557	: V=1.06955305, theta=-23.7731082 -> V=1.044445, theta=0.0
% INFO    : Bus 4558	: V=1.0200589, theta=-24.4251589 -> V=1.0000025, theta=0.0
% INFO    : Bus 4559	: V=1.01713085, theta=-24.7945316 -> V=1.0000025, theta=0.0
% INFO    : Bus 4560	: V=1.0810134, theta=-17.2107 -> V=1.044445, theta=0.0
% INFO    : Bus 4561	: V=1.01499409, theta=-24.3409572 -> V=0.999999, theta=0.0
% INFO    : Bus 4562	: V=1.05928659, theta=-21.929786 -> V=1.0000025, theta=0.0
% INFO    : Bus 4563	: V=1.04141649, theta=-21.1615008 -> V=1.0010505, theta=0.0
% INFO    : Bus 4564	: V=1.042, theta=-20.5729821 -> V=1.0000025, theta=0.0
% INFO    : Bus 4565	: V=1.02149698, theta=-12.2791911 -> V=0.999999, theta=0.0
% INFO    : Bus 4566	: V=1.02508336, theta=-20.0883174 -> V=0.999999, theta=0.0
% INFO    : Bus 4567	: V=1.01308397, theta=-22.0223503 -> V=0.999999, theta=0.0
% INFO    : Bus 4568	: V=1.02424111, theta=-26.4478328 -> V=1.0000025, theta=0.0
% INFO    : Bus 4569	: V=1.07618327, theta=-19.03068 -> V=1.029934, theta=0.0
% INFO    : Bus 4570	: V=1.09149652, theta=-13.8147163 -> V=1.073685, theta=0.0
% INFO    : Bus 4571	: V=1.053, theta=-14.063838 -> V=1.0377785, theta=0.0
% INFO    : Bus 4572	: V=1.04873953, theta=-10.5516828 -> V=1.046665, theta=0.0
% INFO    : Bus 4573	: V=1.05140855, theta=-9.50743942 -> V=1.046665, theta=0.0
% INFO    : Bus 4574	: V=1.0580879, theta=-4.55427995 -> V=1.078945, theta=0.0
% INFO    : Bus 4575	: V=1.06312567, theta=-21.9603404 -> V=1.04444, theta=0.0
% INFO    : Bus 4576	: V=1.05290922, theta=-38.0307283 -> V=1.04444, theta=0.0
% INFO    : Bus 4577	: V=1.01395247, theta=-21.6257271 -> V=1.0000005, theta=0.0
% INFO    : Bus 4578	: V=1.12049758, theta=5.61909271 -> V=1.0424605, theta=0.0
% INFO    : Bus 4579	: V=1.01653798, theta=-29.0700102 -> V=1.0000025, theta=0.0
% INFO    : Bus 4580	: V=1.02302239, theta=-18.0316726 -> V=0.999999, theta=0.0
% INFO    : Bus 4581	: V=1.00068077, theta=-12.5490711 -> V=1.015872, theta=0.0
% INFO    : Bus 4582	: V=1.00067699, theta=-12.5489888 -> V=1.015872, theta=0.0
% INFO    : Bus 4583	: V=1.07597513, theta=-16.132088 -> V=1.046665, theta=0.0
% INFO    : Bus 4584	: V=0.949893251, theta=-6.69466037 -> V=0.9444445, theta=0.0
% INFO    : Bus 4585	: V=1.033, theta=-26.0672713 -> V=1.0000025, theta=0.0
% INFO    : Bus 4586	: V=1.02643681, theta=-14.5511079 -> V=0.999999, theta=0.0
% INFO    : Bus 4587	: V=1.03965641, theta=-1.53000033 -> V=1.0000025, theta=0.0
% INFO    : Bus 4588	: V=1.04962638, theta=-12.6005305 -> V=1.000001, theta=0.0
% INFO    : Bus 4589	: V=1.06970412, theta=-18.9049162 -> V=1.046665, theta=0.0
% INFO    : Bus 4590	: V=1.047916, theta=-12.5646566 -> V=1.033333, theta=0.0
% INFO    : Bus 4591	: V=0.998950787, theta=-30.9128049 -> V=1.0000025, theta=0.0
% INFO    : Bus 4592	: V=1.07154592, theta=-21.3642082 -> V=1.027779, theta=0.0
% INFO    : Bus 4593	: V=1.09058004, theta=-13.8713452 -> V=1.073685, theta=0.0
% INFO    : Bus 4594	: V=1.09015483, theta=-13.8677633 -> V=1.073685, theta=0.0
% INFO    : Bus 4595	: V=1.04226548, theta=-15.8073542 -> V=1.015872, theta=0.0
% INFO    : Bus 4596	: V=1.04017144, theta=-11.8866884 -> V=1.046665, theta=0.0
% INFO    : Bus 4597	: V=1.04621231, theta=-14.3884799 -> V=0.999999, theta=0.0
% INFO    : Bus 4598	: V=1.06844375, theta=-13.3364303 -> V=1.046665, theta=0.0
% INFO    : Bus 4599	: V=1.07670911, theta=-9.28522216 -> V=1.073685, theta=0.0
% INFO    : Bus 4600	: V=1.07680178, theta=-9.61903082 -> V=1.073685, theta=0.0
% INFO    : Bus 4601	: V=1.00500559, theta=-24.4041043 -> V=1.022224, theta=0.0
% INFO    : Bus 4602	: V=1.0304074, theta=-24.198711 -> V=1.0000025, theta=0.0
% INFO    : Bus 4603	: V=1.04914369, theta=-22.5750771 -> V=1.022224, theta=0.0
% INFO    : Bus 4604	: V=1.04297072, theta=-8.72877042 -> V=1.0158755, theta=0.0
% INFO    : Bus 4605	: V=0.987923781, theta=-33.7581732 -> V=1.0214805, theta=0.0
% INFO    : Bus 4606	: V=1.00397448, theta=-23.3763011 -> V=1.022224, theta=0.0
% INFO    : Bus 4607	: V=1.04425419, theta=-47.9850862 -> V=1.0079355, theta=0.0
% INFO    : Bus 4608	: V=1.05948713, theta=-40.37921 -> V=1.04444, theta=0.0
% INFO    : Bus 4609	: V=1.03317129, theta=-6.86634986 -> V=1.0158755, theta=0.0
% INFO    : Bus 4610	: V=1.0123441, theta=-18.2521481 -> V=1.0000005, theta=0.0
% INFO    : Bus 4611	: V=1.02364669, theta=-33.2339478 -> V=1.022224, theta=0.0
% INFO    : Bus 4612	: V=1.01385668, theta=-19.1861359 -> V=1.015872, theta=0.0
% INFO    : Bus 4613	: V=1.06077573, theta=-39.7273037 -> V=1.022224, theta=0.0
% INFO    : Bus 4614	: V=1.02049346, theta=-24.3548678 -> V=0.999999, theta=0.0
% INFO    : Bus 4615	: V=1.0665413, theta=-8.71905109 -> V=1.000001, theta=0.0
% INFO    : Bus 4616	: V=1.06055841, theta=-5.3797785 -> V=0.9888895, theta=0.0
% INFO    : Bus 4617	: V=0.994820252, theta=-11.2618846 -> V=1.0158755, theta=0.0
% INFO    : Bus 4618	: V=1.04763282, theta=-24.8958574 -> V=1.027779, theta=0.0
% INFO    : Bus 4619	: V=1.02441225, theta=-17.9047364 -> V=1.022224, theta=0.0
% INFO    : Bus 4620	: V=1.0230714, theta=-18.4239439 -> V=1.022224, theta=0.0
% INFO    : Bus 4621	: V=1.01905103, theta=3.46381093 -> V=1.0158755, theta=0.0
% INFO    : Bus 4622	: V=1.07182429, theta=-24.7147698 -> V=1.046665, theta=0.0
% INFO    : Bus 4623	: V=1.02145142, theta=-12.2791565 -> V=0.999999, theta=0.0
% INFO    : Bus 4624	: V=1.01093025, theta=-37.2684948 -> V=1.0000025, theta=0.0
% INFO    : Bus 4625	: V=1.01210629, theta=-16.0105523 -> V=0.999999, theta=0.0
% INFO    : Bus 4626	: V=1.05599523, theta=-16.4049767 -> V=0.999999, theta=0.0
% INFO    : Bus 4627	: V=1.01128238, theta=-33.6233919 -> V=1.022224, theta=0.0
% INFO    : Bus 4628	: V=1.02091916, theta=-16.3692235 -> V=1.015872, theta=0.0
% INFO    : Bus 4629	: V=1.00826239, theta=-24.8353354 -> V=1.022224, theta=0.0
% INFO    : Bus 4630	: V=1.01606104, theta=-16.5205838 -> V=1.0000005, theta=0.0
% INFO    : Bus 4631	: V=1.02902473, theta=-27.5401407 -> V=1.022224, theta=0.0
% INFO    : Bus 4632	: V=1.00366427, theta=-29.9517317 -> V=1.0000025, theta=0.0
% INFO    : Bus 4633	: V=1.03183971, theta=-26.9360812 -> V=1.0000025, theta=0.0
% INFO    : Bus 4634	: V=1.07659384, theta=-4.5922864 -> V=1.0377785, theta=0.0
% INFO    : Bus 4635	: V=1.02577266, theta=-12.9264484 -> V=0.999999, theta=0.0
% INFO    : Bus 4636	: V=1.04879338, theta=-18.0560919 -> V=1.027779, theta=0.0
% INFO    : Bus 4637	: V=1.07976893, theta=-11.3895011 -> V=1.073685, theta=0.0
% INFO    : Bus 4638	: V=1.08025581, theta=-11.4006715 -> V=1.073685, theta=0.0
% INFO    : Bus 4639	: V=1.02704135, theta=-18.7226509 -> V=1.0158755, theta=0.0
% INFO    : Bus 4640	: V=1.06261091, theta=-16.4112244 -> V=1.046665, theta=0.0
% INFO    : Bus 4641	: V=1.0215054, theta=-39.2161928 -> V=1.022224, theta=0.0
% INFO    : Bus 4642	: V=1.02449332, theta=-17.57904 -> V=1.022224, theta=0.0
% INFO    : Bus 4643	: V=1.02642425, theta=-17.8133676 -> V=1.022224, theta=0.0
% INFO    : Bus 4644	: V=0.976242758, theta=-12.9960301 -> V=0.9444445, theta=0.0
% INFO    : Bus 4645	: V=1.08159983, theta=-16.5283683 -> V=1.046665, theta=0.0
% INFO    : Bus 4646	: V=1.07033346, theta=-18.2475294 -> V=1.027779, theta=0.0
% INFO    : Bus 4647	: V=1.09524224, theta=-12.3641799 -> V=1.073685, theta=0.0
% INFO    : Bus 4648	: V=1.06857399, theta=-19.5301046 -> V=1.027779, theta=0.0
% INFO    : Bus 4649	: V=1.03492413, theta=-14.5094343 -> V=1.0158755, theta=0.0
% INFO    : Bus 4650	: V=1.07381089, theta=-12.1838776 -> V=1.0377785, theta=0.0
% INFO    : Bus 4651	: V=1.07347318, theta=-12.1893993 -> V=1.0377785, theta=0.0
% INFO    : Bus 4652	: V=1.03696263, theta=-2.08670455 -> V=1.0000025, theta=0.0
% INFO    : Bus 4653	: V=1.04287734, theta=-24.7003733 -> V=1.0000025, theta=0.0
% INFO    : Bus 4654	: V=1.04390314, theta=-22.0973485 -> V=1.0000025, theta=0.0
% INFO    : Bus 4655	: V=1.04056139, theta=-22.3489042 -> V=1.027779, theta=0.0
% INFO    : Bus 4656	: V=1.03114736, theta=-20.0943601 -> V=1.0000005, theta=0.0
% INFO    : Bus 4657	: V=0.998905375, theta=-28.4031246 -> V=1.0000025, theta=0.0
% INFO    : Bus 4658	: V=1.01867696, theta=-18.9170664 -> V=1.022224, theta=0.0
% INFO    : Bus 4659	: V=1.03255758, theta=-16.581785 -> V=1.022224, theta=0.0
% INFO    : Bus 4660	: V=1.07620059, theta=-17.1760492 -> V=1.046665, theta=0.0
% INFO    : Bus 4661	: V=1.08579268, theta=-13.1228091 -> V=1.073685, theta=0.0
% INFO    : Bus 4662	: V=0.946922165, theta=-10.3255019 -> V=0.9444445, theta=0.0
% INFO    : Bus 4663	: V=1.06914271, theta=-18.3516298 -> V=1.027779, theta=0.0
% INFO    : Bus 4664	: V=1.00027711, theta=-12.2328119 -> V=0.999999, theta=0.0
% INFO    : Bus 4665	: V=1.01915844, theta=-27.251595 -> V=1.022224, theta=0.0
% INFO    : Bus 4666	: V=1.02606088, theta=-18.1190522 -> V=1.022224, theta=0.0
% INFO    : Bus 4667	: V=1.02009281, theta=-21.0805506 -> V=1.0000005, theta=0.0
% INFO    : Bus 4668	: V=1.05588165, theta=-28.0952973 -> V=1.022224, theta=0.0
% INFO    : Bus 4669	: V=1.06710799, theta=-21.081924 -> V=1.044445, theta=0.0
% INFO    : Bus 4670	: V=1.05016833, theta=-9.98317137 -> V=1.0111115, theta=0.0
% INFO    : Bus 4671	: V=1.008, theta=-22.0800141 -> V=0.975, theta=0.0
% INFO    : Bus 4672	: V=0.987567152, theta=-28.9127603 -> V=0.975, theta=0.0
% INFO    : Bus 4673	: V=0.987559009, theta=-28.9054187 -> V=1.0000025, theta=0.0
% INFO    : Bus 4674	: V=1.00788772, theta=-22.0956631 -> V=1.0000025, theta=0.0
% INFO    : Bus 4675	: V=1.02278517, theta=-30.2041966 -> V=1.015872, theta=0.0
% INFO    : Bus 4676	: V=1.04003288, theta=-26.1107907 -> V=1.046665, theta=0.0
% INFO    : Bus 4677	: V=1.04305211, theta=-23.6859792 -> V=1.06579, theta=0.0
% INFO    : Bus 4678	: V=1.01089444, theta=-15.6966932 -> V=1.015872, theta=0.0
% INFO    : Bus 4679	: V=1.02050619, theta=-27.0546306 -> V=1.000001, theta=0.0
% INFO    : Bus 4680	: V=0.991696013, theta=-18.6238463 -> V=0.999999, theta=0.0
% INFO    : Bus 4681	: V=1.03180832, theta=-40.1038793 -> V=1.0079355, theta=0.0
% INFO    : Bus 4682	: V=1.03593211, theta=-44.1734162 -> V=1.0079355, theta=0.0
% INFO    : Bus 4683	: V=1.06360478, theta=-36.731162 -> V=1.04444, theta=0.0
% INFO    : Bus 4684	: V=1.03191241, theta=-30.543901 -> V=1.022224, theta=0.0
% INFO    : Bus 4685	: V=1.05214665, theta=-12.6749516 -> V=1.000001, theta=0.0
% INFO    : Bus 4686	: V=1.01224519, theta=-33.7485056 -> V=1.022224, theta=0.0
% INFO    : Bus 4687	: V=1.02333781, theta=-19.2287854 -> V=1.015872, theta=0.0
% INFO    : Bus 4688	: V=1.04399589, theta=-16.2544522 -> V=0.999999, theta=0.0
% INFO    : Bus 4689	: V=1.03412358, theta=-12.4993832 -> V=1.0111115, theta=0.0
% INFO    : Bus 4690	: V=1.02009957, theta=-25.1812013 -> V=1.022224, theta=0.0
% INFO    : Bus 4691	: V=1.01799574, theta=-10.8043929 -> V=1.015872, theta=0.0
% INFO    : Bus 4692	: V=1.01799559, theta=-10.8044211 -> V=1.015872, theta=0.0
% INFO    : Bus 4693	: V=1.01476331, theta=3.99001313 -> V=1.033334, theta=0.0
% INFO    : Bus 4694	: V=1.01279285, theta=3.7650234 -> V=1.033334, theta=0.0
% INFO    : Bus 4695	: V=1.01351188, theta=3.78391903 -> V=1.033334, theta=0.0
% INFO    : Bus 4696	: V=1.01231412, theta=4.17423959 -> V=1.033334, theta=0.0
% INFO    : Bus 4697	: V=1.02179373, theta=-19.3561343 -> V=1.0158755, theta=0.0
% INFO    : Bus 4698	: V=1.03668876, theta=-35.2581043 -> V=1.0079355, theta=0.0
% INFO    : Bus 4699	: V=1.0590268, theta=-10.1215781 -> V=1.022222, theta=0.0
% INFO    : Bus 4700	: V=1.03239404, theta=-16.983926 -> V=1.015872, theta=0.0
% INFO    : Bus 4701	: V=0.991138649, theta=-23.8418948 -> V=1.015872, theta=0.0
% INFO    : Bus 4702	: V=1.06872981, theta=-4.37295405 -> V=0.9888895, theta=0.0
% INFO    : Bus 4703	: V=1.06873775, theta=-4.37152211 -> V=0.9888895, theta=0.0
% INFO    : Bus 4704	: V=1.0575131, theta=-6.03037172 -> V=1.046665, theta=0.0
% INFO    : Bus 4705	: V=1.01303208, theta=2.98289444 -> V=1.046665, theta=0.0
% INFO    : Bus 4706	: V=1.01080418, theta=2.75700324 -> V=1.046665, theta=0.0
% INFO    : Bus 4707	: V=1.012828, theta=3.148931 -> V=1.046665, theta=0.0
% INFO    : Bus 4708	: V=1.01112678, theta=2.98446176 -> V=1.046665, theta=0.0
% INFO    : Bus 4709	: V=1.01164005, theta=2.79008402 -> V=1.046665, theta=0.0
% INFO    : Bus 4710	: V=1.01031654, theta=2.99353816 -> V=1.046585, theta=0.0
% INFO    : Bus 4711	: V=1.01199094, theta=3.00516496 -> V=1.046665, theta=0.0
% INFO    : Bus 4712	: V=1.01055913, theta=3.23718709 -> V=1.046665, theta=0.0
% INFO    : Bus 4713	: V=1.06573292, theta=-0.617890486 -> V=1.078945, theta=0.0
% INFO    : Bus 4714	: V=1.0130225, theta=-29.5238013 -> V=1.0000025, theta=0.0
% INFO    : Bus 4715	: V=1.03410442, theta=-10.0486272 -> V=1.0158755, theta=0.0
% INFO    : Bus 4716	: V=1.01452109, theta=-6.59421031 -> V=1.0158755, theta=0.0
% INFO    : Bus 4717	: V=1.05035147, theta=-22.8555499 -> V=1.0000025, theta=0.0
% INFO    : Bus 4718	: V=1.07318214, theta=-17.8719118 -> V=1.0, theta=0.0
% INFO    : Bus 4719	: V=1.01322162, theta=0.630956141 -> V=1.0158755, theta=0.0
% INFO    : Bus 4720	: V=1.068, theta=-26.3018124 -> V=1.0000025, theta=0.0
% INFO    : Bus 4721	: V=1.0483716, theta=-21.9816145 -> V=1.044445, theta=0.0
% INFO    : Bus 4722	: V=1.03229273, theta=-25.3395125 -> V=1.000001, theta=0.0
% INFO    : Bus 4723	: V=1.07609126, theta=-0.263137587 -> V=0.9888895, theta=0.0
% INFO    : Bus 4724	: V=1.07610374, theta=-0.260831338 -> V=0.9888895, theta=0.0
% INFO    : Bus 4725	: V=1.07599274, theta=-0.270139775 -> V=0.9888895, theta=0.0
% INFO    : Bus 4726	: V=1.02551284, theta=-26.0390966 -> V=1.000001, theta=0.0
% INFO    : Bus 4727	: V=1.07774858, theta=-15.7818796 -> V=1.046665, theta=0.0
% INFO    : Bus 4728	: V=1.00999166, theta=-6.11249192 -> V=1.0158755, theta=0.0
% INFO    : Bus 4729	: V=1.02837012, theta=-16.0766574 -> V=1.0000005, theta=0.0
% INFO    : Bus 4730	: V=1.02812268, theta=-26.9366873 -> V=1.022224, theta=0.0
% INFO    : Bus 4731	: V=1.06954759, theta=-0.698278447 -> V=1.0377785, theta=0.0
% INFO    : Bus 4732	: V=1.00038292, theta=-6.58408199 -> V=0.999999, theta=0.0
% INFO    : Bus 4733	: V=1.0476434, theta=-24.8959139 -> V=1.027779, theta=0.0
% INFO    : Bus 4734	: V=1.03062741, theta=-10.2744984 -> V=1.0158755, theta=0.0
% INFO    : Bus 4735	: V=1.03694837, theta=-29.483697 -> V=1.015872, theta=0.0
% INFO    : Bus 4736	: V=1.04566877, theta=-26.4785249 -> V=1.046665, theta=0.0
% INFO    : Bus 4737	: V=1.08646275, theta=-14.274416 -> V=1.04777, theta=0.0
% INFO    : Bus 4738	: V=0.998859076, theta=-7.08744585 -> V=1.0000015, theta=0.0
% INFO    : Bus 4739	: V=0.99110506, theta=-17.8010417 -> V=0.999999, theta=0.0
% INFO    : Bus 4740	: V=1.02483378, theta=-9.84618657 -> V=0.999999, theta=0.0
% INFO    : Bus 4741	: V=1.01880912, theta=-2.77112564 -> V=1.0158755, theta=0.0
% INFO    : Bus 4742	: V=1.01678519, theta=-29.245352 -> V=1.015872, theta=0.0
% INFO    : Bus 4743	: V=1.041692, theta=-25.9501579 -> V=1.046665, theta=0.0
% INFO    : Bus 4744	: V=0.946922165, theta=-10.3255019 -> V=0.9444445, theta=0.0
% INFO    : Bus 4745	: V=1.04953097, theta=-7.72248148 -> V=1.0111115, theta=0.0
% INFO    : Bus 4746	: V=1.01719677, theta=-27.00455 -> V=1.0000025, theta=0.0
% INFO    : Bus 4747	: V=1.03243497, theta=-16.32454 -> V=0.999999, theta=0.0
% INFO    : Bus 4748	: V=1.02317821, theta=-25.7128255 -> V=1.0000025, theta=0.0
% INFO    : Bus 4749	: V=1.04559317, theta=-26.8762925 -> V=1.0000025, theta=0.0
% INFO    : Bus 4750	: V=1.05091946, theta=-19.5590687 -> V=1.0000025, theta=0.0
% INFO    : Bus 4751	: V=1.02526725, theta=-7.22548633 -> V=1.0158755, theta=0.0
% INFO    : Bus 4752	: V=1.01251731, theta=3.28998854 -> V=1.013331, theta=0.0
% INFO    : Bus 4753	: V=1.07054108, theta=-1.61334988 -> V=1.033333, theta=0.0
% INFO    : Bus 4754	: V=1.04587136, theta=-22.2722513 -> V=1.000001, theta=0.0
% INFO    : Bus 4755	: V=1.024, theta=-28.7090283 -> V=1.0000025, theta=0.0
% INFO    : Bus 4756	: V=1.013, theta=-19.4131083 -> V=1.015872, theta=0.0
% INFO    : Bus 4757	: V=1.013, theta=-19.4131083 -> V=1.015872, theta=0.0
% INFO    : Bus 4758	: V=1.01162936, theta=-52.0903233 -> V=1.0079355, theta=0.0
% INFO    : Bus 4759	: V=0.984983093, theta=-21.238171 -> V=1.015872, theta=0.0
% INFO    : Bus 4760	: V=1.00699789, theta=-17.7753929 -> V=1.0000005, theta=0.0
% INFO    : Bus 4761	: V=1.07483653, theta=-14.7276568 -> V=1.046665, theta=0.0
% INFO    : Bus 4762	: V=1.07972873, theta=-14.6420569 -> V=1.046665, theta=0.0
% INFO    : Bus 4763	: V=1.0553397, theta=-6.90074707 -> V=1.0111115, theta=0.0
% INFO    : Bus 4764	: V=0.97464332, theta=-22.9702071 -> V=1.015872, theta=0.0
% INFO    : Bus 4765	: V=1.01493354, theta=-26.7945454 -> V=1.015872, theta=0.0
% INFO    : Bus 4766	: V=1.038, theta=-25.6068718 -> V=1.0233335, theta=0.0
% INFO    : Bus 4767	: V=1.0014563, theta=-13.2014729 -> V=1.015872, theta=0.0
% INFO    : Bus 4768	: V=1.01282083, theta=-31.7372431 -> V=1.015872, theta=0.0
% INFO    : Bus 4769	: V=1.05454115, theta=-21.1789586 -> V=1.027779, theta=0.0
% INFO    : Bus 4770	: V=0.999535685, theta=-18.2034795 -> V=1.0158755, theta=0.0
% INFO    : Bus 4771	: V=0.94012532, theta=-13.2506168 -> V=0.975, theta=0.0
% INFO    : Bus 4772	: V=1.03595224, theta=-17.0051732 -> V=1.022224, theta=0.0
% INFO    : Bus 4773	: V=1.06564831, theta=-12.750977 -> V=1.04444, theta=0.0
% INFO    : Bus 4774	: V=1.08248196, theta=-6.06304511 -> V=1.07237, theta=0.0
% INFO    : Bus 4775	: V=1.01371741, theta=-16.7781835 -> V=1.0158755, theta=0.0
% INFO    : Bus 4776	: V=1.01475915, theta=-11.6110413 -> V=1.0158755, theta=0.0
% INFO    : Bus 4777	: V=0.983390942, theta=-29.1644606 -> V=1.0000025, theta=0.0
% INFO    : Bus 4778	: V=1.00979681, theta=-11.2447054 -> V=0.999999, theta=0.0
% INFO    : Bus 4779	: V=1.03062368, theta=-6.98473848 -> V=1.0111115, theta=0.0
% INFO    : Bus 4780	: V=1.02448425, theta=-17.9619098 -> V=1.022224, theta=0.0
% INFO    : Bus 4781	: V=1.06182761, theta=-5.20718651 -> V=0.9888895, theta=0.0
% INFO    : Bus 4782	: V=1.01966559, theta=-18.3489736 -> V=1.0000005, theta=0.0
% INFO    : Bus 4783	: V=1.06283811, theta=-14.6616439 -> V=1.046665, theta=0.0
% INFO    : Bus 4784	: V=1.00274473, theta=-28.1207601 -> V=1.0000025, theta=0.0
% INFO    : Bus 4785	: V=1.01920734, theta=-20.7200096 -> V=1.015872, theta=0.0
% INFO    : Bus 4786	: V=1.02374234, theta=-28.8362303 -> V=1.022224, theta=0.0
% INFO    : Bus 4787	: V=1.0200683, theta=-27.8209687 -> V=1.022224, theta=0.0
% INFO    : Bus 4788	: V=1.02259202, theta=-38.9040737 -> V=1.022224, theta=0.0
% INFO    : Bus 4789	: V=1.01348633, theta=-19.645728 -> V=0.999999, theta=0.0
% INFO    : Bus 4790	: V=1.05441173, theta=-28.311244 -> V=1.022224, theta=0.0
% INFO    : Bus 4791	: V=1.0567069, theta=-19.6277694 -> V=1.027779, theta=0.0
% INFO    : Bus 4792	: V=1.05439315, theta=-20.5655313 -> V=1.027779, theta=0.0
% INFO    : Bus 4793	: V=1.028, theta=-11.4224653 -> V=0.999999, theta=0.0
% INFO    : Bus 4794	: V=1.07131419, theta=-8.32351152 -> V=1.0111115, theta=0.0
% INFO    : Bus 4795	: V=1.02478476, theta=-17.1737451 -> V=1.0000005, theta=0.0
% INFO    : Bus 4796	: V=1.02435705, theta=-17.1860714 -> V=1.0000005, theta=0.0
% INFO    : Bus 4797	: V=0.974749626, theta=-17.7606432 -> V=1.015872, theta=0.0
% INFO    : Bus 4798	: V=0.975464094, theta=-17.6263037 -> V=1.015872, theta=0.0
% INFO    : Bus 4799	: V=1.00031578, theta=-13.28542 -> V=1.015872, theta=0.0
% INFO    : Bus 4800	: V=1.04064577, theta=-18.7403515 -> V=1.027779, theta=0.0
% INFO    : Bus 4801	: V=1.01557643, theta=-29.9537143 -> V=1.015872, theta=0.0
% INFO    : Bus 4802	: V=1.0209742, theta=2.20462114 -> V=1.0158755, theta=0.0
% INFO    : Bus 4803	: V=1.07869332, theta=4.21238918 -> V=1.0396585, theta=0.0
% INFO    : Bus 4804	: V=1.001, theta=-11.7476203 -> V=0.999999, theta=0.0
% INFO    : Bus 4805	: V=1.04085102, theta=-48.6558206 -> V=1.0079355, theta=0.0
% INFO    : Bus 4806	: V=0.995632286, theta=-21.3365061 -> V=1.0000005, theta=0.0
% INFO    : Bus 4807	: V=1.00154307, theta=-5.46542622 -> V=1.0158755, theta=0.0
% INFO    : Bus 4808	: V=1.02534196, theta=-17.7268675 -> V=1.022224, theta=0.0
% INFO    : Bus 4809	: V=1.03785292, theta=-28.829903 -> V=1.022224, theta=0.0
% INFO    : Bus 4810	: V=1.0678265, theta=-15.6244882 -> V=1.04444, theta=0.0
% INFO    : Bus 4811	: V=1.00514008, theta=-19.9351504 -> V=1.0158755, theta=0.0
% INFO    : Bus 4812	: V=1.04304665, theta=-22.1047647 -> V=1.027779, theta=0.0
% INFO    : Bus 4813	: V=1.01769544, theta=-18.8983487 -> V=1.015872, theta=0.0
% INFO    : Bus 4814	: V=1.05468232, theta=-29.8168827 -> V=1.027779, theta=0.0
% INFO    : Bus 4815	: V=1.06157828, theta=-8.83546081 -> V=1.0111115, theta=0.0
% INFO    : Bus 4816	: V=1.04209415, theta=-18.9654501 -> V=1.027779, theta=0.0
% INFO    : Bus 4817	: V=1.016, theta=-11.0661356 -> V=1.0158755, theta=0.0
% INFO    : Bus 4818	: V=1.013, theta=-12.0498095 -> V=0.975, theta=0.0
% INFO    : Bus 4819	: V=1.012, theta=-12.1809929 -> V=0.975, theta=0.0
% INFO    : Bus 4820	: V=1.01210216, theta=-12.9437976 -> V=0.999999, theta=0.0
% INFO    : Bus 4821	: V=1.012089, theta=-12.9444815 -> V=0.999999, theta=0.0
% INFO    : Bus 4822	: V=1.0294326, theta=-28.2283926 -> V=1.022224, theta=0.0
% INFO    : Bus 4823	: V=1.01062512, theta=-13.1290697 -> V=0.999999, theta=0.0
% INFO    : Bus 4824	: V=1.08, theta=1.55148213 -> V=0.975, theta=0.0
% INFO    : Bus 4825	: V=1.085, theta=5.49014298 -> V=0.975, theta=0.0
% INFO    : Bus 4826	: V=1.06609766, theta=-4.42263701 -> V=1.072365, theta=0.0
% INFO    : Bus 4827	: V=1.06900684, theta=-13.7560154 -> V=1.027779, theta=0.0
% INFO    : Bus 4828	: V=1.08148979, theta=-10.364137 -> V=1.046665, theta=0.0
% INFO    : Bus 4829	: V=1.08198046, theta=-10.81973 -> V=1.046665, theta=0.0
% INFO    : Bus 4830	: V=1.08900529, theta=-4.57344528 -> V=1.073685, theta=0.0
% INFO    : Bus 4831	: V=0.992775351, theta=-22.973586 -> V=1.015872, theta=0.0
% INFO    : Bus 4832	: V=1.04221332, theta=-15.999987 -> V=0.984126, theta=0.0
% INFO    : Bus 4833	: V=1.03555833, theta=-26.4379451 -> V=1.022224, theta=0.0
% INFO    : Bus 4834	: V=0.999187299, theta=-18.5691568 -> V=1.015872, theta=0.0
% INFO    : Bus 4835	: V=1.02801176, theta=-16.6004529 -> V=0.999999, theta=0.0
% INFO    : Bus 4836	: V=1.03370244, theta=-12.5335675 -> V=1.033333, theta=0.0
% INFO    : Bus 4837	: V=1.01964859, theta=-16.5497276 -> V=1.015872, theta=0.0
% INFO    : Bus 4838	: V=1.01988116, theta=-16.5687475 -> V=1.0158755, theta=0.0
% INFO    : Bus 4839	: V=1.01438335, theta=-17.6497143 -> V=1.0158755, theta=0.0
% INFO    : Bus 4840	: V=1.0308727, theta=-29.90735 -> V=1.015872, theta=0.0
% INFO    : Bus 4841	: V=0.994479707, theta=-22.7338375 -> V=1.0000025, theta=0.0
% INFO    : Bus 4842	: V=0.993890232, theta=-23.444118 -> V=1.0000025, theta=0.0
% INFO    : Bus 4843	: V=1.04402494, theta=-16.2518596 -> V=0.999999, theta=0.0
% INFO    : Bus 4844	: V=1.0521566, theta=-6.77786747 -> V=0.9888895, theta=0.0
% INFO    : Bus 4845	: V=1.00950457, theta=-22.9375921 -> V=1.022224, theta=0.0
% INFO    : Bus 4846	: V=1.02895861, theta=-18.5021633 -> V=1.022224, theta=0.0
% INFO    : Bus 4847	: V=1.04178798, theta=-10.6664205 -> V=0.999999, theta=0.0
% INFO    : Bus 4848	: V=1.054932, theta=-8.04020649 -> V=1.0111115, theta=0.0
% INFO    : Bus 4849	: V=1.04110162, theta=-14.3383796 -> V=1.0000025, theta=0.0
% INFO    : Bus 4850	: V=1.02690021, theta=-18.1094048 -> V=1.015872, theta=0.0
% INFO    : Bus 4851	: V=0.904, theta=-6.98587369 -> V=0.9444445, theta=0.0
% INFO    : Bus 4852	: V=0.903961013, theta=-6.99091575 -> V=0.9444445, theta=0.0
% INFO    : Bus 4853	: V=1.053464, theta=-6.60923254 -> V=1.0111115, theta=0.0
% INFO    : Bus 4854	: V=1.02179051, theta=-12.4913498 -> V=0.999999, theta=0.0
% INFO    : Bus 4855	: V=1.04213456, theta=-19.4558025 -> V=1.022224, theta=0.0
% INFO    : Bus 4856	: V=0.973955371, theta=-4.32209129 -> V=1.0158755, theta=0.0
% INFO    : Bus 4857	: V=1.05514533, theta=-23.3731981 -> V=1.0000025, theta=0.0
% INFO    : Bus 4858	: V=1.06844483, theta=-20.4924766 -> V=1.044445, theta=0.0
% INFO    : Bus 4859	: V=1.07681259, theta=-15.4302884 -> V=1.078945, theta=0.0
% INFO    : Bus 4860	: V=1.08731206, theta=-10.3775301 -> V=1.07237, theta=0.0
% INFO    : Bus 4861	: V=1.05918502, theta=-19.4673458 -> V=1.046665, theta=0.0
% INFO    : Bus 4862	: V=1.01684622, theta=-23.3182397 -> V=1.0000025, theta=0.0
% INFO    : Bus 4863	: V=1.06730049, theta=-19.1158844 -> V=1.044445, theta=0.0
% INFO    : Bus 4864	: V=1.01549451, theta=-12.3969229 -> V=0.999999, theta=0.0
% INFO    : Bus 4865	: V=1.02611727, theta=-22.6393617 -> V=0.999999, theta=0.0
% INFO    : Bus 4866	: V=1.00239679, theta=-14.018056 -> V=0.999999, theta=0.0
% INFO    : Bus 4867	: V=1.02420884, theta=-9.86738692 -> V=0.999999, theta=0.0
% INFO    : Bus 4868	: V=1.03522106, theta=-35.6640781 -> V=1.022224, theta=0.0
% INFO    : Bus 4869	: V=1.03034454, theta=-10.8768335 -> V=0.999999, theta=0.0
% INFO    : Bus 4870	: V=1.07940089, theta=-12.121433 -> V=1.016666, theta=0.0
% INFO    : Bus 4871	: V=1.046, theta=-22.5034078 -> V=1.033334, theta=0.0
% INFO    : Bus 4872	: V=1.03088283, theta=-15.0582855 -> V=1.0158755, theta=0.0
% INFO    : Bus 4873	: V=1.02961023, theta=-15.2003272 -> V=1.0158755, theta=0.0
% INFO    : Bus 4874	: V=1.01254104, theta=-22.7339443 -> V=1.0000005, theta=0.0
% INFO    : Bus 4875	: V=1.01227462, theta=-21.8488585 -> V=1.0000005, theta=0.0
% INFO    : Bus 4876	: V=0.997032294, theta=-21.3282955 -> V=1.0000005, theta=0.0
% INFO    : Bus 4877	: V=1.0594117, theta=-20.1497998 -> V=1.046665, theta=0.0
% INFO    : Bus 4878	: V=1.027, theta=-18.5021476 -> V=0.999999, theta=0.0
% INFO    : Bus 4879	: V=1.06169513, theta=-5.75974294 -> V=0.9888895, theta=0.0
% INFO    : Bus 4880	: V=1.04058821, theta=-37.1909859 -> V=1.022224, theta=0.0
% INFO    : Bus 4881	: V=1.06379505, theta=-33.2222895 -> V=1.04444, theta=0.0
% INFO    : Bus 4882	: V=1.03780157, theta=-9.65686978 -> V=1.0111115, theta=0.0
% INFO    : Bus 4883	: V=1.01342242, theta=-9.9226819 -> V=1.0158755, theta=0.0
% INFO    : Bus 4884	: V=1.05375136, theta=-6.0847134 -> V=0.9888895, theta=0.0
% INFO    : Bus 4885	: V=1.06612382, theta=-2.30358384 -> V=1.039472, theta=0.0
% INFO    : Bus 4886	: V=1.01772448, theta=-12.9817696 -> V=1.0158755, theta=0.0
% INFO    : Bus 4887	: V=0.99510297, theta=-22.7420461 -> V=1.015872, theta=0.0
% INFO    : Bus 4888	: V=0.988469553, theta=-25.3029485 -> V=1.0000005, theta=0.0
% INFO    : Bus 4889	: V=1.01914787, theta=-19.8476164 -> V=1.015872, theta=0.0
% INFO    : Bus 4890	: V=1.0656086, theta=-23.0079241 -> V=1.000001, theta=0.0
% INFO    : Bus 4891	: V=1.05087279, theta=-8.45858632 -> V=0.9888895, theta=0.0
% INFO    : Bus 4892	: V=1.05598368, theta=-26.9719849 -> V=1.027779, theta=0.0
% INFO    : Bus 4893	: V=1.0053429, theta=-23.970607 -> V=1.0000025, theta=0.0
% INFO    : Bus 4894	: V=1.03049485, theta=2.15094147 -> V=1.0158755, theta=0.0
% INFO    : Bus 4895	: V=1.05249718, theta=-31.0531801 -> V=1.022224, theta=0.0
% INFO    : Bus 4896	: V=1.01841298, theta=-19.0877621 -> V=0.999999, theta=0.0
% INFO    : Bus 4897	: V=1.01326505, theta=-9.15354048 -> V=0.999999, theta=0.0
% INFO    : Bus 4898	: V=1.01379652, theta=-8.89863076 -> V=0.999999, theta=0.0
% INFO    : Bus 4899	: V=1.02273934, theta=-30.2027944 -> V=1.015872, theta=0.0
% INFO    : Bus 4900	: V=1.0341404, theta=-14.6577528 -> V=1.0158755, theta=0.0
% INFO    : Bus 4901	: V=1.07410419, theta=-10.3297102 -> V=1.0377785, theta=0.0
% INFO    : Bus 4902	: V=1.07783339, theta=-11.6651862 -> V=1.0388035, theta=0.0
% INFO    : Bus 4903	: V=1.08731715, theta=-7.67697708 -> V=1.072365, theta=0.0
% INFO    : Bus 4904	: V=1.03795366, theta=-17.8072498 -> V=1.022224, theta=0.0
% INFO    : Bus 4905	: V=1.04281361, theta=-21.031504 -> V=1.027779, theta=0.0
% INFO    : Bus 4906	: V=1.01685034, theta=-24.8216879 -> V=1.0000025, theta=0.0
% INFO    : Bus 4907	: V=1.07938316, theta=5.91874663 -> V=1.0393085, theta=0.0
% INFO    : Bus 4908	: V=1.08894173, theta=9.20354182 -> V=1.072365, theta=0.0
% INFO    : Bus 4909	: V=1.08968901, theta=10.3946275 -> V=1.072365, theta=0.0
% INFO    : Bus 4910	: V=1.04581843, theta=-25.8932447 -> V=1.027779, theta=0.0
% INFO    : Bus 4911	: V=0.97769296, theta=-16.1583652 -> V=0.999999, theta=0.0
% INFO    : Bus 4912	: V=1.08303716, theta=-16.36672 -> V=1.046665, theta=0.0
% INFO    : Bus 4913	: V=1.07686998, theta=-15.6338596 -> V=1.046665, theta=0.0
% INFO    : Bus 4914	: V=1.02597103, theta=-5.23736498 -> V=1.0158755, theta=0.0
% INFO    : Bus 4915	: V=1.03232292, theta=-4.74790177 -> V=1.0158755, theta=0.0
% INFO    : Bus 4916	: V=1.0029814, theta=-4.20844847 -> V=1.0, theta=0.0
% INFO    : Bus 4917	: V=1.07105715, theta=-1.53656115 -> V=1.0377785, theta=0.0
% INFO    : Bus 4918	: V=1.08500301, theta=1.33359484 -> V=1.072365, theta=0.0
% INFO    : Bus 4919	: V=1.01675052, theta=-19.6320419 -> V=1.022224, theta=0.0
% INFO    : Bus 4920	: V=1.011, theta=-19.9098909 -> V=1.015872, theta=0.0
% INFO    : Bus 4921	: V=1.0211335, theta=-29.0456309 -> V=1.015872, theta=0.0
% INFO    : Bus 4922	: V=1.03939953, theta=-24.8787323 -> V=1.046665, theta=0.0
% INFO    : Bus 4923	: V=1.017, theta=-24.156899 -> V=1.0000025, theta=0.0
% INFO    : Bus 4924	: V=1.01986634, theta=-24.7076183 -> V=1.0000025, theta=0.0
% INFO    : Bus 4925	: V=1.02320051, theta=-29.0780432 -> V=1.022224, theta=0.0
% INFO    : Bus 4926	: V=1.03077628, theta=-16.8547874 -> V=1.015872, theta=0.0
% INFO    : Bus 4927	: V=1.04405974, theta=-12.584184 -> V=1.046665, theta=0.0
% INFO    : Bus 4928	: V=1.05406153, theta=-1.17465318 -> V=1.0000025, theta=0.0
% INFO    : Bus 4929	: V=1.05414797, theta=-1.14436363 -> V=1.0000025, theta=0.0
% INFO    : Bus 4930	: V=1.05384252, theta=-28.0443362 -> V=1.027779, theta=0.0
% INFO    : Bus 4931	: V=1.01550274, theta=-17.1267254 -> V=0.999999, theta=0.0
% INFO    : Bus 4932	: V=1.03387507, theta=-19.3301972 -> V=1.0000005, theta=0.0
% INFO    : Bus 4933	: V=1.0081678, theta=-36.2186031 -> V=1.022224, theta=0.0
% INFO    : Bus 4934	: V=1.01786582, theta=-23.9072213 -> V=1.015872, theta=0.0
% INFO    : Bus 4935	: V=1.03406047, theta=-19.330604 -> V=1.0000005, theta=0.0
% INFO    : Bus 4936	: V=1.03406112, theta=-19.3303531 -> V=1.0000005, theta=0.0
% INFO    : Bus 4937	: V=1.03401213, theta=-19.3335596 -> V=1.0000005, theta=0.0
% INFO    : Bus 4938	: V=1.08320598, theta=-16.2532796 -> V=1.046665, theta=0.0
% INFO    : Bus 4939	: V=1.08321141, theta=-16.250399 -> V=1.046665, theta=0.0
% INFO    : Bus 4940	: V=1.02400221, theta=-7.07183991 -> V=1.0158755, theta=0.0
% INFO    : Bus 4941	: V=1.06521428, theta=-2.53821517 -> V=1.0377785, theta=0.0
% INFO    : Bus 4942	: V=1.08291529, theta=-16.3296112 -> V=1.046665, theta=0.0
% INFO    : Bus 4943	: V=1.01015847, theta=-12.2563525 -> V=1.015872, theta=0.0
% INFO    : Bus 4944	: V=1.01333312, theta=-12.3948881 -> V=0.999999, theta=0.0
% INFO    : Bus 4945	: V=1.01789325, theta=-18.3986567 -> V=1.0000005, theta=0.0
% INFO    : Bus 4946	: V=0.9, theta=-6.01126461 -> V=0.9444445, theta=0.0
% INFO    : Bus 4947	: V=1.07687269, theta=-10.7501796 -> V=1.072365, theta=0.0
% INFO    : Bus 4948	: V=0.996513921, theta=-17.2104707 -> V=1.0158755, theta=0.0
% INFO    : Bus 4949	: V=1.08578653, theta=-8.99441768 -> V=1.072365, theta=0.0
% INFO    : Bus 4950	: V=1.04168795, theta=-27.2199489 -> V=1.027779, theta=0.0
% INFO    : Bus 4951	: V=1.01830577, theta=-19.5741683 -> V=0.999999, theta=0.0
% INFO    : Bus 4952	: V=1.02269585, theta=-14.6680042 -> V=0.999999, theta=0.0
% INFO    : Bus 4953	: V=1.00755006, theta=-11.2884763 -> V=1.0158755, theta=0.0
% INFO    : Bus 4954	: V=1.03560781, theta=-19.2087853 -> V=0.975, theta=0.0
% INFO    : Bus 4955	: V=1.03010723, theta=-18.7653957 -> V=0.975, theta=0.0
% INFO    : Bus 4956	: V=1.05882904, theta=-20.6078784 -> V=1.027779, theta=0.0
% INFO    : Bus 4957	: V=1.07851267, theta=-17.5524914 -> V=1.046665, theta=0.0
% INFO    : Bus 4958	: V=1.0700543, theta=-17.279148 -> V=1.046665, theta=0.0
% INFO    : Bus 4959	: V=1.07495084, theta=-13.1599811 -> V=1.073685, theta=0.0
% INFO    : Bus 4960	: V=1.06449622, theta=-12.584467 -> V=0.975, theta=0.0
% INFO    : Bus 4961	: V=1.06141089, theta=-14.9490692 -> V=1.023684, theta=0.0
% INFO    : Bus 4962	: V=1.06453913, theta=-12.5740236 -> V=1.04444, theta=0.0
% INFO    : Bus 4963	: V=1.05589799, theta=-19.3876493 -> V=1.022224, theta=0.0
% INFO    : Bus 4964	: V=1.04195541, theta=-26.4377069 -> V=1.0000025, theta=0.0
% INFO    : Bus 4965	: V=1.01255351, theta=-18.9036094 -> V=1.0000005, theta=0.0
% INFO    : Bus 4966	: V=1.07043055, theta=-17.3418932 -> V=1.046665, theta=0.0
% INFO    : Bus 4967	: V=1.01913499, theta=-19.1703781 -> V=1.022224, theta=0.0
% INFO    : Bus 4968	: V=1.08275799, theta=-12.8558932 -> V=1.07237, theta=0.0
% INFO    : Bus 4969	: V=1.0863056, theta=-11.9108032 -> V=1.07237, theta=0.0
% INFO    : Bus 4970	: V=1.031, theta=-15.5473683 -> V=0.999999, theta=0.0
% INFO    : Bus 4971	: V=1.02395269, theta=-19.3545795 -> V=1.0000005, theta=0.0
% INFO    : Bus 4972	: V=1.03702593, theta=-2.08943978 -> V=1.000001, theta=0.0
% INFO    : Bus 4973	: V=1.03535734, theta=-18.107096 -> V=1.0000005, theta=0.0
% INFO    : Bus 4974	: V=1.03872182, theta=-18.0988954 -> V=1.0000005, theta=0.0
% INFO    : Bus 4975	: V=1.07482663, theta=-14.7276139 -> V=1.046665, theta=0.0
% INFO    : Bus 4976	: V=1.07969968, theta=-14.6418097 -> V=1.046665, theta=0.0
% INFO    : Bus 4977	: V=1.07647621, theta=-10.9494067 -> V=1.073685, theta=0.0
% INFO    : Bus 4978	: V=1.04105674, theta=-15.0209649 -> V=0.999999, theta=0.0
% INFO    : Bus 4979	: V=1.04528444, theta=-19.6515478 -> V=1.000001, theta=0.0
% INFO    : Bus 4980	: V=1.04343965, theta=-19.895811 -> V=1.000001, theta=0.0
% INFO    : Bus 4981	: V=1.04415481, theta=-13.6975395 -> V=1.0158755, theta=0.0
% INFO    : Bus 4982	: V=1.07586363, theta=-11.3738468 -> V=1.0377785, theta=0.0
% INFO    : Bus 4983	: V=1.008, theta=-10.3767306 -> V=0.999999, theta=0.0
% INFO    : Bus 4984	: V=1.093, theta=3.16823651 -> V=0.975, theta=0.0
% INFO    : Bus 4985	: V=1.107, theta=1.85295135 -> V=0.975, theta=0.0
% INFO    : Bus 4986	: V=1.107, theta=1.85636945 -> V=0.975, theta=0.0
% INFO    : Bus 4987	: V=1.06340732, theta=-1.43954072 -> V=1.0377785, theta=0.0
% INFO    : Bus 4988	: V=1.08230977, theta=-2.81913963 -> V=1.0377785, theta=0.0
% INFO    : Bus 4989	: V=1.08230975, theta=-2.8191281 -> V=1.0377785, theta=0.0
% INFO    : Bus 4990	: V=1.01642771, theta=-5.99297594 -> V=1.0158755, theta=0.0
% INFO    : Bus 4991	: V=1.08224936, theta=-2.8351497 -> V=1.0377785, theta=0.0
% INFO    : Bus 4992	: V=1.06332984, theta=-1.45544037 -> V=1.0377785, theta=0.0
% INFO    : Bus 4993	: V=1.00839119, theta=-4.09254108 -> V=1.0158755, theta=0.0
% INFO    : Bus 4994	: V=1.00470883, theta=0.166254004 -> V=1.0158755, theta=0.0
% INFO    : Bus 4995	: V=1.06738122, theta=2.36121568 -> V=1.0377785, theta=0.0
% INFO    : Bus 4996	: V=0.994593565, theta=-26.0459327 -> V=0.999999, theta=0.0
% INFO    : Bus 4997	: V=1.01770613, theta=-15.0275967 -> V=0.999999, theta=0.0
% INFO    : Bus 4998	: V=1.04619908, theta=-20.0978719 -> V=0.999999, theta=0.0
% INFO    : Bus 4999	: V=1.03440972, theta=-16.2264041 -> V=1.0111115, theta=0.0
% INFO    : Bus 5000	: V=1.029466, theta=-16.4595582 -> V=0.999999, theta=0.0
% INFO    : Bus 5001	: V=1.03602944, theta=-10.4506487 -> V=1.0111115, theta=0.0
% INFO    : Bus 5002	: V=0.976599854, theta=-20.6314493 -> V=0.999999, theta=0.0
% INFO    : Bus 5003	: V=1.01906974, theta=-14.4136609 -> V=0.999999, theta=0.0
% INFO    : Bus 5004	: V=1.0010095, theta=-19.4616564 -> V=1.0158755, theta=0.0
% INFO    : Bus 5005	: V=1.02079022, theta=-16.0738096 -> V=0.999999, theta=0.0
% INFO    : Bus 5006	: V=1.05014065, theta=-12.7641305 -> V=1.0111115, theta=0.0
% INFO    : Bus 5007	: V=1.04204537, theta=-14.7181404 -> V=0.999999, theta=0.0
% INFO    : Bus 5008	: V=1.00896962, theta=-12.7769786 -> V=1.0158755, theta=0.0
% INFO    : Bus 5009	: V=0.996122439, theta=-12.997313 -> V=1.015872, theta=0.0
% INFO    : Bus 5010	: V=1.0732115, theta=-12.9303173 -> V=1.046665, theta=0.0
% INFO    : Bus 5011	: V=1.07271493, theta=-12.9259359 -> V=1.046665, theta=0.0
% INFO    : Bus 5012	: V=1.03643788, theta=-9.35027722 -> V=1.0000025, theta=0.0
% INFO    : Bus 5013	: V=1.04286306, theta=-19.7405172 -> V=1.022224, theta=0.0
% INFO    : Bus 5014	: V=1.02227679, theta=-20.4220129 -> V=1.022224, theta=0.0
% INFO    : Bus 5015	: V=1.0573593, theta=-16.7653235 -> V=1.000229, theta=0.0
% INFO    : Bus 5016	: V=1.02639438, theta=-22.546132 -> V=1.0000025, theta=0.0
% INFO    : Bus 5017	: V=1.02888032, theta=-18.0558727 -> V=0.999999, theta=0.0
% INFO    : Bus 5018	: V=1.03689541, theta=-5.23128324 -> V=1.0277795, theta=0.0
% INFO    : Bus 5019	: V=1.0175023, theta=-27.0082647 -> V=1.027779, theta=0.0
% INFO    : Bus 5020	: V=1.01941123, theta=-10.8334677 -> V=1.0158755, theta=0.0
% INFO    : Bus 5021	: V=1.02793504, theta=-19.7884533 -> V=1.0000005, theta=0.0
% INFO    : Bus 5022	: V=1.06448769, theta=-16.0175859 -> V=1.046665, theta=0.0
% INFO    : Bus 5023	: V=1.06562606, theta=-15.4224867 -> V=1.046665, theta=0.0
% INFO    : Bus 5024	: V=1.062, theta=-19.4061104 -> V=1.000001, theta=0.0
% INFO    : Bus 5025	: V=1.02614344, theta=-21.3279151 -> V=1.0000025, theta=0.0
% INFO    : Bus 5026	: V=1.00685175, theta=-28.0440593 -> V=1.022224, theta=0.0
% INFO    : Bus 5027	: V=1.03096993, theta=-26.3885291 -> V=1.022224, theta=0.0
% INFO    : Bus 5028	: V=1.00654067, theta=-29.5135198 -> V=1.0000025, theta=0.0
% INFO    : Bus 5029	: V=1.05618315, theta=-9.97990338 -> V=1.0000025, theta=0.0
% INFO    : Bus 5030	: V=0.991, theta=-25.9506688 -> V=1.0000025, theta=0.0
% INFO    : Bus 5031	: V=1.02651243, theta=-17.4513502 -> V=0.9682545, theta=0.0
% INFO    : Bus 5032	: V=1.01040974, theta=0.435758088 -> V=1.0158755, theta=0.0
% INFO    : Bus 5033	: V=1.00712979, theta=-28.7528846 -> V=1.0000025, theta=0.0
% INFO    : Bus 5034	: V=1.02825969, theta=-17.7851509 -> V=1.0000005, theta=0.0
% INFO    : Bus 5035	: V=1.0818801, theta=-16.4540051 -> V=1.046665, theta=0.0
% INFO    : Bus 5036	: V=1.05236753, theta=-21.906387 -> V=1.000001, theta=0.0
% INFO    : Bus 5037	: V=1.04575805, theta=-22.8047122 -> V=1.000001, theta=0.0
% INFO    : Bus 5038	: V=1.00133158, theta=-9.3726258 -> V=0.999999, theta=0.0
% INFO    : Bus 5039	: V=1.03138447, theta=-36.3965626 -> V=1.022224, theta=0.0
% INFO    : Bus 5040	: V=0.986624855, theta=-13.979722 -> V=0.999999, theta=0.0
% INFO    : Bus 5041	: V=1.03899337, theta=-25.8542764 -> V=1.0000025, theta=0.0
% INFO    : Bus 5042	: V=1.02046999, theta=-13.4868576 -> V=1.0158755, theta=0.0
% INFO    : Bus 5043	: V=1.04586833, theta=-11.6818552 -> V=1.022222, theta=0.0
% INFO    : Bus 5044	: V=1.02677891, theta=2.76193259 -> V=1.0158755, theta=0.0
% INFO    : Bus 5045	: V=1.01739059, theta=-28.1458163 -> V=1.022224, theta=0.0
% INFO    : Bus 5046	: V=1.04151376, theta=-7.04304195 -> V=1.0111115, theta=0.0
% INFO    : Bus 5047	: V=1.03106616, theta=-6.00719904 -> V=1.0277795, theta=0.0
% INFO    : Bus 5048	: V=1.00364824, theta=-17.9979294 -> V=1.0000005, theta=0.0
% INFO    : Bus 5049	: V=1.02679235, theta=-6.52135694 -> V=1.0158755, theta=0.0
% INFO    : Bus 5050	: V=1.01755876, theta=-6.36679311 -> V=1.0158755, theta=0.0
% INFO    : Bus 5051	: V=1.02087325, theta=-25.7038199 -> V=1.0000025, theta=0.0
% INFO    : Bus 5052	: V=1.05463504, theta=-33.4572934 -> V=1.022224, theta=0.0
% INFO    : Bus 5053	: V=1.04984353, theta=-28.1961774 -> V=1.04444, theta=0.0
% INFO    : Bus 5054	: V=1.009997, theta=-12.1261994 -> V=0.999999, theta=0.0
% INFO    : Bus 5055	: V=1.06809928, theta=-7.02919317 -> V=1.033333, theta=0.0
% INFO    : Bus 5056	: V=1.04735167, theta=-18.276702 -> V=1.0158755, theta=0.0
% INFO    : Bus 5057	: V=0.986369647, theta=-3.36245349 -> V=1.0158755, theta=0.0
% INFO    : Bus 5058	: V=1.01198269, theta=-18.2733177 -> V=1.0000005, theta=0.0
% INFO    : Bus 5059	: V=1.02733844, theta=-8.1393118 -> V=1.0158755, theta=0.0
% INFO    : Bus 5060	: V=1.01084519, theta=-6.40039006 -> V=1.0158755, theta=0.0
% INFO    : Bus 5061	: V=1.07719822, theta=2.18140404 -> V=0.9888895, theta=0.0
% INFO    : Bus 5062	: V=1.07005148, theta=0.780608808 -> V=0.9888895, theta=0.0
% INFO    : Bus 5063	: V=1.08613863, theta=4.40162156 -> V=1.05263, theta=0.0
% INFO    : Bus 5064	: V=1.08785767, theta=4.57329917 -> V=1.05263, theta=0.0
% INFO    : Bus 5065	: V=1.04869021, theta=-5.77266755 -> V=1.033333, theta=0.0
% INFO    : Bus 5066	: V=1.01981949, theta=-6.47901635 -> V=1.0158755, theta=0.0
% INFO    : Bus 5067	: V=1.0570761, theta=-9.59688488 -> V=1.022222, theta=0.0
% INFO    : Bus 5068	: V=1.06163927, theta=-6.01316276 -> V=0.9888895, theta=0.0
% INFO    : Bus 5069	: V=1.06176132, theta=-6.06039968 -> V=0.9888895, theta=0.0
% INFO    : Bus 5070	: V=1.06396431, theta=-4.54452765 -> V=0.9888895, theta=0.0
% INFO    : Bus 5071	: V=1.06960874, theta=-0.84652799 -> V=1.05263, theta=0.0
% INFO    : Bus 5072	: V=1.06991572, theta=1.15330958 -> V=0.9888895, theta=0.0
% INFO    : Bus 5073	: V=1.06961058, theta=1.1210771 -> V=0.9888895, theta=0.0
% INFO    : Bus 5074	: V=1.05851167, theta=-3.03439505 -> V=0.9888895, theta=0.0
% INFO    : Bus 5075	: V=1.02995228, theta=2.16376148 -> V=1.0158755, theta=0.0
% INFO    : Bus 5076	: V=0.991551994, theta=-4.20023503 -> V=1.0158755, theta=0.0
% INFO    : Bus 5077	: V=1.05681861, theta=-14.1846299 -> V=1.027779, theta=0.0
% INFO    : Bus 5078	: V=1.0614714, theta=-16.7991781 -> V=1.027779, theta=0.0
% INFO    : Bus 5079	: V=1.07914417, theta=-12.1257073 -> V=1.046665, theta=0.0
% INFO    : Bus 5080	: V=1.06317319, theta=-19.2762723 -> V=1.000001, theta=0.0
% INFO    : Bus 5081	: V=1.03425596, theta=-13.5429281 -> V=0.999999, theta=0.0
% INFO    : Bus 5082	: V=1.03430512, theta=-29.2733472 -> V=1.027779, theta=0.0
% INFO    : Bus 5083	: V=1.01671397, theta=-19.8886701 -> V=0.999999, theta=0.0
% INFO    : Bus 5084	: V=1.04526338, theta=-18.277551 -> V=1.027779, theta=0.0
% INFO    : Bus 5085	: V=1.06517538, theta=-18.6999556 -> V=1.046665, theta=0.0
% INFO    : Bus 5086	: V=1.07200825, theta=-13.6690223 -> V=1.073685, theta=0.0
% INFO    : Bus 5087	: V=1.02625065, theta=-20.2978409 -> V=0.999999, theta=0.0
% INFO    : Bus 5088	: V=1.01980784, theta=-32.3005681 -> V=1.022224, theta=0.0
% INFO    : Bus 5089	: V=1.05069821, theta=-21.3591238 -> V=1.0222235, theta=0.0
% INFO    : Bus 5090	: V=0.9438276, theta=-6.22433065 -> V=0.9444445, theta=0.0
% INFO    : Bus 5091	: V=1.01841171, theta=-21.4787957 -> V=0.999999, theta=0.0
% INFO    : Bus 5092	: V=1.04195532, theta=-17.0379395 -> V=1.022224, theta=0.0
% INFO    : Bus 5093	: V=1.01573364, theta=-17.7781845 -> V=1.0000005, theta=0.0
% INFO    : Bus 5094	: V=1.00837572, theta=-29.0280933 -> V=1.022224, theta=0.0
% INFO    : Bus 5095	: V=1.05094209, theta=-23.8120707 -> V=1.0000025, theta=0.0
% INFO    : Bus 5096	: V=1.01493331, theta=2.12885491 -> V=1.0158755, theta=0.0
% INFO    : Bus 5097	: V=1.02871328, theta=-19.596173 -> V=1.0000005, theta=0.0
% INFO    : Bus 5098	: V=1.0689979, theta=-25.5078966 -> V=1.04444, theta=0.0
% INFO    : Bus 5099	: V=1.02390775, theta=-14.4899595 -> V=0.999999, theta=0.0
% INFO    : Bus 5100	: V=1.03182759, theta=-18.4205037 -> V=0.999999, theta=0.0
% INFO    : Bus 5101	: V=0.942233786, theta=-7.00694018 -> V=0.9444445, theta=0.0
% INFO    : Bus 5102	: V=0.966296828, theta=-9.9432164 -> V=0.9444445, theta=0.0
% INFO    : Bus 5103	: V=1.02543296, theta=-7.15060043 -> V=1.0158755, theta=0.0
% INFO    : Bus 5104	: V=1.03746175, theta=-24.9885989 -> V=1.022224, theta=0.0
% INFO    : Bus 5105	: V=1.07422353, theta=-6.71884325 -> V=0.9933315, theta=0.0
% INFO    : Bus 5106	: V=0.973059153, theta=-24.3963974 -> V=1.0000025, theta=0.0
% INFO    : Bus 5107	: V=1.02759325, theta=-27.2438334 -> V=1.022224, theta=0.0
% INFO    : Bus 5108	: V=1.01506924, theta=-16.3169201 -> V=1.0000005, theta=0.0
% INFO    : Bus 5109	: V=1.07137713, theta=-6.59712154 -> V=1.005558, theta=0.0
% INFO    : Bus 5110	: V=1.07048566, theta=-6.68117774 -> V=1.005558, theta=0.0
% INFO    : Bus 5111	: V=1.04812999, theta=-25.8172013 -> V=1.0000025, theta=0.0
% INFO    : Bus 5112	: V=1.01637944, theta=-15.2460117 -> V=1.0158755, theta=0.0
% INFO    : Bus 5113	: V=1.02549251, theta=-17.5571341 -> V=1.022224, theta=0.0
% INFO    : Bus 5114	: V=0.948167592, theta=-8.50646106 -> V=0.9444445, theta=0.0
% INFO    : Bus 5115	: V=1.03278839, theta=-35.4545182 -> V=1.022224, theta=0.0
% INFO    : Bus 5116	: V=1.02104795, theta=1.90794436 -> V=1.0158755, theta=0.0
% INFO    : Bus 5117	: V=1.01881576, theta=-21.8156586 -> V=1.015872, theta=0.0
% INFO    : Bus 5118	: V=1.03668664, theta=-26.2068017 -> V=1.022224, theta=0.0
% INFO    : Bus 5119	: V=1.07309551, theta=-17.8703617 -> V=1.0333335, theta=0.0
% INFO    : Bus 5120	: V=1.04704787, theta=-11.670633 -> V=1.005558, theta=0.0
% INFO    : Bus 5121	: V=1.03209405, theta=-24.4582355 -> V=1.0000025, theta=0.0
% INFO    : Bus 5122	: V=0.999114099, theta=-30.3782486 -> V=1.0000025, theta=0.0
% INFO    : Bus 5123	: V=1.0776006, theta=-15.3266893 -> V=1.046665, theta=0.0
% INFO    : Bus 5124	: V=1.07765348, theta=-15.3184121 -> V=1.046665, theta=0.0
% INFO    : Bus 5125	: V=1.06238586, theta=-6.94391351 -> V=0.9933315, theta=0.0
% INFO    : Bus 5126	: V=1.00081525, theta=-13.1547864 -> V=1.015872, theta=0.0
% INFO    : Bus 5127	: V=1.0433913, theta=-19.2221957 -> V=0.999999, theta=0.0
% INFO    : Bus 5128	: V=1.06612662, theta=-18.7661455 -> V=1.027779, theta=0.0
% INFO    : Bus 5129	: V=1.04199385, theta=-27.8137099 -> V=1.0000025, theta=0.0
% INFO    : Bus 5130	: V=0.990127682, theta=-27.0332877 -> V=1.0000025, theta=0.0
% INFO    : Bus 5131	: V=1.04858408, theta=-7.17002379 -> V=0.9888895, theta=0.0
% INFO    : Bus 5132	: V=1.07004858, theta=-17.1608285 -> V=1.046665, theta=0.0
% INFO    : Bus 5133	: V=1.0163747, theta=-19.1892979 -> V=1.0000025, theta=0.0
% INFO    : Bus 5134	: V=1.01634623, theta=-25.4202389 -> V=1.015872, theta=0.0
% INFO    : Bus 5135	: V=1.03883945, theta=-6.98071359 -> V=1.0000015, theta=0.0
% INFO    : Bus 5136	: V=1.02620912, theta=-21.1694786 -> V=1.0000025, theta=0.0
% INFO    : Bus 5137	: V=1.01591406, theta=-12.0522047 -> V=0.999999, theta=0.0
% INFO    : Bus 5138	: V=1.02871127, theta=-12.0120709 -> V=1.0158755, theta=0.0
% INFO    : Bus 5139	: V=1.0176173, theta=-12.939584 -> V=0.999999, theta=0.0
% INFO    : Bus 5140	: V=1.0348814, theta=-30.0689776 -> V=1.022224, theta=0.0
% INFO    : Bus 5141	: V=0.983998012, theta=-19.5376039 -> V=0.999999, theta=0.0
% INFO    : Bus 5142	: V=1.05584852, theta=-27.5665958 -> V=1.0000025, theta=0.0
% INFO    : Bus 5143	: V=1.02820792, theta=-17.7965681 -> V=1.0000005, theta=0.0
% INFO    : Bus 5144	: V=1.05725879, theta=-27.4783164 -> V=1.0000025, theta=0.0
% INFO    : Bus 5145	: V=1.02671354, theta=-14.3384086 -> V=0.999999, theta=0.0
% INFO    : Bus 5146	: V=1.01342481, theta=-18.8572379 -> V=1.0000005, theta=0.0
% INFO    : Bus 5147	: V=1.02061389, theta=-26.9584525 -> V=1.0000025, theta=0.0
% INFO    : Bus 5148	: V=1.01453131, theta=-16.0344769 -> V=0.999999, theta=0.0
% INFO    : Bus 5149	: V=1.04807799, theta=-7.069884 -> V=0.9933315, theta=0.0
% INFO    : Bus 5150	: V=1.01402514, theta=-20.3116101 -> V=1.0000025, theta=0.0
% INFO    : Bus 5151	: V=1.01296388, theta=-20.3356583 -> V=1.0000025, theta=0.0
% INFO    : Bus 5152	: V=0.989042593, theta=-25.8566547 -> V=1.0000025, theta=0.0
% INFO    : Bus 5153	: V=0.988775396, theta=-25.884242 -> V=1.0000025, theta=0.0
% INFO    : Bus 5154	: V=1.020105, theta=-24.7207681 -> V=1.0000025, theta=0.0
% INFO    : Bus 5155	: V=1.02642035, theta=-18.9554186 -> V=1.022224, theta=0.0
% INFO    : Bus 5156	: V=1.0508473, theta=-13.2693836 -> V=1.0111115, theta=0.0
% INFO    : Bus 5157	: V=1.04173739, theta=-35.0771847 -> V=1.0079355, theta=0.0
% INFO    : Bus 5158	: V=1.04034033, theta=-21.8391802 -> V=1.0000025, theta=0.0
% INFO    : Bus 5159	: V=1.04181859, theta=-21.7527329 -> V=1.0000025, theta=0.0
% INFO    : Bus 5160	: V=1.05656128, theta=-13.1132774 -> V=1.046665, theta=0.0
% INFO    : Bus 5161	: V=1.01706126, theta=-19.4376859 -> V=1.022224, theta=0.0
% INFO    : Bus 5162	: V=1.01705822, theta=-19.4371907 -> V=1.022224, theta=0.0
% INFO    : Bus 5163	: V=1.04721065, theta=-20.2750705 -> V=1.0222235, theta=0.0
% INFO    : Bus 5164	: V=1.05037459, theta=-29.6985858 -> V=1.022224, theta=0.0
% INFO    : Bus 5165	: V=1.00364715, theta=-22.8759405 -> V=1.0000025, theta=0.0
% INFO    : Bus 5166	: V=1.01271568, theta=-20.758816 -> V=1.0000025, theta=0.0
% INFO    : Bus 5167	: V=0.996675876, theta=-31.6838352 -> V=1.0000025, theta=0.0
% INFO    : Bus 5168	: V=0.998682191, theta=-30.5617333 -> V=1.0000025, theta=0.0
% INFO    : Bus 5169	: V=1.06692528, theta=-23.8661034 -> V=1.0000025, theta=0.0
% INFO    : Bus 5170	: V=0.996382969, theta=-30.5656403 -> V=1.0000025, theta=0.0
% INFO    : Bus 5171	: V=1.01703486, theta=-24.82594 -> V=1.0000025, theta=0.0
% INFO    : Bus 5172	: V=1.03268254, theta=-12.1697046 -> V=0.999999, theta=0.0
% INFO    : Bus 5173	: V=1.01959697, theta=-40.1008287 -> V=1.0079355, theta=0.0
% INFO    : Bus 5174	: V=1.00279106, theta=-28.109414 -> V=1.0000025, theta=0.0
% INFO    : Bus 5175	: V=1.06093274, theta=-39.6079444 -> V=1.022224, theta=0.0
% INFO    : Bus 5176	: V=0.996857438, theta=-23.7169369 -> V=1.0000005, theta=0.0
% INFO    : Bus 5177	: V=1.02956418, theta=-17.8017686 -> V=1.0158755, theta=0.0
% INFO    : Bus 5178	: V=1.01465288, theta=-34.4188826 -> V=1.022224, theta=0.0
% INFO    : Bus 5179	: V=1.01996391, theta=-26.4694178 -> V=1.022224, theta=0.0
% INFO    : Bus 5180	: V=0.998755122, theta=-23.6758555 -> V=1.0000005, theta=0.0
% INFO    : Bus 5181	: V=1.07799574, theta=-15.5226005 -> V=1.046665, theta=0.0
% INFO    : Bus 5182	: V=1.03341809, theta=-48.0174642 -> V=1.0079355, theta=0.0
% INFO    : Bus 5183	: V=1.03854487, theta=-14.6018605 -> V=1.0233335, theta=0.0
% INFO    : Bus 5184	: V=1.07780139, theta=-15.5843284 -> V=1.046665, theta=0.0
% INFO    : Bus 5185	: V=1.03514904, theta=-35.5487272 -> V=1.0079355, theta=0.0
% INFO    : Bus 5186	: V=1.01972563, theta=-39.9066248 -> V=1.0079355, theta=0.0
% INFO    : Bus 5187	: V=1.01374519, theta=-17.2487684 -> V=0.999999, theta=0.0
% INFO    : Bus 5188	: V=1.01956802, theta=-35.6113641 -> V=1.022224, theta=0.0
% INFO    : Bus 5189	: V=1.06320614, theta=-22.3447858 -> V=1.0000025, theta=0.0
% INFO    : Bus 5190	: V=1.06743307, theta=-14.4423765 -> V=1.026154, theta=0.0
% INFO    : Bus 5191	: V=1.03038417, theta=-30.1534501 -> V=1.022224, theta=0.0
% INFO    : Bus 5192	: V=1.06473982, theta=-28.8362949 -> V=1.04444, theta=0.0
% INFO    : Bus 5193	: V=1.03513196, theta=-21.4269653 -> V=1.0000025, theta=0.0
% INFO    : Bus 5194	: V=1.03118994, theta=-30.6597807 -> V=1.022224, theta=0.0
% INFO    : Bus 5195	: V=1.03694921, theta=-21.9974558 -> V=1.022224, theta=0.0
% INFO    : Bus 5196	: V=1.03400239, theta=-24.9841038 -> V=1.0222235, theta=0.0
% INFO    : Bus 5197	: V=0.976945575, theta=-13.8845488 -> V=0.999999, theta=0.0
% INFO    : Bus 5198	: V=1.00428415, theta=-5.28376287 -> V=1.0158755, theta=0.0
% INFO    : Bus 5199	: V=1.03780683, theta=-28.812261 -> V=1.022224, theta=0.0
% INFO    : Bus 5200	: V=1.013524, theta=-33.116673 -> V=1.022224, theta=0.0
% INFO    : Bus 5201	: V=1.03496942, theta=-14.487496 -> V=0.999999, theta=0.0
% INFO    : Bus 5202	: V=1.07660165, theta=5.0938801 -> V=0.9890795, theta=0.0
% INFO    : Bus 5203	: V=1.02576249, theta=-24.1130898 -> V=1.0000025, theta=0.0
% INFO    : Bus 5204	: V=0.995897696, theta=-15.7979392 -> V=1.0158755, theta=0.0
% INFO    : Bus 5205	: V=1.03610835, theta=-13.9178406 -> V=0.999999, theta=0.0
% INFO    : Bus 5206	: V=1.01888453, theta=-8.79980572 -> V=0.999999, theta=0.0
% INFO    : Bus 5207	: V=1.03061638, theta=-5.73524584 -> V=1.0111115, theta=0.0
% INFO    : Bus 5208	: V=1.02781432, theta=-17.84432 -> V=1.015872, theta=0.0
% INFO    : Bus 5209	: V=1.02499993, theta=-21.5836951 -> V=1.015872, theta=0.0
% INFO    : Bus 5210	: V=1.03102754, theta=-40.1303664 -> V=1.0079355, theta=0.0
% INFO    : Bus 5211	: V=1.04634917, theta=-19.2855329 -> V=1.046665, theta=0.0
% INFO    : Bus 5212	: V=0.996072905, theta=-21.9368839 -> V=1.015872, theta=0.0
% INFO    : Bus 5213	: V=1.04980537, theta=-27.7843915 -> V=1.0000025, theta=0.0
% INFO    : Bus 5214	: V=1.04381345, theta=-22.0946867 -> V=1.0000025, theta=0.0
% INFO    : Bus 5215	: V=1.06902914, theta=-13.7564653 -> V=1.027779, theta=0.0
% INFO    : Bus 5216	: V=0.996404836, theta=-26.4779916 -> V=1.0000025, theta=0.0
% INFO    : Bus 5217	: V=0.996862802, theta=-26.4521441 -> V=1.0000025, theta=0.0
% INFO    : Bus 5218	: V=1.00512627, theta=-24.8623615 -> V=1.0000025, theta=0.0
% INFO    : Bus 5219	: V=1.07834098, theta=-17.5534366 -> V=1.046665, theta=0.0
% INFO    : Bus 5220	: V=1.02808253, theta=3.87563131 -> V=1.0158755, theta=0.0
% INFO    : Bus 5221	: V=1.00594885, theta=-24.9350481 -> V=1.0000025, theta=0.0
% INFO    : Bus 5222	: V=1.07854357, theta=-17.5559569 -> V=1.046665, theta=0.0
% INFO    : Bus 5223	: V=0.998633017, theta=-25.1340308 -> V=1.0000025, theta=0.0
% INFO    : Bus 5224	: V=1.04214044, theta=-48.4776913 -> V=1.0079355, theta=0.0
% INFO    : Bus 5225	: V=1.0026998, theta=-30.1269442 -> V=1.0000025, theta=0.0
% INFO    : Bus 5226	: V=1.0521588, theta=-23.6092616 -> V=1.0000025, theta=0.0
% INFO    : Bus 5227	: V=1.05339432, theta=-23.4209836 -> V=1.0000025, theta=0.0
% INFO    : Bus 5228	: V=1.00947421, theta=-27.0198748 -> V=1.0000025, theta=0.0
% INFO    : Bus 5229	: V=1.05710577, theta=-24.2374588 -> V=1.027779, theta=0.0
% INFO    : Bus 5230	: V=1.0097549, theta=-27.0704567 -> V=1.0000025, theta=0.0
% INFO    : Bus 5231	: V=1.02134169, theta=-18.9177894 -> V=1.015872, theta=0.0
% INFO    : Bus 5232	: V=0.995064127, theta=-28.090934 -> V=1.0000025, theta=0.0
% INFO    : Bus 5233	: V=1.03068053, theta=-24.1951018 -> V=1.0000025, theta=0.0
% INFO    : Bus 5234	: V=1.03187076, theta=-6.38921612 -> V=1.0111115, theta=0.0
% INFO    : Bus 5235	: V=1.01865872, theta=-24.8592996 -> V=1.0000025, theta=0.0
% INFO    : Bus 5236	: V=1.0186225, theta=-24.9410179 -> V=1.0000025, theta=0.0
% INFO    : Bus 5237	: V=1.03350476, theta=-20.2570475 -> V=1.0158755, theta=0.0
% INFO    : Bus 5238	: V=1.02311675, theta=-12.0212804 -> V=0.999999, theta=0.0
% INFO    : Bus 5239	: V=1.02740028, theta=-26.1789319 -> V=1.022224, theta=0.0
% INFO    : Bus 5240	: V=1.03788904, theta=-17.7866551 -> V=1.022224, theta=0.0
% INFO    : Bus 5241	: V=1.01369236, theta=-11.0632089 -> V=0.999999, theta=0.0
% INFO    : Bus 5242	: V=1.0639307, theta=-22.1914343 -> V=1.0222235, theta=0.0
% INFO    : Bus 5243	: V=0.975872366, theta=-12.9848643 -> V=0.9444445, theta=0.0
% INFO    : Bus 5244	: V=1.07883203, theta=-10.3982541 -> V=1.073685, theta=0.0
% INFO    : Bus 5245	: V=1.00257657, theta=-9.1616146 -> V=0.999999, theta=0.0
% INFO    : Bus 5246	: V=1.0258926, theta=-18.4420831 -> V=1.022224, theta=0.0
% INFO    : Bus 5247	: V=1.01201783, theta=0.394422551 -> V=1.0158755, theta=0.0
% INFO    : Bus 5248	: V=1.04425464, theta=-13.5955583 -> V=1.0000015, theta=0.0
% INFO    : Bus 5249	: V=1.01408102, theta=-27.6188735 -> V=1.022224, theta=0.0
% INFO    : Bus 5250	: V=1.02443815, theta=-16.5139187 -> V=1.0000005, theta=0.0
% INFO    : Bus 5251	: V=1.01734846, theta=-16.5059344 -> V=1.0000005, theta=0.0
% INFO    : Bus 5252	: V=1.01560486, theta=-10.4472067 -> V=0.999999, theta=0.0
% INFO    : Bus 5253	: V=1.01306726, theta=-22.741 -> V=1.0000005, theta=0.0
% INFO    : Bus 5254	: V=1.02215465, theta=-15.6588385 -> V=1.015872, theta=0.0
% INFO    : Bus 5255	: V=1.02375092, theta=-7.27979967 -> V=1.0158755, theta=0.0
% INFO    : Bus 5256	: V=1.0445055, theta=-12.7536522 -> V=1.003335, theta=0.0
% INFO    : Bus 5257	: V=1.02017073, theta=-18.6295375 -> V=0.999999, theta=0.0
% INFO    : Bus 5258	: V=0.996756975, theta=-0.993861026 -> V=1.0158755, theta=0.0
% INFO    : Bus 5259	: V=1.02339533, theta=-16.3502947 -> V=1.015872, theta=0.0
% INFO    : Bus 5260	: V=1.01009351, theta=-21.458568 -> V=1.022224, theta=0.0
% INFO    : Bus 5261	: V=0.988797422, theta=-31.7981842 -> V=1.0000025, theta=0.0
% INFO    : Bus 5262	: V=1.07091981, theta=-16.8056086 -> V=1.046665, theta=0.0
% INFO    : Bus 5263	: V=1.0709405, theta=-16.8284101 -> V=1.046665, theta=0.0
% INFO    : Bus 5264	: V=1.06323586, theta=-26.4125104 -> V=1.04444, theta=0.0
% INFO    : Bus 5265	: V=1.06658963, theta=-37.9366942 -> V=1.04444, theta=0.0
% INFO    : Bus 5266	: V=1.04865813, theta=-46.7303856 -> V=1.0079355, theta=0.0
% INFO    : Bus 5267	: V=1.06360248, theta=-22.7956363 -> V=1.0000025, theta=0.0
% INFO    : Bus 5268	: V=1.06960592, theta=-22.7821628 -> V=1.027779, theta=0.0
% INFO    : Bus 5269	: V=1.07017049, theta=-1.67084842 -> V=1.005558, theta=0.0
% INFO    : Bus 5270	: V=1.06501234, theta=-2.55093642 -> V=1.005558, theta=0.0
% INFO    : Bus 5271	: V=1.07120685, theta=-15.8217178 -> V=1.046665, theta=0.0
% INFO    : Bus 5272	: V=1.06118268, theta=-23.2128908 -> V=1.0000025, theta=0.0
% INFO    : Bus 5273	: V=1.02158273, theta=-25.2179349 -> V=1.000001, theta=0.0
% INFO    : Bus 5274	: V=1.03311966, theta=-7.21684809 -> V=1.0111115, theta=0.0
% INFO    : Bus 5275	: V=1.00581912, theta=-13.0260141 -> V=0.999999, theta=0.0
% INFO    : Bus 5276	: V=1.01496203, theta=-17.4023551 -> V=1.015872, theta=0.0
% INFO    : Bus 5277	: V=1.01186496, theta=-10.2629591 -> V=0.999999, theta=0.0
% INFO    : Bus 5278	: V=1.02369745, theta=-9.33519731 -> V=0.999999, theta=0.0
% INFO    : Bus 5279	: V=1.04103924, theta=-23.4130756 -> V=1.027779, theta=0.0
% INFO    : Bus 5280	: V=1.00825598, theta=-12.6937564 -> V=1.015872, theta=0.0
% INFO    : Bus 5281	: V=1.01869112, theta=-13.017778 -> V=0.999999, theta=0.0
% INFO    : Bus 5282	: V=1.01357247, theta=-22.3884223 -> V=1.0000005, theta=0.0
% INFO    : Bus 5283	: V=1.03112459, theta=-18.206258 -> V=1.0158755, theta=0.0
% INFO    : Bus 5284	: V=1.05650525, theta=-19.6446316 -> V=1.027779, theta=0.0
% INFO    : Bus 5285	: V=1.05222644, theta=-19.4395715 -> V=1.022224, theta=0.0
% INFO    : Bus 5286	: V=1.0651886, theta=-9.86225816 -> V=1.0111115, theta=0.0
% INFO    : Bus 5287	: V=1.01159704, theta=-27.2581943 -> V=1.0000025, theta=0.0
% INFO    : Bus 5288	: V=1.00101972, theta=-25.2801314 -> V=1.0000025, theta=0.0
% INFO    : Bus 5289	: V=1.01144171, theta=-27.2459558 -> V=1.0000025, theta=0.0
% INFO    : Bus 5290	: V=1.00257153, theta=-25.1129289 -> V=1.0000025, theta=0.0
% INFO    : Bus 5291	: V=1.05373344, theta=-5.95670036 -> V=0.9933315, theta=0.0
% INFO    : Bus 5292	: V=1.06013031, theta=-10.8805562 -> V=0.9888895, theta=0.0
% INFO    : Bus 5293	: V=1.00825544, theta=-12.6931634 -> V=1.015872, theta=0.0
% INFO    : Bus 5294	: V=1.0229623, theta=-12.2430627 -> V=1.015872, theta=0.0
% INFO    : Bus 5295	: V=1.02375884, theta=-10.0391144 -> V=1.015872, theta=0.0
% INFO    : Bus 5296	: V=1.05375794, theta=-10.0352797 -> V=1.005558, theta=0.0
% INFO    : Bus 5297	: V=1.01978643, theta=-13.3519797 -> V=0.999999, theta=0.0
% INFO    : Bus 5298	: V=1.05915255, theta=-22.5616375 -> V=1.0222235, theta=0.0
% INFO    : Bus 5299	: V=1.01682264, theta=-19.0337073 -> V=1.015872, theta=0.0
% INFO    : Bus 5300	: V=1.00688731, theta=-13.6647835 -> V=1.0158755, theta=0.0
% INFO    : Bus 5301	: V=1.02065633, theta=-24.5141352 -> V=1.015872, theta=0.0
% INFO    : Bus 5302	: V=1.04278942, theta=-23.8958409 -> V=1.0000025, theta=0.0
% INFO    : Bus 5303	: V=1.04623115, theta=-22.9427933 -> V=1.0000025, theta=0.0
% INFO    : Bus 5304	: V=0.977976271, theta=-23.0725217 -> V=1.0158755, theta=0.0
% INFO    : Bus 5305	: V=0.977968825, theta=-23.0741653 -> V=1.0158755, theta=0.0
% INFO    : Bus 5306	: V=1.03660198, theta=-24.1665441 -> V=1.0222235, theta=0.0
% INFO    : Bus 5307	: V=1.04277269, theta=-21.185899 -> V=1.027779, theta=0.0
% INFO    : Bus 5308	: V=1.06676225, theta=-29.063468 -> V=1.027779, theta=0.0
% INFO    : Bus 5309	: V=1.0214598, theta=-24.4002798 -> V=1.015872, theta=0.0
% INFO    : Bus 5310	: V=1.04707333, theta=-18.6819996 -> V=1.022224, theta=0.0
% INFO    : Bus 5311	: V=1.0692293, theta=-9.40939601 -> V=0.9888895, theta=0.0
% INFO    : Bus 5312	: V=1.01875409, theta=-32.0352386 -> V=1.022224, theta=0.0
% INFO    : Bus 5313	: V=1.02837423, theta=-19.4401407 -> V=1.0000005, theta=0.0
% INFO    : Bus 5314	: V=1.05279701, theta=-27.541793 -> V=1.0000025, theta=0.0
% INFO    : Bus 5315	: V=1.06222369, theta=-13.7399523 -> V=1.027779, theta=0.0
% INFO    : Bus 5316	: V=1.01414812, theta=-3.49290602 -> V=1.0158755, theta=0.0
% INFO    : Bus 5317	: V=1.02339377, theta=-13.2695076 -> V=0.999999, theta=0.0
% INFO    : Bus 5318	: V=1.07435754, theta=-18.8403086 -> V=1.046665, theta=0.0
% INFO    : Bus 5319	: V=1.02939643, theta=-12.7445839 -> V=1.0158755, theta=0.0
% INFO    : Bus 5320	: V=1.06421245, theta=-33.335207 -> V=1.04444, theta=0.0
% INFO    : Bus 5321	: V=1.06889823, theta=1.12826237 -> V=0.9933315, theta=0.0
% INFO    : Bus 5322	: V=1.03152909, theta=-17.0234055 -> V=1.022224, theta=0.0
% INFO    : Bus 5323	: V=1.02183451, theta=-24.2365492 -> V=0.999999, theta=0.0
% INFO    : Bus 5324	: V=1.01324231, theta=-19.6403978 -> V=0.999999, theta=0.0
% INFO    : Bus 5325	: V=1.01506837, theta=-13.6271179 -> V=0.999999, theta=0.0
% INFO    : Bus 5326	: V=1.05585414, theta=-16.6114695 -> V=1.027779, theta=0.0
% INFO    : Bus 5327	: V=1.03978737, theta=-16.0982476 -> V=1.027779, theta=0.0
% INFO    : Bus 5328	: V=1.00217197, theta=-23.8007145 -> V=1.0000005, theta=0.0
% INFO    : Bus 5329	: V=1.03864913, theta=-21.369328 -> V=1.0000005, theta=0.0
% INFO    : Bus 5330	: V=1.07508748, theta=-17.5272098 -> V=1.046665, theta=0.0
% INFO    : Bus 5331	: V=1.07967263, theta=-18.2311412 -> V=1.046665, theta=0.0
% INFO    : Bus 5332	: V=1.03119712, theta=-11.2721485 -> V=1.0000015, theta=0.0
% INFO    : Bus 5333	: V=1.05900146, theta=-4.07582209 -> V=0.9888895, theta=0.0
% INFO    : Bus 5334	: V=1.0352355, theta=-21.5054978 -> V=1.0000025, theta=0.0
% INFO    : Bus 5335	: V=1.08099086, theta=-15.1150666 -> V=1.04445, theta=0.0
% INFO    : Bus 5336	: V=1.03913347, theta=-25.2555158 -> V=1.0000025, theta=0.0
% INFO    : Bus 5337	: V=1.05783505, theta=-38.5304189 -> V=1.022224, theta=0.0
% INFO    : Bus 5338	: V=1.06917139, theta=-9.92598512 -> V=1.005558, theta=0.0
% INFO    : Bus 5339	: V=1.01182895, theta=-24.7215208 -> V=1.015872, theta=0.0
% INFO    : Bus 5340	: V=1.03545141, theta=-24.9150633 -> V=1.0222235, theta=0.0
% INFO    : Bus 5341	: V=1.0261968, theta=-21.4595925 -> V=1.015872, theta=0.0
% INFO    : Bus 5342	: V=1.05257722, theta=-19.0030881 -> V=1.027779, theta=0.0
% INFO    : Bus 5343	: V=1.0191729, theta=-25.3822683 -> V=1.0000025, theta=0.0
% INFO    : Bus 5344	: V=1.042003, theta=-23.7753875 -> V=1.0222235, theta=0.0
% INFO    : Bus 5345	: V=1.03414367, theta=-47.0677274 -> V=1.0079355, theta=0.0
% INFO    : Bus 5346	: V=1.01578436, theta=1.13957371 -> V=1.0158755, theta=0.0
% INFO    : Bus 5347	: V=1.0108829, theta=0.565104617 -> V=1.0158755, theta=0.0
% INFO    : Bus 5348	: V=0.981969826, theta=-26.5858333 -> V=1.0000025, theta=0.0
% INFO    : Bus 5349	: V=1.04317879, theta=-23.367591 -> V=1.0000025, theta=0.0
% INFO    : Bus 5350	: V=1.06448902, theta=-16.0229569 -> V=1.046665, theta=0.0
% INFO    : Bus 5351	: V=1.06426169, theta=-16.0309287 -> V=1.046665, theta=0.0
% INFO    : Bus 5352	: V=1.02623234, theta=-25.9690127 -> V=1.0222235, theta=0.0
% INFO    : Bus 5353	: V=1.03477851, theta=-13.0261667 -> V=0.999999, theta=0.0
% INFO    : Bus 5354	: V=1.01805016, theta=-27.5773136 -> V=1.022224, theta=0.0
% INFO    : Bus 5355	: V=1.01811687, theta=-10.0880169 -> V=0.999999, theta=0.0
% INFO    : Bus 5356	: V=1.04828072, theta=-12.6263557 -> V=1.0000015, theta=0.0
% INFO    : Bus 5357	: V=1.0230296, theta=-12.0309053 -> V=0.999999, theta=0.0
% INFO    : Bus 5358	: V=1.00341668, theta=-23.9366605 -> V=1.0000005, theta=0.0
% INFO    : Bus 5359	: V=1.0308692, theta=-20.0718509 -> V=1.022224, theta=0.0
% INFO    : Bus 5360	: V=0.973066453, theta=-24.3966179 -> V=1.0000025, theta=0.0
% INFO    : Bus 5361	: V=1.01137716, theta=-27.4820473 -> V=1.022224, theta=0.0
% INFO    : Bus 5362	: V=1.04288162, theta=-12.0921074 -> V=1.005558, theta=0.0
% INFO    : Bus 5363	: V=1.02174878, theta=-20.1120954 -> V=1.0000025, theta=0.0
% INFO    : Bus 5364	: V=1.06908857, theta=-18.3816541 -> V=1.046665, theta=0.0
% INFO    : Bus 5365	: V=1.06862841, theta=-18.4249865 -> V=1.046665, theta=0.0
% INFO    : Bus 5366	: V=1.05677004, theta=-0.362179044 -> V=1.0000015, theta=0.0
% INFO    : Bus 5367	: V=1.01244915, theta=-21.4386385 -> V=0.999999, theta=0.0
% INFO    : Bus 5368	: V=1.06722801, theta=-10.8881954 -> V=1.005558, theta=0.0
% INFO    : Bus 5369	: V=1.07444568, theta=-21.3450992 -> V=1.0222235, theta=0.0
% INFO    : Bus 5370	: V=1.05081428, theta=-17.2529406 -> V=1.022224, theta=0.0
% INFO    : Bus 5371	: V=1.04370913, theta=-20.488797 -> V=1.027779, theta=0.0
% INFO    : Bus 5372	: V=1.07829812, theta=-14.9910777 -> V=1.046665, theta=0.0
% INFO    : Bus 5373	: V=1.07460012, theta=-15.0241191 -> V=1.046665, theta=0.0
% INFO    : Bus 5374	: V=1.07642087, theta=5.38690493 -> V=0.9890045, theta=0.0
% INFO    : Bus 5375	: V=1.0135047, theta=-19.0710028 -> V=1.0000005, theta=0.0
% INFO    : Bus 5376	: V=1.01285837, theta=-21.4855898 -> V=1.0000025, theta=0.0
% INFO    : Bus 5377	: V=1.02286207, theta=-12.9318979 -> V=1.0158755, theta=0.0
% INFO    : Bus 5378	: V=1.00626589, theta=-23.5128034 -> V=1.0000005, theta=0.0
% INFO    : Bus 5379	: V=1.03529364, theta=-32.0764686 -> V=1.022224, theta=0.0
% INFO    : Bus 5380	: V=1.0304005, theta=-35.4290792 -> V=1.022224, theta=0.0
% INFO    : Bus 5381	: V=1.02776628, theta=-17.3794239 -> V=1.0158755, theta=0.0
% INFO    : Bus 5382	: V=1.0011497, theta=-12.040508 -> V=0.999999, theta=0.0
% INFO    : Bus 5383	: V=1.01306248, theta=-16.9222926 -> V=1.0158755, theta=0.0
% INFO    : Bus 5384	: V=1.07422618, theta=-9.64601361 -> V=1.04444, theta=0.0
% INFO    : Bus 5385	: V=1.03917542, theta=-13.7447848 -> V=0.999999, theta=0.0
% INFO    : Bus 5386	: V=1.04210154, theta=-24.2478545 -> V=1.0000025, theta=0.0
% INFO    : Bus 5387	: V=1.00578961, theta=-12.548948 -> V=1.0158755, theta=0.0
% INFO    : Bus 5388	: V=1.04425427, theta=-24.1370487 -> V=1.0000025, theta=0.0
% INFO    : Bus 5389	: V=1.07417011, theta=-9.65289439 -> V=1.04444, theta=0.0
% INFO    : Bus 5390	: V=0.939248777, theta=-8.48981224 -> V=0.9444445, theta=0.0
% INFO    : Bus 5391	: V=1.03354673, theta=-21.0780541 -> V=1.022224, theta=0.0
% INFO    : Bus 5392	: V=1.02982637, theta=-23.7816905 -> V=1.022224, theta=0.0
% INFO    : Bus 5393	: V=1.06227234, theta=-2.65482057 -> V=0.9888895, theta=0.0
% INFO    : Bus 5394	: V=1.07808017, theta=-14.9808173 -> V=1.046665, theta=0.0
% INFO    : Bus 5395	: V=1.05109718, theta=-17.740317 -> V=1.0222235, theta=0.0
% INFO    : Bus 5396	: V=1.05715135, theta=-18.2358899 -> V=1.0222235, theta=0.0
% INFO    : Bus 5397	: V=1.0216668, theta=-14.2046299 -> V=0.999999, theta=0.0
% INFO    : Bus 5398	: V=1.03121969, theta=-33.8854303 -> V=1.022224, theta=0.0
% INFO    : Bus 5399	: V=1.04316141, theta=-19.2190731 -> V=0.999999, theta=0.0
% INFO    : Bus 5400	: V=1.06925241, theta=-21.5665005 -> V=1.04444, theta=0.0
% INFO    : Bus 5401	: V=1.05260682, theta=-19.4272787 -> V=1.022224, theta=0.0
% INFO    : Bus 5402	: V=1.02579138, theta=-17.2967216 -> V=0.999999, theta=0.0
% INFO    : Bus 5403	: V=1.04058443, theta=-17.8446484 -> V=1.022224, theta=0.0
% INFO    : Bus 5404	: V=1.05171239, theta=-8.02491941 -> V=1.0111115, theta=0.0
% INFO    : Bus 5405	: V=1.0252585, theta=-24.3141723 -> V=1.0000025, theta=0.0
% INFO    : Bus 5406	: V=1.0186488, theta=-45.8367195 -> V=1.0079355, theta=0.0
% INFO    : Bus 5407	: V=1.02261526, theta=-9.85460315 -> V=1.0158755, theta=0.0
% INFO    : Bus 5408	: V=1.00412074, theta=-19.3655942 -> V=1.0158755, theta=0.0
% INFO    : Bus 5409	: V=1.0447228, theta=-29.9530521 -> V=1.022224, theta=0.0
% INFO    : Bus 5410	: V=1.00361468, theta=-23.4190071 -> V=1.0000025, theta=0.0
% INFO    : Bus 5411	: V=1.04267276, theta=-36.7383988 -> V=1.022224, theta=0.0
% INFO    : Bus 5412	: V=1.04245526, theta=-31.0034131 -> V=1.022224, theta=0.0
% INFO    : Bus 5413	: V=1.06038939, theta=-13.8534858 -> V=1.027779, theta=0.0
% INFO    : Bus 5414	: V=1.00566903, theta=-22.3884162 -> V=1.0000005, theta=0.0
% INFO    : Bus 5415	: V=0.894899843, theta=-5.42812892 -> V=0.9444445, theta=0.0
% INFO    : Bus 5416	: V=1.06582557, theta=-5.31909367 -> V=0.9933315, theta=0.0
% INFO    : Bus 5417	: V=1.0195271, theta=-3.57793013 -> V=1.0158755, theta=0.0
% INFO    : Bus 5418	: V=1.0241288, theta=-27.017548 -> V=1.0000025, theta=0.0
% INFO    : Bus 5419	: V=1.01300543, theta=-10.6602454 -> V=1.0079355, theta=0.0
% INFO    : Bus 5420	: V=1.01483338, theta=-11.3729725 -> V=0.999999, theta=0.0
% INFO    : Bus 5421	: V=1.06881039, theta=-17.8853405 -> V=1.046665, theta=0.0
% INFO    : Bus 5422	: V=1.01961404, theta=-39.9402635 -> V=1.0079355, theta=0.0
% INFO    : Bus 5423	: V=1.06827069, theta=-17.9248133 -> V=1.046665, theta=0.0
% INFO    : Bus 5424	: V=1.0193471, theta=-5.50825187 -> V=1.0158755, theta=0.0
% INFO    : Bus 5425	: V=1.05689255, theta=-12.3555864 -> V=1.005558, theta=0.0
% INFO    : Bus 5426	: V=1.01049583, theta=-7.13678674 -> V=1.0158755, theta=0.0
% INFO    : Bus 5427	: V=1.07447798, theta=-5.21305409 -> V=0.9888895, theta=0.0
% INFO    : Bus 5428	: V=1.02095356, theta=3.50602978 -> V=1.0158755, theta=0.0
% INFO    : Bus 5429	: V=1.07571807, theta=5.16405628 -> V=0.9888895, theta=0.0
% INFO    : Bus 5430	: V=1.00900666, theta=-10.5150074 -> V=1.015872, theta=0.0
% INFO    : Bus 5431	: V=1.06384942, theta=-8.61932037 -> V=1.005558, theta=0.0
% INFO    : Bus 5432	: V=1.04401058, theta=-22.2027488 -> V=1.0000025, theta=0.0
% INFO    : Bus 5433	: V=1.01284471, theta=-22.714137 -> V=1.0000005, theta=0.0
% INFO    : Bus 5434	: V=1.03417982, theta=-20.8736246 -> V=1.022224, theta=0.0
% INFO    : Bus 5435	: V=1.02790044, theta=-27.997533 -> V=1.022224, theta=0.0
% INFO    : Bus 5436	: V=1.06146122, theta=-39.5540254 -> V=1.022224, theta=0.0
% INFO    : Bus 5437	: V=1.03054075, theta=-19.1164896 -> V=1.022224, theta=0.0
% INFO    : Bus 5438	: V=1.03793143, theta=-19.1959991 -> V=1.0000005, theta=0.0
% INFO    : Bus 5439	: V=1.03674298, theta=-19.3962956 -> V=1.0000005, theta=0.0
% INFO    : Bus 5440	: V=1.04246023, theta=-14.160258 -> V=1.046665, theta=0.0
% INFO    : Bus 5441	: V=1.05295918, theta=-10.250606 -> V=1.0111115, theta=0.0
% INFO    : Bus 5442	: V=1.03124338, theta=-25.6054947 -> V=1.0000025, theta=0.0
% INFO    : Bus 5443	: V=1.03003529, theta=-26.7223333 -> V=1.022224, theta=0.0
% INFO    : Bus 5444	: V=1.01206765, theta=-6.24870777 -> V=1.0158755, theta=0.0
% INFO    : Bus 5445	: V=1.03446033, theta=-47.3258347 -> V=1.0079355, theta=0.0
% INFO    : Bus 5446	: V=1.01162605, theta=-54.4321917 -> V=1.0079355, theta=0.0
% INFO    : Bus 5447	: V=1.07480837, theta=-31.1498576 -> V=1.04444, theta=0.0
% INFO    : Bus 5448	: V=1.04670285, theta=-47.9385287 -> V=1.0079355, theta=0.0
% INFO    : Bus 5449	: V=1.0393189, theta=-24.5398292 -> V=1.0000025, theta=0.0
% INFO    : Bus 5450	: V=1.00047739, theta=-25.1948102 -> V=1.0000025, theta=0.0
% INFO    : Bus 5451	: V=1.03822086, theta=-27.1573078 -> V=1.0000025, theta=0.0
% INFO    : Bus 5452	: V=1.04459463, theta=-23.6298388 -> V=1.0000025, theta=0.0
% INFO    : Bus 5453	: V=1.04351601, theta=-24.4804761 -> V=1.0000025, theta=0.0
% INFO    : Bus 5454	: V=1.0595047, theta=-19.4014634 -> V=1.022224, theta=0.0
% INFO    : Bus 5455	: V=1.03131208, theta=-25.8282847 -> V=1.0000025, theta=0.0
% INFO    : Bus 5456	: V=1.06075505, theta=-9.1788566 -> V=1.046665, theta=0.0
% INFO    : Bus 5457	: V=0.997881184, theta=-29.5392792 -> V=1.0000025, theta=0.0
% INFO    : Bus 5458	: V=1.04104622, theta=-30.2151896 -> V=1.022224, theta=0.0
% INFO    : Bus 5459	: V=1.06369417, theta=-27.2110262 -> V=1.0000025, theta=0.0
% INFO    : Bus 5460	: V=1.04140537, theta=-23.5143444 -> V=1.0000025, theta=0.0
% INFO    : Bus 5461	: V=1.08287006, theta=-15.1922015 -> V=1.046665, theta=0.0
% INFO    : Bus 5462	: V=1.0117442, theta=-2.99403109 -> V=1.0158755, theta=0.0
% INFO    : Bus 5463	: V=1.0678518, theta=-15.1173323 -> V=1.046665, theta=0.0
% INFO    : Bus 5464	: V=1.0455739, theta=-10.1468297 -> V=1.0111115, theta=0.0
% INFO    : Bus 5465	: V=1.01618919, theta=-47.2655378 -> V=1.0079355, theta=0.0
% INFO    : Bus 5466	: V=1.07125011, theta=-15.8031126 -> V=1.046665, theta=0.0
% INFO    : Bus 5467	: V=1.00632763, theta=-19.7068538 -> V=1.015872, theta=0.0
% INFO    : Bus 5468	: V=1.03042292, theta=-15.7889111 -> V=0.999999, theta=0.0
% INFO    : Bus 5469	: V=1.00355712, theta=-20.5176804 -> V=1.0000005, theta=0.0
% INFO    : Bus 5470	: V=1.03844267, theta=-25.3501972 -> V=1.0000025, theta=0.0
% INFO    : Bus 5471	: V=1.05157074, theta=-23.5624277 -> V=1.0000025, theta=0.0
% INFO    : Bus 5472	: V=1.05948896, theta=-17.5904872 -> V=1.046665, theta=0.0
% INFO    : Bus 5473	: V=1.0113653, theta=-11.5602147 -> V=1.0158755, theta=0.0
% INFO    : Bus 5474	: V=1.05952757, theta=-17.7188654 -> V=1.046665, theta=0.0
% INFO    : Bus 5475	: V=1.01395331, theta=-13.1396679 -> V=0.999999, theta=0.0
% INFO    : Bus 5476	: V=1.02240192, theta=-24.5796443 -> V=0.999999, theta=0.0
% INFO    : Bus 5477	: V=1.01182748, theta=-22.7435357 -> V=1.0000005, theta=0.0
% INFO    : Bus 5478	: V=1.04686784, theta=-9.99456682 -> V=1.0000015, theta=0.0
% INFO    : Bus 5479	: V=1.07138105, theta=-16.9025191 -> V=1.046665, theta=0.0
% INFO    : Bus 5480	: V=1.02730498, theta=-29.4099991 -> V=1.022224, theta=0.0
% INFO    : Bus 5481	: V=1.01855468, theta=-49.4301215 -> V=1.0079355, theta=0.0
% INFO    : Bus 5482	: V=1.02367078, theta=-49.4831061 -> V=1.0079355, theta=0.0
% INFO    : Bus 5483	: V=1.02559374, theta=-14.1334732 -> V=0.999999, theta=0.0
% INFO    : Bus 5484	: V=1.02600626, theta=-14.120931 -> V=0.999999, theta=0.0
% INFO    : Bus 5485	: V=1.00765184, theta=-18.0414749 -> V=1.0000005, theta=0.0
% INFO    : Bus 5486	: V=1.05799662, theta=-15.5236461 -> V=1.022224, theta=0.0
% INFO    : Bus 5487	: V=1.0370125, theta=-18.531629 -> V=0.999999, theta=0.0
% INFO    : Bus 5488	: V=1.03095012, theta=-32.0080543 -> V=1.022224, theta=0.0
% INFO    : Bus 5489	: V=1.01981984, theta=-23.9422388 -> V=1.0000025, theta=0.0
% INFO    : Bus 5490	: V=1.00864724, theta=-3.93906508 -> V=1.0158755, theta=0.0
% INFO    : Bus 5491	: V=1.00828776, theta=-3.95298779 -> V=1.0158755, theta=0.0
% INFO    : Bus 5492	: V=1.02752933, theta=-25.9353232 -> V=1.0000025, theta=0.0
% INFO    : Bus 5493	: V=1.07165878, theta=-3.05399991 -> V=0.9888895, theta=0.0
% INFO    : Bus 5494	: V=1.01341039, theta=-15.5526873 -> V=1.0158755, theta=0.0
% INFO    : Bus 5495	: V=1.05963595, theta=1.16894026 -> V=0.9888895, theta=0.0
% INFO    : Bus 5496	: V=1.06226801, theta=-13.4966974 -> V=0.9888895, theta=0.0
% INFO    : Bus 5497	: V=1.02867105, theta=-25.4945809 -> V=1.0222235, theta=0.0
% INFO    : Bus 5498	: V=1.01637373, theta=-23.4125282 -> V=1.022224, theta=0.0
% INFO    : Bus 5499	: V=1.06902785, theta=-13.7564398 -> V=1.027779, theta=0.0
% INFO    : Bus 5500	: V=1.04025752, theta=-24.9483015 -> V=1.027779, theta=0.0
% INFO    : Bus 5501	: V=1.0161799, theta=-24.3977295 -> V=1.015872, theta=0.0
% INFO    : Bus 5502	: V=1.03261225, theta=-23.1350162 -> V=1.027779, theta=0.0
% INFO    : Bus 5503	: V=1.04422223, theta=-30.712719 -> V=1.022224, theta=0.0
% INFO    : Bus 5504	: V=1.04209854, theta=-29.7742743 -> V=1.022224, theta=0.0
% INFO    : Bus 5505	: V=1.02308771, theta=-15.6846638 -> V=1.0000005, theta=0.0
% INFO    : Bus 5506	: V=1.01177495, theta=-22.8893545 -> V=1.0000005, theta=0.0
% INFO    : Bus 5507	: V=1.04898743, theta=-12.4867149 -> V=1.0000015, theta=0.0
% INFO    : Bus 5508	: V=1.02249415, theta=-10.22023 -> V=1.0111115, theta=0.0
% INFO    : Bus 5509	: V=1.01456419, theta=-22.7610113 -> V=1.0000005, theta=0.0
% INFO    : Bus 5510	: V=1.0369625, theta=-2.08670383 -> V=1.0000015, theta=0.0
% INFO    : Bus 5511	: V=1.06466857, theta=-4.09040431 -> V=0.9888895, theta=0.0
% INFO    : Bus 5512	: V=1.07883051, theta=-17.8708073 -> V=1.046665, theta=0.0
% INFO    : Bus 5513	: V=1.03129578, theta=-15.7946971 -> V=0.999999, theta=0.0
% INFO    : Bus 5514	: V=1.01174928, theta=-24.5498272 -> V=1.0000025, theta=0.0
% INFO    : Bus 5515	: V=1.01932593, theta=-7.0744379 -> V=1.0000015, theta=0.0
% INFO    : Bus 5516	: V=1.03927984, theta=-23.7186224 -> V=1.0000025, theta=0.0
% INFO    : Bus 5517	: V=1.03884863, theta=-23.7544507 -> V=1.0000025, theta=0.0
% INFO    : Bus 5518	: V=1.05978875, theta=-15.081957 -> V=1.046665, theta=0.0
% INFO    : Bus 5519	: V=1.00865234, theta=-18.8286428 -> V=1.0000005, theta=0.0
% INFO    : Bus 5520	: V=1.01558544, theta=-18.3378574 -> V=1.0000005, theta=0.0
% INFO    : Bus 5521	: V=1.02385781, theta=-22.9599965 -> V=1.046665, theta=0.0
% INFO    : Bus 5522	: V=1.00972794, theta=-11.8833924 -> V=0.999999, theta=0.0
% INFO    : Bus 5523	: V=1.01254173, theta=-29.5729896 -> V=1.0000025, theta=0.0
% INFO    : Bus 5524	: V=1.03339468, theta=-26.3409045 -> V=1.0000025, theta=0.0
% INFO    : Bus 5525	: V=1.04691024, theta=-9.68954527 -> V=1.0111115, theta=0.0
% INFO    : Bus 5526	: V=1.03790812, theta=-26.500426 -> V=1.0000025, theta=0.0
% INFO    : Bus 5527	: V=1.07453213, theta=-23.8910488 -> V=1.046665, theta=0.0
% INFO    : Bus 5528	: V=1.0185524, theta=-24.8887536 -> V=1.022224, theta=0.0
% INFO    : Bus 5529	: V=0.988501866, theta=-24.6190455 -> V=1.0000005, theta=0.0
% INFO    : Bus 5530	: V=1.01440404, theta=-18.7819195 -> V=1.0158755, theta=0.0
% INFO    : Bus 5531	: V=1.00347482, theta=-0.463362745 -> V=1.0158755, theta=0.0
% INFO    : Bus 5532	: V=1.02220232, theta=-20.6490485 -> V=1.015872, theta=0.0
% INFO    : Bus 5533	: V=1.02330581, theta=-13.3717184 -> V=0.999999, theta=0.0
% INFO    : Bus 5534	: V=1.03998564, theta=-28.9961969 -> V=1.0000025, theta=0.0
% INFO    : Bus 5535	: V=1.00493424, theta=-4.74686764 -> V=1.0158755, theta=0.0
% INFO    : Bus 5536	: V=1.00176967, theta=-18.2920749 -> V=1.0158755, theta=0.0
% INFO    : Bus 5537	: V=1.00179352, theta=-18.2889577 -> V=1.0158755, theta=0.0
% INFO    : Bus 5538	: V=1.04896526, theta=-20.1440023 -> V=1.022224, theta=0.0
% INFO    : Bus 5539	: V=1.00555554, theta=-12.0601549 -> V=0.999999, theta=0.0
% INFO    : Bus 5540	: V=1.0639502, theta=-12.8908187 -> V=1.0000015, theta=0.0
% INFO    : Bus 5541	: V=1.06764822, theta=-12.6729396 -> V=1.0000015, theta=0.0
% INFO    : Bus 5542	: V=1.03977029, theta=-10.5754771 -> V=0.999999, theta=0.0
% INFO    : Bus 5543	: V=1.04337371, theta=-25.0304921 -> V=1.0000025, theta=0.0
% INFO    : Bus 5544	: V=1.02515112, theta=-24.3114506 -> V=1.0000025, theta=0.0
% INFO    : Bus 5545	: V=1.07274264, theta=-18.9200018 -> V=1.0333335, theta=0.0
% INFO    : Bus 5546	: V=1.07009778, theta=-21.3184601 -> V=1.0000025, theta=0.0
% INFO    : Bus 5547	: V=1.06942218, theta=-21.2875161 -> V=1.0000025, theta=0.0
% INFO    : Bus 5548	: V=1.02657994, theta=-10.3334575 -> V=1.0158755, theta=0.0
% INFO    : Bus 5549	: V=1.00978722, theta=-11.2444966 -> V=0.999999, theta=0.0
% INFO    : Bus 5550	: V=1.0120987, theta=-10.0440459 -> V=0.999999, theta=0.0
% INFO    : Bus 5551	: V=1.01200305, theta=-14.0880823 -> V=1.0158755, theta=0.0
% INFO    : Bus 5552	: V=1.01796727, theta=-16.4369896 -> V=0.999999, theta=0.0
% INFO    : Bus 5553	: V=0.973000176, theta=-24.3947077 -> V=1.0000025, theta=0.0
% INFO    : Bus 5554	: V=1.04829709, theta=-23.5287113 -> V=1.0222235, theta=0.0
% INFO    : Bus 5555	: V=1.01596915, theta=-11.2027611 -> V=1.015872, theta=0.0
% INFO    : Bus 5556	: V=1.04716145, theta=-23.6557784 -> V=1.0222235, theta=0.0
% INFO    : Bus 5557	: V=1.01312581, theta=-22.6657864 -> V=1.0000005, theta=0.0
% INFO    : Bus 5558	: V=1.01593683, theta=-21.6945615 -> V=0.999999, theta=0.0
% INFO    : Bus 5559	: V=1.06983928, theta=-17.3770349 -> V=1.046665, theta=0.0
% INFO    : Bus 5560	: V=1.07000182, theta=-17.3639976 -> V=1.046665, theta=0.0
% INFO    : Bus 5561	: V=1.02660809, theta=-13.1649255 -> V=0.999999, theta=0.0
% INFO    : Bus 5562	: V=1.0153572, theta=-11.7202003 -> V=1.0000015, theta=0.0
% INFO    : Bus 5563	: V=0.983573909, theta=-27.4974689 -> V=1.0000025, theta=0.0
% INFO    : Bus 5564	: V=0.983599279, theta=-27.5423277 -> V=1.0000025, theta=0.0
% INFO    : Bus 5565	: V=1.0615251, theta=-18.3971293 -> V=1.046665, theta=0.0
% INFO    : Bus 5566	: V=1.0422721, theta=-42.0553722 -> V=1.022224, theta=0.0
% INFO    : Bus 5567	: V=1.02071589, theta=-21.6020775 -> V=0.999999, theta=0.0
% INFO    : Bus 5568	: V=1.0636379, theta=-24.8798579 -> V=1.0000025, theta=0.0
% INFO    : Bus 5569	: V=1.06370628, theta=-24.8517395 -> V=1.0000025, theta=0.0
% INFO    : Bus 5570	: V=1.07172383, theta=-21.5934716 -> V=1.0222235, theta=0.0
% INFO    : Bus 5571	: V=1.02132053, theta=-18.2253893 -> V=1.015872, theta=0.0
% INFO    : Bus 5572	: V=0.975113604, theta=-24.9744962 -> V=1.0000025, theta=0.0
% INFO    : Bus 5573	: V=0.976748214, theta=-24.4034149 -> V=1.0000025, theta=0.0
% INFO    : Bus 5574	: V=1.02647795, theta=-16.5224708 -> V=0.999999, theta=0.0
% INFO    : Bus 5575	: V=1.01913833, theta=-28.5067558 -> V=1.0000025, theta=0.0
% INFO    : Bus 5576	: V=1.01796237, theta=-26.713362 -> V=1.0000025, theta=0.0
% INFO    : Bus 5577	: V=1.01818242, theta=-26.7270993 -> V=1.0000025, theta=0.0
% INFO    : Bus 5578	: V=1.05746478, theta=-24.833909 -> V=1.0000025, theta=0.0
% INFO    : Bus 5579	: V=1.05030735, theta=-12.7341643 -> V=1.0000015, theta=0.0
% INFO    : Bus 5580	: V=1.05255614, theta=-12.0436824 -> V=1.005558, theta=0.0
% INFO    : Bus 5581	: V=1.01269379, theta=-17.8947998 -> V=0.999999, theta=0.0
% INFO    : Bus 5582	: V=1.01798584, theta=-8.15337079 -> V=1.0079355, theta=0.0
% INFO    : Bus 5583	: V=1.07302206, theta=-17.8689877 -> V=1.0333335, theta=0.0
% INFO    : Bus 5584	: V=1.04558598, theta=-10.1032332 -> V=1.0000015, theta=0.0
% INFO    : Bus 5585	: V=1.03556214, theta=-16.5011765 -> V=1.0158755, theta=0.0
% INFO    : Bus 5586	: V=1.04133236, theta=-16.1960356 -> V=1.027779, theta=0.0
% INFO    : Bus 5587	: V=1.04127786, theta=-48.4152359 -> V=1.0079355, theta=0.0
% INFO    : Bus 5588	: V=1.01584417, theta=-17.655813 -> V=1.015872, theta=0.0
% INFO    : Bus 5589	: V=1.05318704, theta=-21.0595988 -> V=1.027779, theta=0.0
% INFO    : Bus 5590	: V=1.01623886, theta=-29.1102094 -> V=1.0000025, theta=0.0
% INFO    : Bus 5591	: V=1.07870467, theta=-14.4258856 -> V=1.046665, theta=0.0
% INFO    : Bus 5592	: V=1.06829647, theta=-6.92386434 -> V=1.005558, theta=0.0
% INFO    : Bus 5593	: V=1.0130767, theta=-12.3261747 -> V=0.999999, theta=0.0
% INFO    : Bus 5594	: V=1.03260397, theta=-16.9477792 -> V=1.0158755, theta=0.0
% INFO    : Bus 5595	: V=1.01833778, theta=-13.6481334 -> V=1.0158755, theta=0.0
% INFO    : Bus 5596	: V=1.00984285, theta=-20.46506 -> V=1.015872, theta=0.0
% INFO    : Bus 5597	: V=1.02175895, theta=-20.1123155 -> V=1.0000025, theta=0.0
% INFO    : Bus 5598	: V=1.02971048, theta=-25.7497114 -> V=1.0000025, theta=0.0
% INFO    : Bus 5599	: V=1.03424262, theta=-25.3815311 -> V=1.0000025, theta=0.0
% INFO    : Bus 5600	: V=1.05100082, theta=-21.1397946 -> V=1.0000025, theta=0.0
% INFO    : Bus 5601	: V=1.04963617, theta=-21.2594059 -> V=1.0000025, theta=0.0
% INFO    : Bus 5602	: V=1.05241513, theta=-21.0038427 -> V=1.0000025, theta=0.0
% INFO    : Bus 5603	: V=1.03000564, theta=-25.6912194 -> V=1.0000025, theta=0.0
% INFO    : Bus 5604	: V=1.07984875, theta=5.59910999 -> V=0.9908495, theta=0.0
% INFO    : Bus 5605	: V=1.01697466, theta=-25.3303855 -> V=1.015872, theta=0.0
% INFO    : Bus 5606	: V=1.02178924, theta=-46.8458253 -> V=1.0079355, theta=0.0
% INFO    : Bus 5607	: V=1.01376487, theta=-25.7351974 -> V=1.015872, theta=0.0
% INFO    : Bus 5608	: V=1.00465444, theta=-29.1450268 -> V=1.0000025, theta=0.0
% INFO    : Bus 5609	: V=1.02280432, theta=-14.2443753 -> V=0.999999, theta=0.0
% INFO    : Bus 5610	: V=1.07554696, theta=-19.2211866 -> V=1.029679, theta=0.0
% INFO    : Bus 5611	: V=1.02465504, theta=-13.9686374 -> V=0.999999, theta=0.0
% INFO    : Bus 5612	: V=1.07554008, theta=-19.2258638 -> V=1.029674, theta=0.0
% INFO    : Bus 5613	: V=1.00528265, theta=-29.1036829 -> V=1.0000025, theta=0.0
% INFO    : Bus 5614	: V=1.02074572, theta=-6.18058275 -> V=1.0158755, theta=0.0
% INFO    : Bus 5615	: V=1.02091789, theta=-6.11658467 -> V=1.0158755, theta=0.0
% INFO    : Bus 5616	: V=1.03402701, theta=-19.534791 -> V=0.999999, theta=0.0
% INFO    : Bus 5617	: V=1.02558952, theta=-21.3187637 -> V=1.0000025, theta=0.0
% INFO    : Bus 5618	: V=1.01764398, theta=-37.6004955 -> V=1.022224, theta=0.0
% INFO    : Bus 5619	: V=1.01510884, theta=-32.6971029 -> V=1.015872, theta=0.0
% INFO    : Bus 5620	: V=1.01506841, theta=-32.7032303 -> V=1.015872, theta=0.0
% INFO    : Bus 5621	: V=1.03156638, theta=-30.5766887 -> V=1.022224, theta=0.0
% INFO    : Bus 5622	: V=1.01859346, theta=-28.6416572 -> V=1.022224, theta=0.0
% INFO    : Bus 5623	: V=1.02164217, theta=-38.5203442 -> V=1.022224, theta=0.0
% INFO    : Bus 5624	: V=1.01252912, theta=-46.5116769 -> V=1.0079355, theta=0.0
% INFO    : Bus 5625	: V=1.0601176, theta=-9.68642976 -> V=1.0000015, theta=0.0
% INFO    : Bus 5626	: V=1.03041253, theta=-44.3132512 -> V=1.0079355, theta=0.0
% INFO    : Bus 5627	: V=1.01371277, theta=-16.7780402 -> V=1.0158755, theta=0.0
% INFO    : Bus 5628	: V=0.992634468, theta=-18.8020065 -> V=0.999999, theta=0.0
% INFO    : Bus 5629	: V=1.01408747, theta=-9.65766053 -> V=0.999999, theta=0.0
% INFO    : Bus 5630	: V=1.02834792, theta=-34.881512 -> V=1.022224, theta=0.0
% INFO    : Bus 5631	: V=1.0224327, theta=-49.0854816 -> V=1.0079355, theta=0.0
% INFO    : Bus 5632	: V=1.00091232, theta=-12.0512874 -> V=1.015872, theta=0.0
% INFO    : Bus 5633	: V=1.03351211, theta=-25.0095638 -> V=1.0222235, theta=0.0
% INFO    : Bus 5634	: V=1.03154846, theta=-17.8985253 -> V=0.999999, theta=0.0
% INFO    : Bus 5635	: V=1.0427686, theta=-48.2143849 -> V=1.0079355, theta=0.0
% INFO    : Bus 5636	: V=1.02301817, theta=-18.0315839 -> V=0.999999, theta=0.0
% INFO    : Bus 5637	: V=1.07447606, theta=-32.1127745 -> V=1.04444, theta=0.0
% INFO    : Bus 5638	: V=1.01247085, theta=-18.2238048 -> V=1.0000005, theta=0.0
% INFO    : Bus 5639	: V=1.058853, theta=-20.6081819 -> V=1.027779, theta=0.0
% INFO    : Bus 5640	: V=1.03079155, theta=-18.1391664 -> V=1.0000025, theta=0.0
% INFO    : Bus 5641	: V=1.02035875, theta=-38.4175914 -> V=1.022224, theta=0.0
% INFO    : Bus 5642	: V=1.03079155, theta=-18.1391664 -> V=1.0000025, theta=0.0
% INFO    : Bus 5643	: V=1.04726184, theta=-10.0433039 -> V=1.0000015, theta=0.0
% INFO    : Bus 5644	: V=1.0326881, theta=-33.0117379 -> V=1.022224, theta=0.0
% INFO    : Bus 5645	: V=1.07474245, theta=-11.4119395 -> V=1.072365, theta=0.0
% INFO    : Bus 5646	: V=1.03448902, theta=-10.7070697 -> V=0.999999, theta=0.0
% INFO    : Bus 5647	: V=1.02247626, theta=-13.9454124 -> V=1.0199985, theta=0.0
% INFO    : Bus 5648	: V=1.0311908, theta=-10.7625466 -> V=0.999999, theta=0.0
% INFO    : Bus 5649	: V=1.01739525, theta=-28.1433507 -> V=1.022224, theta=0.0
% INFO    : Bus 5650	: V=1.01334947, theta=-11.0760565 -> V=0.999999, theta=0.0
% INFO    : Bus 5651	: V=1.0390743, theta=-29.7079542 -> V=1.0000025, theta=0.0
% INFO    : Bus 5652	: V=1.03428425, theta=-16.691487 -> V=1.015872, theta=0.0
% INFO    : Bus 5653	: V=1.02240385, theta=-24.5796877 -> V=0.999999, theta=0.0
% INFO    : Bus 5654	: V=1.01895592, theta=-14.433553 -> V=0.999999, theta=0.0
% INFO    : Bus 5655	: V=1.04643438, theta=-21.0816184 -> V=1.022224, theta=0.0
% INFO    : Bus 5656	: V=1.00219335, theta=-17.2914092 -> V=0.999999, theta=0.0
% INFO    : Bus 5657	: V=1.02465856, theta=-13.6882765 -> V=0.999999, theta=0.0
% INFO    : Bus 5658	: V=1.04759339, theta=-16.7718636 -> V=1.046665, theta=0.0
% INFO    : Bus 5659	: V=1.05605598, theta=-8.61934544 -> V=0.9888895, theta=0.0
% INFO    : Bus 5660	: V=1.01581473, theta=-12.3071369 -> V=0.999999, theta=0.0
% INFO    : Bus 5661	: V=1.01743366, theta=-11.9093324 -> V=0.999999, theta=0.0
% INFO    : Bus 5662	: V=1.06402342, theta=-9.09793225 -> V=1.0000015, theta=0.0
% INFO    : Bus 5663	: V=1.06060858, theta=-5.36364905 -> V=0.9933315, theta=0.0
% INFO    : Bus 5664	: V=1.0379602, theta=-12.0700529 -> V=1.005558, theta=0.0
% INFO    : Bus 5665	: V=1.07098468, theta=-24.9712346 -> V=1.04444, theta=0.0
% INFO    : Bus 5666	: V=1.05729137, theta=-18.0445685 -> V=1.046665, theta=0.0
% INFO    : Bus 5667	: V=1.01205727, theta=-10.0536803 -> V=0.999999, theta=0.0
% INFO    : Bus 5668	: V=1.01469038, theta=-22.7630357 -> V=1.0000005, theta=0.0
% INFO    : Bus 5669	: V=1.01312915, theta=-19.0096043 -> V=1.0000005, theta=0.0
% INFO    : Bus 5670	: V=1.0520509, theta=-7.26414 -> V=1.0111115, theta=0.0
% INFO    : Bus 5671	: V=0.99923254, theta=-25.2406571 -> V=1.0000025, theta=0.0
% INFO    : Bus 5672	: V=1.01015847, theta=-12.2563525 -> V=1.015872, theta=0.0
% INFO    : Bus 5673	: V=1.0347434, theta=-19.3629962 -> V=1.0000005, theta=0.0
% INFO    : Bus 5674	: V=1.04034324, theta=-34.7501867 -> V=1.022224, theta=0.0
% INFO    : Bus 5675	: V=1.04925922, theta=-6.90677399 -> V=1.027779, theta=0.0
% INFO    : Bus 5676	: V=1.01006324, theta=-13.8380001 -> V=0.999999, theta=0.0
% INFO    : Bus 5677	: V=1.067004, theta=-19.5848483 -> V=1.046665, theta=0.0
% INFO    : Bus 5678	: V=1.0639867, theta=-19.2519935 -> V=1.046665, theta=0.0
% INFO    : Bus 5679	: V=1.03097612, theta=-26.3868171 -> V=1.022224, theta=0.0
% INFO    : Bus 5680	: V=1.01644636, theta=-11.7415012 -> V=0.999999, theta=0.0
% INFO    : Bus 5681	: V=1.0454605, theta=-20.4660214 -> V=1.022224, theta=0.0
% INFO    : Bus 5682	: V=1.04719433, theta=-20.1231473 -> V=1.022224, theta=0.0
% INFO    : Bus 5683	: V=1.07975454, theta=-17.8903503 -> V=1.046665, theta=0.0
% INFO    : Bus 5684	: V=1.06989115, theta=-17.7958654 -> V=1.046665, theta=0.0
% INFO    : Bus 5685	: V=1.02455746, theta=-14.0635408 -> V=0.999999, theta=0.0
% INFO    : Bus 5686	: V=1.01913182, theta=-26.6587764 -> V=1.0000025, theta=0.0
% INFO    : Bus 5687	: V=1.01920012, theta=-26.6213022 -> V=1.0000025, theta=0.0
% INFO    : Bus 5688	: V=1.0187339, theta=3.44840011 -> V=1.0158755, theta=0.0
% INFO    : Bus 5689	: V=1.02617353, theta=-38.2462843 -> V=1.0079355, theta=0.0
% INFO    : Bus 5690	: V=1.02804131, theta=-38.1398498 -> V=1.0079355, theta=0.0
% INFO    : Bus 5691	: V=1.01788281, theta=-24.7304245 -> V=1.015872, theta=0.0
% INFO    : Bus 5692	: V=1.02768024, theta=-25.7734041 -> V=1.0222235, theta=0.0
% INFO    : Bus 5693	: V=1.04755532, theta=-25.2561082 -> V=1.0000025, theta=0.0
% INFO    : Bus 5694	: V=1.02819299, theta=-26.2182772 -> V=1.0233335, theta=0.0
% INFO    : Bus 5695	: V=1.06475369, theta=-1.07424506 -> V=0.9933315, theta=0.0
% INFO    : Bus 5696	: V=1.05758875, theta=-9.82358288 -> V=0.9933315, theta=0.0
% INFO    : Bus 5697	: V=1.01110164, theta=-19.6593531 -> V=1.0000005, theta=0.0
% INFO    : Bus 5698	: V=1.05286857, theta=-9.56847593 -> V=1.0111115, theta=0.0
% INFO    : Bus 5699	: V=1.00404857, theta=-13.2590137 -> V=1.015872, theta=0.0
% INFO    : Bus 5700	: V=1.0357583, theta=-25.6341422 -> V=1.0000025, theta=0.0
% INFO    : Bus 5701	: V=1.05855231, theta=-14.6143205 -> V=1.046665, theta=0.0
% INFO    : Bus 5702	: V=1.04052599, theta=-19.693818 -> V=1.022224, theta=0.0
% INFO    : Bus 5703	: V=1.02727955, theta=-16.8716356 -> V=1.015872, theta=0.0
% INFO    : Bus 5704	: V=1.03308866, theta=-30.269019 -> V=1.022224, theta=0.0
% INFO    : Bus 5705	: V=1.01951345, theta=-21.7425271 -> V=0.999999, theta=0.0
% INFO    : Bus 5706	: V=0.990824474, theta=-24.4980099 -> V=1.0000005, theta=0.0
% INFO    : Bus 5707	: V=1.06721213, theta=4.25828395 -> V=0.9888895, theta=0.0
% INFO    : Bus 5708	: V=1.07445822, theta=-16.1002456 -> V=1.044445, theta=0.0
% INFO    : Bus 5709	: V=1.01406082, theta=-3.40857152 -> V=1.0158755, theta=0.0
% INFO    : Bus 5710	: V=1.05150712, theta=-21.0749321 -> V=1.027779, theta=0.0
% INFO    : Bus 5711	: V=1.06566512, theta=3.60735019 -> V=0.9888895, theta=0.0
% INFO    : Bus 5712	: V=1.05189861, theta=-21.095385 -> V=1.027779, theta=0.0
% INFO    : Bus 5713	: V=1.02508615, theta=-25.0254426 -> V=1.022224, theta=0.0
% INFO    : Bus 5714	: V=1.07757649, theta=-15.400279 -> V=1.046665, theta=0.0
% INFO    : Bus 5715	: V=1.04216996, theta=-48.5026892 -> V=1.0079355, theta=0.0
% INFO    : Bus 5716	: V=1.00213595, theta=-30.0909384 -> V=1.015872, theta=0.0
% INFO    : Bus 5717	: V=1.01480573, theta=-26.6684374 -> V=1.022224, theta=0.0
% INFO    : Bus 5718	: V=1.03316004, theta=-19.1984037 -> V=1.0158755, theta=0.0
% INFO    : Bus 5719	: V=1.01102997, theta=-17.3342051 -> V=0.999999, theta=0.0
% INFO    : Bus 5720	: V=1.00609397, theta=-20.5911325 -> V=1.022224, theta=0.0
% INFO    : Bus 5721	: V=1.03015225, theta=-30.7378071 -> V=1.022224, theta=0.0
% INFO    : Bus 5722	: V=1.03641323, theta=-31.9643141 -> V=1.022224, theta=0.0
% INFO    : Bus 5723	: V=1.06965887, theta=1.1953527 -> V=1.05263, theta=0.0
% INFO    : Bus 5724	: V=1.01395385, theta=-11.8260957 -> V=1.0158755, theta=0.0
% INFO    : Bus 5725	: V=1.02761178, theta=-13.7959088 -> V=0.999999, theta=0.0
% INFO    : Bus 5726	: V=1.03402008, theta=-27.0236389 -> V=1.015872, theta=0.0
% INFO    : Bus 5727	: V=1.04679398, theta=-11.343954 -> V=1.0000015, theta=0.0
% INFO    : Bus 5728	: V=1.01374096, theta=-19.9475745 -> V=1.015872, theta=0.0
% INFO    : Bus 5729	: V=1.01983679, theta=-16.6580343 -> V=1.015872, theta=0.0
% INFO    : Bus 5730	: V=1.00724007, theta=-27.8991823 -> V=1.015872, theta=0.0
% INFO    : Bus 5731	: V=1.05283937, theta=-22.1658826 -> V=1.0000025, theta=0.0
% INFO    : Bus 5732	: V=1.02896455, theta=-18.8849893 -> V=1.0000025, theta=0.0
% INFO    : Bus 5733	: V=1.01965758, theta=3.55497305 -> V=1.0158755, theta=0.0
% INFO    : Bus 5734	: V=1.02530784, theta=-10.2351284 -> V=0.999999, theta=0.0
% INFO    : Bus 5735	: V=1.02232239, theta=3.49381266 -> V=1.0158755, theta=0.0
% INFO    : Bus 5736	: V=1.01584092, theta=-29.2570273 -> V=1.0000025, theta=0.0
% INFO    : Bus 5737	: V=1.02849193, theta=-18.8724807 -> V=0.999999, theta=0.0
% INFO    : Bus 5738	: V=1.03785841, theta=-49.0564678 -> V=1.0079355, theta=0.0
% INFO    : Bus 5739	: V=1.03748235, theta=-40.3769876 -> V=1.022224, theta=0.0
% INFO    : Bus 5740	: V=1.02854731, theta=-48.3657693 -> V=1.0079355, theta=0.0
% INFO    : Bus 5741	: V=1.02398362, theta=-13.0025277 -> V=1.015872, theta=0.0
% INFO    : Bus 5742	: V=1.0659506, theta=-21.9778946 -> V=1.0000025, theta=0.0
% INFO    : Bus 5743	: V=0.935031322, theta=-8.32721549 -> V=0.9444445, theta=0.0
% INFO    : Bus 5744	: V=1.05705097, theta=-18.5240072 -> V=1.046665, theta=0.0
% INFO    : Bus 5745	: V=1.03226446, theta=-21.0265526 -> V=1.0000025, theta=0.0
% INFO    : Bus 5746	: V=1.00895149, theta=-29.2297645 -> V=1.0000025, theta=0.0
% INFO    : Bus 5747	: V=1.01471928, theta=-11.3464372 -> V=0.999999, theta=0.0
% INFO    : Bus 5748	: V=1.02839909, theta=-24.1938343 -> V=1.027779, theta=0.0
% INFO    : Bus 5749	: V=1.03265559, theta=-14.7972847 -> V=0.999999, theta=0.0
% INFO    : Bus 5750	: V=1.02990777, theta=-17.1777285 -> V=1.0158755, theta=0.0
% INFO    : Bus 5751	: V=1.06104112, theta=-19.3887167 -> V=1.0222235, theta=0.0
% INFO    : Bus 5752	: V=1.0088695, theta=-30.2179182 -> V=1.0000025, theta=0.0
% INFO    : Bus 5753	: V=0.950018191, theta=-8.15534766 -> V=0.9444445, theta=0.0
% INFO    : Bus 5754	: V=1.02785263, theta=-24.9820934 -> V=1.0000025, theta=0.0
% INFO    : Bus 5755	: V=1.03825784, theta=-24.8767248 -> V=1.0000025, theta=0.0
% INFO    : Bus 5756	: V=1.0098739, theta=-30.0722259 -> V=1.0000025, theta=0.0
% INFO    : Bus 5757	: V=1.00908645, theta=-21.6247562 -> V=1.0000025, theta=0.0
% INFO    : Bus 5758	: V=1.00927728, theta=-21.5826884 -> V=1.0000025, theta=0.0
% INFO    : Bus 5759	: V=1.06812241, theta=-30.4688375 -> V=1.04444, theta=0.0
% INFO    : Bus 5760	: V=1.01231724, theta=-19.0257657 -> V=1.0000005, theta=0.0
% INFO    : Bus 5761	: V=1.01109479, theta=-26.3621711 -> V=1.0000025, theta=0.0
% INFO    : Bus 5762	: V=1.05468265, theta=-19.171953 -> V=1.022224, theta=0.0
% INFO    : Bus 5763	: V=1.02198514, theta=-7.04530854 -> V=1.0158755, theta=0.0
% INFO    : Bus 5764	: V=1.0334996, theta=-35.9105397 -> V=1.0079355, theta=0.0
% INFO    : Bus 5765	: V=1.0427331, theta=-20.890149 -> V=1.022224, theta=0.0
% INFO    : Bus 5766	: V=1.06838779, theta=-2.22425964 -> V=0.9888895, theta=0.0
% INFO    : Bus 5767	: V=1.02362278, theta=-6.80612054 -> V=1.0158755, theta=0.0
% INFO    : Bus 5768	: V=1.02021113, theta=-40.0528962 -> V=1.0079355, theta=0.0
% INFO    : Bus 5769	: V=1.02057612, theta=-32.5107217 -> V=1.015872, theta=0.0
% INFO    : Bus 5770	: V=1.02532915, theta=-29.8789601 -> V=1.015872, theta=0.0
% INFO    : Bus 5771	: V=1.01032288, theta=-23.2696239 -> V=0.999999, theta=0.0
% INFO    : Bus 5772	: V=1.00729943, theta=-18.2027725 -> V=1.0000005, theta=0.0
% INFO    : Bus 5773	: V=1.0101094, theta=-18.439996 -> V=1.0000005, theta=0.0
% INFO    : Bus 5774	: V=1.02834378, theta=-46.060653 -> V=1.0079355, theta=0.0
% INFO    : Bus 5775	: V=1.04559296, theta=-26.8762882 -> V=1.0000025, theta=0.0
% INFO    : Bus 5776	: V=1.03643333, theta=-22.2677966 -> V=1.027779, theta=0.0
% INFO    : Bus 5777	: V=1.02416398, theta=-11.339791 -> V=1.0158755, theta=0.0
% INFO    : Bus 5778	: V=1.02190987, theta=-1.67038608 -> V=1.0000015, theta=0.0
% INFO    : Bus 5779	: V=1.02716572, theta=-22.4572872 -> V=1.015872, theta=0.0
% INFO    : Bus 5780	: V=1.03357085, theta=-29.1001509 -> V=1.022224, theta=0.0
% INFO    : Bus 5781	: V=1.00197883, theta=-19.8181215 -> V=0.999999, theta=0.0
% INFO    : Bus 5782	: V=1.06101619, theta=-19.5219046 -> V=1.046665, theta=0.0
% INFO    : Bus 5783	: V=1.01938978, theta=-16.2701726 -> V=0.999999, theta=0.0
% INFO    : Bus 5784	: V=1.01985353, theta=-1.80034414 -> V=1.0000015, theta=0.0
% INFO    : Bus 5785	: V=1.03696126, theta=-2.08666773 -> V=1.0000015, theta=0.0
% INFO    : Bus 5786	: V=1.04556284, theta=-41.5188707 -> V=1.022224, theta=0.0
% INFO    : Bus 5787	: V=1.0723091, theta=-19.4069339 -> V=1.046665, theta=0.0
% INFO    : Bus 5788	: V=1.04209837, theta=-19.7379643 -> V=0.999999, theta=0.0
% INFO    : Bus 5789	: V=1.02340664, theta=-18.0468723 -> V=1.015872, theta=0.0
% INFO    : Bus 5790	: V=1.05188247, theta=-13.6774451 -> V=0.999999, theta=0.0
% INFO    : Bus 5791	: V=1.01503392, theta=-34.395412 -> V=1.022224, theta=0.0
% INFO    : Bus 5792	: V=1.00983524, theta=-22.1055988 -> V=1.0000005, theta=0.0
% INFO    : Bus 5793	: V=1.00402429, theta=-12.1725737 -> V=1.015872, theta=0.0
% INFO    : Bus 5794	: V=0.950538407, theta=-8.11897089 -> V=0.9444445, theta=0.0
% INFO    : Bus 5795	: V=0.950746341, theta=-6.64687579 -> V=0.9444445, theta=0.0
% INFO    : Bus 5796	: V=1.04621809, theta=-14.3875829 -> V=0.999999, theta=0.0
% INFO    : Bus 5797	: V=1.03364475, theta=-14.5322068 -> V=0.999999, theta=0.0
% INFO    : Bus 5798	: V=1.00739772, theta=-24.1013092 -> V=1.022224, theta=0.0
% INFO    : Bus 5799	: V=1.04915981, theta=-22.5349851 -> V=1.022224, theta=0.0
% INFO    : Bus 5800	: V=1.06077854, theta=-39.707846 -> V=1.022224, theta=0.0
% INFO    : Bus 5801	: V=1.04547834, theta=-24.3772119 -> V=1.027779, theta=0.0
% INFO    : Bus 5802	: V=1.02090874, theta=-16.368942 -> V=1.015872, theta=0.0
% INFO    : Bus 5803	: V=1.02163988, theta=-17.1128311 -> V=1.015872, theta=0.0
% INFO    : Bus 5804	: V=1.03183971, theta=-26.9360812 -> V=1.0000025, theta=0.0
% INFO    : Bus 5805	: V=1.07423029, theta=-12.0662455 -> V=0.9888895, theta=0.0
% INFO    : Bus 5806	: V=1.00903856, theta=-25.7173827 -> V=1.0000025, theta=0.0
% INFO    : Bus 5807	: V=1.00945732, theta=-25.6906522 -> V=1.0000025, theta=0.0
% INFO    : Bus 5808	: V=1.00027913, theta=-12.2325089 -> V=0.999999, theta=0.0
% INFO    : Bus 5809	: V=1.03130859, theta=-34.5313894 -> V=1.022224, theta=0.0
% INFO    : Bus 5810	: V=0.899560981, theta=-8.45562275 -> V=0.9444445, theta=0.0
% INFO    : Bus 5811	: V=1.00371681, theta=-22.8624417 -> V=1.0000025, theta=0.0
% INFO    : Bus 5812	: V=1.04402103, theta=-16.2517643 -> V=0.999999, theta=0.0
% INFO    : Bus 5813	: V=1.05722062, theta=-24.6950024 -> V=1.0000025, theta=0.0
% INFO    : Bus 5814	: V=1.07144188, theta=-40.2184599 -> V=1.04444, theta=0.0
% INFO    : Bus 5815	: V=1.0311268, theta=-30.6839253 -> V=1.022224, theta=0.0
% INFO    : Bus 5816	: V=1.04107331, theta=-35.9923231 -> V=1.022224, theta=0.0
% INFO    : Bus 5817	: V=1.03239141, theta=-16.9838697 -> V=1.015872, theta=0.0
% INFO    : Bus 5818	: V=1.06874373, theta=-4.37152442 -> V=0.9933315, theta=0.0
% INFO    : Bus 5819	: V=1.01313642, theta=-29.4844809 -> V=1.0000025, theta=0.0
% INFO    : Bus 5820	: V=1.03238916, theta=-17.0189436 -> V=1.022224, theta=0.0
% INFO    : Bus 5821	: V=1.05033804, theta=-22.8573822 -> V=1.0000025, theta=0.0
% INFO    : Bus 5822	: V=1.01002616, theta=-6.06577741 -> V=1.0158755, theta=0.0
% INFO    : Bus 5823	: V=1.05173939, theta=-11.023663 -> V=1.07374, theta=0.0
% INFO    : Bus 5824	: V=1.03667567, theta=-25.8631479 -> V=1.0000025, theta=0.0
% INFO    : Bus 5825	: V=1.03438588, theta=-25.9475354 -> V=1.0000025, theta=0.0
% INFO    : Bus 5826	: V=1.0168839, theta=-9.31563905 -> V=1.0079355, theta=0.0
% INFO    : Bus 5827	: V=1.01921297, theta=-20.7197565 -> V=1.015872, theta=0.0
% INFO    : Bus 5828	: V=0.975445219, theta=-17.666878 -> V=1.015872, theta=0.0
% INFO    : Bus 5829	: V=1.06323979, theta=-14.517405 -> V=1.046665, theta=0.0
% INFO    : Bus 5830	: V=1.00581751, theta=-11.296719 -> V=0.999999, theta=0.0
% INFO    : Bus 5831	: V=1.01252031, theta=-23.1529011 -> V=1.0000025, theta=0.0
% INFO    : Bus 5832	: V=1.02857353, theta=-16.6095321 -> V=0.999999, theta=0.0
% INFO    : Bus 5833	: V=1.02421444, theta=-9.86661691 -> V=0.999999, theta=0.0
% INFO    : Bus 5834	: V=1.04879657, theta=-23.0927836 -> V=1.0000025, theta=0.0
% INFO    : Bus 5835	: V=1.04936576, theta=-28.8025385 -> V=1.022224, theta=0.0
% INFO    : Bus 5836	: V=1.02878728, theta=-15.6843497 -> V=1.0000005, theta=0.0
% INFO    : Bus 5837	: V=1.01328988, theta=-9.1503753 -> V=0.999999, theta=0.0
% INFO    : Bus 5838	: V=1.04311255, theta=-20.9668147 -> V=1.027779, theta=0.0
% INFO    : Bus 5839	: V=1.0155189, theta=-17.1232319 -> V=0.999999, theta=0.0
% INFO    : Bus 5840	: V=0.899977789, theta=-6.02315922 -> V=0.9444445, theta=0.0
% INFO    : Bus 5841	: V=1.03821507, theta=-24.8758587 -> V=1.0000025, theta=0.0
% INFO    : Bus 5842	: V=1.01398348, theta=-18.8538582 -> V=1.0000005, theta=0.0
% INFO    : Bus 5843	: V=1.03704167, theta=-2.07793103 -> V=1.0000015, theta=0.0
% INFO    : Bus 5844	: V=0.97658979, theta=-20.6319489 -> V=0.999999, theta=0.0
% INFO    : Bus 5845	: V=1.0429333, theta=-19.734157 -> V=1.022224, theta=0.0
% INFO    : Bus 5846	: V=1.02551511, theta=-22.5368504 -> V=1.0000025, theta=0.0
% INFO    : Bus 5847	: V=1.02774366, theta=-22.4154382 -> V=1.0000025, theta=0.0
% INFO    : Bus 5848	: V=0.991006402, theta=-25.9561257 -> V=1.0000025, theta=0.0
% INFO    : Bus 5849	: V=1.04411296, theta=-6.67392392 -> V=1.0111115, theta=0.0
% INFO    : Bus 5850	: V=1.01704887, theta=-18.931339 -> V=1.0000005, theta=0.0
% INFO    : Bus 5851	: V=1.05852772, theta=-3.03426812 -> V=0.9933315, theta=0.0
% INFO    : Bus 5852	: V=1.0577059, theta=-17.28415 -> V=1.027779, theta=0.0
% INFO    : Bus 5853	: V=1.05454547, theta=-16.688007 -> V=1.027779, theta=0.0
% INFO    : Bus 5854	: V=1.03424601, theta=-19.5484266 -> V=0.999999, theta=0.0
% INFO    : Bus 5855	: V=1.01980341, theta=-32.2994059 -> V=1.022224, theta=0.0
% INFO    : Bus 5856	: V=1.05361979, theta=1.70167159 -> V=0.975, theta=0.0
% INFO    : Bus 5857	: V=1.06231661, theta=0.834664756 -> V=0.975, theta=0.0
% INFO    : Bus 5858	: V=1.03975396, theta=11.5104625 -> V=0.975, theta=0.0
% INFO    : Bus 5859	: V=1.03973478, theta=11.5086095 -> V=0.975, theta=0.0
% INFO    : Bus 5860	: V=1.07998106, theta=15.4911648 -> V=0.975, theta=0.0
% INFO    : Bus 5861	: V=1.07504625, theta=1.73395788 -> V=0.975, theta=0.0
% INFO    : Bus 5862	: V=1.05655155, theta=5.30168052 -> V=0.975, theta=0.0
% INFO    : Bus 5863	: V=1.09695587, theta=10.8030939 -> V=0.975, theta=0.0
% INFO    : Bus 5864	: V=1.04120754, theta=-15.0225911 -> V=0.975, theta=0.0
% INFO    : Bus 5865	: V=1.09781207, theta=4.03531014 -> V=0.975, theta=0.0
% INFO    : Bus 5866	: V=1.10596339, theta=-5.87049369 -> V=0.975, theta=0.0
% INFO    : Bus 5867	: V=1.05528108, theta=1.07591557 -> V=0.975, theta=0.0
% INFO    : Bus 5868	: V=1.05511884, theta=2.31369412 -> V=0.975, theta=0.0
% INFO    : Bus 5869	: V=1.05131562, theta=2.36577067 -> V=0.975, theta=0.0
% INFO    : Bus 5870	: V=1.05095406, theta=2.33731342 -> V=0.975, theta=0.0
% INFO    : Bus 5871	: V=1.10075405, theta=0.48811288 -> V=0.975, theta=0.0
% INFO    : Bus 5872	: V=1.07376899, theta=-7.1932573 -> V=0.975, theta=0.0
% INFO    : Bus 5873	: V=1.05628064, theta=-27.3339524 -> V=0.975, theta=0.0
% INFO    : Bus 5874	: V=1.04489531, theta=-26.2050927 -> V=0.975, theta=0.0
% INFO    : Bus 5875	: V=1.05887215, theta=-18.5061733 -> V=0.975, theta=0.0
% INFO    : Bus 5876	: V=1.06687345, theta=-17.9014907 -> V=0.975, theta=0.0
% INFO    : Bus 5877	: V=1.06900245, theta=-7.07911393 -> V=0.975, theta=0.0
% INFO    : Bus 5878	: V=1.09040845, theta=-15.0365219 -> V=0.975, theta=0.0
% INFO    : Bus 5879	: V=1.08500397, theta=-16.1531725 -> V=0.975, theta=0.0
% INFO    : Bus 5880	: V=1.05915199, theta=-11.3994109 -> V=0.975, theta=0.0
% INFO    : Bus 5881	: V=1.0693979, theta=-21.4868898 -> V=0.975, theta=0.0
% INFO    : Bus 5882	: V=1.07828639, theta=-14.2741507 -> V=0.975, theta=0.0
% INFO    : Bus 5883	: V=1.07267194, theta=-41.957267 -> V=0.975, theta=0.0
% INFO    : Bus 5884	: V=1.0730748, theta=3.24922965 -> V=0.975, theta=0.0
% INFO    : Bus 5885	: V=1.06367788, theta=-19.618687 -> V=0.975, theta=0.0
% INFO    : Bus 5886	: V=1.06821081, theta=-18.9757509 -> V=0.975, theta=0.0
% INFO    : Bus 5887	: V=1.05372902, theta=-8.59342483 -> V=0.975, theta=0.0
% INFO    : Bus 5888	: V=1.07638754, theta=-17.8386701 -> V=0.975, theta=0.0
% INFO    : Bus 5889	: V=1.04789944, theta=-23.0011646 -> V=0.975, theta=0.0
% INFO    : Bus 5890	: V=1.0652268, theta=-16.6698342 -> V=0.975, theta=0.0
% INFO    : Bus 5891	: V=1.0709932, theta=-25.6147627 -> V=0.975, theta=0.0
% INFO    : Bus 5892	: V=1.070805, theta=-16.594129 -> V=0.975, theta=0.0
% INFO    : Bus 5893	: V=1.07968333, theta=-15.8733118 -> V=0.975, theta=0.0
% INFO    : Bus 5894	: V=1.07758529, theta=-15.7025713 -> V=0.975, theta=0.0
% INFO    : Bus 5895	: V=1.07680575, theta=-12.2313667 -> V=0.975, theta=0.0
% INFO    : Bus 5896	: V=1.02874385, theta=-26.1616669 -> V=0.975, theta=0.0
% INFO    : Bus 5897	: V=1.05705584, theta=-16.4126412 -> V=0.975, theta=0.0
% INFO    : Bus 5898	: V=1.0745894, theta=-13.3859019 -> V=0.975, theta=0.0
% INFO    : Bus 5899	: V=1.07835867, theta=-18.399444 -> V=0.975, theta=0.0
% INFO    : Bus 5900	: V=1.05136627, theta=-7.84810144 -> V=0.975, theta=0.0
% INFO    : Bus 5901	: V=1.03070734, theta=-19.5416367 -> V=0.975, theta=0.0
% INFO    : Bus 5902	: V=1.0568815, theta=-27.5088994 -> V=0.975, theta=0.0
% INFO    : Bus 5903	: V=1.08027802, theta=-18.5592384 -> V=0.975, theta=0.0
% INFO    : Bus 5904	: V=1.04477537, theta=-26.2800152 -> V=0.975, theta=0.0
% INFO    : Bus 5905	: V=1.05870481, theta=-18.1176287 -> V=0.975, theta=0.0
% INFO    : Bus 5906	: V=1.06304284, theta=-6.77364729 -> V=0.975, theta=0.0
% INFO    : Bus 5907	: V=1.0867707, theta=-15.1817711 -> V=0.975, theta=0.0
% INFO    : Bus 5908	: V=1.05869069, theta=-19.0076055 -> V=0.975, theta=0.0
% INFO    : Bus 5909	: V=1.0603595, theta=-9.30520491 -> V=0.975, theta=0.0
% INFO    : Bus 5910	: V=1.07215758, theta=-40.9003191 -> V=0.975, theta=0.0
% INFO    : Bus 5911	: V=1.07263951, theta=3.0890788 -> V=0.975, theta=0.0
% INFO    : Bus 5912	: V=1.06978323, theta=-18.9409844 -> V=0.975, theta=0.0
% INFO    : Bus 5913	: V=1.04920713, theta=-8.66196402 -> V=0.975, theta=0.0
% INFO    : Bus 5914	: V=1.08791332, theta=-15.5197017 -> V=0.975, theta=0.0
% INFO    : Bus 5915	: V=1.07641053, theta=-17.7103152 -> V=0.975, theta=0.0
% INFO    : Bus 5916	: V=1.04833291, theta=-23.2224725 -> V=0.975, theta=0.0
% INFO    : Bus 5917	: V=1.08034945, theta=-15.759821 -> V=0.975, theta=0.0
% INFO    : Bus 5918	: V=1.07088637, theta=-16.5561553 -> V=0.975, theta=0.0
% INFO    : Bus 5919	: V=1.0773212, theta=-15.7042708 -> V=0.975, theta=0.0
% INFO    : Bus 5920	: V=1.05720363, theta=-16.2147923 -> V=0.975, theta=0.0
% INFO    : Bus 5921	: V=1.06768594, theta=-21.3922955 -> V=0.975, theta=0.0
% INFO    : Bus 5922	: V=1.07832589, theta=-18.4218797 -> V=0.975, theta=0.0
% INFO    : Bus 5923	: V=1.07998393, theta=-16.1535777 -> V=0.975, theta=0.0
% INFO    : Bus 5924	: V=1.05019932, theta=-6.73293048 -> V=0.975, theta=0.0
% INFO    : Bus 5925	: V=1.07363088, theta=-7.2368418 -> V=0.975, theta=0.0
% INFO    : Bus 5926	: V=1.04646485, theta=-19.4868523 -> V=0.975, theta=0.0
% INFO    : Bus 5927	: V=1.0577719, theta=-13.8927618 -> V=0.975, theta=0.0
% INFO    : Bus 5928	: V=1.07163433, theta=-18.7564834 -> V=0.975, theta=0.0
% INFO    : Bus 5929	: V=1.06931564, theta=-13.6621163 -> V=0.975, theta=0.0
% INFO    : Bus 5930	: V=1.07096607, theta=-17.3132278 -> V=0.975, theta=0.0
% INFO    : Bus 5931	: V=1.06359895, theta=-21.3470892 -> V=0.975, theta=0.0
% INFO    : Bus 5932	: V=1.06719813, theta=-10.4247703 -> V=0.975, theta=0.0
% INFO    : Bus 5933	: V=1.06762067, theta=-22.0084995 -> V=0.975, theta=0.0
% INFO    : Bus 5934	: V=1.07124506, theta=-7.8483518 -> V=0.975, theta=0.0
% INFO    : Bus 5935	: V=1.06929377, theta=-18.6588278 -> V=0.975, theta=0.0
% INFO    : Bus 5936	: V=1.08681548, theta=-16.2188308 -> V=0.975, theta=0.0
% INFO    : Bus 5937	: V=1.06553601, theta=-16.776963 -> V=0.975, theta=0.0
% INFO    : Bus 5938	: V=1.06953789, theta=-16.984731 -> V=0.975, theta=0.0
% INFO    : Bus 5939	: V=1.08143118, theta=-4.30126457 -> V=0.975, theta=0.0
% INFO    : Bus 5940	: V=1.07526546, theta=-18.3256029 -> V=0.975, theta=0.0
% INFO    : Bus 5941	: V=1.07029583, theta=-18.4501963 -> V=0.975, theta=0.0
% INFO    : Bus 5942	: V=1.06907025, theta=-18.2582864 -> V=0.975, theta=0.0
% INFO    : Bus 5943	: V=1.07179654, theta=-30.8255969 -> V=0.975, theta=0.0
% INFO    : Bus 5944	: V=1.07629841, theta=-20.9299139 -> V=0.975, theta=0.0
% INFO    : Bus 5945	: V=1.06365004, theta=-19.6722239 -> V=0.975, theta=0.0
% INFO    : Bus 5946	: V=1.08690437, theta=-16.2760101 -> V=0.975, theta=0.0
% INFO    : Bus 5947	: V=1.06482627, theta=-17.3810069 -> V=0.975, theta=0.0
% INFO    : Bus 5948	: V=1.0799399, theta=-4.69376659 -> V=0.975, theta=0.0
% INFO    : Bus 5949	: V=1.07510182, theta=-18.3235124 -> V=0.975, theta=0.0
% INFO    : Bus 5950	: V=1.08488905, theta=-18.8211192 -> V=0.975, theta=0.0
% INFO    : Bus 5951	: V=1.07919827, theta=-15.384389 -> V=0.975, theta=0.0
% INFO    : Bus 5952	: V=1.07180272, theta=-18.0817115 -> V=0.975, theta=0.0
% INFO    : Bus 5953	: V=1.11548811, theta=-6.72637955 -> V=0.975, theta=0.0
% INFO    : Bus 5954	: V=1.07218484, theta=-30.5358878 -> V=0.975, theta=0.0
% INFO    : Bus 5955	: V=1.07792809, theta=-9.44364651 -> V=0.975, theta=0.0
% INFO    : Bus 5956	: V=1.08860213, theta=-19.2663541 -> V=0.975, theta=0.0
% INFO    : Bus 5957	: V=1.07335343, theta=-15.1425145 -> V=0.975, theta=0.0
% INFO    : Bus 5958	: V=1.07241763, theta=5.33695273 -> V=0.975, theta=0.0
% INFO    : Bus 5959	: V=1.09789819, theta=-9.11436161 -> V=0.975, theta=0.0
% INFO    : Bus 5960	: V=1.10049362, theta=-2.08992033 -> V=0.975, theta=0.0
% INFO    : Bus 5961	: V=1.06665732, theta=-23.497348 -> V=0.975, theta=0.0
% INFO    : Bus 5962	: V=1.05208889, theta=-12.7500854 -> V=0.975, theta=0.0
% INFO    : Bus 5963	: V=1.098, theta=-2.41037233 -> V=0.975, theta=0.0
% INFO    : Bus 5964	: V=1.10070066, theta=-0.897268209 -> V=0.975, theta=0.0
% INFO    : Bus 5965	: V=1.07307492, theta=5.54589178 -> V=0.975, theta=0.0
% INFO    : Bus 5966	: V=1.13391273, theta=6.28929843 -> V=0.975, theta=0.0
% INFO    : Bus 5967	: V=1.08825383, theta=5.80162217 -> V=0.975, theta=0.0
% INFO    : Bus 5968	: V=1.05936951, theta=-1.01140208 -> V=0.975, theta=0.0
% INFO    : Bus 5969	: V=1.0659828, theta=-9.53043494 -> V=0.975, theta=0.0
% INFO    : Bus 5970	: V=1.09570946, theta=-10.5959839 -> V=0.975, theta=0.0
% INFO    : Bus 5971	: V=1.09787781, theta=-13.990338 -> V=0.975, theta=0.0
% INFO    : Bus 5972	: V=1.08085122, theta=-6.83691093 -> V=0.975, theta=0.0
% INFO    : Bus 5973	: V=1.104, theta=-5.99572047 -> V=0.975, theta=0.0
% INFO    : Bus 5974	: V=1.08093829, theta=-8.20672013 -> V=0.975, theta=0.0
% INFO    : Bus 5975	: V=1.08913697, theta=-3.01450214 -> V=0.975, theta=0.0
% INFO    : Bus 5976	: V=1.075, theta=-8.77023617 -> V=0.975, theta=0.0
% INFO    : Bus 5977	: V=1.06694042, theta=-11.6380381 -> V=0.975, theta=0.0
% INFO    : Bus 5978	: V=1.08993467, theta=-8.2450756 -> V=0.975, theta=0.0
% INFO    : Bus 5979	: V=1.10271132, theta=-5.0802689 -> V=0.975, theta=0.0
% INFO    : Bus 5980	: V=1.07840848, theta=-18.3099363 -> V=0.975, theta=0.0
% INFO    : Bus 5981	: V=1.0204444, theta=-13.1377365 -> V=0.975, theta=0.0
% INFO    : Bus 5982	: V=1.08514339, theta=-11.8037337 -> V=0.975, theta=0.0
% INFO    : Bus 5983	: V=1.09852624, theta=0.414057782 -> V=0.975, theta=0.0
% INFO    : Bus 5984	: V=1.06502674, theta=-7.40870764 -> V=0.975, theta=0.0
% INFO    : Bus 5985	: V=1.06056597, theta=-9.32534593 -> V=0.975, theta=0.0
% INFO    : Bus 5986	: V=1.07985695, theta=-3.176635 -> V=0.975, theta=0.0
% INFO    : Bus 5987	: V=1.04276429, theta=-9.04050852 -> V=0.975, theta=0.0
% INFO    : Bus 5988	: V=1.1092619, theta=-5.50357918 -> V=0.975, theta=0.0
% INFO    : Bus 5989	: V=1.061, theta=10.4469232 -> V=0.975, theta=0.0
% INFO    : Bus 5990	: V=1.07241261, theta=-10.3597398 -> V=0.975, theta=0.0
% INFO    : Bus 5991	: V=1.10006512, theta=-15.3895702 -> V=0.975, theta=0.0
% INFO    : Bus 5992	: V=1.05576637, theta=11.0246499 -> V=0.975, theta=0.0
% INFO    : Bus 5993	: V=1.10219309, theta=-3.03069683 -> V=0.975, theta=0.0
% INFO    : Bus 5994	: V=1.0523769, theta=1.88391488 -> V=0.975, theta=0.0
% INFO    : Bus 5995	: V=1.07137536, theta=4.89876764 -> V=0.975, theta=0.0
% INFO    : Bus 5996	: V=1.06309879, theta=-0.677395985 -> V=0.975, theta=0.0
% INFO    : Bus 5997	: V=1.09963456, theta=-14.9643548 -> V=0.975, theta=0.0
% INFO    : Bus 5998	: V=1.0949975, theta=10.1415274 -> V=0.975, theta=0.0
% INFO    : Bus 5999	: V=1.10506987, theta=-13.9203097 -> V=0.975, theta=0.0
% INFO    : Bus 6000	: V=1.00772144, theta=-21.751991 -> V=0.975, theta=0.0
% INFO    : Bus 6001	: V=1.01044845, theta=-34.2507665 -> V=0.975, theta=0.0
% INFO    : Bus 6002	: V=1.07700628, theta=-9.07812968 -> V=0.975, theta=0.0
% INFO    : Bus 6003	: V=1.0852467, theta=-9.15529361 -> V=0.975, theta=0.0
% INFO    : Bus 6004	: V=0.993, theta=-1.54725668 -> V=0.975, theta=0.0
% INFO    : Bus 6005	: V=1.06087, theta=-9.74710622 -> V=0.975, theta=0.0
% INFO    : Bus 6006	: V=1.07587698, theta=-10.2096217 -> V=0.975, theta=0.0
% INFO    : Bus 6007	: V=1.072, theta=-8.3696403 -> V=0.975, theta=0.0
% INFO    : Bus 6008	: V=1.10334533, theta=-14.5456291 -> V=0.975, theta=0.0
% INFO    : Bus 6009	: V=1.0629548, theta=-9.65596617 -> V=0.975, theta=0.0
% INFO    : Bus 6010	: V=1.07137491, theta=4.8968454 -> V=0.975, theta=0.0
% INFO    : Bus 6011	: V=1.07132283, theta=4.86562135 -> V=0.975, theta=0.0
% INFO    : Bus 6012	: V=1.04771327, theta=-6.95339348 -> V=0.975, theta=0.0
% INFO    : Bus 6013	: V=1.06009202, theta=3.6202459 -> V=0.975, theta=0.0
% INFO    : Bus 6014	: V=1.06415636, theta=-11.1750867 -> V=0.975, theta=0.0
% INFO    : Bus 6015	: V=1.109, theta=-3.55243475 -> V=0.975, theta=0.0
% INFO    : Bus 6016	: V=0.985199941, theta=-13.8631297 -> V=0.975, theta=0.0
% INFO    : Bus 6017	: V=1.05510797, theta=1.98703474 -> V=0.975, theta=0.0
% INFO    : Bus 6018	: V=1.08008963, theta=-9.70305239 -> V=0.975, theta=0.0
% INFO    : Bus 6019	: V=1.08603341, theta=-11.1554107 -> V=0.975, theta=0.0
% INFO    : Bus 6020	: V=1.08822798, theta=12.9246186 -> V=0.975, theta=0.0
% INFO    : Bus 6021	: V=1.08843258, theta=12.938376 -> V=0.975, theta=0.0
% INFO    : Bus 6022	: V=1.079, theta=3.40850712 -> V=0.975, theta=0.0
% INFO    : Bus 6023	: V=1.07474136, theta=2.51719836 -> V=0.975, theta=0.0
% INFO    : Bus 6024	: V=1.105, theta=6.02537603 -> V=0.975, theta=0.0
% INFO    : Bus 6025	: V=1.1006149, theta=5.46762527 -> V=0.975, theta=0.0
% INFO    : Bus 6026	: V=1.0389189, theta=11.3919858 -> V=0.975, theta=0.0
% INFO    : Bus 6027	: V=1.013, theta=19.150475 -> V=0.975, theta=0.0
% INFO    : Bus 6028	: V=1.05368736, theta=13.0659855 -> V=0.975, theta=0.0
% INFO    : Bus 6029	: V=1.05863045, theta=10.9069735 -> V=0.975, theta=0.0
% INFO    : Bus 6030	: V=1.054, theta=5.31949841 -> V=0.975, theta=0.0
% INFO    : Bus 6031	: V=1.06113304, theta=11.8693311 -> V=0.975, theta=0.0
% INFO    : Bus 6032	: V=1.0536931, theta=1.44618346 -> V=0.975, theta=0.0
% INFO    : Bus 6033	: V=1.06450483, theta=0.623286118 -> V=0.975, theta=0.0
% INFO    : Bus 6034	: V=1.07883911, theta=-2.8240923 -> V=0.975, theta=0.0
% INFO    : Bus 6035	: V=1.08973297, theta=-1.4136352 -> V=0.975, theta=0.0
% INFO    : Bus 6036	: V=1.10288194, theta=1.49452482 -> V=0.975, theta=0.0
% INFO    : Bus 6037	: V=1.04655686, theta=10.7092458 -> V=0.975, theta=0.0
% INFO    : Bus 6038	: V=1.05150812, theta=-10.299784 -> V=0.975, theta=0.0
% INFO    : Bus 6039	: V=1.09601983, theta=2.30299638 -> V=0.975, theta=0.0
% INFO    : Bus 6040	: V=1.04902695, theta=9.53876138 -> V=0.975, theta=0.0
% INFO    : Bus 6041	: V=1.04, theta=11.6597687 -> V=0.975, theta=0.0
% INFO    : Bus 6042	: V=1.09189906, theta=10.5328457 -> V=0.975, theta=0.0
% INFO    : Bus 6043	: V=1.09257505, theta=10.180054 -> V=0.975, theta=0.0
% INFO    : Bus 6044	: V=1.06050904, theta=13.7625777 -> V=0.975, theta=0.0
% INFO    : Bus 6045	: V=1.04271111, theta=-14.9484058 -> V=0.975, theta=0.0
% INFO    : Bus 6046	: V=1.10132785, theta=-2.4728798 -> V=0.975, theta=0.0
% INFO    : Bus 6047	: V=1.04488835, theta=-7.80914482 -> V=0.975, theta=0.0
% INFO    : Bus 6048	: V=1.09050946, theta=-4.68725887 -> V=0.975, theta=0.0
% INFO    : Bus 6049	: V=1.06044573, theta=-2.7026384 -> V=0.975, theta=0.0
% INFO    : Bus 6050	: V=1.10917378, theta=-6.79977428 -> V=0.975, theta=0.0
% INFO    : Bus 6051	: V=1.10442783, theta=-11.7916812 -> V=0.975, theta=0.0
% INFO    : Bus 6052	: V=1.06428034, theta=-10.6302467 -> V=0.975, theta=0.0
% INFO    : Bus 6053	: V=1.02427198, theta=-13.2836409 -> V=0.975, theta=0.0
% INFO    : Bus 6054	: V=1.0911568, theta=-7.06566495 -> V=0.975, theta=0.0
% INFO    : Bus 6055	: V=1.09846731, theta=-9.04508051 -> V=0.975, theta=0.0
% INFO    : Bus 6056	: V=1.048, theta=11.2428136 -> V=0.975, theta=0.0
% INFO    : Bus 6057	: V=1.10602381, theta=-11.97849 -> V=0.975, theta=0.0
% INFO    : Bus 6058	: V=1.08974334, theta=-4.93652257 -> V=0.975, theta=0.0
% INFO    : Bus 6059	: V=1.095, theta=-0.922876859 -> V=0.975, theta=0.0
% INFO    : Bus 6060	: V=1.06168324, theta=-3.11142472 -> V=0.975, theta=0.0
% INFO    : Bus 6061	: V=1.06168324, theta=-3.11142472 -> V=0.975, theta=0.0
% INFO    : Bus 6062	: V=1.06154767, theta=-3.64085787 -> V=0.975, theta=0.0
% INFO    : Bus 6063	: V=1.06097443, theta=-2.37932665 -> V=0.975, theta=0.0
% INFO    : Bus 6064	: V=1.05515889, theta=1.9764045 -> V=0.975, theta=0.0
% INFO    : Bus 6065	: V=1.05501451, theta=1.97479004 -> V=0.975, theta=0.0
% INFO    : Bus 6066	: V=1.0844116, theta=5.5663532 -> V=0.975, theta=0.0
% INFO    : Bus 6067	: V=1.065, theta=5.35670709 -> V=0.975, theta=0.0
% INFO    : Bus 6068	: V=1.10612858, theta=-4.66271541 -> V=0.975, theta=0.0
% INFO    : Bus 6069	: V=1.10624374, theta=-4.67124074 -> V=0.975, theta=0.0
% INFO    : Bus 6070	: V=1.10185474, theta=-3.77732035 -> V=0.975, theta=0.0
% INFO    : Bus 6071	: V=1.05437838, theta=14.3113971 -> V=0.975, theta=0.0
% INFO    : Bus 6072	: V=1.06841917, theta=15.1824918 -> V=0.975, theta=0.0
% INFO    : Bus 6073	: V=1.08175414, theta=-9.55437648 -> V=0.975, theta=0.0
% INFO    : Bus 6074	: V=1.07282746, theta=-7.49751138 -> V=0.975, theta=0.0
% INFO    : Bus 6075	: V=1.10009695, theta=-7.18051036 -> V=0.975, theta=0.0
% INFO    : Bus 6076	: V=1.04631021, theta=-4.52833421 -> V=0.975, theta=0.0
% INFO    : Bus 6077	: V=1.07382777, theta=-4.9622162 -> V=0.975, theta=0.0
% INFO    : Bus 6078	: V=1.07261962, theta=-3.15476699 -> V=0.975, theta=0.0
% INFO    : Bus 6079	: V=1.07325905, theta=-10.387014 -> V=0.975, theta=0.0
% INFO    : Bus 6080	: V=1.06588063, theta=14.1580718 -> V=0.975, theta=0.0
% INFO    : Bus 6081	: V=1.10533062, theta=4.1868705 -> V=0.975, theta=0.0
% INFO    : Bus 6082	: V=1.04948971, theta=-12.1297381 -> V=0.975, theta=0.0
% INFO    : Bus 6083	: V=1.0943305, theta=-11.0426704 -> V=0.975, theta=0.0
% INFO    : Bus 6084	: V=1.10308876, theta=-3.86823781 -> V=0.975, theta=0.0
% INFO    : Bus 6085	: V=1.10131896, theta=7.11644168 -> V=0.975, theta=0.0
% INFO    : Bus 6086	: V=1.04350634, theta=-10.412097 -> V=0.975, theta=0.0
% INFO    : Bus 6087	: V=1.09424261, theta=-9.28232454 -> V=0.975, theta=0.0
% INFO    : Bus 6088	: V=1.0228005, theta=-14.545083 -> V=0.975, theta=0.0
% INFO    : Bus 6089	: V=1.10508535, theta=7.38190994 -> V=0.975, theta=0.0
% INFO    : Bus 6090	: V=1.10508532, theta=7.3819112 -> V=0.975, theta=0.0
% INFO    : Bus 6091	: V=1.08, theta=15.4904516 -> V=0.975, theta=0.0
% INFO    : Bus 6092	: V=1.04767638, theta=12.5505662 -> V=0.975, theta=0.0
% INFO    : Bus 6093	: V=1.066, theta=-3.54806373 -> V=0.975, theta=0.0
% INFO    : Bus 6094	: V=1.072, theta=-2.46763781 -> V=0.975, theta=0.0
% INFO    : Bus 6095	: V=1.099, theta=0.574719608 -> V=0.975, theta=0.0
% INFO    : Bus 6096	: V=1.10375139, theta=-0.80861316 -> V=0.975, theta=0.0
% INFO    : Bus 6097	: V=1.07503465, theta=1.72850735 -> V=0.975, theta=0.0
% INFO    : Bus 6098	: V=1.06627768, theta=-4.08805102 -> V=0.975, theta=0.0
% INFO    : Bus 6099	: V=1.07577443, theta=-5.09869991 -> V=0.975, theta=0.0
% INFO    : Bus 6100	: V=1.07526839, theta=-3.15983306 -> V=0.975, theta=0.0
% INFO    : Bus 6101	: V=1.0976744, theta=0.379499118 -> V=0.975, theta=0.0
% INFO    : Bus 6102	: V=1.10202796, theta=-0.987979968 -> V=0.975, theta=0.0
% INFO    : Bus 6103	: V=1.10181842, theta=-8.89019869 -> V=0.975, theta=0.0
% INFO    : Bus 6104	: V=1.098, theta=1.13099458 -> V=0.975, theta=0.0
% INFO    : Bus 6105	: V=1.059, theta=13.5291498 -> V=0.975, theta=0.0
% INFO    : Bus 6106	: V=1.04579037, theta=-9.1674378 -> V=0.975, theta=0.0
% INFO    : Bus 6107	: V=1.0769691, theta=-8.40342581 -> V=0.975, theta=0.0
% INFO    : Bus 6108	: V=1.07055235, theta=-7.4562834 -> V=0.975, theta=0.0
% INFO    : Bus 6109	: V=1.04878554, theta=2.65174873 -> V=0.975, theta=0.0
% INFO    : Bus 6110	: V=1.04649574, theta=2.44571643 -> V=0.975, theta=0.0
% INFO    : Bus 6111	: V=1.05427037, theta=4.88159838 -> V=0.975, theta=0.0
% INFO    : Bus 6112	: V=1.10473992, theta=-4.72994972 -> V=0.975, theta=0.0
% INFO    : Bus 6113	: V=1.052, theta=11.7636113 -> V=0.975, theta=0.0
% INFO    : Bus 6114	: V=1.054, theta=11.4208259 -> V=0.975, theta=0.0
% INFO    : Bus 6115	: V=1.09168532, theta=-1.37030093 -> V=0.975, theta=0.0
% INFO    : Bus 6116	: V=1.08, theta=-8.67139658 -> V=0.975, theta=0.0
% INFO    : Bus 6117	: V=1.10348354, theta=-3.53619334 -> V=0.975, theta=0.0
% INFO    : Bus 6118	: V=1.10909168, theta=-5.12268246 -> V=0.975, theta=0.0
% INFO    : Bus 6119	: V=1.04523318, theta=2.36060206 -> V=0.975, theta=0.0
% INFO    : Bus 6120	: V=1.05901601, theta=17.5773942 -> V=0.975, theta=0.0
% INFO    : Bus 6121	: V=1.04073604, theta=2.38634861 -> V=0.975, theta=0.0
% INFO    : Bus 6122	: V=1.02862297, theta=-3.60549862 -> V=0.975, theta=0.0
% INFO    : Bus 6123	: V=1.10357992, theta=-3.19318344 -> V=0.975, theta=0.0
% INFO    : Bus 6124	: V=1.10141537, theta=-13.288242 -> V=0.975, theta=0.0
% INFO    : Bus 6125	: V=1.04997943, theta=3.15724089 -> V=0.975, theta=0.0
% INFO    : Bus 6126	: V=1.09727115, theta=-3.20697481 -> V=0.975, theta=0.0
% INFO    : Bus 6127	: V=1.097, theta=10.8085681 -> V=0.975, theta=0.0
% INFO    : Bus 6128	: V=1.06277816, theta=-3.26634969 -> V=0.975, theta=0.0
% INFO    : Bus 6129	: V=1.0558044, theta=-0.850598849 -> V=0.975, theta=0.0
% INFO    : Bus 6130	: V=1.05956273, theta=-3.44143719 -> V=0.975, theta=0.0
% INFO    : Bus 6131	: V=1.103, theta=-1.7620556 -> V=0.975, theta=0.0
% INFO    : Bus 6132	: V=1.04120558, theta=-15.0711121 -> V=0.975, theta=0.0
% INFO    : Bus 6133	: V=1.05940118, theta=-9.68113976 -> V=0.975, theta=0.0
% INFO    : Bus 6134	: V=1.075, theta=-9.55325316 -> V=0.975, theta=0.0
% INFO    : Bus 6135	: V=1.10321104, theta=-12.6135612 -> V=0.975, theta=0.0
% INFO    : Bus 6136	: V=1.04934199, theta=-5.90230734 -> V=0.975, theta=0.0
% INFO    : Bus 6137	: V=1.11170293, theta=-4.13788837 -> V=0.975, theta=0.0
% INFO    : Bus 6138	: V=1.09055461, theta=11.5809635 -> V=0.975, theta=0.0
% INFO    : Bus 6139	: V=1.09776252, theta=4.02267022 -> V=0.975, theta=0.0
% INFO    : Bus 6140	: V=1.083, theta=14.7053331 -> V=0.975, theta=0.0
% INFO    : Bus 6141	: V=1.06755827, theta=-7.58669845 -> V=0.975, theta=0.0
% INFO    : Bus 6142	: V=1.06687645, theta=-3.67782573 -> V=0.975, theta=0.0
% INFO    : Bus 6143	: V=1.05163817, theta=13.4606051 -> V=0.975, theta=0.0
% INFO    : Bus 6144	: V=1.04904431, theta=-7.21572546 -> V=0.975, theta=0.0
% INFO    : Bus 6145	: V=1.09330965, theta=11.0333898 -> V=0.975, theta=0.0
% INFO    : Bus 6146	: V=1.09711591, theta=-14.4476733 -> V=0.975, theta=0.0
% INFO    : Bus 6147	: V=1.09322403, theta=-1.87612908 -> V=0.975, theta=0.0
% INFO    : Bus 6148	: V=1.08474492, theta=16.330249 -> V=0.975, theta=0.0
% INFO    : Bus 6149	: V=1.02341664, theta=-12.5304338 -> V=0.975, theta=0.0
% INFO    : Bus 6150	: V=1.04491045, theta=-3.14335486 -> V=0.975, theta=0.0
% INFO    : Bus 6151	: V=1.10088278, theta=-1.94403362 -> V=0.975, theta=0.0
% INFO    : Bus 6152	: V=1.10508517, theta=7.38191427 -> V=0.975, theta=0.0
% INFO    : Bus 6153	: V=1.10773275, theta=-11.4607181 -> V=0.975, theta=0.0
% INFO    : Bus 6154	: V=1.0614808, theta=-8.53069911 -> V=0.975, theta=0.0
% INFO    : Bus 6155	: V=1.08616918, theta=-8.5880597 -> V=0.975, theta=0.0
% INFO    : Bus 6156	: V=1.078142, theta=-9.0485751 -> V=0.975, theta=0.0
% INFO    : Bus 6157	: V=1.07879511, theta=-8.3931803 -> V=0.975, theta=0.0
% INFO    : Bus 6158	: V=1.07907075, theta=-8.97544792 -> V=0.975, theta=0.0
% INFO    : Bus 6159	: V=1.10192138, theta=-2.08259167 -> V=0.975, theta=0.0
% INFO    : Bus 6160	: V=1.06025511, theta=-2.83221673 -> V=0.975, theta=0.0
% INFO    : Bus 6161	: V=1.09872808, theta=-3.55000318 -> V=0.975, theta=0.0
% INFO    : Bus 6162	: V=1.10099839, theta=7.11807054 -> V=0.975, theta=0.0
% INFO    : Bus 6163	: V=1.092, theta=-11.1641934 -> V=0.975, theta=0.0
% INFO    : Bus 6164	: V=0.860487437, theta=-23.9433812 -> V=0.975, theta=0.0
% INFO    : Bus 6165	: V=1.0618513, theta=-9.74285387 -> V=0.975, theta=0.0
% INFO    : Bus 6166	: V=1.08, theta=-9.15587141 -> V=0.975, theta=0.0
% INFO    : Bus 6167	: V=1.10682978, theta=-7.22503618 -> V=0.975, theta=0.0
% INFO    : Bus 6168	: V=1.10810838, theta=-9.23591269 -> V=0.975, theta=0.0
% INFO    : Bus 6169	: V=1.02675852, theta=-13.6103161 -> V=0.975, theta=0.0
% INFO    : Bus 6170	: V=1.09913762, theta=-13.5712188 -> V=0.975, theta=0.0
% INFO    : Bus 6171	: V=1.0554786, theta=1.03005637 -> V=0.975, theta=0.0
% INFO    : Bus 6172	: V=1.06781914, theta=-11.5400223 -> V=0.975, theta=0.0
% INFO    : Bus 6173	: V=1.086, theta=17.3969774 -> V=0.975, theta=0.0
% INFO    : Bus 6174	: V=1.0415172, theta=-10.0910141 -> V=0.975, theta=0.0
% INFO    : Bus 6175	: V=1.072, theta=-8.62885973 -> V=0.975, theta=0.0
% INFO    : Bus 6176	: V=1.09419677, theta=-8.40609198 -> V=0.975, theta=0.0
% INFO    : Bus 6177	: V=1.09779188, theta=-2.36298111 -> V=0.975, theta=0.0
% INFO    : Bus 6178	: V=1.04176612, theta=-7.97976994 -> V=0.975, theta=0.0
% INFO    : Bus 6179	: V=1.04611057, theta=-6.59088729 -> V=0.975, theta=0.0
% INFO    : Bus 6180	: V=1.04920994, theta=-9.66299429 -> V=0.975, theta=0.0
% INFO    : Bus 6181	: V=1.09969129, theta=-6.80757342 -> V=0.975, theta=0.0
% INFO    : Bus 6182	: V=1.03311134, theta=-14.4406939 -> V=0.975, theta=0.0
% INFO    : Bus 6183	: V=1.07651168, theta=14.3351935 -> V=0.975, theta=0.0
% INFO    : Bus 6184	: V=1.0243887, theta=-11.6184307 -> V=0.975, theta=0.0
% INFO    : Bus 6185	: V=1.08505792, theta=-9.30567124 -> V=0.975, theta=0.0
% INFO    : Bus 6186	: V=1.07661303, theta=-3.63213425 -> V=0.975, theta=0.0
% INFO    : Bus 6187	: V=1.10831361, theta=-3.47352555 -> V=0.975, theta=0.0
% INFO    : Bus 6188	: V=1.07146972, theta=13.349262 -> V=0.975, theta=0.0
% INFO    : Bus 6189	: V=1.109, theta=-5.94039957 -> V=0.975, theta=0.0
% INFO    : Bus 6190	: V=1.10000283, theta=-9.87743258 -> V=0.975, theta=0.0
% INFO    : Bus 6191	: V=1.07787179, theta=-9.78501511 -> V=0.975, theta=0.0
% INFO    : Bus 6192	: V=1.0198383, theta=-14.365905 -> V=0.975, theta=0.0
% INFO    : Bus 6193	: V=1.0329334, theta=-16.6078481 -> V=0.975, theta=0.0
% INFO    : Bus 6194	: V=1.11053152, theta=-4.53937861 -> V=0.975, theta=0.0
% INFO    : Bus 6195	: V=1.10818715, theta=-10.9359446 -> V=0.975, theta=0.0
% INFO    : Bus 6196	: V=1.062, theta=-4.2841522 -> V=0.975, theta=0.0
% INFO    : Bus 6197	: V=1.10942076, theta=-4.98904985 -> V=0.975, theta=0.0
% INFO    : Bus 6198	: V=1.01467809, theta=-20.8286069 -> V=0.975, theta=0.0
% INFO    : Bus 6199	: V=1.00657138, theta=-1.88243762 -> V=0.975, theta=0.0
% INFO    : Bus 6200	: V=1.04570082, theta=9.25778025 -> V=0.975, theta=0.0
% INFO    : Bus 6201	: V=1.06827742, theta=14.1788948 -> V=0.975, theta=0.0
% INFO    : Bus 6202	: V=1.01002243, theta=18.569341 -> V=0.975, theta=0.0
% INFO    : Bus 6203	: V=1.01002243, theta=18.569341 -> V=0.975, theta=0.0
% INFO    : Bus 6204	: V=1.05277428, theta=-1.98339149 -> V=0.975, theta=0.0
% INFO    : Bus 6205	: V=1.18272211, theta=-20.8525514 -> V=0.995655, theta=0.0
% INFO    : Bus 6206	: V=1.07208529, theta=-8.61750067 -> V=0.975, theta=0.0
% INFO    : Bus 6207	: V=1.06713439, theta=10.8097778 -> V=0.975, theta=0.0
% INFO    : Bus 6208	: V=1.05208057, theta=10.7851893 -> V=0.975, theta=0.0
% INFO    : Bus 6209	: V=1.05229765, theta=11.3227835 -> V=0.975, theta=0.0
% INFO    : Bus 6210	: V=1.04896988, theta=3.18894899 -> V=0.975, theta=0.0
% INFO    : Bus 6211	: V=1.06071274, theta=-2.47396235 -> V=0.975, theta=0.0
% INFO    : Bus 6212	: V=1.0536513, theta=2.10207378 -> V=0.975, theta=0.0
% INFO    : Bus 6213	: V=1.09819027, theta=-2.36590312 -> V=0.975, theta=0.0
% INFO    : Bus 6214	: V=1.04486143, theta=-7.81226552 -> V=0.975, theta=0.0
% INFO    : Bus 6215	: V=1.09846727, theta=0.558794192 -> V=0.975, theta=0.0
% INFO    : Bus 6216	: V=1.06576236, theta=5.25458148 -> V=0.975, theta=0.0
% INFO    : Bus 6217	: V=1.07615526, theta=-9.30082344 -> V=0.975, theta=0.0
% INFO    : Bus 6218	: V=1.09602535, theta=0.732238664 -> V=0.975, theta=0.0
% INFO    : Bus 6219	: V=1.1, theta=-13.1235413 -> V=0.975, theta=0.0
% INFO    : Bus 6220	: V=1.041, theta=11.440118 -> V=0.975, theta=0.0
% INFO    : Bus 6221	: V=1.09430048, theta=10.7394843 -> V=0.975, theta=0.0
% INFO    : Bus 6222	: V=1.06568297, theta=-9.52283802 -> V=0.975, theta=0.0
% INFO    : Bus 6223	: V=1.097, theta=-2.92776918 -> V=0.975, theta=0.0
% INFO    : Bus 6224	: V=1.05546175, theta=6.99813939 -> V=0.975, theta=0.0
% INFO    : Bus 6225	: V=1.0495018, theta=5.79399138 -> V=0.975, theta=0.0
% INFO    : Bus 6226	: V=1.06734141, theta=-11.5345049 -> V=0.975, theta=0.0
% INFO    : Bus 6227	: V=1.077, theta=-9.83789016 -> V=0.975, theta=0.0
% INFO    : Bus 6228	: V=1.05117674, theta=1.92114825 -> V=0.975, theta=0.0
% INFO    : Bus 6229	: V=1.05006438, theta=1.82823497 -> V=0.975, theta=0.0
% INFO    : Bus 6230	: V=1.0650077, theta=-10.099622 -> V=0.975, theta=0.0
% INFO    : Bus 6231	: V=1.06538669, theta=-7.83510447 -> V=0.975, theta=0.0
% INFO    : Bus 6232	: V=1.083, theta=-9.72798168 -> V=0.975, theta=0.0
% INFO    : Bus 6233	: V=1.0320104, theta=-13.381095 -> V=0.975, theta=0.0
% INFO    : Bus 6234	: V=1.07907926, theta=-12.1304289 -> V=0.975, theta=0.0
% INFO    : Bus 6235	: V=1.04427104, theta=-14.2907618 -> V=0.975, theta=0.0
% INFO    : Bus 6236	: V=1.08006146, theta=-12.0956519 -> V=0.975, theta=0.0
% INFO    : Bus 6237	: V=1.1001415, theta=-4.72061565 -> V=0.975, theta=0.0
% INFO    : Bus 6238	: V=1.09999361, theta=0.305312713 -> V=0.975, theta=0.0
% INFO    : Bus 6239	: V=1.06502076, theta=-9.54773853 -> V=0.975, theta=0.0
% INFO    : Bus 6240	: V=1.089, theta=-11.007502 -> V=0.975, theta=0.0
% INFO    : Bus 6241	: V=1.0986734, theta=3.12042909 -> V=0.975, theta=0.0
% INFO    : Bus 6242	: V=1.1021693, theta=-6.6438334 -> V=0.975, theta=0.0
% INFO    : Bus 6243	: V=1.10546287, theta=-6.30139966 -> V=0.975, theta=0.0
% INFO    : Bus 6244	: V=1.08421997, theta=-7.88181634 -> V=0.975, theta=0.0
% INFO    : Bus 6245	: V=1.10274636, theta=-6.31280427 -> V=0.975, theta=0.0
% INFO    : Bus 6246	: V=1.09433694, theta=-6.14669229 -> V=0.975, theta=0.0
% INFO    : Bus 6247	: V=1.03326949, theta=-13.9413673 -> V=0.975, theta=0.0
% INFO    : Bus 6248	: V=1.074, theta=-8.7090291 -> V=0.975, theta=0.0
% INFO    : Bus 6249	: V=1.06837517, theta=-1.46795209 -> V=0.975, theta=0.0
% INFO    : Bus 6250	: V=1.07053279, theta=-1.83964233 -> V=0.975, theta=0.0
% INFO    : Bus 6251	: V=1.09467982, theta=6.16091697 -> V=0.975, theta=0.0
% INFO    : Bus 6252	: V=1.04770433, theta=6.73594887 -> V=0.975, theta=0.0
% INFO    : Bus 6253	: V=1.05256574, theta=6.31846928 -> V=0.975, theta=0.0
% INFO    : Bus 6254	: V=1.04883115, theta=-10.4826248 -> V=0.975, theta=0.0
% INFO    : Bus 6255	: V=1.06390207, theta=14.5775866 -> V=0.975, theta=0.0
% INFO    : Bus 6256	: V=0.993, theta=-5.0444808 -> V=0.975, theta=0.0
% INFO    : Bus 6257	: V=0.969624136, theta=-5.04325504 -> V=0.975, theta=0.0
% INFO    : Bus 6258	: V=1.072, theta=-22.7149665 -> V=0.975, theta=0.0
% INFO    : Bus 6259	: V=0.995, theta=-13.4427094 -> V=0.975, theta=0.0
% INFO    : Bus 6260	: V=0.937578999, theta=-19.4736199 -> V=0.975, theta=0.0
% INFO    : Bus 6261	: V=1.074, theta=-7.79083556 -> V=0.975, theta=0.0
% INFO    : Bus 6262	: V=1.074, theta=-7.79083556 -> V=0.975, theta=0.0
% INFO    : Bus 6263	: V=1.058, theta=-7.63555755 -> V=0.975, theta=0.0
% INFO    : Bus 6264	: V=1.058, theta=-7.83209993 -> V=0.975, theta=0.0
% INFO    : Bus 6265	: V=0.983, theta=-0.762515913 -> V=0.975, theta=0.0
% INFO    : Bus 6266	: V=0.979, theta=-3.15639821 -> V=0.975, theta=0.0
% INFO    : Bus 6267	: V=1.037, theta=0.458187594 -> V=0.975, theta=0.0
% INFO    : Bus 6268	: V=1.035, theta=-0.271065268 -> V=0.975, theta=0.0
% INFO    : Bus 6269	: V=0.951, theta=0.238878557 -> V=0.975, theta=0.0
% INFO    : Bus 6270	: V=0.954, theta=0.753773363 -> V=0.975, theta=0.0
% INFO    : Bus 6271	: V=1.044, theta=-2.09518592 -> V=0.975, theta=0.0
% INFO    : Bus 6272	: V=1.044, theta=-1.80341604 -> V=0.975, theta=0.0
% INFO    : Bus 6273	: V=1.043, theta=-1.80784706 -> V=0.975, theta=0.0
% INFO    : Bus 6274	: V=1.042, theta=-2.05467632 -> V=0.975, theta=0.0
% INFO    : Bus 6276	: V=1.004, theta=11.0966982 -> V=0.975, theta=0.0
% INFO    : Bus 6277	: V=1.007, theta=11.0395689 -> V=0.975, theta=0.0
% INFO    : Bus 6278	: V=1.032, theta=11.3565114 -> V=0.975, theta=0.0
% INFO    : Bus 6279	: V=1.032, theta=6.35662928 -> V=0.975, theta=0.0
% INFO    : Bus 6280	: V=1.02663721, theta=6.35662928 -> V=0.975, theta=0.0
% INFO    : Bus 6281	: V=1.015, theta=-1.40378912 -> V=0.975, theta=0.0
% INFO    : Bus 6282	: V=1.017, theta=-0.856431727 -> V=0.975, theta=0.0
% INFO    : Bus 6283	: V=1.015, theta=-1.40378912 -> V=0.975, theta=0.0
% INFO    : Bus 6284	: V=1.017, theta=-0.856431727 -> V=0.975, theta=0.0
% INFO    : Bus 6285	: V=1.017, theta=-0.856431727 -> V=0.975, theta=0.0
% INFO    : Bus 6286	: V=0.992, theta=-0.889388669 -> V=0.975, theta=0.0
% INFO    : Bus 6287	: V=0.962, theta=-5.16501141 -> V=0.975, theta=0.0
% INFO    : Bus 6288	: V=0.995, theta=-4.71715452 -> V=0.975, theta=0.0
% INFO    : Bus 6289	: V=0.982, theta=-2.9702125 -> V=0.975, theta=0.0
% INFO    : Bus 6290	: V=0.99, theta=4.42165353 -> V=0.975, theta=0.0
% INFO    : Bus 6291	: V=0.991, theta=4.42431309 -> V=0.975, theta=0.0
% INFO    : Bus 6292	: V=0.992, theta=4.27611081 -> V=0.975, theta=0.0
% INFO    : Bus 6293	: V=0.991, theta=4.05874947 -> V=0.975, theta=0.0
% INFO    : Bus 6294	: V=0.992, theta=4.31769869 -> V=0.975, theta=0.0
% INFO    : Bus 6295	: V=0.992, theta=4.30071807 -> V=0.975, theta=0.0
% INFO    : Bus 6296	: V=1.038, theta=-9.36973917 -> V=0.975, theta=0.0
% INFO    : Bus 6297	: V=1.038, theta=-9.26473084 -> V=0.975, theta=0.0
% INFO    : Bus 6298	: V=1.038, theta=-9.26473084 -> V=0.975, theta=0.0
% INFO    : Bus 6299	: V=1.037, theta=-9.34263436 -> V=0.975, theta=0.0
% INFO    : Bus 6300	: V=1.037, theta=-9.34263436 -> V=0.975, theta=0.0
% INFO    : Bus 6301	: V=1.037, theta=-9.34263436 -> V=0.975, theta=0.0
% INFO    : Bus 6302	: V=1.018, theta=-14.8986201 -> V=0.975, theta=0.0
% INFO    : Bus 6303	: V=1.018, theta=-14.8986201 -> V=0.975, theta=0.0
% INFO    : Bus 6304	: V=1.0, theta=18.7972791 -> V=0.975, theta=0.0
% INFO    : Bus 6305	: V=1.006, theta=19.5324535 -> V=0.975, theta=0.0
% INFO    : Bus 6306	: V=1.005, theta=19.782624 -> V=0.975, theta=0.0
% INFO    : Bus 6307	: V=1.096, theta=-12.724348 -> V=0.975, theta=0.0
% INFO    : Bus 6308	: V=1.026, theta=-32.9065774 -> V=0.975, theta=0.0
% INFO    : Bus 6309	: V=1.004, theta=-9.07173576 -> V=0.975, theta=0.0
% INFO    : Bus 6311	: V=1.003, theta=-9.01039171 -> V=0.975, theta=0.0
% INFO    : Bus 6312	: V=1.004, theta=-9.03907845 -> V=0.975, theta=0.0
% INFO    : Bus 6313	: V=1.02, theta=19.0302345 -> V=0.975, theta=0.0
% INFO    : Bus 6314	: V=1.022, theta=18.6626331 -> V=0.975, theta=0.0
% INFO    : Bus 6315	: V=1.017, theta=1.79033901 -> V=0.975, theta=0.0
% INFO    : Bus 6316	: V=1.015, theta=1.59900083 -> V=0.975, theta=0.0
% INFO    : Bus 6317	: V=0.992, theta=-9.70152305 -> V=0.975, theta=0.0
% INFO    : Bus 6318	: V=0.994, theta=-9.62936371 -> V=0.975, theta=0.0
% INFO    : Bus 6319	: V=1.019, theta=-9.79635703 -> V=0.975, theta=0.0
% INFO    : Bus 6320	: V=0.988089154, theta=-30.8278588 -> V=0.975, theta=0.0
% INFO    : Bus 6321	: V=1.001, theta=-24.4286396 -> V=0.975, theta=0.0
% INFO    : Bus 6322	: V=1.0, theta=-24.6790867 -> V=0.975, theta=0.0
% INFO    : Bus 6324	: V=0.986228469, theta=-27.6111831 -> V=0.975, theta=0.0
% INFO    : Bus 6325	: V=0.992, theta=-0.722044655 -> V=0.975, theta=0.0
% INFO    : Bus 6326	: V=0.992, theta=-0.864664531 -> V=0.975, theta=0.0
% INFO    : Bus 6327	: V=0.992, theta=-0.577947021 -> V=0.975, theta=0.0
% INFO    : Bus 6328	: V=0.992, theta=-0.577947021 -> V=0.975, theta=0.0
% INFO    : Bus 6329	: V=0.992, theta=-0.722044655 -> V=0.975, theta=0.0
% INFO    : Bus 6330	: V=0.992, theta=-1.00868879 -> V=0.975, theta=0.0
% INFO    : Bus 6331	: V=1.004, theta=8.85165877 -> V=0.975, theta=0.0
% INFO    : Bus 6332	: V=1.006, theta=8.91865498 -> V=0.975, theta=0.0
% INFO    : Bus 6333	: V=1.008, theta=8.883379 -> V=0.975, theta=0.0
% INFO    : Bus 6334	: V=1.007, theta=8.64194471 -> V=0.975, theta=0.0
% INFO    : Bus 6335	: V=1.004, theta=-10.4469297 -> V=0.975, theta=0.0
% INFO    : Bus 6336	: V=1.004, theta=-10.3421547 -> V=0.975, theta=0.0
% INFO    : Bus 6337	: V=0.950209737, theta=-19.600239 -> V=0.975, theta=0.0
% INFO    : Bus 6338	: V=0.978925134, theta=-19.6002631 -> V=0.975, theta=0.0
% INFO    : Bus 6339	: V=1.021, theta=2.82082778 -> V=0.975, theta=0.0
% INFO    : Bus 6340	: V=0.999, theta=1.54581863 -> V=0.975, theta=0.0
% INFO    : Bus 6341	: V=0.998, theta=1.55260989 -> V=0.975, theta=0.0
% INFO    : Bus 6342	: V=0.997, theta=1.6123226 -> V=0.975, theta=0.0
% INFO    : Bus 6343	: V=0.997, theta=1.72579149 -> V=0.975, theta=0.0
% INFO    : Bus 6344	: V=1.03372926, theta=-18.231278 -> V=0.975, theta=0.0
% INFO    : Bus 6345	: V=1.042, theta=-3.44546276 -> V=0.975, theta=0.0
% INFO    : Bus 6346	: V=1.044, theta=-3.82270503 -> V=0.975, theta=0.0
% INFO    : Bus 6347	: V=1.014, theta=-6.47107549 -> V=0.975, theta=0.0
% INFO    : Bus 6348	: V=1.03, theta=-5.65744802 -> V=0.975, theta=0.0
% INFO    : Bus 6349	: V=1.026, theta=-6.09000265 -> V=0.975, theta=0.0
% INFO    : Bus 6350	: V=1.028, theta=-5.12732216 -> V=0.975, theta=0.0
% INFO    : Bus 6351	: V=1.033, theta=-4.91510203 -> V=0.975, theta=0.0
% INFO    : Bus 6352	: V=1.028, theta=-2.58023742 -> V=0.975, theta=0.0
% INFO    : Bus 6353	: V=1.03, theta=-2.94816532 -> V=0.975, theta=0.0
% INFO    : Bus 6354	: V=0.978, theta=-19.6485763 -> V=0.975, theta=0.0
% INFO    : Bus 6355	: V=1.007, theta=-10.2112667 -> V=0.975, theta=0.0
% INFO    : Bus 6356	: V=1.011, theta=11.6402242 -> V=0.975, theta=0.0
% INFO    : Bus 6357	: V=1.009, theta=11.6609234 -> V=0.975, theta=0.0
% INFO    : Bus 6358	: V=1.009, theta=11.6816983 -> V=0.975, theta=0.0
% INFO    : Bus 6359	: V=1.007, theta=11.7976249 -> V=0.975, theta=0.0
% INFO    : Bus 6360	: V=1.007, theta=11.7058352 -> V=0.975, theta=0.0
% INFO    : Bus 6361	: V=1.012, theta=11.1152192 -> V=0.975, theta=0.0
% INFO    : Bus 6362	: V=1.018, theta=-0.747898745 -> V=0.975, theta=0.0
% INFO    : Bus 6363	: V=0.997011603, theta=-32.4349259 -> V=0.975, theta=0.0
% INFO    : Bus 6364	: V=1.043, theta=-6.62039958 -> V=0.975, theta=0.0
% INFO    : Bus 6365	: V=1.00007186, theta=-11.7995504 -> V=0.975, theta=0.0
% INFO    : Bus 6366	: V=0.985175453, theta=-10.2898511 -> V=0.975, theta=0.0
% INFO    : Bus 6368	: V=0.967, theta=-0.318335309 -> V=0.975, theta=0.0
% INFO    : Bus 6369	: V=1.043, theta=-19.2126293 -> V=0.975, theta=0.0
% INFO    : Bus 6370	: V=1.061, theta=-6.27162002 -> V=0.975, theta=0.0
% INFO    : Bus 6371	: V=1.061, theta=-6.53124855 -> V=0.975, theta=0.0
% INFO    : Bus 6372	: V=1.028, theta=-11.978333 -> V=0.975, theta=0.0
% INFO    : Bus 6373	: V=1.002, theta=-1.54058498 -> V=0.975, theta=0.0
% INFO    : Bus 6374	: V=1.003, theta=-1.36793444 -> V=0.975, theta=0.0
% INFO    : Bus 6375	: V=1.003, theta=-1.36793444 -> V=0.975, theta=0.0
% INFO    : Bus 6376	: V=1.003, theta=-1.36793444 -> V=0.975, theta=0.0
% INFO    : Bus 6377	: V=0.962, theta=-3.704672 -> V=0.975, theta=0.0
% INFO    : Bus 6378	: V=0.984, theta=-14.1513293 -> V=0.975, theta=0.0
% INFO    : Bus 6379	: V=1.01, theta=-2.48414056 -> V=0.975, theta=0.0
% INFO    : Bus 6380	: V=1.018, theta=0.0819680738 -> V=0.975, theta=0.0
% INFO    : Bus 6381	: V=1.017, theta=-1.1184171 -> V=0.975, theta=0.0
% INFO    : Bus 6382	: V=1.011, theta=-2.35005628 -> V=0.975, theta=0.0
% INFO    : Bus 6383	: V=1.042, theta=-12.1187175 -> V=0.975, theta=0.0
% INFO    : Bus 6384	: V=1.042, theta=-12.1187175 -> V=0.975, theta=0.0
% INFO    : Bus 6385	: V=1.043, theta=-12.2932295 -> V=0.975, theta=0.0
% INFO    : Bus 6386	: V=1.027, theta=-13.2239387 -> V=0.975, theta=0.0
% INFO    : Bus 6387	: V=0.994, theta=11.6586922 -> V=0.975, theta=0.0
% INFO    : Bus 6388	: V=0.994, theta=11.199043 -> V=0.975, theta=0.0
% INFO    : Bus 6389	: V=0.914, theta=-20.9671444 -> V=0.975, theta=0.0
% INFO    : Bus 6390	: V=1.002, theta=-12.7823931 -> V=0.975, theta=0.0
% INFO    : Bus 6391	: V=1.067, theta=-13.503579 -> V=0.975, theta=0.0
% INFO    : Bus 6392	: V=1.067, theta=-13.503579 -> V=0.975, theta=0.0
% INFO    : Bus 6393	: V=0.997938468, theta=-12.923998 -> V=0.975, theta=0.0
% INFO    : Bus 6394	: V=0.997938266, theta=-12.9239956 -> V=0.975, theta=0.0
% INFO    : Bus 6395	: V=0.985, theta=-4.22298891 -> V=0.975, theta=0.0
% INFO    : Bus 6396	: V=0.985, theta=-4.32178465 -> V=0.975, theta=0.0
% INFO    : Bus 6397	: V=1.056, theta=7.42150786 -> V=0.975, theta=0.0
% INFO    : Bus 6398	: V=1.03, theta=7.70028915 -> V=0.975, theta=0.0
% INFO    : Bus 6399	: V=1.006, theta=-19.3782847 -> V=0.975, theta=0.0
% INFO    : Bus 6400	: V=0.939247826, theta=-19.3781251 -> V=0.975, theta=0.0
% INFO    : Bus 6401	: V=1.015, theta=1.05243116 -> V=0.975, theta=0.0
% INFO    : Bus 6402	: V=1.029, theta=-11.4911412 -> V=0.975, theta=0.0
% INFO    : Bus 6403	: V=1.029, theta=-11.4911412 -> V=0.975, theta=0.0
% INFO    : Bus 6404	: V=1.004, theta=-1.97709177 -> V=0.975, theta=0.0
% INFO    : Bus 6405	: V=1.021, theta=7.19488222 -> V=0.975, theta=0.0
% INFO    : Bus 6406	: V=1.034, theta=7.0760137 -> V=0.975, theta=0.0
% INFO    : Bus 6407	: V=1.036, theta=6.5229358 -> V=0.975, theta=0.0
% INFO    : Bus 6408	: V=1.032, theta=6.99465327 -> V=0.975, theta=0.0
% INFO    : Bus 6409	: V=1.023, theta=-8.2762827 -> V=0.975, theta=0.0
% INFO    : Bus 6410	: V=1.028, theta=6.36954467 -> V=0.975, theta=0.0
% INFO    : Bus 6411	: V=1.03, theta=5.94992067 -> V=0.975, theta=0.0
% INFO    : Bus 6412	: V=0.97148234, theta=-13.5476342 -> V=0.975, theta=0.0
% INFO    : Bus 6413	: V=0.97148234, theta=-13.5476342 -> V=0.975, theta=0.0
% INFO    : Bus 6414	: V=0.971482504, theta=-13.5476342 -> V=0.975, theta=0.0
% INFO    : Bus 6415	: V=0.981244967, theta=-13.5476342 -> V=0.975, theta=0.0
% INFO    : Bus 6416	: V=0.998, theta=-9.38743419 -> V=0.975, theta=0.0
% INFO    : Bus 6417	: V=1.012, theta=-12.291521 -> V=0.975, theta=0.0
% INFO    : Bus 6418	: V=0.968, theta=-10.90909 -> V=0.975, theta=0.0
% INFO    : Bus 6419	: V=1.03, theta=-6.16791061 -> V=0.975, theta=0.0
% INFO    : Bus 6420	: V=1.032, theta=-4.69685706 -> V=0.975, theta=0.0
% INFO    : Bus 6421	: V=0.994, theta=-8.71281654 -> V=0.975, theta=0.0
% INFO    : Bus 6422	: V=1.03, theta=-8.18868347 -> V=0.975, theta=0.0
% INFO    : Bus 6423	: V=1.03, theta=-8.18968449 -> V=0.975, theta=0.0
% INFO    : Bus 6424	: V=1.002, theta=5.87535913 -> V=0.975, theta=0.0
% INFO    : Bus 6425	: V=1.081, theta=-33.5565132 -> V=0.975, theta=0.0
% INFO    : Bus 6426	: V=1.085, theta=-33.5560984 -> V=0.975, theta=0.0
% INFO    : Bus 6427	: V=1.085, theta=-33.5562456 -> V=0.975, theta=0.0
% INFO    : Bus 6428	: V=0.966, theta=1.72626984 -> V=0.975, theta=0.0
% INFO    : Bus 6429	: V=0.985417227, theta=-4.0465761 -> V=0.975, theta=0.0
% INFO    : Bus 6430	: V=0.966, theta=1.72626984 -> V=0.975, theta=0.0
% INFO    : Bus 6431	: V=0.985417227, theta=-4.0465761 -> V=0.975, theta=0.0
% INFO    : Bus 6432	: V=1.032, theta=-10.1910185 -> V=0.975, theta=0.0
% INFO    : Bus 6433	: V=1.05, theta=-11.0750429 -> V=0.975, theta=0.0
% INFO    : Bus 6434	: V=1.049, theta=-11.2467807 -> V=0.975, theta=0.0
% INFO    : Bus 6435	: V=1.03, theta=-12.6678871 -> V=0.975, theta=0.0
% INFO    : Bus 6436	: V=1.024, theta=-13.0802212 -> V=0.975, theta=0.0
% INFO    : Bus 6437	: V=0.976, theta=1.5686256 -> V=0.975, theta=0.0
% INFO    : Bus 6438	: V=0.976008405, theta=-9.77438604 -> V=0.975, theta=0.0
% INFO    : Bus 6439	: V=1.03, theta=-12.0148109 -> V=0.975, theta=0.0
% INFO    : Bus 6440	: V=1.031, theta=-11.0961884 -> V=0.975, theta=0.0
% INFO    : Bus 6441	: V=0.994, theta=7.15973593 -> V=0.975, theta=0.0
% INFO    : Bus 6442	: V=0.994, theta=7.01583617 -> V=0.975, theta=0.0
% INFO    : Bus 6443	: V=1.002, theta=12.4737842 -> V=0.975, theta=0.0
% INFO    : Bus 6444	: V=0.994, theta=13.2236641 -> V=0.975, theta=0.0
% INFO    : Bus 6445	: V=1.019, theta=19.3590829 -> V=0.975, theta=0.0
% INFO    : Bus 6446	: V=0.985, theta=10.621693 -> V=0.975, theta=0.0
% INFO    : Bus 6447	: V=1.056, theta=-12.5726969 -> V=0.975, theta=0.0
% INFO    : Bus 6448	: V=1.057, theta=-12.3148794 -> V=0.975, theta=0.0
% INFO    : Bus 6449	: V=0.931, theta=-5.04119185 -> V=0.975, theta=0.0
% INFO    : Bus 6450	: V=1.007, theta=-15.6158516 -> V=0.975, theta=0.0
% INFO    : Bus 6451	: V=1.0, theta=-3.81652088 -> V=0.975, theta=0.0
% INFO    : Bus 6452	: V=1.0, theta=-3.87104219 -> V=0.975, theta=0.0
% INFO    : Bus 6453	: V=1.051, theta=-13.1432727 -> V=0.975, theta=0.0
% INFO    : Bus 6454	: V=1.049, theta=-12.3891976 -> V=0.975, theta=0.0
% INFO    : Bus 6455	: V=1.049, theta=-12.3891976 -> V=0.975, theta=0.0
% INFO    : Bus 6456	: V=0.998, theta=5.52309261 -> V=0.975, theta=0.0
% INFO    : Bus 6457	: V=0.998, theta=5.62584996 -> V=0.975, theta=0.0
% INFO    : Bus 6458	: V=1.011, theta=-12.096274 -> V=0.975, theta=0.0
% INFO    : Bus 6459	: V=1.012, theta=-10.379972 -> V=0.975, theta=0.0
% INFO    : Bus 6460	: V=0.99, theta=10.8361561 -> V=0.975, theta=0.0
% INFO    : Bus 6461	: V=0.988, theta=10.4141125 -> V=0.975, theta=0.0
% INFO    : Bus 6462	: V=0.987, theta=10.8045455 -> V=0.975, theta=0.0
% INFO    : Bus 6463	: V=0.984, theta=11.304683 -> V=0.975, theta=0.0
% INFO    : Bus 6464	: V=1.02940228, theta=-14.6420569 -> V=0.975, theta=0.0
% INFO    : Bus 6465	: V=1.02940228, theta=-14.6420569 -> V=0.975, theta=0.0
% INFO    : Bus 6466	: V=1.02473811, theta=-14.7276568 -> V=0.975, theta=0.0
% INFO    : Bus 6467	: V=0.925, theta=-1.71257625 -> V=0.975, theta=0.0
% INFO    : Bus 6468	: V=0.925, theta=-1.71257625 -> V=0.975, theta=0.0
% INFO    : Bus 6469	: V=0.925, theta=-1.71257625 -> V=0.975, theta=0.0
% INFO    : Bus 6470	: V=1.011, theta=-10.9135332 -> V=0.975, theta=0.0
% INFO    : Bus 6471	: V=1.012, theta=-11.5847378 -> V=0.975, theta=0.0
% INFO    : Bus 6472	: V=1.088, theta=-5.14710346 -> V=0.975, theta=0.0
% INFO    : Bus 6473	: V=1.00545424, theta=-12.7641305 -> V=0.975, theta=0.0
% INFO    : Bus 6474	: V=1.00545424, theta=-12.7641305 -> V=0.975, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 4	: Vg=1.045 -> Vg=1.0111115
% INFO    : Gen at bus 4	: Vg=1.045 -> Vg=1.0111115
% INFO    : Gen at bus 5	: Pg=6.05, Qg=0.0 -> Pg=4.55, Qg=0.0
% INFO    : Gen at bus 5	: Vg=1.017 -> Vg=1.0079355
% INFO    : Gen at bus 11	: Vg=1.035 -> Vg=1.000001
% INFO    : Gen at bus 11	: Vg=1.035 -> Vg=1.000001
% INFO    : Gen at bus 17	: Pg=1.22, Qg=0.0 -> Pg=4.1, Qg=0.0
% INFO    : Gen at bus 17	: Vg=1.049 -> Vg=1.022224
% INFO    : Gen at bus 19	: Vg=1.02 -> Vg=0.999999
% INFO    : Gen at bus 22	: Vg=1.013 -> Vg=1.0158755
% INFO    : Gen at bus 24	: Vg=1.042 -> Vg=1.033333
% INFO    : Gen at bus 24	: Pg=0.18, Qg=0.0 -> Pg=17.75, Qg=0.0
% INFO    : Gen at bus 24	: Vg=1.042 -> Vg=1.033333
% INFO    : Gen at bus 25	: Pg=3.21, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 25	: Vg=1.074 -> Vg=1.022222
% INFO    : Gen at bus 25	: Vg=1.074 -> Vg=1.022222
% INFO    : Gen at bus 40	: Vg=1.063 -> Vg=1.027779
% INFO    : Gen at bus 47	: Pg=9.47, Qg=-5.96 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 47	: Vg=1.012 -> Vg=0.999999
% INFO    : Gen at bus 47	: Vg=1.012 -> Vg=0.999999
% INFO    : Gen at bus 48	: Pg=2.17, Qg=0.0 -> Pg=11.5, Qg=0.0
% INFO    : Gen at bus 48	: Vg=1.035 -> Vg=1.000001
% INFO    : Gen at bus 48	: Pg=1.17, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 48	: Vg=1.035 -> Vg=1.000001
% INFO    : Gen at bus 57	: Pg=0.0, Qg=1.0 -> Pg=6.5, Qg=0.95
% INFO    : Gen at bus 57	: Vg=1.051 -> Vg=1.0000025
% INFO    : Gen at bus 64	: Vg=1.075 -> Vg=0.9888895
% INFO    : Gen at bus 64	: Pg=1.19, Qg=0.0 -> Pg=13.8, Qg=0.0
% INFO    : Gen at bus 64	: Vg=1.075 -> Vg=0.9888895
% INFO    : Gen at bus 69	: Pg=7.25, Qg=0.0 -> Pg=15.02, Qg=0.0
% INFO    : Gen at bus 69	: Vg=1.042 -> Vg=1.0079355
% INFO    : Gen at bus 70	: Pg=3.27, Qg=0.0 -> Pg=11.5, Qg=0.0
% INFO    : Gen at bus 70	: Vg=1.015 -> Vg=1.0158755
% INFO    : Gen at bus 85	: Vg=1.034 -> Vg=0.999999
% INFO    : Gen at bus 86	: Pg=2.76, Qg=0.0 -> Pg=4.6, Qg=0.0
% INFO    : Gen at bus 86	: Vg=1.021 -> Vg=1.022224
% INFO    : Gen at bus 102	: Pg=19.07, Qg=-3.5 -> Pg=23.0, Qg=6.0
% INFO    : Gen at bus 102	: Vg=1.026 -> Vg=1.0158755
% INFO    : Gen at bus 122	: Pg=7.97, Qg=-1.18 -> Pg=6.0, Qg=1.5
% INFO    : Gen at bus 122	: Vg=1.026 -> Vg=1.0158755
% INFO    : Gen at bus 124	: Pg=1.36, Qg=0.0 -> Pg=4.5, Qg=0.0
% INFO    : Gen at bus 124	: Vg=1.038 -> Vg=1.022224
% INFO    : Gen at bus 125	: Pg=6.12, Qg=0.0 -> Pg=13.0, Qg=0.0
% INFO    : Gen at bus 125	: Vg=1.037 -> Vg=1.0158755
% INFO    : Gen at bus 125	: Pg=1.12, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 125	: Vg=1.037 -> Vg=1.0158755
% INFO    : Gen at bus 132	: Pg=7.12, Qg=1.99 -> Pg=8.5, Qg=0.0
% INFO    : Gen at bus 132	: Vg=1.065 -> Vg=1.000001
% INFO    : Gen at bus 132	: Vg=1.065 -> Vg=1.000001
% INFO    : Gen at bus 132	: Vg=1.065 -> Vg=1.000001
% INFO    : Gen at bus 132	: Vg=1.065 -> Vg=1.000001
% INFO    : Gen at bus 137	: Vg=1.032 -> Vg=1.015872
% INFO    : Gen at bus 137	: Pg=4.0, Qg=-0.8 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 137	: Vg=1.032 -> Vg=1.015872
% INFO    : Gen at bus 155	: Vg=0.971 -> Vg=1.0000025
% INFO    : Gen at bus 158	: Pg=7.05, Qg=1.44 -> Pg=8.95, Qg=-1.5
% INFO    : Gen at bus 158	: Vg=0.947 -> Vg=0.9444445
% INFO    : Gen at bus 158	: Vg=0.947 -> Vg=0.9444445
% INFO    : Gen at bus 177	: Vg=1.073 -> Vg=1.0
% INFO    : Gen at bus 190	: Vg=1.009 -> Vg=1.0000025
% INFO    : Gen at bus 190	: Vg=1.009 -> Vg=1.0000025
% INFO    : Gen at bus 192	: Vg=0.939 -> Vg=0.9444445
% INFO    : Gen at bus 194	: Vg=1.05 -> Vg=1.0000025
% INFO    : Gen at bus 196	: Pg=2.44, Qg=0.9 -> Pg=7.5, Qg=0.95
% INFO    : Gen at bus 196	: Vg=1.037 -> Vg=1.0000025
% INFO    : Gen at bus 196	: Pg=2.44, Qg=0.9 -> Pg=7.5, Qg=0.95
% INFO    : Gen at bus 196	: Vg=1.037 -> Vg=1.0000025
% INFO    : Gen at bus 219	: Pg=1.46, Qg=0.0 -> Pg=5.97, Qg=0.0
% INFO    : Gen at bus 219	: Vg=1.016 -> Vg=1.022224
% INFO    : Gen at bus 226	: Vg=1.073 -> Vg=1.0
% INFO    : Gen at bus 229	: Pg=3.17, Qg=0.0 -> Pg=3.75, Qg=0.0
% INFO    : Gen at bus 229	: Vg=1.025 -> Vg=1.0079355
% INFO    : Gen at bus 238	: Pg=1.2, Qg=0.0 -> Pg=16.75, Qg=0.0
% INFO    : Gen at bus 238	: Vg=1.047 -> Vg=1.000001
% INFO    : Gen at bus 238	: Pg=0.2, Qg=0.0 -> Pg=12.15, Qg=0.0
% INFO    : Gen at bus 238	: Vg=1.047 -> Vg=1.000001
% INFO    : Gen at bus 240	: Vg=1.022 -> Vg=1.022224
% INFO    : Gen at bus 240	: Pg=6.28, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 240	: Vg=1.022 -> Vg=1.022224
% INFO    : Gen at bus 248	: Vg=0.976 -> Vg=0.999999
% INFO    : Gen at bus 248	: Vg=0.976 -> Vg=0.999999
% INFO    : Gen at bus 248	: Vg=0.976 -> Vg=0.999999
% INFO    : Gen at bus 248	: Vg=0.976 -> Vg=0.999999
% INFO    : Gen at bus 258	: Vg=1.031 -> Vg=1.0000025
% INFO    : Gen at bus 258	: Vg=1.031 -> Vg=1.0000025
% INFO    : Gen at bus 260	: Pg=27.18, Qg=1.0 -> Pg=15.0, Qg=0.95
% INFO    : Gen at bus 260	: Vg=1.071 -> Vg=1.000001
% INFO    : Gen at bus 263	: Pg=3.85, Qg=-0.6 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 263	: Vg=0.998 -> Vg=1.0000025
% INFO    : Gen at bus 271	: Vg=0.997 -> Vg=1.0000025
% INFO    : Gen at bus 284	: Vg=0.975 -> Vg=0.999999
% INFO    : Gen at bus 297	: Vg=1.064 -> Vg=0.9888895
% INFO    : Gen at bus 298	: Vg=1.014 -> Vg=1.0158755
% INFO    : Gen at bus 307	: Pg=1.12, Qg=-6.48 -> Pg=7.5, Qg=0.0
% INFO    : Gen at bus 307	: Vg=1.038 -> Vg=0.999999
% INFO    : Gen at bus 314	: Pg=7.16, Qg=0.0 -> Pg=12.9, Qg=0.0
% INFO    : Gen at bus 314	: Vg=1.032 -> Vg=1.000001
% INFO    : Gen at bus 314	: Pg=18.16, Qg=0.0 -> Pg=24.8, Qg=0.0
% INFO    : Gen at bus 314	: Vg=1.032 -> Vg=1.000001
% INFO    : Gen at bus 319	: Vg=1.05 -> Vg=1.0000025
% INFO    : Gen at bus 319	: Vg=1.05 -> Vg=1.0000025
% INFO    : Gen at bus 321	: Pg=4.8, Qg=-0.1 -> Pg=5.4, Qg=0.0
% INFO    : Gen at bus 321	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 327	: Vg=1.023 -> Vg=0.999999
% INFO    : Gen at bus 334	: Vg=1.028 -> Vg=1.015872
% INFO    : Gen at bus 335	: Pg=2.11, Qg=2.07 -> Pg=12.5, Qg=2.0
% INFO    : Gen at bus 335	: Vg=1.037 -> Vg=1.0233335
% INFO    : Gen at bus 338	: Pg=9.13, Qg=-0.33 -> Pg=6.5, Qg=-0.5
% INFO    : Gen at bus 338	: Vg=1.013 -> Vg=1.0000025
% INFO    : Gen at bus 340	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 340	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 347	: Vg=1.057 -> Vg=1.027779
% INFO    : Gen at bus 347	: Pg=15.24, Qg=0.0 -> Pg=9.75, Qg=0.0
% INFO    : Gen at bus 347	: Vg=1.057 -> Vg=1.027779
% INFO    : Gen at bus 350	: Vg=1.058 -> Vg=1.022222
% INFO    : Gen at bus 358	: Vg=1.027 -> Vg=1.0000025
% INFO    : Gen at bus 359	: Pg=1.97, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 359	: Vg=1.001 -> Vg=1.0158755
% INFO    : Gen at bus 359	: Pg=2.97, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 359	: Vg=1.001 -> Vg=1.0158755
% INFO    : Gen at bus 366	: Pg=127.22, Qg=8.45 -> Pg=65.0, Qg=16.5
% INFO    : Gen at bus 366	: Vg=1.078 -> Vg=1.046665
% INFO    : Gen at bus 393	: Vg=1.006 -> Vg=1.0000025
% INFO    : Gen at bus 412	: Pg=1.4, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 412	: Vg=1.026 -> Vg=1.022224
% INFO    : Gen at bus 412	: Pg=1.4, Qg=0.0 -> Pg=5.75, Qg=0.0
% INFO    : Gen at bus 412	: Vg=1.026 -> Vg=1.022224
% INFO    : Gen at bus 432	: Vg=1.047 -> Vg=1.0000025
% INFO    : Gen at bus 441	: Vg=1.023 -> Vg=1.0000025
% INFO    : Gen at bus 448	: Vg=0.992 -> Vg=1.015872
% INFO    : Gen at bus 463	: Vg=1.013 -> Vg=1.0079355
% INFO    : Gen at bus 463	: Pg=3.21, Qg=0.0 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 463	: Vg=1.013 -> Vg=1.0079355
% INFO    : Gen at bus 465	: Pg=7.19, Qg=0.74 -> Pg=14.0, Qg=1.5
% INFO    : Gen at bus 465	: Vg=1.171 -> Vg=0.985555
% INFO    : Gen at bus 465	: Pg=7.19, Qg=0.74 -> Pg=14.0, Qg=1.5
% INFO    : Gen at bus 465	: Vg=1.171 -> Vg=0.985555
% INFO    : Gen at bus 467	: Pg=42.78, Qg=10.85 -> Pg=24.5, Qg=4.5
% INFO    : Gen at bus 467	: Vg=1.042 -> Vg=1.0079355
% INFO    : Gen at bus 471	: Vg=1.035 -> Vg=0.999999
% INFO    : Gen at bus 471	: Vg=1.035 -> Vg=0.999999
% INFO    : Gen at bus 480	: Vg=0.982 -> Vg=0.999999
% INFO    : Gen at bus 480	: Vg=0.982 -> Vg=0.999999
% INFO    : Gen at bus 480	: Vg=0.982 -> Vg=0.999999
% INFO    : Gen at bus 492	: Vg=1.055 -> Vg=1.033334
% INFO    : Gen at bus 509	: Vg=1.002 -> Vg=0.999999
% INFO    : Gen at bus 518	: Vg=1.0 -> Vg=1.015874
% INFO    : Gen at bus 519	: Pg=8.33, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 519	: Vg=1.035 -> Vg=1.022224
% INFO    : Gen at bus 529	: Vg=1.017 -> Vg=0.999999
% INFO    : Gen at bus 529	: Vg=1.017 -> Vg=0.999999
% INFO    : Gen at bus 529	: Pg=1.95, Qg=-1.62 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 529	: Vg=1.017 -> Vg=0.999999
% INFO    : Gen at bus 535	: Pg=0.28, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 535	: Vg=1.014 -> Vg=1.022224
% INFO    : Gen at bus 535	: Pg=4.28, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 535	: Vg=1.014 -> Vg=1.022224
% INFO    : Gen at bus 544	: Pg=1.22, Qg=1.9 -> Pg=4.5, Qg=1.95
% INFO    : Gen at bus 544	: Vg=1.0 -> Vg=1.0000025
% INFO    : Gen at bus 547	: Vg=0.984 -> Vg=1.0000025
% INFO    : Gen at bus 569	: Pg=2.23, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 569	: Vg=1.006 -> Vg=1.0158755
% INFO    : Gen at bus 569	: Pg=12.23, Qg=0.0 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 569	: Vg=1.006 -> Vg=1.0158755
% INFO    : Gen at bus 569	: Pg=5.23, Qg=0.0 -> Pg=5.75, Qg=0.0
% INFO    : Gen at bus 569	: Vg=1.006 -> Vg=1.0158755
% INFO    : Gen at bus 582	: Pg=4.38, Qg=2.76 -> Pg=8.0, Qg=1.5
% INFO    : Gen at bus 582	: Vg=1.029 -> Vg=1.0000005
% INFO    : Gen at bus 584	: Pg=0.16, Qg=0.0 -> Pg=4.5, Qg=0.0
% INFO    : Gen at bus 584	: Vg=0.993 -> Vg=1.0158755
% INFO    : Gen at bus 585	: Pg=1.04, Qg=0.5 -> Pg=4.75, Qg=0.0
% INFO    : Gen at bus 585	: Vg=1.01 -> Vg=0.999999
% INFO    : Gen at bus 588	: Vg=1.029 -> Vg=1.000001
% INFO    : Gen at bus 592	: Vg=1.012 -> Vg=1.0000025
% INFO    : Gen at bus 599	: Vg=1.026 -> Vg=1.015872
% INFO    : Gen at bus 609	: Pg=41.38, Qg=-4.32 -> Pg=22.5, Qg=0.0
% INFO    : Gen at bus 609	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 609	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 611	: Pg=3.39, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 611	: Vg=1.01 -> Vg=1.022224
% INFO    : Gen at bus 611	: Pg=3.39, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 611	: Vg=1.01 -> Vg=1.022224
% INFO    : Gen at bus 611	: Pg=3.39, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 611	: Vg=1.01 -> Vg=1.022224
% INFO    : Gen at bus 612	: Pg=2.14, Qg=0.0 -> Pg=17.5, Qg=0.0
% INFO    : Gen at bus 612	: Vg=1.012 -> Vg=1.0000005
% INFO    : Gen at bus 612	: Vg=1.012 -> Vg=1.0000005
% INFO    : Gen at bus 623	: Pg=-2.11, Qg=-8.3 -> Pg=0.0, Qg=0.0
% INFO    : Gen at bus 623	: Vg=1.049 -> Vg=1.0111115
% INFO    : Gen at bus 632	: Vg=1.026 -> Vg=0.999999
% INFO    : Gen at bus 635	: Vg=1.011 -> Vg=1.015872
% INFO    : Gen at bus 635	: Pg=4.02, Qg=4.91 -> Pg=7.5, Qg=3.5
% INFO    : Gen at bus 635	: Vg=1.011 -> Vg=1.015872
% INFO    : Gen at bus 640	: Pg=94.82, Qg=-101.18 -> Pg=119.5, Qg=-11.4
% INFO    : Gen at bus 640	: Vg=1.083 -> Vg=1.078945
% INFO    : Gen at bus 651	: Vg=1.064 -> Vg=1.0000025
% INFO    : Gen at bus 669	: Pg=3.19, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 669	: Vg=1.033 -> Vg=1.022224
% INFO    : Gen at bus 669	: Pg=3.19, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 669	: Vg=1.033 -> Vg=1.022224
% INFO    : Gen at bus 670	: Pg=3.25, Qg=0.0 -> Pg=3.75, Qg=0.0
% INFO    : Gen at bus 670	: Vg=1.053 -> Vg=1.027779
% INFO    : Gen at bus 670	: Pg=14.25, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 670	: Vg=1.053 -> Vg=1.027779
% INFO    : Gen at bus 678	: Vg=1.011 -> Vg=1.022224
% INFO    : Gen at bus 679	: Pg=0.12, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 679	: Vg=1.059 -> Vg=1.022224
% INFO    : Gen at bus 683	: Pg=4.2, Qg=-2.58 -> Pg=4.5, Qg=0.5
% INFO    : Gen at bus 683	: Vg=0.89 -> Vg=0.9444445
% INFO    : Gen at bus 683	: Pg=4.2, Qg=-2.58 -> Pg=4.5, Qg=0.5
% INFO    : Gen at bus 683	: Vg=0.89 -> Vg=0.9444445
% INFO    : Gen at bus 683	: Vg=0.89 -> Vg=0.9444445
% INFO    : Gen at bus 683	: Pg=4.2, Qg=-2.58 -> Pg=5.5, Qg=1.5
% INFO    : Gen at bus 683	: Vg=0.89 -> Vg=0.9444445
% INFO    : Gen at bus 694	: Pg=16.2, Qg=0.0 -> Pg=16.175, Qg=0.0
% INFO    : Gen at bus 694	: Vg=1.055 -> Vg=1.022222
% INFO    : Gen at bus 694	: Pg=1.2, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 694	: Vg=1.055 -> Vg=1.022222
% INFO    : Gen at bus 694	: Pg=7.2, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 694	: Vg=1.055 -> Vg=1.022222
% INFO    : Gen at bus 698	: Pg=31.61, Qg=-7.06 -> Pg=18.5, Qg=-1.0
% INFO    : Gen at bus 698	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 698	: Pg=30.63, Qg=-7.06 -> Pg=18.5, Qg=-1.0
% INFO    : Gen at bus 698	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 697	: Pg=32.52, Qg=-7.35 -> Pg=18.5, Qg=0.0
% INFO    : Gen at bus 697	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 697	: Pg=29.5, Qg=-7.35 -> Pg=18.5, Qg=0.0
% INFO    : Gen at bus 697	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 696	: Pg=31.51, Qg=-5.32 -> Pg=18.5, Qg=-1.0
% INFO    : Gen at bus 696	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 696	: Pg=31.51, Qg=-5.32 -> Pg=18.5, Qg=-1.0
% INFO    : Gen at bus 696	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 704	: Pg=1.17, Qg=-0.66 -> Pg=2.0, Qg=0.0
% INFO    : Gen at bus 704	: Vg=0.896 -> Vg=0.9444445
% INFO    : Gen at bus 704	: Pg=1.17, Qg=-0.16 -> Pg=2.0, Qg=0.0
% INFO    : Gen at bus 704	: Vg=0.896 -> Vg=0.9444445
% INFO    : Gen at bus 704	: Pg=2.87, Qg=0.34 -> Pg=2.85, Qg=0.0
% INFO    : Gen at bus 704	: Vg=0.896 -> Vg=0.9444445
% INFO    : Gen at bus 704	: Vg=0.896 -> Vg=0.9444445
% INFO    : Gen at bus 731	: Pg=16.79, Qg=0.0 -> Pg=9.75, Qg=0.0
% INFO    : Gen at bus 731	: Vg=1.044 -> Vg=1.022224
% INFO    : Gen at bus 732	: Pg=27.31, Qg=-2.16 -> Pg=19.5, Qg=0.0
% INFO    : Gen at bus 732	: Vg=0.977 -> Vg=0.999999
% INFO    : Gen at bus 733	: Pg=1.1, Qg=0.0 -> Pg=5.75, Qg=0.0
% INFO    : Gen at bus 733	: Vg=1.004 -> Vg=1.0158755
% INFO    : Gen at bus 733	: Pg=2.1, Qg=0.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 733	: Vg=1.004 -> Vg=1.0158755
% INFO    : Gen at bus 735	: Vg=1.051 -> Vg=1.000001
% INFO    : Gen at bus 735	: Pg=7.19, Qg=0.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 735	: Vg=1.051 -> Vg=1.000001
% INFO    : Gen at bus 736	: Pg=0.46, Qg=0.1 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 736	: Vg=1.032 -> Vg=1.0000025
% INFO    : Gen at bus 743	: Pg=3.56, Qg=2.67 -> Pg=3.35, Qg=0.01
% INFO    : Gen at bus 743	: Vg=0.983 -> Vg=0.999999
% INFO    : Gen at bus 743	: Pg=2.65, Qg=1.95 -> Pg=2.8, Qg=0.0
% INFO    : Gen at bus 743	: Vg=0.983 -> Vg=0.999999
% INFO    : Gen at bus 744	: Pg=3.25, Qg=-19.76 -> Pg=13.3, Qg=-2.38
% INFO    : Gen at bus 744	: Vg=0.975 -> Vg=0.999999
% INFO    : Gen at bus 745	: Pg=4.6, Qg=2.0 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 745	: Vg=1.011 -> Vg=1.022224
% INFO    : Gen at bus 750	: Vg=0.975 -> Vg=0.999999
% INFO    : Gen at bus 757	: Vg=1.068 -> Vg=0.9888895
% INFO    : Gen at bus 759	: Vg=1.037 -> Vg=0.999999
% INFO    : Gen at bus 760	: Vg=1.035 -> Vg=0.999999
% INFO    : Gen at bus 759	: Pg=16.11, Qg=-5.86 -> Pg=18.75, Qg=2.0
% INFO    : Gen at bus 759	: Vg=1.037 -> Vg=0.999999
% INFO    : Gen at bus 760	: Pg=15.44, Qg=-2.51 -> Pg=18.75, Qg=2.0
% INFO    : Gen at bus 760	: Vg=1.035 -> Vg=0.999999
% INFO    : Gen at bus 761	: Vg=0.596 -> Vg=0.825
% INFO    : Gen at bus 761	: Pg=0.91, Qg=2.61 -> Pg=13.05, Qg=0.0
% INFO    : Gen at bus 761	: Vg=0.596 -> Vg=0.825
% INFO    : Gen at bus 761	: Vg=0.596 -> Vg=0.825
% INFO    : Gen at bus 761	: Vg=0.596 -> Vg=0.825
% INFO    : Gen at bus 765	: Vg=1.02 -> Vg=1.0158755
% INFO    : Gen at bus 765	: Pg=0.16, Qg=0.0 -> Pg=17.0, Qg=0.0
% INFO    : Gen at bus 765	: Vg=1.02 -> Vg=1.0158755
% INFO    : Gen at bus 785	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 785	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 786	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 800	: Pg=25.57, Qg=-7.03 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 800	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 800	: Pg=26.55, Qg=-7.03 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 800	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 801	: Pg=26.91, Qg=-5.94 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 801	: Vg=1.022 -> Vg=0.975
% INFO    : Gen at bus 801	: Pg=26.91, Qg=-5.94 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 801	: Vg=1.022 -> Vg=0.975
% INFO    : Gen at bus 802	: Pg=25.92, Qg=-6.45 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 802	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 802	: Pg=26.91, Qg=-6.45 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 802	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 806	: Pg=0.88, Qg=0.0 -> Pg=20.4, Qg=0.0
% INFO    : Gen at bus 806	: Vg=1.008 -> Vg=1.0000025
% INFO    : Gen at bus 814	: Pg=23.28, Qg=1.33 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 814	: Vg=1.023 -> Vg=1.015872
% INFO    : Gen at bus 814	: Vg=1.023 -> Vg=1.015872
% INFO    : Gen at bus 815	: Pg=23.25, Qg=0.73 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 815	: Vg=1.024 -> Vg=1.015872
% INFO    : Gen at bus 815	: Pg=23.25, Qg=0.73 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 815	: Vg=1.024 -> Vg=1.015872
% INFO    : Gen at bus 815	: Pg=21.25, Qg=0.73 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 815	: Vg=1.024 -> Vg=1.015872
% INFO    : Gen at bus 815	: Pg=23.25, Qg=0.73 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 815	: Vg=1.024 -> Vg=1.015872
% INFO    : Gen at bus 825	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 825	: Pg=1.16, Qg=3.0 -> Pg=3.5, Qg=0.0
% INFO    : Gen at bus 825	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 828	: Vg=1.059 -> Vg=1.022222
% INFO    : Gen at bus 829	: Pg=9.77, Qg=-3.27 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 829	: Vg=1.032 -> Vg=1.0000025
% INFO    : Gen at bus 830	: Vg=0.937 -> Vg=0.9444445
% INFO    : Gen at bus 832	: Vg=1.053 -> Vg=1.0000025
% INFO    : Gen at bus 832	: Vg=1.053 -> Vg=1.0000025
% INFO    : Gen at bus 835	: Pg=0.0, Qg=2.9 -> Pg=7.5, Qg=2.95
% INFO    : Gen at bus 835	: Vg=0.984 -> Vg=1.0000025
% INFO    : Gen at bus 837	: Vg=1.013 -> Vg=1.0000025
% INFO    : Gen at bus 837	: Vg=1.013 -> Vg=1.0000025
% INFO    : Gen at bus 856	: Vg=1.013 -> Vg=1.0000025
% INFO    : Gen at bus 856	: Vg=1.013 -> Vg=1.0000025
% INFO    : Gen at bus 863	: Vg=1.003 -> Vg=1.0000025
% INFO    : Gen at bus 864	: Pg=8.03, Qg=2.95 -> Pg=7.0, Qg=0.0
% INFO    : Gen at bus 864	: Vg=1.006 -> Vg=1.0000025
% INFO    : Gen at bus 885	: Vg=0.997 -> Vg=1.0000025
% INFO    : Gen at bus 885	: Vg=0.997 -> Vg=1.0000025
% INFO    : Gen at bus 889	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 889	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 889	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 889	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 907	: Pg=6.49, Qg=0.0 -> Pg=7.0, Qg=0.0
% INFO    : Gen at bus 907	: Vg=1.061 -> Vg=1.027779
% INFO    : Gen at bus 944	: Pg=4.05, Qg=0.0 -> Pg=4.05, Qg=0.0
% INFO    : Gen at bus 944	: Vg=0.977 -> Vg=1.0000025
% INFO    : Gen at bus 948	: Vg=1.04 -> Vg=1.000001
% INFO    : Gen at bus 969	: Pg=41.12, Qg=-1.5 -> Pg=25.0, Qg=9.0
% INFO    : Gen at bus 969	: Vg=1.056 -> Vg=0.975
% INFO    : Gen at bus 971	: Pg=6.79, Qg=0.0 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 971	: Vg=1.044 -> Vg=1.022224
% INFO    : Gen at bus 977	: Pg=4.17, Qg=-0.29 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 977	: Vg=1.014 -> Vg=0.999999
% INFO    : Gen at bus 977	: Vg=1.014 -> Vg=0.999999
% INFO    : Gen at bus 987	: Vg=1.062 -> Vg=1.027779
% INFO    : Gen at bus 987	: Vg=1.062 -> Vg=1.027779
% INFO    : Gen at bus 987	: Vg=1.062 -> Vg=1.027779
% INFO    : Gen at bus 989	: Vg=1.014 -> Vg=0.984126
% INFO    : Gen at bus 991	: Pg=1.14, Qg=1.0 -> Pg=2.0, Qg=0.0
% INFO    : Gen at bus 991	: Vg=1.038 -> Vg=1.022224
% INFO    : Gen at bus 1013	: Pg=0.12, Qg=1.0 -> Pg=1.5, Qg=0.95
% INFO    : Gen at bus 1013	: Vg=1.064 -> Vg=1.000001
% INFO    : Gen at bus 1013	: Vg=1.064 -> Vg=1.000001
% INFO    : Gen at bus 1017	: Pg=2.96, Qg=-0.95 -> Pg=3.6, Qg=0.0
% INFO    : Gen at bus 1017	: Vg=1.024 -> Vg=0.999999
% INFO    : Gen at bus 1029	: Pg=4.72, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 1029	: Vg=1.025 -> Vg=1.022224
% INFO    : Gen at bus 1052	: Vg=0.996 -> Vg=0.999999
% INFO    : Gen at bus 1054	: Vg=0.978 -> Vg=1.015872
% INFO    : Gen at bus 1054	: Vg=0.978 -> Vg=1.015872
% INFO    : Gen at bus 1061	: Pg=7.24, Qg=2.4 -> Pg=9.4, Qg=1.5
% INFO    : Gen at bus 1061	: Vg=1.073 -> Vg=1.022222
% INFO    : Gen at bus 1062	: Pg=0.68, Qg=0.0 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 1062	: Vg=1.031 -> Vg=1.022224
% INFO    : Gen at bus 1069	: Vg=1.033 -> Vg=0.9682545
% INFO    : Gen at bus 1070	: Pg=0.0, Qg=1.9 -> Pg=6.0, Qg=1.95
% INFO    : Gen at bus 1070	: Vg=0.973 -> Vg=1.0000025
% INFO    : Gen at bus 1074	: Vg=1.001 -> Vg=1.0158755
% INFO    : Gen at bus 1112	: Pg=14.2, Qg=1.14 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 1112	: Vg=1.073 -> Vg=0.975
% INFO    : Gen at bus 1112	: Vg=1.073 -> Vg=0.975
% INFO    : Gen at bus 1112	: Vg=1.073 -> Vg=0.975
% INFO    : Gen at bus 1112	: Vg=1.073 -> Vg=0.975
% INFO    : Gen at bus 1114	: Vg=1.016 -> Vg=0.999999
% INFO    : Gen at bus 1114	: Vg=1.016 -> Vg=0.999999
% INFO    : Gen at bus 1129	: Vg=1.03 -> Vg=1.0000025
% INFO    : Gen at bus 1132	: Pg=1.52, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 1132	: Vg=1.027 -> Vg=1.022224
% INFO    : Gen at bus 1139	: Pg=0.07, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 1139	: Vg=1.028 -> Vg=1.0000025
% INFO    : Gen at bus 1151	: Vg=1.045 -> Vg=1.022224
% INFO    : Gen at bus 1151	: Vg=1.045 -> Vg=1.022224
% INFO    : Gen at bus 1214	: Pg=32.13, Qg=-34.69 -> Pg=31.0, Qg=0.0
% INFO    : Gen at bus 1214	: Vg=1.071 -> Vg=1.044445
% INFO    : Gen at bus 1215	: Pg=3.57, Qg=-9.28 -> Pg=20.7, Qg=0.415
% INFO    : Gen at bus 1215	: Vg=1.062 -> Vg=1.044445
% INFO    : Gen at bus 1225	: Pg=2.44, Qg=0.0 -> Pg=5.6, Qg=0.0
% INFO    : Gen at bus 1225	: Vg=1.069 -> Vg=1.027779
% INFO    : Gen at bus 1250	: Vg=0.582 -> Vg=0.825
% INFO    : Gen at bus 1250	: Vg=0.582 -> Vg=0.825
% INFO    : Gen at bus 1260	: Pg=8.08, Qg=0.0 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 1260	: Vg=1.025 -> Vg=1.0079355
% INFO    : Gen at bus 1262	: Pg=5.13, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1262	: Vg=1.038 -> Vg=1.0158755
% INFO    : Gen at bus 1263	: Pg=7.12, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1263	: Vg=1.038 -> Vg=1.0158755
% INFO    : Gen at bus 1267	: Vg=0.99 -> Vg=1.015872
% INFO    : Gen at bus 1281	: Pg=1.19, Qg=0.0 -> Pg=14.5, Qg=0.0
% INFO    : Gen at bus 1281	: Vg=1.042 -> Vg=1.033333
% INFO    : Gen at bus 1281	: Vg=1.042 -> Vg=1.033333
% INFO    : Gen at bus 1290	: Vg=1.058 -> Vg=1.0000025
% INFO    : Gen at bus 1290	: Vg=1.058 -> Vg=1.0000025
% INFO    : Gen at bus 1290	: Pg=1.0, Qg=2.18 -> Pg=4.0, Qg=-0.1
% INFO    : Gen at bus 1290	: Vg=1.058 -> Vg=1.0000025
% INFO    : Gen at bus 1307	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 1314	: Vg=1.05 -> Vg=1.0000025
% INFO    : Gen at bus 1314	: Pg=9.97, Qg=1.0 -> Pg=8.5, Qg=0.95
% INFO    : Gen at bus 1314	: Vg=1.05 -> Vg=1.0000025
% INFO    : Gen at bus 1314	: Vg=1.05 -> Vg=1.0000025
% INFO    : Gen at bus 1317	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 1317	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 1319	: Vg=1.037 -> Vg=1.022224
% INFO    : Gen at bus 1319	: Vg=1.037 -> Vg=1.022224
% INFO    : Gen at bus 1327	: Vg=0.937 -> Vg=0.9444445
% INFO    : Gen at bus 1329	: Pg=0.0, Qg=1.0 -> Pg=2.5, Qg=0.95
% INFO    : Gen at bus 1329	: Vg=1.066 -> Vg=1.000001
% INFO    : Gen at bus 1329	: Pg=2.13, Qg=1.0 -> Pg=2.5, Qg=0.95
% INFO    : Gen at bus 1329	: Vg=1.066 -> Vg=1.000001
% INFO    : Gen at bus 1344	: Vg=1.017 -> Vg=0.999999
% INFO    : Gen at bus 1348	: Pg=0.0, Qg=1.71 -> Pg=5.5, Qg=3.0
% INFO    : Gen at bus 1348	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 1348	: Pg=0.0, Qg=1.71 -> Pg=5.5, Qg=3.0
% INFO    : Gen at bus 1348	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 1358	: Pg=0.16, Qg=0.0 -> Pg=9.075, Qg=0.0
% INFO    : Gen at bus 1358	: Vg=1.047 -> Vg=1.0000025
% INFO    : Gen at bus 1358	: Pg=4.16, Qg=0.0 -> Pg=17.85, Qg=0.0
% INFO    : Gen at bus 1358	: Vg=1.047 -> Vg=1.0000025
% INFO    : Gen at bus 1358	: Pg=0.16, Qg=0.0 -> Pg=14.2, Qg=0.0
% INFO    : Gen at bus 1358	: Vg=1.047 -> Vg=1.0000025
% INFO    : Gen at bus 1360	: Pg=28.88, Qg=-10.33 -> Pg=22.5, Qg=0.0
% INFO    : Gen at bus 1360	: Vg=1.037 -> Vg=0.999999
% INFO    : Gen at bus 1366	: Pg=7.48, Qg=-4.26 -> Pg=6.5, Qg=1.0
% INFO    : Gen at bus 1366	: Vg=1.029 -> Vg=1.015872
% INFO    : Gen at bus 1366	: Vg=1.029 -> Vg=1.015872
% INFO    : Gen at bus 1413	: Vg=1.021 -> Vg=1.015872
% INFO    : Gen at bus 1423	: Pg=41.09, Qg=1.73 -> Pg=25.0, Qg=0.0
% INFO    : Gen at bus 1423	: Vg=1.037 -> Vg=1.000001
% INFO    : Gen at bus 1423	: Pg=41.09, Qg=1.73 -> Pg=25.0, Qg=0.0
% INFO    : Gen at bus 1423	: Vg=1.037 -> Vg=1.000001
% INFO    : Gen at bus 1436	: Vg=1.022 -> Vg=1.015872
% INFO    : Gen at bus 1443	: Pg=9.18, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 1443	: Vg=1.011 -> Vg=1.015872
% INFO    : Gen at bus 1457	: Vg=0.607 -> Vg=0.825
% INFO    : Gen at bus 1457	: Vg=0.607 -> Vg=0.825
% INFO    : Gen at bus 1457	: Vg=0.607 -> Vg=0.825
% INFO    : Gen at bus 1466	: Vg=1.012 -> Vg=1.0158755
% INFO    : Gen at bus 1467	: Pg=0.32, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 1467	: Vg=1.029 -> Vg=1.027779
% INFO    : Gen at bus 1477	: Vg=1.026 -> Vg=1.015872
% INFO    : Gen at bus 1498	: Pg=5.72, Qg=0.0 -> Pg=13.0, Qg=0.0
% INFO    : Gen at bus 1498	: Vg=1.038 -> Vg=1.022224
% INFO    : Gen at bus 1500	: Vg=1.053 -> Vg=1.0111115
% INFO    : Gen at bus 1500	: Pg=0.16, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 1500	: Vg=1.053 -> Vg=1.0111115
% INFO    : Gen at bus 1520	: Pg=198.95, Qg=17.27 -> Pg=141.5, Qg=20.0
% INFO    : Gen at bus 1520	: Vg=1.091 -> Vg=0.975
% INFO    : Gen at bus 1522	: Pg=79.68, Qg=25.47 -> Pg=141.5, Qg=20.0
% INFO    : Gen at bus 1522	: Vg=1.1 -> Vg=0.975
% INFO    : Gen at bus 1523	: Pg=76.45, Qg=7.51 -> Pg=125.5, Qg=12.5
% INFO    : Gen at bus 1523	: Vg=0.957 -> Vg=0.975
% INFO    : Gen at bus 1521	: Pg=159.15, Qg=18.31 -> Pg=125.5, Qg=12.5
% INFO    : Gen at bus 1521	: Vg=0.959 -> Vg=0.975
% INFO    : Gen at bus 1553	: Vg=1.042 -> Vg=1.022222
% INFO    : Gen at bus 1553	: Vg=1.042 -> Vg=1.022222
% INFO    : Gen at bus 1560	: Pg=8.22, Qg=4.04 -> Pg=25.0, Qg=6.5
% INFO    : Gen at bus 1560	: Vg=1.047 -> Vg=1.033333
% INFO    : Gen at bus 1564	: Pg=4.43, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 1564	: Vg=1.069 -> Vg=1.027779
% INFO    : Gen at bus 1564	: Pg=13.43, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1564	: Vg=1.069 -> Vg=1.027779
% INFO    : Gen at bus 1565	: Pg=0.34, Qg=0.0 -> Pg=2.0, Qg=0.0
% INFO    : Gen at bus 1565	: Vg=1.077 -> Vg=1.046665
% INFO    : Gen at bus 1566	: Pg=0.69, Qg=0.0 -> Pg=5.75, Qg=0.0
% INFO    : Gen at bus 1566	: Vg=1.032 -> Vg=1.022224
% INFO    : Gen at bus 1570	: Pg=1.01, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1570	: Vg=0.974 -> Vg=1.0158755
% INFO    : Gen at bus 1570	: Vg=0.974 -> Vg=1.0158755
% INFO    : Gen at bus 1584	: Vg=1.012 -> Vg=0.999999
% INFO    : Gen at bus 1599	: Pg=5.19, Qg=3.5 -> Pg=18.0, Qg=-0.5
% INFO    : Gen at bus 1599	: Vg=1.041 -> Vg=1.022224
% INFO    : Gen at bus 1599	: Vg=1.041 -> Vg=1.022224
% INFO    : Gen at bus 1605	: Pg=39.36, Qg=17.04 -> Pg=21.0, Qg=5.0
% INFO    : Gen at bus 1605	: Vg=1.039 -> Vg=1.0000005
% INFO    : Gen at bus 1619	: Pg=14.21, Qg=0.0 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 1619	: Vg=1.051 -> Vg=1.027779
% INFO    : Gen at bus 1619	: Pg=5.21, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 1619	: Vg=1.051 -> Vg=1.027779
% INFO    : Gen at bus 1630	: Pg=30.69, Qg=-6.35 -> Pg=39.0, Qg=-2.675
% INFO    : Gen at bus 1630	: Vg=1.059 -> Vg=1.0377785
% INFO    : Gen at bus 1643	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 1644	: Vg=1.02 -> Vg=1.0000025
% INFO    : Gen at bus 1644	: Vg=1.02 -> Vg=1.0000025
% INFO    : Gen at bus 1645	: Pg=14.8, Qg=-1.51 -> Pg=26.0, Qg=-1.5
% INFO    : Gen at bus 1645	: Vg=1.081 -> Vg=1.04445
% INFO    : Gen at bus 1648	: Vg=1.036 -> Vg=1.0000025
% INFO    : Gen at bus 1659	: Vg=1.028 -> Vg=1.0000025
% INFO    : Gen at bus 1675	: Pg=0.13, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 1675	: Vg=1.04 -> Vg=1.0111115
% INFO    : Gen at bus 1675	: Pg=1.13, Qg=0.0 -> Pg=8.75, Qg=0.0
% INFO    : Gen at bus 1675	: Vg=1.04 -> Vg=1.0111115
% INFO    : Gen at bus 1684	: Vg=1.016 -> Vg=1.015872
% INFO    : Gen at bus 1684	: Vg=1.016 -> Vg=1.015872
% INFO    : Gen at bus 1685	: Vg=1.0 -> Vg=1.0000025
% INFO    : Gen at bus 1686	: Vg=1.023 -> Vg=1.015872
% INFO    : Gen at bus 1686	: Vg=1.023 -> Vg=1.015872
% INFO    : Gen at bus 1687	: Pg=2.06, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 1687	: Vg=1.018 -> Vg=0.999999
% INFO    : Gen at bus 1688	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 1693	: Pg=4.07, Qg=1.44 -> Pg=3.55, Qg=0.07
% INFO    : Gen at bus 1693	: Vg=0.982 -> Vg=1.0000025
% INFO    : Gen at bus 1697	: Pg=1.35, Qg=-0.0 -> Pg=7.5, Qg=0.0
% INFO    : Gen at bus 1697	: Vg=1.029 -> Vg=1.0158755
% INFO    : Gen at bus 1697	: Pg=1.35, Qg=-0.0 -> Pg=7.5, Qg=0.0
% INFO    : Gen at bus 1697	: Vg=1.029 -> Vg=1.0158755
% INFO    : Gen at bus 1697	: Pg=1.35, Qg=-0.0 -> Pg=7.5, Qg=0.0
% INFO    : Gen at bus 1697	: Vg=1.029 -> Vg=1.0158755
% INFO    : Gen at bus 1700	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 1703	: Pg=0.0, Qg=1.9 -> Pg=9.0, Qg=1.95
% INFO    : Gen at bus 1703	: Vg=1.009 -> Vg=1.0000025
% INFO    : Gen at bus 1704	: Vg=1.045 -> Vg=1.0000025
% INFO    : Gen at bus 1706	: Vg=1.026 -> Vg=0.999999
% INFO    : Gen at bus 1717	: Vg=1.073 -> Vg=1.015874
% INFO    : Gen at bus 1728	: Vg=0.978 -> Vg=0.975
% INFO    : Gen at bus 1728	: Vg=0.978 -> Vg=0.975
% INFO    : Gen at bus 1731	: Pg=1.25, Qg=0.0 -> Pg=2.25, Qg=0.0
% INFO    : Gen at bus 1731	: Vg=1.055 -> Vg=1.027779
% INFO    : Gen at bus 1733	: Pg=0.76, Qg=-2.95 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 1733	: Vg=1.018 -> Vg=0.999999
% INFO    : Gen at bus 1739	: Pg=7.58, Qg=2.44 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 1739	: Vg=1.039 -> Vg=1.0000025
% INFO    : Gen at bus 1739	: Vg=1.039 -> Vg=1.0000025
% INFO    : Gen at bus 1746	: Pg=27.89, Qg=14.84 -> Pg=20.0, Qg=1.0
% INFO    : Gen at bus 1746	: Vg=1.127 -> Vg=0.975
% INFO    : Gen at bus 1747	: Pg=37.24, Qg=9.83 -> Pg=20.0, Qg=1.0
% INFO    : Gen at bus 1747	: Vg=1.109 -> Vg=0.975
% INFO    : Gen at bus 1748	: Pg=37.24, Qg=13.43 -> Pg=20.0, Qg=1.0
% INFO    : Gen at bus 1748	: Vg=1.12 -> Vg=0.975
% INFO    : Gen at bus 1802	: Vg=1.001 -> Vg=1.0000025
% INFO    : Gen at bus 1812	: Vg=0.971 -> Vg=1.0000025
% INFO    : Gen at bus 1829	: Vg=1.007 -> Vg=1.022224
% INFO    : Gen at bus 1836	: Vg=1.048 -> Vg=1.0111115
% INFO    : Gen at bus 1842	: Pg=0.1, Qg=0.0 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 1842	: Vg=1.034 -> Vg=1.0158755
% INFO    : Gen at bus 1842	: Pg=3.1, Qg=0.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 1842	: Vg=1.034 -> Vg=1.0158755
% INFO    : Gen at bus 1852	: Vg=1.032 -> Vg=1.015872
% INFO    : Gen at bus 1852	: Vg=1.032 -> Vg=1.015872
% INFO    : Gen at bus 1860	: Vg=1.05 -> Vg=1.0000025
% INFO    : Gen at bus 1863	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 1863	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 1868	: Pg=5.13, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1868	: Vg=1.04 -> Vg=1.0111115
% INFO    : Gen at bus 1868	: Pg=8.13, Qg=0.0 -> Pg=18.25, Qg=0.0
% INFO    : Gen at bus 1868	: Vg=1.04 -> Vg=1.0111115
% INFO    : Gen at bus 1868	: Pg=10.13, Qg=0.0 -> Pg=21.75, Qg=0.0
% INFO    : Gen at bus 1868	: Vg=1.04 -> Vg=1.0111115
% INFO    : Gen at bus 1869	: Pg=1.41, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 1869	: Vg=1.022 -> Vg=1.022224
% INFO    : Gen at bus 1870	: Pg=38.45, Qg=7.91 -> Pg=22.0, Qg=5.5
% INFO    : Gen at bus 1870	: Vg=1.026 -> Vg=1.0000005
% INFO    : Gen at bus 1871	: Vg=1.021 -> Vg=0.999999
% INFO    : Gen at bus 1876	: Vg=1.075 -> Vg=1.000001
% INFO    : Gen at bus 1885	: Pg=0.81, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 1885	: Vg=1.032 -> Vg=1.022224
% INFO    : Gen at bus 1893	: Pg=18.3, Qg=-0.76 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1893	: Vg=1.036 -> Vg=0.975
% INFO    : Gen at bus 1894	: Pg=15.83, Qg=-1.37 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1894	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 1895	: Pg=18.73, Qg=0.76 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1895	: Vg=1.04 -> Vg=0.975
% INFO    : Gen at bus 1896	: Pg=18.21, Qg=1.24 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1896	: Vg=1.041 -> Vg=0.975
% INFO    : Gen at bus 1908	: Vg=1.024 -> Vg=0.999999
% INFO    : Gen at bus 1927	: Vg=1.06 -> Vg=1.000001
% INFO    : Gen at bus 1940	: Vg=1.018 -> Vg=0.999999
% INFO    : Gen at bus 1939	: Vg=1.017 -> Vg=0.999999
% INFO    : Gen at bus 1948	: Pg=18.18, Qg=1.9 -> Pg=15.0, Qg=1.95
% INFO    : Gen at bus 1948	: Vg=1.038 -> Vg=1.0000025
% INFO    : Gen at bus 1959	: Vg=0.989 -> Vg=1.0000025
% INFO    : Gen at bus 1967	: Pg=14.69, Qg=-5.32 -> Pg=12.0, Qg=0.5
% INFO    : Gen at bus 1967	: Vg=1.053 -> Vg=0.975
% INFO    : Gen at bus 1968	: Pg=14.2, Qg=2.88 -> Pg=12.0, Qg=2.82
% INFO    : Gen at bus 1968	: Vg=1.062 -> Vg=0.975
% INFO    : Gen at bus 1969	: Pg=17.19, Qg=-4.77 -> Pg=12.0, Qg=0.5
% INFO    : Gen at bus 1969	: Vg=1.053 -> Vg=0.975
% INFO    : Gen at bus 1970	: Pg=16.18, Qg=3.29 -> Pg=12.0, Qg=0.5
% INFO    : Gen at bus 1970	: Vg=1.062 -> Vg=0.975
% INFO    : Gen at bus 1971	: Pg=15.17, Qg=3.78 -> Pg=12.0, Qg=0.5
% INFO    : Gen at bus 1971	: Vg=1.063 -> Vg=0.975
% INFO    : Gen at bus 1980	: Pg=25.24, Qg=0.83 -> Pg=14.5, Qg=0.0
% INFO    : Gen at bus 1980	: Vg=1.033 -> Vg=0.975
% INFO    : Gen at bus 1980	: Pg=24.27, Qg=0.83 -> Pg=14.5, Qg=0.0
% INFO    : Gen at bus 1980	: Vg=1.033 -> Vg=0.975
% INFO    : Gen at bus 1981	: Pg=25.01, Qg=-6.4 -> Pg=14.5, Qg=-6.5
% INFO    : Gen at bus 1981	: Vg=1.003 -> Vg=0.999999
% INFO    : Gen at bus 1982	: Pg=26.21, Qg=-2.07 -> Pg=14.5, Qg=-5.0
% INFO    : Gen at bus 1982	: Vg=1.017 -> Vg=0.999999
% INFO    : Gen at bus 1984	: Vg=1.023 -> Vg=1.0000025
% INFO    : Gen at bus 1986	: Pg=1.65, Qg=-2.0 -> Pg=2.55, Qg=0.0
% INFO    : Gen at bus 1986	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 1986	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 1992	: Vg=1.034 -> Vg=0.999999
% INFO    : Gen at bus 2000	: Vg=0.889 -> Vg=0.9444445
% INFO    : Gen at bus 2007	: Pg=23.07, Qg=-1.85 -> Pg=23.0, Qg=6.0
% INFO    : Gen at bus 2007	: Vg=1.026 -> Vg=1.0158755
% INFO    : Gen at bus 2018	: Pg=13.63, Qg=-8.51 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2018	: Vg=1.025 -> Vg=1.0000025
% INFO    : Gen at bus 2019	: Pg=14.02, Qg=-1.94 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2019	: Vg=1.029 -> Vg=1.0000025
% INFO    : Gen at bus 2019	: Pg=14.02, Qg=-1.94 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2019	: Vg=1.029 -> Vg=1.0000025
% INFO    : Gen at bus 2024	: Pg=4.24, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2024	: Vg=1.051 -> Vg=1.027779
% INFO    : Gen at bus 2028	: Pg=21.36, Qg=4.36 -> Pg=0.0, Qg=0.0
% INFO    : Gen at bus 2028	: Vg=1.058 -> Vg=1.000001
% INFO    : Gen at bus 2036	: Pg=0.79, Qg=0.0 -> Pg=4.5, Qg=0.0
% INFO    : Gen at bus 2036	: Vg=1.014 -> Vg=1.0079355
% INFO    : Gen at bus 2050	: Pg=28.2, Qg=5.45 -> Pg=17.0, Qg=1.5
% INFO    : Gen at bus 2050	: Vg=1.027 -> Vg=0.999999
% INFO    : Gen at bus 2060	: Pg=0.02, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2060	: Vg=1.02 -> Vg=1.0000025
% INFO    : Gen at bus 2084	: Vg=1.01 -> Vg=1.0000025
% INFO    : Gen at bus 2097	: Pg=8.05, Qg=0.0 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 2097	: Vg=1.02 -> Vg=1.0079355
% INFO    : Gen at bus 2098	: Pg=39.22, Qg=2.63 -> Pg=27.5, Qg=6.0
% INFO    : Gen at bus 2098	: Vg=1.058 -> Vg=1.022222
% INFO    : Gen at bus 2102	: Pg=7.2, Qg=5.0 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 2102	: Vg=1.014 -> Vg=1.0079355
% INFO    : Gen at bus 2122	: Pg=1.9, Qg=0.0 -> Pg=9.95, Qg=0.0
% INFO    : Gen at bus 2122	: Vg=1.033 -> Vg=1.0079355
% INFO    : Gen at bus 2122	: Pg=4.9, Qg=0.0 -> Pg=16.2, Qg=0.0
% INFO    : Gen at bus 2122	: Vg=1.033 -> Vg=1.0079355
% INFO    : Gen at bus 2150	: Pg=2.78, Qg=0.0 -> Pg=5.125, Qg=0.0
% INFO    : Gen at bus 2150	: Vg=1.037 -> Vg=1.022224
% INFO    : Gen at bus 2150	: Pg=3.78, Qg=0.0 -> Pg=3.0, Qg=0.0
% INFO    : Gen at bus 2150	: Vg=1.037 -> Vg=1.022224
% INFO    : Gen at bus 2160	: Pg=14.3, Qg=5.41 -> Pg=14.5, Qg=3.5
% INFO    : Gen at bus 2160	: Vg=1.063 -> Vg=1.027779
% INFO    : Gen at bus 2164	: Vg=1.031 -> Vg=1.0000005
% INFO    : Gen at bus 2165	: Pg=0.23, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2165	: Vg=1.071 -> Vg=1.033333
% INFO    : Gen at bus 2181	: Vg=1.05 -> Vg=1.0000025
% INFO    : Gen at bus 2181	: Vg=1.05 -> Vg=1.0000025
% INFO    : Gen at bus 2186	: Pg=4.26, Qg=0.0 -> Pg=4.6, Qg=0.0
% INFO    : Gen at bus 2186	: Vg=1.059 -> Vg=1.027779
% INFO    : Gen at bus 2189	: Vg=1.016 -> Vg=0.9682545
% INFO    : Gen at bus 2189	: Vg=1.016 -> Vg=0.9682545
% INFO    : Gen at bus 2191	: Vg=1.065 -> Vg=1.022222
% INFO    : Gen at bus 2192	: Pg=7.62, Qg=1.66 -> Pg=7.5, Qg=0.0
% INFO    : Gen at bus 2192	: Vg=0.895 -> Vg=0.9444445
% INFO    : Gen at bus 2194	: Pg=15.9, Qg=2.0 -> Pg=10.0, Qg=1.95
% INFO    : Gen at bus 2194	: Vg=1.065 -> Vg=1.000001
% INFO    : Gen at bus 2225	: Vg=1.058 -> Vg=1.022222
% INFO    : Gen at bus 2225	: Vg=1.058 -> Vg=1.022222
% INFO    : Gen at bus 2244	: Pg=4.24, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2244	: Vg=1.006 -> Vg=1.0158755
% INFO    : Gen at bus 2244	: Pg=12.24, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 2244	: Vg=1.006 -> Vg=1.0158755
% INFO    : Gen at bus 2246	: Vg=1.069 -> Vg=0.975
% INFO    : Gen at bus 2246	: Pg=4.05, Qg=-1.47 -> Pg=13.25, Qg=0.0
% INFO    : Gen at bus 2246	: Vg=1.069 -> Vg=0.975
% INFO    : Gen at bus 2280	: Pg=4.22, Qg=0.0 -> Pg=6.9, Qg=0.0
% INFO    : Gen at bus 2280	: Vg=1.017 -> Vg=1.0158755
% INFO    : Gen at bus 2290	: Pg=1.72, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2290	: Vg=1.043 -> Vg=1.022224
% INFO    : Gen at bus 2294	: Pg=1.35, Qg=3.53 -> Pg=28.0, Qg=-1.5
% INFO    : Gen at bus 2294	: Vg=0.997 -> Vg=1.0000005
% INFO    : Gen at bus 2296	: Vg=1.029 -> Vg=1.0000005
% INFO    : Gen at bus 2302	: Vg=1.005 -> Vg=1.0158755
% INFO    : Gen at bus 2302	: Vg=1.005 -> Vg=1.0158755
% INFO    : Gen at bus 2328	: Pg=1.07, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2328	: Vg=1.02 -> Vg=1.0158755
% INFO    : Gen at bus 2334	: Vg=1.023 -> Vg=1.015872
% INFO    : Gen at bus 2338	: Vg=1.024 -> Vg=1.0079355
% INFO    : Gen at bus 2340	: Pg=14.1, Qg=-5.16 -> Pg=14.0, Qg=1.5
% INFO    : Gen at bus 2340	: Vg=0.997 -> Vg=1.015872
% INFO    : Gen at bus 2340	: Pg=17.1, Qg=-5.16 -> Pg=14.0, Qg=1.5
% INFO    : Gen at bus 2340	: Vg=0.997 -> Vg=1.015872
% INFO    : Gen at bus 2340	: Pg=12.1, Qg=-5.16 -> Pg=14.0, Qg=1.5
% INFO    : Gen at bus 2340	: Vg=0.997 -> Vg=1.015872
% INFO    : Gen at bus 2341	: Vg=1.055 -> Vg=1.0000025
% INFO    : Gen at bus 2341	: Vg=1.055 -> Vg=1.0000025
% INFO    : Gen at bus 2342	: Pg=2.15, Qg=2.0 -> Pg=3.5, Qg=0.0
% INFO    : Gen at bus 2342	: Vg=1.038 -> Vg=1.022224
% INFO    : Gen at bus 2364	: Pg=21.15, Qg=4.48 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2364	: Vg=1.091 -> Vg=0.975
% INFO    : Gen at bus 2365	: Pg=21.14, Qg=7.57 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2365	: Vg=1.096 -> Vg=0.975
% INFO    : Gen at bus 2366	: Pg=13.31, Qg=-7.13 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2366	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 2367	: Pg=21.14, Qg=4.88 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2367	: Vg=1.091 -> Vg=0.975
% INFO    : Gen at bus 2368	: Pg=11.74, Qg=9.74 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 2368	: Vg=1.1 -> Vg=0.975
% INFO    : Gen at bus 2378	: Pg=1.28, Qg=0.0 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 2378	: Vg=1.016 -> Vg=1.0158755
% INFO    : Gen at bus 2395	: Pg=0.03, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2395	: Vg=1.013 -> Vg=1.0000025
% INFO    : Gen at bus 2397	: Vg=1.01 -> Vg=1.0000025
% INFO    : Gen at bus 2397	: Vg=1.01 -> Vg=1.0000025
% INFO    : Gen at bus 2413	: Pg=8.78, Qg=1.94 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 2413	: Vg=1.058 -> Vg=1.000001
% INFO    : Gen at bus 2415	: Vg=1.022 -> Vg=1.0079355
% INFO    : Gen at bus 2415	: Pg=7.79, Qg=0.0 -> Pg=9.6, Qg=0.0
% INFO    : Gen at bus 2415	: Vg=1.022 -> Vg=1.0079355
% INFO    : Gen at bus 2422	: Pg=1.26, Qg=0.0 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 2422	: Vg=1.017 -> Vg=1.0158755
% INFO    : Gen at bus 2422	: Pg=6.26, Qg=0.0 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 2422	: Vg=1.017 -> Vg=1.0158755
% INFO    : Gen at bus 2422	: Pg=4.26, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2422	: Vg=1.017 -> Vg=1.0158755
% INFO    : Gen at bus 2434	: Pg=3.07, Qg=0.0 -> Pg=9.85, Qg=0.0
% INFO    : Gen at bus 2434	: Vg=1.023 -> Vg=1.0079355
% INFO    : Gen at bus 2438	: Vg=1.026 -> Vg=0.999999
% INFO    : Gen at bus 2438	: Vg=1.026 -> Vg=0.999999
% INFO    : Gen at bus 2441	: Vg=1.024 -> Vg=0.999999
% INFO    : Gen at bus 2441	: Vg=1.024 -> Vg=0.999999
% INFO    : Gen at bus 2446	: Pg=6.04, Qg=0.0 -> Pg=5.2, Qg=0.0
% INFO    : Gen at bus 2446	: Vg=1.021 -> Vg=1.0079355
% INFO    : Gen at bus 2445	: Pg=14.05, Qg=0.0 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 2445	: Vg=1.01 -> Vg=1.0079355
% INFO    : Gen at bus 2462	: Vg=1.072 -> Vg=1.044445
% INFO    : Gen at bus 2463	: Vg=1.012 -> Vg=1.015872
% INFO    : Gen at bus 2463	: Pg=0.02, Qg=1.91 -> Pg=2.25, Qg=0.0
% INFO    : Gen at bus 2463	: Vg=1.012 -> Vg=1.015872
% INFO    : Gen at bus 2466	: Vg=1.041 -> Vg=1.022224
% INFO    : Gen at bus 2477	: Vg=1.025 -> Vg=0.999999
% INFO    : Gen at bus 2483	: Vg=1.013 -> Vg=1.0000025
% INFO    : Gen at bus 2497	: Vg=1.019 -> Vg=1.015872
% INFO    : Gen at bus 2525	: Pg=40.2, Qg=1.34 -> Pg=44.0, Qg=5.5
% INFO    : Gen at bus 2525	: Vg=1.153 -> Vg=1.054343
% INFO    : Gen at bus 2525	: Pg=42.2, Qg=1.34 -> Pg=44.0, Qg=5.5
% INFO    : Gen at bus 2525	: Vg=1.153 -> Vg=1.054343
% INFO    : Gen at bus 2531	: Pg=1.96, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 2531	: Vg=0.974 -> Vg=1.0000025
% INFO    : Gen at bus 2531	: Pg=2.96, Qg=0.0 -> Pg=18.425, Qg=0.0
% INFO    : Gen at bus 2531	: Vg=0.974 -> Vg=1.0000025
% INFO    : Gen at bus 2532	: Vg=1.043 -> Vg=1.0000025
% INFO    : Gen at bus 2532	: Vg=1.043 -> Vg=1.0000025
% INFO    : Gen at bus 2534	: Pg=4.5, Qg=-0.96 -> Pg=4.8, Qg=0.005
% INFO    : Gen at bus 2534	: Vg=1.013 -> Vg=1.0158755
% INFO    : Gen at bus 2547	: Vg=1.014 -> Vg=1.0000025
% INFO    : Gen at bus 2549	: Vg=1.027 -> Vg=0.999999
% INFO    : Gen at bus 2557	: Vg=1.059 -> Vg=1.0000025
% INFO    : Gen at bus 2557	: Vg=1.059 -> Vg=1.0000025
% INFO    : Gen at bus 2560	: Pg=6.66, Qg=0.42 -> Pg=8.0, Qg=1.5
% INFO    : Gen at bus 2560	: Vg=1.016 -> Vg=0.999999
% INFO    : Gen at bus 2565	: Pg=2.18, Qg=0.0 -> Pg=8.4, Qg=0.0
% INFO    : Gen at bus 2565	: Vg=1.018 -> Vg=1.0079355
% INFO    : Gen at bus 2578	: Vg=1.026 -> Vg=1.0158755
% INFO    : Gen at bus 2578	: Vg=1.026 -> Vg=1.0158755
% INFO    : Gen at bus 2583	: Vg=1.048 -> Vg=1.022224
% INFO    : Gen at bus 2588	: Pg=1.11, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2588	: Vg=1.039 -> Vg=1.022224
% INFO    : Gen at bus 2588	: Pg=4.11, Qg=0.0 -> Pg=10.35, Qg=0.0
% INFO    : Gen at bus 2588	: Vg=1.039 -> Vg=1.022224
% INFO    : Gen at bus 2594	: Vg=1.001 -> Vg=0.975
% INFO    : Gen at bus 2603	: Pg=4.23, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2603	: Vg=1.015 -> Vg=1.0079355
% INFO    : Gen at bus 2603	: Vg=1.015 -> Vg=1.0079355
% INFO    : Gen at bus 2612	: Vg=1.012 -> Vg=1.0000025
% INFO    : Gen at bus 2613	: Vg=1.016 -> Vg=1.015872
% INFO    : Gen at bus 2618	: Pg=1.55, Qg=0.0 -> Pg=5.525, Qg=0.0
% INFO    : Gen at bus 2618	: Vg=1.02 -> Vg=1.022224
% INFO    : Gen at bus 2626	: Pg=0.2, Qg=0.0 -> Pg=18.75, Qg=0.0
% INFO    : Gen at bus 2626	: Vg=1.061 -> Vg=1.0111115
% INFO    : Gen at bus 2626	: Vg=1.061 -> Vg=1.0111115
% INFO    : Gen at bus 2629	: Pg=7.99, Qg=-0.95 -> Pg=14.0, Qg=4.5
% INFO    : Gen at bus 2629	: Vg=1.006 -> Vg=1.0158755
% INFO    : Gen at bus 2642	: Vg=1.043 -> Vg=1.0000025
% INFO    : Gen at bus 2642	: Vg=1.043 -> Vg=1.0000025
% INFO    : Gen at bus 2642	: Vg=1.043 -> Vg=1.0000025
% INFO    : Gen at bus 2645	: Vg=1.011 -> Vg=1.0000025
% INFO    : Gen at bus 2646	: Pg=7.24, Qg=3.46 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 2646	: Vg=1.011 -> Vg=1.0000025
% INFO    : Gen at bus 2647	: Vg=1.029 -> Vg=1.0000025
% INFO    : Gen at bus 2647	: Pg=11.13, Qg=-6.9 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 2647	: Vg=1.029 -> Vg=1.0000025
% INFO    : Gen at bus 2647	: Vg=1.029 -> Vg=1.0000025
% INFO    : Gen at bus 2648	: Vg=1.054 -> Vg=1.0000025
% INFO    : Gen at bus 2648	: Vg=1.054 -> Vg=1.0000025
% INFO    : Gen at bus 2648	: Vg=1.054 -> Vg=1.0000025
% INFO    : Gen at bus 2651	: Pg=1.15, Qg=0.0 -> Pg=17.5, Qg=0.0
% INFO    : Gen at bus 2651	: Vg=1.01 -> Vg=1.0158755
% INFO    : Gen at bus 2651	: Vg=1.01 -> Vg=1.0158755
% INFO    : Gen at bus 2654	: Pg=4.11, Qg=4.0 -> Pg=14.0, Qg=3.95
% INFO    : Gen at bus 2654	: Vg=1.066 -> Vg=1.0000025
% INFO    : Gen at bus 2661	: Vg=1.018 -> Vg=0.999999
% INFO    : Gen at bus 2661	: Pg=4.5, Qg=-0.8 -> Pg=4.9, Qg=0.0
% INFO    : Gen at bus 2661	: Vg=1.018 -> Vg=0.999999
% INFO    : Gen at bus 2662	: Pg=30.2, Qg=4.77 -> Pg=17.5, Qg=-1.5
% INFO    : Gen at bus 2662	: Vg=1.009 -> Vg=1.015872
% INFO    : Gen at bus 2662	: Pg=31.2, Qg=4.77 -> Pg=17.5, Qg=-1.5
% INFO    : Gen at bus 2662	: Vg=1.009 -> Vg=1.015872
% INFO    : Gen at bus 2665	: Vg=0.993 -> Vg=0.975
% INFO    : Gen at bus 2666	: Pg=3.12, Qg=0.9 -> Pg=3.5, Qg=0.95
% INFO    : Gen at bus 2666	: Vg=1.078 -> Vg=0.975
% INFO    : Gen at bus 2665	: Vg=0.993 -> Vg=0.975
% INFO    : Gen at bus 2664	: Pg=0.74, Qg=-4.63 -> Pg=6.0, Qg=-1.5
% INFO    : Gen at bus 2664	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 2666	: Vg=1.078 -> Vg=0.975
% INFO    : Gen at bus 2667	: Pg=2.08, Qg=3.01 -> Pg=6.0, Qg=-1.205
% INFO    : Gen at bus 2667	: Vg=0.993 -> Vg=1.0000025
% INFO    : Gen at bus 2671	: Vg=0.5 -> Vg=0.825
% INFO    : Gen at bus 2671	: Vg=0.5 -> Vg=0.825
% INFO    : Gen at bus 2671	: Vg=0.5 -> Vg=0.825
% INFO    : Gen at bus 2671	: Vg=0.5 -> Vg=0.825
% INFO    : Gen at bus 2671	: Vg=0.5 -> Vg=0.825
% INFO    : Gen at bus 2676	: Pg=3.9, Qg=0.0 -> Pg=3.075, Qg=0.0
% INFO    : Gen at bus 2676	: Vg=0.997 -> Vg=1.0079355
% INFO    : Gen at bus 2690	: Pg=0.16, Qg=0.0 -> Pg=18.2, Qg=0.0
% INFO    : Gen at bus 2690	: Vg=1.067 -> Vg=1.033333
% INFO    : Gen at bus 2697	: Pg=6.05, Qg=-3.46 -> Pg=7.5, Qg=-0.5
% INFO    : Gen at bus 2697	: Vg=1.018 -> Vg=1.0000005
% INFO    : Gen at bus 2730	: Pg=5.21, Qg=0.0 -> Pg=10.9, Qg=0.0
% INFO    : Gen at bus 2730	: Vg=1.045 -> Vg=1.022224
% INFO    : Gen at bus 2735	: Pg=4.97, Qg=0.85 -> Pg=8.5, Qg=0.0
% INFO    : Gen at bus 2735	: Vg=1.06 -> Vg=1.000001
% INFO    : Gen at bus 2735	: Pg=4.97, Qg=0.85 -> Pg=8.5, Qg=0.0
% INFO    : Gen at bus 2735	: Vg=1.06 -> Vg=1.000001
% INFO    : Gen at bus 2767	: Vg=1.049 -> Vg=1.0000025
% INFO    : Gen at bus 2777	: Vg=1.032 -> Vg=1.0158755
% INFO    : Gen at bus 2813	: Pg=1.68, Qg=0.0 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 2813	: Vg=1.027 -> Vg=1.022224
% INFO    : Gen at bus 2814	: Vg=1.019 -> Vg=0.984126
% INFO    : Gen at bus 2819	: Vg=1.065 -> Vg=1.0000025
% INFO    : Gen at bus 2823	: Vg=1.043 -> Vg=1.022224
% INFO    : Gen at bus 2834	: Pg=8.23, Qg=5.0 -> Pg=6.0, Qg=1.5
% INFO    : Gen at bus 2834	: Vg=1.035 -> Vg=1.0000005
% INFO    : Gen at bus 2839	: Vg=1.057 -> Vg=1.033334
% INFO    : Gen at bus 2841	: Pg=4.21, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 2841	: Vg=1.042 -> Vg=1.022224
% INFO    : Gen at bus 2841	: Pg=0.21, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2841	: Vg=1.042 -> Vg=1.022224
% INFO    : Gen at bus 2844	: Pg=0.34, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2844	: Vg=1.009 -> Vg=1.022224
% INFO    : Gen at bus 2844	: Pg=6.34, Qg=0.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 2844	: Vg=1.009 -> Vg=1.022224
% INFO    : Gen at bus 2846	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 2846	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 2858	: Pg=4.08, Qg=0.0 -> Pg=8.8, Qg=0.0
% INFO    : Gen at bus 2858	: Vg=1.029 -> Vg=1.0079355
% INFO    : Gen at bus 2869	: Pg=0.45, Qg=0.0 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 2869	: Vg=1.02 -> Vg=1.022224
% INFO    : Gen at bus 2875	: Pg=4.51, Qg=0.0 -> Pg=6.9, Qg=0.0
% INFO    : Gen at bus 2875	: Vg=1.064 -> Vg=1.027779
% INFO    : Gen at bus 2877	: Pg=2.77, Qg=0.0 -> Pg=7.4, Qg=0.0
% INFO    : Gen at bus 2877	: Vg=1.019 -> Vg=1.022224
% INFO    : Gen at bus 2877	: Vg=1.019 -> Vg=1.022224
% INFO    : Gen at bus 2885	: Vg=1.025 -> Vg=1.0158755
% INFO    : Gen at bus 2900	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 2900	: Pg=7.06, Qg=-1.38 -> Pg=16.25, Qg=0.0
% INFO    : Gen at bus 2900	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 2900	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 2905	: Vg=1.073 -> Vg=1.0
% INFO    : Gen at bus 2905	: Vg=1.073 -> Vg=1.0
% INFO    : Gen at bus 2905	: Vg=1.073 -> Vg=1.0
% INFO    : Gen at bus 2909	: Vg=1.023 -> Vg=1.0000025
% INFO    : Gen at bus 2929	: Vg=1.005 -> Vg=0.999999
% INFO    : Gen at bus 2930	: Vg=1.046 -> Vg=1.000001
% INFO    : Gen at bus 2942	: Pg=6.32, Qg=0.0 -> Pg=17.25, Qg=0.0
% INFO    : Gen at bus 2942	: Vg=1.009 -> Vg=1.022224
% INFO    : Gen at bus 2949	: Vg=1.01 -> Vg=1.0158755
% INFO    : Gen at bus 2955	: Pg=5.65, Qg=0.0 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 2955	: Vg=1.045 -> Vg=1.022224
% INFO    : Gen at bus 2955	: Pg=1.65, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 2955	: Vg=1.045 -> Vg=1.022224
% INFO    : Gen at bus 2977	: Vg=1.025 -> Vg=1.0158755
% INFO    : Gen at bus 2984	: Pg=1.53, Qg=0.0 -> Pg=4.1, Qg=0.0
% INFO    : Gen at bus 2984	: Vg=1.063 -> Vg=1.027779
% INFO    : Gen at bus 2995	: Pg=12.04, Qg=-6.36 -> Pg=17.0, Qg=0.0
% INFO    : Gen at bus 2995	: Vg=1.033 -> Vg=0.999999
% INFO    : Gen at bus 3022	: Vg=0.999 -> Vg=1.0158755
% INFO    : Gen at bus 3022	: Vg=0.999 -> Vg=1.0158755
% INFO    : Gen at bus 3023	: Pg=1.06, Qg=-0.83 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 3023	: Vg=1.016 -> Vg=0.999999
% INFO    : Gen at bus 3025	: Pg=3.55, Qg=0.0 -> Pg=9.2, Qg=0.0
% INFO    : Gen at bus 3025	: Vg=1.023 -> Vg=1.022224
% INFO    : Gen at bus 3028	: Vg=1.048 -> Vg=1.0000025
% INFO    : Gen at bus 3028	: Vg=1.048 -> Vg=1.0000025
% INFO    : Gen at bus 3030	: Pg=8.22, Qg=0.0 -> Pg=5.75, Qg=0.0
% INFO    : Gen at bus 3030	: Vg=1.064 -> Vg=1.022222
% INFO    : Gen at bus 3037	: Vg=1.016 -> Vg=1.015872
% INFO    : Gen at bus 3039	: Vg=1.064 -> Vg=1.044445
% INFO    : Gen at bus 3050	: Pg=4.14, Qg=0.0 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 3050	: Vg=0.997 -> Vg=1.015872
% INFO    : Gen at bus 3060	: Vg=1.026 -> Vg=0.999999
% INFO    : Gen at bus 3061	: Vg=1.036 -> Vg=1.022224
% INFO    : Gen at bus 3071	: Pg=6.08, Qg=0.0 -> Pg=8.625, Qg=0.0
% INFO    : Gen at bus 3071	: Vg=0.995 -> Vg=1.015872
% INFO    : Gen at bus 3098	: Vg=0.962 -> Vg=0.9444445
% INFO    : Gen at bus 3107	: Vg=1.02 -> Vg=0.999999
% INFO    : Gen at bus 3110	: Vg=1.063 -> Vg=1.0377785
% INFO    : Gen at bus 3113	: Pg=1.19, Qg=0.0 -> Pg=5.55, Qg=0.0
% INFO    : Gen at bus 3113	: Vg=1.012 -> Vg=1.0079355
% INFO    : Gen at bus 3116	: Pg=35.3, Qg=-1.34 -> Pg=19.0, Qg=0.5
% INFO    : Gen at bus 3116	: Vg=1.056 -> Vg=0.975
% INFO    : Gen at bus 3117	: Pg=30.7, Qg=8.79 -> Pg=19.0, Qg=0.5
% INFO    : Gen at bus 3117	: Vg=1.092 -> Vg=0.975
% INFO    : Gen at bus 3118	: Pg=31.74, Qg=9.43 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3118	: Vg=1.093 -> Vg=0.975
% INFO    : Gen at bus 3122	: Vg=1.042 -> Vg=1.022224
% INFO    : Gen at bus 3123	: Pg=0.1, Qg=1.34 -> Pg=8.4, Qg=0.0
% INFO    : Gen at bus 3123	: Vg=1.032 -> Vg=0.999999
% INFO    : Gen at bus 3123	: Pg=0.1, Qg=1.34 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 3123	: Vg=1.032 -> Vg=0.999999
% INFO    : Gen at bus 3125	: Pg=12.1, Qg=0.0 -> Pg=10.4, Qg=0.0
% INFO    : Gen at bus 3125	: Vg=1.023 -> Vg=0.999999
% INFO    : Gen at bus 3126	: Vg=1.008 -> Vg=1.0000025
% INFO    : Gen at bus 3131	: Vg=0.991 -> Vg=1.015872
% INFO    : Gen at bus 3132	: Pg=0.33, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 3132	: Vg=1.017 -> Vg=1.022224
% INFO    : Gen at bus 3132	: Pg=2.33, Qg=0.0 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 3132	: Vg=1.017 -> Vg=1.022224
% INFO    : Gen at bus 3136	: Pg=0.0, Qg=1.0 -> Pg=5.5, Qg=0.95
% INFO    : Gen at bus 3136	: Vg=1.072 -> Vg=1.000001
% INFO    : Gen at bus 3136	: Vg=1.072 -> Vg=1.000001
% INFO    : Gen at bus 3140	: Vg=1.073 -> Vg=1.0377785
% INFO    : Gen at bus 3140	: Vg=1.073 -> Vg=1.0377785
% INFO    : Gen at bus 3142	: Vg=0.971 -> Vg=1.0000025
% INFO    : Gen at bus 3147	: Vg=1.005 -> Vg=1.0000025
% INFO    : Gen at bus 3147	: Vg=1.005 -> Vg=1.0000025
% INFO    : Gen at bus 3151	: Pg=4.96, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3151	: Vg=1.0 -> Vg=1.0158755
% INFO    : Gen at bus 3157	: Pg=40.19, Qg=-0.47 -> Pg=26.5, Qg=6.0
% INFO    : Gen at bus 3157	: Vg=1.059 -> Vg=1.0111115
% INFO    : Gen at bus 3159	: Vg=1.074 -> Vg=1.000001
% INFO    : Gen at bus 3159	: Vg=1.074 -> Vg=1.000001
% INFO    : Gen at bus 3159	: Pg=5.11, Qg=5.69 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 3159	: Vg=1.074 -> Vg=1.000001
% INFO    : Gen at bus 3178	: Vg=1.015 -> Vg=1.0
% INFO    : Gen at bus 3178	: Vg=1.015 -> Vg=1.0
% INFO    : Gen at bus 3185	: Pg=1.17, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 3185	: Vg=1.046 -> Vg=1.000001
% INFO    : Gen at bus 3185	: Pg=1.17, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3185	: Vg=1.046 -> Vg=1.000001
% INFO    : Gen at bus 3188	: Pg=4.1, Qg=0.0 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 3188	: Vg=1.039 -> Vg=0.999999
% INFO    : Gen at bus 3188	: Vg=1.039 -> Vg=0.999999
% INFO    : Gen at bus 3210	: Pg=1.12, Qg=0.0 -> Pg=10.0, Qg=1.0
% INFO    : Gen at bus 3210	: Vg=1.073 -> Vg=1.0
% INFO    : Gen at bus 3219	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 3219	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 3238	: Pg=2.06, Qg=0.0 -> Pg=11.15, Qg=0.0
% INFO    : Gen at bus 3238	: Vg=1.025 -> Vg=1.0158755
% INFO    : Gen at bus 3239	: Vg=1.061 -> Vg=1.000001
% INFO    : Gen at bus 3241	: Vg=1.004 -> Vg=0.999999
% INFO    : Gen at bus 3244	: Pg=3.42, Qg=0.0 -> Pg=4.6, Qg=0.0
% INFO    : Gen at bus 3244	: Vg=1.054 -> Vg=1.027779
% INFO    : Gen at bus 3246	: Vg=0.997 -> Vg=1.0000025
% INFO    : Gen at bus 3250	: Vg=1.036 -> Vg=1.022224
% INFO    : Gen at bus 3260	: Pg=4.38, Qg=0.0 -> Pg=3.75, Qg=0.0
% INFO    : Gen at bus 3260	: Vg=1.051 -> Vg=1.027779
% INFO    : Gen at bus 3264	: Vg=1.015 -> Vg=1.0000025
% INFO    : Gen at bus 3265	: Pg=4.3, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3265	: Vg=1.036 -> Vg=1.022224
% INFO    : Gen at bus 3265	: Pg=7.3, Qg=0.0 -> Pg=16.35, Qg=0.0
% INFO    : Gen at bus 3265	: Vg=1.036 -> Vg=1.022224
% INFO    : Gen at bus 3265	: Pg=0.3, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3265	: Vg=1.036 -> Vg=1.022224
% INFO    : Gen at bus 3266	: Pg=28.59, Qg=11.27 -> Pg=21.0, Qg=2.5
% INFO    : Gen at bus 3266	: Vg=1.051 -> Vg=1.0
% INFO    : Gen at bus 3266	: Pg=34.7, Qg=11.27 -> Pg=21.0, Qg=2.5
% INFO    : Gen at bus 3266	: Vg=1.051 -> Vg=1.0
% INFO    : Gen at bus 3276	: Vg=1.036 -> Vg=1.0000025
% INFO    : Gen at bus 3276	: Vg=1.036 -> Vg=1.0000025
% INFO    : Gen at bus 3280	: Pg=33.31, Qg=11.56 -> Pg=18.05, Qg=2.5
% INFO    : Gen at bus 3280	: Vg=1.116 -> Vg=0.975
% INFO    : Gen at bus 3281	: Pg=33.32, Qg=8.78 -> Pg=18.05, Qg=2.5
% INFO    : Gen at bus 3281	: Vg=1.048 -> Vg=0.975
% INFO    : Gen at bus 3282	: Pg=33.32, Qg=-0.13 -> Pg=18.05, Qg=2.5
% INFO    : Gen at bus 3282	: Vg=1.025 -> Vg=0.975
% INFO    : Gen at bus 3295	: Vg=1.016 -> Vg=0.999999
% INFO    : Gen at bus 3301	: Vg=1.035 -> Vg=1.015872
% INFO    : Gen at bus 3308	: Pg=0.0, Qg=0.9 -> Pg=8.5, Qg=0.95
% INFO    : Gen at bus 3308	: Vg=1.0 -> Vg=1.0000025
% INFO    : Gen at bus 3308	: Pg=0.0, Qg=0.9 -> Pg=8.5, Qg=0.95
% INFO    : Gen at bus 3308	: Vg=1.0 -> Vg=1.0000025
% INFO    : Gen at bus 3313	: Vg=1.024 -> Vg=0.999999
% INFO    : Gen at bus 3313	: Vg=1.024 -> Vg=0.999999
% INFO    : Gen at bus 3315	: Pg=2.77, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3315	: Vg=1.05 -> Vg=1.022224
% INFO    : Gen at bus 3315	: Pg=0.77, Qg=0.0 -> Pg=9.7, Qg=0.0
% INFO    : Gen at bus 3315	: Vg=1.05 -> Vg=1.022224
% INFO    : Gen at bus 3339	: Pg=2.36, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 3339	: Vg=1.004 -> Vg=1.022224
% INFO    : Gen at bus 3345	: Vg=1.028 -> Vg=0.999999
% INFO    : Gen at bus 3377	: Pg=4.42, Qg=0.0 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 3377	: Vg=1.057 -> Vg=1.027779
% INFO    : Gen at bus 3377	: Pg=15.42, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 3377	: Vg=1.057 -> Vg=1.027779
% INFO    : Gen at bus 3382	: Pg=2.14, Qg=0.0 -> Pg=19.9, Qg=0.0
% INFO    : Gen at bus 3382	: Vg=1.057 -> Vg=1.0111115
% INFO    : Gen at bus 3383	: Vg=1.069 -> Vg=1.0000025
% INFO    : Gen at bus 3405	: Pg=39.94, Qg=12.98 -> Pg=21.5, Qg=6.0
% INFO    : Gen at bus 3405	: Vg=1.02 -> Vg=1.0158755
% INFO    : Gen at bus 3408	: Pg=3.25, Qg=-5.97 -> Pg=12.0, Qg=-0.13
% INFO    : Gen at bus 3408	: Vg=1.034 -> Vg=0.999999
% INFO    : Gen at bus 3418	: Vg=1.006 -> Vg=1.0000025
% INFO    : Gen at bus 3418	: Pg=4.32, Qg=1.0 -> Pg=3.75, Qg=0.0
% INFO    : Gen at bus 3418	: Vg=1.006 -> Vg=1.0000025
% INFO    : Gen at bus 3418	: Vg=1.006 -> Vg=1.0000025
% INFO    : Gen at bus 3418	: Vg=1.006 -> Vg=1.0000025
% INFO    : Gen at bus 3418	: Vg=1.006 -> Vg=1.0000025
% INFO    : Gen at bus 3423	: Pg=10.21, Qg=0.0 -> Pg=17.5, Qg=0.0
% INFO    : Gen at bus 3423	: Vg=1.047 -> Vg=1.022224
% INFO    : Gen at bus 3423	: Pg=9.21, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3423	: Vg=1.047 -> Vg=1.022224
% INFO    : Gen at bus 3424	: Pg=12.87, Qg=0.05 -> Pg=11.55, Qg=0.0
% INFO    : Gen at bus 3424	: Vg=0.997 -> Vg=0.999999
% INFO    : Gen at bus 3424	: Pg=12.87, Qg=0.05 -> Pg=11.55, Qg=0.0
% INFO    : Gen at bus 3424	: Vg=0.997 -> Vg=0.999999
% INFO    : Gen at bus 3431	: Vg=1.0 -> Vg=1.015872
% INFO    : Gen at bus 3434	: Pg=11.8, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 3434	: Vg=1.024 -> Vg=1.022224
% INFO    : Gen at bus 3437	: Pg=11.36, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 3437	: Vg=1.045 -> Vg=1.022224
% INFO    : Gen at bus 3440	: Pg=2.06, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3440	: Vg=1.031 -> Vg=1.0079355
% INFO    : Gen at bus 3440	: Pg=2.06, Qg=0.0 -> Pg=5.25, Qg=0.0
% INFO    : Gen at bus 3440	: Vg=1.031 -> Vg=1.0079355
% INFO    : Gen at bus 3445	: Vg=1.026 -> Vg=1.0079355
% INFO    : Gen at bus 3450	: Pg=4.09, Qg=0.0 -> Pg=10.275, Qg=0.0
% INFO    : Gen at bus 3450	: Vg=1.054 -> Vg=1.0079355
% INFO    : Gen at bus 3451	: Vg=1.032 -> Vg=1.0079355
% INFO    : Gen at bus 3454	: Pg=0.33, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3454	: Vg=1.054 -> Vg=1.027779
% INFO    : Gen at bus 3461	: Vg=1.014 -> Vg=1.0158755
% INFO    : Gen at bus 3468	: Pg=8.76, Qg=-5.69 -> Pg=6.6, Qg=0.0
% INFO    : Gen at bus 3468	: Vg=1.014 -> Vg=0.999999
% INFO    : Gen at bus 3488	: Vg=1.026 -> Vg=1.0079355
% INFO    : Gen at bus 3491	: Vg=1.08 -> Vg=1.00713
% INFO    : Gen at bus 3491	: Pg=35.78, Qg=-2.47 -> Pg=26.5, Qg=3.5
% INFO    : Gen at bus 3491	: Vg=1.08 -> Vg=1.00713
% INFO    : Gen at bus 3495	: Pg=9.19, Qg=0.0 -> Pg=10.6, Qg=0.0
% INFO    : Gen at bus 3495	: Vg=1.025 -> Vg=1.0079355
% INFO    : Gen at bus 3502	: Vg=1.031 -> Vg=1.0000025
% INFO    : Gen at bus 3502	: Vg=1.031 -> Vg=1.0000025
% INFO    : Gen at bus 3505	: Vg=1.058 -> Vg=1.044445
% INFO    : Gen at bus 3506	: Vg=0.995 -> Vg=0.975
% INFO    : Gen at bus 3508	: Vg=1.027 -> Vg=0.999999
% INFO    : Gen at bus 3509	: Pg=1.1, Qg=0.0 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 3509	: Vg=1.031 -> Vg=0.999999
% INFO    : Gen at bus 3514	: Pg=7.0, Qg=0.0 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 3514	: Vg=1.024 -> Vg=1.0158755
% INFO    : Gen at bus 3514	: Pg=1.0, Qg=0.0 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 3514	: Vg=1.024 -> Vg=1.0158755
% INFO    : Gen at bus 3522	: Vg=1.044 -> Vg=0.999999
% INFO    : Gen at bus 3531	: Pg=7.11, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 3531	: Vg=0.989 -> Vg=1.015872
% INFO    : Gen at bus 3545	: Pg=2.33, Qg=-0.92 -> Pg=6.4, Qg=0.0
% INFO    : Gen at bus 3545	: Vg=1.03 -> Vg=0.999999
% INFO    : Gen at bus 3546	: Pg=1.84, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3546	: Vg=1.048 -> Vg=1.0079355
% INFO    : Gen at bus 3551	: Vg=1.026 -> Vg=1.0158755
% INFO    : Gen at bus 3551	: Vg=1.026 -> Vg=1.0158755
% INFO    : Gen at bus 3551	: Vg=1.026 -> Vg=1.0158755
% INFO    : Gen at bus 3550	: Vg=1.118 -> Vg=1.0424305
% INFO    : Gen at bus 3585	: Pg=4.32, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 3585	: Vg=1.052 -> Vg=1.027779
% INFO    : Gen at bus 3588	: Pg=16.92, Qg=-2.19 -> Pg=10.4, Qg=-2.0
% INFO    : Gen at bus 3588	: Vg=1.019 -> Vg=0.975
% INFO    : Gen at bus 3588	: Pg=15.93, Qg=-2.19 -> Pg=10.4, Qg=0.0
% INFO    : Gen at bus 3588	: Vg=1.019 -> Vg=0.975
% INFO    : Gen at bus 3587	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 3587	: Pg=17.13, Qg=-2.51 -> Pg=10.4, Qg=0.0
% INFO    : Gen at bus 3587	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 3600	: Pg=33.05, Qg=-2.41 -> Pg=19.5, Qg=0.0
% INFO    : Gen at bus 3600	: Vg=1.08 -> Vg=1.002375
% INFO    : Gen at bus 3602	: Vg=1.075 -> Vg=1.000001
% INFO    : Gen at bus 3602	: Vg=1.075 -> Vg=1.000001
% INFO    : Gen at bus 3602	: Vg=1.075 -> Vg=1.000001
% INFO    : Gen at bus 3606	: Pg=12.67, Qg=8.14 -> Pg=0.0, Qg=10.0
% INFO    : Gen at bus 3606	: Vg=1.025 -> Vg=0.999999
% INFO    : Gen at bus 3606	: Pg=12.67, Qg=8.14 -> Pg=0.0, Qg=0.0
% INFO    : Gen at bus 3606	: Vg=1.025 -> Vg=0.999999
% INFO    : Gen at bus 3638	: Vg=1.045 -> Vg=0.999999
% INFO    : Gen at bus 3648	: Vg=0.96 -> Vg=1.0000025
% INFO    : Gen at bus 3648	: Vg=0.96 -> Vg=1.0000025
% INFO    : Gen at bus 3651	: Vg=1.042 -> Vg=1.022224
% INFO    : Gen at bus 3653	: Pg=0.0, Qg=0.9 -> Pg=3.5, Qg=0.95
% INFO    : Gen at bus 3653	: Vg=1.03 -> Vg=1.0000025
% INFO    : Gen at bus 3653	: Pg=0.0, Qg=0.9 -> Pg=3.5, Qg=0.95
% INFO    : Gen at bus 3653	: Vg=1.03 -> Vg=1.0000025
% INFO    : Gen at bus 3654	: Vg=1.022 -> Vg=1.0158755
% INFO    : Gen at bus 3659	: Vg=0.983 -> Vg=1.0000025
% INFO    : Gen at bus 3662	: Vg=1.017 -> Vg=1.0158755
% INFO    : Gen at bus 3663	: Vg=1.026 -> Vg=1.0079355
% INFO    : Gen at bus 3668	: Vg=0.979 -> Vg=0.999999
% INFO    : Gen at bus 3668	: Vg=0.979 -> Vg=0.999999
% INFO    : Gen at bus 3669	: Vg=0.999 -> Vg=0.999999
% INFO    : Gen at bus 3685	: Vg=1.035 -> Vg=1.015872
% INFO    : Gen at bus 3687	: Pg=0.19, Qg=1.8 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 3687	: Vg=1.016 -> Vg=0.999999
% INFO    : Gen at bus 3693	: Pg=1.95, Qg=-2.53 -> Pg=4.75, Qg=0.0
% INFO    : Gen at bus 3693	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 3695	: Vg=1.045 -> Vg=1.0111115
% INFO    : Gen at bus 3697	: Vg=1.027 -> Vg=0.999999
% INFO    : Gen at bus 3714	: Pg=3.09, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 3714	: Vg=1.013 -> Vg=1.0079355
% INFO    : Gen at bus 3716	: Pg=12.46, Qg=6.01 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 3716	: Vg=1.062 -> Vg=1.027779
% INFO    : Gen at bus 3717	: Vg=1.011 -> Vg=0.999999
% INFO    : Gen at bus 3718	: Pg=41.12, Qg=-5.73 -> Pg=22.0, Qg=0.0
% INFO    : Gen at bus 3718	: Vg=1.031 -> Vg=0.999999
% INFO    : Gen at bus 3745	: Vg=1.023 -> Vg=0.999999
% INFO    : Gen at bus 3749	: Pg=8.35, Qg=2.37 -> Pg=8.4, Qg=0.25
% INFO    : Gen at bus 3749	: Vg=1.02 -> Vg=0.999999
% INFO    : Gen at bus 3754	: Pg=13.51, Qg=0.0 -> Pg=21.5, Qg=0.0
% INFO    : Gen at bus 3754	: Vg=1.05 -> Vg=1.022224
% INFO    : Gen at bus 3759	: Pg=0.15, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 3759	: Vg=1.021 -> Vg=0.984126
% INFO    : Gen at bus 3759	: Vg=1.021 -> Vg=0.984126
% INFO    : Gen at bus 3761	: Pg=7.19, Qg=0.0 -> Pg=11.025, Qg=0.0
% INFO    : Gen at bus 3761	: Vg=1.012 -> Vg=1.0079355
% INFO    : Gen at bus 3762	: Pg=5.87, Qg=-1.2 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3762	: Vg=0.998 -> Vg=1.0158755
% INFO    : Gen at bus 3797	: Vg=1.055 -> Vg=1.0000025
% INFO    : Gen at bus 3797	: Vg=1.055 -> Vg=1.0000025
% INFO    : Gen at bus 3800	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 3800	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 3800	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 3802	: Pg=2.03, Qg=0.0 -> Pg=10.01, Qg=0.0
% INFO    : Gen at bus 3802	: Vg=1.012 -> Vg=1.0000025
% INFO    : Gen at bus 3802	: Pg=1.03, Qg=0.0 -> Pg=10.175, Qg=0.0
% INFO    : Gen at bus 3802	: Vg=1.012 -> Vg=1.0000025
% INFO    : Gen at bus 3817	: Pg=35.11, Qg=3.28 -> Pg=18.9, Qg=2.0
% INFO    : Gen at bus 3817	: Vg=1.07 -> Vg=0.975
% INFO    : Gen at bus 3818	: Pg=31.87, Qg=-1.19 -> Pg=18.9, Qg=2.0
% INFO    : Gen at bus 3818	: Vg=1.056 -> Vg=0.975
% INFO    : Gen at bus 3819	: Pg=31.17, Qg=7.94 -> Pg=18.9, Qg=2.0
% INFO    : Gen at bus 3819	: Vg=1.087 -> Vg=0.975
% INFO    : Gen at bus 3823	: Pg=5.72, Qg=0.0 -> Pg=13.6, Qg=0.0
% INFO    : Gen at bus 3823	: Vg=1.039 -> Vg=1.022224
% INFO    : Gen at bus 3827	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 3837	: Vg=1.051 -> Vg=1.0000025
% INFO    : Gen at bus 3843	: Pg=3.15, Qg=-2.75 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3843	: Vg=1.016 -> Vg=0.999999
% INFO    : Gen at bus 3843	: Pg=3.15, Qg=-2.75 -> Pg=6.5, Qg=0.0
% INFO    : Gen at bus 3843	: Vg=1.016 -> Vg=0.999999
% INFO    : Gen at bus 3854	: Pg=5.16, Qg=-3.41 -> Pg=11.0, Qg=1.0
% INFO    : Gen at bus 3854	: Vg=1.032 -> Vg=1.0000025
% INFO    : Gen at bus 3864	: Pg=0.32, Qg=0.0 -> Pg=3.34, Qg=0.0
% INFO    : Gen at bus 3864	: Vg=1.042 -> Vg=1.022224
% INFO    : Gen at bus 3869	: Pg=6.15, Qg=3.0 -> Pg=4.5, Qg=0.0
% INFO    : Gen at bus 3869	: Vg=1.04 -> Vg=1.022224
% INFO    : Gen at bus 3870	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 3877	: Vg=1.041 -> Vg=1.0000025
% INFO    : Gen at bus 3890	: Pg=5.14, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3890	: Vg=1.033 -> Vg=1.0277795
% INFO    : Gen at bus 3894	: Vg=1.041 -> Vg=1.0079355
% INFO    : Gen at bus 3894	: Vg=1.041 -> Vg=1.0079355
% INFO    : Gen at bus 3905	: Pg=4.12, Qg=0.0 -> Pg=6.6, Qg=0.0
% INFO    : Gen at bus 3905	: Vg=1.041 -> Vg=1.0079355
% INFO    : Gen at bus 3905	: Pg=10.12, Qg=0.0 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 3905	: Vg=1.041 -> Vg=1.0079355
% INFO    : Gen at bus 3920	: Vg=1.024 -> Vg=1.0000025
% INFO    : Gen at bus 3925	: Vg=1.054 -> Vg=1.015874
% INFO    : Gen at bus 3926	: Vg=1.059 -> Vg=1.026667
% INFO    : Gen at bus 3928	: Vg=1.012 -> Vg=1.015872
% INFO    : Gen at bus 3940	: Vg=1.043 -> Vg=1.000001
% INFO    : Gen at bus 3941	: Vg=1.007 -> Vg=1.0000025
% INFO    : Gen at bus 3952	: Pg=1.56, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3952	: Vg=1.011 -> Vg=1.0158755
% INFO    : Gen at bus 3970	: Pg=36.79, Qg=-0.67 -> Pg=20.5, Qg=0.0
% INFO    : Gen at bus 3970	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 3970	: Pg=37.18, Qg=-0.67 -> Pg=20.5, Qg=0.0
% INFO    : Gen at bus 3970	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 3969	: Pg=37.16, Qg=-1.2 -> Pg=20.5, Qg=-5.0
% INFO    : Gen at bus 3969	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 3969	: Pg=35.08, Qg=-1.2 -> Pg=20.5, Qg=-5.0
% INFO    : Gen at bus 3969	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 3978	: Vg=1.029 -> Vg=1.000001
% INFO    : Gen at bus 3978	: Vg=1.029 -> Vg=1.000001
% INFO    : Gen at bus 3988	: Vg=0.998 -> Vg=1.015872
% INFO    : Gen at bus 3988	: Vg=0.998 -> Vg=1.015872
% INFO    : Gen at bus 3988	: Pg=1.16, Qg=2.25 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 3988	: Vg=0.998 -> Vg=1.015872
% INFO    : Gen at bus 3999	: Vg=1.02 -> Vg=1.0000025
% INFO    : Gen at bus 3999	: Pg=0.02, Qg=0.0 -> Pg=12.4, Qg=0.0
% INFO    : Gen at bus 3999	: Vg=1.02 -> Vg=1.0000025
% INFO    : Gen at bus 4001	: Pg=0.18, Qg=0.0 -> Pg=6.9, Qg=0.0
% INFO    : Gen at bus 4001	: Vg=1.058 -> Vg=1.022222
% INFO    : Gen at bus 4001	: Pg=5.18, Qg=0.0 -> Pg=11.35, Qg=0.0
% INFO    : Gen at bus 4001	: Vg=1.058 -> Vg=1.022222
% INFO    : Gen at bus 4026	: Pg=3.94, Qg=-1.67 -> Pg=5.3, Qg=0.0
% INFO    : Gen at bus 4026	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 4030	: Vg=0.891 -> Vg=0.9444445
% INFO    : Gen at bus 4032	: Pg=20.2, Qg=0.0 -> Pg=15.2, Qg=0.0
% INFO    : Gen at bus 4032	: Vg=1.055 -> Vg=1.0111115
% INFO    : Gen at bus 4032	: Pg=5.2, Qg=0.0 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 4032	: Vg=1.055 -> Vg=1.0111115
% INFO    : Gen at bus 4055	: Pg=6.23, Qg=0.0 -> Pg=13.0, Qg=0.0
% INFO    : Gen at bus 4055	: Vg=1.016 -> Vg=1.0079355
% INFO    : Gen at bus 4056	: Pg=21.21, Qg=6.0 -> Pg=13.5, Qg=-2.5
% INFO    : Gen at bus 4056	: Vg=1.027 -> Vg=1.015872
% INFO    : Gen at bus 4056	: Pg=20.21, Qg=6.0 -> Pg=13.5, Qg=-2.5
% INFO    : Gen at bus 4056	: Vg=1.027 -> Vg=1.015872
% INFO    : Gen at bus 4066	: Pg=7.17, Qg=0.0 -> Pg=8.55, Qg=0.0
% INFO    : Gen at bus 4066	: Vg=1.037 -> Vg=1.0079355
% INFO    : Gen at bus 4072	: Vg=1.048 -> Vg=1.027779
% INFO    : Gen at bus 4110	: Pg=1.21, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 4110	: Vg=1.046 -> Vg=1.022224
% INFO    : Gen at bus 4127	: Vg=1.02 -> Vg=1.0079355
% INFO    : Gen at bus 4131	: Pg=1.99, Qg=-1.93 -> Pg=6.15, Qg=0.0
% INFO    : Gen at bus 4131	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 4131	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 4131	: Pg=1.99, Qg=-1.93 -> Pg=6.15, Qg=0.0
% INFO    : Gen at bus 4131	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 4133	: Vg=0.999 -> Vg=1.015872
% INFO    : Gen at bus 4133	: Vg=0.999 -> Vg=1.015872
% INFO    : Gen at bus 4171	: Pg=19.09, Qg=0.23 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 4171	: Vg=1.038 -> Vg=1.0000025
% INFO    : Gen at bus 4200	: Pg=5.31, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 4200	: Vg=1.04 -> Vg=1.022224
% INFO    : Gen at bus 4200	: Pg=5.31, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 4200	: Vg=1.04 -> Vg=1.022224
% INFO    : Gen at bus 4219	: Pg=1.33, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 4219	: Vg=1.031 -> Vg=1.0158755
% INFO    : Gen at bus 4218	: Vg=1.029 -> Vg=1.0158755
% INFO    : Gen at bus 4233	: Pg=9.99, Qg=0.0 -> Pg=6.5, Qg=6.5
% INFO    : Gen at bus 4233	: Vg=1.02 -> Vg=0.999999
% INFO    : Gen at bus 4237	: Pg=13.77, Qg=0.0 -> Pg=8.2, Qg=0.0
% INFO    : Gen at bus 4237	: Vg=1.036 -> Vg=1.022224
% INFO    : Gen at bus 4246	: Vg=1.06 -> Vg=1.000001
% INFO    : Gen at bus 4247	: Vg=0.982 -> Vg=1.015872
% INFO    : Gen at bus 4262	: Pg=6.16, Qg=0.0 -> Pg=7.75, Qg=0.0
% INFO    : Gen at bus 4262	: Vg=1.035 -> Vg=1.0079355
% INFO    : Gen at bus 4262	: Pg=10.16, Qg=0.0 -> Pg=12.85, Qg=0.0
% INFO    : Gen at bus 4262	: Vg=1.035 -> Vg=1.0079355
% INFO    : Gen at bus 4276	: Pg=6.77, Qg=-0.22 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 4276	: Vg=1.033 -> Vg=0.975
% INFO    : Gen at bus 4276	: Pg=5.79, Qg=-0.22 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 4276	: Vg=1.033 -> Vg=0.975
% INFO    : Gen at bus 4277	: Vg=1.035 -> Vg=1.015872
% INFO    : Gen at bus 4277	: Vg=1.035 -> Vg=1.015872
% INFO    : Gen at bus 4295	: Vg=1.008 -> Vg=1.015872
% INFO    : Gen at bus 4301	: Pg=19.08, Qg=-0.62 -> Pg=23.0, Qg=-7.0
% INFO    : Gen at bus 4301	: Vg=1.014 -> Vg=0.999999
% INFO    : Gen at bus 4302	: Vg=1.028 -> Vg=0.999999
% INFO    : Gen at bus 4303	: Vg=1.027 -> Vg=1.0000025
% INFO    : Gen at bus 4307	: Vg=1.026 -> Vg=1.0079355
% INFO    : Gen at bus 4311	: Vg=1.032 -> Vg=0.999999
% INFO    : Gen at bus 4311	: Vg=1.032 -> Vg=0.999999
% INFO    : Gen at bus 4317	: Pg=41.13, Qg=14.24 -> Pg=22.0, Qg=0.0
% INFO    : Gen at bus 4317	: Vg=1.043 -> Vg=0.999999
% INFO    : Gen at bus 4321	: Pg=15.17, Qg=-2.85 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 4321	: Vg=1.063 -> Vg=1.000001
% INFO    : Gen at bus 4322	: Vg=1.023 -> Vg=1.0000025
% INFO    : Gen at bus 4326	: Vg=1.053 -> Vg=1.0111115
% INFO    : Gen at bus 4328	: Pg=2.04, Qg=0.0 -> Pg=5.5, Qg=0.0
% INFO    : Gen at bus 4328	: Vg=1.047 -> Vg=1.0079355
% INFO    : Gen at bus 4328	: Vg=1.047 -> Vg=1.0079355
% INFO    : Gen at bus 4329	: Pg=22.2, Qg=7.77 -> Pg=19.5, Qg=0.0
% INFO    : Gen at bus 4329	: Vg=0.996 -> Vg=0.999999
% INFO    : Gen at bus 4339	: Vg=1.044 -> Vg=1.0000025
% INFO    : Gen at bus 4339	: Vg=1.044 -> Vg=1.0000025
% INFO    : Gen at bus 4347	: Pg=15.0, Qg=1.9 -> Pg=13.0, Qg=1.95
% INFO    : Gen at bus 4347	: Vg=1.012 -> Vg=1.0000025
% INFO    : Gen at bus 4354	: Vg=1.008 -> Vg=1.0000025
% INFO    : Gen at bus 4377	: Vg=0.974 -> Vg=1.0158755
% INFO    : Gen at bus 4380	: Pg=3.72, Qg=0.0 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 4380	: Vg=1.035 -> Vg=1.022224
% INFO    : Gen at bus 4385	: Vg=1.031 -> Vg=1.015872
% INFO    : Gen at bus 4385	: Vg=1.031 -> Vg=1.015872
% INFO    : Gen at bus 4385	: Vg=1.031 -> Vg=1.015872
% INFO    : Gen at bus 4394	: Pg=2.13, Qg=0.0 -> Pg=6.8, Qg=0.0
% INFO    : Gen at bus 4394	: Vg=1.024 -> Vg=1.0079355
% INFO    : Gen at bus 4414	: Pg=0.05, Qg=0.0 -> Pg=1.3, Qg=0.0
% INFO    : Gen at bus 4414	: Vg=1.019 -> Vg=1.0079355
% INFO    : Gen at bus 4414	: Pg=11.05, Qg=0.0 -> Pg=8.95, Qg=0.0
% INFO    : Gen at bus 4414	: Vg=1.019 -> Vg=1.0079355
% INFO    : Gen at bus 4415	: Vg=0.974 -> Vg=1.0079355
% INFO    : Gen at bus 4415	: Pg=7.93, Qg=0.0 -> Pg=5.125, Qg=0.0
% INFO    : Gen at bus 4415	: Vg=0.974 -> Vg=1.0079355
% INFO    : Gen at bus 4416	: Vg=1.03 -> Vg=1.015872
% INFO    : Gen at bus 4431	: Pg=0.23, Qg=0.95 -> Pg=3.0, Qg=0.0
% INFO    : Gen at bus 4431	: Vg=0.989 -> Vg=1.0000025
% INFO    : Gen at bus 4449	: Pg=0.11, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 4449	: Vg=1.004 -> Vg=0.999999
% INFO    : Gen at bus 4449	: Vg=1.004 -> Vg=0.999999
% INFO    : Gen at bus 4454	: Pg=2.06, Qg=0.0 -> Pg=14.95, Qg=0.0
% INFO    : Gen at bus 4454	: Vg=1.052 -> Vg=1.0000025
% INFO    : Gen at bus 4455	: Vg=1.004 -> Vg=1.0000025
% INFO    : Gen at bus 4473	: Vg=1.043 -> Vg=1.0000025
% INFO    : Gen at bus 4475	: Vg=0.983 -> Vg=1.0000025
% INFO    : Gen at bus 4476	: Pg=15.16, Qg=1.37 -> Pg=11.85, Qg=0.73
% INFO    : Gen at bus 4476	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 4477	: Pg=16.78, Qg=0.4 -> Pg=11.85, Qg=2.0
% INFO    : Gen at bus 4477	: Vg=1.052 -> Vg=0.975
% INFO    : Gen at bus 4478	: Pg=18.78, Qg=0.44 -> Pg=11.85, Qg=2.0
% INFO    : Gen at bus 4478	: Vg=1.052 -> Vg=0.975
% INFO    : Gen at bus 4479	: Pg=18.76, Qg=-1.58 -> Pg=11.85, Qg=2.0
% INFO    : Gen at bus 4479	: Vg=1.049 -> Vg=0.975
% INFO    : Gen at bus 4480	: Pg=18.79, Qg=0.94 -> Pg=11.85, Qg=2.0
% INFO    : Gen at bus 4480	: Vg=1.052 -> Vg=0.975
% INFO    : Gen at bus 4493	: Vg=1.029 -> Vg=1.0158755
% INFO    : Gen at bus 4506	: Vg=1.009 -> Vg=1.015872
% INFO    : Gen at bus 4509	: Pg=12.11, Qg=-0.94 -> Pg=10.5, Qg=1.1
% INFO    : Gen at bus 4509	: Vg=1.037 -> Vg=0.975
% INFO    : Gen at bus 4509	: Pg=12.11, Qg=-0.94 -> Pg=10.5, Qg=1.0
% INFO    : Gen at bus 4509	: Vg=1.037 -> Vg=0.975
% INFO    : Gen at bus 4513	: Pg=12.37, Qg=-20.81 -> Pg=43.5, Qg=0.87
% INFO    : Gen at bus 4513	: Vg=1.061 -> Vg=1.044445
% INFO    : Gen at bus 4535	: Vg=0.5 -> Vg=0.825
% INFO    : Gen at bus 4535	: Vg=0.5 -> Vg=0.825
% INFO    : Gen at bus 4535	: Vg=0.5 -> Vg=0.825
% INFO    : Gen at bus 4535	: Vg=0.5 -> Vg=0.825
% INFO    : Gen at bus 4535	: Vg=0.5 -> Vg=0.825
% INFO    : Gen at bus 4564	: Pg=14.2, Qg=3.94 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 4564	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 4568	: Vg=1.024 -> Vg=1.0000025
% INFO    : Gen at bus 4571	: Pg=42.0, Qg=23.34 -> Pg=44.5, Qg=9.0
% INFO    : Gen at bus 4571	: Vg=1.053 -> Vg=1.0377785
% INFO    : Gen at bus 4571	: Pg=43.0, Qg=23.34 -> Pg=44.5, Qg=9.0
% INFO    : Gen at bus 4571	: Vg=1.053 -> Vg=1.0377785
% INFO    : Gen at bus 4579	: Vg=1.015 -> Vg=1.0000025
% INFO    : Gen at bus 4580	: Vg=1.028 -> Vg=0.999999
% INFO    : Gen at bus 4582	: Pg=0.15, Qg=0.0 -> Pg=3.0, Qg=0.0
% INFO    : Gen at bus 4582	: Vg=1.001 -> Vg=1.015872
% INFO    : Gen at bus 4585	: Vg=1.033 -> Vg=1.0000025
% INFO    : Gen at bus 4585	: Pg=4.66, Qg=1.0 -> Pg=6.35, Qg=0.95
% INFO    : Gen at bus 4585	: Vg=1.033 -> Vg=1.0000025
% INFO    : Gen at bus 4620	: Pg=9.28, Qg=0.0 -> Pg=18.4, Qg=0.0
% INFO    : Gen at bus 4620	: Vg=1.024 -> Vg=1.022224
% INFO    : Gen at bus 4631	: Pg=2.4, Qg=0.0 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 4631	: Vg=1.03 -> Vg=1.022224
% INFO    : Gen at bus 4632	: Vg=0.997 -> Vg=1.0000025
% INFO    : Gen at bus 4633	: Vg=1.032 -> Vg=1.0000025
% INFO    : Gen at bus 4642	: Pg=6.29, Qg=0.0 -> Pg=15.75, Qg=0.0
% INFO    : Gen at bus 4642	: Vg=1.025 -> Vg=1.022224
% INFO    : Gen at bus 4643	: Pg=8.29, Qg=0.0 -> Pg=16.5, Qg=0.0
% INFO    : Gen at bus 4643	: Vg=1.027 -> Vg=1.022224
% INFO    : Gen at bus 4648	: Pg=1.42, Qg=0.0 -> Pg=8.75, Qg=0.0
% INFO    : Gen at bus 4648	: Vg=1.071 -> Vg=1.027779
% INFO    : Gen at bus 4654	: Vg=1.053 -> Vg=1.0000025
% INFO    : Gen at bus 4658	: Pg=0.27, Qg=0.0 -> Pg=5.75, Qg=0.0
% INFO    : Gen at bus 4658	: Vg=1.019 -> Vg=1.022224
% INFO    : Gen at bus 4659	: Pg=10.31, Qg=0.0 -> Pg=17.5, Qg=0.0
% INFO    : Gen at bus 4659	: Vg=1.033 -> Vg=1.022224
% INFO    : Gen at bus 4666	: Pg=1.28, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 4666	: Vg=1.027 -> Vg=1.022224
% INFO    : Gen at bus 4666	: Pg=4.28, Qg=0.0 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 4666	: Vg=1.027 -> Vg=1.022224
% INFO    : Gen at bus 4672	: Vg=0.983 -> Vg=0.975
% INFO    : Gen at bus 4672	: Vg=0.983 -> Vg=0.975
% INFO    : Gen at bus 4672	: Vg=0.983 -> Vg=0.975
% INFO    : Gen at bus 4671	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 4672	: Vg=0.983 -> Vg=0.975
% INFO    : Gen at bus 4672	: Vg=0.983 -> Vg=0.975
% INFO    : Gen at bus 4671	: Pg=6.63, Qg=0.1 -> Pg=10.5, Qg=0.54
% INFO    : Gen at bus 4671	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 4685	: Pg=4.19, Qg=0.0 -> Pg=7.0, Qg=0.0
% INFO    : Gen at bus 4685	: Vg=1.053 -> Vg=1.000001
% INFO    : Gen at bus 4700	: Vg=1.031 -> Vg=1.015872
% INFO    : Gen at bus 4700	: Vg=1.031 -> Vg=1.015872
% INFO    : Gen at bus 4700	: Vg=1.031 -> Vg=1.015872
% INFO    : Gen at bus 4717	: Vg=1.053 -> Vg=1.0000025
% INFO    : Gen at bus 4717	: Vg=1.053 -> Vg=1.0000025
% INFO    : Gen at bus 4718	: Vg=1.073 -> Vg=1.0
% INFO    : Gen at bus 4718	: Vg=1.073 -> Vg=1.0
% INFO    : Gen at bus 4719	: Vg=1.012 -> Vg=1.0158755
% INFO    : Gen at bus 4720	: Pg=2.15, Qg=1.0 -> Pg=5.0, Qg=0.95
% INFO    : Gen at bus 4720	: Vg=1.068 -> Vg=1.0000025
% INFO    : Gen at bus 4720	: Pg=8.15, Qg=1.0 -> Pg=7.5, Qg=0.95
% INFO    : Gen at bus 4720	: Vg=1.068 -> Vg=1.0000025
% INFO    : Gen at bus 4720	: Vg=1.068 -> Vg=1.0000025
% INFO    : Gen at bus 4755	: Pg=1.7, Qg=0.03 -> Pg=4.5, Qg=0.0
% INFO    : Gen at bus 4755	: Vg=1.024 -> Vg=1.0000025
% INFO    : Gen at bus 4756	: Pg=6.09, Qg=2.35 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 4756	: Vg=1.013 -> Vg=1.015872
% INFO    : Gen at bus 4756	: Pg=6.09, Qg=2.35 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 4756	: Vg=1.013 -> Vg=1.015872
% INFO    : Gen at bus 4757	: Pg=6.09, Qg=3.85 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 4757	: Vg=1.013 -> Vg=1.015872
% INFO    : Gen at bus 4757	: Pg=6.09, Qg=3.85 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 4757	: Vg=1.013 -> Vg=1.015872
% INFO    : Gen at bus 4766	: Pg=13.13, Qg=0.33 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 4766	: Vg=1.038 -> Vg=1.0233335
% INFO    : Gen at bus 4769	: Vg=1.057 -> Vg=1.027779
% INFO    : Gen at bus 4777	: Vg=0.983 -> Vg=1.0000025
% INFO    : Gen at bus 4782	: Pg=0.23, Qg=0.0 -> Pg=14.0, Qg=0.0
% INFO    : Gen at bus 4782	: Vg=1.023 -> Vg=1.0000005
% INFO    : Gen at bus 4788	: Pg=1.77, Qg=0.0 -> Pg=4.6, Qg=0.0
% INFO    : Gen at bus 4788	: Vg=1.023 -> Vg=1.022224
% INFO    : Gen at bus 4793	: Pg=0.95, Qg=-3.51 -> Pg=7.0, Qg=0.0
% INFO    : Gen at bus 4793	: Vg=1.028 -> Vg=0.999999
% INFO    : Gen at bus 4804	: Pg=16.29, Qg=1.1 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 4804	: Vg=1.001 -> Vg=0.999999
% INFO    : Gen at bus 4814	: Pg=8.5, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 4814	: Vg=1.062 -> Vg=1.027779
% INFO    : Gen at bus 4817	: Pg=3.34, Qg=-0.64 -> Pg=3.2, Qg=0.0
% INFO    : Gen at bus 4817	: Vg=1.016 -> Vg=1.0158755
% INFO    : Gen at bus 4818	: Pg=10.12, Qg=0.5 -> Pg=8.0, Qg=-0.45
% INFO    : Gen at bus 4818	: Vg=1.013 -> Vg=0.975
% INFO    : Gen at bus 4818	: Pg=10.12, Qg=0.5 -> Pg=7.5, Qg=-0.5
% INFO    : Gen at bus 4818	: Vg=1.013 -> Vg=0.975
% INFO    : Gen at bus 4819	: Pg=9.12, Qg=-0.51 -> Pg=7.5, Qg=-0.5
% INFO    : Gen at bus 4819	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 4819	: Pg=8.12, Qg=-0.51 -> Pg=8.0, Qg=-0.45
% INFO    : Gen at bus 4819	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 4824	: Vg=1.08 -> Vg=0.975
% INFO    : Gen at bus 4825	: Pg=129.5, Qg=9.71 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 4825	: Vg=1.085 -> Vg=0.975
% INFO    : Gen at bus 4825	: Pg=85.71, Qg=9.71 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 4825	: Vg=1.085 -> Vg=0.975
% INFO    : Gen at bus 4824	: Pg=128.77, Qg=19.2 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 4824	: Vg=1.08 -> Vg=0.975
% INFO    : Gen at bus 4832	: Vg=1.044 -> Vg=0.984126
% INFO    : Gen at bus 4832	: Vg=1.044 -> Vg=0.984126
% INFO    : Gen at bus 4843	: Vg=1.045 -> Vg=0.999999
% INFO    : Gen at bus 4851	: Pg=1.62, Qg=-0.41 -> Pg=3.2, Qg=0.0
% INFO    : Gen at bus 4851	: Vg=0.904 -> Vg=0.9444445
% INFO    : Gen at bus 4851	: Pg=1.62, Qg=-0.41 -> Pg=5.4, Qg=0.0
% INFO    : Gen at bus 4851	: Vg=0.904 -> Vg=0.9444445
% INFO    : Gen at bus 4864	: Vg=1.019 -> Vg=0.999999
% INFO    : Gen at bus 4864	: Vg=1.019 -> Vg=0.999999
% INFO    : Gen at bus 4871	: Pg=0.41, Qg=-0.1 -> Pg=11.0, Qg=-2.5
% INFO    : Gen at bus 4871	: Vg=1.046 -> Vg=1.033334
% INFO    : Gen at bus 4878	: Pg=9.58, Qg=-1.67 -> Pg=6.4, Qg=0.0
% INFO    : Gen at bus 4878	: Vg=1.027 -> Vg=0.999999
% INFO    : Gen at bus 4882	: Pg=3.11, Qg=0.0 -> Pg=17.51, Qg=0.0
% INFO    : Gen at bus 4882	: Vg=1.039 -> Vg=1.0111115
% INFO    : Gen at bus 4882	: Pg=2.11, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 4882	: Vg=1.039 -> Vg=1.0111115
% INFO    : Gen at bus 4894	: Vg=1.026 -> Vg=1.0158755
% INFO    : Gen at bus 4898	: Vg=1.01 -> Vg=0.999999
% INFO    : Gen at bus 4900	: Vg=1.035 -> Vg=1.0158755
% INFO    : Gen at bus 4900	: Pg=0.09, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 4900	: Vg=1.035 -> Vg=1.0158755
% INFO    : Gen at bus 4900	: Pg=0.09, Qg=0.0 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 4900	: Vg=1.035 -> Vg=1.0158755
% INFO    : Gen at bus 4920	: Pg=25.07, Qg=6.87 -> Pg=16.0, Qg=2.0
% INFO    : Gen at bus 4920	: Vg=1.011 -> Vg=1.015872
% INFO    : Gen at bus 4923	: Pg=27.09, Qg=2.63 -> Pg=16.5, Qg=0.0
% INFO    : Gen at bus 4923	: Vg=1.017 -> Vg=1.0000025
% INFO    : Gen at bus 4930	: Pg=9.52, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 4930	: Vg=1.06 -> Vg=1.027779
% INFO    : Gen at bus 4946	: Pg=6.15, Qg=-1.37 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 4946	: Vg=0.9 -> Vg=0.9444445
% INFO    : Gen at bus 4950	: Vg=1.047 -> Vg=1.027779
% INFO    : Gen at bus 4963	: Pg=7.16, Qg=0.0 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 4963	: Vg=1.056 -> Vg=1.022224
% INFO    : Gen at bus 4963	: Pg=5.16, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 4963	: Vg=1.056 -> Vg=1.022224
% INFO    : Gen at bus 4970	: Vg=1.031 -> Vg=0.999999
% INFO    : Gen at bus 4970	: Pg=14.13, Qg=-3.47 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 4970	: Vg=1.031 -> Vg=0.999999
% INFO    : Gen at bus 4983	: Pg=3.04, Qg=-2.64 -> Pg=16.0, Qg=-1.0
% INFO    : Gen at bus 4983	: Vg=1.008 -> Vg=0.999999
% INFO    : Gen at bus 4984	: Pg=26.57, Qg=9.17 -> Pg=17.55, Qg=-4.5
% INFO    : Gen at bus 4984	: Vg=1.093 -> Vg=0.975
% INFO    : Gen at bus 4985	: Pg=27.71, Qg=7.88 -> Pg=17.55, Qg=-4.5
% INFO    : Gen at bus 4985	: Vg=1.107 -> Vg=0.975
% INFO    : Gen at bus 4986	: Pg=27.73, Qg=7.88 -> Pg=17.55, Qg=-4.5
% INFO    : Gen at bus 4986	: Vg=1.107 -> Vg=0.975
% INFO    : Gen at bus 4993	: Vg=1.007 -> Vg=1.0158755
% INFO    : Gen at bus 4994	: Pg=11.22, Qg=0.0 -> Pg=15.25, Qg=0.0
% INFO    : Gen at bus 4994	: Vg=1.001 -> Vg=1.0158755
% INFO    : Gen at bus 5012	: Vg=1.037 -> Vg=1.0000025
% INFO    : Gen at bus 5012	: Vg=1.037 -> Vg=1.0000025
% INFO    : Gen at bus 5014	: Pg=2.28, Qg=0.0 -> Pg=10.35, Qg=0.0
% INFO    : Gen at bus 5014	: Vg=1.023 -> Vg=1.022224
% INFO    : Gen at bus 5020	: Pg=3.03, Qg=0.0 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 5020	: Vg=1.018 -> Vg=1.0158755
% INFO    : Gen at bus 5024	: Pg=10.61, Qg=4.0 -> Pg=18.0, Qg=3.95
% INFO    : Gen at bus 5024	: Vg=1.062 -> Vg=1.000001
% INFO    : Gen at bus 5030	: Pg=3.65, Qg=-0.76 -> Pg=25.3, Qg=0.505
% INFO    : Gen at bus 5030	: Vg=0.991 -> Vg=1.0000025
% INFO    : Gen at bus 5038	: Vg=0.994 -> Vg=0.999999
% INFO    : Gen at bus 5039	: Vg=1.035 -> Vg=1.022224
% INFO    : Gen at bus 5041	: Vg=1.041 -> Vg=1.0000025
% INFO    : Gen at bus 5041	: Vg=1.041 -> Vg=1.0000025
% INFO    : Gen at bus 5043	: Vg=1.046 -> Vg=1.022222
% INFO    : Gen at bus 5043	: Vg=1.046 -> Vg=1.022222
% INFO    : Gen at bus 5047	: Vg=1.032 -> Vg=1.0277795
% INFO    : Gen at bus 5049	: Vg=1.027 -> Vg=1.0158755
% INFO    : Gen at bus 5049	: Vg=1.027 -> Vg=1.0158755
% INFO    : Gen at bus 5055	: Vg=1.069 -> Vg=1.033333
% INFO    : Gen at bus 5959	: Vg=1.096 -> Vg=0.975
% INFO    : Gen at bus 5959	: Vg=1.096 -> Vg=0.975
% INFO    : Gen at bus 5959	: Vg=1.096 -> Vg=0.975
% INFO    : Gen at bus 5960	: Vg=1.101 -> Vg=0.975
% INFO    : Gen at bus 5960	: Vg=1.101 -> Vg=0.975
% INFO    : Gen at bus 5962	: Vg=1.052 -> Vg=0.975
% INFO    : Gen at bus 5963	: Pg=980.41, Qg=-4.93 -> Pg=700.0, Qg=70.0
% INFO    : Gen at bus 5963	: Vg=1.098 -> Vg=0.975
% INFO    : Gen at bus 5963	: Pg=1002.41, Qg=-4.93 -> Pg=700.0, Qg=70.0
% INFO    : Gen at bus 5963	: Vg=1.098 -> Vg=0.975
% INFO    : Gen at bus 5965	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 5966	: Vg=1.12 -> Vg=0.975
% INFO    : Gen at bus 5968	: Vg=1.06 -> Vg=0.975
% INFO    : Gen at bus 5968	: Vg=1.06 -> Vg=0.975
% INFO    : Gen at bus 5969	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 5969	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 5973	: Pg=132.5, Qg=-42.98 -> Pg=275.0, Qg=-40.0
% INFO    : Gen at bus 5973	: Vg=1.104 -> Vg=0.975
% INFO    : Gen at bus 5976	: Pg=56.23, Qg=-27.39 -> Pg=29.58, Qg=-4.82
% INFO    : Gen at bus 5976	: Vg=1.075 -> Vg=0.975
% INFO    : Gen at bus 5976	: Pg=56.23, Qg=-27.39 -> Pg=29.58, Qg=-4.82
% INFO    : Gen at bus 5976	: Vg=1.075 -> Vg=0.975
% INFO    : Gen at bus 5984	: Vg=1.069 -> Vg=0.975
% INFO    : Gen at bus 5984	: Vg=1.069 -> Vg=0.975
% INFO    : Gen at bus 5987	: Vg=1.042 -> Vg=0.975
% INFO    : Gen at bus 5987	: Vg=1.042 -> Vg=0.975
% INFO    : Gen at bus 5989	: Pg=169.41, Qg=-1.19 -> Pg=225.0, Qg=0.0
% INFO    : Gen at bus 5989	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 5989	: Pg=297.41, Qg=-1.19 -> Pg=225.0, Qg=0.0
% INFO    : Gen at bus 5989	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 5998	: Vg=1.109 -> Vg=0.975
% INFO    : Gen at bus 5998	: Vg=1.109 -> Vg=0.975
% INFO    : Gen at bus 6003	: Vg=1.081 -> Vg=0.975
% INFO    : Gen at bus 6003	: Vg=1.081 -> Vg=0.975
% INFO    : Gen at bus 6003	: Vg=1.081 -> Vg=0.975
% INFO    : Gen at bus 6003	: Vg=1.081 -> Vg=0.975
% INFO    : Gen at bus 6003	: Vg=1.081 -> Vg=0.975
% INFO    : Gen at bus 6003	: Vg=1.081 -> Vg=0.975
% INFO    : Gen at bus 6004	: Pg=160.17, Qg=65.92 -> Pg=81.535, Qg=9.71
% INFO    : Gen at bus 6004	: Vg=0.993 -> Vg=0.975
% INFO    : Gen at bus 6004	: Pg=262.47, Qg=65.92 -> Pg=132.685, Qg=0.0
% INFO    : Gen at bus 6004	: Vg=0.993 -> Vg=0.975
% INFO    : Gen at bus 6004	: Pg=112.57, Qg=65.92 -> Pg=57.735, Qg=16.85
% INFO    : Gen at bus 6004	: Vg=0.993 -> Vg=0.975
% INFO    : Gen at bus 6007	: Pg=405.43, Qg=-130.52 -> Pg=204.21, Qg=-3.995
% INFO    : Gen at bus 6007	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6010	: Vg=1.068 -> Vg=0.975
% INFO    : Gen at bus 6011	: Vg=1.067 -> Vg=0.975
% INFO    : Gen at bus 6015	: Pg=1.89, Qg=-4.43 -> Pg=301.5, Qg=66.5
% INFO    : Gen at bus 6015	: Vg=1.109 -> Vg=0.975
% INFO    : Gen at bus 6015	: Vg=1.109 -> Vg=0.975
% INFO    : Gen at bus 6015	: Vg=1.109 -> Vg=0.975
% INFO    : Gen at bus 6015	: Pg=10.4, Qg=-4.43 -> Pg=279.0, Qg=98.0
% INFO    : Gen at bus 6015	: Vg=1.109 -> Vg=0.975
% INFO    : Gen at bus 6023	: Vg=1.075 -> Vg=0.975
% INFO    : Gen at bus 6022	: Pg=154.89, Qg=-90.76 -> Pg=78.805, Qg=-21.74
% INFO    : Gen at bus 6022	: Vg=1.079 -> Vg=0.975
% INFO    : Gen at bus 6024	: Pg=272.02, Qg=8.67 -> Pg=137.35, Qg=0.0
% INFO    : Gen at bus 6024	: Vg=1.105 -> Vg=0.975
% INFO    : Gen at bus 6027	: Pg=515.85, Qg=-75.5 -> Pg=259.14, Qg=0.0
% INFO    : Gen at bus 6027	: Vg=1.013 -> Vg=0.975
% INFO    : Gen at bus 6028	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6030	: Pg=1053.26, Qg=11.22 -> Pg=653.0, Qg=235.0
% INFO    : Gen at bus 6030	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6030	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6030	: Pg=409.26, Qg=11.22 -> Pg=304.0, Qg=84.0
% INFO    : Gen at bus 6030	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6030	: Pg=409.26, Qg=11.22 -> Pg=304.0, Qg=72.5
% INFO    : Gen at bus 6030	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6041	: Pg=98.0, Qg=-10.34 -> Pg=350.0, Qg=142.5
% INFO    : Gen at bus 6041	: Vg=1.04 -> Vg=0.975
% INFO    : Gen at bus 6046	: Vg=1.101 -> Vg=0.975
% INFO    : Gen at bus 6050	: Vg=1.111 -> Vg=0.975
% INFO    : Gen at bus 6056	: Pg=402.4, Qg=27.29 -> Pg=202.5, Qg=0.0
% INFO    : Gen at bus 6056	: Vg=1.048 -> Vg=0.975
% INFO    : Gen at bus 6059	: Pg=1089.92, Qg=-68.59 -> Pg=546.385, Qg=0.0
% INFO    : Gen at bus 6059	: Vg=1.095 -> Vg=0.975
% INFO    : Gen at bus 6067	: Pg=1045.28, Qg=-8.43 -> Pg=675.0, Qg=70.0
% INFO    : Gen at bus 6067	: Vg=1.065 -> Vg=0.975
% INFO    : Gen at bus 6067	: Pg=510.28, Qg=-8.43 -> Pg=605.0, Qg=70.0
% INFO    : Gen at bus 6067	: Vg=1.065 -> Vg=0.975
% INFO    : Gen at bus 6067	: Pg=479.28, Qg=-8.43 -> Pg=605.0, Qg=70.0
% INFO    : Gen at bus 6067	: Vg=1.065 -> Vg=0.975
% INFO    : Gen at bus 6070	: Vg=1.101 -> Vg=0.975
% INFO    : Gen at bus 6071	: Vg=1.052 -> Vg=0.975
% INFO    : Gen at bus 6084	: Vg=1.103 -> Vg=0.975
% INFO    : Gen at bus 6085	: Vg=1.108 -> Vg=0.975
% INFO    : Gen at bus 6089	: Vg=1.107 -> Vg=0.975
% INFO    : Gen at bus 6090	: Vg=1.107 -> Vg=0.975
% INFO    : Gen at bus 6091	: Pg=175.48, Qg=60.18 -> Pg=89.0, Qg=5.3
% INFO    : Gen at bus 6091	: Vg=1.08 -> Vg=0.975
% INFO    : Gen at bus 6093	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 6094	: Pg=52.13, Qg=43.63 -> Pg=27.5, Qg=15.75
% INFO    : Gen at bus 6094	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6093	: Pg=6.18, Qg=-2.7 -> Pg=4.5, Qg=0.0
% INFO    : Gen at bus 6093	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 6093	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 6096	: Vg=1.106 -> Vg=0.975
% INFO    : Gen at bus 6095	: Pg=138.09, Qg=12.23 -> Pg=70.45, Qg=0.0
% INFO    : Gen at bus 6095	: Vg=1.099 -> Vg=0.975
% INFO    : Gen at bus 6104	: Pg=1221.92, Qg=-116.25 -> Pg=612.365, Qg=0.0
% INFO    : Gen at bus 6104	: Vg=1.098 -> Vg=0.975
% INFO    : Gen at bus 6105	: Pg=207.44, Qg=-17.19 -> Pg=225.0, Qg=0.0
% INFO    : Gen at bus 6105	: Vg=1.059 -> Vg=0.975
% INFO    : Gen at bus 6107	: Vg=1.076 -> Vg=0.975
% INFO    : Gen at bus 6114	: Pg=63.38, Qg=-3.25 -> Pg=33.0, Qg=0.0
% INFO    : Gen at bus 6114	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6113	: Pg=145.38, Qg=-5.24 -> Pg=74.0, Qg=0.0
% INFO    : Gen at bus 6113	: Vg=1.052 -> Vg=0.975
% INFO    : Gen at bus 6114	: Pg=144.38, Qg=-3.25 -> Pg=73.5, Qg=0.0
% INFO    : Gen at bus 6114	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6113	: Vg=1.052 -> Vg=0.975
% INFO    : Gen at bus 6116	: Vg=1.08 -> Vg=0.975
% INFO    : Gen at bus 6116	: Pg=398.04, Qg=58.84 -> Pg=200.5, Qg=0.0
% INFO    : Gen at bus 6116	: Vg=1.08 -> Vg=0.975
% INFO    : Gen at bus 6118	: Vg=1.108 -> Vg=0.975
% INFO    : Gen at bus 6127	: Pg=735.39, Qg=-33.46 -> Pg=369.0, Qg=0.0
% INFO    : Gen at bus 6127	: Vg=1.097 -> Vg=0.975
% INFO    : Gen at bus 6131	: Pg=1022.24, Qg=83.72 -> Pg=512.405, Qg=0.0
% INFO    : Gen at bus 6131	: Vg=1.103 -> Vg=0.975
% INFO    : Gen at bus 6133	: Vg=1.058 -> Vg=0.975
% INFO    : Gen at bus 6134	: Pg=183.02, Qg=-7.96 -> Pg=93.0, Qg=0.0
% INFO    : Gen at bus 6134	: Vg=1.075 -> Vg=0.975
% INFO    : Gen at bus 6134	: Pg=186.02, Qg=-7.96 -> Pg=94.5, Qg=0.0
% INFO    : Gen at bus 6134	: Vg=1.075 -> Vg=0.975
% INFO    : Gen at bus 6135	: Vg=1.105 -> Vg=0.975
% INFO    : Gen at bus 6135	: Vg=1.105 -> Vg=0.975
% INFO    : Gen at bus 6135	: Vg=1.105 -> Vg=0.975
% INFO    : Gen at bus 6135	: Vg=1.105 -> Vg=0.975
% INFO    : Gen at bus 6140	: Pg=459.46, Qg=43.27 -> Pg=231.0, Qg=0.0
% INFO    : Gen at bus 6140	: Vg=1.083 -> Vg=0.975
% INFO    : Gen at bus 6140	: Pg=163.46, Qg=43.27 -> Pg=83.0, Qg=0.0
% INFO    : Gen at bus 6140	: Vg=1.083 -> Vg=0.975
% INFO    : Gen at bus 6140	: Pg=52.46, Qg=43.27 -> Pg=27.5, Qg=15.25
% INFO    : Gen at bus 6140	: Vg=1.083 -> Vg=0.975
% INFO    : Gen at bus 6140	: Pg=93.46, Qg=43.27 -> Pg=48.0, Qg=9.1
% INFO    : Gen at bus 6140	: Vg=1.083 -> Vg=0.975
% INFO    : Gen at bus 6140	: Pg=66.46, Qg=43.27 -> Pg=34.5, Qg=13.15
% INFO    : Gen at bus 6140	: Vg=1.083 -> Vg=0.975
% INFO    : Gen at bus 6147	: Vg=1.096 -> Vg=0.975
% INFO    : Gen at bus 6158	: Vg=1.078 -> Vg=0.975
% INFO    : Gen at bus 6158	: Vg=1.078 -> Vg=0.975
% INFO    : Gen at bus 6159	: Vg=1.102 -> Vg=0.975
% INFO    : Gen at bus 6161	: Vg=1.101 -> Vg=0.975
% INFO    : Gen at bus 6163	: Pg=359.05, Qg=22.73 -> Pg=181.055, Qg=0.0
% INFO    : Gen at bus 6163	: Vg=1.092 -> Vg=0.975
% INFO    : Gen at bus 6163	: Pg=213.02, Qg=22.73 -> Pg=108.04, Qg=0.0
% INFO    : Gen at bus 6163	: Vg=1.092 -> Vg=0.975
% INFO    : Gen at bus 6166	: Pg=44.46, Qg=-8.19 -> Pg=23.7, Qg=0.0
% INFO    : Gen at bus 6166	: Vg=1.08 -> Vg=0.975
% INFO    : Gen at bus 6166	: Pg=44.46, Qg=-8.19 -> Pg=23.7, Qg=0.0
% INFO    : Gen at bus 6166	: Vg=1.08 -> Vg=0.975
% INFO    : Gen at bus 6173	: Pg=2680.29, Qg=245.96 -> Pg=1341.385, Qg=0.0
% INFO    : Gen at bus 6173	: Vg=1.086 -> Vg=0.975
% INFO    : Gen at bus 6174	: Vg=1.041 -> Vg=0.975
% INFO    : Gen at bus 6175	: Pg=2.61, Qg=13.08 -> Pg=2.81, Qg=7.855
% INFO    : Gen at bus 6175	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6175	: Pg=2.61, Qg=13.08 -> Pg=2.81, Qg=7.855
% INFO    : Gen at bus 6175	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6177	: Vg=1.097 -> Vg=0.975
% INFO    : Gen at bus 6180	: Vg=1.049 -> Vg=0.975
% INFO    : Gen at bus 6185	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 6189	: Pg=200.62, Qg=10.15 -> Pg=101.795, Qg=0.0
% INFO    : Gen at bus 6189	: Vg=1.109 -> Vg=0.975
% INFO    : Gen at bus 6189	: Pg=203.85, Qg=10.15 -> Pg=103.41, Qg=0.0
% INFO    : Gen at bus 6189	: Vg=1.109 -> Vg=0.975
% INFO    : Gen at bus 6190	: Vg=1.101 -> Vg=0.975
% INFO    : Gen at bus 6194	: Vg=1.11 -> Vg=0.975
% INFO    : Gen at bus 6194	: Vg=1.11 -> Vg=0.975
% INFO    : Gen at bus 6195	: Vg=1.121 -> Vg=0.975
% INFO    : Gen at bus 6195	: Vg=1.121 -> Vg=0.975
% INFO    : Gen at bus 6195	: Vg=1.121 -> Vg=0.975
% INFO    : Gen at bus 6196	: Pg=71.4, Qg=-24.44 -> Pg=100.0, Qg=0.0
% INFO    : Gen at bus 6196	: Vg=1.062 -> Vg=0.975
% INFO    : Gen at bus 6197	: Vg=1.104 -> Vg=0.975
% INFO    : Gen at bus 6197	: Vg=1.104 -> Vg=0.975
% INFO    : Gen at bus 6213	: Vg=1.098 -> Vg=0.975
% INFO    : Gen at bus 6216	: Vg=1.065 -> Vg=0.975
% INFO    : Gen at bus 6217	: Vg=1.077 -> Vg=0.975
% INFO    : Gen at bus 6217	: Vg=1.077 -> Vg=0.975
% INFO    : Gen at bus 6217	: Vg=1.077 -> Vg=0.975
% INFO    : Gen at bus 6219	: Vg=1.1 -> Vg=0.975
% INFO    : Gen at bus 6219	: Vg=1.1 -> Vg=0.975
% INFO    : Gen at bus 6219	: Pg=246.87, Qg=43.08 -> Pg=125.0, Qg=0.0
% INFO    : Gen at bus 6219	: Vg=1.1 -> Vg=0.975
% INFO    : Gen at bus 6219	: Vg=1.1 -> Vg=0.975
% INFO    : Gen at bus 6219	: Pg=107.87, Qg=43.08 -> Pg=125.0, Qg=0.0
% INFO    : Gen at bus 6219	: Vg=1.1 -> Vg=0.975
% INFO    : Gen at bus 6219	: Vg=1.1 -> Vg=0.975
% INFO    : Gen at bus 6219	: Vg=1.1 -> Vg=0.975
% INFO    : Gen at bus 6220	: Pg=639.4, Qg=-100.38 -> Pg=321.0, Qg=142.5
% INFO    : Gen at bus 6220	: Vg=1.041 -> Vg=0.975
% INFO    : Gen at bus 6222	: Vg=1.065 -> Vg=0.975
% INFO    : Gen at bus 6223	: Pg=1039.39, Qg=-218.44 -> Pg=700.0, Qg=70.0
% INFO    : Gen at bus 6223	: Vg=1.097 -> Vg=0.975
% INFO    : Gen at bus 6227	: Pg=144.94, Qg=-12.61 -> Pg=73.93, Qg=0.0
% INFO    : Gen at bus 6227	: Vg=1.077 -> Vg=0.975
% INFO    : Gen at bus 6230	: Vg=1.065 -> Vg=0.975
% INFO    : Gen at bus 6230	: Vg=1.065 -> Vg=0.975
% INFO    : Gen at bus 6232	: Pg=80.53, Qg=52.6 -> Pg=41.745, Qg=15.01
% INFO    : Gen at bus 6232	: Vg=1.083 -> Vg=0.975
% INFO    : Gen at bus 6232	: Pg=80.53, Qg=52.6 -> Pg=41.745, Qg=15.01
% INFO    : Gen at bus 6232	: Vg=1.083 -> Vg=0.975
% INFO    : Gen at bus 6240	: Pg=363.71, Qg=-36.84 -> Pg=183.38, Qg=0.0
% INFO    : Gen at bus 6240	: Vg=1.089 -> Vg=0.975
% INFO    : Gen at bus 6246	: Vg=1.094 -> Vg=0.975
% INFO    : Gen at bus 6248	: Pg=565.3, Qg=-46.4 -> Pg=625.0, Qg=-14.0
% INFO    : Gen at bus 6248	: Vg=1.074 -> Vg=0.975
% INFO    : Gen at bus 6248	: Pg=367.05, Qg=-46.4 -> Pg=285.0, Qg=-44.0
% INFO    : Gen at bus 6248	: Vg=1.074 -> Vg=0.975
% INFO    : Gen at bus 6248	: Pg=367.05, Qg=-46.4 -> Pg=285.0, Qg=-44.0
% INFO    : Gen at bus 6248	: Vg=1.074 -> Vg=0.975
% INFO    : Gen at bus 6256	: Pg=13.3, Qg=133.19 -> Pg=448.3, Qg=52.615
% INFO    : Gen at bus 6256	: Vg=0.993 -> Vg=0.975
% INFO    : Gen at bus 6257	: Vg=0.968 -> Vg=0.975
% INFO    : Gen at bus 6258	: Pg=3.72, Qg=9.34 -> Pg=13.5, Qg=4.515
% INFO    : Gen at bus 6258	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6259	: Pg=68.61, Qg=44.04 -> Pg=43.0, Qg=20.295
% INFO    : Gen at bus 6259	: Vg=0.995 -> Vg=0.975
% INFO    : Gen at bus 6260	: Vg=0.94 -> Vg=0.975
% INFO    : Gen at bus 6261	: Pg=22.47, Qg=10.21 -> Pg=16.0, Qg=1.705
% INFO    : Gen at bus 6261	: Vg=1.074 -> Vg=0.975
% INFO    : Gen at bus 6262	: Pg=22.47, Qg=10.21 -> Pg=16.0, Qg=1.705
% INFO    : Gen at bus 6262	: Vg=1.074 -> Vg=0.975
% INFO    : Gen at bus 6263	: Pg=22.94, Qg=5.55 -> Pg=16.0, Qg=1.545
% INFO    : Gen at bus 6263	: Vg=1.058 -> Vg=0.975
% INFO    : Gen at bus 6264	: Pg=21.91, Qg=5.38 -> Pg=16.0, Qg=1.545
% INFO    : Gen at bus 6264	: Vg=1.058 -> Vg=0.975
% INFO    : Gen at bus 6265	: Pg=77.63, Qg=-13.09 -> Pg=46.0, Qg=14.82
% INFO    : Gen at bus 6265	: Vg=0.983 -> Vg=0.975
% INFO    : Gen at bus 6266	: Pg=45.44, Qg=-18.26 -> Pg=46.0, Qg=14.82
% INFO    : Gen at bus 6266	: Vg=0.979 -> Vg=0.975
% INFO    : Gen at bus 6267	: Pg=70.37, Qg=15.08 -> Pg=46.0, Qg=17.7
% INFO    : Gen at bus 6267	: Vg=1.037 -> Vg=0.975
% INFO    : Gen at bus 6268	: Pg=61.33, Qg=13.27 -> Pg=46.0, Qg=17.7
% INFO    : Gen at bus 6268	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 6269	: Pg=70.71, Qg=-37.7 -> Pg=46.0, Qg=12.5
% INFO    : Gen at bus 6269	: Vg=0.951 -> Vg=0.975
% INFO    : Gen at bus 6270	: Pg=76.68, Qg=-35.27 -> Pg=46.0, Qg=13.715
% INFO    : Gen at bus 6270	: Vg=0.954 -> Vg=0.975
% INFO    : Gen at bus 6271	: Pg=932.03, Qg=130.9 -> Pg=589.92, Qg=-38.37
% INFO    : Gen at bus 6271	: Vg=1.044 -> Vg=0.975
% INFO    : Gen at bus 6272	: Pg=974.0, Qg=133.29 -> Pg=631.89, Qg=-27.81
% INFO    : Gen at bus 6272	: Vg=1.044 -> Vg=0.975
% INFO    : Gen at bus 6273	: Pg=972.04, Qg=125.81 -> Pg=614.92, Qg=-32.13
% INFO    : Gen at bus 6273	: Vg=1.043 -> Vg=0.975
% INFO    : Gen at bus 6274	: Pg=934.03, Qg=112.31 -> Pg=591.92, Qg=-37.99
% INFO    : Gen at bus 6274	: Vg=1.042 -> Vg=0.975
% INFO    : Gen at bus 6276	: Pg=234.58, Qg=34.59 -> Pg=204.0, Qg=31.78
% INFO    : Gen at bus 6276	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 6277	: Pg=232.54, Qg=40.75 -> Pg=202.0, Qg=31.955
% INFO    : Gen at bus 6277	: Vg=1.007 -> Vg=0.975
% INFO    : Gen at bus 6278	: Pg=222.99, Qg=45.34 -> Pg=202.0, Qg=22.52
% INFO    : Gen at bus 6278	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 6279	: Pg=10.0, Qg=22.92 -> Pg=213.5, Qg=42.55
% INFO    : Gen at bus 6279	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 6280	: Vg=1.026 -> Vg=0.975
% INFO    : Gen at bus 6281	: Pg=55.2, Qg=10.91 -> Pg=29.0, Qg=-0.45
% INFO    : Gen at bus 6281	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 6282	: Pg=55.2, Qg=11.5 -> Pg=29.0, Qg=-0.1
% INFO    : Gen at bus 6282	: Vg=1.017 -> Vg=0.975
% INFO    : Gen at bus 6283	: Pg=55.2, Qg=10.91 -> Pg=29.0, Qg=-0.45
% INFO    : Gen at bus 6283	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 6284	: Pg=55.2, Qg=11.5 -> Pg=29.0, Qg=-0.1
% INFO    : Gen at bus 6284	: Vg=1.017 -> Vg=0.975
% INFO    : Gen at bus 6285	: Pg=55.2, Qg=11.5 -> Pg=29.0, Qg=-0.1
% INFO    : Gen at bus 6285	: Vg=1.017 -> Vg=0.975
% INFO    : Gen at bus 6286	: Pg=135.29, Qg=11.46 -> Pg=198.0, Qg=45.885
% INFO    : Gen at bus 6286	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6287	: Pg=20.13, Qg=-13.63 -> Pg=16.0, Qg=4.37
% INFO    : Gen at bus 6287	: Vg=0.962 -> Vg=0.975
% INFO    : Gen at bus 6288	: Pg=16.16, Qg=-15.7 -> Pg=16.0, Qg=2.335
% INFO    : Gen at bus 6288	: Vg=0.995 -> Vg=0.975
% INFO    : Gen at bus 6289	: Pg=19.17, Qg=-14.57 -> Pg=16.0, Qg=3.82
% INFO    : Gen at bus 6289	: Vg=0.982 -> Vg=0.975
% INFO    : Gen at bus 6290	: Pg=933.12, Qg=97.73 -> Pg=600.97, Qg=162.755
% INFO    : Gen at bus 6290	: Vg=0.99 -> Vg=0.975
% INFO    : Gen at bus 6291	: Pg=926.26, Qg=93.14 -> Pg=602.77, Qg=166.03
% INFO    : Gen at bus 6291	: Vg=0.991 -> Vg=0.975
% INFO    : Gen at bus 6292	: Pg=921.11, Qg=109.43 -> Pg=598.96, Qg=149.145
% INFO    : Gen at bus 6292	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6293	: Pg=884.24, Qg=95.53 -> Pg=592.76, Qg=149.315
% INFO    : Gen at bus 6293	: Vg=0.991 -> Vg=0.975
% INFO    : Gen at bus 6294	: Pg=1231.54, Qg=58.41 -> Pg=813.0, Qg=218.085
% INFO    : Gen at bus 6294	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6295	: Pg=1231.54, Qg=59.0 -> Pg=813.0, Qg=218.085
% INFO    : Gen at bus 6295	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6296	: Pg=29.64, Qg=4.43 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6296	: Vg=1.038 -> Vg=0.975
% INFO    : Gen at bus 6297	: Pg=30.62, Qg=4.55 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6297	: Vg=1.038 -> Vg=0.975
% INFO    : Gen at bus 6298	: Pg=30.62, Qg=4.55 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6298	: Vg=1.038 -> Vg=0.975
% INFO    : Gen at bus 6299	: Pg=29.88, Qg=3.99 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6299	: Vg=1.037 -> Vg=0.975
% INFO    : Gen at bus 6300	: Pg=29.88, Qg=3.99 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6300	: Vg=1.037 -> Vg=0.975
% INFO    : Gen at bus 6301	: Pg=29.88, Qg=3.99 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6301	: Vg=1.037 -> Vg=0.975
% INFO    : Gen at bus 6302	: Pg=4.99, Qg=10.77 -> Pg=10.0, Qg=1.73
% INFO    : Gen at bus 6302	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6303	: Pg=4.99, Qg=10.77 -> Pg=10.0, Qg=1.73
% INFO    : Gen at bus 6303	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6304	: Pg=1278.94, Qg=101.41 -> Pg=833.5, Qg=226.955
% INFO    : Gen at bus 6304	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 6305	: Pg=1229.97, Qg=125.39 -> Pg=863.5, Qg=235.535
% INFO    : Gen at bus 6305	: Vg=1.006 -> Vg=0.975
% INFO    : Gen at bus 6306	: Pg=1252.97, Qg=130.62 -> Pg=863.5, Qg=235.535
% INFO    : Gen at bus 6306	: Vg=1.005 -> Vg=0.975
% INFO    : Gen at bus 6307	: Pg=68.88, Qg=44.84 -> Pg=47.5, Qg=10.18
% INFO    : Gen at bus 6307	: Vg=1.096 -> Vg=0.975
% INFO    : Gen at bus 6308	: Pg=1.4, Qg=81.23 -> Pg=1.45, Qg=91.015
% INFO    : Gen at bus 6308	: Vg=1.026 -> Vg=0.975
% INFO    : Gen at bus 6309	: Pg=935.77, Qg=152.26 -> Pg=587.38, Qg=172.985
% INFO    : Gen at bus 6309	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 6311	: Pg=948.47, Qg=142.36 -> Pg=596.4, Qg=192.69
% INFO    : Gen at bus 6311	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 6312	: Pg=945.47, Qg=147.39 -> Pg=593.4, Qg=201.74
% INFO    : Gen at bus 6312	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 6313	: Pg=1500.33, Qg=335.81 -> Pg=953.0, Qg=217.35
% INFO    : Gen at bus 6313	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 6314	: Pg=1500.33, Qg=356.76 -> Pg=953.0, Qg=217.35
% INFO    : Gen at bus 6314	: Vg=1.022 -> Vg=0.975
% INFO    : Gen at bus 6315	: Pg=1495.01, Qg=111.88 -> Pg=948.0, Qg=-28.08
% INFO    : Gen at bus 6315	: Vg=1.017 -> Vg=0.975
% INFO    : Gen at bus 6316	: Pg=1451.56, Qg=86.31 -> Pg=948.0, Qg=-38.82
% INFO    : Gen at bus 6316	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 6317	: Pg=66.9, Qg=-0.1 -> Pg=66.75, Qg=21.35
% INFO    : Gen at bus 6317	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6318	: Pg=68.9, Qg=2.77 -> Pg=66.75, Qg=21.35
% INFO    : Gen at bus 6318	: Vg=0.994 -> Vg=0.975
% INFO    : Gen at bus 6319	: Pg=121.69, Qg=2.93 -> Pg=76.2, Qg=35.07
% INFO    : Gen at bus 6319	: Vg=1.019 -> Vg=0.975
% INFO    : Gen at bus 6320	: Vg=0.988 -> Vg=0.975
% INFO    : Gen at bus 6321	: Pg=557.05, Qg=101.1 -> Pg=460.0, Qg=94.405
% INFO    : Gen at bus 6321	: Vg=1.001 -> Vg=0.975
% INFO    : Gen at bus 6322	: Pg=557.01, Qg=96.93 -> Pg=460.0, Qg=55.15
% INFO    : Gen at bus 6322	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 6324	: Vg=0.986 -> Vg=0.975
% INFO    : Gen at bus 6325	: Pg=40.98, Qg=8.48 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6325	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6326	: Pg=39.99, Qg=8.27 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6326	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6327	: Pg=41.98, Qg=8.7 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6327	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6328	: Pg=41.98, Qg=8.7 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6328	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6329	: Pg=40.98, Qg=8.48 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6329	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6330	: Pg=38.99, Qg=8.06 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6330	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6331	: Pg=949.76, Qg=185.16 -> Pg=640.0, Qg=196.325
% INFO    : Gen at bus 6331	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 6332	: Pg=960.77, Qg=205.09 -> Pg=640.0, Qg=196.325
% INFO    : Gen at bus 6332	: Vg=1.006 -> Vg=0.975
% INFO    : Gen at bus 6333	: Pg=960.77, Qg=222.25 -> Pg=640.0, Qg=218.295
% INFO    : Gen at bus 6333	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 6334	: Pg=927.16, Qg=209.33 -> Pg=605.0, Qg=208.07
% INFO    : Gen at bus 6334	: Vg=1.007 -> Vg=0.975
% INFO    : Gen at bus 6335	: Pg=24.69, Qg=-2.59 -> Pg=28.5, Qg=4.565
% INFO    : Gen at bus 6335	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 6336	: Pg=25.71, Qg=-2.49 -> Pg=28.5, Qg=4.565
% INFO    : Gen at bus 6336	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 6337	: Vg=0.95 -> Vg=0.975
% INFO    : Gen at bus 6338	: Vg=0.978 -> Vg=0.975
% INFO    : Gen at bus 6339	: Pg=8.8, Qg=6.1 -> Pg=341.3, Qg=54.86
% INFO    : Gen at bus 6339	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 6340	: Pg=924.76, Qg=82.66 -> Pg=582.69, Qg=187.52
% INFO    : Gen at bus 6340	: Vg=0.999 -> Vg=0.975
% INFO    : Gen at bus 6341	: Pg=924.76, Qg=76.13 -> Pg=582.69, Qg=187.52
% INFO    : Gen at bus 6341	: Vg=0.998 -> Vg=0.975
% INFO    : Gen at bus 6342	: Pg=931.76, Qg=70.74 -> Pg=589.69, Qg=188.875
% INFO    : Gen at bus 6342	: Vg=0.997 -> Vg=0.975
% INFO    : Gen at bus 6343	: Pg=946.77, Qg=73.93 -> Pg=604.695, Qg=191.875
% INFO    : Gen at bus 6343	: Vg=0.997 -> Vg=0.975
% INFO    : Gen at bus 6344	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 6345	: Pg=1244.45, Qg=165.76 -> Pg=860.0, Qg=-28.245
% INFO    : Gen at bus 6345	: Vg=1.042 -> Vg=0.975
% INFO    : Gen at bus 6346	: Pg=1189.46, Qg=182.82 -> Pg=860.0, Qg=-28.245
% INFO    : Gen at bus 6346	: Vg=1.044 -> Vg=0.975
% INFO    : Gen at bus 6347	: Pg=22.49, Qg=-1.34 -> Pg=15.75, Qg=4.47
% INFO    : Gen at bus 6347	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 6348	: Pg=52.79, Qg=18.6 -> Pg=32.5, Qg=7.34
% INFO    : Gen at bus 6348	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6349	: Pg=51.03, Qg=14.73 -> Pg=35.0, Qg=0.32
% INFO    : Gen at bus 6349	: Vg=1.026 -> Vg=0.975
% INFO    : Gen at bus 6350	: Pg=55.84, Qg=16.13 -> Pg=32.5, Qg=10.38
% INFO    : Gen at bus 6350	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 6351	: Pg=54.76, Qg=19.61 -> Pg=35.0, Qg=9.63
% INFO    : Gen at bus 6351	: Vg=1.033 -> Vg=0.975
% INFO    : Gen at bus 6352	: Pg=1301.61, Qg=151.83 -> Pg=798.0, Qg=36.21
% INFO    : Gen at bus 6352	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 6353	: Pg=1233.61, Qg=172.47 -> Pg=798.0, Qg=36.21
% INFO    : Gen at bus 6353	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6354	: Pg=7.26, Qg=9.65 -> Pg=273.76, Qg=84.835
% INFO    : Gen at bus 6354	: Vg=0.978 -> Vg=0.975
% INFO    : Gen at bus 6355	: Pg=27.31, Qg=-0.75 -> Pg=18.0, Qg=-1.11
% INFO    : Gen at bus 6355	: Vg=1.007 -> Vg=0.975
% INFO    : Gen at bus 6356	: Pg=921.18, Qg=166.0 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 6356	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 6357	: Pg=942.08, Qg=166.93 -> Pg=607.0, Qg=190.895
% INFO    : Gen at bus 6357	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 6358	: Pg=944.12, Qg=167.51 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 6358	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 6359	: Pg=937.21, Qg=140.91 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 6359	: Vg=1.007 -> Vg=0.975
% INFO    : Gen at bus 6360	: Pg=944.12, Qg=154.51 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 6360	: Vg=1.007 -> Vg=0.975
% INFO    : Gen at bus 6361	: Pg=856.09, Qg=166.46 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 6361	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 6362	: Pg=166.28, Qg=71.93 -> Pg=197.5, Qg=60.46
% INFO    : Gen at bus 6362	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6363	: Vg=0.997 -> Vg=0.975
% INFO    : Gen at bus 6364	: Pg=220.24, Qg=93.53 -> Pg=195.0, Qg=33.755
% INFO    : Gen at bus 6364	: Vg=1.043 -> Vg=0.975
% INFO    : Gen at bus 6365	: Vg=1.002 -> Vg=0.975
% INFO    : Gen at bus 6366	: Vg=0.988 -> Vg=0.975
% INFO    : Gen at bus 6368	: Pg=54.12, Qg=-7.93 -> Pg=28.5, Qg=12.31
% INFO    : Gen at bus 6368	: Vg=0.967 -> Vg=0.975
% INFO    : Gen at bus 6369	: Pg=23.03, Qg=13.27 -> Pg=8.0, Qg=6.455
% INFO    : Gen at bus 6369	: Vg=1.043 -> Vg=0.975
% INFO    : Gen at bus 6370	: Pg=10.84, Qg=0.3 -> Pg=9.75, Qg=1.46
% INFO    : Gen at bus 6370	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 6371	: Pg=9.87, Qg=0.18 -> Pg=9.75, Qg=1.46
% INFO    : Gen at bus 6371	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 6372	: Pg=15.41, Qg=-0.99 -> Pg=10.5, Qg=1.405
% INFO    : Gen at bus 6372	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 6373	: Pg=28.45, Qg=5.47 -> Pg=17.5, Qg=-0.555
% INFO    : Gen at bus 6373	: Vg=1.002 -> Vg=0.975
% INFO    : Gen at bus 6374	: Pg=29.43, Qg=5.67 -> Pg=17.5, Qg=-0.555
% INFO    : Gen at bus 6374	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 6375	: Pg=29.43, Qg=5.67 -> Pg=17.5, Qg=-0.15
% INFO    : Gen at bus 6375	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 6376	: Pg=29.43, Qg=5.67 -> Pg=17.5, Qg=-0.555
% INFO    : Gen at bus 6376	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 6377	: Pg=241.31, Qg=-19.69 -> Pg=192.5, Qg=0.99
% INFO    : Gen at bus 6377	: Vg=0.962 -> Vg=0.975
% INFO    : Gen at bus 6378	: Pg=40.7, Qg=-4.05 -> Pg=23.5, Qg=2.37
% INFO    : Gen at bus 6378	: Vg=0.984 -> Vg=0.975
% INFO    : Gen at bus 6379	: Pg=59.73, Qg=10.8 -> Pg=36.5, Qg=10.17
% INFO    : Gen at bus 6379	: Vg=1.01 -> Vg=0.975
% INFO    : Gen at bus 6380	: Pg=68.83, Qg=14.85 -> Pg=34.5, Qg=13.355
% INFO    : Gen at bus 6380	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6381	: Pg=69.83, Qg=13.33 -> Pg=38.0, Qg=11.28
% INFO    : Gen at bus 6381	: Vg=1.017 -> Vg=0.975
% INFO    : Gen at bus 6382	: Pg=61.75, Qg=11.1 -> Pg=38.75, Qg=10.505
% INFO    : Gen at bus 6382	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 6383	: Pg=20.6, Qg=15.29 -> Pg=15.5, Qg=2.31
% INFO    : Gen at bus 6383	: Vg=1.042 -> Vg=0.975
% INFO    : Gen at bus 6384	: Pg=20.6, Qg=15.29 -> Pg=15.5, Qg=2.31
% INFO    : Gen at bus 6384	: Vg=1.042 -> Vg=0.975
% INFO    : Gen at bus 6385	: Pg=19.66, Qg=15.41 -> Pg=15.5, Qg=2.37
% INFO    : Gen at bus 6385	: Vg=1.043 -> Vg=0.975
% INFO    : Gen at bus 6386	: Pg=28.0, Qg=32.2 -> Pg=25.0, Qg=8.315
% INFO    : Gen at bus 6386	: Vg=1.027 -> Vg=0.975
% INFO    : Gen at bus 6387	: Pg=228.02, Qg=11.31 -> Pg=193.5, Qg=68.455
% INFO    : Gen at bus 6387	: Vg=0.994 -> Vg=0.975
% INFO    : Gen at bus 6388	: Pg=210.51, Qg=9.44 -> Pg=193.5, Qg=68.455
% INFO    : Gen at bus 6388	: Vg=0.994 -> Vg=0.975
% INFO    : Gen at bus 6389	: Pg=9.11, Qg=-5.57 -> Pg=9.5, Qg=1.75
% INFO    : Gen at bus 6389	: Vg=0.914 -> Vg=0.975
% INFO    : Gen at bus 6390	: Pg=5.9, Qg=-16.91 -> Pg=310.9, Qg=26.99
% INFO    : Gen at bus 6390	: Vg=1.002 -> Vg=0.975
% INFO    : Gen at bus 6391	: Pg=42.08, Qg=33.46 -> Pg=26.0, Qg=10.215
% INFO    : Gen at bus 6391	: Vg=1.067 -> Vg=0.975
% INFO    : Gen at bus 6392	: Pg=42.08, Qg=33.46 -> Pg=26.0, Qg=10.215
% INFO    : Gen at bus 6392	: Vg=1.067 -> Vg=0.975
% INFO    : Gen at bus 6393	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 6394	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 6395	: Pg=53.26, Qg=-3.86 -> Pg=32.5, Qg=12.59
% INFO    : Gen at bus 6395	: Vg=0.985 -> Vg=0.975
% INFO    : Gen at bus 6396	: Pg=52.2, Qg=-4.04 -> Pg=32.5, Qg=12.59
% INFO    : Gen at bus 6396	: Vg=0.985 -> Vg=0.975
% INFO    : Gen at bus 6397	: Pg=870.06, Qg=421.11 -> Pg=593.5, Qg=182.745
% INFO    : Gen at bus 6397	: Vg=1.056 -> Vg=0.975
% INFO    : Gen at bus 6398	: Pg=889.06, Qg=202.49 -> Pg=593.5, Qg=193.685
% INFO    : Gen at bus 6398	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6399	: Pg=12.0, Qg=17.4 -> Pg=242.0, Qg=22.125
% INFO    : Gen at bus 6399	: Vg=1.006 -> Vg=0.975
% INFO    : Gen at bus 6400	: Vg=0.939 -> Vg=0.975
% INFO    : Gen at bus 6401	: Pg=1289.26, Qg=244.03 -> Pg=824.5, Qg=229.315
% INFO    : Gen at bus 6401	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 6402	: Pg=43.78, Qg=27.87 -> Pg=30.5, Qg=2.34
% INFO    : Gen at bus 6402	: Vg=1.029 -> Vg=0.975
% INFO    : Gen at bus 6403	: Pg=43.78, Qg=27.87 -> Pg=30.5, Qg=2.34
% INFO    : Gen at bus 6403	: Vg=1.029 -> Vg=0.975
% INFO    : Gen at bus 6404	: Pg=18.25, Qg=8.65 -> Pg=17.5, Qg=6.57
% INFO    : Gen at bus 6404	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 6405	: Pg=1286.75, Qg=210.03 -> Pg=865.0, Qg=235.84
% INFO    : Gen at bus 6405	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 6406	: Pg=1300.5, Qg=315.73 -> Pg=865.0, Qg=235.84
% INFO    : Gen at bus 6406	: Vg=1.034 -> Vg=0.975
% INFO    : Gen at bus 6407	: Pg=1248.51, Qg=318.04 -> Pg=865.0, Qg=230.335
% INFO    : Gen at bus 6407	: Vg=1.036 -> Vg=0.975
% INFO    : Gen at bus 6408	: Pg=1286.99, Qg=316.14 -> Pg=820.0, Qg=210.31
% INFO    : Gen at bus 6408	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 6409	: Pg=3.89, Qg=4.92 -> Pg=25.9, Qg=13.51
% INFO    : Gen at bus 6409	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 6410	: Pg=1307.8, Qg=283.79 -> Pg=860.0, Qg=234.135
% INFO    : Gen at bus 6410	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 6411	: Pg=1232.54, Qg=294.51 -> Pg=860.0, Qg=234.135
% INFO    : Gen at bus 6411	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6412	: Vg=0.976 -> Vg=0.975
% INFO    : Gen at bus 6413	: Vg=0.976 -> Vg=0.975
% INFO    : Gen at bus 6414	: Vg=0.976 -> Vg=0.975
% INFO    : Gen at bus 6415	: Vg=0.985 -> Vg=0.975
% INFO    : Gen at bus 6416	: Pg=64.9, Qg=-0.44 -> Pg=40.0, Qg=10.44
% INFO    : Gen at bus 6416	: Vg=0.998 -> Vg=0.975
% INFO    : Gen at bus 6417	: Pg=229.02, Qg=101.08 -> Pg=165.0, Qg=16.655
% INFO    : Gen at bus 6417	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 6418	: Pg=576.15, Qg=51.58 -> Pg=450.0, Qg=57.26
% INFO    : Gen at bus 6418	: Vg=0.968 -> Vg=0.975
% INFO    : Gen at bus 6419	: Pg=28.13, Qg=-0.52 -> Pg=28.0, Qg=4.12
% INFO    : Gen at bus 6419	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6420	: Pg=40.92, Qg=1.38 -> Pg=28.0, Qg=4.12
% INFO    : Gen at bus 6420	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 6421	: Pg=3.27, Qg=-1.88 -> Pg=29.0, Qg=29.66
% INFO    : Gen at bus 6421	: Vg=0.994 -> Vg=0.975
% INFO    : Gen at bus 6422	: Pg=15.75, Qg=3.31 -> Pg=11.55, Qg=3.15
% INFO    : Gen at bus 6422	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6423	: Pg=15.75, Qg=3.31 -> Pg=11.55, Qg=3.14
% INFO    : Gen at bus 6423	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6424	: Pg=376.47, Qg=49.86 -> Pg=335.3, Qg=81.55
% INFO    : Gen at bus 6424	: Vg=1.002 -> Vg=0.975
% INFO    : Gen at bus 6425	: Pg=-1.97, Qg=9.78 -> Pg=0.0, Qg=5.695
% INFO    : Gen at bus 6425	: Vg=1.081 -> Vg=0.975
% INFO    : Gen at bus 6426	: Pg=-1.97, Qg=12.93 -> Pg=0.0, Qg=5.695
% INFO    : Gen at bus 6426	: Vg=1.085 -> Vg=0.975
% INFO    : Gen at bus 6427	: Pg=-1.97, Qg=12.93 -> Pg=0.0, Qg=5.695
% INFO    : Gen at bus 6427	: Vg=1.085 -> Vg=0.975
% INFO    : Gen at bus 6428	: Pg=29.2, Qg=-2.17 -> Pg=16.0, Qg=4.57
% INFO    : Gen at bus 6428	: Vg=0.966 -> Vg=0.975
% INFO    : Gen at bus 6429	: Vg=0.959 -> Vg=0.975
% INFO    : Gen at bus 6430	: Pg=29.2, Qg=-2.17 -> Pg=16.0, Qg=4.57
% INFO    : Gen at bus 6430	: Vg=0.966 -> Vg=0.975
% INFO    : Gen at bus 6431	: Vg=0.959 -> Vg=0.975
% INFO    : Gen at bus 6432	: Pg=25.62, Qg=0.48 -> Pg=22.0, Qg=4.315
% INFO    : Gen at bus 6432	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 6433	: Pg=27.41, Qg=16.57 -> Pg=15.5, Qg=2.94
% INFO    : Gen at bus 6433	: Vg=1.05 -> Vg=0.975
% INFO    : Gen at bus 6434	: Pg=26.43, Qg=16.38 -> Pg=15.5, Qg=2.94
% INFO    : Gen at bus 6434	: Vg=1.049 -> Vg=0.975
% INFO    : Gen at bus 6435	: Pg=20.86, Qg=-2.44 -> Pg=19.0, Qg=4.36
% INFO    : Gen at bus 6435	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6436	: Pg=18.88, Qg=-2.74 -> Pg=19.0, Qg=4.225
% INFO    : Gen at bus 6436	: Vg=1.024 -> Vg=0.975
% INFO    : Gen at bus 6437	: Pg=73.4, Qg=-5.62 -> Pg=42.0, Qg=15.305
% INFO    : Gen at bus 6437	: Vg=0.976 -> Vg=0.975
% INFO    : Gen at bus 6438	: Vg=0.944 -> Vg=0.975
% INFO    : Gen at bus 6439	: Pg=36.74, Qg=-3.21 -> Pg=65.0, Qg=6.33
% INFO    : Gen at bus 6439	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6440	: Pg=56.03, Qg=-1.65 -> Pg=65.0, Qg=6.33
% INFO    : Gen at bus 6440	: Vg=1.031 -> Vg=0.975
% INFO    : Gen at bus 6441	: Pg=1309.65, Qg=164.93 -> Pg=807.0, Qg=215.91
% INFO    : Gen at bus 6441	: Vg=0.994 -> Vg=0.975
% INFO    : Gen at bus 6442	: Pg=1283.65, Qg=169.27 -> Pg=807.0, Qg=215.91
% INFO    : Gen at bus 6442	: Vg=0.994 -> Vg=0.975
% INFO    : Gen at bus 6443	: Pg=278.84, Qg=28.79 -> Pg=217.5, Qg=91.59
% INFO    : Gen at bus 6443	: Vg=1.002 -> Vg=0.975
% INFO    : Gen at bus 6444	: Pg=580.05, Qg=56.12 -> Pg=410.0, Qg=53.715
% INFO    : Gen at bus 6444	: Vg=0.994 -> Vg=0.975
% INFO    : Gen at bus 6445	: Pg=411.5, Qg=141.99 -> Pg=285.0, Qg=62.505
% INFO    : Gen at bus 6445	: Vg=1.019 -> Vg=0.975
% INFO    : Gen at bus 6446	: Pg=7.0, Qg=20.17 -> Pg=285.0, Qg=13.06
% INFO    : Gen at bus 6446	: Vg=0.985 -> Vg=0.975
% INFO    : Gen at bus 6447	: Pg=44.6, Qg=26.5 -> Pg=25.0, Qg=1.74
% INFO    : Gen at bus 6447	: Vg=1.056 -> Vg=0.975
% INFO    : Gen at bus 6448	: Pg=46.58, Qg=26.96 -> Pg=25.0, Qg=1.74
% INFO    : Gen at bus 6448	: Vg=1.057 -> Vg=0.975
% INFO    : Gen at bus 6449	: Pg=23.23, Qg=-3.87 -> Pg=15.0, Qg=4.19
% INFO    : Gen at bus 6449	: Vg=0.931 -> Vg=0.975
% INFO    : Gen at bus 6450	: Pg=33.49, Qg=16.02 -> Pg=42.5, Qg=19.785
% INFO    : Gen at bus 6450	: Vg=1.007 -> Vg=0.975
% INFO    : Gen at bus 6451	: Pg=919.34, Qg=92.38 -> Pg=591.95, Qg=196.325
% INFO    : Gen at bus 6451	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 6452	: Pg=911.34, Qg=90.67 -> Pg=594.94, Qg=196.865
% INFO    : Gen at bus 6452	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 6453	: Pg=27.85, Qg=23.1 -> Pg=24.5, Qg=1.45
% INFO    : Gen at bus 6453	: Vg=1.051 -> Vg=0.975
% INFO    : Gen at bus 6454	: Pg=34.79, Qg=22.18 -> Pg=24.5, Qg=0.99
% INFO    : Gen at bus 6454	: Vg=1.049 -> Vg=0.975
% INFO    : Gen at bus 6455	: Pg=34.79, Qg=22.18 -> Pg=24.5, Qg=0.99
% INFO    : Gen at bus 6455	: Vg=1.049 -> Vg=0.975
% INFO    : Gen at bus 6456	: Pg=133.43, Qg=-0.84 -> Pg=0.0, Qg=34.06
% INFO    : Gen at bus 6456	: Vg=0.998 -> Vg=0.975
% INFO    : Gen at bus 6457	: Pg=135.36, Qg=-0.35 -> Pg=78.0, Qg=32.39
% INFO    : Gen at bus 6457	: Vg=0.998 -> Vg=0.975
% INFO    : Gen at bus 6458	: Pg=11.37, Qg=1.67 -> Pg=49.5, Qg=-5.525
% INFO    : Gen at bus 6458	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 6459	: Pg=37.0, Qg=3.27 -> Pg=49.5, Qg=-5.525
% INFO    : Gen at bus 6459	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 6460	: Pg=932.94, Qg=220.53 -> Pg=630.0, Qg=121.775
% INFO    : Gen at bus 6460	: Vg=0.99 -> Vg=0.975
% INFO    : Gen at bus 6461	: Pg=903.76, Qg=212.84 -> Pg=630.0, Qg=116.775
% INFO    : Gen at bus 6461	: Vg=0.988 -> Vg=0.975
% INFO    : Gen at bus 6462	: Pg=951.79, Qg=204.8 -> Pg=630.0, Qg=116.775
% INFO    : Gen at bus 6462	: Vg=0.987 -> Vg=0.975
% INFO    : Gen at bus 6463	: Pg=962.13, Qg=190.15 -> Pg=630.0, Qg=116.775
% INFO    : Gen at bus 6463	: Vg=0.984 -> Vg=0.975
% INFO    : Gen at bus 6464	: Vg=1.031 -> Vg=0.975
% INFO    : Gen at bus 6465	: Vg=1.031 -> Vg=0.975
% INFO    : Gen at bus 6466	: Vg=1.027 -> Vg=0.975
% INFO    : Gen at bus 6467	: Pg=61.14, Qg=2.46 -> Pg=0.0, Qg=19.4
% INFO    : Gen at bus 6467	: Vg=0.925 -> Vg=0.975
% INFO    : Gen at bus 6468	: Pg=61.14, Qg=2.46 -> Pg=0.0, Qg=19.4
% INFO    : Gen at bus 6468	: Vg=0.925 -> Vg=0.975
% INFO    : Gen at bus 6469	: Pg=61.14, Qg=2.46 -> Pg=0.0, Qg=19.4
% INFO    : Gen at bus 6469	: Vg=0.925 -> Vg=0.975
% INFO    : Gen at bus 6470	: Pg=227.56, Qg=36.7 -> Pg=203.0, Qg=30.365
% INFO    : Gen at bus 6470	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 6471	: Pg=201.56, Qg=37.1 -> Pg=203.0, Qg=30.365
% INFO    : Gen at bus 6471	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 6472	: Pg=157.5, Qg=64.17 -> Pg=90.0, Qg=27.8
% INFO    : Gen at bus 6472	: Vg=1.088 -> Vg=0.975
% INFO    : Gen at bus 6473	: Vg=1.005 -> Vg=0.975
% INFO    : Gen at bus 6474	: Vg=1.005 -> Vg=0.975
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
