%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v23.07     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                         23 - July - 2023                         %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%CASE6495RTE
%   AC Power flow data for French system.
%   Please see CASEFORMAT for details on the case file format.
%
%   This case accurately represents the size and complexity of French
%   very high voltage and high voltage transmission network.
%   These data are snapshots of French VHV+HV grid in 2013.
%   These data can be used to validate mathematical methods and tools.
%   These data should NOT be used for operation
%   nor planning of the French or European grids.
%
%   When publishing results using this data, please cite:
%     C. Josz, S. Fliscounakis, J. Maeght, and P. Panciatici,
%     "AC Power Flow Data in MATPOWER and QCQP Format: iTesla, RTE Snapshots, and PEGASE"
%     http://arxiv.org/abs/1603.01533
%
%   Contacts (primary contact for this file : Jean Maeght):
%   Cédric Josz, Stéphane Fliscounakis, Jean Maeght, Patrick Panciatici
%   firstname.lastname@rte-france.com
%   Réseau de Transport d'Electricité (French Transmission System Operator)
%   Département Expertise Système, Immeuble "Le Colbert"
%   9 rue de la Porte de Buc, 78000 Versailles Cedex, France
%   March 4th, 2016
%
%   Copyright (c) 2016 by Cédric Josz, Stéphane Fliscounakis, Jean Maeght,
%   and Patrick Panciatici
%   Licensed under the Creative Commons Attribution 4.0 International license,
%   http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case6495_rte
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	1	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3	 1	 13.1	 2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4	 1	 49.2	 3.4	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	5	 1	 11.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	6	 1	 13.0	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	7	 1	 1.2	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	8	 1	 24.6	 13.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	9	 1	 14.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	10	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	11	 1	 30.7	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	12	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	13	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07788	    0.00000	 380.0	 1	    1.10263	    1.05313;
	14	 1	 52.7	 13.4	 0.0	 30.4	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	15	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	16	 1	 12.5	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	17	 1	 10.9	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	18	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	19	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	20	 1	 3.9	 -18.2	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	21	 1	 6.3	 -2.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	22	 1	 17.3	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	23	 1	 24.4	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	24	 1	 16.7	 -1.3	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	25	 1	 51.1	 -4.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	26	 1	 32.4	 5.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	27	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	28	 1	 0.0	 -0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	29	 1	 75.0	 9.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	30	 1	 37.6	 3.3	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	31	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	32	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	33	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	34	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	35	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	36	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	37	 1	 2.4	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	38	 1	 8.0	 3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	39	 1	 40.6	 -4.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	40	 1	 34.7	 5.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	41	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04798	    0.00000	 225.0	 1	    1.09152	    1.00444;
	42	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04036	    0.00000	 63.0	 1	    1.12834	    0.95238;
	43	 1	 3.3	 2.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	44	 1	 15.2	 1.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	45	 1	 3.8	 0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	46	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	47	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	48	 1	 38.6	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	49	 1	 9.9	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	50	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00554	    0.00000	 63.0	 1	    1.07458	    0.93651;
	51	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	52	 1	 8.0	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	53	 1	 0.1	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	54	 1	 -0.6	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	55	 1	 49.0	 11.3	 0.0	 0.0	 1	    1.04717	    0.00000	 225.0	 1	    1.08991	    1.00444;
	56	 1	 78.6	 22.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	57	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	58	 1	 146.7	 32.5	 0.0	 0.0	 1	    1.04710	    0.00000	 225.0	 1	    1.08975	    1.00444;
	59	 1	 5.1	 0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	60	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	61	 1	 41.4	 11.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	62	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	63	 1	 15.8	 2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	64	 1	 64.3	 5.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	65	 1	 12.0	 2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	66	 1	 14.4	 -6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	67	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	68	 1	 48.7	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	69	 1	 17.3	 -1.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	70	 1	 11.7	 3.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	71	 1	 68.8	 17.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	72	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04668	    0.00000	 225.0	 1	    1.08892	    1.00444;
	73	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04668	    0.00000	 225.0	 1	    1.08892	    1.00444;
	74	 1	 53.3	 -8.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	75	 1	 25.0	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	76	 1	 9.0	 0.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	77	 1	 40.8	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	78	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	79	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	80	 1	 34.6	 10.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	81	 1	 34.6	 9.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	82	 1	 11.6	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	83	 1	 92.4	 64.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	84	 1	 1.4	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	85	 1	 1.8	 -2.0	 0.0	 0.0	 1	    1.00109	    0.00000	 63.0	 1	    1.06568	    0.93651;
	86	 1	 44.9	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	87	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	88	 1	 15.9	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	89	 1	 25.7	 0.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	90	 1	 0.4	 -2.3	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	91	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	92	 1	 31.6	 3.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	93	 1	 2.2	 -2.2	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	94	 1	 16.9	 -4.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	95	 1	 53.2	 9.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	96	 1	 1.2	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	97	 1	 55.0	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	98	 1	 7.7	 -2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	99	 1	 31.9	 5.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	100	 1	 59.9	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	101	 1	 17.1	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	102	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	103	 1	 13.0	 -1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	104	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	105	 1	 37.7	 0.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	106	 1	 56.3	 8.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	107	 1	 107.4	 13.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	108	 1	 12.7	 -3.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	109	 1	 60.8	 4.1	 0.0	 0.0	 1	    1.00244	    0.00000	 63.0	 1	    1.06837	    0.93651;
	110	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	111	 1	 37.3	 -7.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	114	 1	 12.9	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	115	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	117	 1	 12.8	 -2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	118	 1	 2.0	 0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	119	 1	 40.3	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	120	 1	 22.0	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	121	 1	 22.1	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	122	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	123	 1	 11.0	 3.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	124	 1	 8.9	 -2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	125	 1	 11.6	 -1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	126	 1	 0.4	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	127	 1	 10.7	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	128	 1	 13.4	 5.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	129	 1	 17.0	 12.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	131	 1	 110.7	 4.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	132	 2	 9.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	133	 1	 2.5	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	134	 1	 101.1	 28.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04758	    0.00000	 225.0	 1	    1.09072	    1.00444;
	136	 1	 23.7	 0.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	137	 2	 8.1	 -3.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	138	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	139	 1	 15.7	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	140	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	141	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	142	 1	 12.5	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	143	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	144	 1	 8.9	 2.5	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	145	 1	 24.0	 7.7	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	146	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	147	 1	 28.0	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	148	 1	 6.6	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	149	 1	 15.9	 4.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	150	 1	 48.4	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	151	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	152	 1	 42.6	 9.4	 0.0	 7.7	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	153	 1	 26.9	 -4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	155	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	157	 1	 -1.4	 -2.3	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	158	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	159	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	160	 1	 39.6	 5.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	161	 1	 40.6	 10.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	162	 1	 -0.1	 -1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	165	 1	 12.5	 6.7	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	166	 1	 8.1	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	167	 1	 8.3	 -2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	168	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	169	 1	 9.1	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	170	 1	 78.8	 13.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	171	 1	 26.3	 -0.9	 0.0	 30.0	 1	    1.02849	    0.00000	 90.0	 1	    1.07921	    0.97778;
	172	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	173	 1	 28.9	 8.2	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	174	 1	 54.8	 9.7	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	175	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	176	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	177	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	178	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	179	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	180	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	181	 1	 14.2	 -5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	182	 1	 15.0	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	183	 1	 6.2	 -0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	184	 1	 4.0	 1.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	185	 1	 28.1	 2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	186	 1	 0.4	 1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	187	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	188	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01137	    0.00000	 63.0	 1	    1.10211	    0.92063;
	189	 1	 16.4	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	190	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	191	 1	 14.3	 -1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	192	 1	 7.2	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	193	 1	 -0.3	 0.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	194	 2	 0.7	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	195	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01392	    0.00000	 63.0	 1	    1.07545	    0.95238;
	196	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01392	    0.00000	 63.0	 1	    1.07546	    0.95238;
	197	 1	 27.3	 0.8	 0.0	 15.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	198	 1	 10.0	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	199	 1	 11.4	 1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	200	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	201	 1	 62.6	 22.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	202	 1	 48.1	 0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	203	 1	 23.4	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	204	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	205	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	206	 1	 50.6	 6.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	207	 1	 32.8	 5.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	208	 1	 18.0	 -0.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	209	 1	 0.6	 1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	210	 1	 41.1	 6.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	211	 1	 28.1	 13.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	212	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	213	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	214	 1	 40.9	 3.5	 0.0	 30.4	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	215	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	216	 1	 20.6	 -4.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	217	 1	 26.6	 2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	218	 1	 -0.6	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	219	 1	 12.0	 -3.2	 0.0	 0.0	 1	    1.02295	    0.00000	 90.0	 1	    1.06812	    0.97778;
	220	 1	 12.7	 1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	221	 1	 8.6	 -3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	222	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01383	    0.00000	 225.0	 1	    1.09432	    0.93333;
	223	 1	 41.4	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	224	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	225	 1	 66.8	 4.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	226	 1	 66.8	 43.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	227	 1	 5.0	 -1.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	228	 1	 10.9	 -2.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	229	 1	 10.5	 -3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	230	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	231	 1	 7.0	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	232	 1	 5.1	 0.9	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	233	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	234	 1	 23.0	 7.1	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	235	 1	 14.9	 2.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	236	 1	 23.8	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	237	 1	 40.5	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	238	 1	 25.0	 -2.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	239	 1	 52.1	 2.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	240	 1	 46.6	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	241	 1	 52.9	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	242	 1	 56.3	 9.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	243	 1	 27.7	 -3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	244	 1	 52.3	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	245	 1	 13.7	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	246	 2	 10.5	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	247	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	248	 1	 32.4	 13.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	249	 1	 22.8	 -2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	250	 1	 26.2	 -8.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	251	 1	 11.3	 1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	252	 1	 10.1	 -2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	253	 1	 50.7	 3.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	254	 1	 17.8	 3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	255	 1	 10.5	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	256	 2	 2.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	258	 2	 -0.0	 0.0	 0.0	 0.0	 1	    1.00073	    0.00000	 90.0	 1	    1.07924	    0.92222;
	259	 1	 32.3	 3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	260	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	261	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	262	 1	 0.0	 0.0	 0.0	 80.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	263	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05921	    0.00000	 380.0	 1	    1.10526	    1.01316;
	265	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	266	 1	 29.7	 8.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	267	 1	 65.5	 9.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	268	 1	 13.2	 13.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	269	 1	 24.5	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	270	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	272	 1	 44.2	 6.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	273	 1	 29.5	 5.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	274	 1	 53.3	 7.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	277	 1	 1.8	 3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	278	 1	 -1.7	 4.6	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	279	 1	 12.0	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	280	 1	 48.8	 7.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	281	 1	 11.8	 -0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	282	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	283	 1	 10.8	 -1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	284	 1	 16.1	 3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	285	 1	 0.3	 5.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	286	 1	 31.3	 25.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	287	 1	 27.8	 -2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	288	 1	 34.7	 -1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	289	 1	 27.3	 -6.6	 0.0	 0.0	 1	    0.98937	    0.00000	 225.0	 1	    1.08985	    0.88889;
	290	 1	 3.4	 3.9	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	291	 1	 14.3	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	292	 1	 0.0	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	293	 1	 43.0	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	294	 1	 0.0	 -0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	295	 1	 21.3	 4.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	296	 1	 8.0	 -0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	297	 1	 1.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	298	 1	 13.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	299	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	300	 1	 54.4	 17.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	301	 1	 3.3	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	302	 1	 16.3	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	303	 1	 41.9	 10.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	304	 1	 35.5	 -0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	305	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00369	    0.00000	 63.0	 1	    1.07088	    0.93651;
	306	 1	 13.9	 -1.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	307	 1	 19.2	 -2.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	308	 1	 0.6	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	309	 1	 7.0	 2.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	310	 1	 12.0	 3.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	311	 1	 1.5	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	312	 1	 -2.5	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	313	 1	 30.7	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	314	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	315	 1	 20.8	 -1.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	316	 1	 28.6	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	317	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	318	 1	 13.3	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	319	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	320	 1	 35.0	 4.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	321	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	322	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	324	 1	 26.4	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	325	 2	 18.6	 10.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	326	 1	 10.8	 17.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	327	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	328	 1	 34.6	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	329	 1	 73.9	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	330	 1	 81.7	 -1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	331	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	332	 2	 8.4	 -0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	333	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	334	 1	 6.9	 -3.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	335	 1	 8.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	336	 2	 0.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	337	 1	 14.6	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	338	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	339	 1	 15.1	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	340	 1	 23.8	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	341	 1	 7.3	 -10.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	342	 1	 12.1	 -2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	344	 1	 11.9	 -3.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	345	 1	 27.4	 -5.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	346	 1	 13.1	 0.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	347	 1	 -1.4	 -0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	348	 1	 54.0	 7.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	349	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07453	    0.00000	 380.0	 1	    1.10695	    1.04211;
	350	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07455	    0.00000	 380.0	 1	    1.10699	    1.04211;
	351	 1	 26.7	 5.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	352	 1	 11.5	 11.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	353	 1	 31.7	 -8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	354	 1	 1.6	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	355	 1	 3.0	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	356	 1	 6.0	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	357	 1	 15.5	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	358	 1	 23.7	 7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	359	 1	 33.7	 1.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	360	 1	 54.2	 1.5	 0.0	 19.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	361	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	362	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	363	 1	 9.5	 5.1	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	364	 2	 -3.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	365	 1	 -0.0	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	367	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	368	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	369	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04735	    0.00000	 225.0	 1	    1.09026	    1.00444;
	370	 1	 62.0	 14.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	371	 1	 11.8	 2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	372	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	373	 1	 25.0	 8.3	 0.0	 0.0	 1	    1.04726	    0.00000	 225.0	 1	    1.09008	    1.00444;
	374	 1	 23.9	 1.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	375	 1	 15.0	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	376	 1	 53.8	 1.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	377	 1	 4.2	 -1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	378	 1	 29.7	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	379	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	380	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	381	 1	 49.3	 5.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	382	 1	 16.4	 -0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	383	 1	 44.9	 16.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	384	 1	 18.2	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	385	 1	 15.8	 9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	386	 1	 42.8	 9.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	387	 1	 5.7	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	388	 1	 44.7	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	389	 1	 26.8	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	390	 1	 2.8	 0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	391	 1	 21.2	 -4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	392	 1	 29.2	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	393	 1	 5.0	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	394	 1	 6.0	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	395	 1	 41.0	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	396	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	397	 1	 13.0	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	398	 1	 6.0	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	399	 1	 3.5	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	400	 1	 20.1	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	401	 1	 5.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	402	 1	 21.7	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	403	 1	 20.0	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	404	 1	 31.5	 9.5	 0.0	 0.0	 1	    1.00011	    0.00000	 63.0	 1	    1.06372	    0.93651;
	405	 1	 6.9	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	406	 1	 59.9	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	407	 1	 0.6	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	408	 1	 13.8	 -4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	409	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	410	 1	 20.0	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	411	 1	 15.9	 -0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	412	 1	 22.8	 -5.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	413	 1	 28.1	 0.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	414	 1	 -0.3	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	415	 1	 9.6	 -1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	416	 1	 20.4	 -31.1	 0.0	 0.0	 1	    1.04683	    0.00000	 225.0	 1	    1.08923	    1.00444;
	417	 1	 18.3	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	418	 1	 9.0	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	419	 1	 27.2	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	420	 1	 -4.3	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	421	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	422	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	423	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04455	    0.00000	 225.0	 1	    1.08911	    1.00000;
	424	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	425	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	426	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	427	 1	 -0.1	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	428	 1	 7.0	 -2.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	429	 1	 56.7	 7.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	430	 1	 114.0	 32.2	 0.0	 0.0	 1	    1.04798	    0.00000	 225.0	 1	    1.09152	    1.00444;
	431	 1	 13.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	432	 1	 25.0	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	433	 1	 3.2	 3.9	 0.0	 0.0	 1	    1.00942	    0.00000	 63.0	 1	    1.06645	    0.95238;
	434	 1	 14.0	 -3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	435	 1	 34.1	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	436	 1	 26.1	 -5.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	437	 1	 2.0	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	438	 1	 11.9	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	439	 1	 12.8	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	440	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	441	 1	 3.2	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	442	 1	 26.5	 3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	443	 1	 14.4	 3.9	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	445	 1	 29.7	 6.4	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	446	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	447	 2	 -0.0	 2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	448	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04080	    0.00000	 225.0	 1	    1.09494	    0.98667;
	450	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	451	 1	 0.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	452	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	453	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	454	 1	 25.0	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	455	 1	 10.0	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	456	 1	 28.0	 5.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	457	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	458	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	460	 1	 22.0	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	461	 1	 12.9	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	462	 1	 33.6	 -2.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	463	 1	 0.0	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	464	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.98440	    0.00000	 20.0	 1	    1.16881	    0.80000;
	465	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	466	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	467	 1	 74.6	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	468	 1	 31.4	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	469	 1	 0.3	 -1.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	470	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	471	 1	 -1.2	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	472	 1	 455.8	 268.5	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.15789	    0.94737;
	473	 1	 443.8	 285.5	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.15789	    0.94737;
	474	 1	 57.1	 1.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	475	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	478	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94981	    0.00000	 45.0	 1	    1.01073	    0.88889;
	479	 2	 8.2	 -5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	482	 1	 15.9	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	483	 1	 57.4	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	484	 1	 50.2	 0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	485	 1	 33.9	 1.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	486	 1	 10.4	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	487	 1	 46.2	 8.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	488	 1	 1.0	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	489	 1	 36.6	 8.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	490	 1	 -23.6	 9.6	 0.0	 0.0	 1	    1.01127	    0.00000	 90.0	 1	    1.08920	    0.93333;
	491	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	492	 1	 22.4	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	493	 1	 -3.8	 -6.3	 0.0	 0.0	 1	    1.05068	    0.00000	 225.0	 1	    1.10135	    1.00000;
	494	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	495	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	496	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	497	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	498	 1	 3.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	499	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04104	    0.00000	 225.0	 1	    1.09541	    0.98667;
	500	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04115	    0.00000	 225.0	 1	    1.09564	    0.98667;
	501	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	502	 1	 20.6	 -3.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	503	 1	 41.0	 -3.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	504	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	505	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	506	 1	 13.9	 6.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	507	 1	 52.5	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	508	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	509	 1	 36.0	 2.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	510	 1	 43.9	 -1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	511	 1	 45.5	 11.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	512	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	513	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	514	 1	 6.1	 -4.8	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	515	 1	 2.0	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	516	 1	 25.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	517	 1	 36.5	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	518	 1	 12.8	 2.6	 0.0	 0.0	 1	    0.97224	    0.00000	 63.0	 1	    1.05560	    0.88889;
	519	 1	 31.6	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	520	 1	 29.6	 -4.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	521	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	522	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	523	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	524	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	525	 1	 9.4	 4.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	526	 1	 2.4	 21.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	527	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	528	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	529	 1	 4.7	 1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	530	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	531	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	532	 1	 31.2	 9.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	533	 1	 25.3	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	534	 1	 24.9	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	535	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	537	 1	 20.6	 -1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	538	 1	 29.5	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	539	 1	 17.7	 3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	540	 1	 10.0	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	541	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	542	 1	 55.2	 6.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	543	 1	 52.2	 8.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	544	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	545	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04672	    0.00000	 225.0	 1	    1.08900	    1.00444;
	546	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	547	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	548	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	549	 1	 36.0	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	550	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	551	 1	 49.7	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	552	 1	 28.2	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	553	 1	 2.0	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	554	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	555	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04638	    0.00000	 225.0	 1	    1.09275	    1.00000;
	556	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04638	    0.00000	 225.0	 1	    1.09275	    1.00000;
	557	 1	 59.4	 -0.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	558	 1	 35.4	 -2.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	559	 1	 13.3	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	560	 1	 11.9	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	561	 1	 27.7	 -3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	562	 1	 19.5	 -2.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	563	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	564	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	565	 1	 13.2	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	566	 1	 34.7	 6.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	567	 1	 -0.1	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	568	 1	 12.9	 4.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	569	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	570	 1	 22.9	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	571	 1	 18.0	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	572	 1	 40.8	 -5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	574	 1	 6.0	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	575	 1	 5.9	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	576	 1	 7.0	 -0.9	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	577	 1	 39.0	 8.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	578	 1	 2.3	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	582	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	583	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	584	 1	 4.0	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	585	 1	 19.0	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	586	 2	 36.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	587	 1	 28.1	 -1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	588	 1	 12.2	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	589	 2	 14.2	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	590	 1	 201.4	 33.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	591	 1	 22.2	 -2.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	592	 1	 14.2	 -3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	593	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	594	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05067	    0.00000	 225.0	 1	    1.10134	    1.00000;
	595	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	596	 1	 8.9	 -1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	597	 1	 9.5	 -1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	598	 1	 30.0	 -0.5	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	599	 1	 7.4	 2.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	600	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	601	 1	 -0.8	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	602	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	604	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	605	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	606	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	607	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	608	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	609	 1	 2.5	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	610	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	611	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	612	 1	 31.3	 -3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	613	 1	 15.2	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	614	 1	 10.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	615	 1	 47.3	 24.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	616	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	617	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07944	    0.00000	 380.0	 1	    1.10625	    1.05263;
	618	 1	 15.7	 -5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	619	 1	 18.9	 -3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	620	 1	 3.0	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	621	 1	 3.0	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	622	 1	 0.0	 -1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	623	 1	 15.2	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	624	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	625	 1	 48.1	 -3.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	626	 1	 10.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	627	 1	 11.8	 -1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	628	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	629	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02471	    0.00000	 90.0	 1	    1.07165	    0.97778;
	630	 1	 35.5	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	631	 1	 55.8	 1.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	632	 1	 -0.1	 1.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	633	 2	 13.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	634	 1	 9.4	 -1.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	635	 1	 24.7	 4.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	636	 2	 31.7	 2.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	637	 1	 20.2	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	638	 1	 7.3	 -1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	639	 1	 4.0	 0.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	640	 1	 35.3	 3.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	641	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.07997	    0.00000	 380.0	 1	    1.10730	    1.05263;
	642	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	643	 1	 14.6	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	644	 1	 16.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	645	 1	 26.9	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	646	 1	 29.5	 -3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	647	 1	 24.6	 2.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	648	 1	 41.0	 4.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	649	 1	 46.5	 13.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	650	 1	 14.9	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	651	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	652	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	653	 1	 41.9	 3.4	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	654	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	655	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	656	 1	 8.9	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	657	 1	 47.4	 7.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	658	 1	 33.4	 13.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	659	 1	 7.0	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	660	 1	 2.8	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	661	 1	 43.4	 4.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	662	 1	 -0.0	 -14.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	663	 1	 30.6	 -4.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	664	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	665	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	666	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	667	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	668	 1	 0.0	 0.0	 0.0	 10.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	669	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	670	 1	 11.4	 -6.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	671	 1	 37.9	 -0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	672	 1	 26.2	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	673	 1	 1.8	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	674	 1	 6.0	 -0.6	 0.0	 0.0	 1	    1.02328	    0.00000	 90.0	 1	    1.06878	    0.97778;
	675	 1	 13.6	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	676	 1	 4.9	 2.5	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	677	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02459	    0.00000	 90.0	 1	    1.07141	    0.97778;
	678	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	679	 1	 13.0	 -1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	680	 1	 15.2	 -3.8	 0.0	 0.0	 1	    1.02237	    0.00000	 90.0	 1	    1.06697	    0.97778;
	681	 1	 96.6	 18.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	682	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	683	 1	 33.3	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	684	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	685	 1	 -2.6	 -1.5	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	686	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	687	 1	 -2.6	 -1.5	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	688	 1	 3.7	 1.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	689	 1	 2.2	 1.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	690	 1	 11.5	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	691	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	692	 1	 42.5	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	693	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	694	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	695	 1	 33.4	 -4.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	696	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	697	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	698	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	699	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	700	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	701	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	702	 1	 42.3	 10.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	703	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	704	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	705	 2	 8.9	 -0.6	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	706	 1	 23.4	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	707	 1	 18.9	 -0.3	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	708	 1	 23.9	 2.7	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	709	 1	 27.9	 0.7	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	710	 1	 0.0	 0.0	 0.0	 29.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	711	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.02384	    0.00000	 90.0	 1	    1.06990	    0.97778;
	712	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	713	 1	 0.4	 -6.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	714	 1	 17.8	 -2.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	715	 1	 -1.2	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	716	 1	 1.9	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	717	 1	 29.3	 -3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	718	 1	 24.9	 -8.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	719	 1	 8.7	 -1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	720	 1	 37.2	 5.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	721	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04464	    0.00000	 225.0	 1	    1.08484	    1.00444;
	722	 1	 47.2	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	723	 1	 27.4	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	724	 1	 38.6	 5.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	725	 1	 12.8	 9.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	726	 1	 13.6	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	727	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02000	    0.00000	 225.0	 1	    1.08889	    0.95111;
	728	 1	 30.9	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	729	 1	 19.0	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	730	 1	 22.0	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	731	 1	 52.2	 11.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	732	 1	 13.9	 -2.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	733	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	734	 1	 0.1	 -3.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	735	 1	 9.0	 1.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	736	 1	 29.1	 -6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	737	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	738	 1	 42.8	 -2.1	 0.0	 0.0	 1	    1.02791	    0.00000	 90.0	 1	    1.07804	    0.97778;
	739	 1	 79.9	 11.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	740	 1	 11.0	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	741	 1	 12.0	 -3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	742	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	743	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	744	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	745	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	746	 2	 11.8	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	747	 1	 11.9	 1.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	748	 1	 4.0	 3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	749	 1	 12.8	 -6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	750	 1	 11.3	 -1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	751	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	752	 1	 9.8	 2.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	753	 1	 22.8	 3.2	 0.0	 0.0	 1	    1.00294	    0.00000	 63.0	 1	    1.06937	    0.93651;
	754	 1	 17.3	 3.9	 0.0	 78.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	755	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	756	 1	 47.2	 3.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	757	 1	 99.2	 23.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	758	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	759	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	760	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00071	    0.00000	 63.0	 1	    1.06491	    0.93651;
	761	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	762	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.82500	    0.00000	 20.0	 1	    1.15000	    0.50000;
	763	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	764	 1	 17.0	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	765	 1	 18.7	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	766	 1	 8.9	 -3.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	767	 1	 17.6	 3.7	 0.0	 0.0	 1	    1.02274	    0.00000	 90.0	 1	    1.06771	    0.97778;
	768	 1	 0.0	 0.0	 0.0	 34.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	769	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	770	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	771	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	772	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	773	 1	 67.0	 15.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	774	 1	 10.9	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	775	 1	 45.6	 6.0	 0.0	 0.0	 1	    1.02945	    0.00000	 90.0	 1	    1.08112	    0.97778;
	776	 1	 25.7	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	777	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	778	 1	 7.0	 1.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	779	 1	 22.0	 6.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	780	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	781	 1	 7.8	 4.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	782	 1	 20.2	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	783	 1	 28.1	 -3.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	784	 1	 107.3	 9.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	785	 1	 1.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	786	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	787	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	788	 1	 -5.6	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	789	 1	 -20.6	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	790	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	791	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	792	 1	 9.0	 4.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	793	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	794	 1	 0.8	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	795	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	796	 1	 58.7	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	797	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	798	 1	 11.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	799	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	800	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	801	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	802	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	803	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	804	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	805	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	806	 1	 11.0	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	807	 1	 13.6	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	808	 1	 62.8	 21.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	809	 1	 -0.2	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	810	 1	 -2.8	 -3.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	811	 1	 68.3	 19.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	812	 1	 1.3	 -1.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	813	 1	 4.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	814	 1	 15.5	 -0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	815	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	816	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	817	 1	 72.8	 11.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	818	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	819	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	820	 1	 20.9	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	821	 1	 40.5	 0.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	822	 1	 31.3	 -6.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	823	 1	 5.9	 0.9	 0.0	 0.0	 1	    1.03039	    0.00000	 90.0	 1	    1.08301	    0.97778;
	824	 1	 1.7	 2.5	 0.0	 0.0	 1	    1.02667	    0.00000	 150.0	 1	    1.10667	    0.94667;
	825	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	826	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	827	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	828	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	829	 1	 52.9	 6.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	830	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	831	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	832	 1	 0.3	 -1.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	833	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	834	 1	 42.0	 -4.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	835	 1	 46.3	 -8.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	836	 2	 -0.5	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	837	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	838	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	839	 1	 7.6	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	840	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	841	 1	 41.2	 -4.0	 0.0	 0.0	 1	    1.02812	    0.00000	 90.0	 1	    1.07846	    0.97778;
	842	 1	 1.9	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	843	 1	 27.4	 13.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	844	 1	 9.8	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	845	 1	 30.5	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	846	 1	 18.0	 3.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	847	 1	 26.9	 -1.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	848	 1	 15.0	 -1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	849	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	850	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04585	    0.00000	 225.0	 1	    1.09170	    1.00000;
	851	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	852	 1	 -2.5	 -1.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	853	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.08889	    0.91111;
	854	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	855	 1	 7.0	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	856	 1	 10.4	 4.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	857	 2	 15.3	 -1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	858	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	859	 1	 36.5	 11.0	 0.0	 0.0	 1	    1.04733	    0.00000	 225.0	 1	    1.09023	    1.00444;
	860	 1	 26.0	 4.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	861	 1	 21.0	 -5.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	862	 1	 -1.8	 -0.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	863	 1	 10.2	 -0.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	864	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	865	 2	 13.8	 -10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	866	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	867	 1	 0.0	 -0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	868	 1	 0.2	 -5.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	869	 1	 43.9	 4.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	870	 1	 16.0	 9.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	871	 1	 22.9	 9.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	872	 1	 3.3	 -0.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	873	 1	 51.2	 3.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	874	 1	 46.7	 2.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	875	 1	 24.4	 1.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	876	 1	 26.3	 4.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	877	 1	 2.6	 -0.1	 0.0	 0.0	 1	    1.04682	    0.00000	 225.0	 1	    1.08920	    1.00444;
	878	 1	 15.6	 7.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	879	 1	 16.4	 4.8	 0.0	 0.0	 1	    1.00953	    0.00000	 63.0	 1	    1.06668	    0.95238;
	880	 1	 26.9	 4.8	 0.0	 0.0	 1	    1.00009	    0.00000	 63.0	 1	    1.04779	    0.95238;
	881	 1	 59.2	 -2.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	882	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	883	 1	 46.8	 11.4	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	884	 1	 3.9	 0.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	885	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	886	 1	 55.8	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	887	 1	 69.2	 15.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	888	 1	 57.6	 14.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	889	 2	 6.6	 -0.6	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	890	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	891	 1	 37.9	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	892	 1	 5.0	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	893	 1	 30.7	 2.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	894	 1	 15.9	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	895	 1	 -8.5	 -9.9	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	896	 1	 46.5	 23.5	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	897	 1	 -5.5	 -12.3	 0.0	 0.0	 1	    1.07245	    0.00000	 380.0	 1	    1.10544	    1.03947;
	898	 1	 -48.6	 -2.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	899	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	900	 1	 5.0	 3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	901	 1	 10.7	 -1.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	902	 1	 23.7	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	903	 1	 27.6	 2.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	904	 1	 40.5	 3.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	905	 1	 108.8	 26.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	906	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	907	 1	 10.9	 2.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	908	 1	 32.4	 1.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	909	 1	 18.0	 -2.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	910	 1	 5.9	 0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	911	 1	 0.7	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	912	 1	 7.7	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	913	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	914	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	915	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	916	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	917	 1	 6.8	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	918	 1	 30.8	 3.6	 0.0	 0.0	 1	    1.02833	    0.00000	 90.0	 1	    1.07889	    0.97778;
	919	 1	 23.7	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	920	 1	 1.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	921	 1	 0.4	 -7.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	922	 1	 -2.1	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	923	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	924	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	925	 1	 24.9	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	926	 1	 13.2	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	927	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01621	    0.00000	 63.0	 1	    1.08004	    0.95238;
	928	 1	 53.8	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	929	 1	 0.7	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	930	 1	 31.6	 -4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	931	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	932	 1	 5.7	 0.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	933	 1	 5.0	 8.8	 0.0	 0.0	 1	    1.04693	    0.00000	 225.0	 1	    1.08943	    1.00444;
	934	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	935	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	936	 1	 12.5	 2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	937	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	938	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00889	    0.00000	 225.0	 1	    1.08889	    0.92889;
	939	 1	 124.0	 -15.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	940	 1	 8.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	941	 1	 48.6	 8.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	942	 1	 0.2	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	943	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	944	 2	 3.0	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	945	 1	 32.3	 2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	946	 1	 14.8	 -2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	947	 1	 8.2	 2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	948	 1	 35.1	 -1.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	949	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	950	 1	 9.5	 9.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	951	 1	 -1.0	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	952	 1	 13.4	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	953	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00187	    0.00000	 63.0	 1	    1.06724	    0.93651;
	954	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	955	 1	 1.0	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	956	 1	 1.8	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	957	 1	 -0.3	 -0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	958	 1	 9.9	 -4.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	959	 1	 35.5	 -1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	960	 1	 38.1	 14.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	961	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	963	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	964	 1	 0.2	 0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	965	 2	 46.5	 32.4	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	966	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	967	 1	 36.4	 -7.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	968	 1	 65.0	 14.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	969	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	970	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	971	 1	 0.6	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	972	 1	 36.9	 -5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	973	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	974	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	975	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	976	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	977	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	978	 1	 12.8	 4.6	 0.0	 0.0	 1	    1.00434	    0.00000	 63.0	 1	    1.07217	    0.93651;
	979	 1	 53.4	 6.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	980	 1	 14.5	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	981	 1	 32.4	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	982	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	983	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	984	 1	 17.1	 -0.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	985	 1	 12.0	 1.3	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	986	 1	 9.0	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	987	 2	 -1.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	988	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	989	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	990	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	991	 1	 19.9	 -3.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	992	 1	 18.1	 2.4	 0.0	 0.0	 1	    1.00115	    0.00000	 63.0	 1	    1.06579	    0.93651;
	993	 1	 13.5	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	994	 1	 8.7	 2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	995	 1	 0.0	 0.0	 0.0	 -64.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	996	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	997	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	998	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	999	 1	 54.0	 11.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1000	 1	 2.0	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1001	 1	 1.7	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1002	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1003	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1004	 1	 16.9	 2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1005	 1	 10.0	 -1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1006	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1007	 1	 46.5	 1.3	 0.0	 0.0	 1	    1.04699	    0.00000	 225.0	 1	    1.08953	    1.00444;
	1008	 1	 114.1	 16.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1009	 2	 -4.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1010	 1	 26.0	 -5.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1011	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00327	    0.00000	 63.0	 1	    1.07004	    0.93651;
	1012	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1013	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00455	    0.00000	 63.0	 1	    1.07259	    0.93651;
	1014	 1	 16.9	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1015	 1	 42.3	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1016	 1	 12.7	 6.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1017	 1	 65.6	 15.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1018	 1	 29.2	 2.6	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1019	 1	 19.2	 4.5	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1020	 1	 35.7	 -4.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1021	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1022	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1023	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1024	 1	 1.0	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1025	 1	 26.6	 4.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1026	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02435	    0.00000	 63.0	 1	    1.09632	    0.95238;
	1027	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02438	    0.00000	 63.0	 1	    1.09637	    0.95238;
	1028	 1	 81.2	 10.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1029	 1	 2.0	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1030	 1	 38.0	 7.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1031	 1	 17.4	 4.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1032	 1	 0.0	 -7.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1033	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1034	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1035	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1036	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1037	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1038	 1	 19.5	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1039	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1040	 1	 42.2	 2.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1041	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1042	 1	 -5.1	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1043	 1	 29.3	 1.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1044	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1045	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1046	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1047	 1	 60.7	 12.9	 0.0	 0.0	 1	    1.04800	    0.00000	 225.0	 1	    1.09156	    1.00444;
	1048	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1050	 1	 11.9	 -3.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1051	 1	 0.0	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1052	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1053	 1	 24.9	 0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1054	 1	 15.0	 1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1055	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1057	 2	 11.7	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1058	 1	 49.9	 16.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1059	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1060	 1	 30.0	 11.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1061	 1	 12.5	 -1.7	 0.0	 0.0	 1	    1.05843	    0.00000	 380.0	 1	    1.11686	    1.00000;
	1062	 1	 -28.7	 4.1	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1063	 1	 5.9	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1064	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1065	 1	 13.5	 -1.0	 0.0	 0.0	 1	    0.97360	    0.00000	 63.0	 1	    1.05832	    0.88889;
	1066	 2	 7.3	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1067	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1068	 1	 0.5	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1069	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1070	 1	 8.6	 -3.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1071	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1072	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1073	 1	 0.0	 0.0	 0.0	 10.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1074	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04547	    0.00000	 225.0	 1	    1.09093	    1.00000;
	1075	 1	 -11.7	 -0.3	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1076	 1	 -11.6	 -0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1077	 1	 21.1	 1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1078	 1	 40.4	 -3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1079	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1080	 1	 -1.8	 -12.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1081	 1	 -1.8	 -7.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1082	 1	 2.0	 2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1083	 1	 20.5	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1084	 1	 -0.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1085	 1	 11.2	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1086	 1	 9.2	 -0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1087	 1	 5.9	 -2.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1088	 1	 88.2	 11.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1089	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1090	 1	 6.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1091	 1	 40.9	 5.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1092	 1	 52.9	 14.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1093	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1094	 1	 27.7	 -0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1095	 1	 38.8	 0.4	 0.0	 0.0	 1	    1.00541	    0.00000	 63.0	 1	    1.07431	    0.93651;
	1096	 1	 51.3	 12.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1097	 1	 18.4	 1.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1098	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1099	 1	 23.0	 3.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1100	 1	 18.4	 0.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1101	 1	 21.1	 9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1102	 1	 34.7	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1103	 1	 25.6	 1.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1104	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1105	 1	 3.0	 1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1106	 1	 31.1	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1107	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01081	    0.00000	 63.0	 1	    1.06923	    0.95238;
	1108	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1109	 1	 11.8	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1110	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00238	    0.00000	 63.0	 1	    1.06826	    0.93651;
	1111	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1113	 1	 0.4	 -0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1114	 1	 15.0	 9.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1115	 1	 57.8	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1116	 1	 22.9	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1117	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1118	 1	 20.7	 -3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1119	 1	 75.1	 10.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1120	 1	 21.7	 3.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1121	 1	 19.9	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1122	 1	 27.0	 -3.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1123	 1	 10.9	 -16.5	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	1124	 1	 0.8	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1125	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1127	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1128	 1	 25.3	 -1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1129	 1	 0.1	 -3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1130	 1	 0.0	 0.0	 0.0	 29.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1131	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1132	 1	 43.4	 4.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1133	 1	 19.9	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1134	 1	 12.2	 -7.9	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1135	 1	 39.2	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1136	 1	 3.9	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1137	 1	 0.8	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1138	 1	 61.6	 4.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1139	 1	 17.8	 4.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1140	 1	 14.5	 4.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1141	 1	 31.9	 -4.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1142	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1143	 1	 60.3	 -0.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1144	 1	 9.6	 -5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1145	 1	 30.6	 -1.2	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1146	 1	 36.4	 5.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1147	 1	 9.1	 -2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1148	 1	 12.8	 -2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1149	 1	 38.2	 -3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1150	 1	 11.0	 2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1151	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1152	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1153	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1154	 1	 31.0	 5.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1155	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1156	 1	 90.4	 25.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1157	 1	 29.0	 16.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1158	 1	 36.1	 12.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1159	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1160	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1161	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1162	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1164	 1	 3.0	 6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1165	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1166	 1	 6.9	 -9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1167	 1	 22.6	 -4.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1168	 1	 8.4	 11.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1169	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1170	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1171	 1	 -0.2	 0.8	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1172	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1174	 1	 -0.7	 4.2	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1175	 1	 6.0	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1176	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1177	 1	 12.6	 5.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1178	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1179	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1180	 1	 2.0	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1181	 1	 -0.0	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1182	 1	 66.0	 17.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1183	 1	 54.4	 11.1	 0.0	 0.0	 1	    1.04788	    0.00000	 225.0	 1	    1.09132	    1.00444;
	1184	 1	 -0.6	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1185	 1	 174.5	 26.9	 0.0	 0.0	 1	    1.04757	    0.00000	 225.0	 1	    1.09070	    1.00444;
	1186	 1	 22.9	 4.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1187	 1	 14.3	 -4.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1188	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1189	 1	 19.3	 -6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1190	 1	 30.4	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1191	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1192	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1193	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1194	 1	 -0.5	 1.3	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1195	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1196	 1	 29.5	 -1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1197	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1198	 1	 36.9	 4.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1199	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1200	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1201	 1	 51.9	 2.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1202	 1	 28.1	 17.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1203	 1	 19.5	 3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1204	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1205	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1206	 1	 0.0	 0.0	 0.0	 40.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1207	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1208	 1	 7.0	 2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1209	 1	 17.4	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1210	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04740	    0.00000	 225.0	 1	    1.09481	    1.00000;
	1211	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1212	 1	 19.5	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1213	 1	 -0.6	 0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1214	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10263	    1.05526;
	1215	 1	 8.0	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1216	 1	 7.0	 -2.6	 0.0	 0.0	 1	    1.02740	    0.00000	 90.0	 1	    1.07703	    0.97778;
	1217	 1	 45.6	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1218	 1	 10.2	 -1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1219	 1	 2.8	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1220	 1	 25.8	 1.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1221	 1	 29.8	 -4.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1222	 1	 26.1	 14.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1223	 1	 15.9	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1224	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1225	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1226	 1	 0.0	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1227	 1	 0.1	 -0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1228	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1229	 1	 38.9	 9.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1230	 1	 14.8	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1231	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1232	 1	 45.2	 7.1	 0.0	 0.0	 1	    1.02360	    0.00000	 90.0	 1	    1.06943	    0.97778;
	1233	 1	 27.9	 -4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1234	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1235	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1236	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1237	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1238	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1239	 1	 25.3	 -1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1240	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1241	 1	 7.6	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1242	 1	 35.4	 10.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1243	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1244	 1	 26.6	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1245	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1246	 1	 0.0	 0.0	 0.0	 9.0	 1	    0.82500	    0.00000	 20.0	 1	    1.15000	    0.50000;
	1247	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1248	 1	 56.5	 0.3	 0.0	 0.0	 1	    1.00279	    0.00000	 63.0	 1	    1.06907	    0.93651;
	1249	 1	 28.0	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1250	 1	 24.1	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1251	 1	 61.8	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1252	 1	 0.0	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1253	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1254	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1255	 1	 2.2	 -1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1256	 1	 10.9	 -1.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1257	 1	 0.7	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1258	 1	 19.0	 -6.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1259	 1	 8.9	 -0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1260	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1261	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1262	 1	 8.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1263	 1	 34.1	 -5.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1264	 1	 93.7	 18.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1265	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04821	    0.00000	 225.0	 1	    1.09197	    1.00444;
	1266	 1	 10.9	 2.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1267	 1	 29.8	 3.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1268	 1	 10.4	 1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1269	 1	 12.6	 -5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1270	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1272	 1	 0.1	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1273	 1	 50.0	 7.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1274	 1	 45.8	 12.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1275	 1	 1.0	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1276	 1	 39.0	 -2.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1277	 1	 10.8	 1.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1278	 1	 20.6	 -8.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1279	 1	 -0.2	 -0.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1280	 1	 28.5	 2.5	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1281	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1282	 1	 47.9	 20.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1283	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1284	 1	 10.8	 13.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1285	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1286	 2	 -1.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1287	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1288	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1289	 1	 14.2	 -5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1290	 1	 18.9	 -4.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1291	 1	 -0.3	 -0.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1292	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1293	 1	 -13.4	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1294	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1295	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1296	 1	 39.6	 2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1297	 1	 33.6	 -2.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1298	 1	 25.0	 -3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1300	 1	 9.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1301	 1	 15.9	 0.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1302	 1	 32.9	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1303	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1304	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1305	 1	 -3.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1306	 1	 15.5	 -4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1307	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1308	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1309	 1	 0.4	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1310	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1311	 1	 0.1	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1312	 1	 15.9	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1313	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1314	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1315	 1	 34.4	 5.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1316	 1	 35.6	 -6.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1317	 1	 2.2	 1.9	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1318	 1	 0.2	 0.8	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1319	 1	 3.4	 -0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1320	 1	 19.5	 -1.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1321	 1	 25.1	 -1.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1322	 1	 42.3	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1323	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1324	 1	 20.7	 -2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1325	 2	 0.5	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1326	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1327	 1	 35.5	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1328	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1329	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1330	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1331	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1332	 1	 15.4	 1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1333	 1	 0.1	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1334	 1	 0.2	 -0.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1335	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1336	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1337	 1	 12.1	 1.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1338	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1339	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03919	    0.00000	 225.0	 1	    1.09172	    0.98667;
	1340	 2	 -19.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1341	 1	 26.2	 9.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1342	 1	 1.0	 -5.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1343	 1	 49.4	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1344	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1345	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1346	 1	 14.0	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1347	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1348	 1	 7.0	 2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1349	 1	 27.0	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1350	 1	 21.5	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1351	 1	 24.7	 -5.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1352	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1353	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1354	 1	 16.5	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1355	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99778	    0.00000	 225.0	 1	    1.08889	    0.90667;
	1356	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1357	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1358	 1	 5.0	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1359	 1	 20.8	 -1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1360	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1361	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1362	 1	 1.0	 0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1363	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1364	 1	 21.4	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1365	 1	 10.8	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1366	 1	 28.6	 -3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1367	 1	 57.3	 14.1	 0.0	 0.0	 1	    1.04672	    0.00000	 225.0	 1	    1.08901	    1.00444;
	1368	 1	 47.8	 11.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1369	 1	 -0.6	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1370	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1371	 1	 7.9	 1.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1372	 1	 133.6	 28.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1373	 1	 14.9	 4.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1374	 1	 12.8	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1375	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1376	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00445	    0.00000	 225.0	 1	    1.08889	    0.92000;
	1377	 1	 15.5	 -0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1378	 1	 0.0	 0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1379	 1	 17.8	 -5.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1380	 1	 33.3	 3.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1381	 1	 17.2	 -0.6	 0.0	 0.0	 1	    1.00472	    0.00000	 63.0	 1	    1.05706	    0.95238;
	1382	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1383	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1384	 1	 1.6	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1385	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1386	 1	 4.8	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1387	 1	 31.3	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1388	 1	 -1.0	 -0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1389	 1	 16.4	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1390	 1	 8.1	 -3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1391	 1	 6.0	 2.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1392	 1	 18.4	 9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1393	 1	 61.1	 10.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1394	 1	 0.5	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1395	 1	 27.9	 3.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1396	 1	 -2.2	 0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1397	 1	 24.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1398	 1	 6.9	 -2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1399	 1	 0.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1400	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1401	 1	 3.4	 -0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1402	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1403	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1404	 1	 45.0	 2.2	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1405	 1	 15.2	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1406	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1407	 1	 18.6	 -1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1408	 1	 13.0	 2.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1409	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1410	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1411	 1	 36.4	 -5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1412	 1	 21.5	 -0.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1413	 1	 35.7	 6.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1414	 1	 31.9	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1415	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1416	 1	 3.3	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1417	 1	 74.6	 9.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1418	 1	 22.0	 2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1419	 1	 9.2	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1420	 2	 35.1	 20.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1421	 1	 39.7	 9.7	 0.0	 0.0	 1	    1.04800	    0.00000	 225.0	 1	    1.09157	    1.00444;
	1422	 1	 31.4	 -0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1423	 1	 0.3	 1.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1424	 1	 21.8	 2.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1425	 1	 0.4	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1426	 1	 43.1	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1427	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1428	 1	 86.0	 12.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1429	 1	 16.0	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1430	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1431	 1	 39.0	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1432	 1	 37.2	 -0.4	 0.0	 0.0	 1	    1.02960	    0.00000	 90.0	 1	    1.08142	    0.97778;
	1433	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1434	 1	 4.9	 1.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1435	 1	 21.7	 -0.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1436	 1	 24.5	 1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1437	 1	 33.0	 -5.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1438	 1	 16.6	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1439	 1	 12.2	 2.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1440	 1	 20.7	 1.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1441	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1442	 1	 7.0	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1443	 1	 0.0	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1444	 1	 62.2	 17.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1445	 1	 -0.8	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1446	 1	 77.0	 20.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1447	 1	 19.0	 -2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1448	 1	 0.0	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1449	 1	 0.0	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1450	 1	 27.9	 -3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1451	 1	 21.1	 -10.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1452	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1453	 1	 11.0	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1454	 1	 0.0	 0.0	 0.0	 6.0	 1	    0.82500	    0.00000	 20.0	 1	    1.15000	    0.50000;
	1455	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1456	 1	 18.1	 -0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1457	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1458	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1460	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1461	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1462	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99778	    0.00000	 225.0	 1	    1.08889	    0.90667;
	1463	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1464	 1	 17.8	 -2.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1465	 1	 12.0	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1466	 1	 68.1	 16.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1467	 1	 58.7	 11.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1468	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1469	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1470	 1	 29.0	 4.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1471	 1	 46.0	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1472	 1	 11.6	 1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1473	 1	 5.0	 1.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1474	 1	 -1.1	 6.7	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1475	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1476	 1	 34.2	 -4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02437	    0.00000	 63.0	 1	    1.09636	    0.95238;
	1478	 1	 60.7	 21.3	 0.0	 20.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04031	    0.00000	 63.0	 1	    1.12823	    0.95238;
	1480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	1481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02667	    0.00000	 150.0	 1	    1.10667	    0.94667;
	1482	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1483	 1	 40.7	 3.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1484	 1	 4.8	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1485	 1	 9.0	 3.2	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1486	 1	 27.4	 3.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1487	 1	 27.7	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1488	 1	 17.6	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1489	 1	 -0.4	 -5.9	 0.0	 0.0	 1	    0.98971	    0.00000	 225.0	 1	    1.09053	    0.88889;
	1490	 1	 27.3	 0.6	 0.0	 0.0	 1	    1.02420	    0.00000	 90.0	 1	    1.07063	    0.97778;
	1491	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1492	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1493	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1494	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	1495	 1	 14.0	 4.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1496	 1	 11.0	 5.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1497	 1	 30.9	 3.7	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1498	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1499	 1	 25.0	 -71.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1500	 1	 144.8	 100.4	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	1501	 1	 14.0	 0.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1502	 1	 16.9	 3.9	 0.0	 0.0	 1	    1.02913	    0.00000	 90.0	 1	    1.08048	    0.97778;
	1503	 1	 71.8	 2.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1504	 1	 17.8	 -6.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1505	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1506	 1	 11.4	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1507	 1	 10.8	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1508	 1	 26.7	 3.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1509	 1	 13.7	 -7.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1510	 1	 35.1	 0.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1511	 1	 36.6	 7.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1512	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1513	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1514	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1515	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1516	 1	 35.5	 4.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1517	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	1518	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	1519	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 225.0	 1	    1.15556	    0.88889;
	1520	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 225.0	 1	    1.15556	    0.88889;
	1521	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1522	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1523	 1	 46.7	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1524	 1	 24.6	 2.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1525	 1	 2.0	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1526	 1	 35.0	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1527	 1	 19.5	 5.3	 0.0	 0.0	 1	    1.02816	    0.00000	 90.0	 1	    1.07854	    0.97778;
	1528	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1529	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1530	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04748	    0.00000	 225.0	 1	    1.09053	    1.00444;
	1531	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1532	 1	 16.3	 -3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1533	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1534	 1	 43.4	 12.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1535	 1	 6.0	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1537	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1538	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1539	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1540	 1	 5.0	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1541	 1	 10.9	 -5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1542	 1	 10.8	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1543	 1	 20.8	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1544	 1	 22.2	 5.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1545	 1	 27.5	 2.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1546	 1	 23.7	 -5.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1547	 1	 8.0	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1548	 1	 30.5	 -6.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1549	 1	 39.3	 3.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1550	 1	 26.6	 3.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1551	 1	 40.4	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1552	 1	 5.0	 1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1553	 1	 30.1	 4.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1554	 1	 25.6	 6.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1555	 2	 29.3	 9.1	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1556	 1	 35.9	 1.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1557	 1	 13.6	 13.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1558	 1	 56.9	 3.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1559	 1	 37.3	 6.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1560	 1	 37.9	 8.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1561	 1	 14.2	 0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1562	 1	 14.9	 2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1563	 1	 26.5	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1564	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1565	 1	 26.8	 4.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1566	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	1567	 1	 76.3	 19.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1568	 1	 17.5	 2.6	 0.0	 0.0	 1	    1.00210	    0.00000	 63.0	 1	    1.06770	    0.93651;
	1569	 1	 5.9	 -0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1570	 1	 44.2	 3.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1571	 1	 36.8	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1572	 1	 26.9	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1574	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1575	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1576	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1577	 1	 20.9	 3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1578	 1	 82.6	 8.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1579	 2	 35.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1582	 1	 25.6	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1583	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1584	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	1585	 1	 24.4	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1586	 1	 9.6	 -1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1587	 1	 25.0	 -2.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1588	 1	 21.6	 20.7	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	1589	 1	 24.9	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1590	 1	 15.4	 -3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1591	 1	 42.7	 2.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1592	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1593	 2	 -6.5	 -2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1594	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04784	    0.00000	 225.0	 1	    1.09123	    1.00444;
	1595	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1596	 1	 23.6	 10.2	 0.0	 30.0	 1	    1.01227	    0.00000	 63.0	 1	    1.07215	    0.95238;
	1597	 1	 125.1	 20.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1598	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1599	 2	 -2.0	 0.0	 0.0	 0.0	 1	    1.00289	    0.00000	 63.0	 1	    1.05339	    0.95238;
	1600	 1	 -7.8	 6.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1601	 1	 20.9	 1.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1602	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1604	 1	 38.4	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1605	 1	 22.7	 -3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1606	 1	 52.0	 3.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1607	 1	 50.9	 4.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1608	 1	 10.1	 -4.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1610	 1	 10.3	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1611	 1	 4.1	 -3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1612	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1613	 1	 25.2	 1.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1614	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1615	 1	 39.4	 -3.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1616	 1	 55.4	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1617	 1	 -1.4	 -1.6	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1618	 1	 56.7	 12.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1619	 1	 49.9	 13.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1620	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1621	 1	 12.5	 -2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1622	 1	 34.9	 8.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1623	 1	 52.9	 13.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1624	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1625	 1	 10.0	 3.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1626	 1	 59.2	 13.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1627	 1	 20.6	 3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1628	 1	 17.6	 -6.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1629	 1	 21.9	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1630	 1	 10.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1631	 1	 22.6	 3.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1632	 1	 38.8	 -1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1633	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1634	 1	 22.4	 1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1635	 1	 -2.6	 -3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1636	 1	 33.0	 2.7	 0.0	 0.0	 1	    1.00110	    0.00000	 63.0	 1	    1.06570	    0.93651;
	1637	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1638	 1	 14.2	 -3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1639	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1640	 1	 21.9	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1641	 1	 20.0	 6.2	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1642	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1643	 1	 14.2	 2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1644	 1	 9.0	 -2.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1645	 1	 40.5	 7.5	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1646	 1	 26.9	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1647	 1	 37.4	 5.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1648	 1	 21.0	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1649	 1	 19.0	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1650	 1	 23.0	 8.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1651	 1	 43.2	 8.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1652	 1	 1.6	 -0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1653	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1654	 1	 12.3	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1655	 1	 14.6	 6.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1656	 1	 33.2	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1657	 1	 48.9	 13.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1658	 1	 7.6	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1659	 1	 18.1	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1660	 1	 -1.4	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1661	 1	 21.6	 -1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1662	 1	 11.6	 0.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1663	 1	 22.0	 5.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1664	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1665	 1	 23.7	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1666	 1	 -0.2	 -0.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1667	 1	 55.0	 4.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1668	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1669	 1	 7.1	 -6.3	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1670	 1	 13.6	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1671	 1	 17.6	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1672	 1	 54.0	 -10.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1673	 1	 3.8	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1674	 1	 33.7	 -8.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1675	 1	 15.8	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1676	 1	 56.8	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1677	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1678	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1679	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1680	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1681	 1	 5.0	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1682	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1683	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1684	 1	 89.7	 0.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1685	 1	 -1.4	 -0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1686	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1687	 2	 -0.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1688	 1	 28.5	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07276	    0.00000	 380.0	 1	    1.10606	    1.03947;
	1690	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07275	    0.00000	 380.0	 1	    1.10604	    1.03947;
	1691	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1692	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03904	    0.00000	 225.0	 1	    1.09142	    0.98667;
	1693	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03898	    0.00000	 225.0	 1	    1.09129	    0.98667;
	1694	 2	 0.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1695	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1696	 1	 19.3	 36.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1697	 2	 0.0	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1698	 2	 9.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1699	 1	 42.2	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1700	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1701	 1	 74.0	 25.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1702	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1703	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1704	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1706	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1707	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1708	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1711	 1	 57.5	 7.7	 0.0	 10.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	1712	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01556	    0.00000	 225.0	 1	    1.08889	    0.94222;
	1713	 1	 67.8	 12.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1714	 1	 75.1	 15.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1715	 1	 0.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1716	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1717	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1718	 1	 0.0	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1719	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1720	 1	 19.7	 2.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1721	 1	 24.8	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1722	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1723	 1	 -4.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1724	 1	 14.4	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1725	 1	 50.5	 2.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1726	 1	 15.0	 4.2	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1727	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1728	 1	 13.5	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1729	 1	 20.6	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1730	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1731	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1732	 1	 13.4	 -2.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1733	 1	 19.5	 0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1734	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1735	 1	 12.0	 -2.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1736	 1	 -0.1	 2.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1737	 1	 -0.1	 2.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1738	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1739	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1740	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1741	 2	 -0.5	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1742	 2	 -4.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1743	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1744	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1745	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1746	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1747	 1	 14.8	 -5.4	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1748	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1749	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1750	 1	 21.8	 8.9	 0.0	 15.4	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1751	 1	 2.0	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1752	 1	 11.5	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1753	 1	 1.4	 0.4	 0.0	 0.0	 1	    1.00324	    0.00000	 63.0	 1	    1.06997	    0.93651;
	1754	 1	 23.5	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1755	 1	 22.6	 10.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1756	 1	 31.5	 4.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1757	 1	 15.2	 3.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1758	 1	 3.5	 -0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1759	 1	 26.4	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1760	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1761	 1	 48.0	 6.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1762	 1	 2.0	 -6.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1763	 1	 12.9	 3.4	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1764	 1	 21.4	 -2.9	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1765	 1	 2.0	 -4.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1766	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1767	 1	 28.6	 5.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1768	 1	 -1.9	 2.6	 0.0	 0.0	 1	    1.00007	    0.00000	 63.0	 1	    1.06363	    0.93651;
	1769	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1770	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1771	 1	 0.0	 0.0	 0.0	 20.0	 1	    1.02884	    0.00000	 90.0	 1	    1.07991	    0.97778;
	1772	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02534	    0.00000	 90.0	 1	    1.07290	    0.97778;
	1773	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1774	 1	 33.2	 4.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1775	 1	 74.4	 2.6	 0.0	 30.4	 1	    1.03550	    0.00000	 90.0	 1	    1.09322	    0.97778;
	1776	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1777	 1	 17.9	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1778	 1	 0.2	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1779	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	1780	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1781	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1782	 1	 12.1	 1.8	 0.0	 0.0	 1	    1.00273	    0.00000	 63.0	 1	    1.05307	    0.95238;
	1783	 1	 -0.2	 0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1784	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1785	 1	 27.0	 -3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1786	 1	 18.5	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1787	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1788	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1789	 1	 12.2	 5.8	 0.0	 10.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1790	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1791	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1792	 1	 42.0	 6.7	 0.0	 0.0	 1	    1.04700	    0.00000	 225.0	 1	    1.08957	    1.00444;
	1793	 1	 33.3	 6.1	 0.0	 0.0	 1	    1.04692	    0.00000	 225.0	 1	    1.08940	    1.00444;
	1794	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1795	 1	 18.3	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1796	 1	 49.0	 14.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1797	 1	 2.3	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1798	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1799	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1800	 1	 4.7	 -1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1801	 1	 18.7	 3.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1802	 1	 6.4	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1803	 1	 7.7	 1.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1804	 1	 5.0	 3.3	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1805	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.00007	    0.00000	 63.0	 1	    1.04775	    0.95238;
	1806	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1807	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1808	 1	 30.0	 4.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1809	 1	 23.3	 6.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1810	 1	 46.1	 -3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1811	 1	 3.0	 -0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	1812	 1	 29.3	 -4.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1813	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1814	 1	 10.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	1815	 1	 11.6	 -0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1816	 1	 48.9	 11.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1817	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1818	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1819	 1	 19.9	 1.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1820	 1	 42.0	 3.4	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1821	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1822	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1823	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1824	 1	 12.9	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1825	 1	 51.2	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1826	 1	 78.1	 -0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1827	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1828	 1	 6.1	 2.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1829	 1	 2.2	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1830	 1	 16.5	 2.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1831	 1	 14.1	 -3.6	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1832	 1	 41.6	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1833	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1834	 1	 36.8	 17.8	 0.0	 0.0	 1	    1.04724	    0.00000	 225.0	 1	    1.09005	    1.00444;
	1835	 1	 -0.9	 -2.0	 0.0	 0.0	 1	    1.04744	    0.00000	 225.0	 1	    1.09044	    1.00444;
	1836	 1	 0.2	 -0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1837	 1	 6.3	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1838	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1839	 1	 -2.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1840	 1	 7.6	 1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1841	 1	 9.6	 9.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1842	 1	 1.2	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1843	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1844	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1845	 1	 10.0	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1846	 1	 -0.3	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1847	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 63.0	 1	    1.06508	    0.96825;
	1848	 1	 34.1	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1849	 1	 22.0	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1850	 1	 25.0	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1851	 1	 18.4	 3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1852	 1	 27.1	 6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1853	 1	 39.7	 6.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1854	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1855	 2	 0.0	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1856	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1857	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1858	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1859	 1	 9.0	 1.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1860	 1	 14.0	 -2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1861	 1	 25.3	 6.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1862	 1	 32.8	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1863	 1	 8.6	 -2.6	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	1864	 1	 32.8	 -5.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1865	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1866	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1867	 1	 50.3	 8.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1868	 1	 39.7	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1869	 1	 16.9	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1870	 1	 0.5	 1.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1871	 1	 5.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1872	 1	 51.9	 19.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1873	 1	 9.0	 0.7	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	1874	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1875	 1	 -3.1	 2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1876	 1	 19.5	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1877	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1878	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04668	    0.00000	 225.0	 1	    1.08891	    1.00444;
	1879	 1	 13.9	 -1.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1880	 1	 9.0	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1881	 1	 10.0	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1882	 1	 30.1	 -0.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1883	 1	 36.3	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1884	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1885	 1	 37.4	 16.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1886	 1	 28.7	 10.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1887	 1	 117.4	 28.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1888	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1889	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1890	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1891	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1892	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1893	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1894	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1895	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1896	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1897	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1898	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1899	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1900	 1	 11.5	 -7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1901	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1902	 1	 1.1	 -2.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1903	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1904	 1	 -2.0	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1905	 1	 27.8	 -2.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1906	 1	 28.7	 4.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1907	 1	 44.1	 -1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1908	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1909	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1910	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1911	 1	 -1.8	 0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1912	 1	 70.3	 3.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1913	 1	 16.3	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1914	 1	 65.4	 10.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1915	 1	 40.3	 9.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1916	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1917	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1918	 1	 7.8	 -3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1919	 1	 33.0	 5.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	1920	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1921	 1	 53.1	 14.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1922	 2	 14.2	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1923	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1924	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1925	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1926	 1	 58.5	 7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1927	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	1928	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1929	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1930	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1931	 1	 -7.7	 -20.2	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1932	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1933	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1934	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1935	 1	 25.0	 1.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1936	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1937	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	1938	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01556	    0.00000	 225.0	 1	    1.08889	    0.94222;
	1939	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1940	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00359	    0.00000	 63.0	 1	    1.05480	    0.95238;
	1941	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	1942	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1943	 1	 8.1	 -0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1944	 1	 25.1	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1945	 1	 33.3	 -8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1946	 1	 36.4	 -5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1947	 1	 15.9	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1948	 1	 24.8	 2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1949	 1	 1.4	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1950	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1951	 1	 16.1	 -4.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1952	 1	 1.1	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1953	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1954	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1955	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1956	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1957	 1	 17.0	 -1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1958	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1959	 1	 13.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1960	 1	 29.8	 -2.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1961	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1962	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1963	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1964	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1965	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1966	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1967	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1968	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1969	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1970	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1971	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1972	 1	 9.5	 3.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1973	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1974	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	1975	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1976	 2	 -1.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1977	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1978	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1979	 1	 31.1	 0.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1980	 2	 -1.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1981	 1	 1.3	 0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1982	 1	 53.9	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1983	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	1984	 1	 40.8	 3.3	 0.0	 0.0	 1	    1.02735	    0.00000	 90.0	 1	    1.07693	    0.97778;
	1985	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1986	 2	 0.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1987	 1	 -0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1988	 1	 0.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1989	 1	 15.0	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1990	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1991	 1	 17.1	 2.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1992	 1	 12.0	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1993	 1	 8.9	 3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1994	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1995	 1	 0.7	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1996	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1997	 1	 22.5	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1998	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1999	 1	 56.0	 11.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2000	 1	 12.7	 1.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2001	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2002	 1	 49.7	 8.7	 0.0	 0.0	 1	    1.04809	    0.00000	 225.0	 1	    1.09175	    1.00444;
	2003	 1	 22.2	 7.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2004	 1	 2.2	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2005	 1	 19.0	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2006	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2007	 1	 12.0	 -4.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2008	 1	 1.0	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2009	 1	 64.7	 19.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2010	 1	 -8.5	 -36.1	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	2011	 1	 5.5	 8.2	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	2012	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2013	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2014	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04724	    0.00000	 225.0	 1	    1.09448	    1.00000;
	2015	 1	 7.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2016	 1	 -0.7	 -4.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2017	 1	 23.5	 8.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2018	 1	 26.9	 -0.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2019	 1	 36.0	 3.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2020	 1	 47.6	 2.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2021	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2022	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2023	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2024	 1	 9.6	 1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2025	 1	 60.6	 8.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2026	 1	 30.7	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2027	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2028	 1	 32.2	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2029	 1	 7.3	 -1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2030	 1	 14.5	 -0.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2031	 1	 16.0	 -5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2032	 1	 7.0	 -4.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2033	 1	 37.2	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2034	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2035	 1	 47.1	 1.1	 0.0	 15.4	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2036	 1	 9.6	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2037	 1	 38.9	 0.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2038	 1	 8.0	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2039	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2040	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2041	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2042	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2043	 1	 31.2	 1.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2044	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2045	 1	 25.3	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2046	 1	 15.5	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2047	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2048	 1	 1.3	 -0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2050	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2051	 1	 19.7	 3.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2052	 1	 16.7	 1.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2053	 1	 15.7	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2054	 1	 16.4	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2055	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2057	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2058	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2059	 1	 -4.7	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2060	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2061	 1	 13.2	 0.8	 0.0	 0.0	 1	    1.00695	    0.00000	 63.0	 1	    1.07740	    0.93651;
	2062	 1	 51.4	 2.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2063	 1	 25.6	 4.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2064	 1	 -0.3	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2065	 1	 33.4	 10.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2066	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00606	    0.00000	 63.0	 1	    1.07561	    0.93651;
	2067	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2068	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2069	 1	 16.0	 6.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2070	 1	 20.9	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2071	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2072	 1	 34.0	 3.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2073	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2074	 1	 69.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2075	 1	 96.0	 -5.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2076	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2077	 1	 2.1	 -1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2078	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2079	 1	 17.0	 0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2080	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2081	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2082	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2083	 1	 51.1	 8.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2084	 1	 25.8	 4.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2085	 1	 12.9	 -3.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2086	 1	 20.5	 4.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2087	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.08889	    0.91111;
	2088	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.08889	    0.91111;
	2089	 1	 52.3	 18.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2090	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2091	 1	 14.2	 3.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2092	 2	 9.0	 3.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2093	 1	 22.7	 -1.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2094	 1	 17.1	 -6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2095	 1	 11.8	 -1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2096	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2097	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2098	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2099	 1	 30.8	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2100	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2101	 1	 14.1	 -7.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2102	 1	 2.1	 -0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2103	 1	 9.1	 1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2104	 1	 7.1	 -2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2105	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2106	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2107	 1	 5.1	 -1.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2108	 1	 16.6	 -2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2109	 1	 25.2	 -0.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2110	 1	 14.0	 8.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2111	 1	 26.4	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2112	 1	 2.1	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2113	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2114	 1	 3.0	 -0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2115	 1	 48.3	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2116	 1	 28.1	 -11.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2117	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2118	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2120	 1	 14.4	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2121	 1	 15.2	 -4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2122	 1	 37.1	 -3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2123	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2124	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2125	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2127	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02667	    0.00000	 150.0	 1	    1.10667	    0.94667;
	2128	 1	 37.2	 1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 225.0	 1	    1.08889	    0.95556;
	2129	 1	 16.1	 3.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2130	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2131	 1	 14.1	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2132	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2133	 1	 405.8	 117.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2134	 1	 19.6	 8.8	 0.0	 0.0	 1	    0.98937	    0.00000	 225.0	 1	    1.08986	    0.88889;
	2135	 1	 6.0	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2136	 1	 11.7	 5.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2137	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2138	 1	 -2.6	 2.3	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2139	 1	 40.3	 49.8	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2140	 1	 57.4	 9.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2141	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2142	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2143	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2144	 1	 18.2	 -1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2145	 1	 12.0	 0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2146	 1	 24.6	 3.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2147	 1	 23.5	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2148	 1	 13.0	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2149	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2150	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2151	 1	 42.2	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2152	 1	 14.0	 4.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2153	 1	 56.4	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2154	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2155	 1	 52.5	 -0.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04858	    0.00000	 225.0	 1	    1.09272	    1.00444;
	2157	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2158	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2159	 1	 27.2	 -2.6	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2160	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	2161	 1	 4.6	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2162	 1	 8.6	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2163	 1	 14.6	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2164	 1	 -0.3	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2165	 1	 18.7	 -4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2166	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01621	    0.00000	 63.0	 1	    1.08003	    0.95238;
	2167	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2168	 1	 32.4	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2169	 1	 32.6	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2170	 1	 65.7	 20.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2171	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2172	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2173	 1	 55.8	 12.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2174	 1	 17.2	 5.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2175	 1	 18.6	 -3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2176	 1	 60.3	 12.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2177	 1	 33.3	 6.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2178	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2179	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2180	 1	 24.3	 1.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2181	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2182	 1	 6.0	 5.4	 0.0	 0.0	 1	    1.00351	    0.00000	 63.0	 1	    1.05463	    0.95238;
	2183	 1	 36.7	 3.2	 0.0	 0.0	 1	    0.96825	    0.00000	 63.0	 1	    1.04762	    0.88889;
	2184	 1	 39.9	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2185	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2186	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2187	 1	 17.4	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2188	 2	 0.7	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2189	 1	 4.3	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	2190	 1	 9.3	 2.5	 0.0	 0.0	 1	    1.04688	    0.00000	 225.0	 1	    1.08931	    1.00444;
	2191	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2192	 1	 14.3	 0.0	 0.0	 0.0	 1	    1.04688	    0.00000	 225.0	 1	    1.08932	    1.00444;
	2193	 1	 -2.7	 11.0	 0.0	 0.0	 1	    1.04687	    0.00000	 225.0	 1	    1.08930	    1.00444;
	2194	 1	 5.1	 4.7	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2195	 1	 8.4	 -0.4	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	2196	 1	 57.2	 -3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2197	 1	 48.9	 -0.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2198	 1	 2.0	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2199	 1	 119.1	 6.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2200	 1	 13.9	 5.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2201	 1	 26.0	 4.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2202	 1	 1.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2203	 1	 87.3	 4.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2204	 1	 7.7	 -2.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2205	 1	 16.9	 2.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2206	 1	 7.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2207	 1	 40.5	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2208	 1	 28.1	 18.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2209	 1	 77.6	 8.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2210	 1	 114.0	 30.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2211	 1	 1.0	 -1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2212	 1	 14.0	 0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2213	 1	 35.4	 -0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2214	 1	 27.3	 4.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2215	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2216	 1	 87.5	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2217	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2218	 1	 11.6	 4.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2219	 1	 36.6	 3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2220	 1	 29.0	 9.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2221	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2222	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2223	 1	 21.4	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2224	 1	 6.6	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2225	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2226	 1	 37.1	 5.8	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2227	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	2228	 1	 18.0	 -0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2229	 1	 -12.1	 0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	2230	 1	 37.7	 8.5	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2231	 1	 11.3	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2232	 1	 0.2	 4.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2233	 1	 1.5	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2234	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.83000	    0.00000	 150.0	 1	    1.00000	    0.66000;
	2235	 1	 43.5	 -16.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2236	 1	 12.1	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2237	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2238	 1	 7.1	 3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2239	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2240	 2	 0.2	 -0.4	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2241	 1	 3.1	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2242	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2243	 1	 10.3	 -7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2244	 1	 29.7	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2245	 1	 10.4	 5.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2246	 1	 20.0	 6.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	2247	 1	 49.3	 22.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2248	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2249	 1	 93.8	 5.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2250	 1	 42.8	 10.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2251	 1	 59.1	 9.3	 0.0	 0.0	 1	    1.04854	    0.00000	 225.0	 1	    1.09265	    1.00444;
	2252	 1	 50.5	 8.9	 0.0	 0.0	 1	    1.04828	    0.00000	 225.0	 1	    1.09212	    1.00444;
	2253	 1	 1.7	 -2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2254	 1	 4.0	 -1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2255	 1	 14.2	 2.4	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2256	 1	 28.5	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2258	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2259	 1	 25.7	 -0.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2260	 1	 4.1	 -0.4	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	2261	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03796	    0.00000	 63.0	 1	    1.12354	    0.95238;
	2262	 1	 1.7	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2263	 1	 -2.9	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2264	 1	 54.5	 8.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2265	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	2266	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	2267	 1	 27.8	 4.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2268	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2269	 1	 4.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2270	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2271	 1	 1.4	 -0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2272	 1	 4.9	 -1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2273	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2274	 1	 8.0	 -8.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2275	 1	 -143.5	 -79.4	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	2276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	2277	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2278	 1	 37.2	 9.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2279	 1	 16.9	 0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2280	 1	 6.0	 -1.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2281	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2282	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2283	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	2284	 1	 14.3	 4.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2285	 1	 44.7	 11.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2286	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2287	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2288	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2289	 1	 46.5	 12.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2290	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2291	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00609	    0.00000	 63.0	 1	    1.07568	    0.93651;
	2292	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2293	 1	 37.7	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2294	 1	 17.3	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2295	 1	 7.8	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2296	 1	 9.1	 -3.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2297	 1	 -0.8	 -1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2298	 1	 14.4	 0.4	 0.0	 15.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2299	 1	 8.6	 -2.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2300	 1	 6.0	 0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2301	 1	 52.4	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2302	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2303	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2304	 1	 23.5	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2305	 1	 20.8	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2306	 1	 59.5	 6.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2307	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2308	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2309	 1	 58.0	 13.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2310	 1	 13.9	 2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2311	 1	 33.0	 3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2312	 1	 13.0	 5.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2313	 1	 14.9	 -3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2314	 1	 48.4	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2315	 1	 15.6	 -2.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2316	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2317	 1	 19.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2318	 1	 53.1	 13.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2319	 1	 39.1	 11.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2320	 1	 26.6	 1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2321	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2322	 1	 12.9	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2324	 1	 38.7	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2325	 1	 8.9	 -4.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2326	 1	 5.0	 5.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2327	 1	 14.9	 -0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2328	 1	 20.4	 9.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2329	 1	 -1.0	 4.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2330	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07719	    0.00000	 380.0	 1	    1.10263	    1.05174;
	2331	 1	 27.0	 -3.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2332	 1	 13.3	 6.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2333	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2334	 2	 5.8	 2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2335	 2	 1.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2336	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2337	 1	 14.3	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2338	 1	 10.3	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2339	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2340	 1	 16.8	 -1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2341	 1	 38.3	 -1.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2342	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2344	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2345	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2346	 1	 9.0	 3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2347	 1	 17.2	 -5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2348	 1	 7.7	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2349	 1	 8.9	 -0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2350	 1	 8.2	 -3.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2351	 1	 43.9	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2352	 1	 17.1	 10.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2353	 1	 29.8	 3.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2354	 1	 59.5	 4.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2355	 1	 42.7	 -2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2356	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2357	 2	 -2.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2358	 2	 -2.3	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2359	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2360	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2361	 2	 -1.3	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2362	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2364	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2365	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2367	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2368	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2369	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2370	 1	 1.7	 -0.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2371	 1	 20.4	 5.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2372	 1	 12.5	 -2.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2373	 1	 7.2	 3.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2374	 1	 26.5	 -3.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2375	 1	 2.7	 1.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2376	 1	 8.0	 -2.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2377	 1	 27.0	 -0.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2378	 1	 7.0	 0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2379	 1	 43.1	 2.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2380	 1	 17.7	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2381	 1	 2.5	 2.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2382	 1	 10.0	 2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2383	 1	 0.2	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2384	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2385	 1	 19.0	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2386	 1	 4.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2387	 1	 5.3	 -5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2388	 1	 19.4	 -6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2389	 1	 12.8	 -5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2390	 1	 35.9	 9.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2391	 1	 6.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2392	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2393	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2394	 1	 49.8	 13.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2395	 1	 10.9	 6.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2396	 1	 6.9	 4.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2397	 1	 11.4	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2398	 1	 22.6	 -3.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2399	 1	 10.9	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2400	 1	 9.0	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2401	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2402	 1	 11.5	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2403	 1	 12.6	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2404	 1	 15.5	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2405	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2406	 1	 34.1	 5.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2407	 1	 47.1	 1.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2408	 1	 11.0	 3.6	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	2409	 1	 13.9	 13.2	 0.0	 0.0	 1	    1.04737	    0.00000	 225.0	 1	    1.09031	    1.00444;
	2410	 1	 6.9	 10.2	 0.0	 0.0	 1	    1.04738	    0.00000	 225.0	 1	    1.09032	    1.00444;
	2411	 1	 0.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2412	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2413	 1	 -13.0	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2414	 1	 20.1	 2.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2415	 1	 1.1	 0.0	 0.0	 0.0	 1	    1.02344	    0.00000	 90.0	 1	    1.06910	    0.97778;
	2416	 1	 43.7	 -7.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2417	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2418	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2419	 1	 28.0	 -0.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2420	 1	 11.6	 3.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2421	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2422	 1	 16.0	 -3.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2423	 1	 17.7	 9.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2424	 1	 18.9	 2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2425	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2426	 1	 17.7	 4.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2427	 1	 12.5	 -8.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2428	 1	 54.5	 12.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2429	 1	 106.3	 22.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2430	 1	 10.3	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2431	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2432	 1	 1.0	 -3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2433	 1	 10.0	 -7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2434	 1	 37.2	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2435	 1	 4.4	 0.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2436	 1	 13.8	 -0.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2437	 1	 15.9	 1.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2438	 1	 16.9	 -1.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2439	 1	 4.8	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2440	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2441	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2442	 1	 31.4	 -4.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2443	 1	 0.8	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2444	 1	 10.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2445	 1	 15.3	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2446	 1	 33.1	 -6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2447	 1	 60.7	 12.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2448	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2449	 1	 10.6	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2450	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2451	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2452	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2453	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04736	    0.00000	 225.0	 1	    1.09471	    1.00000;
	2454	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2455	 1	 1.3	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2456	 1	 3.8	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2457	 1	 10.1	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2458	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2459	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2460	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2461	 1	 0.0	 0.0	 0.0	 30.4	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2462	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2463	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2464	 1	 24.6	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2465	 1	 48.0	 1.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2466	 1	 10.0	 3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2467	 1	 12.0	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2468	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2469	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2470	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2471	 1	 11.1	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2472	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2474	 1	 19.6	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2475	 1	 59.9	 7.5	 0.0	 63.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2478	 1	 32.0	 3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2479	 1	 13.1	 -3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2480	 1	 20.8	 -0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2481	 1	 22.5	 -7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2482	 1	 16.9	 0.8	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2483	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2484	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2485	 1	 27.9	 1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2486	 1	 44.0	 1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2487	 1	 22.8	 1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2488	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2489	 1	 24.3	 -3.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2490	 1	 3.2	 1.9	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2491	 1	 8.0	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2492	 1	 14.9	 -8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2493	 1	 0.2	 -0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2494	 1	 15.2	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2495	 1	 46.9	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2496	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2497	 1	 35.5	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2498	 1	 4.0	 -4.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2499	 1	 13.9	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2500	 1	 31.6	 -3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2501	 1	 3.0	 -3.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2502	 1	 26.5	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2503	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2504	 1	 25.4	 -0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2505	 1	 0.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2506	 1	 48.7	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2507	 1	 45.8	 10.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2508	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2509	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2510	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2511	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	2512	 1	 17.6	 8.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2513	 1	 19.6	 6.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2514	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2515	 1	 -0.4	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2516	 2	 89.0	 4.0	 0.0	 0.0	 1	    1.05386	    0.00000	 90.0	 1	    1.15216	    0.95556;
	2517	 1	 21.3	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2518	 1	 51.6	 8.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2519	 1	 56.0	 3.5	 0.0	 0.0	 1	    1.04736	    0.00000	 225.0	 1	    1.09027	    1.00444;
	2520	 1	 8.8	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2521	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2522	 1	 45.7	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2523	 1	 16.5	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2524	 1	 41.3	 3.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2525	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2526	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2527	 1	 77.8	 11.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2528	 1	 18.0	 0.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2529	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2530	 1	 4.2	 -7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2531	 1	 35.6	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2532	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2533	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2534	 1	 14.1	 1.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2535	 1	 31.3	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2537	 1	 23.6	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2538	 1	 31.0	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2539	 1	 0.0	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2540	 1	 2.0	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2541	 1	 12.3	 -0.1	 0.0	 60.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2542	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	2543	 1	 33.1	 4.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2544	 1	 58.2	 12.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2545	 1	 24.4	 -4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2546	 1	 4.0	 0.0	 0.0	 0.0	 1	    1.00546	    0.00000	 63.0	 1	    1.07441	    0.93651;
	2547	 1	 41.4	 1.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2548	 1	 4.9	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2549	 1	 23.0	 0.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2550	 1	 13.9	 -0.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2551	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2552	 1	 29.0	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2553	 1	 32.6	 0.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2554	 1	 18.5	 -4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2555	 1	 31.1	 -4.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2556	 1	 10.8	 -3.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2557	 1	 13.5	 -1.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2558	 1	 15.6	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2559	 1	 43.7	 4.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2560	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2561	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2562	 1	 38.1	 3.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2563	 1	 7.7	 1.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2564	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2565	 1	 35.9	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2566	 1	 29.8	 4.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2567	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02468	    0.00000	 90.0	 1	    1.07159	    0.97778;
	2568	 1	 63.6	 15.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2569	 1	 10.9	 2.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2570	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2571	 1	 16.8	 13.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2572	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	2573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2574	 1	 28.9	 -6.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2575	 1	 25.3	 5.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2576	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	2577	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	2578	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2579	 1	 17.8	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2580	 1	 -0.1	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2581	 1	 -0.4	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2582	 1	 7.0	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2583	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2584	 1	 46.6	 19.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2585	 1	 33.1	 -0.1	 0.0	 0.0	 1	    0.97500	    0.00000	 63.0	 1	    1.15000	    0.80000;
	2586	 1	 11.7	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2587	 1	 47.9	 5.2	 0.0	 30.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2588	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2589	 1	 1.9	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2590	 1	 20.2	 1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2591	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2592	 1	 8.5	 -0.6	 0.0	 0.0	 1	    1.00160	    0.00000	 63.0	 1	    1.06669	    0.93651;
	2593	 1	 -2.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2594	 1	 30.9	 -13.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2595	 1	 22.8	 -3.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2596	 1	 15.9	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2597	 1	 28.0	 -6.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2598	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2599	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2600	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2601	 1	 20.0	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2602	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2603	 1	 18.9	 -4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2604	 2	 22.5	 0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2605	 1	 5.9	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2606	 1	 28.5	 -0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2607	 1	 49.7	 12.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2608	 1	 12.1	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2609	 1	 44.9	 2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2610	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2611	 1	 19.3	 -5.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2612	 1	 39.0	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2613	 1	 12.3	 2.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2614	 1	 28.0	 5.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2615	 1	 6.9	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2616	 1	 13.0	 -2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2617	 1	 33.7	 2.5	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	2618	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	2619	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02936	    0.00000	 225.0	 1	    1.08983	    0.96889;
	2620	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2621	 1	 60.2	 12.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2622	 1	 20.9	 1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2623	 1	 5.7	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2624	 1	 0.0	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2625	 1	 8.7	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2626	 1	 7.2	 2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2627	 1	 14.9	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2628	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2629	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2630	 1	 18.3	 -2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2631	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2632	 1	 1.3	 -0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2633	 2	 -3.2	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2634	 1	 2.0	 -1.6	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2635	 1	 49.8	 11.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2636	 1	 -6.1	 7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2637	 2	 -7.4	 9.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2638	 2	 7.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2639	 2	 -12.3	 -6.1	 0.0	 0.0	 1	    1.00740	    0.00000	 63.0	 1	    1.09417	    0.92063;
	2640	 1	 -0.9	 -1.3	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2641	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2642	 1	 5.8	 -2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2643	 1	 17.5	 -2.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2644	 1	 6.6	 -4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2645	 2	 3.6	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2646	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2647	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	2648	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2649	 1	 -0.3	 -4.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2650	 1	 0.5	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2651	 1	 23.1	 1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2652	 2	 -7.6	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2653	 2	 1.3	 10.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2654	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2655	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2656	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2657	 2	 -1.3	 1.5	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2658	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2659	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2660	 1	 69.2	 5.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2661	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2662	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.82500	    0.00000	 20.0	 1	    1.15000	    0.50000;
	2663	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2664	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2665	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2666	 1	 55.4	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2667	 1	 6.0	 0.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2668	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2669	 1	 2.8	 -7.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2670	 1	 42.9	 6.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2671	 1	 3.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2672	 1	 25.6	 15.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2673	 1	 -1.1	 -3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2674	 1	 43.2	 1.7	 0.0	 0.0	 1	    1.02334	    0.00000	 90.0	 1	    1.06890	    0.97778;
	2675	 1	 94.6	 21.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2676	 1	 41.1	 2.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2677	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2678	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2679	 1	 36.1	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2680	 1	 25.8	 -2.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2681	 1	 18.0	 2.5	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	2682	 1	 10.8	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2683	 1	 8.4	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2684	 1	 21.1	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2685	 1	 23.5	 -2.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2686	 1	 120.3	 29.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2687	 1	 16.0	 6.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2688	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2689	 1	 16.5	 -2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2690	 1	 22.0	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2691	 1	 15.3	 -0.1	 0.0	 0.0	 1	    1.02962	    0.00000	 90.0	 1	    1.08146	    0.97778;
	2692	 1	 15.7	 3.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2693	 1	 0.2	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2694	 1	 42.3	 2.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2695	 1	 21.8	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2696	 1	 13.9	 12.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2697	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2698	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00736	    0.00000	 63.0	 1	    1.07822	    0.93651;
	2699	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00416	    0.00000	 63.0	 1	    1.07181	    0.93651;
	2700	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2701	 1	 6.0	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2702	 1	 28.2	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2703	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2704	 1	 31.6	 -3.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2705	 1	 33.4	 4.8	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	2706	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2707	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2708	 1	 31.7	 4.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2711	 1	 4.8	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2712	 1	 -4.5	 3.2	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	2713	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2714	 1	 0.0	 0.0	 0.0	 640.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2715	 1	 53.3	 9.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2716	 1	 27.6	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2717	 1	 2.7	 -0.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2718	 1	 26.6	 -3.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2719	 1	 29.2	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2720	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2721	 1	 7.0	 -6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2722	 1	 10.7	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2723	 1	 0.0	 -2.0	 0.0	 0.0	 1	    1.00492	    0.00000	 63.0	 1	    1.07334	    0.93651;
	2724	 1	 34.8	 3.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2725	 1	 6.6	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2726	 1	 24.4	 -9.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2727	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2728	 1	 19.2	 -2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2729	 1	 5.0	 1.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2730	 1	 8.1	 10.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2731	 1	 1.1	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2732	 1	 1.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2733	 1	 14.0	 -1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2734	 1	 19.0	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2735	 1	 11.9	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2736	 1	 19.4	 3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2737	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2738	 1	 2.4	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2739	 1	 16.7	 0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2740	 1	 7.1	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	2741	 1	 -0.3	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2742	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04636	    0.00000	 225.0	 1	    1.09273	    1.00000;
	2743	 1	 25.5	 -6.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2744	 1	 -0.9	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2745	 1	 27.0	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2746	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2747	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2748	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01163	    0.00000	 63.0	 1	    1.07088	    0.95238;
	2749	 1	 42.5	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2750	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2751	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2752	 1	 3.0	 0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2753	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2754	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2755	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2756	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2757	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2758	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04034	    0.00000	 63.0	 1	    1.12829	    0.95238;
	2759	 1	 21.2	 -4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2760	 1	 36.3	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2761	 1	 0.0	 0.0	 0.0	 -64.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2762	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2763	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2764	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2765	 1	 21.3	 -2.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2766	 1	 10.3	 -0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2767	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00169	    0.00000	 63.0	 1	    1.06688	    0.93651;
	2768	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2769	 1	 38.4	 2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2770	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2771	 1	 29.6	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2772	 1	 49.3	 8.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2773	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2774	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2775	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	2776	 1	 15.0	 17.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2777	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2778	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2779	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2780	 1	 23.4	 1.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2781	 1	 17.3	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2782	 1	 13.6	 1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2783	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2784	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2785	 1	 4.5	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2786	 1	 0.0	 -0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2787	 1	 94.5	 6.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2788	 1	 126.2	 17.6	 0.0	 0.0	 1	    1.04687	    0.00000	 225.0	 1	    1.08930	    1.00444;
	2789	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	2790	 1	 -3.5	 2.7	 0.0	 80.0	 1	    1.02222	    0.00000	 225.0	 1	    1.08889	    0.95556;
	2791	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2792	 1	 14.0	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2793	 1	 16.9	 -2.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2794	 1	 46.5	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2795	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00039	    0.00000	 63.0	 1	    1.04839	    0.95238;
	2796	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	2797	 1	 1.6	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	2798	 1	 13.1	 9.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2799	 1	 29.2	 -7.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2800	 1	 16.3	 -4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2801	 1	 9.0	 2.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2802	 1	 0.0	 0.0	 0.0	 89.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2803	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2804	 1	 29.4	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2805	 1	 20.4	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2806	 1	 4.4	 1.6	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	2807	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2808	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2809	 1	 15.6	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2810	 1	 8.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2811	 2	 1.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2812	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2813	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2814	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2815	 1	 49.5	 4.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2816	 1	 9.8	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2817	 1	 27.9	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2818	 1	 100.9	 18.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2819	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2820	 1	 18.2	 1.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2821	 1	 25.7	 3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2822	 1	 57.4	 7.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2823	 1	 9.7	 1.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2824	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99092	    0.00000	 225.0	 1	    1.09296	    0.88889;
	2825	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2826	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2827	 1	 28.5	 2.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2828	 1	 43.7	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2829	 1	 10.3	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2830	 1	 2.8	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2831	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2832	 1	 43.1	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2833	 1	 12.4	 -2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2834	 1	 28.4	 -13.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2835	 1	 16.8	 -7.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2836	 1	 59.0	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2837	 1	 -2.5	 39.5	 0.0	 0.0	 1	    1.00289	    0.00000	 63.0	 1	    1.05339	    0.95238;
	2838	 1	 23.4	 -8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2839	 1	 19.9	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2840	 1	 49.0	 8.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2841	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2842	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2843	 1	 19.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2844	 1	 44.3	 8.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2845	 1	 41.4	 15.2	 0.0	 0.0	 1	    1.04683	    0.00000	 225.0	 1	    1.08923	    1.00444;
	2846	 1	 21.6	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2847	 1	 0.0	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2848	 1	 -12.8	 -14.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2849	 1	 2.4	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2850	 1	 10.9	 -2.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2851	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2852	 1	 0.4	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2853	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2854	 1	 58.5	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2855	 1	 0.9	 -0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2856	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2857	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2858	 1	 19.0	 0.4	 0.0	 0.0	 1	    1.00409	    0.00000	 63.0	 1	    1.07168	    0.93651;
	2859	 1	 28.0	 6.0	 0.0	 0.0	 1	    1.00340	    0.00000	 63.0	 1	    1.07030	    0.93651;
	2860	 1	 20.2	 2.3	 0.0	 0.0	 1	    1.00039	    0.00000	 63.0	 1	    1.06428	    0.93651;
	2861	 1	 6.3	 2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2862	 1	 16.0	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2863	 1	 -0.0	 -1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2864	 1	 -5.0	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2865	 1	 19.9	 3.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2866	 1	 1.4	 -6.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2867	 1	 33.9	 7.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2868	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2869	 1	 29.9	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2870	 1	 3.8	 2.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2871	 1	 15.9	 1.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2872	 1	 9.9	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2873	 1	 14.1	 7.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2874	 1	 1.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2875	 1	 0.1	 -0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2876	 1	 28.8	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2877	 1	 25.9	 3.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2878	 1	 34.4	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2879	 1	 5.3	 -6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2880	 1	 31.4	 11.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2881	 1	 0.1	 -0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2882	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00279	    0.00000	 63.0	 1	    1.06908	    0.93651;
	2883	 1	 17.6	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2884	 1	 64.5	 6.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2885	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2886	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2887	 1	 0.7	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2888	 1	 44.5	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2889	 1	 5.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2890	 1	 14.7	 4.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2891	 1	 7.8	 -8.6	 0.0	 10.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2892	 2	 -1.0	 1.8	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2893	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01136	    0.00000	 63.0	 1	    1.10208	    0.92063;
	2894	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2895	 1	 31.6	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2896	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2897	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2898	 1	 50.9	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2899	 1	 34.8	 -5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2900	 1	 21.2	 0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2901	 2	 21.0	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2902	 1	 10.3	 -9.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2903	 1	 21.4	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2904	 1	 19.9	 -5.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2905	 1	 30.5	 5.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2906	 1	 56.1	 6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2907	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2908	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2909	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2910	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2911	 1	 1.0	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2912	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2913	 1	 43.1	 2.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2914	 1	 15.8	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2915	 1	 17.6	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2916	 1	 21.5	 2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2917	 1	 11.9	 -1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2918	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2919	 1	 32.7	 -7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2920	 1	 12.7	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2921	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2922	 1	 56.8	 15.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2923	 1	 36.4	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2924	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98916	    0.00000	 225.0	 1	    1.08943	    0.88889;
	2925	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98914	    0.00000	 225.0	 1	    1.08939	    0.88889;
	2926	 1	 67.6	 13.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2927	 1	 39.3	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2928	 1	 10.3	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2929	 1	 19.8	 -4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2930	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2931	 1	 12.0	 3.2	 0.0	 0.0	 1	    1.00157	    0.00000	 63.0	 1	    1.06663	    0.93651;
	2932	 1	 0.3	 1.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2933	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2934	 1	 17.9	 -0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2935	 1	 13.0	 6.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2936	 1	 13.0	 6.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2937	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2938	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04633	    0.00000	 225.0	 1	    1.09266	    1.00000;
	2939	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2940	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2941	 1	 10.9	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2942	 1	 25.8	 2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2943	 1	 156.2	 43.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2944	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2945	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2946	 1	 15.6	 -4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2947	 1	 16.2	 2.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2948	 1	 42.3	 8.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2949	 1	 13.9	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2950	 1	 1.8	 1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2951	 1	 10.1	 -4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2952	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2953	 1	 17.8	 -4.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2954	 1	 12.9	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2955	 1	 0.0	 1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2956	 1	 15.9	 -2.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2957	 1	 28.9	 5.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2958	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2959	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2960	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2961	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	2963	 1	 3.1	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2964	 1	 52.1	 26.7	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2965	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2966	 1	 29.5	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2967	 1	 22.6	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2968	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2969	 1	 44.0	 4.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2970	 1	 20.0	 1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2971	 1	 24.9	 -5.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	2972	 1	 32.4	 2.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	2973	 1	 0.5	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2974	 1	 3.0	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2975	 1	 28.6	 2.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2976	 1	 18.9	 9.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2977	 1	 8.8	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	2978	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2979	 1	 36.8	 3.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	2980	 1	 31.0	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2981	 1	 -4.8	 5.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2982	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2983	 1	 14.0	 5.0	 0.0	 0.0	 1	    1.00229	    0.00000	 63.0	 1	    1.06807	    0.93651;
	2984	 1	 20.5	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2985	 1	 21.1	 1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	2986	 2	 11.4	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2987	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2988	 1	 12.4	 5.0	 0.0	 0.0	 1	    1.00244	    0.00000	 63.0	 1	    1.06838	    0.93651;
	2989	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00076	    0.00000	 63.0	 1	    1.06502	    0.93651;
	2990	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2991	 1	 63.7	 12.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2992	 1	 55.5	 24.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2993	 1	 46.5	 -10.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2994	 1	 42.9	 5.3	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2995	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2996	 1	 25.8	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2997	 1	 51.5	 2.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2998	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	2999	 1	 136.3	 13.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3000	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3001	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3002	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3003	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3004	 1	 22.7	 4.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3005	 1	 55.5	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3006	 1	 56.7	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3007	 1	 0.5	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3008	 1	 44.3	 -1.2	 0.0	 0.0	 1	    1.02476	    0.00000	 90.0	 1	    1.07174	    0.97778;
	3009	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3010	 1	 20.9	 2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3011	 1	 0.6	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3012	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3013	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3014	 2	 15.3	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3015	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00236	    0.00000	 63.0	 1	    1.06821	    0.93651;
	3016	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3017	 1	 12.0	 -2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3018	 1	 1.0	 -2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3019	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3020	 1	 35.7	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3021	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3022	 1	 50.3	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	3023	 1	 -1.3	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3024	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3025	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	3026	 1	 22.6	 1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3027	 1	 40.1	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3028	 1	 21.7	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3029	 1	 28.9	 -5.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3030	 1	 30.1	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3031	 1	 -30.4	 9.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3032	 1	 1.2	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3033	 1	 21.5	 -5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3034	 1	 2.0	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3035	 1	 53.6	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3036	 1	 22.9	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3037	 1	 20.0	 3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3038	 1	 10.9	 -1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3039	 1	 36.7	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3040	 1	 47.0	 5.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3041	 1	 10.9	 3.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3042	 1	 54.2	 5.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3043	 1	 9.0	 -1.6	 0.0	 0.0	 1	    1.02343	    0.00000	 90.0	 1	    1.06909	    0.97778;
	3044	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3045	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3046	 1	 0.2	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3047	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3048	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.08024	    0.00000	 380.0	 1	    1.10785	    1.05263;
	3050	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.08027	    0.00000	 380.0	 1	    1.10791	    1.05263;
	3051	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.08027	    0.00000	 380.0	 1	    1.10791	    1.05263;
	3052	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3053	 1	 37.9	 4.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3054	 1	 15.9	 6.1	 0.0	 0.0	 1	    1.00571	    0.00000	 63.0	 1	    1.05903	    0.95238;
	3055	 1	 29.6	 -1.5	 0.0	 0.0	 1	    1.00553	    0.00000	 63.0	 1	    1.05867	    0.95238;
	3056	 1	 14.2	 3.6	 0.0	 29.0	 1	    1.02409	    0.00000	 90.0	 1	    1.07041	    0.97778;
	3057	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3058	 1	 15.1	 -5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3059	 1	 31.1	 -3.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3060	 1	 27.2	 5.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3061	 1	 50.2	 2.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3062	 1	 33.2	 -2.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3063	 1	 5.7	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3064	 1	 0.8	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3065	 1	 25.9	 -4.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3066	 1	 29.8	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3067	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3068	 1	 2.5	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3069	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3070	 1	 1.8	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3071	 1	 20.3	 0.7	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	3072	 1	 5.2	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3073	 1	 12.1	 4.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3074	 1	 23.4	 3.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3075	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3076	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3077	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3078	 1	 86.7	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3079	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3080	 1	 2.1	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3081	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3082	 1	 5.4	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3083	 1	 25.9	 -0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3084	 1	 28.2	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3085	 1	 17.7	 1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3086	 1	 0.0	 -0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3087	 1	 1.0	 -2.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3088	 1	 12.7	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3089	 1	 11.5	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3090	 1	 9.3	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3091	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3092	 1	 24.8	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3093	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3094	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3095	 1	 78.4	 21.0	 0.0	 0.0	 1	    1.04670	    0.00000	 225.0	 1	    1.08895	    1.00444;
	3096	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3097	 1	 29.0	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3098	 1	 14.8	 1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3099	 1	 8.9	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3100	 2	 6.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3101	 1	 33.3	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3102	 1	 69.5	 1.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3103	 1	 -13.8	 -1.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3104	 1	 51.5	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3105	 1	 43.9	 18.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3106	 1	 12.1	 3.6	 0.0	 16.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3107	 1	 0.1	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3108	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3109	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3110	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3111	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3114	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3115	 1	 22.2	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3116	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3117	 1	 7.3	 1.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3118	 1	 4.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3119	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3120	 1	 88.9	 19.9	 0.0	 19.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3122	 1	 33.1	 1.0	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	3123	 1	 3.0	 3.0	 0.0	 0.0	 1	    1.00460	    0.00000	 63.0	 1	    1.08857	    0.92063;
	3124	 1	 26.0	 -1.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3125	 1	 14.9	 -4.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3126	 1	 35.8	 3.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	3127	 1	 43.2	 -2.9	 0.0	 0.0	 1	    1.00218	    0.00000	 63.0	 1	    1.06785	    0.93651;
	3128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3129	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3130	 1	 57.7	 12.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3131	 1	 43.7	 -4.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3132	 1	 13.7	 2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3133	 1	 39.3	 6.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3134	 1	 46.4	 -8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3135	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3136	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3137	 1	 9.5	 4.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3138	 1	 16.3	 7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3139	 1	 52.5	 5.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3140	 1	 22.9	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3141	 1	 3.1	 0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3142	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3143	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05336	    0.00000	 380.0	 1	    1.10263	    1.00409;
	3144	 1	 15.4	 1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3145	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.06667	    0.98889;
	3146	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3147	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3148	 1	 4.0	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3149	 1	 29.6	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3150	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3151	 1	 31.1	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3152	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3153	 1	 19.7	 3.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3154	 1	 23.2	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3155	 1	 0.2	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3156	 1	 107.8	 22.5	 0.0	 0.0	 1	    1.04739	    0.00000	 225.0	 1	    1.09034	    1.00444;
	3157	 1	 25.5	 9.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3158	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04711	    0.00000	 225.0	 1	    1.09422	    1.00000;
	3159	 1	 1.7	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3160	 1	 58.4	 13.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3161	 1	 45.9	 5.0	 0.0	 0.0	 1	    1.04802	    0.00000	 225.0	 1	    1.09161	    1.00444;
	3162	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3163	 1	 -0.1	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3165	 1	 15.8	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3166	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3167	 1	 46.8	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3168	 1	 40.7	 10.2	 0.0	 0.0	 1	    1.00350	    0.00000	 63.0	 1	    1.05462	    0.95238;
	3169	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3170	 1	 7.9	 -3.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3171	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3172	 1	 0.0	 0.0	 0.0	 78.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	3174	 1	 17.8	 -1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3175	 1	 24.4	 1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3176	 1	 9.7	 1.1	 0.0	 0.0	 1	    0.99375	    0.00000	 63.0	 1	    1.08273	    0.90476;
	3177	 1	 25.0	 0.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3178	 1	 46.7	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3179	 1	 21.5	 2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3180	 1	 12.5	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3181	 1	 15.7	 -0.4	 0.0	 0.0	 1	    1.00673	    0.00000	 63.0	 1	    1.07695	    0.93651;
	3182	 1	 0.0	 -2.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3183	 1	 42.3	 7.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3184	 1	 6.0	 2.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3185	 1	 17.0	 3.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3186	 1	 28.9	 0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3187	 1	 36.0	 33.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3188	 1	 33.2	 2.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3189	 1	 10.0	 3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3190	 1	 40.9	 8.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3191	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3192	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3193	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3194	 1	 54.2	 10.3	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	3195	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99556	    0.00000	 225.0	 1	    1.08889	    0.90222;
	3196	 1	 12.9	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3197	 1	 18.2	 5.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3198	 1	 0.0	 7.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3199	 1	 19.5	 -0.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3200	 1	 14.5	 2.9	 0.0	 10.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3201	 1	 20.5	 0.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	3202	 1	 18.5	 -3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3203	 2	 11.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3204	 1	 43.7	 -4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3205	 1	 124.8	 30.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3206	 1	 6.2	 -0.4	 0.0	 0.0	 1	    0.97337	    0.00000	 63.0	 1	    1.05785	    0.88889;
	3207	 1	 -0.3	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3208	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01391	    0.00000	 63.0	 1	    1.07543	    0.95238;
	3209	 1	 3.1	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3210	 1	 165.1	 59.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3211	 1	 46.0	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3212	 1	 17.0	 -7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3213	 1	 57.6	 5.1	 0.0	 0.0	 1	    1.00235	    0.00000	 63.0	 1	    1.05232	    0.95238;
	3214	 1	 6.0	 -2.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3215	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3216	 1	 0.2	 0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3217	 1	 15.6	 1.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3218	 1	 2.2	 0.2	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3219	 1	 23.3	 -8.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3220	 1	 23.1	 -4.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3221	 1	 4.0	 5.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3222	 1	 -0.6	 -1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3223	 1	 20.5	 -39.5	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3224	 1	 54.4	 10.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3225	 1	 50.9	 9.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3226	 1	 46.4	 11.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3227	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3228	 1	 33.6	 1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3229	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3230	 1	 3.1	 -2.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3231	 1	 27.8	 4.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3232	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3233	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3234	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3235	 1	 7.7	 3.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3236	 1	 21.3	 58.1	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	3237	 1	 18.1	 3.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3238	 1	 28.7	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3239	 2	 -3.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3240	 1	 35.2	 2.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3241	 1	 1.9	 1.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3242	 1	 7.8	 -4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3243	 1	 40.6	 -3.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3244	 1	 48.4	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3245	 1	 9.9	 1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3246	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3247	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3248	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3249	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3250	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3251	 1	 43.1	 -8.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3252	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3253	 1	 16.5	 1.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3254	 1	 21.1	 3.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3255	 1	 65.5	 8.8	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3256	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3257	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3258	 1	 6.3	 -11.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3259	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3260	 1	 14.6	 3.8	 0.0	 0.0	 1	    1.04780	    0.00000	 225.0	 1	    1.09117	    1.00444;
	3261	 1	 31.4	 4.8	 0.0	 0.0	 1	    0.99323	    0.00000	 63.0	 1	    1.04762	    0.93884;
	3262	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3263	 1	 31.6	 6.2	 0.0	 0.0	 1	    1.00222	    0.00000	 225.0	 1	    1.08889	    0.91556;
	3264	 1	 102.6	 18.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3265	 1	 18.9	 -3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3266	 1	 130.8	 13.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3267	 1	 29.6	 -5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3268	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3269	 1	 18.8	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3270	 1	 60.2	 3.8	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	3271	 1	 3.4	 19.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3272	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3273	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3274	 2	 -1.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3275	 2	 -0.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3277	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3279	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3280	 1	 2.2	 0.3	 0.0	 0.0	 1	    1.00069	    0.00000	 63.0	 1	    1.06488	    0.93651;
	3281	 1	 59.6	 11.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3282	 1	 0.1	 -1.3	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	3283	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02139	    0.00000	 63.0	 1	    1.09039	    0.95238;
	3284	 1	 47.7	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3285	 1	 25.8	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3286	 1	 9.7	 3.4	 0.0	 0.0	 1	    1.00006	    0.00000	 63.0	 1	    1.06362	    0.93651;
	3287	 1	 0.1	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3288	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3289	 1	 3.3	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3290	 1	 18.4	 6.7	 0.0	 15.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3291	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3292	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3293	 1	 0.9	 -0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3294	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02123	    0.00000	 63.0	 1	    1.07421	    0.96825;
	3295	 1	 53.4	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3296	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3297	 1	 22.5	 0.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3298	 1	 1.8	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3299	 1	 2.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3300	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3301	 2	 0.7	 10.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3302	 1	 2.5	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3303	 1	 10.9	 1.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3304	 1	 48.0	 13.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3305	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3306	 1	 4.1	 -3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3307	 1	 28.7	 -2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3308	 1	 25.4	 -3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3309	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3310	 1	 -9.6	 87.4	 0.0	 0.0	 1	    1.08129	    0.00000	 380.0	 1	    1.12046	    1.04211;
	3311	 1	 0.0	 1.9	 0.0	 0.0	 1	    1.08007	    0.00000	 380.0	 1	    1.11803	    1.04211;
	3312	 1	 24.0	 17.1	 0.0	 0.0	 1	    1.08269	    0.00000	 380.0	 1	    1.12326	    1.04211;
	3313	 1	 24.6	 34.2	 0.0	 0.0	 1	    1.08154	    0.00000	 380.0	 1	    1.12096	    1.04211;
	3314	 1	 0.2	 0.4	 0.0	 60.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3315	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3316	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3317	 1	 -0.6	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3318	 1	 6.0	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3319	 1	 4.6	 1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3320	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3321	 1	 -1.5	 -0.7	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3322	 1	 -1.5	 -0.8	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3323	 1	 18.0	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3324	 1	 20.1	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3325	 1	 25.0	 10.6	 0.0	 0.0	 1	    1.00402	    0.00000	 63.0	 1	    1.07154	    0.93651;
	3326	 1	 0.0	 0.5	 0.0	 0.0	 1	    1.00436	    0.00000	 63.0	 1	    1.07222	    0.93651;
	3327	 1	 51.5	 -2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3328	 1	 23.2	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3329	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3330	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3331	 1	 26.1	 -3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3332	 1	 49.7	 6.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3333	 1	 15.0	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3334	 1	 -0.0	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3335	 1	 65.0	 17.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3336	 1	 3.0	 2.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3337	 1	 1.8	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3338	 2	 27.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3339	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3340	 1	 9.0	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3341	 1	 33.0	 -1.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3342	 1	 0.1	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3344	 1	 107.3	 32.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3345	 1	 4.5	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3346	 1	 34.8	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3347	 1	 23.9	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3348	 1	 29.9	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3349	 1	 52.8	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3350	 1	 2.2	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3351	 1	 19.0	 -0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3352	 1	 47.8	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3353	 1	 31.6	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3354	 1	 27.2	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3355	 1	 6.0	 -1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3356	 1	 43.9	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3357	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3358	 1	 72.6	 0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3359	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04021	    0.00000	 63.0	 1	    1.12803	    0.95238;
	3360	 1	 133.5	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3361	 1	 7.2	 6.7	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3362	 1	 7.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3363	 1	 34.5	 5.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3364	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3365	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07835	    0.00000	 380.0	 1	    1.11459	    1.04211;
	3366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07875	    0.00000	 380.0	 1	    1.11538	    1.04211;
	3367	 1	 -19.5	 7.8	 0.0	 0.0	 1	    1.07876	    0.00000	 380.0	 1	    1.11541	    1.04211;
	3368	 1	 -0.6	 3.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3369	 1	 21.5	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3370	 1	 32.9	 3.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3371	 1	 9.2	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3372	 1	 27.2	 6.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3373	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	3374	 1	 0.0	 0.0	 0.0	 80.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3375	 1	 37.3	 2.9	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3376	 1	 7.7	 -2.6	 0.0	 0.0	 1	    1.00271	    0.00000	 63.0	 1	    1.08479	    0.92063;
	3377	 1	 11.7	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3378	 1	 5.0	 -2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3379	 1	 0.0	 -0.9	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3380	 1	 35.7	 0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3381	 1	 9.6	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3382	 1	 43.0	 -0.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3383	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04739	    0.00000	 225.0	 1	    1.09033	    1.00444;
	3384	 1	 0.9	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3385	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3386	 1	 47.3	 9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3387	 1	 18.7	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3388	 1	 40.8	 5.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3389	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	3390	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02445	    0.00000	 225.0	 1	    1.08889	    0.96000;
	3391	 1	 38.5	 3.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3392	 1	 13.2	 12.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3393	 1	 17.7	 1.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3394	 1	 34.9	 14.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3395	 1	 7.7	 2.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3396	 1	 32.0	 8.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3397	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3398	 2	 38.0	 16.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3399	 1	 23.7	 7.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3400	 1	 103.0	 4.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3401	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00403	    0.00000	 63.0	 1	    1.07155	    0.93651;
	3402	 1	 35.2	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3403	 1	 155.8	 65.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3404	 1	 14.9	 1.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3405	 1	 16.1	 -0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3406	 1	 4.8	 1.6	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3407	 1	 3.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3408	 1	 21.7	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3409	 1	 -8.4	 2.6	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	3410	 1	 2.3	 -6.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3411	 2	 -4.6	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3412	 1	 26.8	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3413	 1	 12.7	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3414	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3415	 1	 30.7	 3.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3416	 1	 44.5	 -6.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3417	 2	 40.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3418	 1	 10.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3419	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00992	    0.00000	 63.0	 1	    1.06746	    0.95238;
	3420	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3421	 1	 0.8	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3422	 1	 27.3	 -0.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3423	 1	 -2.0	 -12.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3424	 1	 50.4	 5.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3425	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3426	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	3427	 1	 10.1	 -1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3428	 1	 14.2	 -1.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3429	 1	 27.1	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3430	 1	 -0.8	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3431	 1	 63.9	 3.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3432	 1	 32.9	 -1.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3433	 1	 32.3	 -3.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3434	 1	 3.4	 -34.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3435	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.95000	    0.00000	 150.0	 1	    1.10000	    0.80000;
	3436	 1	 10.2	 1.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3437	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3438	 1	 16.1	 -2.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3439	 1	 0.3	 1.2	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	3440	 1	 35.7	 0.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3441	 1	 12.9	 -0.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3442	 1	 38.8	 1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3443	 1	 8.9	 -4.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3444	 1	 6.4	 0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3445	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3446	 1	 30.1	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3447	 1	 17.9	 -1.6	 0.0	 0.0	 1	    1.02780	    0.00000	 90.0	 1	    1.07783	    0.97778;
	3448	 1	 27.1	 -0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3450	 1	 75.4	 14.1	 0.0	 30.7	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3451	 1	 28.7	 -1.9	 0.0	 0.0	 1	    1.00221	    0.00000	 63.0	 1	    1.06792	    0.93651;
	3452	 1	 32.8	 -6.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3453	 1	 22.7	 -1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3454	 1	 24.1	 3.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3455	 1	 1.4	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3456	 1	 50.8	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3457	 1	 19.0	 12.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3458	 1	 31.3	 10.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3459	 1	 48.6	 5.9	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3460	 1	 4.7	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3461	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3462	 1	 24.9	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3463	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3464	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05336	    0.00000	 380.0	 1	    1.10263	    1.00409;
	3465	 1	 0.4	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3466	 1	 1.4	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3467	 1	 0.4	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3468	 1	 6.4	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3469	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3470	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3471	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3472	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3474	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3475	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3477	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07779	    0.97778;
	3478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3479	 1	 32.2	 2.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3480	 1	 57.9	 4.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3481	 1	 43.8	 -4.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3482	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3483	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3484	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3485	 1	 10.5	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3486	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3487	 1	 10.7	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3488	 1	 9.8	 -2.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3489	 1	 23.6	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3490	 1	 20.4	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3491	 1	 28.3	 3.0	 0.0	 0.0	 1	    1.02269	    0.00000	 90.0	 1	    1.06760	    0.97778;
	3492	 1	 0.1	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3493	 1	 17.8	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3494	 1	 10.0	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3495	 1	 -4.8	 -2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3496	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3497	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3498	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3499	 1	 -5.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3500	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3501	 1	 8.5	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3502	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3503	 1	 10.0	 4.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3504	 1	 25.3	 4.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3505	 1	 46.1	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3506	 1	 14.3	 -3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3507	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3508	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	3509	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	3510	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3511	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3512	 1	 11.7	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3513	 1	 -0.2	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3514	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3515	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3516	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3517	 1	 11.9	 -4.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3518	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3519	 1	 1.5	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3520	 1	 17.3	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3521	 1	 88.6	 14.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3522	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	3523	 1	 36.1	 3.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3524	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3525	 1	 13.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3526	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3527	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3528	 1	 -1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3529	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3530	 1	 5.9	 1.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3531	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3532	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.00889	    0.00000	 225.0	 1	    1.08889	    0.92889;
	3533	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3534	 1	 24.1	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3535	 1	 40.6	 8.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3537	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3538	 1	 56.7	 9.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3539	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3540	 1	 2.1	 -0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3541	 1	 8.0	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3542	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04022	    0.00000	 63.0	 1	    1.12805	    0.95238;
	3543	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3544	 1	 39.2	 1.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3545	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3546	 1	 20.8	 -0.3	 0.0	 0.0	 1	    1.00232	    0.00000	 63.0	 1	    1.06813	    0.93651;
	3547	 1	 30.9	 6.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3548	 1	 4.1	 16.1	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3549	 1	 71.6	 2.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3550	 1	 41.7	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3551	 1	 -6.0	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3552	 1	 15.6	 5.8	 0.0	 15.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3553	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3554	 1	 28.5	 7.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3555	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04701	    0.00000	 225.0	 1	    1.08958	    1.00444;
	3556	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04701	    0.00000	 225.0	 1	    1.08958	    1.00444;
	3557	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3558	 1	 94.3	 55.7	 0.0	 0.0	 1	    1.04704	    0.00000	 225.0	 1	    1.08963	    1.00444;
	3559	 1	 19.8	 9.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3560	 1	 33.7	 2.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3561	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3562	 1	 9.3	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3563	 1	 0.4	 0.1	 0.0	 0.0	 1	    1.02363	    0.00000	 90.0	 1	    1.06949	    0.97778;
	3564	 1	 27.0	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3565	 1	 48.4	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3566	 1	 -2.8	 -0.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3567	 1	 62.4	 23.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3568	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3569	 1	 42.2	 0.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3570	 1	 56.2	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3571	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3572	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3574	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3575	 1	 54.1	 9.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3576	 1	 9.3	 1.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3577	 1	 34.3	 -1.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3578	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3579	 2	 -0.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3580	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00010	    0.00000	 63.0	 1	    1.06369	    0.93651;
	3582	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3583	 1	 19.8	 1.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3584	 1	 22.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3585	 1	 7.6	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3586	 1	 -1.5	 2.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3587	 1	 -1.7	 17.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3588	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3589	 1	 31.3	 5.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3590	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3591	 1	 6.1	 1.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	3592	 1	 26.3	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3593	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3594	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3595	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3596	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3597	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3598	 1	 -1.8	 1.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3599	 1	 19.8	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3600	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3601	 1	 31.4	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3602	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3603	 1	 24.6	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3604	 1	 16.0	 0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3605	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3606	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3607	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3608	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3610	 1	 1.8	 0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3611	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3612	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3613	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3614	 1	 24.9	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3615	 1	 7.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3616	 1	 0.0	 0.0	 0.0	 20.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3617	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	3618	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3619	 1	 3.0	 -1.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3620	 1	 2.0	 -0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3621	 1	 14.0	 2.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3622	 1	 15.0	 3.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3623	 1	 65.1	 29.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3624	 1	 19.7	 6.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3625	 1	 11.7	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3626	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3627	 1	 64.8	 4.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3628	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3629	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00681	    0.00000	 63.0	 1	    1.07711	    0.93651;
	3630	 1	 24.2	 4.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3631	 1	 57.5	 1.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3632	 1	 17.9	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3633	 1	 12.0	 -37.7	 0.0	 0.0	 1	    1.00508	    0.00000	 63.0	 1	    1.05778	    0.95238;
	3634	 1	 28.7	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3635	 1	 5.0	 -1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3636	 1	 15.7	 -2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3637	 1	 15.7	 3.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3638	 1	 19.2	 10.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3639	 1	 31.7	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3640	 1	 43.0	 12.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3641	 1	 20.1	 -9.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3642	 1	 9.0	 3.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3643	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3644	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3645	 2	 18.2	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3646	 1	 83.9	 48.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3647	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3648	 1	 23.1	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3649	 1	 11.0	 -0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3650	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3651	 1	 8.7	 -9.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3652	 1	 15.3	 20.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3653	 1	 20.3	 3.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3654	 2	 0.1	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3655	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3656	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3657	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3658	 1	 0.0	 0.0	 0.0	 40.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3659	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3660	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3661	 1	 15.1	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3662	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	3663	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	3664	 1	 15.2	 -4.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3665	 1	 25.9	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3666	 1	 61.8	 -5.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3667	 1	 12.6	 3.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3668	 1	 15.6	 2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3669	 1	 2.6	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3670	 1	 49.4	 -2.1	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3671	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3672	 1	 16.9	 -1.4	 0.0	 0.0	 1	    1.00144	    0.00000	 63.0	 1	    1.06637	    0.93651;
	3673	 1	 10.0	 -4.0	 0.0	 0.0	 1	    1.00436	    0.00000	 63.0	 1	    1.07222	    0.93651;
	3674	 1	 10.9	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3675	 1	 26.0	 -0.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3676	 2	 23.1	 1.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3677	 1	 37.7	 4.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3678	 2	 -0.6	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3679	 1	 9.5	 -1.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3680	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3681	 1	 27.0	 -12.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3682	 1	 25.2	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3683	 1	 1.5	 -2.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3684	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3685	 1	 55.8	 7.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	3686	 1	 27.9	 4.3	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	3687	 1	 17.8	 0.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3688	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3689	 1	 15.0	 2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3690	 1	 15.9	 -0.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3691	 1	 14.5	 -6.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3692	 1	 52.1	 -3.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3693	 1	 0.2	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3694	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3695	 1	 -0.3	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3696	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3697	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	3698	 1	 6.0	 2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3699	 1	 88.6	 9.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3700	 1	 5.3	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3701	 1	 36.4	 9.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3702	 1	 80.7	 2.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3703	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3704	 1	 121.1	 3.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3705	 1	 6.4	 -0.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3706	 1	 53.6	 -1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3707	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3708	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3709	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3710	 1	 17.8	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3711	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01169	    0.00000	 63.0	 1	    1.07099	    0.95238;
	3712	 1	 50.1	 3.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3713	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3714	 1	 0.5	 1.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3715	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3716	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3717	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3718	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3719	 1	 -1.0	 -1.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	3720	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3721	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	3722	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3723	 1	 13.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3724	 1	 35.1	 14.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3725	 1	 16.5	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3726	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3727	 1	 84.4	 9.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3728	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3729	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3730	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3731	 1	 6.0	 5.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3732	 1	 8.0	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3733	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3734	 1	 47.4	 5.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3735	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3736	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3737	 1	 77.5	 19.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3738	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3739	 1	 0.0	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3740	 2	 6.2	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3741	 1	 13.1	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3742	 1	 0.5	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3743	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3744	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	3745	 1	 9.6	 -5.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3746	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3747	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3748	 1	 31.9	 -1.9	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3749	 1	 29.0	 -3.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3750	 1	 38.4	 2.8	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	3751	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3752	 1	 6.0	 -1.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3753	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3754	 1	 9.7	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3755	 1	 333.2	 132.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3756	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3757	 1	 14.5	 4.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3758	 1	 31.5	 2.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3759	 1	 39.0	 2.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3760	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3761	 1	 0.0	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3762	 1	 -0.5	 1.3	 0.0	 0.0	 1	    1.03983	    0.00000	 225.0	 1	    1.09299	    0.98667;
	3763	 1	 7.6	 3.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3764	 1	 23.1	 0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3765	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3766	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3767	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3768	 1	 13.4	 2.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3769	 1	 63.3	 34.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3770	 1	 36.3	 -8.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3771	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3772	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3773	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3774	 1	 8.3	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3775	 1	 -0.5	 0.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3776	 1	 -5.1	 -2.4	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3777	 1	 26.9	 7.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3778	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3779	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3780	 1	 21.7	 4.2	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3781	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3782	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3783	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3784	 1	 66.4	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3785	 1	 25.4	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3786	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3787	 1	 26.4	 1.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3788	 1	 12.5	 -2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3789	 1	 8.5	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3790	 1	 17.3	 -1.4	 0.0	 0.0	 1	    1.00038	    0.00000	 63.0	 1	    1.04838	    0.95238;
	3791	 1	 30.8	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3792	 1	 -2.1	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3793	 1	 30.2	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3794	 1	 23.9	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3795	 1	 1.6	 4.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3796	 1	 28.6	 3.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3797	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	3798	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	3799	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	3800	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	3801	 1	 14.8	 -0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3802	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3803	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3804	 1	 13.4	 -0.4	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	3805	 1	 48.5	 9.5	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3806	 1	 14.6	 0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3807	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3808	 2	 -1.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3809	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3810	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3811	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3812	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3813	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3814	 1	 18.9	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3815	 1	 4.7	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3816	 1	 17.3	 -1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3817	 1	 2.2	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3818	 1	 14.9	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3819	 1	 40.8	 1.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3820	 1	 30.0	 5.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3821	 1	 49.6	 13.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3822	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3823	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3824	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3825	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3826	 1	 22.0	 6.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	3827	 1	 16.4	 -4.6	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	3828	 1	 39.8	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3829	 1	 11.5	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3830	 1	 33.5	 -7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3831	 1	 43.6	 12.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3832	 1	 46.7	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3833	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3834	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3835	 1	 10.9	 -4.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3836	 1	 10.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3837	 1	 3.0	 0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3838	 1	 107.4	 10.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3839	 1	 0.2	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3840	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3841	 1	 16.7	 -4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3842	 1	 35.1	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3843	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	3844	 1	 1.2	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3845	 2	 0.7	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3846	 1	 4.3	 1.9	 0.0	 0.0	 1	    1.00014	    0.00000	 63.0	 1	    1.06377	    0.93651;
	3847	 1	 10.4	 4.2	 0.0	 0.0	 1	    1.00182	    0.00000	 63.0	 1	    1.06713	    0.93651;
	3848	 1	 47.5	 -0.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3849	 1	 9.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3850	 1	 39.6	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3851	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3852	 1	 48.5	 4.3	 0.0	 0.0	 1	    1.04697	    0.00000	 225.0	 1	    1.08950	    1.00444;
	3853	 1	 41.6	 5.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3854	 1	 30.8	 8.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3855	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3856	 1	 38.9	 -8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3857	 1	 14.0	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3858	 1	 16.4	 -1.8	 0.0	 0.0	 1	    1.02590	    0.00000	 90.0	 1	    1.07403	    0.97778;
	3859	 1	 22.1	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3860	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3861	 1	 40.6	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3862	 1	 29.7	 -0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3863	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3864	 1	 3.2	 5.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3865	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3866	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3867	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3868	 1	 26.1	 -2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3869	 1	 15.6	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3870	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3871	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3872	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3873	 1	 90.4	 5.9	 0.0	 80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3874	 1	 44.0	 8.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3875	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3876	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3877	 1	 0.0	 0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3878	 1	 38.3	 -2.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3879	 1	 21.7	 2.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3880	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3881	 1	 17.9	 -3.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.06667	    0.98889;
	3882	 1	 30.9	 -0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3883	 1	 16.3	 -0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3884	 1	 -0.1	 -0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3885	 2	 22.0	 -1.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3886	 1	 -0.2	 1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3887	 1	 33.9	 7.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3888	 1	 39.8	 2.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3889	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3890	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3891	 1	 1.0	 0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3892	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3893	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	3894	 1	 32.1	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3895	 1	 2.4	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3896	 1	 10.3	 -2.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3897	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04997	    0.00000	 225.0	 1	    1.09551	    1.00444;
	3898	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3899	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	3900	 1	 24.9	 21.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3901	 1	 6.7	 -1.7	 0.0	 0.0	 1	    1.02865	    0.00000	 90.0	 1	    1.07953	    0.97778;
	3902	 1	 -1.9	 16.6	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	3903	 1	 11.9	 -2.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3904	 1	 6.0	 -1.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3905	 1	 52.4	 3.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3906	 1	 6.7	 -5.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3907	 1	 13.7	 3.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3908	 1	 27.8	 3.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3909	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3910	 1	 8.9	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3911	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3912	 1	 43.0	 4.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3913	 1	 35.0	 7.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3914	 1	 41.2	 5.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3915	 1	 6.8	 -0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	3916	 1	 6.6	 -0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	3917	 1	 6.7	 -1.7	 0.0	 0.0	 1	    1.02667	    0.00000	 225.0	 1	    1.08889	    0.96444;
	3918	 1	 20.4	 12.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3919	 2	 -5.2	 -3.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3920	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	3921	 1	 8.6	 -14.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3922	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3923	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	3924	 1	 11.2	 -4.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3925	 1	 2.2	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3926	 1	 62.9	 -1.8	 0.0	 0.0	 1	    1.04736	    0.00000	 225.0	 1	    1.09027	    1.00444;
	3927	 1	 65.9	 9.2	 0.0	 0.0	 1	    1.04729	    0.00000	 225.0	 1	    1.09013	    1.00444;
	3928	 1	 15.1	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3929	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04758	    0.00000	 225.0	 1	    1.09515	    1.00000;
	3930	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07987	    0.00000	 380.0	 1	    1.10711	    1.05263;
	3931	 1	 25.3	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3932	 1	 -7.0	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3933	 1	 0.0	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3934	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3935	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	3936	 1	 21.7	 0.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3937	 1	 1.8	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3938	 1	 6.8	 0.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3939	 1	 97.6	 35.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3940	 1	 35.6	 8.0	 0.0	 0.0	 1	    1.04782	    0.00000	 225.0	 1	    1.09120	    1.00444;
	3941	 1	 18.8	 4.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3942	 1	 10.5	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3943	 1	 5.3	 1.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3944	 1	 21.7	 6.2	 0.0	 0.0	 1	    1.04816	    0.00000	 225.0	 1	    1.09188	    1.00444;
	3945	 1	 13.2	 2.0	 0.0	 0.0	 1	    1.04798	    0.00000	 225.0	 1	    1.09151	    1.00444;
	3946	 1	 13.0	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3947	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3948	 1	 22.3	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3949	 1	 17.9	 1.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3950	 1	 41.7	 8.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3951	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3952	 1	 -0.7	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3953	 1	 0.2	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3954	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3955	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3956	 1	 38.6	 -5.4	 0.0	 0.0	 1	    1.02269	    0.00000	 90.0	 1	    1.06761	    0.97778;
	3957	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3958	 1	 97.8	 28.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3959	 1	 32.5	 4.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3960	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3961	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	3962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3963	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	3964	 1	 19.4	 0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3965	 1	 24.5	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3966	 1	 31.4	 8.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3967	 1	 8.0	 -1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3968	 1	 77.9	 39.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	3969	 2	 13.4	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	3970	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3971	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3972	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3973	 1	 32.8	 -3.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3974	 1	 17.5	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3975	 1	 4.7	 2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3976	 1	 58.4	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3977	 1	 27.9	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3978	 1	 0.5	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	3979	 2	 12.8	 -1.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3980	 1	 26.1	 1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3981	 1	 7.9	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3982	 1	 13.4	 -2.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3983	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3984	 1	 0.1	 1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3985	 1	 -2.7	 -0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	3986	 1	 23.6	 -3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3987	 1	 4.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	3988	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	3989	 1	 -1.7	 -4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3990	 1	 8.0	 -4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	3991	 1	 4.9	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	3992	 1	 32.7	 -3.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	3993	 1	 53.4	 11.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3994	 1	 1.8	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3995	 1	 23.9	 -3.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	3996	 1	 31.8	 -10.7	 0.0	 34.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	3997	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	3998	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	3999	 1	 16.8	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4000	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4001	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4002	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00377	    0.00000	 63.0	 1	    1.07104	    0.93651;
	4003	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4004	 1	 13.7	 -0.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4005	 1	 0.9	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4006	 1	 32.0	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4007	 1	 31.6	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4008	 1	 54.4	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4009	 1	 25.4	 12.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4010	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4011	 1	 15.0	 6.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4012	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04728	    0.00000	 225.0	 1	    1.09456	    1.00000;
	4013	 1	 34.3	 -8.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4014	 1	 32.5	 1.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4015	 1	 33.2	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4016	 1	 22.6	 2.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4017	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4018	 1	 33.0	 -6.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4019	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4020	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	4021	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4022	 1	 81.5	 17.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4023	 1	 25.6	 0.4	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	4024	 1	 6.3	 0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4025	 1	 21.7	 7.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4026	 1	 18.8	 -0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4027	 1	 23.0	 -1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4028	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4029	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4030	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00069	    0.00000	 63.0	 1	    1.06488	    0.93651;
	4031	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4032	 1	 136.9	 40.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4033	 1	 16.6	 -3.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4034	 1	 45.5	 3.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4035	 1	 98.5	 23.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4036	 1	 51.3	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4037	 1	 9.9	 -2.9	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4038	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4039	 1	 45.2	 13.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4040	 1	 20.7	 3.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4041	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4042	 1	 7.6	 6.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4043	 1	 9.9	 -0.9	 0.0	 0.0	 1	    0.97500	    0.00000	 63.0	 1	    1.15000	    0.80000;
	4044	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4045	 1	 23.9	 2.0	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	4046	 1	 6.0	 -2.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4047	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4048	 1	 11.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4050	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4051	 1	 24.1	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4052	 1	 19.7	 0.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4053	 1	 51.8	 41.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4054	 1	 9.4	 -0.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4055	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00872	    0.00000	 63.0	 1	    1.08094	    0.93651;
	4056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4057	 1	 14.8	 3.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4058	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	4059	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4060	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4061	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4062	 1	 32.1	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4063	 1	 14.4	 -1.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4064	 1	 29.2	 2.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4065	 1	 11.6	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4066	 1	 0.7	 0.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4067	 1	 19.2	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4068	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4069	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4070	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4071	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4072	 1	 62.3	 11.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4073	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4074	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4075	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4076	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4077	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4078	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4079	 1	 17.0	 2.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4080	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4081	 1	 65.7	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4082	 1	 13.4	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4083	 1	 5.8	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4084	 1	 27.6	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4085	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4086	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4087	 1	 35.4	 4.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4088	 1	 37.5	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4089	 1	 -0.1	 -0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4090	 1	 10.0	 -3.6	 0.0	 0.0	 1	    1.02922	    0.00000	 90.0	 1	    1.08067	    0.97778;
	4091	 1	 0.8	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4092	 1	 41.1	 -3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4093	 1	 21.8	 8.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4094	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4095	 1	 91.7	 24.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4096	 1	 29.7	 0.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4097	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4098	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4099	 1	 0.9	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4100	 1	 7.2	 -0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4101	 1	 27.7	 -2.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4102	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4104	 1	 1.4	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4105	 1	 37.5	 7.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4106	 1	 12.3	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4107	 1	 8.3	 4.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4108	 1	 1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4109	 1	 43.0	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4110	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	4111	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	4113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	4114	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	4115	 1	 14.0	 1.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4116	 1	 10.8	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4117	 1	 13.7	 -5.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4118	 1	 102.4	 29.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4119	 1	 41.1	 8.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4120	 1	 29.6	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4121	 2	 15.2	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4122	 1	 21.8	 -0.5	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	4123	 2	 31.7	 -7.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4124	 1	 0.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4125	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4127	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4128	 1	 14.5	 -3.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4129	 1	 10.6	 -1.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4130	 1	 40.7	 7.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	4131	 1	 14.5	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4132	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4133	 1	 39.3	 12.0	 0.0	 48.0	 1	    1.02662	    0.00000	 90.0	 1	    1.07547	    0.97778;
	4134	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4135	 1	 17.0	 11.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4136	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4137	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4138	 1	 48.9	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4139	 1	 15.8	 6.1	 0.0	 0.0	 1	    1.00482	    0.00000	 63.0	 1	    1.07314	    0.93651;
	4140	 1	 14.4	 -0.1	 0.0	 0.0	 1	    1.00171	    0.00000	 63.0	 1	    1.06691	    0.93651;
	4141	 1	 34.6	 2.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4142	 1	 13.3	 -1.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4143	 1	 0.3	 -4.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4144	 1	 18.2	 1.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.09524	    0.93651;
	4145	 1	 33.0	 1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4146	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4147	 1	 12.0	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4148	 1	 29.0	 2.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4149	 1	 102.0	 10.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4150	 1	 0.0	 0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4151	 1	 1.6	 -0.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4152	 1	 52.0	 3.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4153	 1	 34.8	 4.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4154	 1	 30.2	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4155	 1	 12.3	 -1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4156	 1	 27.0	 -5.4	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	4157	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	4158	 1	 6.2	 -1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4159	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4160	 1	 6.3	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4161	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4162	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4164	 1	 -22.9	 10.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4165	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4166	 1	 50.6	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4167	 1	 16.6	 1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4168	 1	 24.7	 -6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4169	 1	 24.5	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4170	 1	 35.6	 6.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4171	 1	 10.0	 4.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4172	 1	 1.5	 0.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4174	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4175	 1	 21.5	 1.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4176	 1	 17.3	 -53.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.04762	    0.98413;
	4177	 1	 19.3	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4178	 1	 0.0	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4179	 1	 -0.7	 -0.8	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4180	 1	 -0.7	 -0.8	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4181	 1	 4.0	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4182	 1	 71.7	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4183	 1	 49.0	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4184	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4185	 1	 -0.3	 -0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4186	 1	 34.6	 -5.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4187	 1	 98.4	 19.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4188	 1	 63.7	 -2.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4189	 1	 10.9	 -6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4190	 1	 21.8	 -4.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4191	 1	 27.9	 2.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4192	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4193	 1	 5.0	 1.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4194	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4195	 1	 12.4	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4196	 1	 6.4	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4197	 1	 41.0	 2.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4198	 1	 57.4	 8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4199	 1	 7.1	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4200	 1	 13.5	 2.5	 0.0	 80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4201	 1	 108.6	 0.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4202	 1	 31.0	 -8.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4203	 1	 10.6	 3.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4204	 1	 11.7	 0.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4205	 1	 33.0	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4206	 1	 12.0	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4207	 1	 0.2	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4208	 1	 36.0	 18.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4209	 1	 40.7	 15.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4210	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03891	    0.00000	 225.0	 1	    1.09116	    0.98667;
	4211	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07265	    0.00000	 380.0	 1	    1.10583	    1.03947;
	4212	 1	 12.5	 3.9	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4213	 1	 32.2	 6.4	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4214	 1	 8.7	 1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4215	 1	 -0.3	 0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4216	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4217	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4218	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4219	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4220	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4221	 1	 0.9	 -0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4222	 1	 18.5	 -1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4223	 2	 -7.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4224	 1	 10.9	 -0.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4225	 1	 18.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4226	 1	 11.9	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4227	 1	 25.0	 -2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4228	 1	 34.9	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4229	 1	 26.0	 5.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4230	 1	 41.0	 3.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4231	 1	 12.9	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4232	 1	 16.2	 -3.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4233	 1	 38.9	 5.9	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4234	 1	 15.2	 3.7	 0.0	 34.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4235	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04777	    0.00000	 225.0	 1	    1.09110	    1.00444;
	4236	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4237	 2	 22.6	 5.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4238	 1	 0.9	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4239	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4240	 1	 24.3	 -0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4241	 1	 13.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4242	 1	 37.6	 -2.4	 0.0	 20.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4243	 1	 42.9	 17.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4244	 1	 56.1	 0.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4245	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4246	 1	 -3.1	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4247	 1	 0.0	 0.0	 0.0	 20.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4248	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4249	 1	 27.0	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4250	 1	 39.0	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4251	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4252	 1	 22.1	 -4.5	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4253	 1	 0.2	 -0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4254	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4255	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4256	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4257	 1	 59.5	 0.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4258	 1	 18.6	 -4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4259	 1	 5.7	 -2.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4260	 1	 4.0	 -0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4261	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4262	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4263	 1	 27.1	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4264	 1	 35.0	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4265	 1	 21.8	 3.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4266	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4267	 2	 7.1	 -3.7	 0.0	 0.0	 1	    1.02050	    0.00000	 63.0	 1	    1.07274	    0.96825;
	4268	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	4269	 1	 -0.2	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4270	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4271	 1	 39.0	 7.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4272	 1	 14.2	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4273	 1	 29.9	 4.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4274	 1	 41.3	 7.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4275	 1	 37.5	 3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4276	 1	 -1.7	 -1.9	 0.0	 0.0	 1	    1.04481	    0.00000	 225.0	 1	    1.08518	    1.00444;
	4277	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4279	 1	 43.7	 10.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4280	 1	 9.0	 8.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4281	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4282	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03928	    0.00000	 63.0	 1	    1.12617	    0.95238;
	4283	 1	 3.5	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4284	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4285	 2	 1.2	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4286	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4287	 1	 29.2	 4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4288	 1	 19.3	 0.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4289	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4290	 1	 -0.2	 2.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4291	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4292	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4293	 1	 1.8	 -2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4294	 1	 55.4	 10.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4295	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4296	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04672	    0.00000	 225.0	 1	    1.09345	    1.00000;
	4297	 1	 16.0	 -4.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4298	 1	 -0.3	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4300	 1	 -0.3	 0.7	 0.0	 0.0	 1	    1.00596	    0.00000	 63.0	 1	    1.07542	    0.93651;
	4301	 1	 10.5	 -2.7	 0.0	 0.0	 1	    1.00489	    0.00000	 63.0	 1	    1.07327	    0.93651;
	4302	 1	 39.4	 2.2	 0.0	 30.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4303	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4304	 1	 21.1	 5.2	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4305	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4306	 1	 29.0	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4307	 2	 -3.0	 0.0	 0.0	 0.0	 1	    1.00308	    0.00000	 63.0	 1	    1.06965	    0.93651;
	4308	 1	 3.0	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4309	 1	 42.0	 5.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4310	 1	 39.9	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4311	 2	 -11.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4312	 2	 1.2	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4313	 1	 56.8	 -2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4314	 1	 18.7	 -7.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4315	 1	 22.2	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4316	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4317	 1	 16.1	 -3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4318	 2	 2.0	 -4.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4319	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4320	 1	 10.1	 -2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4321	 1	 35.3	 11.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4322	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4324	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4325	 1	 19.5	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4326	 1	 14.8	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4327	 1	 16.8	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4328	 1	 23.7	 3.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4329	 1	 31.2	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4330	 1	 -0.1	 -0.5	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4331	 1	 22.9	 2.1	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4332	 1	 22.9	 2.1	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4333	 1	 28.9	 -1.9	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4334	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4335	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4336	 1	 12.8	 -1.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4337	 2	 0.7	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4338	 1	 158.9	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4339	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4340	 1	 34.5	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4341	 1	 44.4	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4342	 1	 19.4	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4343	 1	 19.4	 -3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4344	 2	 6.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4345	 1	 62.6	 8.7	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4346	 1	 7.7	 3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4347	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04551	    0.00000	 225.0	 1	    1.08659	    1.00444;
	4348	 1	 23.5	 -4.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4349	 1	 24.5	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4350	 1	 15.1	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4351	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4352	 1	 34.2	 -1.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4353	 1	 52.8	 11.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4354	 1	 0.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4355	 1	 26.1	 0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4356	 1	 56.0	 -5.2	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4357	 1	 -9.9	 -3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4358	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4359	 1	 10.4	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4360	 1	 3.5	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4361	 1	 31.8	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4362	 1	 24.0	 -0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4363	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4364	 1	 3.0	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4365	 1	 17.5	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4366	 1	 12.0	 -1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4367	 1	 14.0	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4368	 1	 19.6	 5.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4369	 1	 13.4	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4370	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4371	 1	 32.2	 5.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4372	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4373	 1	 30.5	 -5.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4374	 1	 18.0	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4375	 1	 5.2	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4376	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4377	 1	 47.0	 5.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4378	 1	 115.2	 15.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4379	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4380	 1	 10.9	 3.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4381	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4382	 1	 60.3	 4.5	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4383	 1	 7.3	 2.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4384	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4385	 1	 9.0	 -5.6	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4386	 1	 12.2	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4387	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	4388	 1	 57.6	 17.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	4389	 1	 38.0	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4390	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4391	 1	 104.9	 22.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4392	 1	 3.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4393	 1	 28.5	 0.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4394	 1	 33.1	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4395	 1	 39.9	 -3.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4396	 1	 2.8	 -1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4397	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04634	    0.00000	 225.0	 1	    1.09267	    1.00000;
	4398	 1	 21.4	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4399	 1	 47.9	 8.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4400	 1	 12.6	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4401	 1	 22.9	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4402	 1	 23.2	 -0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4403	 1	 40.1	 2.8	 0.0	 0.0	 1	    1.00005	    0.00000	 63.0	 1	    1.06360	    0.93651;
	4404	 1	 54.4	 13.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4405	 1	 21.4	 -8.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4406	 1	 45.6	 4.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4407	 2	 -0.8	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4408	 1	 0.0	 0.0	 0.0	 -15.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4409	 1	 7.2	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4410	 1	 34.6	 9.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4411	 1	 29.6	 0.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4412	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4413	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4414	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4415	 1	 9.8	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4416	 1	 10.7	 6.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4417	 1	 0.3	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4418	 1	 15.3	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4419	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4420	 1	 32.3	 1.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4421	 1	 18.8	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4422	 1	 13.1	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4423	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4424	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4425	 1	 7.8	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4426	 1	 41.2	 2.1	 0.0	 0.0	 1	    1.00370	    0.00000	 63.0	 1	    1.07090	    0.93651;
	4427	 1	 22.7	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4428	 1	 7.7	 -0.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4429	 1	 21.4	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4430	 1	 -0.2	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4431	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4432	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4433	 1	 75.0	 8.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4434	 1	 23.7	 9.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4435	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02692	    0.00000	 150.0	 1	    1.08717	    0.96667;
	4436	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4437	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4438	 1	 2.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4439	 1	 25.9	 10.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4440	 1	 -0.1	 9.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4441	 1	 38.5	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4442	 1	 40.6	 6.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4443	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	4444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4445	 1	 13.7	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4446	 1	 0.0	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4447	 1	 -1.9	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4448	 1	 7.8	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4450	 1	 36.8	 4.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4451	 1	 7.4	 -3.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4452	 1	 42.7	 11.7	 0.0	 20.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4453	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4454	 1	 37.6	 9.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4455	 1	 14.9	 -3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4456	 1	 5.2	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4457	 1	 -0.2	 -4.6	 0.0	 0.0	 1	    1.00297	    0.00000	 63.0	 1	    1.06944	    0.93651;
	4458	 1	 0.9	 -2.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4460	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4461	 1	 16.9	 11.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4462	 1	 28.8	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4463	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4464	 1	 14.0	 1.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4465	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4466	 1	 9.0	 -4.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4467	 1	 14.1	 2.0	 0.0	 15.4	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4468	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	4469	 2	 -6.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4470	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4471	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4472	 2	 -1.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4473	 2	 -0.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4474	 2	 -1.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4475	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4480	 1	 -0.5	 3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4482	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4483	 1	 16.1	 -3.6	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	4484	 1	 -0.4	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4485	 1	 9.0	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4486	 1	 4.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4487	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4488	 1	 23.0	 1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4489	 1	 35.9	 2.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4490	 1	 45.0	 -2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4491	 1	 6.0	 3.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4492	 1	 5.5	 -2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4493	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03566	    0.00000	 63.0	 1	    1.10306	    0.96825;
	4494	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03566	    0.00000	 63.0	 1	    1.10306	    0.96825;
	4495	 1	 15.1	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	4496	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4497	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4498	 1	 0.0	 -0.2	 0.0	 0.0	 1	    1.00027	    0.00000	 90.0	 1	    1.07831	    0.92222;
	4499	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4500	 2	 63.0	 10.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4501	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4502	 1	 0.9	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4503	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4504	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4505	 1	 23.4	 -2.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4506	 1	 14.0	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4507	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4508	 1	 23.3	 -1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4509	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.08889	    0.93778;
	4510	 1	 77.8	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4511	 1	 52.4	 10.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4512	 1	 5.6	 -10.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4513	 1	 18.8	 -5.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4514	 1	 32.0	 -4.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4515	 1	 14.1	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4516	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00662	    0.00000	 63.0	 1	    1.07674	    0.93651;
	4517	 1	 1.9	 -0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4518	 1	 12.8	 13.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4519	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	4520	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4521	 1	 12.9	 0.9	 0.0	 0.0	 1	    0.96825	    0.00000	 63.0	 1	    1.04762	    0.88889;
	4522	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4523	 1	 22.7	 2.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4524	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4525	 1	 12.5	 3.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4526	 1	 2.9	 -3.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4527	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4528	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4529	 1	 29.3	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4530	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.82500	    0.00000	 20.0	 1	    1.15000	    0.50000;
	4531	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4532	 1	 12.5	 -2.4	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4533	 1	 29.5	 11.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4534	 1	 42.0	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4535	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4537	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4538	 1	 45.6	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4539	 1	 0.0	 1.2	 0.0	 0.0	 1	    1.00867	    0.00000	 63.0	 1	    1.08083	    0.93651;
	4540	 1	 27.2	 1.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4541	 1	 -0.6	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4542	 1	 0.0	 0.0	 0.0	 160.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4543	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	4544	 1	 25.4	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4545	 1	 20.4	 5.7	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4546	 1	 32.8	 0.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4547	 1	 8.3	 -6.1	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4548	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4549	 1	 28.4	 -7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4550	 1	 6.9	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4551	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4552	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4553	 1	 -0.1	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4554	 1	 1.0	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4555	 1	 94.7	 16.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4556	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4557	 1	 1.0	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4558	 1	 1.0	 -36.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4559	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4560	 1	 2.0	 -0.8	 0.0	 0.0	 1	    1.00279	    0.00000	 63.0	 1	    1.06908	    0.93651;
	4561	 1	 20.2	 -5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4562	 1	 21.1	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4563	 1	 11.6	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4564	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4565	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4566	 2	 126.4	 69.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4567	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4568	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4569	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07859	    0.00000	 380.0	 1	    1.10263	    1.05455;
	4570	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4571	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4572	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04032	    0.00000	 63.0	 1	    1.12826	    0.95238;
	4574	 2	 3.8	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4575	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4576	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4577	 1	 45.3	 8.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4578	 1	 187.1	 64.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4579	 1	 3.0	 1.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4580	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4581	 1	 11.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4582	 1	 14.5	 -4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4583	 1	 11.0	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	4584	 1	 101.6	 26.2	 0.0	 0.0	 1	    1.04722	    0.00000	 225.0	 1	    1.09000	    1.00444;
	4585	 1	 6.0	 3.0	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	4586	 1	 10.5	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4587	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02996	    0.00000	 90.0	 1	    1.08215	    0.97778;
	4588	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4589	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4590	 1	 44.3	 3.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4591	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4592	 1	 2.1	 0.2	 0.0	 0.0	 1	    1.00167	    0.00000	 63.0	 1	    1.06684	    0.93651;
	4593	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4594	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4595	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4596	 1	 11.7	 1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4597	 1	 0.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4598	 1	 8.0	 -3.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4599	 1	 31.1	 3.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4600	 1	 15.8	 0.5	 0.0	 0.0	 1	    1.02141	    0.00000	 90.0	 1	    1.06667	    0.97615;
	4601	 1	 2.0	 1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4602	 1	 48.4	 -8.5	 0.0	 90.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4604	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4605	 1	 51.1	 9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4606	 1	 0.0	 1.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4607	 1	 31.3	 5.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4608	 1	 0.0	 -0.9	 0.0	 0.0	 1	    1.02270	    0.00000	 90.0	 1	    1.06762	    0.97778;
	4609	 1	 35.9	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4610	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	4611	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4612	 1	 23.8	 7.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4613	 1	 15.4	 -0.3	 0.0	 0.0	 1	    1.02919	    0.00000	 90.0	 1	    1.08061	    0.97778;
	4614	 1	 0.9	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4615	 1	 17.6	 2.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4616	 1	 2.7	 -1.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4617	 1	 18.4	 -1.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4618	 1	 4.0	 2.2	 0.0	 0.0	 1	    1.00274	    0.00000	 63.0	 1	    1.06897	    0.93651;
	4619	 1	 16.0	 -9.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4620	 1	 16.1	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4621	 1	 47.9	 1.5	 0.0	 0.0	 1	    1.00215	    0.00000	 63.0	 1	    1.06779	    0.93651;
	4622	 1	 22.7	 3.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4623	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4624	 1	 38.0	 8.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4625	 1	 9.3	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4626	 1	 17.8	 -2.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4627	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4628	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4629	 1	 23.5	 6.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4630	 1	 51.5	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4631	 1	 3.7	 13.4	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4632	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4633	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4634	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4635	 1	 85.9	 21.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4636	 1	 21.0	 3.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4637	 1	 5.9	 -1.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4638	 1	 8.2	 -3.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4639	 1	 1.0	 -1.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4640	 1	 101.2	 24.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4641	 1	 0.0	 0.0	 0.0	 60.8	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4642	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4643	 1	 52.9	 7.2	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4644	 1	 20.3	 0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4645	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4646	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4647	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4648	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4649	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4650	 1	 46.6	 3.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4651	 1	 44.4	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4652	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4653	 1	 9.8	 1.8	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4654	 1	 -1.7	 -1.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4655	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4656	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4657	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4658	 1	 25.8	 3.5	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4659	 1	 -0.1	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4660	 1	 57.6	 -6.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4661	 1	 13.8	 -3.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4662	 1	 29.6	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4663	 1	 15.2	 2.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4664	 1	 78.4	 -5.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4665	 1	 37.1	 7.5	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	4666	 2	 -5.9	 -0.3	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4667	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4668	 1	 52.8	 18.0	 0.0	 61.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4669	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4670	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	4671	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4672	 1	 27.1	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4673	 1	 17.1	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4674	 1	 30.3	 11.2	 0.0	 32.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4675	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4676	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4677	 1	 21.2	 3.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4678	 1	 33.8	 -6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4679	 1	 14.9	 0.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4680	 1	 11.8	 -1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4681	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00686	    0.00000	 63.0	 1	    1.07722	    0.93651;
	4682	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4683	 1	 31.0	 3.4	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4684	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4685	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4686	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4687	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4688	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4690	 1	 12.8	 -2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4691	 1	 4.1	 0.3	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4692	 1	 36.1	 7.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	4693	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4694	 1	 16.2	 0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4695	 1	 102.0	 14.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4696	 1	 1.2	 3.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4697	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4698	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4699	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4700	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4701	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4702	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4703	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4704	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4706	 3	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10263	    1.05526;
	4707	 1	 30.2	 -8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4708	 1	 42.6	 2.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4710	 2	 -6.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4711	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4712	 1	 14.2	 0.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4713	 2	 13.4	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4714	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4715	 1	 17.4	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4716	 1	 8.6	 -1.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4717	 1	 0.6	 -0.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4718	 1	 73.6	 14.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4719	 1	 11.8	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4720	 1	 69.0	 16.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4721	 1	 4.7	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4722	 1	 49.6	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4723	 1	 44.5	 -7.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4724	 1	 14.3	 -6.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4725	 1	 -0.1	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4726	 1	 0.0	 -9.0	 0.0	 0.0	 1	    1.02920	    0.00000	 90.0	 1	    1.08062	    0.97778;
	4727	 1	 28.8	 7.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4728	 1	 55.5	 7.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4729	 1	 55.1	 17.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4730	 1	 -0.4	 0.5	 0.0	 0.0	 1	    1.04689	    0.00000	 225.0	 1	    1.08934	    1.00444;
	4731	 1	 12.3	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	4732	 1	 41.3	 10.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4733	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4734	 1	 53.8	 8.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4735	 1	 9.7	 0.8	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4736	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4737	 1	 67.1	 30.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4738	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4739	 1	 21.1	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4740	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4741	 1	 66.2	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4742	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4743	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4744	 1	 2.0	 0.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4745	 1	 22.6	 24.8	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	4746	 1	 16.0	 -1.9	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	4747	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	4748	 1	 29.8	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4749	 2	 -1.9	 -3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4750	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4751	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4752	 1	 6.0	 -1.8	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4753	 1	 41.3	 7.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4754	 1	 17.2	 3.9	 0.0	 0.0	 1	    1.00909	    0.00000	 63.0	 1	    1.06580	    0.95238;
	4755	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4756	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4757	 1	 131.7	 23.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4758	 1	 28.6	 -4.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4759	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4760	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	4761	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4762	 1	 40.8	 3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4763	 1	 13.8	 0.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4764	 1	 16.8	 3.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4765	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4766	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4767	 1	 -1.3	 3.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4768	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4769	 1	 23.7	 6.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4770	 2	 25.4	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4771	 1	 43.2	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4772	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4773	 1	 14.9	 -1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4774	 1	 73.7	 4.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4775	 1	 21.4	 -3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4776	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4777	 1	 29.4	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4778	 1	 1.9	 0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4779	 1	 28.6	 -0.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4780	 1	 -0.1	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4781	 1	 20.9	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4782	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4783	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4784	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4785	 1	 19.2	 1.6	 0.0	 27.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4786	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4787	 1	 -8.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4788	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4789	 1	 9.0	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4790	 1	 17.4	 2.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4791	 1	 12.0	 0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4792	 1	 24.9	 2.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4793	 1	 14.9	 5.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4794	 1	 43.9	 -6.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4795	 1	 22.0	 3.6	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4796	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03983	    0.00000	 225.0	 1	    1.09300	    0.98667;
	4797	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4798	 1	 53.8	 -1.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	4799	 1	 43.4	 8.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4800	 1	 16.6	 5.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4801	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4802	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4803	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4804	 1	 3.9	 1.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4805	 1	 24.8	 1.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4806	 1	 7.8	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4807	 1	 19.1	 1.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4808	 1	 49.8	 24.3	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	4809	 1	 65.8	 11.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4810	 2	 -2.5	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4811	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4812	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4813	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4814	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4815	 1	 -3.0	 -0.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4816	 1	 2.3	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4817	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4818	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4819	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4820	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4821	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4822	 1	 0.0	 0.0	 0.0	 29.0	 1	    1.03070	    0.00000	 90.0	 1	    1.08362	    0.97778;
	4823	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04893	    0.00000	 225.0	 1	    1.09341	    1.00444;
	4824	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04861	    0.00000	 225.0	 1	    1.09279	    1.00444;
	4825	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4826	 1	 32.8	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4827	 1	 36.3	 2.5	 0.0	 0.0	 1	    0.98413	    0.00000	 63.0	 1	    1.06349	    0.90476;
	4828	 1	 19.9	 -3.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4829	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4830	 1	 64.2	 17.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4831	 1	 13.7	 2.9	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	4832	 1	 23.3	 1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4833	 1	 -0.0	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4834	 1	 17.8	 -2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4835	 1	 30.8	 4.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4836	 1	 23.3	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4837	 1	 29.4	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4838	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00681	    0.00000	 63.0	 1	    1.07711	    0.93651;
	4839	 1	 70.4	 7.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4840	 1	 45.4	 1.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4841	 1	 18.2	 2.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4842	 1	 3.6	 2.4	 0.0	 0.0	 1	    1.00437	    0.00000	 63.0	 1	    1.07223	    0.93651;
	4843	 1	 77.9	 5.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4844	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4845	 1	 6.3	 -4.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4846	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4847	 1	 2.3	 5.6	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4848	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4849	 1	 3.0	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4850	 1	 5.2	 -0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4851	 1	 22.3	 4.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4852	 1	 22.2	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4853	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4854	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	4855	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4856	 1	 53.9	 3.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4857	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4858	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	4859	 2	 6.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4860	 1	 23.1	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4861	 1	 22.2	 -3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4862	 1	 1.7	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4863	 1	 25.9	 6.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4864	 1	 44.2	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4865	 1	 8.0	 2.1	 0.0	 0.0	 1	    1.01667	    0.00000	 90.0	 1	    1.11111	    0.92222;
	4866	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	4867	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4868	 1	 3.6	 0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4869	 1	 36.9	 11.3	 0.0	 0.0	 1	    1.01052	    0.00000	 63.0	 1	    1.06866	    0.95238;
	4870	 1	 10.0	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4871	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4872	 1	 133.8	 32.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4873	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4874	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4875	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4876	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4877	 1	 14.9	 -1.3	 0.0	 0.0	 1	    1.01111	    0.00000	 90.0	 1	    1.08889	    0.93333;
	4878	 1	 9.7	 0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4879	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4880	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03947	    0.00000	 380.0	 1	    1.10526	    0.97368;
	4881	 1	 28.0	 -0.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4882	 1	 49.8	 5.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4883	 1	 30.4	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4884	 1	 9.9	 -2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4885	 1	 9.4	 13.4	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4886	 1	 12.5	 4.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	4887	 1	 -10.6	 -1.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4888	 1	 29.3	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4889	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4890	 1	 12.5	 0.5	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4891	 1	 57.2	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4892	 1	 12.0	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4893	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4894	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4895	 1	 20.9	 -6.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4896	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4897	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4898	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4899	 1	 28.2	 -4.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4900	 1	 11.0	 -1.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4901	 1	 35.7	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4902	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4903	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4904	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4905	 1	 4.9	 -0.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4906	 1	 12.8	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4907	 1	 40.5	 4.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4908	 1	 76.1	 21.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4909	 1	 5.5	 3.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4910	 1	 3.3	 5.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4911	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4912	 1	 -2.5	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4913	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4914	 1	 29.0	 4.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4915	 2	 26.2	 6.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4916	 1	 0.0	 0.0	 0.0	 50.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4917	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4918	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4919	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4920	 1	 41.7	 6.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4921	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4922	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	4923	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4924	 1	 4.6	 -0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4925	 1	 51.6	 6.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4926	 1	 40.6	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4927	 1	 0.7	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4928	 1	 50.4	 9.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4929	 1	 38.2	 -0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4930	 1	 0.7	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4931	 1	 0.7	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4932	 1	 1.7	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4933	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4934	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4935	 1	 47.7	 12.8	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4936	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4937	 1	 147.0	 41.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4938	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	4939	 1	 34.1	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4940	 1	 6.6	 -2.4	 0.0	 0.0	 1	    1.00513	    0.00000	 63.0	 1	    1.05787	    0.95238;
	4941	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	4942	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4943	 1	 0.3	 0.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4944	 1	 42.9	 7.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	4945	 1	 36.8	 6.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4946	 1	 13.6	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4947	 1	 0.9	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4948	 1	 2.4	 -2.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4949	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	4950	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4951	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4952	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4953	 1	 26.8	 3.4	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4954	 1	 24.4	 3.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4955	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4956	 1	 19.3	 -10.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4957	 1	 31.4	 -9.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	4958	 1	 5.5	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4959	 1	 0.8	 -6.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4960	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	4961	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	4963	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4964	 1	 2.0	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4965	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.09524	    0.90476;
	4966	 1	 13.2	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4967	 1	 20.6	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	4968	 1	 36.3	 4.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4969	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	4970	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	4971	 1	 56.8	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4972	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4973	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	4974	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4975	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4976	 2	 16.7	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4977	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4978	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4979	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	4980	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4981	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4982	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4983	 1	 14.3	 6.5	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4984	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4985	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4986	 1	 8.4	 -1.3	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4987	 1	 11.3	 -2.2	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4988	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	4989	 1	 5.0	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4990	 1	 31.5	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4991	 1	 28.9	 5.6	 0.0	 0.0	 1	    1.00236	    0.00000	 63.0	 1	    1.06822	    0.93651;
	4992	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4993	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4994	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	4995	 1	 0.5	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4996	 1	 31.3	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	4997	 1	 0.5	 -0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	4998	 1	 -8.1	 -2.7	 0.0	 0.0	 1	    1.00461	    0.00000	 63.0	 1	    1.07271	    0.93651;
	4999	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5000	 1	 36.7	 -3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5001	 1	 20.8	 1.1	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5002	 1	 14.2	 -2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5003	 1	 -0.5	 -6.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5004	 1	 -0.5	 3.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5005	 1	 16.2	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5006	 1	 0.4	 -0.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5007	 1	 9.9	 -5.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5008	 1	 9.0	 5.1	 0.0	 0.0	 1	    1.00228	    0.00000	 63.0	 1	    1.06805	    0.93651;
	5009	 1	 27.1	 -6.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5010	 1	 8.5	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5011	 1	 -17.6	 -2.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.06667	    0.98889;
	5012	 1	 33.1	 1.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5013	 1	 7.8	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5014	 1	 4.1	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5015	 1	 87.9	 13.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5016	 1	 65.0	 9.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5017	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	5018	 1	 27.3	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5019	 1	 3.0	 1.2	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5020	 1	 0.1	 0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5021	 1	 18.8	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5022	 1	 24.7	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5023	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5024	 1	 16.1	 -3.9	 0.0	 0.0	 1	    0.97093	    0.00000	 63.0	 1	    1.05298	    0.88889;
	5025	 1	 15.0	 6.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5026	 1	 16.3	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5027	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5028	 1	 157.0	 27.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5029	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	5030	 1	 12.7	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	5031	 2	 22.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5032	 1	 16.0	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5033	 1	 21.2	 -5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5034	 2	 28.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5035	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5036	 1	 24.3	 3.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	5037	 1	 5.0	 2.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5038	 1	 1.9	 -0.7	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5039	 1	 171.7	 62.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5040	 1	 -9.5	 -0.8	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.06667	    0.98889;
	5041	 1	 4.2	 3.0	 0.0	 0.0	 1	    1.00637	    0.00000	 63.0	 1	    1.06035	    0.95238;
	5042	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5043	 1	 14.8	 -0.4	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5044	 1	 26.7	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5045	 1	 0.0	 0.0	 0.0	 34.0	 1	    1.02652	    0.00000	 90.0	 1	    1.07527	    0.97778;
	5046	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5047	 1	 12.1	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5048	 1	 37.6	 14.5	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	5049	 1	 1.0	 1.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5050	 1	 6.0	 -0.9	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5051	 1	 7.1	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5052	 1	 26.5	 4.7	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5053	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5054	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98952	    0.00000	 225.0	 1	    1.09016	    0.88889;
	5055	 1	 -1.7	 -10.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	5057	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	5058	 1	 45.5	 3.4	 0.0	 0.0	 1	    1.03333	    0.00000	 90.0	 1	    1.11111	    0.95556;
	5059	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5060	 1	 43.5	 8.9	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.10000	    0.94444;
	5061	 1	 23.3	 4.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5062	 1	 29.3	 4.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5063	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5064	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	5065	 1	 12.4	 8.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5066	 1	 24.4	 14.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5067	 1	 3.7	 1.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5068	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5069	 1	 10.3	 6.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5070	 1	 3.8	 0.1	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5071	 1	 10.4	 -1.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5072	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5073	 1	 4.6	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	5074	 1	 11.6	 -0.5	 0.0	 0.0	 1	    1.00039	    0.00000	 63.0	 1	    1.06427	    0.93651;
	5075	 1	 56.2	 2.6	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5076	 1	 20.5	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5077	 1	 35.3	 2.9	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5078	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5079	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	5080	 1	 31.8	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5081	 1	 0.7	 -0.1	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5082	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5083	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5084	 1	 30.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5085	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5086	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5087	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5088	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5089	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5090	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5091	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5092	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5093	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5094	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5095	 1	 2.4	 1.2	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5096	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5097	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5098	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5099	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5100	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5101	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5102	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5104	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5105	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5106	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5107	 1	 7.9	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5108	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5109	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5110	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5111	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02314	    0.00000	 90.0	 1	    1.06851	    0.97778;
	5112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 150.0	 1	    1.10000	    0.96667;
	5113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5114	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5115	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5117	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5118	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5120	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00713	    0.00000	 63.0	 1	    1.07776	    0.93651;
	5121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5122	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5123	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5124	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5125	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5127	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5129	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5131	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5132	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5133	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5134	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5136	 1	 6.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5137	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5138	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5139	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5140	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5141	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5142	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5143	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5144	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5145	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5146	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5147	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5148	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5149	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5150	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5151	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5152	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5153	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5155	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5157	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5158	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5159	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5160	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5161	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5162	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5165	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5166	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5167	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02264	    0.00000	 90.0	 1	    1.06750	    0.97778;
	5168	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5169	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5170	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5171	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5172	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5174	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5175	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	5176	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5177	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5178	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5179	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5180	 1	 30.7	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5181	 1	 14.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5182	 1	 43.7	 0.0	 0.0	 0.0	 1	    1.02468	    0.00000	 90.0	 1	    1.07159	    0.97778;
	5183	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5184	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5185	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5186	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5187	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5188	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5189	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5190	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5191	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5192	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5193	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5194	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5195	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5196	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5197	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00185	    0.00000	 63.0	 1	    1.06719	    0.93651;
	5198	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5199	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5200	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5201	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5202	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5203	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5204	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5205	 1	 -13.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5206	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03074	    0.00000	 90.0	 1	    1.08371	    0.97778;
	5207	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5208	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5209	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5210	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5211	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5212	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5213	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04682	    0.00000	 225.0	 1	    1.08920	    1.00444;
	5214	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5215	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5216	 1	 -16.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5217	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5218	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5219	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5220	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5221	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5222	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5223	 1	 6.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5224	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5225	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5226	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5227	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5228	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5229	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00327	    0.00000	 63.0	 1	    1.07004	    0.93651;
	5230	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5231	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5232	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5233	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5234	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5235	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	5236	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5237	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5238	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5239	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5240	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5241	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5242	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5243	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5244	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01081	    0.00000	 63.0	 1	    1.06923	    0.95238;
	5245	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5246	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5247	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	5248	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5249	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5250	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5251	 1	 23.8	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5252	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5253	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5254	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5255	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5256	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5258	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5259	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5260	 1	 4.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5261	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5262	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04740	    0.00000	 225.0	 1	    1.09480	    1.00000;
	5263	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 90.0	 1	    1.07778	    0.92222;
	5265	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5266	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5267	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5268	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5269	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5270	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5272	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5273	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5274	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5277	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5279	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5280	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5281	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5282	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5283	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5284	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5285	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5286	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5287	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5288	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5289	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5290	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5291	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5292	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5293	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5294	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5295	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5296	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5297	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5298	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03209	    0.00000	 90.0	 1	    1.08640	    0.97778;
	5300	 1	 18.2	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5301	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5302	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5303	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5304	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5305	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5306	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5307	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5308	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5309	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5310	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5311	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5312	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5313	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5314	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5315	 1	 10.6	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5316	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5317	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5318	 1	 6.0	 1.7	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5319	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5320	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00277	    0.00000	 63.0	 1	    1.05315	    0.95238;
	5321	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5322	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5324	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5325	 1	 -5.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5326	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5327	 1	 -19.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5328	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5329	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5330	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5331	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5332	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5333	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5334	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5335	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5336	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5337	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5338	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5339	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5340	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5341	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5342	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5344	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5345	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5346	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5347	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5348	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00326	    0.00000	 63.0	 1	    1.07001	    0.93651;
	5349	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5350	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5351	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5352	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5353	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5354	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5355	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04744	    0.00000	 225.0	 1	    1.09044	    1.00444;
	5356	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04726	    0.00000	 225.0	 1	    1.09008	    1.00444;
	5357	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5358	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5359	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5360	 1	 3.4	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5361	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5362	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5364	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5365	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5367	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5368	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5369	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5370	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5371	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5372	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5373	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5374	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5375	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5376	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5377	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5378	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5379	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5380	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5381	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5382	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5383	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5384	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5385	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5386	 1	 20.4	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5387	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5388	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5389	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5390	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00702	    0.00000	 63.0	 1	    1.07753	    0.93651;
	5391	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5392	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5393	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5394	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5395	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5396	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5397	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5398	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5399	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5400	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5401	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5402	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5403	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5404	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5405	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00430	    0.00000	 63.0	 1	    1.05621	    0.95238;
	5406	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5407	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5408	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5409	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5410	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5411	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5412	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04678	    0.00000	 225.0	 1	    1.08912	    1.00444;
	5413	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5414	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5415	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5416	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5417	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5418	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5419	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5420	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5421	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5422	 1	 -32.1	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5423	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5424	 1	 8.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5425	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5426	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5427	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5428	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5429	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5430	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5431	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5432	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5433	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5434	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5435	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5436	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5437	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5438	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5439	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5440	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5441	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5442	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5443	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5445	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02345	    0.00000	 90.0	 1	    1.06913	    0.97778;
	5446	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5447	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5448	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5450	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5451	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5452	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5453	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5454	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5455	 1	 0.5	 2.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5456	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5457	 1	 -56.9	 0.0	 0.0	 0.0	 1	    1.04737	    0.00000	 225.0	 1	    1.09473	    1.00000;
	5458	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5460	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5461	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5462	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5463	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5464	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5465	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5466	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5467	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5468	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5469	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5470	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5471	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5472	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5474	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5475	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5476	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00160	    0.00000	 63.0	 1	    1.06670	    0.93651;
	5479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5482	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5483	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5484	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5485	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5486	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5487	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5488	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5489	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5490	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03074	    0.00000	 90.0	 1	    1.08370	    0.97778;
	5491	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5492	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5493	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5494	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5495	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5496	 1	 60.2	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5497	 1	 36.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5498	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5499	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5500	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01161	    0.00000	 63.0	 1	    1.07084	    0.95238;
	5501	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5502	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5503	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04695	    0.00000	 225.0	 1	    1.08945	    1.00444;
	5504	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5505	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5506	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5507	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5508	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5509	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5510	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5511	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00293	    0.00000	 63.0	 1	    1.05348	    0.95238;
	5512	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5513	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5514	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5515	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5516	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5517	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5518	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5519	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5520	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5521	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5522	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5523	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5524	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5525	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5526	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5527	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5528	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5529	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5530	 1	 -1.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5531	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5532	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5533	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00162	    0.00000	 63.0	 1	    1.06673	    0.93651;
	5534	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5535	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 150.0	 1	    1.10000	    0.96667;
	5537	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5538	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5539	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5540	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5541	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5542	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5543	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00236	    0.00000	 63.0	 1	    1.06821	    0.93651;
	5544	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5545	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5546	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5547	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5548	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5549	 1	 -17.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5550	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5551	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5552	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5553	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5554	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5555	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5556	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5557	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5558	 1	 20.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5559	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5560	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5561	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5562	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5563	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5564	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5565	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5566	 1	 18.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5567	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5568	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5569	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5570	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5571	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5572	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5574	 1	 -60.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 150.0	 1	    1.10000	    0.96667;
	5575	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5576	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5577	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5578	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5582	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5583	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5584	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5585	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5586	 1	 18.6	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5587	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5588	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5589	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5590	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5591	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5592	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5593	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5594	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5595	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98977	    0.00000	 225.0	 1	    1.09066	    0.88889;
	5596	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5597	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5598	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5599	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5600	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5601	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5602	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5604	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5605	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5606	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5607	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00403	    0.00000	 63.0	 1	    1.07156	    0.93651;
	5608	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5610	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5611	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5612	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5613	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5614	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5615	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5616	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5617	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5618	 1	 -2.1	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5619	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5620	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5621	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5622	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5623	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5624	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5625	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5626	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5627	 1	 -15.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5628	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5629	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5630	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5631	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5632	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5633	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5634	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5635	 1	 9.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5636	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	5637	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00008	    0.00000	 63.0	 1	    1.06366	    0.93651;
	5638	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02000	    0.00000	 150.0	 1	    1.05333	    0.98667;
	5639	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5640	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5641	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5642	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5643	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5644	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5645	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5646	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5647	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5648	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5649	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5650	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5651	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5652	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5653	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5654	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5655	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00556	    0.00000	 90.0	 1	    1.15556	    0.85556;
	5656	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5657	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5658	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5659	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01169	    0.00000	 63.0	 1	    1.07099	    0.95238;
	5660	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5661	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5662	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5663	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5664	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5665	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5666	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5667	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5668	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5669	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5670	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5671	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5672	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5673	 1	 46.8	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5674	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04700	    0.00000	 225.0	 1	    1.08957	    1.00444;
	5675	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5676	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5677	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5678	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5679	 1	 1.7	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5680	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5681	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5682	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5683	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5684	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5685	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	5686	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5687	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5688	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5690	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5691	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5692	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5693	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5694	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5695	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5696	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5697	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5698	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5699	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04758	    0.00000	 225.0	 1	    1.09517	    1.00000;
	5700	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5701	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5702	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5703	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5704	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5706	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5707	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5708	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5711	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5712	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5713	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5714	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	5715	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5716	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5717	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5718	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5719	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5720	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5721	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5722	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5723	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5724	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5725	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5726	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5727	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5728	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5729	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5730	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5731	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5732	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5733	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5734	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5735	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	5736	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5737	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5738	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5739	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5740	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5741	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5742	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.07778	    0.96667;
	5743	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5744	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5745	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5746	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5747	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5748	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5749	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04554	    0.00000	 225.0	 1	    1.08665	    1.00444;
	5750	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00116	    0.00000	 63.0	 1	    1.04993	    0.95238;
	5751	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5752	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02247	    0.00000	 90.0	 1	    1.06717	    0.97778;
	5753	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5754	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5755	 1	 36.7	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5756	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5757	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5758	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5759	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5760	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5761	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5762	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5763	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5764	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5765	 1	 43.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5766	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5767	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5768	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5769	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5770	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5771	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5772	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5773	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00444	    0.00000	 63.0	 1	    1.07237	    0.93651;
	5774	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5775	 1	 3.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5776	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5777	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	5778	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00833	    0.00000	 63.0	 1	    1.08015	    0.93651;
	5779	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5780	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5781	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5782	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5783	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5784	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5785	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5786	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00168	    0.00000	 63.0	 1	    1.06686	    0.93651;
	5787	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00010	    0.00000	 63.0	 1	    1.06370	    0.93651;
	5788	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5789	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5790	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02270	    0.00000	 90.0	 1	    1.06763	    0.97778;
	5791	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02828	    0.00000	 90.0	 1	    1.07878	    0.97778;
	5792	 1	 2.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5793	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5794	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5795	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	5796	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5797	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5798	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5799	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5800	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5801	 1	 -10.0	 0.0	 0.0	 0.0	 1	    1.00687	    0.00000	 63.0	 1	    1.07724	    0.93651;
	5802	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5803	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	5804	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5805	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5806	 1	 3.7	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5807	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5808	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5809	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5810	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5811	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	5812	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07252	    0.00000	 380.0	 1	    1.10263	    1.04241;
	5813	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5814	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5815	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00794	    0.00000	 63.0	 1	    1.06349	    0.95238;
	5816	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5817	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	5818	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	5819	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5820	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5821	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5822	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5823	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5824	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5825	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5826	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5827	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5828	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5829	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	5830	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5831	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5832	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.14286	    0.85714;
	5833	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5834	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5835	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5836	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5837	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5838	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	5839	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.04762	    0.95238;
	5840	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	5841	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5842	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	5843	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	5844	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	5845	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5846	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5847	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5848	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5849	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5850	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5851	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5852	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5853	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5854	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5855	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5856	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5857	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5858	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5859	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5860	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5861	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5862	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5863	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5864	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5865	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5866	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5867	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5868	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5869	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5870	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5871	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5872	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5873	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5874	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5875	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5876	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5877	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5878	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5879	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5880	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5881	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5882	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5883	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5884	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5885	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	5886	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5887	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5888	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5889	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5890	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5891	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5892	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5893	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5894	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5895	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5896	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5897	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5898	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5899	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5900	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5901	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5902	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5903	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5904	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5905	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5906	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5907	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5908	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5909	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5910	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5911	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5912	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5913	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5914	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5915	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5916	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5917	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5918	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5919	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5920	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5921	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5922	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	5923	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5924	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5925	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5926	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5927	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5928	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5929	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5930	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5931	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5932	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5933	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5934	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5935	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5936	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5937	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5938	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5939	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5940	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5941	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5942	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5943	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5944	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5945	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5946	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5947	 1	 101.9	 -0.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5948	 2	 2.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5949	 2	 -859.2	 -117.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5950	 1	 90.1	 -6.4	 0.0	 0.0	 1	    0.97500	    0.00000	 90.0	 1	    1.15000	    0.80000;
	5951	 1	 97.8	 14.4	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5952	 2	 16.3	 230.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5953	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5954	 2	 165.3	 117.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5955	 2	 -20.0	 -24.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5956	 1	 -44.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5957	 2	 606.4	 163.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5958	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5959	 1	 122.4	 11.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5960	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5961	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5962	 2	 -63.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5963	 1	 283.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5964	 1	 -73.9	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5965	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5966	 1	 102.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5967	 1	 645.4	 22.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5968	 1	 212.0	 12.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5969	 1	 -1.3	 -0.7	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	5970	 1	 2.3	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5971	 1	 144.7	 3.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5972	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5973	 2	 314.6	 72.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5974	 1	 468.9	 110.7	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5975	 1	 -365.3	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5976	 1	 3.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5977	 1	 -9.9	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5978	 2	 -205.1	 -32.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5979	 1	 58.6	 3.9	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5980	 1	 2569.1	 -301.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5981	 1	 82.6	 10.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5982	 1	 537.8	 96.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5983	 1	 407.7	 7.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5984	 1	 137.7	 -6.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5985	 1	 146.0	 42.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5986	 1	 354.5	 -7.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5987	 2	 -341.6	 253.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5988	 1	 54.8	 -70.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5989	 1	 85.9	 -0.4	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5990	 1	 79.4	 22.1	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5991	 1	 255.9	 26.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5992	 2	 -86.7	 211.7	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5993	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5994	 1	 19.2	 4.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5995	 1	 4.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5996	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5997	 1	 -92.2	 62.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	5998	 1	 4.3	 6.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	5999	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6000	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6001	 1	 141.8	 29.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6002	 1	 171.5	 20.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6003	 1	 77.7	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6004	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6005	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 63.0	 1	    1.15000	    0.80000;
	6006	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6007	 1	 30.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6008	 1	 189.2	 36.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6009	 1	 85.8	 -1.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6010	 1	 80.9	 -5.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6011	 2	 83.0	 -15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6012	 1	 123.9	 75.9	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6013	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6014	 1	 -154.3	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6015	 1	 190.6	 57.8	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6016	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6017	 2	 464.0	 -15.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6018	 1	 706.1	 73.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6019	 2	 -20.5	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6020	 1	 504.6	 58.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6021	 1	 187.6	 10.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6022	 1	 48.0	 -76.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6023	 1	 79.1	 -39.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6024	 1	 156.1	 18.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6025	 1	 104.0	 -44.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6026	 1	 801.7	 224.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6027	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6028	 1	 330.4	 67.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6029	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6030	 2	 19.7	 -7.5	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6031	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6032	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6033	 1	 305.9	 -102.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6034	 1	 30.9	 -5.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6035	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6036	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6037	 1	 -79.0	 160.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6038	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6039	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6040	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6041	 1	 164.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6042	 1	 105.0	 4.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6043	 1	 176.6	 3.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6044	 1	 223.7	 21.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6045	 2	 282.1	 297.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6046	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6047	 1	 710.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6048	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6049	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6050	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6051	 1	 446.0	 18.9	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6052	 1	 222.5	 -54.2	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6053	 1	 -3.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6054	 1	 -13.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6055	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6056	 2	 593.7	 220.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6057	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6058	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6059	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6060	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6061	 1	 -1228.0	 -57.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6062	 1	 32.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6063	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6064	 1	 286.9	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6065	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6066	 1	 134.6	 39.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6067	 1	 20.3	 54.9	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6068	 1	 65.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6069	 1	 394.9	 15.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6070	 1	 -238.3	 30.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6071	 1	 25.6	 112.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6072	 1	 230.7	 -119.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6073	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6074	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6075	 1	 145.3	 280.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6076	 1	 180.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6077	 1	 279.1	 41.8	 0.0	 100.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6078	 2	 -4.4	 18.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6079	 2	 0.0	 0.7	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6080	 2	 221.0	 75.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6081	 1	 -363.9	 -22.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6082	 2	 -49.6	 -44.7	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6083	 2	 64.2	 -17.4	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6084	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6085	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6086	 1	 86.3	 6.4	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6087	 1	 -3.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6088	 1	 421.9	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6089	 1	 -20.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6090	 1	 -355.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6091	 1	 17.3	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6092	 1	 -246.9	 -7.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6093	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6094	 2	 312.4	 55.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6095	 1	 -25.0	 -16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6096	 2	 -224.0	 192.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6097	 1	 45.3	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6098	 1	 192.5	 -1.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6099	 1	 222.5	 -5.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6100	 1	 361.4	 118.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6101	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6102	 2	 119.0	 133.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6103	 2	 51.7	 73.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6104	 1	 -329.1	 114.8	 0.0	 -150.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6105	 2	 197.9	 55.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6106	 1	 -148.5	 8.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6107	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6108	 1	 214.0	 9.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6109	 1	 -490.5	 91.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6110	 1	 384.2	 77.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6111	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6112	 1	 -118.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6113	 1	 291.0	 23.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6114	 1	 394.0	 142.8	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6115	 1	 194.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6116	 2	 117.0	 29.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6117	 1	 -50.4	 42.2	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6118	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6119	 1	 133.0	 -33.7	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6120	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6121	 1	 56.8	 2.7	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6122	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6123	 2	 451.5	 -6.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6124	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6125	 1	 -1.8	 -17.7	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6126	 1	 5.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6127	 1	 535.5	 97.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6128	 1	 342.9	 -274.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6129	 2	 234.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6130	 1	 195.9	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6131	 1	 -82.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6132	 1	 -207.4	 186.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6133	 1	 167.2	 10.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6134	 1	 125.0	 -6.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6135	 1	 348.2	 270.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6136	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6137	 1	 45.0	 -11.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6138	 1	 46.8	 14.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6139	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6140	 1	 -26.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6141	 1	 82.9	 2.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6142	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6143	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6144	 1	 370.3	 25.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6145	 1	 74.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6146	 1	 -87.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6147	 2	 101.0	 -41.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6148	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6149	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6150	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6151	 1	 -1388.3	 231.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6152	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6153	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6154	 1	 33.7	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6155	 2	 47.0	 -5.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6156	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6157	 1	 105.0	 11.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6158	 1	 67.3	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6159	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6160	 1	 113.3	 -30.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6161	 1	 183.5	 23.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6162	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6163	 2	 285.0	 42.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6164	 2	 246.0	 31.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6165	 1	 821.5	 -5.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6166	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6167	 1	 -59.2	 22.9	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6168	 1	 -60.2	 29.4	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6169	 2	 228.0	 20.7	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6170	 1	 -670.0	 68.1	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6171	 1	 179.4	 5.5	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6172	 1	 1075.7	 303.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6173	 1	 407.7	 69.1	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6174	 2	 316.2	 -35.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6175	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6176	 1	 -33.3	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6177	 1	 123.2	 18.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6178	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6179	 2	 50.0	 85.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6180	 1	 -2.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6181	 1	 294.4	 47.8	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6182	 1	 217.0	 20.1	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6183	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6184	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6185	 2	 103.8	 -12.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6186	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6187	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6188	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6189	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6190	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6191	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6192	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6193	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6194	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99802	    0.00000	 380.0	 1	    1.19604	    0.80000;
	6195	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6196	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6197	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6198	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6199	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6200	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	6201	 1	 29.0	 175.4	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6202	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6203	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6204	 1	 -105.7	 195.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6205	 1	 314.3	 -161.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6206	 2	 20.5	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6207	 1	 239.4	 54.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6208	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6209	 2	 436.7	 -12.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6210	 1	 86.8	 15.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6211	 2	 6.0	 3.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6212	 2	 11.4	 35.9	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6213	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6214	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6215	 1	 97.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6216	 2	 8.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6217	 1	 148.3	 30.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6218	 1	 188.0	 35.3	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6219	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6220	 1	 5.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6221	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6222	 1	 109.5	 27.6	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6223	 1	 23.1	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6224	 1	 -72.0	 7.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6225	 1	 630.2	 -17.5	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6226	 1	 -595.2	 114.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6227	 1	 124.2	 7.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6228	 1	 53.5	 14.2	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6229	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6230	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6231	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6232	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6233	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6234	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6235	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6236	 1	 -19.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6237	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6238	 1	 218.0	 67.5	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6239	 1	 171.1	 47.1	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6240	 1	 279.7	 107.2	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6241	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6242	 1	 235.7	 36.6	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6243	 1	 304.6	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	6244	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	6245	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6246	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6247	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6248	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6249	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6250	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 11.0	 1	    1.15000	    0.80000;
	6251	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 11.0	 1	    1.15000	    0.80000;
	6252	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6253	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6254	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6255	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6256	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6257	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6258	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6259	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6260	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6261	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6262	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6263	 2	 37.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6264	 2	 37.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6265	 2	 37.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6266	 2	 37.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6268	 2	 16.0	 11.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6269	 2	 14.0	 11.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6270	 2	 14.0	 11.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6271	 2	 10.0	 7.5	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	6272	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6273	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6274	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6275	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6276	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6277	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6278	 2	 13.0	 7.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6279	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6280	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 12.0	 1	    1.15000	    0.80000;
	6281	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 12.0	 1	    1.15000	    0.80000;
	6282	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6283	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6284	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6285	 2	 31.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6286	 2	 31.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6287	 2	 38.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6288	 2	 38.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6289	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6290	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6291	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6292	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6293	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6294	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6295	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6296	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	6297	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6298	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6299	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6300	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6301	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6302	 2	 1.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6303	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6304	 2	 43.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6306	 2	 43.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6307	 2	 43.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6308	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6309	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6310	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6311	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6312	 2	 3.5	 2.2	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6313	 2	 3.5	 2.2	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6314	 2	 4.2	 2.3	 0.0	 0.0	 1	    0.97500	    0.00000	 14.0	 1	    1.15000	    0.80000;
	6315	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6316	 2	 30.0	 14.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6317	 2	 30.0	 14.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6319	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6320	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6321	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6322	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6323	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6324	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6325	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6326	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6327	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6328	 2	 40.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6329	 2	 40.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6330	 2	 40.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6331	 2	 40.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6332	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6333	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6334	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 21.0	 1	    1.15000	    0.80000;
	6335	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6336	 2	 8.8	 6.6	 0.0	 0.0	 1	    0.97500	    0.00000	 19.0	 1	    1.15000	    0.80000;
	6337	 2	 40.0	 17.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6338	 2	 40.0	 17.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6339	 2	 40.0	 17.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6340	 2	 40.0	 17.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6341	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 11.0	 1	    1.15000	    0.80000;
	6342	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6343	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6344	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6345	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6346	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6347	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6348	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6349	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6350	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6351	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6352	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6353	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6354	 2	 7.3	 5.5	 0.0	 0.0	 1	    0.97500	    0.00000	 21.0	 1	    1.15000	    0.80000;
	6355	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6356	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6357	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6358	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6359	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6360	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6361	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6362	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6363	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6364	 2	 10.8	 8.6	 0.0	 0.0	 1	    0.97500	    0.00000	 18.0	 1	    1.15000	    0.80000;
	6365	 2	 10.0	 6.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6366	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6367	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6369	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6370	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6371	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6372	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6373	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6374	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6375	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6376	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6377	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6378	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6379	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6380	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6381	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6382	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6383	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6384	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6385	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6386	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6387	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6388	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6389	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6390	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6391	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 12.0	 1	    1.15000	    0.80000;
	6392	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 12.0	 1	    1.15000	    0.80000;
	6393	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 12.0	 1	    1.15000	    0.80000;
	6394	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 12.0	 1	    1.15000	    0.80000;
	6395	 2	 14.0	 8.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6396	 2	 14.0	 8.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6397	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6398	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6399	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6400	 2	 5.9	 3.6	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6401	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6402	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6403	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6404	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6405	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 18.0	 1	    1.15000	    0.80000;
	6406	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 18.0	 1	    1.15000	    0.80000;
	6407	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 18.0	 1	    1.15000	    0.80000;
	6408	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 18.0	 1	    1.15000	    0.80000;
	6409	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6410	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6411	 2	 30.0	 12.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6412	 2	 30.0	 12.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6413	 2	 12.0	 3.0	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	6414	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6415	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	6416	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6417	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6418	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6419	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6420	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6421	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6422	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6423	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6424	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6425	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6426	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6427	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6428	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6429	 2	 13.0	 8.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6430	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6431	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6432	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6433	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6434	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6435	 2	 15.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6436	 2	 15.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6437	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6438	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6439	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 11.0	 1	    1.15000	    0.80000;
	6440	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6441	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6442	 2	 10.8	 8.6	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6443	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6444	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 3.0	 1	    1.15000	    0.80000;
	6445	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 3.0	 1	    1.15000	    0.80000;
	6446	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 3.0	 1	    1.15000	    0.80000;
	6447	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6448	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6449	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6450	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6451	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 13.0	 1	    1.15000	    0.80000;
	6452	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6453	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6454	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6455	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6456	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6457	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6458	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6459	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6460	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6461	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6462	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6463	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6464	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6465	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6466	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6467	 2	 15.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6468	 2	 7.0	 4.0	 0.0	 0.0	 1	    0.97500	    0.00000	 19.0	 1	    1.15000	    0.80000;
	6469	 2	 7.0	 4.0	 0.0	 0.0	 1	    0.97500	    0.00000	 19.0	 1	    1.15000	    0.80000;
	6470	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6471	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6472	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6473	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6474	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6475	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6476	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6477	 2	 41.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6478	 2	 41.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6479	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6480	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6481	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	6482	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6483	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6484	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6485	 2	 35.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6486	 2	 35.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6487	 2	 35.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6488	 2	 35.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	6489	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6490	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6491	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6492	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6493	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6494	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6495	 2	 18.0	 10.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6496	 2	 18.0	 10.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	6497	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	6498	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	6499	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin
mpc.gen = [
	4	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 12.0	 0.0; % NG
	4	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 10.0	 0.0; % NG
	5	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 9.1	 0.0; % NG
	11	 14.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 28.0	 0.0; % PEL
	11	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 18.0	 0.0; % PEL
	17	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.2	 0.0; % NG
	19	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 1.2	 0.0; % PEL
	22	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % NG
	24	 0.0	 0.0	 0.0	 0.0	 1.033333	 100.0	 0	 16.1	 0.0; % NG
	24	 0.0	 0.0	 0.0	 0.0	 1.033333	 100.0	 0	 35.5	 0.0; % NG
	25	 18.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 1	 36.0	 0.0; % PEL
	25	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 27.2	 0.0; % COW
	40	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 8.0	 0.0; % NG
	47	 8.0	 -0.25	 9.5	 -10.0	 0.999999	 100.0	 1	 16.0	 0.0; % NG
	47	 8.0	 -0.25	 9.5	 -10.0	 0.999999	 100.0	 1	 16.0	 0.0; % PEL
	48	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 23.0	 0.0; % NG
	48	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 24.0	 0.0; % PEL
	57	 6.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 13.0	 0.0; % NG
	64	 0.0	 0.0	 0.0	 0.0	 0.9888895	 100.0	 0	 24.0	 0.0; % PEL
	64	 0.0	 0.0	 0.0	 0.0	 0.9888895	 100.0	 0	 27.6	 0.0; % NG
	69	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 30.04	 0.0; % NG
	70	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 23.0	 0.0; % PEL
	85	 3.34	 0.0	 0.0	 0.0	 1.001094	 100.0	 1	 6.68	 0.0; % NG
	86	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 9.2	 0.0; % NG
	102	 23.0	 6.0	 21.0	 -9.0	 1.0158755	 100.0	 1	 46.0	 0.0; % NG
	122	 6.0	 1.5	 5.0	 -2.0	 1.0158755	 100.0	 1	 12.0	 0.0; % COW
	124	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 9.0	 0.0; % NG
	125	 13.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 26.0	 0.0; % NG
	125	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	132	 8.5	 0.0	 3.0	 -3.0	 1.000001	 100.0	 1	 17.0	 0.0; % PEL
	132	 0.0	 1.0	 1.0	 -1.0	 1.000001	 100.0	 0	 4.0	 0.0; % NG
	132	 0.0	 1.67	 3.0	 -3.0	 1.000001	 100.0	 0	 14.0	 0.0; % NG
	132	 0.0	 1.67	 3.0	 -3.0	 1.000001	 100.0	 0	 14.0	 0.0; % PEL
	137	 0.0	 0.25	 0.8	 -0.8	 1.015872	 100.0	 0	 18.0	 0.0; % PEL
	137	 9.0	 0.0	 0.8	 -0.8	 1.015872	 100.0	 1	 18.0	 0.0; % PEL
	155	 0.0	 1.76	 1.76	 -1.76	 1.0000025	 100.0	 0	 5.3	 0.0; % NG
	158	 8.95	 -1.5	 10.0	 -13.0	 0.9444445	 100.0	 1	 17.9	 0.0; % NG
	158	 8.95	 -1.5	 10.0	 -13.0	 0.9444445	 100.0	 1	 17.9	 0.0; % NG
	176	 0.0	 2.01	 10.0	 -4.0	 1.0	 100.0	 0	 30.0	 0.0; % PEL
	187	 0.0	 2.28	 8.0	 -8.0	 1.0000025	 100.0	 0	 11.0	 0.0; % NG
	187	 0.0	 2.0	 2.0	 -2.0	 1.0000025	 100.0	 0	 11.0	 0.0; % NG
	190	 0.0	 -0.23	 14.0	 -14.0	 0.9444445	 100.0	 0	 30.0	 0.0; % COW
	192	 11.75	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 23.5	 0.0; % PEL
	194	 7.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 15.0	 0.0; % NG
	194	 7.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 15.0	 0.0; % PEL
	217	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 11.94	 0.0; % NG
	224	 0.0	 1.99	 2.0	 0.0	 1.0	 100.0	 0	 6.0	 0.0; % PEL
	227	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 7.5	 0.0; % NG
	236	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 33.5	 0.0; % NG
	236	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 24.3	 0.0; % PEL
	238	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.0	 0.0; % COW
	238	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 36.0	 0.0; % NG
	246	 0.0	 0.0	 2.0	 0.0	 0.999999	 100.0	 0	 1.0	 0.0; % PEL
	246	 0.0	 -0.18	 10.0	 -10.0	 0.999999	 100.0	 0	 31.0	 0.0; % COW
	246	 0.0	 -0.18	 10.0	 -10.0	 0.999999	 100.0	 0	 31.0	 0.0; % PEL
	246	 0.0	 -0.18	 10.0	 -10.0	 0.999999	 100.0	 0	 31.0	 0.0; % NG
	256	 13.0	 0.0	 10.0	 -10.0	 1.0000025	 100.0	 1	 26.0	 0.0; % PEL
	256	 13.0	 0.0	 10.0	 -10.0	 1.0000025	 100.0	 1	 26.0	 0.0; % NG
	258	 15.0	 0.95	 1.0	 0.9	 1.000731	 100.0	 1	 30.0	 0.0; % PEL
	261	 0.0	 2.0	 4.0	 -4.0	 1.0000025	 100.0	 0	 8.0	 0.0; % NG
	269	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.6	 0.0; % NG
	282	 0.0	 -0.19	 6.1	 -6.2	 0.999999	 100.0	 0	 11.6	 0.0; % NG
	295	 0.0	 0.0	 0.0	 0.0	 0.9888895	 100.0	 0	 25.3	 0.0; % PEL
	296	 6.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 12.0	 0.0; % NG
	305	 7.5	 0.0	 9.0	 -9.0	 1.003694	 100.0	 1	 15.0	 0.0; % PEL
	312	 12.9	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 25.8	 0.0; % NG
	312	 24.8	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 49.6	 0.0; % PEL
	317	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 0.0	 -7.0; % SYNC
	317	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 0.0	 -7.0; % SYNC
	319	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 10.8	 0.0; % NG
	325	 0.0	 -0.04	 4.0	 -4.0	 0.999999	 100.0	 0	 11.0	 0.0; % NG
	332	 0.0	 0.68	 13.0	 -9.0	 1.015872	 100.0	 0	 25.0	 0.0; % NG
	333	 0.0	 4.58	 13.0	 -9.0	 1.0233335	 100.0	 0	 25.0	 0.0; % PEL
	336	 6.5	 -0.5	 5.0	 -6.0	 1.0000025	 100.0	 1	 13.0	 0.0; % COW
	338	 0.0	 1.58	 10.0	 -10.0	 1.0000025	 100.0	 0	 21.0	 0.0; % NG
	338	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 2.0	 0.0; % PEL
	345	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 2.3	 0.0; % PEL
	345	 9.75	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 19.5	 0.0; % PEL
	348	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 22.0	 0.0; % PEL
	357	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % PEL
	357	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	364	 65.0	 16.5	 59.0	 -26.0	 1.046665	 100.0	 1	 130.0	 0.0; % NG
	391	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 2.7	 0.0; % PEL
	409	 0.0	 0.73	 5.0	 -5.0	 1.015872	 100.0	 0	 18.0	 0.0; % NG
	411	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	411	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 11.5	 0.0; % NG
	431	 6.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 12.0	 0.0; % PEL
	440	 0.0	 1.45	 10.96	 -11.99	 1.0000025	 100.0	 0	 34.25	 0.0; % PEL
	447	 12.5	 -0.5	 8.0	 -9.0	 1.015872	 100.0	 1	 25.0	 0.0; % PEL
	462	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 2.4	 0.0; % PEL
	462	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 16.0	 0.0; % PEL
	464	 14.0	 1.5	 6.0	 -3.0	 0.984405	 100.0	 1	 27.0	 1.0; % NG
	464	 14.0	 1.5	 6.0	 -3.0	 0.984405	 100.0	 1	 27.0	 1.0; % PEL
	466	 0.0	 0.0	 19.0	 -10.0	 1.0079355	 100.0	 0	 48.0	 1.0; % PEL
	470	 0.0	 -0.57	 6.0	 -6.0	 0.999999	 100.0	 0	 10.0	 0.0; % NG
	470	 0.0	 -3.08	 5.4	 -5.4	 0.999999	 100.0	 0	 9.0	 0.0; % NG
	479	 0.0	 -0.09	 17.0	 -16.0	 0.999999	 100.0	 0	 27.0	 0.0; % PEL
	479	 0.0	 -0.09	 17.0	 -16.0	 0.999999	 100.0	 0	 27.0	 0.0; % NG
	479	 0.0	 -0.09	 17.0	 -16.0	 0.999999	 100.0	 0	 27.0	 0.0; % COW
	491	 0.0	 -0.75	 8.0	 -17.0	 1.033334	 100.0	 0	 23.4	 0.0; % NG
	508	 0.0	 1.72	 2.0	 -2.0	 0.999999	 100.0	 0	 4.0	 0.0; % NG
	519	 0.0	 0.0	 0.0	 0.0	 1.015874	 100.0	 0	 10.0	 0.0; % COW
	520	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % COW
	530	 4.0	 0.0	 4.8	 -4.8	 0.999999	 100.0	 1	 8.0	 0.0; % COW
	530	 4.0	 0.0	 4.8	 -4.8	 0.999999	 100.0	 1	 8.0	 0.0; % NG
	530	 4.0	 0.0	 4.8	 -4.8	 0.999999	 100.0	 1	 8.0	 0.0; % PEL
	537	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % COW
	537	 12.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 24.0	 0.0; % PEL
	546	 4.5	 1.95	 2.0	 1.9	 1.0000025	 100.0	 1	 9.0	 0.0; % NG
	548	 0.0	 2.0	 2.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % COW
	570	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	570	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 30.0	 0.0; % NG
	570	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 11.5	 0.0; % NG
	583	 8.0	 1.5	 7.0	 -4.0	 1.0000005	 100.0	 1	 16.0	 0.0; % NG
	585	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 9.0	 0.0; % NG
	586	 0.0	 4.61	 5.7	 -5.7	 0.999999	 100.0	 0	 9.5	 0.0; % NG
	589	 0.0	 0.1	 0.1	 -0.1	 1.000001	 100.0	 0	 1.0	 0.0; % PEL
	593	 0.0	 1.34	 10.0	 -10.0	 1.0000025	 100.0	 0	 21.0	 0.0; % PEL
	600	 0.0	 0.37	 1.0	 -1.0	 1.015872	 100.0	 0	 6.1	 0.0; % NG
	610	 22.5	 0.0	 45.0	 -45.0	 0.975	 100.0	 1	 45.0	 0.0; % NG
	610	 0.0	 -0.16	 45.0	 -45.0	 0.975	 100.0	 0	 45.0	 0.0; % NG
	612	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % COW
	612	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	612	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	613	 0.0	 0.0	 0.0	 0.0	 1.0000005	 100.0	 0	 35.0	 0.0; % PEL
	613	 0.0	 0.0	 0.0	 0.0	 1.0000005	 100.0	 0	 11.5	 0.0; % NG
	624	 0.0	 0.0	 8.3	 -8.3	 1.0111115	 100.0	 1	 8.3	 -8.3; % NG
	633	 0.0	 -4.7	 4.0	 -4.7	 0.999999	 100.0	 0	 7.3	 0.0; % NG
	636	 0.0	 0.5	 7.0	 0.0	 1.015872	 100.0	 0	 15.0	 0.0; % PEL
	636	 7.5	 3.5	 7.0	 0.0	 1.015872	 100.0	 1	 15.0	 0.0; % PEL
	641	 119.5	 2.5	 80.0	 -75.0	 1.079965	 100.0	 1	 239.0	 0.0; % NG
	652	 0.0	 1.32	 7.0	 0.0	 1.0000025	 100.0	 0	 7.0	 0.0; % COW
	670	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % COW
	670	 6.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 12.0	 0.0; % COW
	671	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 7.5	 0.0; % NG
	671	 12.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 24.0	 0.0; % PEL
	679	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 6.6	 0.0; % NG
	680	 0.0	 0.0	 0.0	 0.0	 1.022374	 100.0	 0	 12.0	 0.0; % COW
	684	 4.5	 0.5	 6.0	 -5.0	 0.9444445	 100.0	 1	 9.0	 0.0; % NG
	684	 4.5	 0.5	 6.0	 -5.0	 0.9444445	 100.0	 1	 9.0	 0.0; % NG
	684	 0.0	 1.87	 8.0	 -5.0	 0.9444445	 100.0	 0	 11.0	 0.0; % PEL
	684	 5.5	 1.5	 8.0	 -5.0	 0.9444445	 100.0	 1	 11.0	 0.0; % NG
	695	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 32.35	 0.0; % NG
	695	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 12.0	 0.0; % NG
	695	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 21.0	 0.0; % NG
	699	 18.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 37.0	 0.0; % NG
	699	 18.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 37.0	 0.0; % NG
	698	 18.5	 0.0	 15.0	 -15.0	 0.975	 100.0	 1	 37.0	 0.0; % PEL
	698	 18.5	 0.0	 15.0	 -15.0	 0.975	 100.0	 1	 37.0	 0.0; % PEL
	697	 18.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 37.0	 0.0; % NG
	697	 18.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 37.0	 0.0; % NG
	705	 0.0	 2.0	 2.0	 -2.0	 0.9444445	 100.0	 0	 4.0	 0.0; % NG
	705	 0.0	 2.5	 2.5	 -2.5	 0.9444445	 100.0	 0	 4.0	 0.0; % NG
	705	 2.85	 0.0	 3.0	 -3.0	 0.9444445	 100.0	 1	 5.7	 0.0; % COW
	705	 0.0	 0.84	 6.0	 -5.0	 0.9444445	 100.0	 0	 8.5	 0.0; % NG
	732	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 19.5	 0.0; % NG
	733	 19.5	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 39.0	 0.0; % NG
	734	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 11.5	 0.0; % NG
	734	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 32.0	 0.0; % PEL
	736	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 12.0	 0.0; % NG
	736	 16.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 32.0	 0.0; % PEL
	737	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 5.0	 0.0; % PEL
	744	 0.0	 3.85	 4.22	 -3.7	 0.999999	 100.0	 0	 6.7	 0.0; % PEL
	744	 0.0	 4.02	 4.39	 -3.0	 0.999999	 100.0	 0	 5.6	 0.0; % PEL
	745	 13.3	 0.0	 15.0	 -15.0	 0.999999	 100.0	 1	 26.6	 0.0; % PEL
	746	 4.0	 0.0	 2.0	 -2.0	 1.022224	 100.0	 1	 7.0	 1.0; % PEL
	751	 0.0	 -0.18	 3.0	 -3.0	 0.999999	 100.0	 0	 5.0	 -5.0; % NG
	758	 0.0	 -2.68	 8.0	 -8.0	 0.9888895	 100.0	 0	 23.5	 0.0; % PEL
	760	 0.0	 0.0	 0.0	 0.0	 1.000709	 100.0	 0	 6.0	 0.0; % NG
	761	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 6.0	 0.0; % PEL
	760	 18.75	 0.79	 10.0	 -8.42	 1.000709	 100.0	 1	 37.5	 0.0; % NG
	761	 18.75	 2.0	 10.0	 -6.0	 0.999999	 100.0	 1	 37.5	 0.0; % COW
	762	 0.0	 0.06	 0.06	 -0.06	 0.825	 100.0	 0	 0.6	 0.0; % PEL
	762	 0.0	 1.73	 2.61	 -2.61	 0.825	 100.0	 0	 26.1	 0.0; % PEL
	762	 0.0	 0.16	 0.16	 -0.16	 0.825	 100.0	 0	 1.6	 0.0; % PEL
	762	 0.0	 0.11	 0.11	 -0.11	 0.825	 100.0	 0	 1.1	 0.0; % NG
	766	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 37.5	 0.0; % NG
	766	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 34.0	 0.0; % NG
	786	 0.0	 -0.79	 26.0	 -26.0	 0.975	 100.0	 0	 8.0	 0.0; % NG
	786	 0.0	 -0.79	 26.0	 -26.0	 0.975	 100.0	 0	 15.0	 0.0; % NG
	787	 0.0	 -0.71	 26.0	 -26.0	 0.975	 100.0	 0	 19.0	 0.0; % PEL
	801	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % PEL
	801	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % COW
	802	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % PEL
	802	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % PEL
	803	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % PEL
	803	 15.5	 -1.0	 15.0	 -17.0	 0.975	 100.0	 1	 31.0	 0.0; % NG
	807	 20.4	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 40.8	 0.0; % NG
	815	 16.5	 -1.5	 6.0	 -9.0	 1.015872	 100.0	 1	 32.0	 1.0; % PEL
	815	 0.0	 0.0	 6.0	 -9.0	 1.015872	 100.0	 0	 32.0	 1.0; % NG
	816	 16.5	 -1.5	 6.0	 -9.0	 1.015872	 100.0	 1	 32.0	 1.0; % PEL
	816	 16.5	 -1.5	 6.0	 -9.0	 1.015872	 100.0	 1	 32.0	 1.0; % NG
	816	 16.5	 -1.5	 6.0	 -9.0	 1.015872	 100.0	 1	 32.0	 1.0; % NG
	816	 16.5	 -1.5	 6.0	 -9.0	 1.015872	 100.0	 1	 32.0	 1.0; % PEL
	826	 0.0	 1.48	 3.0	 -3.0	 1.0000025	 100.0	 0	 13.0	 0.0; % NG
	826	 0.0	 3.0	 3.0	 -3.0	 1.0000025	 100.0	 0	 7.0	 0.0; % COW
	829	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 2.4	 0.0; % PEL
	830	 13.5	 0.0	 10.0	 -10.0	 1.0000025	 100.0	 1	 27.0	 0.0; % NG
	831	 0.0	 -0.33	 10.0	 -10.0	 0.9444445	 100.0	 0	 20.0	 0.0; % NG
	833	 0.0	 -0.46	 3.14	 -3.43	 1.0000025	 100.0	 0	 9.8	 0.0; % NG
	833	 0.0	 0.0	 1.0	 0.0	 1.0000025	 100.0	 0	 5.0	 0.0; % NG
	836	 7.5	 2.95	 3.0	 2.9	 1.0000025	 100.0	 1	 15.0	 0.0; % NG
	838	 0.0	 2.31	 7.5	 -7.5	 1.0000025	 100.0	 0	 19.0	 0.0; % NG
	838	 0.0	 2.31	 7.5	 -7.5	 1.0000025	 100.0	 0	 15.0	 0.0; % NG
	857	 0.0	 0.0	 1.0	 0.9	 1.0000025	 100.0	 0	 12.0	 0.0; % PEL
	857	 0.0	 1.0	 1.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	864	 7.0	 0.0	 7.0	 -7.0	 1.0000025	 100.0	 1	 14.0	 0.0; % PEL
	865	 7.0	 0.0	 7.0	 -7.0	 1.0000025	 100.0	 1	 14.0	 0.0; % COW
	885	 0.0	 1.79	 6.0	 -6.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	885	 0.0	 1.79	 3.0	 -3.0	 1.0000025	 100.0	 0	 12.0	 0.0; % COW
	889	 0.0	 0.53	 5.0	 -5.0	 0.975	 100.0	 0	 13.0	 0.0; % NG
	889	 0.0	 0.53	 5.0	 -5.0	 0.975	 100.0	 0	 13.0	 0.0; % COW
	889	 0.0	 0.53	 5.0	 -5.0	 0.975	 100.0	 0	 13.0	 0.0; % NG
	889	 0.0	 0.53	 5.0	 -5.0	 0.975	 100.0	 0	 13.0	 0.0; % NG
	907	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 14.0	 0.0; % PEL
	940	 4.05	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 8.1	 0.0; % NG
	944	 0.0	 0.1	 0.1	 -0.1	 1.000001	 100.0	 0	 2.0	 0.0; % PEL
	965	 25.0	 9.0	 27.0	 -9.0	 0.975	 100.0	 1	 50.0	 0.0; % NG
	967	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 18.0	 0.0; % NG
	973	 4.0	 0.0	 5.0	 -5.0	 0.999999	 100.0	 1	 8.0	 0.0; % PEL
	973	 4.0	 0.0	 5.0	 -5.0	 0.999999	 100.0	 1	 8.0	 0.0; % PEL
	983	 0.0	 2.15	 22.0	 -10.0	 1.027779	 100.0	 0	 49.0	 0.0; % NG
	983	 0.0	 2.15	 7.0	 -3.0	 1.027779	 100.0	 0	 15.0	 0.0; % NG
	983	 0.0	 2.15	 22.0	 -10.0	 1.027779	 100.0	 0	 49.0	 0.0; % NG
	985	 0.0	 0.0	 0.0	 0.0	 0.984126	 100.0	 0	 22.0	 0.0; % NG
	987	 0.0	 1.0	 1.0	 -1.0	 1.022224	 100.0	 0	 4.0	 0.0; % NG
	1009	 1.5	 0.95	 1.0	 0.9	 1.000001	 100.0	 1	 3.0	 0.0; % NG
	1009	 0.0	 1.0	 1.0	 0.0	 1.000001	 100.0	 0	 3.0	 0.0; % PEL
	1013	 3.6	 0.0	 4.0	 -4.0	 1.004549	 100.0	 1	 7.2	 0.0; % COW
	1025	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 20.0	 0.0; % PEL
	1048	 0.0	 -0.53	 12.0	 -10.0	 0.999999	 100.0	 0	 20.0	 0.0; % PEL
	1050	 6.9	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 13.8	 0.0; % COW
	1050	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 1.2	 0.0; % PEL
	1057	 9.4	 1.5	 6.0	 -3.0	 1.022222	 100.0	 1	 11.8	 7.0; % PEL
	1058	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.0	 0.0; % NG
	1065	 0.0	 0.0	 0.0	 0.0	 0.9736045	 100.0	 0	 12.0	 0.0; % NG
	1066	 6.0	 1.95	 2.0	 1.9	 1.0000025	 100.0	 1	 12.0	 0.0; % COW
	1070	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 8.0	 0.0; % COW
	1108	 16.0	 0.0	 6.0	 -6.0	 0.975	 100.0	 1	 18.0	 14.0; % NG
	1108	 0.0	 0.0	 3.0	 -3.0	 0.975	 100.0	 0	 8.0	 5.0; % COW
	1108	 0.0	 0.0	 3.0	 -3.0	 0.975	 100.0	 0	 8.0	 5.0; % NG
	1108	 6.5	 0.0	 3.0	 -3.0	 0.975	 100.0	 1	 8.0	 5.0; % NG
	1110	 9.0	 0.0	 10.0	 -10.0	 1.002384	 100.0	 1	 18.0	 0.0; % PEL
	1110	 9.0	 0.0	 10.0	 -10.0	 1.002384	 100.0	 1	 18.0	 0.0; % NG
	1125	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 7.0	 0.0; % COW
	1128	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % COW
	1135	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	1147	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 6.0	 0.0; % NG
	1147	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.0	 0.0; % COW
	1210	 31.0	 0.0	 40.0	 -40.0	 1.047405	 100.0	 1	 62.0	 0.0; % NG
	1211	 20.7	 0.215	 12.42	 -11.99	 1.044445	 100.0	 1	 41.4	 0.0; % NG
	1221	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 11.2	 0.0; % COW
	1246	 0.0	 -0.42	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	1246	 0.0	 -0.42	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	1256	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 30.0	 0.0; % PEL
	1258	 12.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 24.0	 0.0; % NG
	1259	 12.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 24.0	 0.0; % PEL
	1263	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 4.6	 0.0; % PEL
	1277	 0.0	 0.0	 0.0	 0.0	 1.033333	 100.0	 0	 29.0	 0.0; % PEL
	1277	 0.0	 0.0	 0.0	 0.0	 1.033333	 100.0	 0	 14.3	 0.0; % NG
	1286	 0.0	 0.35	 0.35	 -0.35	 1.0000025	 100.0	 0	 1.06	 0.0; % PEL
	1286	 0.0	 2.1	 2.6	 -2.8	 1.0000025	 100.0	 0	 8.0	 0.0; % PEL
	1286	 4.0	 -0.1	 2.6	 -2.8	 1.0000025	 100.0	 1	 8.0	 0.0; % PEL
	1303	 0.0	 0.1	 0.1	 -0.1	 0.975	 100.0	 0	 4.0	 0.0; % NG
	1310	 0.0	 1.0	 1.0	 0.0	 1.0000025	 100.0	 0	 17.0	 0.0; % NG
	1310	 0.0	 1.0	 1.0	 0.0	 1.0000025	 100.0	 0	 17.0	 0.0; % PEL
	1310	 0.0	 1.0	 1.0	 0.0	 1.0000025	 100.0	 0	 7.0	 0.0; % COW
	1313	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 0.8	 0.6; % NG
	1313	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 0.8	 0.6; % NG
	1315	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 11.5	 0.0; % PEL
	1315	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 6.9	 0.0; % NG
	1323	 0.0	 0.64	 6.5	 -6.5	 0.9444445	 100.0	 0	 12.4	 0.0; % PEL
	1325	 0.0	 0.0	 1.0	 0.9	 1.000001	 100.0	 0	 5.0	 0.0; % NG
	1325	 2.5	 0.95	 1.0	 0.9	 1.000001	 100.0	 1	 5.0	 0.0; % COW
	1340	 0.0	 -9.48	 40.0	 -40.0	 0.999999	 100.0	 0	 72.5	 0.0; % COW
	1344	 5.5	 3.0	 5.0	 1.0	 0.975	 100.0	 1	 11.0	 0.0; % NG
	1344	 5.5	 3.0	 5.0	 1.0	 0.975	 100.0	 1	 11.0	 0.0; % NG
	1354	 9.075	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 18.15	 0.0; % PEL
	1354	 17.85	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 35.7	 0.0; % NG
	1354	 14.2	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 28.4	 0.0; % PEL
	1357	 22.5	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 45.0	 0.0; % PEL
	1356	 22.5	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 45.0	 0.0; % NG
	1363	 0.0	 0.77	 7.0	 -5.0	 1.015872	 100.0	 0	 13.0	 0.0; % NG
	1363	 6.5	 1.31	 7.62	 -5.0	 1.015872	 100.0	 1	 13.0	 0.0; % NG
	1410	 0.0	 0.0	 22.0	 -10.0	 1.015872	 100.0	 0	 50.0	 5.0; % NG
	1420	 25.0	 0.0	 50.0	 -50.0	 1.000001	 100.0	 1	 50.0	 0.0; % NG
	1420	 25.0	 0.0	 50.0	 -50.0	 1.000001	 100.0	 1	 50.0	 0.0; % NG
	1433	 0.0	 0.0	 22.0	 -10.0	 1.015872	 100.0	 0	 50.0	 5.0; % NG
	1440	 10.5	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 21.0	 0.0; % COW
	1454	 0.0	 0.89	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	1454	 0.0	 0.89	 2.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % PEL
	1454	 0.0	 0.89	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	1463	 0.0	 -0.03	 0.3	 -0.3	 1.0158755	 100.0	 0	 3.0	 0.0; % NG
	1464	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 10.0	 0.0; % PEL
	1474	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 10.0	 0.0; % NG
	1495	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 26.0	 0.0; % PEL
	1497	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 10.0	 0.0; % NG
	1497	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 20.0	 0.0; % PEL
	1517	 141.5	 20.0	 100.0	 -60.0	 0.975	 100.0	 1	 239.0	 44.0; % NG
	1518	 125.5	 12.5	 70.0	 -45.0	 0.975	 100.0	 1	 169.0	 82.0; % NG
	1548	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 20.0	 0.0; % NG
	1548	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 15.85	 0.0; % NG
	1555	 25.0	 6.5	 22.0	 -9.0	 1.033333	 100.0	 1	 49.0	 1.0; % NG
	1559	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 12.0	 0.0; % NG
	1559	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 24.0	 0.0; % PEL
	1560	 0.0	 0.0	 0.0	 0.0	 1.046665	 100.0	 0	 4.0	 0.0; % NG
	1561	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 11.5	 0.0; % PEL
	1565	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 24.0	 0.0; % PEL
	1565	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 14.0	 0.0; % NG
	1579	 0.0	 -7.14	 6.0	 -7.14	 0.999999	 100.0	 0	 10.2	 0.0; % NG
	1593	 18.0	 -0.5	 11.0	 -12.0	 1.022224	 100.0	 1	 36.0	 0.0; % PEL
	1593	 18.0	 -0.5	 11.0	 -12.0	 1.022224	 100.0	 1	 36.0	 0.0; % PEL
	1599	 21.0	 5.0	 20.0	 -10.0	 1.0028855	 100.0	 1	 42.0	 0.0; % NG
	1613	 11.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 1	 22.0	 0.0; % PEL
	1613	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 10.0	 0.0; % NG
	1624	 39.0	 -1.36	 1.0	 -3.72	 1.0377785	 100.0	 1	 78.0	 0.0; % NG
	1637	 0.0	 0.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 3.7	 0.7; % PEL
	1638	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 5.1	 0.0; % NG
	1638	 5.95	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 11.9	 0.0; % NG
	1639	 26.0	 -1.5	 10.0	 -13.0	 1.04444	 100.0	 1	 52.0	 0.0; % NG
	1642	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 4.0	 0.0; % NG
	1653	 0.0	 1.65	 6.0	 -6.0	 1.0000025	 100.0	 0	 15.0	 0.0; % PEL
	1669	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 10.0	 0.0; % NG
	1669	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 17.5	 0.0; % NG
	1678	 5.5	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 11.0	 0.0; % NG
	1678	 5.5	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 11.0	 0.0; % NG
	1679	 0.0	 3.0	 3.0	 0.0	 1.0000025	 100.0	 0	 27.0	 0.0; % PEL
	1680	 0.0	 0.86	 3.0	 -3.0	 1.015872	 100.0	 0	 10.33	 0.0; % PEL
	1680	 0.0	 2.43	 3.0	 -3.0	 1.015872	 100.0	 0	 10.33	 0.0; % NG
	1681	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 12.0	 0.0; % NG
	1682	 0.0	 0.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 3.2	 0.6; % NG
	1687	 3.55	 0.07	 2.13	 -1.99	 1.0000025	 100.0	 1	 7.1	 0.0; % COW
	1691	 0.0	 -0.0	 0.0	 -0.0	 1.0158755	 100.0	 0	 15.0	 0.0; % COW
	1691	 0.0	 -0.0	 0.0	 -0.0	 1.0158755	 100.0	 0	 15.0	 0.0; % NG
	1691	 0.0	 -0.0	 0.0	 -0.0	 1.0158755	 100.0	 0	 15.0	 0.0; % NG
	1694	 0.0	 1.61	 3.0	 0.0	 1.0000025	 100.0	 0	 31.0	 0.0; % NG
	1697	 0.0	 0.0	 2.0	 1.9	 1.0000025	 100.0	 0	 18.0	 0.0; % PEL
	1698	 0.0	 2.7	 25.0	 -25.0	 1.0000025	 100.0	 0	 40.0	 0.0; % COW
	1700	 14.45	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 28.9	 0.0; % NG
	1711	 0.0	 0.0	 0.0	 0.0	 1.015874	 100.0	 0	 2.0	 0.0; % PEL
	1722	 0.0	 -0.29	 2.7	 -2.0	 0.975	 100.0	 0	 4.5	 0.0; % NG
	1722	 0.0	 -0.29	 8.0	 -8.0	 0.975	 100.0	 0	 14.5	 0.0; % PEL
	1725	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 4.5	 0.0; % PEL
	1727	 0.0	 -0.11	 7.5	 -7.5	 0.999999	 100.0	 0	 12.0	 0.0; % NG
	1734	 13.5	 0.0	 14.0	 -14.0	 1.0000025	 100.0	 1	 27.0	 0.0; % NG
	1734	 0.0	 2.22	 6.0	 -6.0	 1.0000025	 100.0	 0	 11.0	 0.0; % COW
	1741	 20.0	 1.0	 20.0	 -18.0	 0.975	 100.0	 1	 40.0	 0.0; % COW
	1742	 20.0	 1.0	 20.0	 -18.0	 0.975	 100.0	 1	 40.0	 0.0; % NG
	1743	 20.0	 1.0	 20.0	 -18.0	 0.975	 100.0	 1	 40.0	 0.0; % NG
	1797	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 3.6	 0.0; % NG
	1807	 0.0	 2.0	 2.0	 0.0	 1.0000025	 100.0	 0	 10.6	 0.0; % NG
	1824	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 9.2	 0.0; % COW
	1831	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 32.7	 0.0; % NG
	1837	 8.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 16.0	 0.0; % NG
	1837	 16.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 32.0	 0.0; % NG
	1847	 0.0	 0.57	 2.0	 -2.0	 1.016667	 100.0	 0	 5.0	 0.0; % NG
	1847	 0.0	 0.57	 1.0	 -1.0	 1.016667	 100.0	 0	 4.0	 0.0; % NG
	1855	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	1858	 0.0	 1.0	 1.0	 0.0	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	1858	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 2.0	 0.0; % PEL
	1863	 12.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 24.0	 0.0; % PEL
	1863	 18.25	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 36.5	 0.0; % COW
	1863	 21.75	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 43.5	 0.0; % NG
	1864	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % PEL
	1865	 22.0	 5.5	 20.0	 -9.0	 1.0000005	 100.0	 1	 44.0	 0.0; % NG
	1866	 0.0	 -0.65	 3.5	 -3.5	 0.999999	 100.0	 0	 5.9	 0.0; % NG
	1871	 4.5	 0.0	 0.0	 0.0	 1.000001	 100.0	 1	 9.0	 0.0; % NG
	1880	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	1888	 12.0	 0.0	 4.0	 -4.0	 0.975	 100.0	 1	 24.0	 0.0; % NG
	1889	 12.0	 0.0	 4.0	 -4.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	1890	 12.0	 0.0	 4.0	 -4.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	1891	 12.0	 0.0	 4.0	 -4.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	1903	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 1.2	 0.0; % PEL
	1922	 0.0	 1.0	 1.0	 -1.0	 1.000001	 100.0	 0	 3.0	 0.0; % PEL
	1934	 0.0	 0.08	 26.0	 -26.0	 0.999999	 100.0	 0	 43.0	 0.0; % NG
	1933	 0.0	 -0.06	 20.0	 -20.0	 0.999999	 100.0	 0	 38.0	 0.0; % NG
	1942	 0.0	 0.0	 2.0	 1.9	 1.0000025	 100.0	 0	 30.0	 0.0; % NG
	1953	 0.0	 2.0	 2.0	 0.0	 1.0000025	 100.0	 0	 6.0	 0.0; % PEL
	1961	 12.0	 0.5	 8.0	 -7.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	1962	 12.0	 0.105	 0.22	 -0.01	 0.975	 100.0	 1	 24.0	 0.0; % NG
	1963	 12.0	 0.5	 8.0	 -7.0	 0.975	 100.0	 1	 24.0	 0.0; % COW
	1964	 12.0	 0.5	 8.0	 -7.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	1965	 12.0	 0.5	 8.0	 -7.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	1974	 14.5	 0.0	 10.0	 -10.0	 0.975	 100.0	 1	 29.0	 0.0; % PEL
	1974	 14.5	 0.0	 10.0	 -10.0	 0.975	 100.0	 1	 29.0	 0.0; % NG
	1975	 14.5	 -6.5	 5.0	 -18.0	 0.999999	 100.0	 1	 29.0	 0.0; % PEL
	1976	 14.5	 -5.0	 8.0	 -18.0	 0.999999	 100.0	 1	 29.0	 0.0; % NG
	1978	 0.0	 -0.39	 6.0	 -6.0	 1.0000025	 100.0	 0	 8.0	 0.0; % NG
	1980	 2.55	 0.0	 2.0	 -2.0	 1.0000025	 100.0	 1	 4.6	 0.5; % PEL
	1980	 0.0	 0.0	 2.0	 -2.0	 1.0000025	 100.0	 0	 4.6	 0.5; % NG
	1986	 0.0	 -2.32	 2.0	 -2.32	 0.999999	 100.0	 0	 3.6	 0.0; % NG
	1994	 0.0	 1.02	 5.0	 -5.0	 0.9444445	 100.0	 0	 8.5	 0.0; % NG
	2001	 23.0	 6.0	 21.0	 -9.0	 1.0158755	 100.0	 1	 46.0	 0.0; % NG
	2012	 12.0	 0.0	 9.0	 -9.0	 1.0000025	 100.0	 1	 24.0	 0.0; % PEL
	2013	 12.0	 0.0	 9.0	 -9.0	 1.0000025	 100.0	 1	 24.0	 0.0; % PEL
	2013	 12.0	 0.0	 9.0	 -9.0	 1.0000025	 100.0	 1	 24.0	 0.0; % NG
	2018	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 12.0	 0.0; % NG
	2022	 0.0	 0.0	 7.0	 -7.0	 1.000001	 100.0	 1	 30.0	 -30.0; % NG
	2030	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 9.0	 0.0; % NG
	2044	 17.0	 1.5	 19.0	 -16.0	 0.999999	 100.0	 1	 34.0	 0.0; % PEL
	2054	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	2078	 0.0	 2.0	 2.0	 0.0	 1.0000025	 100.0	 0	 5.0	 0.0; % NG
	2091	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 16.0	 0.0; % NG
	2092	 27.5	 6.0	 22.0	 -10.0	 1.022222	 100.0	 1	 54.0	 1.0; % NG
	2096	 8.0	 0.0	 5.0	 -5.0	 1.0079355	 100.0	 1	 16.0	 0.0; % NG
	2116	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 19.9	 0.0; % NG
	2116	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 32.4	 0.0; % NG
	2144	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.25	 0.0; % NG
	2144	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 6.0	 0.0; % NG
	2154	 14.5	 3.5	 13.0	 -6.0	 1.027779	 100.0	 1	 29.0	 0.0; % PEL
	2158	 22.5	 6.0	 22.0	 -10.0	 1.0000005	 100.0	 1	 45.0	 0.0; % PEL
	2159	 0.0	 0.0	 0.0	 0.0	 1.033333	 100.0	 0	 12.0	 0.0; % NG
	2175	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 24.0	 0.0; % PEL
	2175	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 29.92	 0.0; % NG
	2180	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 9.2	 0.0; % NG
	2183	 0.0	 0.0	 0.0	 0.0	 0.9682545	 100.0	 0	 12.0	 0.0; % NG
	2183	 0.0	 0.0	 0.0	 0.0	 0.9682545	 100.0	 0	 12.0	 0.0; % PEL
	2185	 0.0	 0.0	 22.0	 -10.0	 1.022222	 100.0	 0	 47.0	 37.0; % NG
	2186	 7.5	 0.0	 9.0	 -9.0	 0.9444445	 100.0	 1	 15.0	 0.0; % NG
	2188	 10.0	 1.95	 2.0	 1.9	 1.000001	 100.0	 1	 20.0	 0.0; % NG
	2219	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 28.0	 0.0; % NG
	2219	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 26.0	 0.0; % NG
	2238	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	2238	 18.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 36.0	 0.0; % COW
	2240	 0.0	 0.0	 8.0	 -8.0	 0.975	 100.0	 0	 24.0	 2.5; % NG
	2240	 13.25	 0.0	 8.0	 -8.0	 0.975	 100.0	 1	 24.0	 2.5; % PEL
	2274	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 13.8	 0.0; % NG
	2284	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	2288	 0.0	 1.96	 17.0	 -20.0	 1.0000005	 100.0	 0	 56.0	 0.0; % PEL
	2290	 0.0	 0.0	 20.0	 -20.0	 1.0000005	 100.0	 1	 64.0	 -64.0; % NG
	2296	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % NG
	2296	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % COW
	2322	 6.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 12.0	 0.0; % NG
	2328	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 11.5	 0.0; % NG
	2332	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 3.6	 0.0; % NG
	2334	 14.0	 1.5	 12.0	 -9.0	 1.015872	 100.0	 1	 28.0	 0.0; % NG
	2334	 14.0	 1.5	 12.0	 -9.0	 1.015872	 100.0	 1	 28.0	 0.0; % NG
	2334	 14.0	 1.5	 12.0	 -9.0	 1.015872	 100.0	 1	 28.0	 0.0; % NG
	2335	 0.0	 -0.56	 1.0	 -1.94	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	2335	 0.0	 1.38	 3.0	 0.0	 1.0000025	 100.0	 0	 7.0	 0.0; % COW
	2336	 0.0	 2.0	 2.0	 -2.0	 1.022224	 100.0	 0	 7.0	 0.0; % NG
	2357	 12.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	2358	 12.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 24.0	 0.0; % NG
	2359	 12.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 24.0	 0.0; % PEL
	2360	 12.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 24.0	 0.0; % COW
	2361	 10.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 20.0	 0.0; % PEL
	2371	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 8.0	 0.0; % NG
	2387	 6.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 12.0	 0.0; % COW
	2389	 17.45	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 34.9	 0.0; % PEL
	2389	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 19.3	 0.0; % NG
	2405	 18.0	 0.0	 14.0	 -14.0	 1.000001	 100.0	 1	 36.0	 0.0; % NG
	2407	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 6.9	 0.0; % PEL
	2407	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 19.2	 0.0; % NG
	2414	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 8.0	 0.0; % NG
	2414	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 16.0	 0.0; % NG
	2414	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	2426	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 19.7	 0.0; % PEL
	2430	 11.3	 0.0	 0.0	 0.0	 0.999999	 100.0	 1	 22.6	 0.0; % NG
	2430	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 1.7	 0.0; % PEL
	2433	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 18.0	 0.0; % NG
	2433	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 21.0	 0.0; % NG
	2438	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 10.4	 0.0; % NG
	2437	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 22.0	 0.0; % NG
	2453	 0.0	 1.47	 8.0	 -8.0	 1.047355	 100.0	 0	 21.0	 0.0; % PEL
	2454	 0.0	 0.52	 3.0	 -3.0	 1.015872	 100.0	 0	 4.5	 0.0; % NG
	2454	 0.0	 1.51	 3.0	 -3.0	 1.015872	 100.0	 0	 4.5	 0.0; % PEL
	2457	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 20.7	 0.0; % NG
	2468	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 12.0	 0.0; % PEL
	2474	 13.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 26.0	 0.0; % PEL
	2488	 0.0	 0.46	 5.0	 -5.0	 1.015872	 100.0	 0	 12.0	 0.0; % COW
	2516	 44.0	 5.5	 19.0	 -8.0	 1.053858	 100.0	 1	 50.0	 38.0; % NG
	2516	 44.0	 5.5	 19.0	 -8.0	 1.053858	 100.0	 1	 50.0	 38.0; % NG
	2522	 10.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 20.0	 0.0; % NG
	2522	 18.425	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 36.85	 0.0; % NG
	2523	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.5	 0.0; % NG
	2523	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 15.0	 0.0; % PEL
	2525	 4.8	 0.135	 1.23	 -0.96	 1.0158755	 100.0	 1	 9.6	 0.0; % COW
	2538	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 5.66	 0.0; % NG
	2540	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 16.0	 0.0; % NG
	2548	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 18.85	 0.0; % PEL
	2548	 17.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 34.0	 0.0; % PEL
	2551	 8.0	 1.5	 12.0	 -9.0	 0.999999	 100.0	 1	 16.0	 0.0; % PEL
	2556	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 16.8	 0.0; % PEL
	2569	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 16.8	 0.0; % PEL
	2569	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 13.5	 0.0; % NG
	2574	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 11.5	 0.0; % NG
	2579	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % COW
	2579	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 20.7	 0.0; % PEL
	2585	 0.0	 0.0	 0.0	 0.0	 0.975	 100.0	 0	 4.6	 0.0; % NG
	2594	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 12.0	 0.0; % NG
	2594	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 9.0	 0.0; % NG
	2603	 11.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 22.0	 0.0; % PEL
	2604	 0.0	 -1.78	 1.0	 -2.0	 1.015872	 100.0	 0	 8.9	 0.0; % NG
	2609	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 11.05	 0.0; % NG
	2617	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 37.5	 0.0; % PEL
	2617	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 12.0	 0.0; % COW
	2620	 14.0	 4.5	 16.0	 -7.0	 1.0158755	 100.0	 1	 28.0	 0.0; % NG
	2633	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 5.0	 0.0; % COW
	2633	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	2633	 0.0	 1.0	 1.0	 0.0	 1.0000025	 100.0	 0	 5.0	 0.0; % NG
	2636	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 2.3	 0.0; % PEL
	2637	 9.0	 0.0	 10.0	 -10.0	 1.0000025	 100.0	 1	 18.0	 0.0; % PEL
	2638	 0.0	 1.77	 14.0	 -14.0	 1.0000025	 100.0	 0	 22.0	 0.0; % PEL
	2638	 11.0	 0.0	 14.0	 -14.0	 1.0000025	 100.0	 1	 22.0	 0.0; % PEL
	2638	 14.5	 -4.0	 8.0	 -16.0	 1.0000025	 100.0	 1	 29.0	 0.0; % NG
	2639	 0.0	 0.1	 0.1	 -0.1	 1.0074025	 100.0	 0	 1.0	 0.0; % PEL
	2639	 0.0	 0.9	 6.0	 -6.0	 1.0074025	 100.0	 0	 10.0	 0.0; % NG
	2639	 0.0	 0.9	 5.0	 -5.0	 1.0074025	 100.0	 0	 9.0	 0.0; % PEL
	2642	 17.5	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 35.0	 0.0; % NG
	2642	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 24.0	 0.0; % PEL
	2645	 14.0	 3.95	 4.0	 3.9	 1.0000025	 100.0	 1	 28.0	 0.0; % NG
	2652	 0.0	 -0.15	 1.7	 -1.7	 0.999999	 100.0	 0	 2.6	 0.0; % PEL
	2652	 4.9	 0.0	 6.0	 -6.0	 0.999999	 100.0	 1	 9.8	 0.0; % PEL
	2653	 17.5	 -1.5	 12.0	 -15.0	 1.015872	 100.0	 1	 35.0	 0.0; % NG
	2653	 17.5	 -1.5	 12.0	 -15.0	 1.015872	 100.0	 1	 35.0	 0.0; % PEL
	2656	 0.0	 1.0	 1.0	 0.0	 0.975	 100.0	 0	 11.0	 0.0; % NG
	2657	 3.5	 0.95	 1.0	 0.9	 0.975	 100.0	 1	 7.0	 0.0; % NG
	2656	 0.0	 0.1	 0.1	 -0.1	 0.975	 100.0	 0	 3.0	 0.0; % PEL
	2655	 0.0	 -2.84	 4.0	 -7.0	 0.975	 100.0	 0	 12.0	 0.0; % NG
	2657	 0.0	 0.1	 0.1	 -0.1	 0.975	 100.0	 0	 4.0	 0.0; % NG
	2658	 6.0	 -1.37	 4.26	 -7.0	 1.0000025	 100.0	 1	 12.0	 0.0; % NG
	2662	 0.0	 2.35	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	2662	 0.0	 2.35	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	2662	 0.0	 2.35	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	2662	 0.0	 2.0	 2.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % COW
	2662	 0.0	 2.35	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	2667	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 6.15	 0.0; % PEL
	2681	 18.2	 0.0	 0.0	 0.0	 1.033333	 100.0	 1	 36.4	 0.0; % PEL
	2688	 7.5	 -0.5	 6.0	 -7.0	 1.0000005	 100.0	 1	 15.0	 0.0; % PEL
	2722	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 21.8	 0.0; % NG
	2727	 8.5	 0.0	 10.0	 -10.0	 1.000001	 100.0	 1	 17.0	 0.0; % NG
	2727	 8.5	 0.0	 10.0	 -10.0	 1.000001	 100.0	 1	 17.0	 0.0; % PEL
	2759	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 26.5	 0.0; % NG
	2769	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 14.0	 0.0; % NG
	2805	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.0	 0.0; % PEL
	2806	 8.075	 0.0	 0.0	 0.0	 0.984126	 100.0	 1	 16.15	 0.0; % PEL
	2811	 0.0	 0.78	 8.0	 -8.0	 1.0000025	 100.0	 0	 20.0	 0.0; % PEL
	2815	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % PEL
	2826	 6.0	 1.5	 5.0	 -2.0	 1.0000005	 100.0	 1	 12.0	 0.0; % NG
	2831	 0.0	 -1.5	 4.63	 -5.56	 1.033334	 100.0	 0	 13.8	 0.0; % PEL
	2833	 10.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 20.0	 0.0; % NG
	2833	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % PEL
	2836	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	2836	 16.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 32.0	 0.0; % NG
	2838	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 2.0	 0.0; % PEL
	2838	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 12.0	 0.0; % PEL
	2850	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 17.6	 0.0; % PEL
	2861	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.0	 0.0; % NG
	2867	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 13.8	 0.0; % PEL
	2869	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 14.8	 0.0; % COW
	2869	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 2.4	 0.0; % PEL
	2877	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 8.2	 0.0; % PEL
	2892	 0.0	 0.0	 9.0	 -9.0	 0.975	 100.0	 0	 26.5	 6.0; % NG
	2892	 16.25	 0.0	 9.0	 -9.0	 0.975	 100.0	 1	 26.5	 6.0; % COW
	2892	 0.0	 0.0	 8.0	 -8.0	 0.975	 100.0	 0	 22.9	 6.0; % PEL
	2897	 0.0	 1.0	 1.0	 0.0	 1.0	 100.0	 0	 14.0	 0.0; % COW
	2897	 0.0	 1.0	 1.0	 0.0	 1.0	 100.0	 0	 12.0	 -10.0; % COW
	2897	 0.0	 1.0	 1.0	 0.0	 1.0	 100.0	 0	 12.0	 -10.0; % NG
	2901	 0.0	 -3.16	 5.43	 -5.43	 1.0000025	 100.0	 0	 16.3	 0.0; % PEL
	2921	 0.0	 -0.41	 3.0	 -3.0	 0.999999	 100.0	 0	 6.0	 0.0; % COW
	2922	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 8.0	 0.0; % COW
	2934	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 34.5	 0.0; % PEL
	2941	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 8.0	 0.0; % COW
	2947	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 18.0	 0.0; % PEL
	2947	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	2968	 0.0	 -0.57	 0.47	 -1.3	 1.0158755	 100.0	 0	 4.7	 0.0; % PEL
	2975	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 8.2	 0.0; % PEL
	2986	 17.0	 0.0	 17.0	 -17.0	 0.999999	 100.0	 1	 34.0	 0.0; % NG
	3013	 0.0	 0.05	 1.7	 -1.7	 1.0158755	 100.0	 0	 17.0	 0.0; % NG
	3013	 0.0	 0.05	 1.7	 -1.7	 1.0158755	 100.0	 0	 17.0	 0.0; % PEL
	3014	 0.0	 3.28	 3.6	 -3.0	 0.999999	 100.0	 0	 5.0	 0.0; % COW
	3015	 0.0	 -0.25	 8.0	 -8.0	 1.002359	 100.0	 0	 13.0	 0.0; % NG
	3015	 6.5	 0.0	 8.0	 -8.0	 1.002359	 100.0	 1	 13.0	 0.0; % NG
	3017	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 18.4	 0.0; % NG
	3020	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 2.4	 0.0; % PEL
	3020	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	3022	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 11.5	 0.0; % NG
	3029	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 6.9	 0.0; % PEL
	3031	 0.0	 0.0	 0.0	 0.0	 1.044445	 100.0	 0	 55.4	 0.0; % NG
	3042	 8.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 16.0	 0.0; % NG
	3052	 0.0	 0.93	 9.0	 -9.0	 0.999999	 100.0	 0	 15.8	 0.0; % COW
	3053	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 2.0	 0.0; % PEL
	3063	 8.625	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 17.25	 0.0; % PEL
	3091	 9.75	 -2.5	 5.0	 -10.0	 0.9444445	 100.0	 1	 19.5	 0.0; % NG
	3100	 0.0	 4.11	 12.0	 0.0	 0.999999	 100.0	 0	 9.0	 0.0; % COW
	3103	 0.0	 0.0	 0.0	 0.0	 1.0377785	 100.0	 0	 54.0	 0.0; % NG
	3106	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 11.1	 0.0; % NG
	3109	 19.0	 0.5	 20.0	 -19.0	 0.975	 100.0	 1	 38.0	 0.0; % NG
	3110	 19.0	 0.5	 20.0	 -19.0	 0.975	 100.0	 1	 38.0	 0.0; % COW
	3111	 19.0	 0.0	 20.0	 -20.0	 0.975	 100.0	 1	 38.0	 0.0; % COW
	3115	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 4.25	 0.0; % NG
	3116	 0.0	 1.1	 10.0	 -10.0	 0.999999	 100.0	 0	 16.8	 0.0; % NG
	3116	 0.0	 1.1	 17.3	 -17.3	 0.999999	 100.0	 0	 16.0	 0.0; % NG
	3118	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 20.8	 0.0; % NG
	3119	 0.0	 1.93	 6.0	 -6.0	 1.0000025	 100.0	 0	 8.0	 0.0; % PEL
	3124	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 7.2	 0.0; % COW
	3125	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	3125	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 18.0	 0.0; % NG
	3129	 5.5	 0.95	 1.0	 0.9	 1.000001	 100.0	 1	 11.0	 0.0; % NG
	3129	 7.0	 0.0	 0.1	 -0.1	 1.000001	 100.0	 1	 14.0	 0.0; % COW
	3133	 0.0	 0.0	 0.0	 0.0	 1.0377785	 100.0	 0	 8.0	 0.0; % COW
	3133	 0.0	 0.0	 0.0	 0.0	 1.0377785	 100.0	 0	 8.0	 0.0; % COW
	3135	 0.0	 0.5	 0.5	 -0.5	 1.0000025	 100.0	 0	 1.5	 0.0; % PEL
	3140	 5.25	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 10.5	 0.0; % NG
	3140	 4.3	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 8.6	 0.0; % NG
	3144	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % COW
	3150	 26.5	 6.0	 22.0	 -10.0	 1.0111115	 100.0	 1	 48.0	 5.0; % PEL
	3152	 8.0	 0.95	 1.0	 0.9	 1.000001	 100.0	 1	 16.0	 0.0; % COW
	3152	 8.0	 0.95	 1.0	 0.9	 1.000001	 100.0	 1	 16.0	 0.0; % PEL
	3152	 9.0	 0.0	 12.0	 -12.0	 1.000001	 100.0	 1	 18.0	 0.0; % PEL
	3171	 0.0	 1.46	 10.0	 -3.0	 1.0	 100.0	 0	 27.0	 0.0; % COW
	3171	 0.0	 1.46	 10.0	 -3.0	 1.0	 100.0	 0	 27.0	 0.0; % NG
	3178	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 10.0	 0.0; % NG
	3178	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 12.0	 0.0; % NG
	3181	 9.0	 0.0	 0.0	 0.0	 1.006729	 100.0	 1	 18.0	 0.0; % NG
	3181	 0.0	 0.0	 0.0	 0.0	 1.006729	 100.0	 0	 10.0	 0.0; % NG
	3203	 10.0	 1.0	 2.0	 0.0	 1.0	 100.0	 1	 20.0	 0.0; % NG
	3212	 11.3	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 22.6	 0.0; % PEL
	3212	 6.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 12.0	 0.0; % NG
	3231	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 22.3	 0.0; % PEL
	3232	 11.0	 1.95	 2.0	 1.9	 1.000001	 100.0	 1	 22.0	 0.0; % NG
	3234	 0.0	 -0.42	 3.0	 -3.0	 0.999999	 100.0	 0	 5.2	 0.0; % NG
	3237	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 9.2	 0.0; % COW
	3239	 5.0	 0.0	 4.0	 -4.0	 1.0000025	 100.0	 1	 10.0	 0.0; % NG
	3243	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.8	 0.0; % NG
	3253	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 7.5	 0.0; % NG
	3257	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	3258	 18.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 36.0	 0.0; % NG
	3258	 16.35	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 32.7	 0.0; % PEL
	3258	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	3259	 21.0	 2.5	 25.0	 -20.0	 1.0	 100.0	 1	 42.0	 0.0; % NG
	3259	 21.0	 2.5	 25.0	 -20.0	 1.0	 100.0	 1	 42.0	 0.0; % NG
	3269	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % PEL
	3269	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % NG
	3273	 18.05	 2.5	 20.0	 -15.0	 0.975	 100.0	 1	 36.1	 0.0; % NG
	3274	 18.05	 2.5	 20.0	 -15.0	 0.975	 100.0	 1	 36.1	 0.0; % NG
	3275	 18.05	 2.5	 20.0	 -15.0	 0.975	 100.0	 1	 36.1	 0.0; % PEL
	3288	 0.0	 1.42	 8.5	 -8.5	 0.999999	 100.0	 0	 11.4	 0.0; % NG
	3294	 6.5	 0.0	 5.0	 -5.0	 1.021232	 100.0	 1	 13.0	 0.0; % NG
	3301	 8.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 17.0	 0.0; % PEL
	3301	 8.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 17.0	 0.0; % NG
	3306	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 18.0	 0.0; % PEL
	3306	 5.1	 0.0	 0.0	 0.0	 0.999999	 100.0	 1	 10.2	 0.0; % NG
	3308	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % COW
	3308	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 19.4	 0.0; % NG
	3332	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	3338	 0.0	 0.0	 24.0	 -24.0	 0.999999	 100.0	 0	 51.0	 0.8; % PEL
	3370	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 8.0	 0.0; % NG
	3370	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 20.0	 0.0; % PEL
	3375	 19.9	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 39.8	 0.0; % PEL
	3376	 0.0	 0.0	 0.0	 0.0	 1.0027125	 100.0	 0	 15.0	 0.0; % COW
	3398	 21.5	 6.0	 22.0	 -10.0	 1.0158755	 100.0	 1	 43.0	 0.0; % NG
	3401	 12.0	 -0.26	 7.0	 -7.52	 1.004029	 100.0	 1	 24.0	 0.0; % PEL
	3411	 0.0	 1.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 7.5	 0.0; % NG
	3411	 3.75	 0.0	 1.0	 -1.0	 1.0000025	 100.0	 1	 7.5	 0.0; % PEL
	3411	 0.0	 1.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 7.5	 0.0; % PEL
	3411	 3.75	 0.0	 1.0	 -1.0	 1.0000025	 100.0	 1	 7.5	 0.0; % PEL
	3411	 0.0	 1.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 7.5	 0.0; % PEL
	3416	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 35.0	 0.0; % PEL
	3416	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 36.0	 0.0; % NG
	3417	 11.55	 0.0	 14.0	 -14.0	 0.999999	 100.0	 1	 23.1	 0.0; % PEL
	3417	 11.55	 0.0	 14.0	 -14.0	 0.999999	 100.0	 1	 23.1	 0.0; % PEL
	3424	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 3.0	 0.0; % PEL
	3427	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 20.0	 0.0; % NG
	3430	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 24.0	 0.0; % PEL
	3433	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 12.0	 0.0; % PEL
	3433	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 10.5	 0.0; % PEL
	3438	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 1.7	 0.0; % PEL
	3443	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 20.55	 0.0; % PEL
	3444	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 6.0	 0.0; % NG
	3447	 0.0	 0.0	 0.0	 0.0	 1.027804	 100.0	 0	 12.0	 0.0; % NG
	3454	 6.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 12.0	 0.0; % NG
	3461	 6.6	 0.0	 8.0	 -8.0	 0.999999	 100.0	 1	 13.2	 0.0; % NG
	3481	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 1.25	 0.0; % PEL
	3484	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 0.0	 -8.0; % SYNC
	3484	 26.5	 3.5	 17.0	 -10.0	 1.0	 100.0	 1	 53.0	 0.0; % PEL
	3488	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 21.2	 0.0; % NG
	3497	 17.5	 -0.585	 15.0	 -16.17	 1.044445	 100.0	 1	 35.0	 0.0; % COW
	3498	 0.0	 -0.34	 15.0	 -10.0	 0.975	 100.0	 0	 50.0	 0.0; % NG
	3500	 0.0	 1.55	 2.8	 -2.8	 0.999999	 100.0	 0	 4.8	 0.0; % NG
	3501	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 18.0	 0.0; % PEL
	3506	 24.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 48.0	 0.0; % NG
	3506	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 16.0	 0.0; % NG
	3514	 13.1	 0.0	 16.0	 -16.0	 0.999999	 100.0	 1	 26.2	 0.0; % PEL
	3523	 5.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 10.0	 0.0; % NG
	3537	 6.4	 0.0	 7.6	 -7.6	 0.999999	 100.0	 1	 12.8	 0.0; % PEL
	3538	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 12.0	 0.0; % PEL
	3543	 0.0	 0.3	 5.0	 -2.0	 1.0158755	 100.0	 0	 12.0	 0.0; % COW
	3543	 0.0	 0.3	 5.0	 -2.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	3543	 0.0	 0.3	 5.0	 -2.0	 1.0158755	 100.0	 0	 12.0	 0.0; % PEL
	3542	 0.0	 0.38	 22.0	 -10.0	 1.0402155	 100.0	 0	 43.0	 0.0; % NG
	3577	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 10.0	 0.0; % COW
	3580	 10.4	 -2.0	 6.0	 -10.0	 0.975	 100.0	 1	 20.0	 0.8; % PEL
	3580	 10.4	 0.0	 4.2	 -4.2	 0.975	 100.0	 1	 20.0	 0.8; % NG
	3579	 0.0	 0.0	 4.2	 -4.2	 0.975	 100.0	 0	 20.0	 0.8; % NG
	3579	 10.4	 0.0	 4.2	 -4.2	 0.975	 100.0	 1	 20.0	 0.8; % NG
	3593	 11.5	 0.5	 10.0	 -9.0	 1.000001	 100.0	 1	 23.0	 0.0; % PEL
	3593	 11.5	 0.5	 10.0	 -9.0	 1.000001	 100.0	 1	 23.0	 0.0; % NG
	3593	 11.5	 0.5	 10.0	 -9.0	 1.000001	 100.0	 1	 23.0	 0.0; % NG
	3597	 0.0	 10.0	 30.0	 -10.0	 0.999999	 100.0	 1	 40.0	 -40.0; % NG
	3597	 0.0	 0.0	 28.0	 -28.0	 0.999999	 100.0	 1	 50.0	 -50.0; % NG
	3629	 0.0	 0.28	 3.0	 -1.0	 1.006809	 100.0	 0	 2.0	 0.0; % PEL
	3639	 7.445	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 14.89	 0.0; % COW
	3639	 17.385	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 34.77	 0.0; % NG
	3642	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	3644	 3.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 7.0	 0.0; % COW
	3644	 3.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 7.0	 0.0; % COW
	3645	 0.0	 -4.68	 12.0	 -12.0	 1.0158755	 100.0	 0	 12.0	 0.0; % PEL
	3650	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % PEL
	3653	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % NG
	3654	 0.0	 1.0	 1.0	 -1.0	 1.0079355	 100.0	 0	 3.0	 0.0; % NG
	3659	 6.0	 0.0	 7.0	 -7.0	 0.999999	 100.0	 1	 12.0	 0.0; % NG
	3659	 6.0	 0.0	 7.0	 -7.0	 0.999999	 100.0	 1	 12.0	 0.0; % COW
	3660	 0.0	 -1.18	 3.0	 -3.0	 0.999999	 100.0	 0	 4.5	 0.0; % NG
	3676	 0.0	 0.44	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % NG
	3678	 0.0	 -0.05	 1.8	 -1.8	 0.999999	 100.0	 0	 3.0	 0.0; % NG
	3684	 4.75	 0.0	 6.0	 -6.0	 0.999999	 100.0	 1	 9.5	 0.0; % PEL
	3686	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 8.0	 0.0; % NG
	3688	 0.0	 0.95	 5.6	 -5.6	 0.999999	 100.0	 0	 8.8	 0.0; % NG
	3705	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 24.0	 0.0; % PEL
	3707	 9.0	 0.0	 8.0	 -8.0	 1.027779	 100.0	 1	 18.0	 0.0; % PEL
	3708	 0.0	 -1.18	 17.0	 -11.0	 0.999999	 100.0	 0	 19.0	 0.0; % NG
	3709	 22.0	 0.0	 17.0	 -17.0	 0.999999	 100.0	 1	 44.0	 0.0; % NG
	3736	 0.0	 -0.28	 6.0	 -7.0	 0.999999	 100.0	 0	 9.0	 0.0; % NG
	3740	 8.4	 0.25	 4.6	 -4.1	 0.999999	 100.0	 1	 11.2	 5.6; % NG
	3745	 21.5	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 43.0	 0.0; % NG
	3750	 5.0	 0.0	 0.0	 0.0	 0.984126	 100.0	 1	 10.0	 0.0; % PEL
	3750	 10.0	 0.0	 0.0	 0.0	 0.984126	 100.0	 1	 20.0	 0.0; % PEL
	3752	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 22.05	 0.0; % NG
	3753	 6.0	 0.0	 1.2	 -1.2	 1.0158755	 100.0	 1	 12.0	 0.0; % NG
	3788	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	3788	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	3791	 13.125	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 26.25	 0.0; % NG
	3791	 10.125	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 20.25	 0.0; % PEL
	3791	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	3793	 10.01	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 20.02	 0.0; % PEL
	3793	 10.175	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 20.35	 0.0; % NG
	3808	 18.9	 2.0	 12.0	 -8.0	 0.975	 100.0	 1	 37.8	 0.0; % PEL
	3809	 18.9	 2.0	 12.0	 -8.0	 0.975	 100.0	 1	 37.8	 0.0; % PEL
	3810	 18.9	 2.0	 12.0	 -8.0	 0.975	 100.0	 1	 37.8	 0.0; % NG
	3814	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 27.2	 0.0; % PEL
	3818	 15.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 30.0	 0.0; % NG
	3828	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 9.1	 0.0; % NG
	3834	 6.0	 0.0	 7.2	 -7.2	 0.999999	 100.0	 1	 12.0	 0.0; % NG
	3834	 6.5	 0.0	 7.8	 -7.8	 0.999999	 100.0	 1	 13.0	 0.0; % NG
	3845	 11.0	 1.0	 6.0	 -4.0	 1.0000025	 100.0	 1	 22.0	 0.0; % PEL
	3855	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 6.68	 0.0; % NG
	3860	 4.5	 0.0	 3.0	 -3.0	 1.022224	 100.0	 1	 9.0	 0.0; % NG
	3861	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	3868	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 8.0	 0.0; % NG
	3881	 0.0	 0.0	 0.0	 0.0	 1.0277795	 100.0	 0	 12.0	 0.0; % COW
	3885	 0.0	 1.0	 1.0	 -1.0	 1.0079355	 100.0	 0	 2.0	 0.0; % NG
	3885	 0.0	 1.0	 1.0	 -1.0	 1.0079355	 100.0	 0	 2.0	 0.0; % PEL
	3896	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 13.2	 0.0; % NG
	3896	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 18.0	 0.0; % NG
	3911	 0.0	 2.05	 5.0	 -4.5	 1.0000025	 100.0	 0	 7.0	 0.0; % PEL
	3916	 0.0	 0.0	 0.0	 0.0	 1.015874	 100.0	 0	 32.0	 0.0; % COW
	3917	 27.5	 0.0	 0.0	 0.0	 1.026667	 100.0	 1	 55.0	 0.0; % NG
	3919	 0.0	 0.81	 2.0	 -3.0	 1.015872	 100.0	 0	 7.0	 0.0; % NG
	3931	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 17.2	 0.0; % NG
	3932	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 11.69	 0.0; % NG
	3943	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 36.0	 0.0; % PEL
	3961	 20.5	 0.0	 6.0	 -6.0	 0.975	 100.0	 1	 40.0	 1.0; % NG
	3961	 20.5	 0.0	 6.0	 -6.0	 0.975	 100.0	 1	 40.0	 1.0; % PEL
	3960	 20.5	 -5.0	 5.0	 -15.0	 0.975	 100.0	 1	 40.0	 1.0; % COW
	3960	 20.5	 -5.0	 5.0	 -15.0	 0.975	 100.0	 1	 40.0	 1.0; % COW
	3969	 0.0	 0.1	 0.1	 -0.1	 1.000001	 100.0	 0	 2.2	 0.0; % NG
	3969	 0.0	 0.0	 4.0	 3.9	 1.000001	 100.0	 0	 12.0	 0.0; % COW
	3979	 0.0	 -0.08	 1.0	 -1.0	 1.015872	 100.0	 0	 2.0	 0.0; % PEL
	3979	 0.0	 1.92	 3.0	 -3.0	 1.015872	 100.0	 0	 8.0	 0.0; % COW
	3979	 4.0	 0.0	 3.0	 -3.0	 1.015872	 100.0	 1	 8.0	 0.0; % NG
	3990	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 12.0	 0.0; % COW
	3990	 12.4	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 24.8	 0.0; % NG
	3992	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 13.8	 0.0; % COW
	3992	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 22.7	 0.0; % PEL
	4017	 0.0	 0.26	 6.5	 -6.5	 0.999999	 100.0	 0	 10.6	 0.0; % PEL
	4021	 0.0	 0.91	 11.0	 -11.0	 0.9444445	 100.0	 0	 18.0	 0.0; % NG
	4023	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 30.4	 0.0; % PEL
	4023	 0.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 0	 16.0	 0.0; % COW
	4046	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 26.0	 0.0; % PEL
	4047	 13.5	 -2.5	 6.0	 -11.0	 1.015872	 100.0	 1	 27.0	 0.0; % PEL
	4047	 13.5	 -2.5	 6.0	 -11.0	 1.015872	 100.0	 1	 27.0	 0.0; % NG
	4057	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 17.1	 0.0; % NG
	4063	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 2.4	 0.0; % PEL
	4100	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % COW
	4117	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 6.9	 0.0; % NG
	4121	 6.15	 0.0	 5.0	 -5.0	 0.999999	 100.0	 1	 12.3	 0.0; % COW
	4121	 0.0	 -0.13	 5.0	 -5.0	 0.999999	 100.0	 0	 12.3	 0.0; % NG
	4121	 6.15	 0.0	 5.0	 -5.0	 0.999999	 100.0	 1	 12.3	 0.0; % NG
	4123	 0.0	 0.17	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % PEL
	4123	 0.0	 2.0	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % NG
	4161	 12.0	 0.0	 10.0	 -10.0	 1.0000025	 100.0	 1	 24.0	 0.0; % NG
	4190	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	4190	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 12.0	 0.0; % NG
	4209	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 12.0	 0.0; % NG
	4208	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % PEL
	4223	 6.5	 6.5	 13.0	 0.0	 0.999999	 100.0	 1	 13.0	 0.0; % PEL
	4227	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 16.4	 0.0; % COW
	4236	 21.0	 0.0	 42.0	 -42.0	 1.000001	 100.0	 1	 42.0	 0.0; % NG
	4237	 9.5	 0.16	 5.32	 -5.0	 1.015872	 100.0	 1	 19.0	 0.0; % PEL
	4252	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 15.5	 0.0; % PEL
	4252	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 25.7	 0.0; % NG
	4266	 6.0	 0.0	 5.0	 -5.0	 0.975	 100.0	 1	 12.0	 0.0; % NG
	4266	 6.0	 0.0	 5.0	 -5.0	 0.975	 100.0	 1	 12.0	 0.0; % COW
	4267	 0.0	 0.86	 5.0	 -5.0	 1.020497	 100.0	 0	 12.0	 0.0; % NG
	4267	 6.0	 0.0	 5.0	 -5.0	 1.020497	 100.0	 1	 12.0	 0.0; % PEL
	4285	 0.0	 -0.26	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % NG
	4291	 23.0	 -7.0	 20.0	 -34.0	 0.999999	 100.0	 1	 46.0	 0.0; % NG
	4292	 0.0	 2.01	 3.6	 -3.6	 0.999999	 100.0	 0	 6.0	 0.0; % PEL
	4293	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 1.74	 0.0; % PEL
	4297	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 8.1	 0.0; % COW
	4301	 0.0	 0.0	 0.0	 0.0	 1.004889	 100.0	 0	 13.8	 0.0; % NG
	4301	 0.0	 0.0	 0.0	 0.0	 1.004889	 100.0	 0	 15.0	 0.0; % NG
	4307	 22.0	 0.0	 25.0	 -25.0	 1.003079	 100.0	 1	 44.0	 0.0; % NG
	4311	 9.0	 0.0	 14.0	 -14.0	 1.000001	 100.0	 1	 18.0	 0.0; % PEL
	4312	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 4.0	 0.0; % NG
	4316	 0.0	 -0.02	 35.0	 -35.0	 1.0111115	 100.0	 0	 58.0	 0.0; % NG
	4318	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 11.0	 0.0; % NG
	4318	 0.0	 2.0	 2.0	 -2.0	 1.0079355	 100.0	 0	 6.0	 0.0; % PEL
	4319	 19.5	 0.0	 24.0	 -24.0	 0.999999	 100.0	 1	 39.0	 0.0; % NG
	4329	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % PEL
	4329	 16.5	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 33.0	 0.0; % PEL
	4337	 13.0	 1.95	 2.0	 1.9	 1.0000025	 100.0	 1	 26.0	 0.0; % PEL
	4344	 0.0	 0.0	 1.0	 0.9	 1.0000025	 100.0	 0	 11.0	 0.0; % NG
	4363	 7.5	 2.95	 3.0	 2.9	 1.000001	 100.0	 1	 15.0	 0.0; % PEL
	4363	 0.0	 0.1	 0.1	 -0.1	 1.000001	 100.0	 0	 2.0	 0.0; % PEL
	4368	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 4.0	 0.0; % NG
	4371	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 16.0	 0.0; % NG
	4376	 0.0	 0.61	 1.0	 -1.0	 1.015872	 100.0	 0	 2.0	 0.0; % PEL
	4376	 0.0	 0.61	 1.0	 -1.0	 1.015872	 100.0	 0	 2.0	 0.0; % PEL
	4376	 0.0	 0.61	 2.0	 -2.0	 1.015872	 100.0	 0	 5.0	 0.0; % NG
	4385	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 13.6	 0.0; % NG
	4405	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 2.6	 0.0; % PEL
	4405	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 17.9	 0.0; % NG
	4406	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 6.0	 0.0; % NG
	4406	 0.0	 0.0	 0.0	 0.0	 1.0079355	 100.0	 0	 10.25	 0.0; % PEL
	4407	 0.0	 1.0	 1.0	 -1.0	 1.015872	 100.0	 0	 3.0	 0.0; % PEL
	4423	 3.0	 0.0	 2.0	 -2.0	 1.0000025	 100.0	 1	 6.0	 0.0; % NG
	4441	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 12.0	 0.0; % NG
	4441	 0.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 0	 4.0	 0.0; % PEL
	4443	 13.0	 -0.5	 16.0	 -17.0	 1.0233335	 100.0	 1	 26.0	 0.0; % PEL
	4443	 13.0	 -0.5	 16.0	 -17.0	 1.0233335	 100.0	 1	 26.0	 0.0; % COW
	4447	 14.95	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 29.9	 0.0; % PEL
	4448	 6.85	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 13.7	 0.0; % NG
	4467	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 10.0	 0.0; % NG
	4469	 0.0	 1.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 50.0	 0.0; % NG
	4470	 11.85	 0.055	 2.11	 -2.0	 0.975	 100.0	 1	 23.7	 0.0; % NG
	4471	 11.85	 2.0	 7.0	 -3.0	 0.975	 100.0	 1	 23.7	 0.0; % NG
	4472	 11.85	 2.0	 7.0	 -3.0	 0.975	 100.0	 1	 23.7	 0.0; % PEL
	4473	 11.85	 2.0	 7.0	 -3.0	 0.975	 100.0	 1	 23.7	 0.0; % PEL
	4474	 11.85	 2.0	 7.0	 -3.0	 0.975	 100.0	 1	 23.7	 0.0; % PEL
	4487	 0.0	 1.56	 15.0	 -15.0	 1.0158755	 100.0	 0	 21.4	 0.0; % PEL
	4500	 0.0	 0.06	 16.0	 -14.0	 1.015872	 100.0	 0	 31.0	 0.0; % PEL
	4503	 10.5	 1.1	 6.7	 -4.5	 0.975	 100.0	 1	 21.0	 0.0; % PEL
	4503	 10.5	 1.0	 6.0	 -4.0	 0.975	 100.0	 1	 21.0	 0.0; % NG
	4507	 43.5	 -0.38	 26.1	 -26.86	 1.044445	 100.0	 1	 87.0	 0.0; % NG
	4516	 11.0	 0.0	 10.0	 -10.0	 1.006624	 100.0	 1	 22.0	 0.0; % PEL
	4516	 11.0	 1.0	 12.0	 -10.0	 1.006624	 100.0	 1	 22.0	 0.0; % COW
	4530	 0.0	 1.79	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	4530	 0.0	 1.79	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	4530	 0.0	 1.79	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	4530	 0.0	 1.79	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % NG
	4530	 0.0	 1.79	 20.0	 -10.0	 0.825	 100.0	 0	 45.0	 0.0; % PEL
	4559	 11.0	 0.0	 7.1	 -7.1	 1.0000025	 100.0	 1	 22.0	 0.0; % PEL
	4563	 0.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 0	 11.7	 0.0; % NG
	4566	 44.5	 9.0	 27.0	 -9.0	 1.0377785	 100.0	 1	 45.0	 44.0; % NG
	4566	 44.5	 9.0	 27.0	 -9.0	 1.0377785	 100.0	 1	 45.0	 44.0; % NG
	4574	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	4575	 0.0	 1.55	 10.0	 -10.0	 0.999999	 100.0	 0	 16.8	 0.0; % NG
	4577	 0.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 0	 6.0	 0.0; % NG
	4580	 6.35	 0.0	 5.0	 -5.0	 1.0000025	 100.0	 1	 12.7	 0.0; % NG
	4580	 6.35	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 12.7	 0.0; % NG
	4615	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 36.8	 0.0; % PEL
	4626	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 8.0	 0.0; % COW
	4627	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 6.0	 0.0; % NG
	4628	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 4.0	 0.0; % NG
	4637	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 31.5	 0.0; % NG
	4638	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 33.0	 0.0; % PEL
	4643	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 17.5	 0.0; % COW
	4649	 0.0	 -0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 9.0	 0.0; % NG
	4653	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 11.5	 0.0; % NG
	4654	 17.5	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 35.0	 0.0; % PEL
	4661	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % PEL
	4661	 11.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 22.0	 0.0; % NG
	4666	 0.0	 0.1	 0.1	 -0.1	 0.975	 100.0	 0	 3.0	 0.0; % PEL
	4666	 0.0	 0.1	 0.1	 -0.1	 0.975	 100.0	 0	 1.0	 0.0; % PEL
	4666	 0.0	 0.1	 0.1	 -0.1	 0.975	 100.0	 0	 5.0	 0.0; % PEL
	4666	 3.5	 0.0	 0.1	 -0.1	 0.975	 100.0	 1	 7.0	 0.0; % NG
	4666	 0.0	 0.1	 0.1	 -0.1	 0.975	 100.0	 0	 3.0	 0.0; % PEL
	4678	 0.0	 0.0	 0.0	 0.0	 1.000001	 100.0	 0	 14.0	 0.0; % COW
	4693	 0.0	 0.57	 1.0	 -1.0	 1.015872	 100.0	 0	 1.0	 0.0; % PEL
	4693	 0.0	 0.57	 1.0	 -1.0	 1.015872	 100.0	 0	 1.0	 0.0; % PEL
	4693	 0.0	 0.57	 1.0	 -1.0	 1.015872	 100.0	 0	 1.0	 0.0; % PEL
	4710	 5.75	 0.0	 1.0	 -1.0	 1.0000025	 100.0	 1	 11.5	 0.0; % NG
	4710	 0.0	 1.0	 1.0	 -1.0	 1.0000025	 100.0	 0	 11.5	 0.0; % NG
	4711	 0.0	 1.0	 1.0	 0.0	 1.0	 100.0	 0	 11.0	 0.0; % NG
	4711	 0.0	 0.1	 0.1	 -0.1	 1.0	 100.0	 0	 2.5	 0.0; % PEL
	4712	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % NG
	4713	 5.0	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 10.0	 0.0; % NG
	4713	 7.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 15.0	 0.0; % PEL
	4713	 7.5	 0.95	 1.0	 0.9	 1.0000025	 100.0	 1	 15.0	 0.0; % PEL
	4749	 0.0	 0.1	 0.1	 -0.1	 1.0000025	 100.0	 0	 9.0	 0.0; % COW
	4750	 5.0	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 10.0	 0.0; % PEL
	4750	 5.0	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 10.0	 0.0; % NG
	4751	 5.0	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 10.0	 0.0; % NG
	4751	 5.0	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 10.0	 0.0; % PEL
	4760	 15.0	 0.0	 10.0	 -10.0	 1.0233335	 100.0	 1	 30.0	 0.0; % NG
	4763	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 3.3	 0.0; % PEL
	4770	 0.0	 1.0	 1.0	 0.0	 1.0000025	 100.0	 0	 7.0	 0.0; % NG
	4775	 0.0	 0.0	 0.0	 0.0	 1.0000005	 100.0	 0	 28.0	 0.0; % NG
	4781	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 9.2	 0.0; % COW
	4786	 0.0	 -4.95	 8.5	 -8.5	 0.999999	 100.0	 0	 14.0	 0.0; % NG
	4797	 13.5	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 27.0	 0.0; % NG
	4807	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 20.0	 0.0; % PEL
	4810	 3.2	 0.0	 0.64	 -0.64	 1.0158755	 100.0	 1	 6.4	 0.0; % NG
	4811	 8.0	 -0.45	 3.6	 -4.5	 0.975	 100.0	 1	 15.0	 1.0; % COW
	4811	 7.5	 -0.5	 3.0	 -4.0	 0.975	 100.0	 1	 15.0	 0.0; % COW
	4812	 7.5	 -0.5	 3.0	 -4.0	 0.975	 100.0	 1	 15.0	 0.0; % NG
	4812	 8.0	 -0.45	 3.6	 -4.5	 0.975	 100.0	 1	 15.0	 1.0; % COW
	4818	 0.0	 0.14	 70.0	 -70.0	 0.975	 100.0	 0	 150.0	 0.0; % NG
	4820	 0.0	 0.12	 70.0	 -80.0	 0.975	 100.0	 0	 170.0	 -170.0; % NG
	4820	 0.0	 -5.0	 70.0	 -80.0	 0.975	 100.0	 1	 170.0	 -170.0; % NG
	4817	 0.0	 -5.0	 70.0	 -80.0	 0.975	 100.0	 1	 170.0	 -170.0; % NG
	4817	 0.0	 -5.0	 70.0	 -80.0	 0.975	 100.0	 1	 170.0	 -170.0; % NG
	4819	 75.0	 0.0	 70.0	 -70.0	 0.975	 100.0	 1	 150.0	 0.0; % COW
	4819	 75.0	 0.0	 70.0	 -70.0	 0.975	 100.0	 1	 150.0	 0.0; % NG
	4818	 75.0	 0.0	 70.0	 -70.0	 0.975	 100.0	 1	 150.0	 0.0; % NG
	4827	 0.0	 0.0	 0.0	 0.0	 0.984126	 100.0	 0	 34.0	 0.0; % NG
	4827	 0.0	 0.0	 0.0	 0.0	 0.984126	 100.0	 0	 24.0	 0.0; % NG
	4838	 0.0	 0.28	 5.5	 -5.5	 1.006809	 100.0	 0	 9.0	 0.0; % NG
	4846	 0.0	 1.82	 4.0	 -4.0	 0.9444445	 100.0	 0	 6.4	 0.0; % NG
	4846	 0.0	 1.82	 6.4	 -6.4	 0.9444445	 100.0	 0	 10.8	 0.0; % NG
	4859	 0.0	 0.09	 6.8	 -6.8	 0.999999	 100.0	 0	 11.2	 0.0; % NG
	4859	 0.0	 6.03	 6.8	 -6.8	 0.999999	 100.0	 0	 11.2	 0.0; % PEL
	4866	 0.0	 -0.86	 7.0	 -12.0	 1.033334	 100.0	 0	 22.0	 0.0; % PEL
	4873	 6.4	 0.0	 7.7	 -7.7	 0.999999	 100.0	 1	 12.8	 0.0; % PEL
	4877	 17.51	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 35.02	 0.0; % PEL
	4877	 10.0	 0.0	 0.0	 0.0	 1.0111115	 100.0	 1	 20.0	 0.0; % NG
	4889	 0.0	 -0.0	 0.0	 -1.0	 1.0158755	 100.0	 0	 5.0	 0.0; % NG
	4893	 8.05	 0.0	 9.8	 -9.8	 0.999999	 100.0	 1	 15.9	 0.2; % PEL
	4895	 10.8	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 21.6	 0.0; % NG
	4895	 10.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 20.0	 0.0; % NG
	4895	 15.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 30.0	 0.0; % NG
	4915	 16.0	 2.0	 12.0	 -8.0	 1.015872	 100.0	 1	 32.0	 0.0; % PEL
	4918	 16.5	 0.0	 12.0	 -12.0	 1.0000025	 100.0	 1	 33.0	 0.0; % PEL
	4925	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 20.0	 0.0; % NG
	4941	 4.8	 0.0	 6.0	 -6.0	 0.9444445	 100.0	 1	 9.6	 0.0; % NG
	4945	 0.0	 0.0	 0.0	 0.0	 1.027779	 100.0	 0	 4.0	 0.0; % NG
	4956	 11.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 22.0	 0.0; % PEL
	4956	 12.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 1	 24.0	 0.0; % NG
	4963	 0.0	 0.44	 18.0	 -18.0	 0.999999	 100.0	 0	 30.0	 0.0; % NG
	4963	 15.0	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 30.0	 0.0; % NG
	4976	 16.0	 -1.0	 16.0	 -18.0	 0.999999	 100.0	 1	 32.0	 0.0; % PEL
	4977	 17.55	 -4.5	 12.0	 -21.0	 0.975	 100.0	 1	 35.1	 0.0; % NG
	4978	 17.55	 -4.5	 12.0	 -21.0	 0.975	 100.0	 1	 35.1	 0.0; % NG
	4979	 17.55	 -4.5	 12.0	 -21.0	 0.975	 100.0	 1	 35.1	 0.0; % NG
	4986	 0.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 0	 10.0	 0.0; % NG
	4987	 15.25	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 30.5	 0.0; % NG
	5005	 6.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 12.0	 0.0; % NG
	5005	 10.0	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 20.0	 0.0; % PEL
	5007	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 20.7	 0.0; % PEL
	5013	 9.0	 0.0	 0.0	 0.0	 1.0158755	 100.0	 1	 18.0	 0.0; % PEL
	5017	 18.0	 3.95	 4.0	 3.9	 1.000001	 100.0	 1	 36.0	 0.0; % PEL
	5023	 25.3	 0.505	 15.18	 -14.17	 1.0000025	 100.0	 1	 50.6	 0.0; % NG
	5031	 0.0	 -4.31	 11.0	 -11.0	 0.999999	 100.0	 0	 18.0	 0.0; % PEL
	5032	 0.0	 0.0	 0.0	 0.0	 1.022224	 100.0	 0	 10.0	 0.0; % NG
	5034	 0.0	 1.77	 5.0	 -5.0	 1.0000025	 100.0	 0	 15.0	 0.0; % NG
	5034	 0.0	 -1.05	 5.0	 -5.0	 1.0000025	 100.0	 0	 15.0	 0.0; % PEL
	5036	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 24.0	 0.0; % PEL
	5036	 0.0	 0.0	 0.0	 0.0	 1.022222	 100.0	 0	 16.0	 0.0; % NG
	5040	 0.0	 0.0	 0.0	 0.0	 1.0277795	 100.0	 0	 36.0	 0.0; % NG
	5042	 0.0	 -0.0	 0.0	 -0.01	 1.0158755	 100.0	 0	 5.6	 0.0; % NG
	5042	 0.0	 -0.0	 0.0	 -0.01	 1.0158755	 100.0	 0	 5.6	 0.0; % COW
	5048	 0.0	 0.0	 0.0	 0.0	 1.033333	 100.0	 0	 3.0	 0.0; % PEL
	5948	 0.0	 3.12	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % NG
	5948	 0.0	 3.12	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % COW
	5948	 0.0	 3.12	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % NG
	5949	 0.0	 10.67	 125.0	 -125.0	 0.975	 100.0	 0	 670.0	 0.0; % COW
	5949	 0.0	 10.67	 125.0	 -125.0	 0.975	 100.0	 0	 670.0	 0.0; % COW
	5951	 0.0	 0.0	 100.0	 -100.0	 0.975	 100.0	 0	 250.0	 50.0; % COW
	5952	 700.0	 70.0	 470.0	 -330.0	 0.975	 100.0	 1	 1100.0	 300.0; % COW
	5952	 700.0	 70.0	 470.0	 -330.0	 0.975	 100.0	 1	 1100.0	 300.0; % COW
	5954	 0.0	 3.15	 60.0	 -60.0	 0.975	 100.0	 0	 200.0	 -20.0; % NG
	5955	 0.0	 -23.11	 60.0	 -60.0	 0.975	 100.0	 0	 200.0	 -20.0; % NG
	5957	 0.0	 0.0	 0.0	 0.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	5957	 0.0	 0.0	 0.0	 0.0	 0.975	 100.0	 0	 1500.0	 0.0; % NUC
	5958	 0.0	 -2.03	 0.22	 -2.03	 0.975	 100.0	 0	 0.75	 0.0; % PEL
	5958	 0.0	 -2.03	 0.22	 -2.03	 0.975	 100.0	 0	 0.75	 0.0; % PEL
	5962	 275.0	 -40.0	 300.0	 -380.0	 0.975	 100.0	 1	 500.0	 50.0; % NG
	5965	 42.265	 -4.03	 25.36	 -33.42	 0.975	 100.0	 1	 84.53	 0.0; % NG
	5965	 42.265	 -4.03	 25.36	 -33.42	 0.975	 100.0	 1	 84.53	 0.0; % COW
	5973	 0.0	 -1.08	 100.0	 -100.0	 0.975	 100.0	 0	 250.0	 -250.0; % NG
	5973	 0.0	 -1.08	 100.0	 -100.0	 0.975	 100.0	 0	 250.0	 -250.0; % NG
	5976	 0.0	 1.55	 40.0	 -40.0	 0.975	 100.0	 0	 30.0	 0.0; % NG
	5976	 0.0	 1.55	 40.0	 -40.0	 0.975	 100.0	 0	 60.0	 0.0; % NG
	5978	 225.0	 0.0	 200.0	 -200.0	 0.975	 100.0	 1	 450.0	 0.0; % COW
	5978	 225.0	 0.0	 200.0	 -200.0	 0.975	 100.0	 1	 450.0	 0.0; % COW
	5987	 0.0	 51.0	 51.0	 0.0	 0.975	 100.0	 0	 0.0	 -53.0; % SYNC
	5987	 0.0	 51.0	 51.0	 0.0	 0.975	 100.0	 0	 0.0	 -16.0; % SYNC
	5992	 0.0	 0.01	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % NUC
	5992	 0.0	 0.01	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % NG
	5992	 24.5	 0.0	 14.7	 -14.7	 0.975	 100.0	 1	 49.0	 0.0; % NG
	5992	 24.5	 0.0	 14.7	 -14.7	 0.975	 100.0	 1	 49.0	 0.0; % NG
	5992	 0.0	 0.01	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	5992	 0.0	 0.01	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	5993	 104.835	 0.0	 62.9	 -62.9	 0.975	 100.0	 1	 209.67	 0.0; % COW
	5993	 108.85	 0.0	 65.31	 -65.31	 0.975	 100.0	 1	 217.7	 0.0; % NG
	5993	 202.15	 0.0	 121.29	 -121.29	 0.975	 100.0	 1	 404.3	 0.0; % NG
	5996	 240.665	 0.0	 144.4	 -144.4	 0.975	 100.0	 1	 481.33	 0.0; % COW
	5999	 450.0	 0.0	 280.0	 -280.0	 0.975	 100.0	 1	 600.0	 300.0; % COW
	6000	 250.0	 0.0	 280.0	 -280.0	 0.975	 100.0	 1	 500.0	 0.0; % COW
	6004	 301.5	 66.5	 304.0	 -171.0	 0.975	 100.0	 1	 418.0	 185.0; % NG
	6004	 0.0	 0.0	 304.0	 -171.0	 0.975	 100.0	 0	 418.0	 185.0; % NG
	6004	 304.5	 66.5	 304.0	 -171.0	 0.975	 100.0	 1	 379.0	 230.0; % NG
	6004	 279.0	 98.0	 367.0	 -171.0	 0.975	 100.0	 1	 393.0	 165.0; % NG
	6012	 0.0	 0.02	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % NUC
	6011	 38.105	 -30.975	 22.86	 -84.81	 0.975	 100.0	 1	 76.21	 0.0; % PEL
	6013	 132.685	 0.0	 79.61	 -79.61	 0.975	 100.0	 1	 265.37	 0.0; % NG
	6016	 233.445	 -1.04	 140.07	 -142.15	 0.975	 100.0	 1	 466.89	 0.0; % NG
	6017	 0.0	 7.0	 7.0	 0.0	 0.975	 100.0	 0	 0.0	 -1.0; % SYNC
	6019	 653.0	 235.0	 570.0	 -100.0	 0.975	 100.0	 1	 1056.0	 250.0; % COW
	6019	 0.0	 0.0	 523.0	 -125.0	 0.975	 100.0	 0	 1056.0	 200.0; % COW
	6019	 304.0	 84.0	 263.0	 -95.0	 0.975	 100.0	 1	 412.0	 196.0; % NG
	6019	 304.0	 72.5	 240.0	 -95.0	 0.975	 100.0	 1	 412.0	 196.0; % NG
	6030	 350.0	 142.5	 400.0	 -115.0	 0.975	 100.0	 1	 600.0	 100.0; % NG
	6035	 0.0	 1.68	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % NG
	6039	 3.865	 -0.645	 2.32	 -3.61	 0.975	 100.0	 1	 7.73	 0.0; % NG
	6045	 253.0	 0.0	 151.8	 -151.8	 0.975	 100.0	 1	 506.0	 0.0; % COW
	6048	 537.725	 0.0	 322.63	 -322.63	 0.975	 100.0	 1	 1075.45	 0.0; % NUC
	6056	 675.0	 70.0	 355.0	 -215.0	 0.975	 100.0	 1	 1050.0	 300.0; % COW
	6056	 605.0	 70.0	 355.0	 -215.0	 0.975	 100.0	 1	 910.0	 300.0; % COW
	6056	 605.0	 70.0	 355.0	 -215.0	 0.975	 100.0	 1	 910.0	 300.0; % COW
	6059	 0.0	 1.72	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6060	 0.0	 0.35	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6073	 0.0	 1.72	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6074	 0.0	 0.14	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6078	 693.5	 0.0	 416.1	 -416.1	 0.975	 100.0	 1	 1387.0	 0.0; % COW
	6079	 0.0	 -3.8	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6080	 110.5	 4.35	 75.0	 -66.3	 0.975	 100.0	 1	 221.0	 0.0; % NG
	6082	 0.0	 0.08	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6083	 0.0	 49.99	 50.0	 0.0	 0.975	 100.0	 0	 0.0	 -1.0; % SYNC
	6082	 21.5	 -5.55	 12.9	 -24.0	 0.975	 100.0	 1	 43.0	 0.0; % NG
	6082	 5.0	 -10.5	 3.0	 -24.0	 0.975	 100.0	 1	 10.0	 0.0; % NG
	6085	 23.02	 28.935	 71.68	 -13.81	 0.975	 100.0	 1	 46.04	 0.0; % NG
	6084	 10.46	 4.495	 15.27	 -6.28	 0.975	 100.0	 1	 20.92	 0.0; % NG
	6093	 612.835	 0.0	 367.7	 -367.7	 0.975	 100.0	 1	 1225.67	 0.0; % COW
	6094	 225.0	 0.0	 200.0	 -200.0	 0.975	 100.0	 1	 450.0	 0.0; % COW
	6096	 0.0	 -66.95	 0.0	 -66.95	 0.975	 100.0	 0	 0.0	 -109.26; % SYNC
	6103	 96.0	 0.0	 57.6	 -57.6	 0.975	 100.0	 1	 192.0	 0.0; % NG
	6102	 94.5	 0.0	 56.7	 -56.7	 0.975	 100.0	 1	 189.0	 0.0; % NG
	6103	 94.5	 0.0	 56.7	 -56.7	 0.975	 100.0	 1	 189.0	 0.0; % NG
	6102	 0.0	 1.03	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6105	 0.0	 -0.2	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % PEL
	6105	 0.0	 64.8	 65.0	 0.0	 0.975	 100.0	 0	 0.0	 -2.0; % SYNC
	6107	 44.37	 9.085	 44.79	 -26.62	 0.975	 100.0	 1	 88.74	 0.0; % NG
	6116	 367.5	 0.0	 220.5	 -220.5	 0.975	 100.0	 1	 735.0	 0.0; % COW
	6120	 0.0	 -298.31	 300.0	 -300.0	 0.975	 100.0	 0	 0.0	 -1579.46; % SYNC
	6122	 3.055	 -2.4	 1.83	 -6.63	 0.975	 100.0	 1	 6.11	 0.0; % NG
	6123	 93.0	 0.0	 55.8	 -55.8	 0.975	 100.0	 1	 186.0	 0.0; % NG
	6123	 94.5	 0.0	 56.7	 -56.7	 0.975	 100.0	 1	 189.0	 0.0; % NG
	6124	 0.0	 -35.0	 182.0	 -252.0	 0.975	 100.0	 1	 280.0	 -280.0; % COW
	6124	 0.0	 -35.0	 182.0	 -252.0	 0.975	 100.0	 1	 280.0	 -280.0; % NG
	6124	 0.0	 -35.0	 182.0	 -252.0	 0.975	 100.0	 1	 280.0	 -280.0; % NG
	6124	 0.0	 -35.0	 182.0	 -252.0	 0.975	 100.0	 1	 280.0	 -280.0; % NG
	6129	 229.5	 0.0	 137.7	 -137.7	 0.975	 100.0	 1	 459.0	 0.0; % COW
	6129	 70.5	 7.75	 57.8	 -42.3	 0.975	 100.0	 1	 141.0	 0.0; % NG
	6129	 31.0	 19.6	 57.8	 -18.6	 0.975	 100.0	 1	 62.0	 0.0; % NG
	6129	 59.0	 11.2	 57.8	 -35.4	 0.975	 100.0	 1	 118.0	 0.0; % NG
	6129	 34.5	 18.55	 57.8	 -20.7	 0.975	 100.0	 1	 69.0	 0.0; % NG
	6136	 0.0	 0.01	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6147	 0.0	 -11.64	 0.0	 -11.64	 0.975	 100.0	 0	 0.0	 -66.03; % SYNC
	6147	 0.0	 -11.64	 0.0	 -11.64	 0.975	 100.0	 0	 0.0	 -66.03; % SYNC
	6148	 0.0	 1.7	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6150	 0.0	 0.02	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % NG
	6152	 211.31	 0.0	 126.79	 -126.79	 0.975	 100.0	 1	 422.62	 0.0; % NG
	6152	 88.715	 -7.845	 53.23	 -68.92	 0.975	 100.0	 1	 177.43	 0.0; % COW
	6155	 86.135	 0.0	 51.68	 -51.68	 0.975	 100.0	 1	 172.27	 0.0; % NG
	6155	 86.135	 0.0	 51.68	 -51.68	 0.975	 100.0	 1	 172.27	 0.0; % NG
	6162	 1449.42	 0.0	 869.65	 -869.65	 0.975	 100.0	 1	 2898.84	 0.0; % COW
	6163	 0.0	 -3.25	 0.0	 -3.25	 0.975	 100.0	 0	 0.0	 -16.81; % SYNC
	6164	 9.605	 5.315	 16.39	 -5.76	 0.975	 100.0	 1	 19.21	 0.0; % PEL
	6164	 9.605	 5.315	 16.39	 -5.76	 0.975	 100.0	 1	 19.21	 0.0; % NG
	6166	 0.0	 1.71	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6169	 0.0	 0.0	 343.0	 -169.0	 0.975	 100.0	 0	 396.0	 223.0; % NG
	6174	 135.0	 0.0	 200.0	 -200.0	 0.975	 100.0	 1	 300.0	 -30.0; % COW
	6178	 137.655	 0.0	 82.59	 -82.59	 0.975	 100.0	 1	 275.31	 0.0; % NG
	6178	 135.865	 0.0	 81.52	 -81.52	 0.975	 100.0	 1	 271.73	 0.0; % NG
	6179	 0.0	 10.55	 10.64	 0.0	 0.975	 100.0	 0	 0.0	 -7.68; % SYNC
	6183	 385.0	 0.0	 300.0	 -300.0	 0.975	 100.0	 1	 770.0	 0.0; % COW
	6183	 385.0	 0.0	 300.0	 -300.0	 0.975	 100.0	 1	 770.0	 0.0; % COW
	6184	 0.0	 69.64	 69.64	 0.0	 0.975	 100.0	 0	 0.0	 -422.3; % SYNC
	6184	 0.0	 69.64	 69.64	 0.0	 0.975	 100.0	 0	 0.0	 -422.3; % SYNC
	6184	 0.0	 69.64	 69.64	 0.0	 0.975	 100.0	 0	 0.0	 -422.3; % SYNC
	6185	 100.0	 0.0	 100.0	 -100.0	 0.975	 100.0	 1	 200.0	 0.0; % NG
	6186	 0.0	 -0.01	 450.0	 -450.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6186	 3.78	 -51.83	 2.27	 -105.93	 0.975	 100.0	 1	 7.56	 0.0; % NG
	6202	 0.0	 1.72	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % NUC
	6205	 0.0	 0.0	 355.0	 -215.0	 0.975	 100.0	 0	 910.0	 300.0; % COW
	6206	 0.0	 2.99	 99.0	 -99.0	 0.975	 100.0	 0	 330.0	 0.0; % COW
	6206	 0.0	 2.99	 99.0	 -99.0	 0.975	 100.0	 0	 330.0	 0.0; % NG
	6206	 0.0	 -0.18	 216.0	 -216.0	 0.975	 100.0	 0	 720.0	 0.0; % COW
	6208	 0.0	 -0.1	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % COW
	6208	 0.0	 35.86	 35.96	 0.0	 0.975	 100.0	 0	 0.0	 -331.79; % SYNC
	6208	 125.0	 0.0	 120.0	 -120.0	 0.975	 100.0	 1	 250.0	 0.0; % COW
	6208	 125.0	 0.0	 120.0	 -120.0	 0.975	 100.0	 1	 250.0	 0.0; % NG
	6208	 125.0	 0.0	 120.0	 -120.0	 0.975	 100.0	 1	 250.0	 0.0; % NG
	6208	 0.0	 -0.1	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % NG
	6208	 0.0	 -0.1	 120.0	 -120.0	 0.975	 100.0	 0	 250.0	 0.0; % NG
	6209	 328.0	 139.5	 400.0	 -121.0	 0.975	 100.0	 1	 656.0	 0.0; % COW
	6211	 36.05	 0.0	 21.63	 -21.63	 0.975	 100.0	 1	 72.1	 0.0; % COW
	6212	 700.0	 70.0	 470.0	 -330.0	 0.975	 100.0	 1	 1100.0	 300.0; % COW
	6216	 37.58	 0.0	 22.55	 -22.55	 0.975	 100.0	 1	 75.16	 0.0; % PEL
	6219	 0.0	 -2.45	 0.0	 -2.58	 0.975	 100.0	 0	 0.0	 -69.0; % SYNC
	6219	 0.0	 -2.45	 0.0	 -2.58	 0.975	 100.0	 0	 0.0	 -69.0; % SYNC
	6221	 58.445	 1.505	 38.08	 -35.07	 0.975	 100.0	 1	 116.89	 0.0; % COW
	6221	 58.445	 1.505	 38.08	 -35.07	 0.975	 100.0	 1	 116.89	 0.0; % NG
	6229	 181.29	 0.0	 108.77	 -108.77	 0.975	 100.0	 1	 362.58	 0.0; % COW
	6235	 0.0	 1.72	 300.0	 -300.0	 0.975	 100.0	 0	 1500.0	 0.0; % COW
	6237	 625.0	 -14.0	 515.0	 -543.0	 0.975	 100.0	 1	 970.0	 280.0; % COW
	6237	 285.0	 -44.0	 206.0	 -294.0	 0.975	 100.0	 1	 370.0	 200.0; % NG
	6237	 285.0	 -44.0	 206.0	 -294.0	 0.975	 100.0	 1	 370.0	 200.0; % NG
	6245	 0.0	 0.0	 260.97	 -173.14	 0.975	 100.0	 0	 670.0	 200.0; % COW
	6246	 0.0	 0.0	 269.33	 -111.09	 0.975	 100.0	 0	 700.0	 140.0; % COW
	6247	 11.5	 2.565	 14.0	 -8.87	 0.975	 100.0	 1	 23.0	 0.0; % PEL
	6248	 11.5	 2.565	 14.0	 -8.87	 0.975	 100.0	 1	 23.0	 0.0; % PEL
	6249	 13.5	 4.515	 22.36	 -13.33	 0.975	 100.0	 1	 27.0	 0.0; % NG
	6250	 43.0	 16.295	 36.04	 -3.45	 0.975	 100.0	 1	 86.0	 0.0; % NG
	6251	 0.0	 0.7	 22.19	 -3.23	 0.975	 100.0	 0	 49.0	 0.0; % NG
	6252	 62.0	 28.595	 79.63	 -22.44	 0.975	 100.0	 1	 124.0	 0.0; % NG
	6253	 16.0	 1.665	 10.13	 -6.8	 0.975	 100.0	 1	 32.0	 0.0; % COW
	6254	 16.0	 1.665	 10.13	 -6.8	 0.975	 100.0	 1	 32.0	 0.0; % COW
	6255	 16.0	 1.545	 9.89	 -6.8	 0.975	 100.0	 1	 32.0	 0.0; % COW
	6256	 16.0	 1.545	 9.89	 -6.8	 0.975	 100.0	 1	 32.0	 0.0; % PEL
	6257	 46.0	 14.82	 59.82	 -30.18	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6258	 46.0	 13.09	 59.82	 -33.64	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6259	 46.0	 17.7	 62.7	 -27.3	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6260	 46.0	 17.7	 62.7	 -27.3	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6261	 46.0	 11.99	 62.7	 -38.72	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6262	 46.0	 13.155	 62.7	 -36.39	 0.975	 100.0	 1	 92.0	 0.0; % NG
	6263	 594.59	 -35.685	 344.58	 -415.95	 0.975	 100.0	 1	 939.59	 249.59; % NUC
	6264	 632.56	 -26.07	 353.88	 -406.02	 0.975	 100.0	 1	 977.56	 287.56; % NUC
	6265	 612.59	 -31.15	 345.27	 -407.57	 0.975	 100.0	 1	 972.59	 252.59; % COW
	6266	 591.59	 -36.5	 343.8	 -416.8	 0.975	 100.0	 1	 936.59	 246.59; % COW
	6268	 204.0	 31.78	 164.82	 -101.26	 0.975	 100.0	 1	 252.0	 156.0; % NG
	6269	 202.0	 31.955	 164.82	 -100.91	 0.975	 100.0	 1	 250.0	 154.0; % NG
	6270	 202.0	 22.52	 101.23	 -56.19	 0.975	 100.0	 1	 250.0	 154.0; % NG
	6271	 213.5	 42.55	 245.17	 -160.07	 0.975	 100.0	 1	 305.0	 122.0; % COW
	6272	 122.0	 17.885	 102.26	 -66.49	 0.975	 100.0	 1	 155.0	 89.0; % NG
	6273	 29.0	 -0.45	 19.65	 -20.55	 0.975	 100.0	 1	 58.0	 0.0; % NG
	6274	 29.0	 0.975	 14.44	 -12.49	 0.975	 100.0	 1	 58.0	 0.0; % NG
	6275	 29.0	 -0.45	 19.65	 -20.55	 0.975	 100.0	 1	 58.0	 0.0; % NG
	6276	 29.0	 0.975	 14.44	 -12.49	 0.975	 100.0	 1	 58.0	 0.0; % NG
	6277	 29.0	 0.905	 14.3	 -12.49	 0.975	 100.0	 1	 58.0	 0.0; % PEL
	6278	 198.0	 45.885	 173.05	 -81.28	 0.975	 100.0	 1	 263.0	 133.0; % COW
	6279	 69.5	 21.71	 99.9	 -56.48	 0.975	 100.0	 1	 139.0	 0.0; % NG
	6280	 24.5	 4.605	 31.97	 -22.76	 0.975	 100.0	 1	 49.0	 0.0; % NG
	6281	 24.5	 4.57	 31.96	 -22.82	 0.975	 100.0	 1	 49.0	 0.0; % NG
	6282	 16.0	 4.37	 22.37	 -13.63	 0.975	 100.0	 1	 32.0	 0.0; % NG
	6283	 16.0	 2.37	 20.37	 -15.63	 0.975	 100.0	 1	 32.0	 0.0; % NG
	6284	 16.0	 4.21	 22.21	 -13.79	 0.975	 100.0	 1	 32.0	 0.0; % COW
	6285	 604.97	 162.7	 551.66	 -226.26	 0.975	 100.0	 1	 939.97	 269.97; % COW
	6286	 605.21	 162.315	 551.2	 -226.57	 0.975	 100.0	 1	 940.21	 270.21; % NUC
	6287	 602.96	 149.25	 520.46	 -221.96	 0.975	 100.0	 1	 927.96	 277.96; % NG
	6288	 595.2	 145.69	 517.11	 -225.73	 0.975	 100.0	 1	 920.2	 270.2; % COW
	6289	 813.0	 218.085	 673.87	 -237.7	 0.975	 100.0	 1	 1308.0	 318.0; % COW
	6290	 813.0	 218.085	 673.87	 -237.7	 0.975	 100.0	 1	 1308.0	 318.0; % COW
	6291	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % COW
	6292	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % NG
	6293	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % PEL
	6294	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % NG
	6295	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % NG
	6296	 17.5	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 0.0; % NG
	6297	 10.0	 1.615	 10.54	 -7.31	 0.975	 100.0	 1	 20.0	 0.0; % NG
	6298	 833.5	 226.955	 703.47	 -249.56	 0.975	 100.0	 1	 1330.0	 337.0; % NUC
	6299	 863.5	 235.535	 712.05	 -240.98	 0.975	 100.0	 1	 1360.0	 367.0; % COW
	6300	 863.5	 235.535	 712.05	 -240.98	 0.975	 100.0	 1	 1360.0	 367.0; % COW
	6301	 47.5	 10.18	 53.63	 -33.27	 0.975	 100.0	 1	 95.0	 0.0; % NG
	6302	 1.45	 91.015	 285.21	 -103.18	 0.975	 100.0	 1	 1.5	 1.4; % PEL
	6303	 0.0	 27.97	 109.25	 -53.31	 0.975	 100.0	 1	 240.0	 -240.0; % NG
	6304	 591.98	 174.145	 504.45	 -156.16	 0.975	 100.0	 1	 946.98	 236.98; % COW
	6306	 602.01	 194.51	 537.92	 -148.9	 0.975	 100.0	 1	 957.01	 247.01; % NUC
	6307	 600.01	 203.3	 556.05	 -149.45	 0.975	 100.0	 1	 955.01	 245.01; % NUC
	6308	 953.0	 217.35	 657.68	 -222.98	 0.975	 100.0	 1	 1503.0	 403.0; % NUC
	6309	 953.0	 217.35	 657.68	 -222.98	 0.975	 100.0	 1	 1503.0	 403.0; % COW
	6310	 948.0	 -28.08	 390.29	 -446.45	 0.975	 100.0	 1	 1498.0	 398.0; % COW
	6311	 948.0	 -38.82	 368.81	 -446.45	 0.975	 100.0	 1	 1498.0	 398.0; % NG
	6312	 66.75	 21.35	 93.6	 -50.9	 0.975	 100.0	 1	 125.0	 8.5; % COW
	6313	 66.75	 21.35	 93.6	 -50.9	 0.975	 100.0	 1	 125.0	 8.5; % NG
	6314	 76.2	 35.07	 72.7	 -2.56	 0.975	 100.0	 1	 148.2	 4.2; % NG
	6315	 0.0	 0.0	 328.92	 -51.66	 0.975	 100.0	 0	 685.0	 180.0; % COW
	6316	 460.0	 94.405	 359.66	 -170.85	 0.975	 100.0	 1	 610.0	 310.0; % COW
	6317	 460.0	 55.15	 323.14	 -212.84	 0.975	 100.0	 1	 610.0	 310.0; % COW
	6319	 0.0	 0.0	 380.92	 -216.75	 0.975	 100.0	 0	 700.0	 205.0; % COW
	6320	 9.0	 0.91	 9.86	 -8.04	 0.975	 100.0	 1	 18.0	 0.0; % PEL
	6321	 19.0	 -0.325	 21.61	 -22.26	 0.975	 100.0	 1	 38.0	 0.0; % COW
	6322	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6323	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6324	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6325	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % COW
	6326	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % PEL
	6327	 25.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6328	 640.0	 196.325	 521.6	 -128.95	 0.975	 100.0	 1	 1000.0	 280.0; % NUC
	6329	 640.0	 196.325	 521.6	 -128.95	 0.975	 100.0	 1	 1000.0	 280.0; % NUC
	6330	 640.0	 218.295	 566.43	 -129.84	 0.975	 100.0	 1	 1000.0	 280.0; % COW
	6331	 605.0	 208.07	 565.46	 -149.32	 0.975	 100.0	 1	 930.0	 280.0; % COW
	6332	 28.5	 4.565	 21.89	 -12.76	 0.975	 100.0	 1	 57.0	 0.0; % NG
	6333	 28.5	 4.565	 21.89	 -12.76	 0.975	 100.0	 1	 57.0	 0.0; % NG
	6334	 0.0	 0.0	 320.29	 -95.56	 0.975	 100.0	 0	 451.0	 239.0; % NG
	6335	 0.0	 0.0	 63.51	 -8.25	 0.975	 100.0	 0	 63.0	 21.0; % NG
	6336	 341.3	 54.86	 274.22	 -164.5	 0.975	 100.0	 1	 433.8	 248.8; % COW
	6337	 576.54	 188.515	 528.05	 -151.02	 0.975	 100.0	 1	 921.54	 231.54; % COW
	6338	 576.54	 188.515	 528.05	 -151.02	 0.975	 100.0	 1	 921.54	 231.54; % COW
	6339	 583.54	 189.84	 528.8	 -149.12	 0.975	 100.0	 1	 928.54	 238.54; % NUC
	6340	 598.55	 192.78	 530.56	 -145.0	 0.975	 100.0	 1	 943.55	 253.55; % COW
	6341	 0.0	 -8.02	 10.38	 -9.67	 0.975	 100.0	 0	 32.0	 0.0; % NG
	6342	 860.0	 -28.245	 407.48	 -463.97	 0.975	 100.0	 1	 1380.0	 340.0; % PEL
	6343	 860.0	 -28.245	 407.48	 -463.97	 0.975	 100.0	 1	 1380.0	 340.0; % COW
	6344	 15.75	 4.47	 22.47	 -13.53	 0.975	 100.0	 1	 31.5	 0.0; % COW
	6345	 32.5	 7.34	 37.34	 -22.66	 0.975	 100.0	 1	 65.0	 0.0; % NG
	6346	 35.0	 0.32	 22.34	 -21.7	 0.975	 100.0	 1	 70.0	 0.0; % PEL
	6347	 32.5	 8.95	 53.95	 -36.05	 0.975	 100.0	 1	 65.0	 0.0; % NG
	6348	 32.5	 10.38	 55.38	 -34.62	 0.975	 100.0	 1	 65.0	 0.0; % NG
	6349	 35.0	 9.63	 39.63	 -20.37	 0.975	 100.0	 1	 70.0	 0.0; % PEL
	6350	 798.0	 36.21	 566.82	 -494.4	 0.975	 100.0	 1	 1308.0	 288.0; % COW
	6351	 798.0	 36.21	 566.82	 -494.4	 0.975	 100.0	 1	 1308.0	 288.0; % NUC
	6352	 0.0	 -1.2	 10.52	 -6.96	 0.975	 100.0	 0	 22.0	 0.0; % NG
	6353	 0.0	 -1.2	 10.52	 -6.96	 0.975	 100.0	 0	 22.0	 0.0; % NG
	6354	 273.76	 84.835	 286.78	 -117.11	 0.975	 100.0	 1	 458.26	 89.26; % COW
	6355	 18.0	 -1.11	 10.34	 -12.56	 0.975	 100.0	 1	 36.0	 0.0; % PEL
	6356	 18.0	 -1.11	 10.34	 -12.56	 0.975	 100.0	 1	 36.0	 0.0; % PEL
	6357	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % COW
	6358	 607.0	 190.895	 527.89	 -146.1	 0.975	 100.0	 1	 947.0	 267.0; % COW
	6359	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % NUC
	6360	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % COW
	6361	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % COW
	6362	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % NG
	6363	 0.0	 0.0	 132.48	 -11.56	 0.975	 100.0	 0	 240.0	 125.0; % NG
	6364	 336.8	 72.235	 271.84	 -127.37	 0.975	 100.0	 1	 456.8	 216.8; % COW
	6365	 195.0	 33.755	 166.41	 -98.9	 0.975	 100.0	 1	 260.0	 130.0; % NG
	6366	 0.0	 0.0	 280.73	 -126.32	 0.975	 100.0	 0	 585.0	 250.0; % COW
	6367	 0.0	 0.0	 287.58	 -119.25	 0.975	 100.0	 0	 585.0	 250.0; % COW
	6369	 28.5	 10.68	 32.55	 -11.19	 0.975	 100.0	 1	 57.0	 0.0; % PEL
	6370	 28.5	 10.61	 32.55	 -11.33	 0.975	 100.0	 1	 57.0	 0.0; % NG
	6371	 8.0	 6.455	 20.13	 -7.22	 0.975	 100.0	 1	 31.0	 -15.0; % NG
	6372	 15.5	 5.97	 33.89	 -21.95	 0.975	 100.0	 1	 31.0	 0.0; % PEL
	6373	 9.75	 1.46	 7.83	 -4.91	 0.975	 100.0	 1	 19.5	 0.0; % PEL
	6374	 9.75	 1.46	 7.83	 -4.91	 0.975	 100.0	 1	 19.5	 0.0; % NG
	6375	 0.0	 -6.18	 8.32	 -7.73	 0.975	 100.0	 0	 21.0	 0.0; % COW
	6376	 17.5	 0.04	 7.32	 -7.24	 0.975	 100.0	 1	 35.0	 0.0; % PEL
	6377	 17.5	 -0.065	 7.11	 -7.24	 0.975	 100.0	 1	 35.0	 0.0; % NG
	6378	 17.5	 -0.15	 11.43	 -11.73	 0.975	 100.0	 1	 35.0	 0.0; % NG
	6379	 17.5	 0.04	 7.32	 -7.24	 0.975	 100.0	 1	 35.0	 0.0; % PEL
	6380	 0.0	 0.0	 112.63	 -113.65	 0.975	 100.0	 0	 235.0	 120.0; % NG
	6381	 23.5	 2.32	 10.25	 -5.61	 0.975	 100.0	 1	 47.0	 0.0; % NG
	6382	 23.5	 2.23	 10.25	 -5.79	 0.975	 100.0	 1	 47.0	 0.0; % NG
	6383	 36.5	 10.17	 51.92	 -31.58	 0.975	 100.0	 1	 73.0	 0.0; % NG
	6384	 34.5	 13.355	 55.2	 -28.49	 0.975	 100.0	 1	 69.0	 0.0; % COW
	6385	 38.0	 11.28	 51.28	 -28.72	 0.975	 100.0	 1	 76.0	 0.0; % NG
	6386	 38.75	 10.505	 51.13	 -30.12	 0.975	 100.0	 1	 77.5	 0.0; % PEL
	6387	 15.5	 2.14	 14.95	 -10.67	 0.975	 100.0	 1	 31.0	 0.0; % NG
	6388	 15.5	 2.14	 14.95	 -10.67	 0.975	 100.0	 1	 31.0	 0.0; % PEL
	6389	 15.5	 2.14	 14.95	 -10.67	 0.975	 100.0	 1	 31.0	 0.0; % NG
	6390	 25.0	 8.08	 31.73	 -15.57	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6391	 18.5	 3.79	 15.94	 -8.36	 0.975	 100.0	 1	 37.0	 0.0; % COW
	6392	 18.5	 3.79	 15.94	 -8.36	 0.975	 100.0	 1	 37.0	 0.0; % NG
	6393	 18.5	 3.79	 15.94	 -8.36	 0.975	 100.0	 1	 37.0	 0.0; % COW
	6394	 18.5	 3.79	 15.94	 -8.36	 0.975	 100.0	 1	 37.0	 0.0; % PEL
	6395	 193.5	 68.455	 170.47	 -33.56	 0.975	 100.0	 1	 250.0	 137.0; % NG
	6396	 193.5	 68.455	 170.47	 -33.56	 0.975	 100.0	 1	 250.0	 137.0; % NG
	6397	 9.5	 1.75	 10.62	 -7.12	 0.975	 100.0	 1	 19.0	 0.0; % NG
	6398	 9.5	 1.75	 10.62	 -7.12	 0.975	 100.0	 1	 19.0	 0.0; % PEL
	6399	 61.0	 7.36	 25.64	 -10.92	 0.975	 100.0	 1	 122.0	 0.0; % NG
	6400	 310.9	 26.99	 215.24	 -161.26	 0.975	 100.0	 1	 419.9	 201.9; % COW
	6401	 26.0	 10.215	 39.82	 -19.39	 0.975	 100.0	 1	 52.0	 0.0; % NG
	6402	 26.0	 10.215	 39.82	 -19.39	 0.975	 100.0	 1	 52.0	 0.0; % NG
	6403	 0.0	 0.0	 104.23	 -23.38	 0.975	 100.0	 0	 185.0	 5.0; % NG
	6404	 0.0	 0.0	 104.23	 -23.38	 0.975	 100.0	 0	 185.0	 5.0; % NG
	6405	 4.5	 69.52	 195.6	 -56.56	 0.975	 100.0	 1	 227.0	 -218.0; % COW
	6406	 4.5	 69.84	 195.94	 -56.26	 0.975	 100.0	 1	 227.0	 -218.0; % NG
	6407	 4.5	 69.84	 195.94	 -56.26	 0.975	 100.0	 1	 227.0	 -218.0; % NG
	6408	 4.5	 69.935	 196.04	 -56.17	 0.975	 100.0	 1	 227.0	 -218.0; % NG
	6409	 32.5	 12.59	 79.87	 -54.69	 0.975	 100.0	 1	 65.0	 0.0; % PEL
	6410	 32.5	 12.59	 79.87	 -54.69	 0.975	 100.0	 1	 65.0	 0.0; % PEL
	6411	 593.5	 182.745	 511.82	 -146.33	 0.975	 100.0	 1	 950.0	 237.0; % COW
	6412	 593.5	 193.685	 533.7	 -146.33	 0.975	 100.0	 1	 950.0	 237.0; % COW
	6413	 242.0	 22.125	 194.0	 -149.75	 0.975	 100.0	 1	 316.0	 168.0; % NG
	6414	 149.0	 42.4	 179.42	 -94.62	 0.975	 100.0	 1	 191.0	 107.0; % NG
	6415	 0.0	 0.0	 194.29	 -148.96	 0.975	 100.0	 0	 304.0	 156.0; % NG
	6416	 824.5	 229.315	 671.92	 -213.29	 0.975	 100.0	 1	 1360.0	 289.0; % COW
	6417	 30.5	 2.34	 28.9	 -24.22	 0.975	 100.0	 1	 61.0	 0.0; % NG
	6418	 30.5	 2.34	 28.9	 -24.22	 0.975	 100.0	 1	 61.0	 0.0; % NG
	6419	 17.5	 6.57	 23.24	 -10.1	 0.975	 100.0	 1	 35.0	 0.0; % PEL
	6420	 865.0	 235.84	 706.84	 -235.16	 0.975	 100.0	 1	 1380.0	 350.0; % COW
	6421	 865.0	 235.84	 706.84	 -235.16	 0.975	 100.0	 1	 1380.0	 350.0; % PEL
	6422	 865.0	 230.335	 695.83	 -235.16	 0.975	 100.0	 1	 1380.0	 350.0; % COW
	6423	 820.0	 210.31	 681.31	 -260.69	 0.975	 100.0	 1	 1290.0	 350.0; % NG
	6424	 25.9	 13.51	 37.51	 -10.49	 0.975	 100.0	 1	 51.0	 0.8; % PEL
	6425	 860.0	 234.135	 675.48	 -207.21	 0.975	 100.0	 1	 1380.0	 340.0; % PEL
	6426	 860.0	 234.135	 675.48	 -207.21	 0.975	 100.0	 1	 1380.0	 340.0; % COW
	6427	 0.0	 0.0	 322.12	 -100.08	 0.975	 100.0	 0	 585.0	 175.0; % NG
	6428	 0.0	 0.0	 322.12	 -100.08	 0.975	 100.0	 0	 585.0	 175.0; % COW
	6429	 393.0	 119.845	 331.77	 -92.08	 0.975	 100.0	 1	 598.0	 188.0; % COW
	6430	 0.0	 0.0	 311.95	 -109.4	 0.975	 100.0	 0	 585.0	 175.0; % COW
	6431	 21.5	 6.31	 33.11	 -20.49	 0.975	 100.0	 1	 43.0	 0.0; % NG
	6432	 21.5	 6.31	 33.11	 -20.49	 0.975	 100.0	 1	 43.0	 0.0; % NG
	6433	 21.5	 6.31	 33.11	 -20.49	 0.975	 100.0	 1	 43.0	 0.0; % NG
	6434	 40.0	 4.5	 42.66	 -33.66	 0.975	 100.0	 1	 80.0	 0.0; % COW
	6435	 165.0	 16.655	 109.16	 -75.85	 0.975	 100.0	 1	 245.0	 85.0; % NG
	6436	 450.0	 57.26	 230.47	 -115.95	 0.975	 100.0	 1	 605.0	 295.0; % NG
	6437	 28.0	 4.12	 24.74	 -16.5	 0.975	 100.0	 1	 56.0	 0.0; % NG
	6438	 28.0	 4.12	 24.74	 -16.5	 0.975	 100.0	 1	 56.0	 0.0; % NG
	6439	 29.0	 29.66	 61.2	 -1.88	 0.975	 100.0	 1	 58.0	 0.0; % COW
	6440	 11.55	 3.15	 17.15	 -10.85	 0.975	 100.0	 1	 23.1	 0.0; % NG
	6441	 11.55	 3.14	 17.14	 -10.86	 0.975	 100.0	 1	 23.1	 0.0; % NG
	6442	 335.3	 81.55	 169.82	 -6.72	 0.975	 100.0	 1	 439.8	 230.8; % COW
	6443	 20.5	 2.215	 21.74	 -17.31	 0.975	 100.0	 1	 41.0	 0.0; % NG
	6444	 0.0	 6.12	 18.02	 -6.63	 0.975	 100.0	 0	 80.0	 -80.0; % COW
	6445	 0.0	 10.61	 18.02	 -6.63	 0.975	 100.0	 0	 80.0	 -80.0; % NG
	6446	 0.0	 10.61	 18.02	 -6.63	 0.975	 100.0	 0	 80.0	 -80.0; % NG
	6447	 16.0	 4.57	 19.57	 -10.43	 0.975	 100.0	 1	 32.0	 0.0; % PEL
	6448	 0.0	 -3.93	 19.57	 -10.43	 0.975	 100.0	 0	 32.0	 0.0; % NG
	6449	 16.0	 4.57	 19.57	 -10.43	 0.975	 100.0	 1	 32.0	 0.0; % COW
	6450	 0.0	 -3.93	 19.57	 -10.43	 0.975	 100.0	 0	 32.0	 0.0; % NG
	6451	 0.0	 13.035	 116.01	 -89.94	 0.975	 100.0	 1	 180.0	 -180.0; % COW
	6452	 22.0	 4.315	 14.64	 -6.01	 0.975	 100.0	 1	 44.0	 0.0; % NG
	6453	 15.5	 2.94	 19.26	 -13.38	 0.975	 100.0	 1	 31.0	 0.0; % PEL
	6454	 15.5	 2.94	 19.26	 -13.38	 0.975	 100.0	 1	 31.0	 0.0; % NG
	6455	 19.0	 4.36	 27.02	 -18.3	 0.975	 100.0	 1	 38.0	 0.0; % NG
	6456	 19.0	 4.225	 26.96	 -18.51	 0.975	 100.0	 1	 38.0	 0.0; % NG
	6457	 19.0	 4.225	 26.96	 -18.51	 0.975	 100.0	 1	 38.0	 0.0; % NG
	6458	 33.0	 7.725	 41.08	 -25.63	 0.975	 100.0	 1	 66.0	 0.0; % PEL
	6459	 42.0	 15.305	 54.62	 -24.01	 0.975	 100.0	 1	 84.0	 0.0; % NG
	6460	 42.0	 15.305	 54.62	 -24.01	 0.975	 100.0	 1	 84.0	 0.0; % COW
	6461	 16.5	 11.24	 26.24	 -3.76	 0.975	 100.0	 1	 33.0	 0.0; % PEL
	6462	 16.5	 10.805	 26.24	 -4.63	 0.975	 100.0	 1	 33.0	 0.0; % PEL
	6463	 65.0	 6.33	 30.84	 -18.18	 0.975	 100.0	 1	 130.0	 0.0; % NG
	6464	 807.0	 215.91	 671.48	 -239.66	 0.975	 100.0	 1	 1332.0	 282.0; % NG
	6465	 807.0	 215.91	 671.48	 -239.66	 0.975	 100.0	 1	 1332.0	 282.0; % COW
	6466	 217.5	 91.59	 168.9	 14.28	 0.975	 100.0	 1	 285.0	 150.0; % NG
	6467	 410.0	 53.715	 204.97	 -97.54	 0.975	 100.0	 1	 595.0	 225.0; % COW
	6468	 285.0	 47.37	 114.04	 -19.3	 0.975	 100.0	 1	 443.0	 127.0; % NG
	6469	 285.0	 50.72	 120.82	 -19.38	 0.975	 100.0	 1	 443.0	 127.0; % NG
	6470	 25.0	 1.74	 27.73	 -24.25	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6471	 25.0	 1.74	 27.73	 -24.25	 0.975	 100.0	 1	 50.0	 0.0; % NG
	6472	 24.5	 5.365	 32.52	 -21.79	 0.975	 100.0	 1	 49.0	 0.0; % PEL
	6473	 24.5	 5.365	 32.52	 -21.79	 0.975	 100.0	 1	 49.0	 0.0; % NG
	6474	 15.0	 4.19	 21.62	 -13.24	 0.975	 100.0	 1	 30.0	 0.0; % NG
	6475	 15.0	 4.19	 21.62	 -13.24	 0.975	 100.0	 1	 30.0	 0.0; % NG
	6476	 42.5	 19.785	 57.42	 -17.85	 0.975	 100.0	 1	 85.0	 0.0; % NG
	6477	 589.43	 195.9	 542.93	 -151.13	 0.975	 100.0	 1	 949.43	 229.43; % NUC
	6478	 592.43	 196.445	 543.17	 -150.28	 0.975	 100.0	 1	 952.43	 232.43; % COW
	6479	 24.5	 0.785	 21.77	 -20.2	 0.975	 100.0	 1	 49.0	 0.0; % NG
	6480	 24.5	 0.785	 21.77	 -20.2	 0.975	 100.0	 1	 49.0	 0.0; % NG
	6481	 24.5	 0.785	 21.77	 -20.2	 0.975	 100.0	 1	 49.0	 0.0; % NG
	6482	 78.0	 26.095	 112.39	 -60.2	 0.975	 100.0	 1	 156.0	 0.0; % NG
	6483	 49.5	 -5.525	 22.91	 -33.96	 0.975	 100.0	 1	 99.0	 0.0; % NG
	6484	 49.5	 -5.525	 22.91	 -33.96	 0.975	 100.0	 1	 99.0	 0.0; % NG
	6485	 630.0	 121.775	 405.58	 -162.03	 0.975	 100.0	 1	 985.0	 275.0; % NUC
	6486	 630.0	 116.775	 400.58	 -167.03	 0.975	 100.0	 1	 985.0	 275.0; % COW
	6487	 630.0	 116.775	 400.58	 -167.03	 0.975	 100.0	 1	 985.0	 275.0; % COW
	6488	 630.0	 116.775	 400.58	 -167.03	 0.975	 100.0	 1	 985.0	 275.0; % NG
	6489	 0.0	 0.0	 102.61	 -26.72	 0.975	 100.0	 0	 185.0	 72.0; % NG
	6490	 0.0	 0.0	 102.61	 -24.82	 0.975	 100.0	 0	 185.0	 72.0; % NG
	6491	 0.0	 0.0	 102.61	 -24.82	 0.975	 100.0	 0	 185.0	 72.0; % NG
	6492	 0.0	 19.4	 89.4	 -50.6	 0.975	 100.0	 1	 64.0	 -64.0; % NG
	6493	 0.0	 19.4	 89.4	 -50.6	 0.975	 100.0	 1	 64.0	 -64.0; % NG
	6494	 0.0	 19.4	 89.4	 -50.6	 0.975	 100.0	 1	 64.0	 -64.0; % NG
	6495	 203.0	 30.365	 148.09	 -87.36	 0.975	 100.0	 1	 268.0	 138.0; % NG
	6496	 203.0	 30.365	 148.09	 -87.36	 0.975	 100.0	 1	 268.0	 138.0; % COW
	6497	 90.0	 27.8	 97.8	 -42.2	 0.975	 100.0	 1	 180.0	 0.0; % NG
	6498	 68.0	 43.88	 133.88	 -46.12	 0.975	 100.0	 1	 136.0	 0.0; % NG
	6499	 64.0	 38.95	 123.95	 -46.05	 0.975	 100.0	 1	 128.0	 0.0; % COW
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.000000	  53.504391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.508375	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.716435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 129.027919	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.545331	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.889083	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.691085	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.318963	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.709311	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.770561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.007581	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.418090	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.833133	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.352851	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 129.030581	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.841169	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.746003	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.494413	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.664437	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.414846	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.140106	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 134.972244	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.165583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.952313	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.296565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.998005	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.206624	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.395964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.077343	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.061703	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.369040	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.321676	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.466109	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  91.897742	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.294977	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  11.152294	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.388369	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.546811	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.131138	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.514740	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.490798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.619751	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 117.413179	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.779921	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.726624	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.100245	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.006697	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.012698	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.731281	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.021000	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.895876	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.057743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.815713	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   9.096664	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  97.228958	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.720301	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.635347	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.164995	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.728595	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.928571	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.762080	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.989407	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.621264	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.460280	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.108740	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.045106	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 133.217831	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  38.122923	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.834338	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.008753	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.424626	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.149604	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.433095	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  88.854729	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.482492	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.558003	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.192972	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.621395	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.202184	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.618145	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.658892	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.939916	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.820999	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.994129	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.289866	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.795836	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  92.169237	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  95.641617	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.503477	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.747567	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.470558	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.562996	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.487379	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.941005	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.547379	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.410254	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.302999	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.747564	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.918907	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.136192	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.662853	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.832289	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.146654	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.099224	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.947006	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 105.763597	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.947686	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.384778	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.161835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.173483	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.329067	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.830772	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.439168	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.766553	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.034252	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.256661	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.903692	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.571461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.824418	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.522708	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.148754	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.107105	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.903003	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.968990	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.025270	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.667931	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.801776	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.500034	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  52.218741	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.986124	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.287270	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.695702	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.041935	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 124.968066	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.900362	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.746809	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.419403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.436505	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 130.177918	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   9.833102	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.556342	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.971076	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.553280	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.859824	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.630533	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.666935	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.167121	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.220455	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.927873	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.674529	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.846550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.713775	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.847005	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.864113	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.879701	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.511667	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 132.395456	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.079079	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.404017	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.272008	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.745819	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.162214	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.482600	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.346572	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.156702	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.089855	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.200435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.577846	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.391394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.770250	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 115.744771	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 138.641657	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.864791	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.283629	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.470098	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.839844	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.970489	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.354384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.132303	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.870541	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.699212	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 120.298901	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.034774	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.150146	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.968847	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.788420	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 128.248743	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.875402	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.050135	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.377164	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.598025	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.263035	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.939589	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.679195	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 100.517789	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.334768	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.391458	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.561948	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.955739	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.761050	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.494228	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.571888	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.026724	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.394677	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.636320	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.982391	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.504651	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.805586	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.379464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.757915	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.676767	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.715695	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.476019	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.545835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  92.078092	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.285835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.334016	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.731996	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.723318	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.869601	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.817761	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.309850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.924163	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.556645	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.754862	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.302038	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.653067	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.594260	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.615332	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.802756	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 121.101408	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.038287	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.720931	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.425620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.147882	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.754082	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.827775	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.715324	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.578581	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.869711	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.870115	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.181334	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.539940	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.848556	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.940325	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.326894	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.815731	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.011942	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.262657	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.994462	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.371709	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.138690	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.744818	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.360877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.886361	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.216732	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.104956	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.055606	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.638679	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 134.638269	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.761227	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.369781	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.845789	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.553581	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.601985	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.018391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.589496	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.917492	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.357953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.542482	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.335845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.993400	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.918855	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.727762	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.153896	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.286857	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.915912	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.117754	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 124.289113	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.073966	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.421272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.133192	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.331151	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.520243	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.841239	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.399837	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.617246	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.315384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.536590	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.072646	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.057293	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  87.795879	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.837121	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 135.532860	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.871843	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.231328	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.464718	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.897480	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.126086	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.187326	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.451627	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.677589	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 128.302657	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.039761	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.824371	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.244243	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.341230	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.306988	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.642352	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.702597	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.426551	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.849094	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.895755	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.157252	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.112120	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.606019	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.386805	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.087418	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.272264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.819982	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.587848	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.195387	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.776289	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.311874	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.646979	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.004483	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.010625	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.601767	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.922103	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.590964	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.738523	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.193988	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.003585	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.519031	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.724858	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.999975	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.704386	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.772810	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.190188	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.191963	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.368400	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.889790	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.055813	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.683386	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.678493	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.306114	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.896988	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.165516	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.642011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.374006	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.800223	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.083324	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.501715	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.896626	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.735286	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.405007	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.318513	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.181665	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.633309	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.832949	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.915856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.139504	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.322038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.284126	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.940032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   4.331925	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.149050	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.527251	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.644893	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.064947	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 125.781765	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.262998	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.954584	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.292925	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.150511	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.223459	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.857253	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.280506	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.913397	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  95.584831	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.494743	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.880641	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.111354	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.613213	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  12.565733	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.213446	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.305748	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.439529	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.500587	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.431210	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.340212	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.781023	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.936707	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.962565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.377748	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.249667	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.622234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.834478	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.149294	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.150373	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.425558	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.127500	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.321117	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.506549	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.070454	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.735731	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.344316	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.024000	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.451468	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.964783	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.227499	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.650553	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.880169	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.517904	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.070665	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.954535	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.170173	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.188713	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.026436	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.852176	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.382634	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.249987	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.050407	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.417656	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.212709	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.401372	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.677057	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.859594	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.403655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.146789	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.200240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.414007	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.196355	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.028580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.866572	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.848519	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.601147	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.766119	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.168717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.078798	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.983145	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.383812	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.257168	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 115.341795	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.293631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.999684	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 119.903353	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.668869	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.047201	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.484978	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.644206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.638070	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.707771	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.154238	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 138.506829	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.030567	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.927217	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.215172	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.885844	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.088330	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.276465	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.847331	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.848193	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.716749	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.477119	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.846756	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.751602	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.868379	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.721600	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.997237	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  65.507918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.313374	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.964843	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  92.075129	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.393301	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.107812	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.725046	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.605195	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 132.003039	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  96.355332	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 124.422128	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.086486	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.534110	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.085838	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.405089	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.662443	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.536948	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.487781	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.248477	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 124.512550	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.838904	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.276476	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.565328	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.238350	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.595401	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.261471	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.513456	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.664464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.260845	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.742603	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.190347	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.096904	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.409986	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.470354	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.920228	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.812344	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.339835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.717087	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.101928	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.455120	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.712618	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.794078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  96.985891	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.506069	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.197094	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.340806	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.853183	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.689110	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.690978	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.210989	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.171193	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.107289	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.411438	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.218040	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 133.775850	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  92.628976	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.237875	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.150421	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.841165	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.053767	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.853143	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.767724	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.332627	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.315050	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.495737	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 131.245704	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.054415	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.584785	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.933177	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.449934	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.121030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.991132	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.997479	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.524262	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.664503	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.991689	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.637488	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.957498	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  96.281964	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.268185	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.143636	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.986174	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 107.864284	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.810990	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.595148	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.188046	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.253533	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.057317	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.505048	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 107.821713	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   7.010338	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 106.297508	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.479085	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.167608	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.182026	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.882765	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.023543	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.945657	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.876267	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.273409	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.513013	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.296511	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.806044	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.185343	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.782720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.830133	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.502018	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.649743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.630620	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.640082	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.431664	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.920055	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.247237	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.052731	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.343364	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.396254	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.721590	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.156212	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.241672	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.429371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.501721	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.844056	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.400621	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  12.904525	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.439086	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.887642	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.434008	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.666462	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.828748	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.876102	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  98.546256	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  55.294747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.311280	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.232486	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 120.639583	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  10.109463	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 109.142085	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.920231	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.639938	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.521918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.923767	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.281515	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.231951	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.806935	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.769040	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.362765	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.960427	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.644308	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.391909	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.174789	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.485040	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.300911	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.200560	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.970291	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.551098	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.905171	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.358961	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.822566	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.212879	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.142992	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.599629	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.281981	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.633909	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.729097	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.418032	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.862767	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.704575	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.172383	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.184491	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.531885	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.405021	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.695306	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.175993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.649299	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.840106	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.902303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.607768	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.742165	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.956732	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.486393	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.891279	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.163397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  96.974157	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 143.864171	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.749825	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.660065	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  98.193181	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.445923	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.411412	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.593914	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.836801	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.239387	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.173513	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  94.849797	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.391831	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.707713	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.883368	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.673627	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.471261	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.767080	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.160797	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.479474	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	 113.731236	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.336455	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.583001	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.269286	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.712149	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.660500	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.535742	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.851729	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.957787	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.959588	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.764056	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.249395	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.836113	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.740953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.774514	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.449112	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.470948	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.289996	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.060578	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.086075	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.114908	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.738011	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.859265	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.865782	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.128480	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.404641	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.979384	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.182305	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.162162	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.255163	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.038861	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.072493	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.184459	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.169232	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  56.362502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.746667	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.105725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.293751	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.220249	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.764868	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.026299	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.543247	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.772780	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.337062	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.479286	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.462205	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.757805	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.820082	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.728032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.214882	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.838933	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.026715	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.168991	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.140530	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.271001	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.058836	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.613947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.390991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.291676	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.263214	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 129.823149	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.162544	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.144458	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.810633	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.739199	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.237674	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.448900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.455294	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.931932	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.622914	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.745894	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.922402	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.529641	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.938532	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.106657	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.449524	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.824804	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.486694	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.473023	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.726453	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.754009	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.122647	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.558298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.236459	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.741618	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.330073	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.681781	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.338436	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.253470	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.913612	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.394886	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.024220	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.127309	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.093698	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.007679	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.315560	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.728723	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.736598	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.604526	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 117.465623	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.102652	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  56.530659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.222541	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   9.497196	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.210342	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.433175	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.445697	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.797737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.584553	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.487162	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.795416	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.651898	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.147724	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.334883	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.473939	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.092702	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.903520	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.847230	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.820139	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.765245	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.908024	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.867838	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.621831	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.632512	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.596282	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.284079	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.797167	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.714161	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.122601	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.490032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.072656	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  13.505371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.853612	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.666099	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.727478	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.270161	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.408621	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.415539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.302734	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.759390	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   4.072186	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.354837	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.937048	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.337789	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.171153	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.653994	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.359757	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.607071	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.065716	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.123967	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.594654	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.593715	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.263690	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.585600	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.653161	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.343244	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  65.483251	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 124.723219	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.741581	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.988236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.306403	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.847342	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.328680	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.930873	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.249098	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  91.203848	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.855522	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 123.737149	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.820297	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.948807	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.399119	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.547374	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.204424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.108852	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.465202	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  99.301487	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.672918	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.619635	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.310665	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.697439	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.654714	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.428618	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.576919	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.023033	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.046967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.983443	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.674290	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.102245	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.443376	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.959552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.370988	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.137887	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.609308	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.848316	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.698139	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.737541	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.380911	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.657085	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.075154	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.468736	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.013335	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.627981	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.838963	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.034132	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.556353	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.698123	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.889535	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.401670	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.456626	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  96.401253	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.359153	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.849955	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.280500	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.471322	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.314545	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 104.244389	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.007954	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.499050	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.451457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.065967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.398964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.211983	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.740885	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.789944	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.340347	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.296568	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.159888	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 117.196148	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.095831	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.733030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  92.117712	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.233283	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.799253	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.870390	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.492090	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.458224	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.118583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.734743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.726066	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  13.498011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.158730	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.287120	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.699004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.037206	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.959653	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.907304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.427763	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.177533	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.414954	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.778206	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.948391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.691167	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.827533	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.089263	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.515330	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.744165	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.326868	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.246822	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 131.102429	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.173080	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.152533	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.096130	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.466238	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.275333	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  92.664722	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.259731	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.667849	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.771740	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.649248	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.515064	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.340018	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.881300	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.681759	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 137.516745	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.671186	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.526288	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.148517	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.287178	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.515424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.248858	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.312280	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.722013	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.466431	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.422385	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.579188	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.300096	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.595716	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.069807	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.225244	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  96.591657	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.188730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.151646	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.697846	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.966962	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  10.544264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.194178	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.909958	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.375591	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.549725	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.954376	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.436993	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.600347	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.959313	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.138606	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.099234	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.840026	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.862703	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.388845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.220239	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.443933	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.491410	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	 114.376419	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.803953	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.519076	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.998539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.592481	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.725921	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.627664	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.439755	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.853379	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.361573	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.232209	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   6.854350	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  42.073294	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.364734	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.375573	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.372772	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.772727	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.453400	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   3.779281	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.030841	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.893905	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.336808	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.306149	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.652562	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.459017	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.281893	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.125890	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.891859	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	 107.234366	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.587307	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.905698	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  25.370931	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.995267	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.051184	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.898752	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.978435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.496006	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.646063	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.809236	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.367502	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  27.216156	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.520259	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.819077	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.348520	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.434920	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.707257	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.677747	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.093937	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.050708	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.944937	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.508695	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  41.791302	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.754022	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.713191	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.748753	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.193614	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.853245	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  20.648621	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.007662	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.187953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.220198	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.776015	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  50.304331	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.224366	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  33.657156	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.518321	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.596481	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.321992	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.178090	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.473926	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.303282	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.062070	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.580538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.517323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.547305	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.510380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.929744	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  31.327737	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.505750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.772085	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   2.993303	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.424150	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.971211	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.414530	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	 111.404067	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.905028	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.949364	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.858901	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.317199	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.990446	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.956471	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  21.432003	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.656571	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   9.740148	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.468482	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.669502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.871492	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  26.396389	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.489711	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.514654	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.570787	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.443021	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  21.385720	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  57.002074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.822246	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.820853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.777985	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.387395	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.922253	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.803547	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  97.238221	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  32.196695	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.899001	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.115825	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.731999	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.250386	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.080582	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.048204	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.366312	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.908033	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.728271	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 100.292867	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.567597	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.540257	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.734523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.558414	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.158468	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.249063	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.038686	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 115.441780	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.208321	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.164764	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.418078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.645930	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.808832	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.221309	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.901347	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   7.230649	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  31.567495	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.289880	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.383668	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.261580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.616615	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.135549	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.511333	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.180362	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.498996	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.531041	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.440510	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.618731	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.242966	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.720274	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.350017	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.201042	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.240392	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.298462	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.736579	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.245810	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.295500	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  56.579662	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.768945	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.450002	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.733112	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.855687	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.368382	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.250208	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  57.297167	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.042942	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.544526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.568131	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.768796	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  26.422264	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.374686	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.518287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.094091	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.674718	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.374647	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.604671	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   6.752036	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   6.004982	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  37.528483	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.379500	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.187341	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.508989	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.203245	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.957324	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.930186	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.542753	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.708164	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.897514	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.796663	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.667640	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.355236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.944383	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.897680	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.762436	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 109.757003	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.839659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.015819	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   6.561278	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  15.495696	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.556946	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.826120	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.824061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.994110	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.886296	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.197146	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.435262	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.504706	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.681896	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  15.216235	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.476076	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  96.842741	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.114635	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.061789	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.110472	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.219919	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.699606	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.587196	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.236065	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.596923	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.532853	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  42.296494	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.737785	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.593143	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 117.599998	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  93.697506	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.417496	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.814208	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.383771	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  39.327277	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.717775	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.970377	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.731379	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.272439	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.799162	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.071586	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.045630	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.149056	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.676497	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.409640	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.322288	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 117.433522	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.452583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.022946	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 103.824477	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.708868	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.274146	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.911572	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.629004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.704211	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.741134	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.784408	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.529192	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.266737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.558523	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.416833	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.671139	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  53.512347	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.101986	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.447929	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.464905	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.976754	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 100.831324	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.063012	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.293931	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.821270	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  94.329869	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.564163	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.782131	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.024512	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.397101	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.727574	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.474662	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.885084	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  56.460063	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.006967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.869938	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.317696	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  92.210438	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.650571	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.424289	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.187291	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.068992	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.946384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.304480	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.331819	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.687034	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.252429	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.979278	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 115.473340	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.131892	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.529584	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.670389	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.059520	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.814051	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.509883	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.310663	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.767989	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.702120	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.088650	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.045749	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.436944	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.719067	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.879098	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.256588	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.347434	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.143428	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.200221	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.977708	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.924015	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.848009	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.473904	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.666298	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.939158	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.881782	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.649510	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  11.302404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.894282	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.661372	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.254336	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.321201	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.131475	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.964456	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.306514	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.298403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.003956	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.908631	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.948426	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.376720	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 119.144249	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.772412	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.455850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.783603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.703689	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.995866	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.739708	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.450202	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.954878	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.525096	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.799724	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.733866	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.044087	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.677509	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.242175	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.999515	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.989735	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  39.754748	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.991580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.740200	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.373079	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.795176	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.410524	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.258714	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.139748	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  25.770178	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.664930	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.536673	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.930774	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.445174	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.063121	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.931620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.843452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.414749	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.664151	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.308477	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.669693	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.555759	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.151555	   0.000000; % COW
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	4639	 1	 0.005726	 0.010482	 0.0	 2186	 2186	 2186	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 1	 0.01284	 0.025679	 0.0	 910	 910	 910	 0.0	 0.0	 1	 -30.0	 30.0;
	1676	 2	 0.005799	 0.010615	 0.0075	 2441	 2441	 2441	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 3	 0.134039	 0.309398	 0.0035	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	2296	 3	 0.049131	 0.133283	 0.0015	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	695	 4	 0.025926	 0.109136	 0.0002	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 4	 0.05	 0.126914	 0.0006	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	5036	 4	 0.02321	 0.097407	 0.0016	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	4405	 5	 0.040564	 0.113631	 0.0013	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	2772	 6	 0.006047	 0.020912	 0.0222	 1398	 1398	 1398	 0.0	 0.0	 1	 -30.0	 30.0;
	2773	 7	 0.012472	 0.032099	 0.0061	 884	 884	 884	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 8	 0.002607	 0.017462	 0.0324	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	470	 9	 0.053893	 0.14258	 0.0017	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 10	 0.000247	 0.001235	 0.0005	 24078	 24078	 24078	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 10	 0.000247	 0.001235	 0.0002	 24078	 24078	 24078	 0.0	 0.0	 1	 -30.0	 30.0;
	30	 11	 0.039753	 0.100988	 0.0047	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	2922	 11	 0.037654	 0.096173	 0.001	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	2174	 12	 0.014613	 0.060721	 0.0008	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	4009	 12	 0.034064	 0.121139	 0.0015	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	4011	 12	 0.000242	 0.000442	 0.0004	 60355	 60355	 60355	 0.0	 0.0	 1	 -30.0	 30.0;
	115	 13	 2.1e-05	 0.000125	 0.1386	 737.0	 737.0	 737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2330	 13	 0.000145	 0.001877	 0.0635	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4569	 13	 0.000319	 0.003234	 0.0838	 1841.0	 1841.0	 1841.0	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 13	 2.1e-05	 0.000125	 0.1386	 737.0	 737.0	 737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1220	 14	 0.04	 0.134198	 0.0274	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	2867	 14	 0.012222	 0.052346	 0.0026	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	4587	 14	 0.007284	 0.045432	 0.0024	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	4945	 14	 0.059963	 0.154222	 0.0236	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 14	 0.018025	 0.110988	 0.0073	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	2867	 14	 0.012222	 0.052593	 0.0032	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	4587	 14	 0.007284	 0.044938	 0.0024	 671	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	2899	 15	 0.037541	 0.100529	 0.0011	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	4116	 15	 0.090199	 0.211388	 0.0023	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	4447	 15	 0.09801	 0.267574	 0.0	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 16	 0.071806	 0.191484	 0.0019	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	337	 16	 0.119174	 0.284958	 0.0044	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	5824	 17	 0.022346	 0.061111	 0.0029	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	3719	 18	 0.009383	 0.019753	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	5084	 19	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	3719	 20	 0.001975	 0.004444	 0.0	 5369	 5369	 5369	 0.0	 0.0	 1	 -30.0	 30.0;
	1349	 21	 0.036296	 0.099012	 0.0045	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	1592	 21	 0.032716	 0.089136	 0.0057	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 22	 0.138574	 0.351474	 0.0058	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	5013	 22	 0.094407	 0.210456	 0.0044	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	1152	 23	 0.047115	 0.117158	 0.001	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	2696	 23	 0.039557	 0.120937	 0.0132	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	3418	 23	 0.022676	 0.062484	 0.0007	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	144	 24	 0.064568	 0.16716	 0.0113	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	1277	 24	 0.048605	 0.128481	 0.0062	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	490	 25	 0.004815	 0.02963	 0.0016	 1048	 1048	 1048	 0.0	 0.0	 1	 -30.0	 30.0;
	2086	 25	 0.007309	 0.04463	 0.0073	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	612	 26	 0.034321	 0.145802	 0.0073	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	1860	 26	 0.004815	 0.009753	 0.0005	 2731	 2731	 2731	 0.0	 0.0	 1	 -30.0	 30.0;
	2595	 26	 0.049012	 0.133704	 0.0063	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	2915	 26	 0.04642	 0.126543	 0.0058	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	3332	 26	 0.046296	 0.125926	 0.006	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	4624	 26	 0.053704	 0.136753	 0.0065	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	2915	 26	 0.03358	 0.120988	 0.0062	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	536	 27	 0.006163	 0.041067	 0.0759	 446.0	 446.0	 446.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2343	 27	 0.000652	 0.004369	 0.0081	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 28	 0.050945	 0.131922	 0.0015	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	3884	 28	 0.058781	 0.149005	 0.0017	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	2880	 29	 0.067019	 0.137566	 0.0037	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 29	 0.032754	 0.088939	 0.0039	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 29	 0.030184	 0.080096	 0.0053	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	144	 30	 0.066049	 0.187778	 0.0099	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	1548	 30	 0.065062	 0.133704	 0.0062	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	4831	 30	 0.041728	 0.106049	 0.005	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 31	 0.009574	 0.03875	 0.0114	 740	 740	 740	 0.0	 0.0	 1	 -30.0	 30.0;
	3155	 31	 0.000171	 0.000313	 0.0002	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	3684	 31	 0.034266	 0.09423	 0.001	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	4733	 31	 0.006803	 0.028219	 0.0	 1018	 1018	 1018	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 31	 0.008566	 0.037541	 0.0121	 767	 767	 767	 0.0	 0.0	 1	 -30.0	 30.0;
	3721	 32	 0.009733	 0.034089	 0.0185	 902	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 34	 0.000277	 0.002015	 0.003	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1012	 33	 0.00881	 0.033995	 0.0607	 289.0	 289.0	 289.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 33	 0.004642	 0.019832	 0.0354	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2573	 34	 0.008861	 0.03506	 0.0623	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2697	 34	 0.006993	 0.032869	 0.0557	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4738	 33	 0.002173	 0.008731	 0.0152	 3441	 3441	 3441	 0.0	 0.0	 1	 -30.0	 30.0;
	4848	 34	 0.00077	 0.003121	 0.0051	 9629	 9629	 9629	 0.0	 0.0	 1	 -30.0	 30.0;
	5661	 33	 0.004109	 0.016138	 0.0284	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	368	 35	 8.3e-05	 0.000907	 0.0202	 1034.0	 1034.0	 1034.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1104	 35	 0.000552	 0.006726	 0.0939	 1786.0	 1786.0	 1786.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 35	 0.000512	 0.008012	 0.2455	 2462.0	 2462.0	 2462.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3128	 35	 0.001107	 0.00918	 0.1906	 1644.0	 1644.0	 1644.0	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 36	 6.2e-05	 0.000741	 0.0173	 1095.0	 1095.0	 1095.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 35	 0.000512	 0.008019	 0.2455	 2462.0	 2462.0	 2462.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 36	 0.001153	 0.013123	 0.1841	 1433.0	 1433.0	 1433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5219	 37	 0.055933	 0.120685	 0.0013	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5505	 37	 0.039053	 0.084404	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	725	 38	 0.00252	 0.006551	 0.0001	 4462	 4462	 4462	 0.0	 0.0	 1	 -30.0	 30.0;
	1224	 39	 0.009877	 0.042222	 0.0021	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 39	 0.024815	 0.063086	 0.0029	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	1224	 39	 0.009877	 0.042222	 0.0021	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	2244	 40	 0.056173	 0.142593	 0.0066	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4587	 40	 0.034444	 0.109012	 0.0076	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	430	 41	 0.000158	 0.000672	 0.0719	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3945	 41	 4.5e-05	 8.9e-05	 0.002	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1479	 42	 0.01096	 0.020063	 0.009	 1454	 1454	 1454	 0.0	 0.0	 1	 -30.0	 30.0;
	2758	 42	 0.002268	 0.008818	 0.0099	 3651	 3651	 3651	 0.0	 0.0	 1	 -30.0	 30.0;
	2717	 43	 0.001481	 0.006296	 0.0039	 4689	 4689	 4689	 0.0	 0.0	 1	 -30.0	 30.0;
	3481	 44	 0.050617	 0.137012	 0.009	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	4314	 44	 0.074326	 0.194507	 0.0021	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	5087	 45	 0.000247	 0.000741	 0.0	 38027	 38027	 38027	 0.0	 0.0	 1	 -30.0	 30.0;
	1080	 46	 0.049131	 0.134039	 0.001	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	2187	 46	 0.033258	 0.090955	 0.001	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	3298	 46	 0.067437	 0.123442	 0.001	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	1080	 47	 0.037289	 0.118166	 0.001	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	5353	 48	 0.021358	 0.057037	 0.0005	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	1218	 49	 0.071303	 0.180902	 0.0021	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	2338	 49	 0.071554	 0.18191	 0.0021	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	470	 50	 0.028193	 0.104535	 0.0013	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 50	 0.055404	 0.171429	 0.01	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	3546	 50	 0.010834	 0.071554	 0.001	 416	 416	 416	 0.0	 0.0	 1	 -30.0	 30.0;
	4621	 50	 0.013857	 0.030234	 0.0003	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	3546	 50	 0.011414	 0.070648	 0.0009	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	4621	 50	 0.013757	 0.030108	 0.0003	 909	 909	 909	 0.0	 0.0	 1	 -30.0	 30.0;
	1191	 51	 0.00478	 0.028622	 0.0547	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1192	 51	 0.00478	 0.028583	 0.0547	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	166	 52	 0.01284	 0.032716	 0.0015	 846	 846	 846	 0.0	 0.0	 1	 -30.0	 30.0;
	5479	 52	 0.014198	 0.036049	 0.0016	 767	 767	 767	 0.0	 0.0	 1	 -30.0	 30.0;
	3342	 53	 0.005291	 0.021668	 0.0003	 1285	 1285	 1285	 0.0	 0.0	 1	 -30.0	 30.0;
	2762	 54	 0.01358	 0.047654	 0.0023	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	373	 55	 0.000257	 0.000514	 0.0294	 53975	 53975	 53975	 0.0	 0.0	 1	 -30.0	 30.0;
	2686	 56	 0.000257	 0.002153	 0.2147	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3420	 56	 0.000277	 0.000869	 0.0931	 481.0	 481.0	 481.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5088	 57	 0.000756	 0.00252	 0.0	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	3383	 58	 0.000237	 0.00083	 0.1863	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3558	 58	 0.000178	 0.000612	 0.1377	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	142	 59	 0.030486	 0.076342	 0.002	 370	 370	 370	 0.0	 0.0	 1	 -30.0	 30.0;
	1646	 59	 0.011086	 0.024691	 0.0015	 1124	 1124	 1124	 0.0	 0.0	 1	 -30.0	 30.0;
	2469	 60	 0.044344	 0.170572	 0.0021	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 60	 0.036709	 0.151776	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	2221	 61	 0.017788	 0.048551	 0.0006	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	2627	 61	 0.057521	 0.145251	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	2041	 62	 0.014109	 0.057949	 0.0029	 510	 510	 510	 0.0	 0.0	 1	 -30.0	 30.0;
	2943	 62	 0.007055	 0.02973	 0.0014	 996	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	371	 63	 0.024263	 0.065911	 0.0007	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	3074	 63	 0.020912	 0.059209	 0.0016	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	145	 64	 0.002568	 0.011753	 0.0203	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5098	 64	 0.002568	 0.011615	 0.0228	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 65	 0.006299	 0.033585	 0.0599	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 65	 0.006299	 0.033661	 0.06	 889	 889	 889	 0.0	 0.0	 1	 -30.0	 30.0;
	1541	 66	 0.102293	 0.226757	 0.0025	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	2285	 66	 0.177551	 0.405291	 0.0046	 67	 67	 67	 0.0	 0.0	 1	 -30.0	 30.0;
	3242	 66	 0.088264	 0.161566	 0.0017	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	3023	 67	 0.007307	 0.014613	 0.0002	 1862	 1862	 1862	 0.0	 0.0	 1	 -30.0	 30.0;
	2876	 68	 0.067775	 0.139834	 0.001	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	4529	 68	 0.047367	 0.16125	 0.0021	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	5141	 68	 0.004031	 0.016629	 0.001	 1726	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	4602	 69	 0.073066	 0.205089	 0.0022	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	5089	 70	 4.8e-05	 8.8e-05	 0.0001	 303410	 303410	 303410	 0.0	 0.0	 1	 -30.0	 30.0;
	2158	 71	 0.000252	 0.00252	 0.0008	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	3138	 71	 0.030738	 0.088687	 0.0169	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	5090	 71	 0.006551	 0.016377	 0.0171	 1625	 1625	 1625	 0.0	 0.0	 1	 -30.0	 30.0;
	3138	 71	 0.025195	 0.07483	 0.0204	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	3738	 72	 9.9e-05	 0.00077	 0.078	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3738	 73	 9.9e-05	 0.00077	 0.077	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5098	 74	 0.000514	 0.003437	 0.0061	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 74	 0.005476	 0.036879	 0.1255	 522.0	 522.0	 522.0	 0.0	 0.0	 1	 -30.0	 30.0;
	145	 74	 0.000514	 0.003457	 0.0061	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4954	 75	 0.017531	 0.046914	 0.0023	 594	 594	 594	 0.0	 0.0	 1	 -30.0	 30.0;
	2077	 75	 0.005309	 0.014321	 0.0006	 1945	 1945	 1945	 0.0	 0.0	 1	 -30.0	 30.0;
	3075	 76	 0.003477	 0.01118	 0.0187	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3824	 76	 0.000612	 0.003121	 0.0152	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2337	 77	 0.013857	 0.035525	 0.0004	 775	 775	 775	 0.0	 0.0	 1	 -30.0	 30.0;
	240	 78	 0.002771	 0.008314	 0.0083	 3471	 3471	 3471	 0.0	 0.0	 1	 -30.0	 30.0;
	4554	 78	 0.000151	 0.000302	 0.0	 90076	 90076	 90076	 0.0	 0.0	 1	 -30.0	 30.0;
	630	 79	 0.010758	 0.02187	 0.0071	 1176	 1176	 1176	 0.0	 0.0	 1	 -30.0	 30.0;
	1865	 79	 0.003779	 0.014613	 0.0198	 1899	 1899	 1899	 0.0	 0.0	 1	 -30.0	 30.0;
	2403	 79	 0.008314	 0.017057	 0.024	 1510	 1510	 1510	 0.0	 0.0	 1	 -30.0	 30.0;
	4069	 79	 0.000252	 0.001764	 0.0043	 16079	 16079	 16079	 0.0	 0.0	 1	 -30.0	 30.0;
	630	 79	 0.010758	 0.02187	 0.0071	 1176	 1176	 1176	 0.0	 0.0	 1	 -30.0	 30.0;
	4068	 79	 0.000302	 0.001562	 0.0037	 18009	 18009	 18009	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 81	 2.4e-05	 0.000144	 0.0213	 701.0	 701.0	 701.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 80	 7.1e-05	 0.000162	 0.0162	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	675	 82	 0.068027	 0.173091	 0.002	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	798	 82	 0.027211	 0.068783	 0.001	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	2066	 82	 0.03099	 0.202822	 0.002	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	3478	 83	 0.000257	 0.001165	 0.002	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2122	 84	 0.045603	 0.11741	 0.001	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	3794	 84	 0.008566	 0.024691	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	5093	 85	 0.047317	 0.131595	 0.0015	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	2802	 86	 0.040494	 0.128889	 0.0064	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	3504	 86	 0.037778	 0.097037	 0.0045	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	3763	 87	 0.032071	 0.058705	 0.0006	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 87	 0.062887	 0.204157	 0.002	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	3763	 87	 0.032026	 0.058624	 0.0006	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 88	 0.075838	 0.224742	 0.0027	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	1700	 88	 0.028471	 0.089695	 0.001	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	3635	 88	 0.080373	 0.255732	 0.003	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 88	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 89	 0.033531	 0.087235	 0.0166	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	4218	 89	 0.03037	 0.08321	 0.0039	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	5094	 90	 0.000444	 0.001136	 0.0	 21404	 21404	 21404	 0.0	 0.0	 1	 -30.0	 30.0;
	3719	 91	 0.057284	 0.130864	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	648	 92	 0.054749	 0.157445	 0.0027	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	4048	 92	 0.038549	 0.103049	 0.0012	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	5719	 92	 0.012598	 0.052406	 0.0006	 548	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	2130	 93	 0.006914	 0.020741	 0.0	 1195	 1195	 1195	 0.0	 0.0	 1	 -30.0	 30.0;
	3760	 94	 0.007901	 0.020741	 0.001	 1339	 1339	 1339	 0.0	 0.0	 1	 -30.0	 30.0;
	5834	 94	 0.02	 0.054691	 0.0026	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	283	 95	 0.012099	 0.030864	 0.0047	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	1169	 95	 0.013704	 0.034444	 0.003	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	5695	 95	 0.005679	 0.014198	 0.0023	 1943	 1943	 1943	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 96	 0.009549	 0.040766	 0.0005	 706	 706	 706	 0.0	 0.0	 1	 -30.0	 30.0;
	2994	 97	 0.026505	 0.119426	 0.1007	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	4168	 97	 0.087641	 0.160426	 0.0015	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	4437	 97	 0.021542	 0.05868	 0.003	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	2994	 97	 0.026505	 0.119426	 0.1007	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 98	 0.000176	 0.000479	 0.0006	 59599	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 98	 0.141119	 0.363442	 0.0042	 79	 79	 79	 0.0	 0.0	 1	 -30.0	 30.0;
	4644	 98	 0.074477	 0.177601	 0.0021	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	2626	 99	 0.025195	 0.067523	 0.0064	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	2627	 99	 0.025069	 0.067599	 0.0064	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	552	 100	 0.024792	 0.057949	 0.003	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	1189	 100	 0.028723	 0.11683	 0.0015	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	1190	 100	 0.027589	 0.112547	 0.0048	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	1898	 101	 0.032124	 0.082892	 0.003	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	4441	 101	 0.025573	 0.09869	 0.0012	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	1474	 102	 0.001512	 0.005291	 0.0064	 5495	 5495	 5495	 0.0	 0.0	 1	 -30.0	 30.0;
	1957	 103	 0.03351	 0.120433	 0.0058	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	2480	 103	 0.062988	 0.159486	 0.0017	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	4273	 103	 0.024943	 0.104283	 0.0031	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	1957	 103	 0.033762	 0.120433	 0.0057	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	1664	 104	 0.005709	 0.037926	 0.0688	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5484	 104	 0.001758	 0.011654	 0.0208	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	263	 105	 0.001383	 0.009462	 0.0172	 463.0	 463.0	 463.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1554	 105	 0.00156	 0.006933	 0.0121	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2088	 105	 0.006376	 0.028733	 0.0506	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3532	 105	 0.00158	 0.010627	 0.0192	 481.0	 481.0	 481.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2201	 106	 0.005556	 0.025185	 0.0008	 1225	 1225	 1225	 0.0	 0.0	 1	 -30.0	 30.0;
	2265	 106	 0.007531	 0.046914	 0.0036	 676	 676	 676	 0.0	 0.0	 1	 -30.0	 30.0;
	3255	 106	 0.033457	 0.09642	 0.0047	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	5060	 106	 0.006914	 0.042469	 0.0005	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	2993	 107	 0.001086	 0.003536	 0.3766	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2993	 107	 0.001086	 0.003536	 0.3766	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3971	 108	 0.026543	 0.074691	 0.0034	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	3970	 108	 0.026914	 0.075802	 0.0034	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	633	 109	 0.04059	 0.110708	 0.0013	 253	 253	 253	 0.0	 0.0	 1	 -30.0	 30.0;
	672	 109	 0.073646	 0.225598	 0.0087	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	760	 109	 0.02066	 0.088687	 0.0021	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	5193	 109	 0.019904	 0.08516	 0.001	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 109	 0.014361	 0.068027	 0.0035	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	4732	 109	 0.059209	 0.150164	 0.0021	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	481	 110	 0.004741	 0.020385	 0.0334	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 110	 0.009027	 0.048869	 0.084	 351.0	 351.0	 351.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5499	 110	 0.003516	 0.016257	 0.0273	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	714	 111	 0.059461	 0.163265	 0.0018	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	4434	 111	 0.146384	 0.373394	 0.0051	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	1163	 112	 0.006299	 0.027715	 0.0003	 1009	 1009	 1009	 0.0	 0.0	 1	 -30.0	 30.0;
	1650	 112	 0.008818	 0.028471	 0.0003	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	2289	 112	 0.043588	 0.145629	 0.008	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	5304	 112	 0.015117	 0.051902	 0.0006	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 112	 0.006551	 0.025951	 0.0003	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	1649	 112	 0.008314	 0.027211	 0.0003	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	2289	 112	 0.043689	 0.145528	 0.0081	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	1648	 112	 0.008566	 0.027967	 0.0003	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	1028	 113	 0.000514	 0.003417	 0.0278	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 113	 0.001084	 0.007198	 0.0132	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5254	 113	 0.000523	 0.002436	 0.0167	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1028	 113	 0.000514	 0.003457	 0.0203	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 113	 0.001086	 0.007249	 0.0132	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5253	 113	 0.000553	 0.002469	 0.0157	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 113	 0.001086	 0.007269	 0.0132	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3514	 114	 0.038725	 0.112799	 0.0116	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	3986	 114	 0.023935	 0.079617	 0.0021	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 117	 0.135693	 0.248384	 0.0025	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 117	 0.192681	 0.352701	 0.0037	 76	 76	 76	 0.0	 0.0	 1	 -30.0	 30.0;
	5399	 117	 0.057193	 0.145377	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 117	 0.021736	 0.039788	 0.0004	 671	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	4954	 118	 0.002469	 0.006938	 0.0248	 4034	 4034	 4034	 0.0	 0.0	 1	 -30.0	 30.0;
	996	 119	 0.016125	 0.068279	 0.0081	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	4549	 119	 0.059209	 0.150416	 0.0021	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	996	 119	 0.016125	 0.068279	 0.0081	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	2696	 120	 0.013605	 0.039305	 0.0061	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	5224	 121	 0.031015	 0.078685	 0.0032	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	5451	 121	 0.080927	 0.181204	 0.0038	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 122	 0.007811	 0.016377	 0.0024	 1677	 1677	 1677	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 123	 0.007811	 0.016377	 0.0024	 1677	 1677	 1677	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 124	 0.010124	 0.028518	 0.0013	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	1259	 125	 0.084656	 0.231041	 0.0026	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	1258	 125	 0.061225	 0.275888	 0.003	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	4301	 126	 0.102293	 0.245906	 0.0027	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	5728	 126	 0.036533	 0.088435	 0.001	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	179	 127	 0.001039	 0.001902	 0.0015	 13220	 13220	 13220	 0.0	 0.0	 1	 -30.0	 30.0;
	2739	 129	 0.019148	 0.081381	 0.0012	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	4251	 129	 0.02318	 0.04258	 0.0006	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 129	 0.002268	 0.022424	 0.0002	 1311	 1311	 1311	 0.0	 0.0	 1	 -30.0	 30.0;
	5732	 128	 0.012094	 0.030486	 0.0004	 901	 901	 901	 0.0	 0.0	 1	 -30.0	 30.0;
	2739	 128	 0.03351	 0.088435	 0.001	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	5285	 128	 0.00252	 0.02066	 0.0002	 1419	 1419	 1419	 0.0	 0.0	 1	 -30.0	 30.0;
	2982	 130	 0.001837	 0.011694	 0.0759	 467.0	 467.0	 467.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3406	 130	 0.001067	 0.007131	 0.0132	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4567	 130	 0.001284	 0.008593	 0.0152	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4568	 130	 0.001284	 0.008593	 0.0162	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4568	 130	 0.001284	 0.008533	 0.0162	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	783	 131	 0.000494	 0.000928	 0.0699	 29203	 29203	 29203	 0.0	 0.0	 1	 -30.0	 30.0;
	1143	 131	 0.000184	 0.00159	 0.1661	 453.0	 453.0	 453.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4034	 131	 0.000198	 0.001711	 0.1711	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 131	 0.000751	 0.003358	 0.1534	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2188	 132	 0.007037	 0.022716	 0.0011	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	2727	 132	 0.028025	 0.071111	 0.0034	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	1703	 133	 0.005192	 0.009503	 0.009	 2646	 2646	 2646	 0.0	 0.0	 1	 -30.0	 30.0;
	1185	 135	 0.000178	 0.001047	 0.1499	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 134	 0.000119	 0.000474	 0.0688	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3383	 135	 0.000316	 0.002232	 0.2774	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1879	 136	 0.060864	 0.152469	 0.0071	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	4807	 136	 0.058222	 0.146864	 0.007	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	626	 137	 0.047115	 0.108088	 0.0031	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	3041	 137	 0.036281	 0.154195	 0.0037	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	4519	 138	 0.037227	 0.106836	 0.0328	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 138	 0.006089	 0.020756	 0.0067	 1408	 1408	 1408	 0.0	 0.0	 1	 -30.0	 30.0;
	3550	 139	 0.086848	 0.206626	 0.0036	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	4743	 139	 0.032754	 0.0839	 0.001	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	2995	 140	 0.000729	 0.005118	 0.0933	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2995	 140	 0.000755	 0.005235	 0.0909	 419.0	 419.0	 419.0	 0.0	 0.0	 1	 -30.0	 30.0;
	851	 141	 0.001787	 0.01946	 0.4214	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	185	 142	 0.01615	 0.036583	 0.027	 761	 761	 761	 0.0	 0.0	 1	 -30.0	 30.0;
	1646	 142	 0.018645	 0.048123	 0.0006	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	2211	 142	 0.03351	 0.061476	 0.0006	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	2212	 142	 0.024943	 0.066264	 0.0007	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	3883	 142	 0.079617	 0.198035	 0.0025	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	5715	 142	 0.0194	 0.05291	 0.0006	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	3883	 142	 0.068279	 0.185689	 0.0021	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	1668	 143	 0.001719	 0.00877	 0.0157	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4125	 143	 0.009165	 0.04318	 0.077	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1548	 144	 0.070988	 0.185185	 0.0089	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	1555	 144	 0.000617	 0.001852	 0.0011	 16510	 16510	 16510	 0.0	 0.0	 1	 -30.0	 30.0;
	3685	 144	 0.010988	 0.068148	 0.0006	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	5036	 144	 0.005309	 0.034691	 0.0382	 915	 915	 915	 0.0	 0.0	 1	 -30.0	 30.0;
	5655	 144	 0.00963	 0.059753	 0.0032	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	1555	 144	 0.002346	 0.006173	 0.0002	 4881	 4881	 4881	 0.0	 0.0	 1	 -30.0	 30.0;
	505	 145	 0.004879	 0.032454	 0.0602	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	696	 145	 0.006341	 0.042746	 0.0785	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	759	 145	 0.006914	 0.031249	 0.0547	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1045	 146	 0.000582	 0.007652	 0.2643	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2714	 146	 0.001648	 0.021634	 0.748	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	3365	 146	 0.000838	 0.014301	 0.5198	 2256	 2256	 2256	 0.0	 0.0	 1	 -30.0	 30.0;
	4594	 146	 0.001163	 0.015312	 0.5285	 2077	 2077	 2077	 0.0	 0.0	 1	 -30.0	 30.0;
	1045	 146	 0.000575	 0.007576	 0.2614	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2714	 146	 0.001646	 0.021633	 0.7479	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	3365	 146	 0.000838	 0.014287	 0.5198	 2258	 2258	 2258	 0.0	 0.0	 1	 -30.0	 30.0;
	4595	 146	 0.00117	 0.015339	 0.5285	 2074	 2074	 2074	 0.0	 0.0	 1	 -30.0	 30.0;
	4594	 146	 0.001821	 0.017874	 0.4318	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4971	 147	 0.004485	 0.01683	 0.0154	 1696	 1696	 1696	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 148	 0.003023	 0.01159	 0.0002	 2466	 2466	 2466	 0.0	 0.0	 1	 -30.0	 30.0;
	4234	 149	 0.022222	 0.060124	 0.0029	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	1988	 150	 0.007307	 0.030486	 0.0071	 942	 942	 942	 0.0	 0.0	 1	 -30.0	 30.0;
	4260	 152	 0.070043	 0.190728	 0.0021	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	4512	 151	 0.110103	 0.294533	 0.004	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	4694	 152	 0.034014	 0.145629	 0.0018	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	156	 151	 0.000171	 0.000313	 0.0003	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	3568	 153	 0.042328	 0.115898	 0.001	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	5474	 153	 0.021416	 0.061476	 0.001	 454	 454	 454	 0.0	 0.0	 1	 -30.0	 30.0;
	5716	 153	 0.0194	 0.053414	 0.001	 520	 520	 520	 0.0	 0.0	 1	 -30.0	 30.0;
	5475	 153	 0.021416	 0.061728	 0.0	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	1955	 154	 0.000672	 0.003477	 0.0365	 254.0	 254.0	 254.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5099	 155	 0.000831	 0.001688	 0.0	 16165	 16165	 16165	 0.0	 0.0	 1	 -30.0	 30.0;
	684	 157	 0.138123	 0.332	 0.001	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	4737	 158	 0.000988	 0.003457	 0.0	 7261	 7261	 7261	 0.0	 0.0	 1	 -30.0	 30.0;
	5800	 157	 0.008395	 0.02321	 0.0	 1058	 1058	 1058	 0.0	 0.0	 1	 -30.0	 30.0;
	1721	 159	 0.047518	 0.118922	 0.0013	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	2757	 159	 0.022928	 0.053414	 0.0006	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	2832	 159	 0.080373	 0.201562	 0.004	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	3684	 159	 0.019652	 0.05291	 0.001	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 161	 0.000632	 0.004188	 0.0081	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 160	 0.000612	 0.004148	 0.0071	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4615	 162	 0.024321	 0.06679	 0.0031	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	4661	 162	 0.015062	 0.041605	 0.0019	 672	 672	 672	 0.0	 0.0	 1	 -30.0	 30.0;
	2216	 164	 0.001587	 0.003527	 0.0013	 7864	 7864	 7864	 0.0	 0.0	 1	 -30.0	 30.0;
	2216	 163	 0.001587	 0.003527	 0.0013	 7864	 7864	 7864	 0.0	 0.0	 1	 -30.0	 30.0;
	1405	 167	 0.03642	 0.095185	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	1585	 167	 0.014938	 0.061852	 0.0046	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3611	 167	 0.043951	 0.11642	 0.007	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 166	 0.014815	 0.033457	 0.0015	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	4171	 166	 0.004198	 0.010741	 0.0013	 2576	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	4488	 166	 0.02	 0.049136	 0.0629	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 167	 0.014444	 0.036173	 0.0018	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 167	 0.015679	 0.042593	 0.0019	 655	 655	 655	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 166	 0.041975	 0.106173	 0.0125	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	3442	 166	 0.022753	 0.056914	 0.0028	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	5844	 166	 0.031235	 0.082839	 0.0042	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	3696	 168	 0.000672	 0.004405	 0.0081	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 168	 0.000968	 0.004602	 0.0081	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3696	 168	 0.000632	 0.004444	 0.0081	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 169	 0.016173	 0.044198	 0.0021	 632	 632	 632	 0.0	 0.0	 1	 -30.0	 30.0;
	2563	 170	 0.001481	 0.005679	 0.0267	 5167	 5167	 5167	 0.0	 0.0	 1	 -30.0	 30.0;
	5580	 170	 0.008642	 0.018272	 0.0045	 1501	 1501	 1501	 0.0	 0.0	 1	 -30.0	 30.0;
	1558	 171	 0.006173	 0.026296	 0.0015	 1125	 1125	 1125	 0.0	 0.0	 1	 -30.0	 30.0;
	4613	 171	 0.039753	 0.105062	 0.0073	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 171	 0.010617	 0.027407	 0.0034	 1035	 1035	 1035	 0.0	 0.0	 1	 -30.0	 30.0;
	1558	 171	 0.006173	 0.026173	 0.0013	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	5668	 172	 0.001975	 0.013215	 0.0243	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5669	 172	 0.001956	 0.013037	 0.0243	 2348	 2348	 2348	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 173	 0.000988	 0.004074	 0.0002	 8279	 8279	 8279	 0.0	 0.0	 1	 -30.0	 30.0;
	445	 174	 0.030494	 0.121605	 0.0071	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	5359	 174	 0.009877	 0.025062	 0.0011	 1284	 1284	 1284	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 174	 0.020741	 0.052469	 0.0003	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	5143	 175	 0.018896	 0.056185	 0.0006	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	5158	 175	 0.002771	 0.008314	 0.0001	 3471	 3471	 3471	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 176	 0.002933	 0.010267	 0.0032	 2959	 2959	 2959	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 176	 0.0028	 0.007511	 0.0022	 3941	 3941	 3941	 0.0	 0.0	 1	 -30.0	 30.0;
	180	 177	 2e-05	 0.000198	 0.0121	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	180	 178	 2e-05	 0.000198	 0.0142	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	911	 179	 0.001008	 0.002268	 0.0034	 11544	 11544	 11544	 0.0	 0.0	 1	 -30.0	 30.0;
	1444	 179	 0.002771	 0.007055	 0.0075	 3780	 3780	 3780	 0.0	 0.0	 1	 -30.0	 30.0;
	1488	 179	 0.008411	 0.015397	 0.0491	 1634	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	3460	 179	 0.008566	 0.016377	 0.0064	 1551	 1551	 1551	 0.0	 0.0	 1	 -30.0	 30.0;
	4927	 179	 0.006299	 0.01159	 0.0008	 2172	 2172	 2172	 0.0	 0.0	 1	 -30.0	 30.0;
	4932	 179	 0.002478	 0.004537	 0.0024	 5543	 5543	 5543	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 179	 0.006488	 0.011876	 0.015	 2118	 2118	 2118	 0.0	 0.0	 1	 -30.0	 30.0;
	912	 179	 0.001008	 0.002771	 0.0037	 9717	 9717	 9717	 0.0	 0.0	 1	 -30.0	 30.0;
	1444	 179	 0.003191	 0.005842	 0.0075	 4305	 4305	 4305	 0.0	 0.0	 1	 -30.0	 30.0;
	1444	 179	 0.002771	 0.007307	 0.0079	 3667	 3667	 3667	 0.0	 0.0	 1	 -30.0	 30.0;
	4930	 179	 0.000756	 0.002268	 0.003	 11985	 11985	 11985	 0.0	 0.0	 1	 -30.0	 30.0;
	4931	 179	 0.000974	 0.001783	 0.0033	 14102	 14102	 14102	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 180	 0.000277	 0.000928	 0.2066	 31961	 31961	 31961	 0.0	 0.0	 1	 -30.0	 30.0;
	1046	 180	 0.002037	 0.010904	 0.0187	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1119	 180	 0.000415	 0.002015	 0.1266	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1264	 180	 0.000395	 0.00156	 0.1893	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2100	 180	 4e-05	 0.000178	 0.0152	 169660	 169660	 169660	 0.0	 0.0	 1	 -30.0	 30.0;
	2959	 180	 0.001323	 0.012444	 0.0678	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4378	 180	 0.000454	 0.002133	 0.2511	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4937	 180	 0.000119	 0.000691	 0.1002	 387.0	 387.0	 387.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5028	 180	 0.00083	 0.005175	 0.0203	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 180	 0.000277	 0.000928	 0.2086	 31961	 31961	 31961	 0.0	 0.0	 1	 -30.0	 30.0;
	2959	 180	 0.001314	 0.012115	 0.0673	 943.0	 943.0	 943.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4934	 180	 5.9e-05	 0.000217	 0.0496	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4933	 180	 5.9e-05	 0.000217	 0.0466	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 181	 0.023583	 0.064324	 0.0007	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	4403	 182	 0.000854	 0.001563	 0.0007	 16580	 16580	 16580	 0.0	 0.0	 1	 -30.0	 30.0;
	5105	 183	 0.015369	 0.060469	 0.0013	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	1031	 184	 0.004314	 0.007897	 0.0123	 3370	 3370	 3370	 0.0	 0.0	 1	 -30.0	 30.0;
	5378	 185	 0.009625	 0.024339	 0.0003	 1163	 1163	 1163	 0.0	 0.0	 1	 -30.0	 30.0;
	5106	 186	 0.002593	 0.00716	 0.0003	 3901	 3901	 3901	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 187	 0.008566	 0.018896	 0.0002	 1466	 1466	 1466	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 188	 0.020912	 0.071303	 0.0008	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	2241	 189	 0.041068	 0.139078	 0.0016	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	5594	 189	 0.070547	 0.233132	 0.0127	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	5107	 190	 0.000494	 0.000988	 0.0	 23633	 23633	 23633	 0.0	 0.0	 1	 -30.0	 30.0;
	2743	 191	 0.018025	 0.049136	 0.0023	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	4828	 191	 0.024198	 0.061728	 0.0029	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	317	 192	 0.062232	 0.138574	 0.0015	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5088	 192	 0.035525	 0.084782	 0.0009	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	4087	 193	 0.000158	 0.000948	 0.002	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2497	 194	 0.043588	 0.119174	 0.0013	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	2773	 194	 0.095062	 0.299849	 0.0069	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	5327	 194	 0.048375	 0.166037	 0.002	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3208	 195	 0.004193	 0.007675	 0.0057	 3453	 3453	 3453	 0.0	 0.0	 1	 -30.0	 30.0;
	3208	 196	 0.004377	 0.008012	 0.0058	 3308	 3308	 3308	 0.0	 0.0	 1	 -30.0	 30.0;
	321	 197	 0.035273	 0.218443	 0.0029	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	573	 197	 0.000252	 0.000504	 0.0	 53974	 53974	 53974	 0.0	 0.0	 1	 -30.0	 30.0;
	930	 197	 0.034442	 0.11809	 0.0091	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	321	 197	 0.034266	 0.221466	 0.0	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	826	 198	 0.0839	 0.229025	 0.0025	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 198	 0.048627	 0.123205	 0.0014	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 199	 0.008025	 0.021852	 0.001	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	2448	 200	 0.001521	 0.007076	 0.0118	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4552	 200	 0.002469	 0.011457	 0.0203	 315.0	 315.0	 315.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1376	 201	 0.001442	 0.009699	 0.0172	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1482	 201	 0.001422	 0.009541	 0.0172	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	392	 202	 0.024691	 0.056941	 0.001	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	829	 203	 0.006914	 0.029259	 0.0015	 1051	 1051	 1051	 0.0	 0.0	 1	 -30.0	 30.0;
	1919	 203	 0.007037	 0.029877	 0.0015	 1030	 1030	 1030	 0.0	 0.0	 1	 -30.0	 30.0;
	2062	 203	 0.02037	 0.08642	 0.0044	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	2712	 203	 0.007531	 0.047037	 0.0047	 674	 674	 674	 0.0	 0.0	 1	 -30.0	 30.0;
	2985	 203	 0.019136	 0.051481	 0.0024	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	829	 203	 0.007531	 0.031605	 0.0016	 973	 973	 973	 0.0	 0.0	 1	 -30.0	 30.0;
	1919	 203	 0.00716	 0.031852	 0.0021	 968	 968	 968	 0.0	 0.0	 1	 -30.0	 30.0;
	1584	 204	 0.004681	 0.028227	 0.0516	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2713	 204	 0.001185	 0.008	 0.0152	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5686	 204	 0.005333	 0.02722	 0.0491	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2714	 205	 0.000145	 0.001911	 0.0661	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5056	 205	 0.000253	 0.003323	 0.1148	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	392	 206	 0.018645	 0.041068	 0.0005	 655	 655	 655	 0.0	 0.0	 1	 -30.0	 30.0;
	1683	 206	 0.049131	 0.124465	 0.0014	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5127	 206	 0.02192	 0.091207	 0.0011	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	563	 207	 0.015117	 0.039808	 0.0005	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	563	 207	 0.015117	 0.039808	 0.0005	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	5577	 208	 0.012296	 0.031173	 0.0015	 905	 905	 905	 0.0	 0.0	 1	 -30.0	 30.0;
	5842	 208	 0.020988	 0.06716	 0.0032	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	3922	 209	 0.004787	 0.018141	 0.0002	 1574	 1574	 1574	 0.0	 0.0	 1	 -30.0	 30.0;
	1791	 211	 0.003779	 0.020912	 0.0028	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	4829	 210	 0.007055	 0.020408	 0.0002	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	1791	 211	 0.003779	 0.020912	 0.0028	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	3866	 212	 0.000494	 0.002252	 0.004	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3866	 213	 0.000494	 0.002252	 0.004	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	525	 214	 0.000741	 0.001358	 0.0036	 19602	 19602	 19602	 0.0	 0.0	 1	 -30.0	 30.0;
	1177	 214	 0.044444	 0.111728	 0.0053	 253	 253	 253	 0.0	 0.0	 1	 -30.0	 30.0;
	1415	 214	 0.093457	 0.227654	 0.0115	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	1732	 214	 0.024938	 0.06642	 0.0032	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	1879	 214	 0.045309	 0.116049	 0.0055	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	4063	 214	 0.06758	 0.184444	 0.0162	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	4905	 214	 0.065062	 0.177531	 0.0083	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	352	 215	 0.004563	 0.030696	 0.0557	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1131	 215	 0.009857	 0.04478	 0.077	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2885	 215	 0.017106	 0.078321	 0.1387	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4617	 215	 0.010272	 0.048691	 0.0866	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1983	 216	 0.11867	 0.311413	 0.0041	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	5410	 216	 0.087931	 0.176115	 0.0018	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	1513	 217	 0.057654	 0.152716	 0.0076	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	1577	 217	 0.037654	 0.101605	 0.0047	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	2762	 218	 0.00037	 0.001235	 0.0015	 23039	 23039	 23039	 0.0	 0.0	 1	 -30.0	 30.0;
	5111	 219	 0.013827	 0.037778	 0.0018	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	5109	 220	 0.015631	 0.028612	 0.0002	 933	 933	 933	 0.0	 0.0	 1	 -30.0	 30.0;
	255	 221	 0.093978	 0.258755	 0.004	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	2038	 221	 0.160699	 0.294157	 0.003	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	4392	 221	 0.059209	 0.163265	 0.0019	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	1594	 222	 0.012978	 0.059338	 0.1002	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 222	 0.01197	 0.056632	 0.0942	 262.0	 262.0	 262.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2307	 223	 0.014613	 0.039808	 0.0005	 718	 718	 718	 0.0	 0.0	 1	 -30.0	 30.0;
	4146	 223	 0.114412	 0.301335	 0.0036	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	2307	 223	 0.026002	 0.055883	 0.0011	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 224	 0.000578	 0.001156	 0.0004	 24440	 24440	 24440	 0.0	 0.0	 1	 -30.0	 30.0;
	3825	 226	 0.000316	 0.001679	 0.0192	 17970	 17970	 17970	 0.0	 0.0	 1	 -30.0	 30.0;
	3825	 225	 0.000316	 0.001679	 0.0192	 17970	 17970	 17970	 0.0	 0.0	 1	 -30.0	 30.0;
	1545	 228	 0.06576	 0.166541	 0.0019	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	1545	 227	 0.063946	 0.174402	 0.002	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	422	 229	 0.015369	 0.064399	 0.0106	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	3134	 229	 0.163093	 0.298541	 0.0034	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	4557	 229	 0.017407	 0.031864	 0.0009	 838	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	422	 229	 0.015344	 0.064248	 0.0103	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	2483	 230	 0.000277	 0.000573	 0.0334	 48541	 48541	 48541	 0.0	 0.0	 1	 -30.0	 30.0;
	520	 231	 0.049383	 0.134444	 0.0063	 208	 208	 208	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 232	 0.009383	 0.039012	 0.0019	 772	 772	 772	 0.0	 0.0	 1	 -30.0	 30.0;
	4877	 232	 0.015803	 0.066543	 0.0034	 453	 453	 453	 0.0	 0.0	 1	 -30.0	 30.0;
	3662	 234	 0.009012	 0.029012	 0.0003	 1054	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	3663	 235	 0.001055	 0.004836	 0.0081	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	504	 236	 0.003951	 0.010247	 0.0005	 2910	 2910	 2910	 0.0	 0.0	 1	 -30.0	 30.0;
	1011	 237	 0.042303	 0.10708	 0.0017	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 237	 0.006047	 0.015117	 0.0	 1814	 1814	 1814	 0.0	 0.0	 1	 -30.0	 30.0;
	2690	 238	 0.035185	 0.095802	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	5007	 238	 0.039691	 0.108716	 0.0052	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	2374	 239	 0.081633	 0.151675	 0.0016	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	4602	 239	 0.057949	 0.240111	 0.003	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	5437	 239	 0.006299	 0.017133	 0.0038	 1618	 1618	 1618	 0.0	 0.0	 1	 -30.0	 30.0;
	5729	 239	 0.047871	 0.197783	 0.0025	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	360	 240	 0.044092	 0.11164	 0.0017	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	4553	 240	 0.003704	 0.023029	 0.0026	 1304	 1304	 1304	 0.0	 0.0	 1	 -30.0	 30.0;
	692	 241	 0.009111	 0.029012	 0.0043	 998	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	4445	 241	 0.020926	 0.060074	 0.0028	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	5488	 241	 0.014222	 0.048111	 0.0024	 605	 605	 605	 0.0	 0.0	 1	 -30.0	 30.0;
	1683	 242	 0.056437	 0.160242	 0.0019	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 242	 0.050894	 0.146384	 0.0017	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	3148	 243	 0.058957	 0.160494	 0.0018	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 243	 0.067019	 0.17032	 0.0019	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	1922	 244	 0.038148	 0.094691	 0.018	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	2348	 244	 0.034259	 0.085321	 0.0145	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	5114	 245	 0.058705	 0.164777	 0.0018	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	282	 246	 0.004031	 0.009826	 0.0001	 2780	 2780	 2780	 0.0	 0.0	 1	 -30.0	 30.0;
	479	 246	 0.024943	 0.112371	 0.003	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	751	 246	 0.006097	 0.011161	 0.0002	 2322	 2322	 2322	 0.0	 0.0	 1	 -30.0	 30.0;
	2444	 246	 0.106843	 0.195575	 0.0051	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	4725	 246	 0.010582	 0.039557	 0.001	 722	 722	 722	 0.0	 0.0	 1	 -30.0	 30.0;
	3572	 247	 0.002114	 0.008553	 0.0152	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3160	 248	 0.000198	 0.000731	 0.0942	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2108	 249	 0.058705	 0.235072	 0.0025	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	3561	 249	 0.042378	 0.116024	 0.0134	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	1267	 250	 0.087176	 0.228773	 0.0059	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	1621	 250	 0.092727	 0.169735	 0.005	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	2256	 250	 0.113127	 0.312169	 0.006	 92	 92	 92	 0.0	 0.0	 1	 -30.0	 30.0;
	2939	 251	 0.005424	 0.009929	 0.0373	 2626	 2626	 2626	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 252	 0.026667	 0.07037	 0.0032	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	5106	 252	 0.00963	 0.026049	 0.0011	 1070	 1070	 1070	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 253	 0.004812	 0.019703	 0.0002	 1500	 1500	 1500	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 253	 0.005039	 0.022424	 0.0002	 1324	 1324	 1324	 0.0	 0.0	 1	 -30.0	 30.0;
	1113	 254	 0.067599	 0.171378	 0.0019	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	3815	 254	 0.043336	 0.111363	 0.0013	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	4634	 254	 0.004787	 0.013102	 0.0002	 2181	 2181	 2181	 0.0	 0.0	 1	 -30.0	 30.0;
	559	 255	 0.166768	 0.305266	 0.003	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	1681	 255	 0.06198	 0.171076	 0.0042	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	4161	 256	 0.037365	 0.080247	 0.0009	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	4550	 256	 0.06198	 0.162409	 0.0017	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	4552	 257	 0.00324	 0.012616	 0.0225	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1109	 258	 0.005679	 0.015185	 0.0006	 1875	 1875	 1875	 0.0	 0.0	 1	 -30.0	 30.0;
	763	 259	 0.086288	 0.157948	 0.0015	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	1455	 259	 0.000882	 0.002494	 0.0021	 11497	 11497	 11497	 0.0	 0.0	 1	 -30.0	 30.0;
	4975	 260	 0.007522	 0.029736	 0.0496	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5795	 260	 0.006809	 0.03043	 0.0521	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5115	 261	 0.038297	 0.078861	 0.0	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	1376	 263	 0.002153	 0.014736	 0.0273	 565.0	 565.0	 565.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1623	 262	 0.000581	 0.003838	 0.0071	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2790	 262	 0.001857	 0.020306	 0.0557	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 263	 0.002331	 0.015526	 0.0278	 549.0	 549.0	 549.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5407	 262	 0.001345	 0.008968	 0.0162	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1622	 262	 0.000573	 0.003911	 0.0071	 415.0	 415.0	 415.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2199	 262	 0.001896	 0.012701	 0.0233	 501.0	 501.0	 501.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1939	 264	 0.000602	 0.006717	 0.1357	 1725.0	 1725.0	 1725.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 264	 0.00063	 0.007098	 0.1588	 1916.0	 1916.0	 1916.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 264	 0.000367	 0.004631	 0.1126	 2275.0	 2275.0	 2275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 264	 0.000472	 0.006201	 0.2137	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5057	 264	 0.001504	 0.019298	 0.4577	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	728	 265	 0.001844	 0.003375	 0.0026	 7450	 7450	 7450	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 266	 0.000158	 0.001106	 0.1357	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1273	 267	 0.000219	 0.00193	 0.1954	 407.0	 407.0	 407.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1372	 267	 0.000158	 0.000909	 0.1316	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3521	 267	 0.000411	 0.00356	 0.3564	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3873	 266	 0.000158	 0.001264	 0.1286	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 268	 0.045855	 0.121189	 0.0013	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	2673	 268	 0.064248	 0.156211	 0.0018	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	549	 269	 0.100277	 0.244898	 0.0026	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	5278	 269	 0.072411	 0.175888	 0.0019	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	2982	 271	 0.000198	 0.001383	 0.003	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2982	 270	 0.000217	 0.001402	 0.003	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1409	 272	 0.036029	 0.091711	 0.001	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	1695	 272	 0.018896	 0.047367	 0.0008	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	4442	 272	 0.003427	 0.009272	 0.0121	 2987	 2987	 2987	 0.0	 0.0	 1	 -30.0	 30.0;
	4832	 272	 0.006299	 0.018392	 0.0164	 1519	 1519	 1519	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 272	 0.017637	 0.044092	 0.0008	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	5792	 272	 0.046273	 0.084703	 0.0015	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	4442	 272	 0.00383	 0.008869	 0.0143	 3057	 3057	 3057	 0.0	 0.0	 1	 -30.0	 30.0;
	1321	 273	 0.001304	 0.008691	 0.0152	 525.0	 525.0	 525.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2982	 273	 0.000691	 0.004662	 0.0091	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 274	 0.009506	 0.058889	 0.0039	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 274	 0.009383	 0.058765	 0.0031	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	278	 275	 9.9e-05	 0.000415	 0.0456	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1052	 276	 1e-06	 0.000104	 0.078	 1078.0	 1078.0	 1078.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1515	 276	 0.000353	 0.004584	 0.1184	 2357.0	 2357.0	 2357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2451	 276	 0.000699	 0.009179	 0.3177	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1515	 276	 0.000353	 0.004584	 0.1184	 2357.0	 2357.0	 2357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2451	 276	 0.000734	 0.009245	 0.3148	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1056	 276	 7e-06	 0.000104	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1055	 276	 7e-06	 0.000104	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	740	 277	 0.01	 0.026667	 0.0046	 1043	 1043	 1043	 0.0	 0.0	 1	 -30.0	 30.0;
	981	 277	 0.049259	 0.114321	 0.0079	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	1054	 277	 0.019383	 0.049383	 0.0256	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	741	 277	 0.009877	 0.026667	 0.0046	 1045	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	1053	 277	 0.02037	 0.052469	 0.0097	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 278	 0.002556	 0.017333	 0.0805	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3696	 278	 0.008849	 0.062617	 0.1144	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2980	 279	 0.024943	 0.069287	 0.0	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	2461	 280	 0.032259	 0.085247	 0.0109	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	4945	 280	 0.051284	 0.130198	 0.0139	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 280	 0.049012	 0.133827	 0.0063	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	2461	 280	 0.006543	 0.026148	 0.1306	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	1258	 281	 0.136634	 0.39607	 0.0046	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 283	 0.000617	 0.001728	 0.0	 16188	 16188	 16188	 0.0	 0.0	 1	 -30.0	 30.0;
	448	 284	 0.010582	 0.03351	 0.0004	 866	 866	 866	 0.0	 0.0	 1	 -30.0	 30.0;
	2663	 284	 0.000227	 0.000907	 0.0013	 32529	 32529	 32529	 0.0	 0.0	 1	 -30.0	 30.0;
	3638	 284	 0.00907	 0.026707	 0.0103	 1079	 1079	 1079	 0.0	 0.0	 1	 -30.0	 30.0;
	5117	 285	 2.2e-05	 9.9e-05	 0.001	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5116	 286	 2e-05	 9.9e-05	 0.0	 306461	 306461	 306461	 0.0	 0.0	 1	 -30.0	 30.0;
	960	 287	 0.025062	 0.064074	 0.0135	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	2316	 288	 1.2e-05	 0.000123	 0.0002	 240340	 240340	 240340	 0.0	 0.0	 1	 -30.0	 30.0;
	2905	 288	 0.00679	 0.013704	 0.0523	 1943	 1943	 1943	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 288	 0.022346	 0.075432	 0.0037	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	5426	 288	 1.2e-05	 0.000123	 0.0002	 240340	 240340	 240340	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 289	 0.000573	 0.002588	 0.0051	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2789	 290	 0.002407	 0.006741	 0.0242	 4503	 4503	 4503	 0.0	 0.0	 1	 -30.0	 30.0;
	2165	 291	 0.102041	 0.259007	 0.0029	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	2624	 291	 0.060555	 0.110845	 0.0026	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	3148	 291	 0.053918	 0.146888	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5195	 291	 0.047367	 0.19098	 0.0021	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	292	 293	 0.00385	 0.007048	 0.0043	 3677	 3677	 3677	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 293	 0.039808	 0.117914	 0.0111	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	1564	 293	 0.019854	 0.04772	 0.0085	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 294	 0.011208	 0.020515	 0.0007	 1302	 1302	 1302	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 295	 2e-05	 0.000198	 0.001	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1299	 296	 0.085412	 0.216931	 0.0024	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 297	 0.003275	 0.008062	 0.0001	 3394	 3394	 3394	 0.0	 0.0	 1	 -30.0	 30.0;
	4315	 298	 0.027715	 0.069791	 0.001	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	2159	 299	 0.000988	 0.003827	 0.001	 8155	 8155	 8155	 0.0	 0.0	 1	 -30.0	 30.0;
	2160	 300	 0.000138	 0.00077	 0.001	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 301	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	1340	 302	 0.006551	 0.028219	 0.042	 1020	 1020	 1020	 0.0	 0.0	 1	 -30.0	 30.0;
	1340	 302	 0.005291	 0.024036	 0.0256	 1200	 1200	 1200	 0.0	 0.0	 1	 -30.0	 30.0;
	197	 303	 0.036533	 0.120433	 0.0015	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	4586	 303	 0.071303	 0.195263	 0.0022	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	5737	 303	 0.046259	 0.156664	 0.0024	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	197	 303	 0.036533	 0.120433	 0.0015	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	4586	 303	 0.071378	 0.195288	 0.0022	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 304	 0.039305	 0.163517	 0.0072	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 304	 0.04006	 0.090703	 0.0039	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	690	 305	 0.091993	 0.168392	 0.001	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 305	 0.059713	 0.134543	 0.001	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	3889	 306	 0.090023	 0.243966	 0.0043	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	2476	 307	 0.055309	 0.140247	 0.0065	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4928	 307	 0.027531	 0.070124	 0.0032	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	1305	 308	 0.023003	 0.052003	 0.0006	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	4574	 308	 0.01358	 0.034114	 0.0004	 829	 829	 829	 0.0	 0.0	 1	 -30.0	 30.0;
	1632	 310	 0.001512	 0.010078	 0.014	 2898	 2898	 2898	 0.0	 0.0	 1	 -30.0	 30.0;
	1632	 309	 0.006551	 0.012094	 0.0046	 2147	 2147	 2147	 0.0	 0.0	 1	 -30.0	 30.0;
	5613	 311	 0.003951	 0.007901	 0.0003	 3363	 3363	 3363	 0.0	 0.0	 1	 -30.0	 30.0;
	3145	 312	 0.000123	 0.001235	 0.0006	 24326	 24326	 24326	 0.0	 0.0	 1	 -30.0	 30.0;
	2635	 313	 0.003049	 0.011111	 0.0172	 2640	 2640	 2640	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 313	 0.024188	 0.061476	 0.0007	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	5151	 313	 0.008818	 0.053918	 0.0007	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	654	 314	 0.001171	 0.007842	 0.0166	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 314	 0.002212	 0.014979	 0.0388	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1031	 315	 0.025309	 0.057778	 0.0026	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	5121	 315	 0.000741	 0.001852	 0.0002	 15203	 15203	 15203	 0.0	 0.0	 1	 -30.0	 30.0;
	2282	 316	 0.021416	 0.086672	 0.0011	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	5278	 316	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 316	 0.00252	 0.006551	 0.0001	 4334	 4334	 4334	 0.0	 0.0	 1	 -30.0	 30.0;
	2282	 316	 0.021164	 0.08642	 0.0011	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	3290	 317	 0.083799	 0.195137	 0.0022	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	3268	 318	 0.002585	 0.004732	 0.0029	 5314	 5314	 5314	 0.0	 0.0	 1	 -30.0	 30.0;
	5122	 319	 0.000479	 0.001285	 0.0	 22178	 22178	 22178	 0.0	 0.0	 1	 -30.0	 30.0;
	1253	 320	 0.019259	 0.061728	 0.0021	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	1651	 320	 0.020123	 0.051111	 0.0021	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	830	 321	 0.008679	 0.015886	 0.0142	 1681	 1681	 1681	 0.0	 0.0	 1	 -30.0	 30.0;
	2304	 321	 0.035878	 0.14646	 0.0	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	3120	 321	 0.009675	 0.060166	 0.0022	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	3140	 321	 0.039053	 0.145377	 0.0054	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	4563	 321	 0.040312	 0.118166	 0.0049	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	2304	 321	 0.036054	 0.147241	 0.0074	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	3120	 321	 0.0097	 0.060393	 0.0027	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	3140	 321	 0.020408	 0.13026	 0.0016	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	3120	 321	 0.020106	 0.076216	 0.0011	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	4142	 322	 0.000691	 0.002588	 0.1691	 11556	 11556	 11556	 0.0	 0.0	 1	 -30.0	 30.0;
	4143	 322	 0.000691	 0.002588	 0.1509	 11556	 11556	 11556	 0.0	 0.0	 1	 -30.0	 30.0;
	1929	 323	 0.001627	 0.014855	 0.3899	 1717.0	 1717.0	 1717.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1929	 323	 0.001676	 0.013899	 0.4216	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2305	 324	 0.002771	 0.009574	 0.0091	 2963	 2963	 2963	 0.0	 0.0	 1	 -30.0	 30.0;
	1676	 324	 0.002771	 0.010834	 0.016	 2641	 2641	 2641	 0.0	 0.0	 1	 -30.0	 30.0;
	522	 325	 0.027186	 0.073369	 0.0039	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	521	 325	 0.027085	 0.073243	 0.0034	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	1839	 326	 0.023285	 0.042623	 0.0	 627	 627	 627	 0.0	 0.0	 1	 -30.0	 30.0;
	2603	 326	 0.04258	 0.112371	 0.0012	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	2918	 326	 0.062988	 0.133535	 0.0017	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 326	 0.006677	 0.035122	 0.0059	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 326	 0.039053	 0.099017	 0.0011	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 326	 0.006551	 0.035021	 0.0059	 854	 854	 854	 0.0	 0.0	 1	 -30.0	 30.0;
	1790	 327	 0.003081	 0.020286	 0.0365	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3079	 327	 0.00241	 0.01603	 0.0294	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 328	 0.034014	 0.100025	 0.0012	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 328	 0.048526	 0.153691	 0.0023	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	2265	 329	 0.001605	 0.009877	 0.0342	 3207	 3207	 3207	 0.0	 0.0	 1	 -30.0	 30.0;
	2265	 329	 0.00284	 0.006049	 0.0031	 4803	 4803	 4803	 0.0	 0.0	 1	 -30.0	 30.0;
	4389	 330	 0.0194	 0.049635	 0.0022	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	4648	 330	 0.000252	 0.00126	 0.0	 23670	 23670	 23670	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 330	 0.028975	 0.075082	 0.0009	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	4664	 331	 0.000176	 0.001385	 0.1521	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4853	 331	 0.001817	 0.012642	 0.0233	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4853	 331	 0.001865	 0.012502	 0.0229	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1363	 332	 0.039053	 0.099269	 0.0011	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	3676	 332	 0.074578	 0.195767	 0.0022	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	1006	 333	 0.007422	 0.024489	 0.0081	 1190	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 333	 0.028356	 0.083956	 0.0274	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	2542	 333	 0.016844	 0.058489	 0.0198	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	4760	 333	 0.009067	 0.028133	 0.0095	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 334	 0.051146	 0.143613	 0.0016	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	1133	 335	 0.001008	 0.00252	 0.0	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	2817	 336	 0.028723	 0.075082	 0.0009	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	4918	 336	 0.01285	 0.032502	 0.0004	 871	 871	 871	 0.0	 0.0	 1	 -30.0	 30.0;
	2497	 337	 0.098514	 0.257748	 0.0029	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	2639	 337	 0.179853	 0.329219	 0.0038	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	1694	 338	 0.039557	 0.089695	 0.001	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	1858	 338	 0.053726	 0.098344	 0.0014	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	3290	 339	 0.111615	 0.283699	 0.0033	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	3494	 339	 0.037213	 0.126279	 0.0015	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	5794	 339	 0.090199	 0.228773	 0.0026	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	3056	 340	 0.054938	 0.149753	 0.007	 188	 188	 188	 0.0	 0.0	 1	 -30.0	 30.0;
	3378	 341	 0.067574	 0.180927	 0.0108	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3231	 342	 0.041824	 0.115394	 0.0013	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	3880	 342	 0.041975	 0.173293	 0.0021	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5398	 342	 0.015117	 0.080625	 0.0006	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	5124	 343	 0.000593	 0.00401	 0.0071	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1859	 344	 0.055959	 0.123205	 0.0037	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	4518	 344	 0.130763	 0.331822	 0.0039	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 344	 0.116906	 0.21416	 0.0029	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	671	 345	 0.048272	 0.114444	 0.0049	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	1725	 345	 0.065679	 0.150988	 0.0068	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	1278	 346	 0.010351	 0.032395	 0.0562	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	5447	 346	 0.009146	 0.025778	 0.041	 1123	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	4916	 347	 0.060217	 0.164273	 0.0018	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	444	 348	 0.022839	 0.046914	 0.0021	 616	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	3375	 348	 0.035062	 0.071852	 0.0074	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	3311	 349	 0.000395	 0.006648	 0.2426	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3365	 349	 0.000492	 0.008345	 0.3032	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3766	 350	 0.001198	 0.015699	 0.5401	 2031	 2031	 2031	 0.0	 0.0	 1	 -30.0	 30.0;
	3899	 350	 0.000734	 0.010623	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4594	 349	 0.001479	 0.019446	 0.6729	 1639	 1639	 1639	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 350	 0.000305	 0.003975	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3312	 349	 0.000395	 0.006641	 0.2426	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3365	 350	 0.000492	 0.008338	 0.3032	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3766	 349	 0.001184	 0.015568	 0.5372	 2048	 2048	 2048	 0.0	 0.0	 1	 -30.0	 30.0;
	3899	 349	 0.000734	 0.010623	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4595	 350	 0.001482	 0.019467	 0.6729	 1638	 1638	 1638	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 349	 0.000305	 0.003982	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3313	 350	 0.000388	 0.0066	 0.2397	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3310	 350	 0.000388	 0.006593	 0.2397	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4019	 351	 0.001817	 0.012049	 0.0233	 439.0	 439.0	 439.0	 0.0	 0.0	 1	 -30.0	 30.0;
	558	 352	 0.003496	 0.023269	 0.0425	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	880	 353	 0.03225	 0.10456	 0.0013	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2688	 353	 0.004558	 0.008344	 0.0062	 3014	 3014	 3014	 0.0	 0.0	 1	 -30.0	 30.0;
	5839	 353	 0.018645	 0.063996	 0.0007	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	5126	 354	 0.001008	 0.00252	 0.0	 11206	 11206	 11206	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 355	 0.050139	 0.112371	 0.0012	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	358	 356	 0.004031	 0.010078	 0.0001	 2802	 2802	 2802	 0.0	 0.0	 1	 -30.0	 30.0;
	1350	 357	 0.114764	 0.210075	 0.006	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	3144	 357	 0.065294	 0.11952	 0.0013	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 357	 0.037818	 0.16125	 0.0025	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	2293	 358	 0.07231	 0.176619	 0.002	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	3023	 358	 0.053414	 0.133787	 0.001	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5129	 358	 0.002268	 0.005014	 0.0001	 5527	 5527	 5527	 0.0	 0.0	 1	 -30.0	 30.0;
	5608	 358	 0.006551	 0.016881	 0.0002	 1680	 1680	 1680	 0.0	 0.0	 1	 -30.0	 30.0;
	1683	 359	 0.028723	 0.06324	 0.0007	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	4015	 360	 0.028849	 0.113731	 0.042	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	4553	 360	 0.004031	 0.024691	 0.0003	 1216	 1216	 1216	 0.0	 0.0	 1	 -30.0	 30.0;
	4919	 360	 0.016881	 0.042832	 0.0005	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	5147	 360	 0.008239	 0.053641	 0.0017	 561	 561	 561	 0.0	 0.0	 1	 -30.0	 30.0;
	2440	 361	 0.019498	 0.06712	 0.0206	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 362	 0.006262	 0.040849	 0.0749	 398.0	 398.0	 398.0	 0.0	 0.0	 1	 -30.0	 30.0;
	490	 363	 0.008272	 0.035062	 0.0171	 860	 860	 860	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 363	 0.002346	 0.009877	 0.0002	 3419	 3419	 3419	 0.0	 0.0	 1	 -30.0	 30.0;
	5102	 363	 0.002346	 0.009753	 0.0002	 3460	 3460	 3460	 0.0	 0.0	 1	 -30.0	 30.0;
	4391	 364	 2e-05	 0.000198	 0.003	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	4733	 365	 0.001114	 0.002039	 0.0009	 12708	 12708	 12708	 0.0	 0.0	 1	 -30.0	 30.0;
	2132	 366	 0.001936	 0.0128	 0.0182	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	859	 369	 2e-05	 0.000198	 0.0081	 155924	 155924	 155924	 0.0	 0.0	 1	 -30.0	 30.0;
	3383	 369	 0.000296	 0.000988	 0.2207	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	860	 370	 8.5e-05	 0.000198	 0.0192	 386.0	 386.0	 386.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3004	 371	 0.025145	 0.068808	 0.0008	 416	 416	 416	 0.0	 0.0	 1	 -30.0	 30.0;
	3074	 371	 0.011892	 0.061199	 0.0007	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	1897	 372	 0.002487	 0.016492	 0.0304	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2169	 372	 0.000873	 0.003563	 0.004	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2755	 372	 0.003563	 0.023682	 0.044	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3756	 372	 0.002724	 0.018108	 0.0334	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2168	 372	 0.000873	 0.003563	 0.004	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3383	 373	 0.000257	 0.000928	 0.1134	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3544	 374	 0.0839	 0.212648	 0.0024	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 374	 0.083396	 0.21164	 0.0024	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	1169	 375	 0.055309	 0.150988	 0.0071	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 375	 0.039753	 0.108519	 0.005	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	2575	 375	 0.034691	 0.094568	 0.0044	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	2093	 376	 0.049383	 0.137062	 0.0016	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	2097	 376	 0.029479	 0.186445	 0.0024	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2097	 376	 0.02973	 0.188461	 0.0024	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	647	 377	 0.047292	 0.098262	 0.0011	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	2322	 377	 0.066012	 0.13681	 0.0015	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	2766	 377	 0.046107	 0.127236	 0.0014	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	401	 378	 0.069035	 0.187957	 0.0021	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	1252	 378	 0.057924	 0.106028	 0.0026	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	1532	 378	 0.174099	 0.45553	 0.0051	 61	 61	 61	 0.0	 0.0	 1	 -30.0	 30.0;
	1903	 378	 0.083396	 0.211892	 0.0051	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 378	 0.127992	 0.330814	 0.004	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 378	 0.081381	 0.206097	 0.0036	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	5010	 378	 0.03351	 0.09675	 0.003	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 378	 0.062988	 0.200302	 0.004	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	5010	 378	 0.03351	 0.09675	 0.003	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	469	 379	 0.002291	 0.009936	 0.0304	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3094	 379	 0.004168	 0.028918	 0.0597	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 379	 0.002054	 0.024691	 0.1276	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4085	 379	 0.004879	 0.032533	 0.0607	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4992	 379	 0.005294	 0.036998	 0.0668	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5149	 379	 0.001422	 0.009896	 0.0172	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1931	 380	 0.002168	 0.029238	 0.9906	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	2068	 380	 0.001468	 0.01491	 0.3841	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 380	 0.002479	 0.028151	 0.6296	 1128	 1128	 1128	 0.0	 0.0	 1	 -30.0	 30.0;
	3935	 380	 0.00072	 0.00946	 0.3263	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2067	 380	 0.00142	 0.01617	 0.3636	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 380	 0.002486	 0.028165	 0.6296	 1127	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	4284	 380	 0.001184	 0.016073	 0.4869	 1979	 1979	 1979	 0.0	 0.0	 1	 -30.0	 30.0;
	4004	 381	 0.033333	 0.08321	 0.0039	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 381	 0.016543	 0.041975	 0.0019	 673	 673	 673	 0.0	 0.0	 1	 -30.0	 30.0;
	2423	 382	 0.102797	 0.262031	 0.0029	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	3689	 382	 0.078534	 0.19229	 0.0021	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	5415	 382	 0.014361	 0.036785	 0.0012	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	937	 383	 0.037289	 0.152381	 0.002	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	3791	 383	 0.082263	 0.222676	 0.0025	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	937	 383	 0.037264	 0.15223	 0.0023	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	3791	 383	 0.082263	 0.222676	 0.0025	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	2434	 384	 0.080877	 0.164021	 0.0016	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	5223	 384	 0.052406	 0.143361	 0.0017	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5751	 384	 0.096643	 0.176905	 0.0017	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	2923	 385	 0.088687	 0.230033	 0.0002	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5768	 385	 0.033258	 0.089947	 0.001	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 386	 0.000521	 0.002315	 0.019	 13045	 13045	 13045	 0.0	 0.0	 1	 -30.0	 30.0;
	1590	 387	 0.018272	 0.07679	 0.0039	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	2937	 387	 0.013765	 0.057852	 0.007	 510	 510	 510	 0.0	 0.0	 1	 -30.0	 30.0;
	2705	 388	 0.006667	 0.043457	 0.0003	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	3531	 388	 0.024691	 0.103704	 0.0016	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	1400	 389	 0.002016	 0.004283	 0.0021	 6238	 6238	 6238	 0.0	 0.0	 1	 -30.0	 30.0;
	1876	 389	 0.008793	 0.026405	 0.0003	 1061	 1061	 1061	 0.0	 0.0	 1	 -30.0	 30.0;
	3846	 389	 0.013958	 0.087679	 0.0011	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 389	 0.075913	 0.210683	 0.0023	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	1399	 389	 0.002135	 0.003909	 0.0034	 6629	 6629	 6629	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 390	 0.053918	 0.138574	 0.0016	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	5720	 390	 0.014865	 0.038045	 0.0004	 723	 723	 723	 0.0	 0.0	 1	 -30.0	 30.0;
	1719	 391	 0.031746	 0.072058	 0.0008	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	1817	 391	 0.090703	 0.247669	 0.0028	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	2323	 391	 0.061225	 0.148652	 0.0016	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	2464	 391	 0.16513	 0.330511	 0.0096	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	3932	 391	 0.031998	 0.08642	 0.001	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	5598	 392	 0.018645	 0.077097	 0.001	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	1907	 393	 0.057308	 0.104902	 0.001	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	395	 394	 0.001008	 0.002268	 0.0	 12255	 12255	 12255	 0.0	 0.0	 1	 -30.0	 30.0;
	1786	 395	 0.00252	 0.015369	 0.0002	 1953	 1953	 1953	 0.0	 0.0	 1	 -30.0	 30.0;
	4559	 395	 0.004001	 0.007323	 0.0	 3645	 3645	 3645	 0.0	 0.0	 1	 -30.0	 30.0;
	1786	 395	 0.002268	 0.015369	 0.0002	 1958	 1958	 1958	 0.0	 0.0	 1	 -30.0	 30.0;
	3863	 396	 0.015621	 0.081355	 0.001	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	4080	 396	 0.016175	 0.085462	 0.0014	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	2392	 397	 0.053918	 0.184933	 0.0	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3842	 397	 0.066264	 0.227261	 0.0	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	5186	 398	 0.005432	 0.013827	 0.0066	 2000	 2000	 2000	 0.0	 0.0	 1	 -30.0	 30.0;
	849	 399	 0.000504	 0.00252	 0.0006	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	2236	 400	 0.056286	 0.153515	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	2783	 400	 0.07231	 0.184429	 0.0021	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	2299	 402	 0.073593	 0.163333	 0.007	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	2807	 402	 0.084197	 0.191605	 0.0089	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	2767	 403	 0.019652	 0.055682	 0.0061	 503	 503	 503	 0.0	 0.0	 1	 -30.0	 30.0;
	5164	 403	 0.069035	 0.142353	 0.001	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 404	 0.023683	 0.067775	 0.0	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	3286	 404	 0.004031	 0.015369	 0.0185	 1859	 1859	 1859	 0.0	 0.0	 1	 -30.0	 30.0;
	1079	 405	 0.020242	 0.037052	 0.0011	 700	 700	 700	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 406	 0.016049	 0.045679	 0.0076	 614	 614	 614	 0.0	 0.0	 1	 -30.0	 30.0;
	1861	 406	 0.00584	 0.019309	 0.001	 1473	 1473	 1473	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 406	 0.010864	 0.035803	 0.0018	 794	 794	 794	 0.0	 0.0	 1	 -30.0	 30.0;
	2355	 407	 0.008605	 0.022012	 0.001	 1257	 1257	 1257	 0.0	 0.0	 1	 -30.0	 30.0;
	2450	 407	 0.013173	 0.041235	 0.002	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	2811	 408	 0.085664	 0.233711	 0.0028	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 409	 0.054926	 0.100781	 0.0011	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	487	 410	 0.012963	 0.035062	 0.0028	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	1058	 410	 0.004691	 0.012963	 0.0018	 2155	 2155	 2155	 0.0	 0.0	 1	 -30.0	 30.0;
	1864	 411	 0.023457	 0.098765	 0.005	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	3190	 411	 0.02021	 0.085111	 0.0044	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	1631	 412	 0.016881	 0.069035	 0.0017	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	2041	 412	 0.076342	 0.184933	 0.0024	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	3233	 412	 0.027261	 0.115294	 0.0019	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 412	 0.057848	 0.157823	 0.0046	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	1141	 413	 0.065004	 0.18065	 0.0019	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	1141	 413	 0.062232	 0.178634	 0.0019	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 414	 0.059209	 0.150416	 0.0021	 188	 188	 188	 0.0	 0.0	 1	 -30.0	 30.0;
	5134	 414	 0.000176	 0.000454	 0.0	 60637	 60637	 60637	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 415	 0.070295	 0.181658	 0.0021	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	3664	 415	 0.067271	 0.173091	 0.002	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	4438	 415	 0.001008	 0.003275	 0.0004	 8876	 8876	 8876	 0.0	 0.0	 1	 -30.0	 30.0;
	545	 416	 0.000178	 0.000909	 0.002	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	857	 417	 0.067019	 0.2129	 0.0024	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 417	 0.07735	 0.263542	 0.0029	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	4120	 417	 0.087377	 0.23996	 0.0028	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	3733	 418	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	4306	 419	 0.082389	 0.209121	 0.0024	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	5137	 419	 0.013354	 0.03477	 0.0004	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	5135	 419	 0.003779	 0.023432	 0.0003	 1282	 1282	 1282	 0.0	 0.0	 1	 -30.0	 30.0;
	5135	 420	 0.004031	 0.010834	 0.0002	 2632	 2632	 2632	 0.0	 0.0	 1	 -30.0	 30.0;
	3547	 421	 0.001512	 0.003023	 0.0013	 8736	 8736	 8736	 0.0	 0.0	 1	 -30.0	 30.0;
	1478	 422	 0.039305	 0.173217	 0.0571	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	1478	 422	 0.039305	 0.173293	 0.0571	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	850	 423	 0.00241	 0.015694	 0.0294	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2774	 423	 0.006874	 0.044761	 0.0835	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1562	 424	 0.051146	 0.139078	 0.0019	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	3404	 424	 0.05165	 0.140842	 0.0016	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 424	 0.018645	 0.050643	 0.002	 564	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	4525	 424	 0.074074	 0.188713	 0.0036	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	1562	 424	 0.051398	 0.14059	 0.0016	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 424	 0.017637	 0.048375	 0.002	 591	 591	 591	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 424	 0.017637	 0.048375	 0.002	 591	 591	 591	 0.0	 0.0	 1	 -30.0	 30.0;
	2755	 425	 0.001521	 0.021728	 0.0871	 831.0	 831.0	 831.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5698	 425	 0.001304	 0.017205	 0.0729	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5136	 426	 0.001678	 0.003072	 0.0	 8185	 8185	 8185	 0.0	 0.0	 1	 -30.0	 30.0;
	1151	 427	 0.008314	 0.018645	 0.0002	 1447	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 428	 0.008314	 0.022928	 0.0002	 1211	 1211	 1211	 0.0	 0.0	 1	 -30.0	 30.0;
	3865	 429	 0.006047	 0.015873	 0.0002	 1739	 1739	 1739	 0.0	 0.0	 1	 -30.0	 30.0;
	5201	 429	 0.00252	 0.006299	 0.0004	 4352	 4352	 4352	 0.0	 0.0	 1	 -30.0	 30.0;
	3865	 429	 0.005795	 0.016125	 0.0002	 1724	 1724	 1724	 0.0	 0.0	 1	 -30.0	 30.0;
	1660	 429	 0.021083	 0.038593	 0.0004	 672	 672	 672	 0.0	 0.0	 1	 -30.0	 30.0;
	1047	 430	 0.000336	 0.001363	 0.1499	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1265	 430	 0.000178	 0.001422	 0.1448	 339.0	 339.0	 339.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3290	 431	 0.052482	 0.176846	 0.0022	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	3200	 432	 0.147392	 0.387503	 0.0044	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	4000	 432	 0.124465	 0.321492	 0.0	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	879	 433	 0.001764	 0.004535	 0.0001	 6104	 6104	 6104	 0.0	 0.0	 1	 -30.0	 30.0;
	1445	 434	 0.03351	 0.108214	 0.0013	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	5466	 434	 0.018392	 0.060217	 0.0008	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	982	 435	 0.027531	 0.072222	 0.0034	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	2839	 435	 0.031235	 0.087901	 0.0045	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	3056	 435	 0.036173	 0.098518	 0.0047	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	5264	 435	 0.016049	 0.042716	 0.0	 665	 665	 665	 0.0	 0.0	 1	 -30.0	 30.0;
	3056	 435	 0.034815	 0.095062	 0.0044	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	3979	 436	 0.080121	 0.168304	 0.0018	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5694	 436	 0.046863	 0.196019	 0.0024	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	2544	 437	 0.009322	 0.021668	 0.0004	 1320	 1320	 1320	 0.0	 0.0	 1	 -30.0	 30.0;
	2977	 438	 0.052397	 0.095912	 0.001	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 439	 0.023885	 0.059587	 0.0012	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	2212	 439	 0.032903	 0.060228	 0.0006	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	5001	 439	 0.031721	 0.081885	 0.0013	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 440	 0.000403	 0.001109	 0.0	 25776	 25776	 25776	 0.0	 0.0	 1	 -30.0	 30.0;
	5138	 441	 0.006047	 0.025951	 0.0	 1109	 1109	 1109	 0.0	 0.0	 1	 -30.0	 30.0;
	2751	 442	 0.025447	 0.067775	 0.0008	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 442	 0.024188	 0.064752	 0.012	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	1553	 443	 0.014074	 0.059136	 0.0038	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	1645	 445	 0.002469	 0.015679	 0.0008	 2031	 2031	 2031	 0.0	 0.0	 1	 -30.0	 30.0;
	2025	 443	 0.008272	 0.035062	 0.0028	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	4865	 445	 0.005062	 0.01037	 0.0005	 2793	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	5329	 443	 0.007531	 0.019259	 0.0019	 1672	 1672	 1672	 0.0	 0.0	 1	 -30.0	 30.0;
	1645	 445	 0.002469	 0.015679	 0.0008	 2031	 2031	 2031	 0.0	 0.0	 1	 -30.0	 30.0;
	2025	 444	 0.008272	 0.034815	 0.0046	 897	 897	 897	 0.0	 0.0	 1	 -30.0	 30.0;
	4865	 445	 0.005062	 0.010494	 0.0005	 2767	 2767	 2767	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 446	 0.002252	 0.011951	 0.0218	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5142	 446	 0.00079	 0.005333	 0.0101	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3587	 447	 0.008062	 0.020408	 0.0002	 1346	 1346	 1346	 0.0	 0.0	 1	 -30.0	 30.0;
	1229	 448	 0.027211	 0.172336	 0.0117	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	2900	 448	 0.015117	 0.065004	 0.0008	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	3975	 448	 0.02372	 0.043419	 0.0005	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	2900	 448	 0.014109	 0.038549	 0.0015	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 449	 0.001501	 0.010015	 0.0182	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1430	 449	 0.003103	 0.021146	 0.04	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4796	 449	 0.00162	 0.010765	 0.0203	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 449	 0.001807	 0.017201	 0.0618	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 449	 0.000217	 0.001442	 0.003	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4796	 449	 0.00162	 0.010726	 0.0203	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	499	 449	 0.000119	 0.001086	 0.004	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2239	 450	 0.00072	 0.009453	 0.3263	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2756	 450	 0.003206	 0.03536	 0.9025	 899	 899	 899	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 450	 0.000616	 0.008054	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2239	 450	 0.000713	 0.009384	 0.3235	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 450	 0.000616	 0.008061	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	501	 450	 3.5e-05	 0.000374	 0.0087	 921.0	 921.0	 921.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5146	 451	 0.000756	 0.00252	 0.0	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 452	 0.106324	 0.289746	 0.0033	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	2332	 452	 0.060217	 0.168808	 0.0018	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	2692	 452	 0.048879	 0.124717	 0.0013	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	3705	 452	 0.058705	 0.152935	 0.0017	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	2332	 452	 0.060972	 0.169312	 0.0018	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	3433	 452	 0.008818	 0.025195	 0.0002	 1107	 1107	 1107	 0.0	 0.0	 1	 -30.0	 30.0;
	3539	 453	 0.013393	 0.069551	 0.1261	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3658	 453	 0.013491	 0.070361	 0.1271	 412.0	 412.0	 412.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5147	 454	 0.006299	 0.017385	 0.0002	 1645	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	4058	 456	 0.002346	 0.006296	 0.0002	 4777	 4777	 4777	 0.0	 0.0	 1	 -30.0	 30.0;
	4058	 455	 0.002346	 0.00642	 0.0003	 4695	 4695	 4695	 0.0	 0.0	 1	 -30.0	 30.0;
	4237	 457	 0.001764	 0.004535	 0.0048	 6068	 6068	 6068	 0.0	 0.0	 1	 -30.0	 30.0;
	2993	 458	 0.001956	 0.010469	 0.3286	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3613	 458	 0.001402	 0.010173	 0.2673	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4670	 459	 0.000648	 0.00657	 0.1704	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4670	 459	 0.000651	 0.006572	 0.1704	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3167	 460	 0.004485	 0.020282	 0.0241	 1465	 1465	 1465	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 461	 0.05029	 0.138246	 0.0033	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	5473	 462	 0.05165	 0.140842	 0.0016	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 463	 0.002963	 0.008025	 0.0003	 3473	 3473	 3473	 0.0	 0.0	 1	 -30.0	 30.0;
	2705	 465	 0.003311	 0.006061	 0.0112	 4634	 4634	 4634	 0.0	 0.0	 1	 -30.0	 30.0;
	5150	 466	 2.5e-05	 0.00252	 0.0001	 11716	 11716	 11716	 0.0	 0.0	 1	 -30.0	 30.0;
	2178	 467	 0.002016	 0.005039	 0.0093	 5279	 5279	 5279	 0.0	 0.0	 1	 -30.0	 30.0;
	3474	 467	 0.022681	 0.041517	 0.0216	 606	 606	 606	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 468	 0.011086	 0.028219	 0.0301	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	2178	 467	 0.001512	 0.005291	 0.0095	 5207	 5207	 5207	 0.0	 0.0	 1	 -30.0	 30.0;
	3473	 467	 0.022761	 0.041664	 0.0218	 604	 604	 604	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 468	 0.011086	 0.028219	 0.0302	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	2178	 467	 0.002016	 0.005039	 0.0091	 5279	 5279	 5279	 0.0	 0.0	 1	 -30.0	 30.0;
	2980	 470	 0.078181	 0.17866	 0.0021	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 471	 0.062358	 0.148047	 0.0068	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	3338	 471	 0.018392	 0.05291	 0.001	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	3736	 471	 0.011208	 0.020515	 0.0002	 1264	 1264	 1264	 0.0	 0.0	 1	 -30.0	 30.0;
	2714	 473	 1e-05	 0.0001	 0.0029	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2714	 472	 1e-05	 0.0001	 0.0029	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4289	 474	 0.012568	 0.033383	 0.0066	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 474	 0.012568	 0.033383	 0.0066	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	2167	 475	 0.035777	 0.088435	 0.001	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	3867	 475	 0.027211	 0.072058	 0.0009	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	5566	 476	 0.027715	 0.070547	 0.0	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	3755	 477	 0.008062	 0.03351	 0.0004	 883	 883	 883	 0.0	 0.0	 1	 -30.0	 30.0;
	3755	 477	 0.008062	 0.03351	 0.0004	 883	 883	 883	 0.0	 0.0	 1	 -30.0	 30.0;
	4037	 478	 0.059259	 0.163457	 0.0	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	642	 479	 0.008062	 0.027463	 0.0021	 1032	 1032	 1032	 0.0	 0.0	 1	 -30.0	 30.0;
	1829	 479	 0.01033	 0.036029	 0.003	 788	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	3571	 479	 0.000252	 0.00126	 0.0021	 22978	 22978	 22978	 0.0	 0.0	 1	 -30.0	 30.0;
	971	 480	 0.000436	 0.000797	 0.0006	 32501	 32501	 32501	 0.0	 0.0	 1	 -30.0	 30.0;
	1563	 480	 0.012002	 0.02197	 0.0233	 1180	 1180	 1180	 0.0	 0.0	 1	 -30.0	 30.0;
	2141	 480	 0.074578	 0.197279	 0.003	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 480	 0.005039	 0.01285	 0.0002	 2140	 2140	 2140	 0.0	 0.0	 1	 -30.0	 30.0;
	3149	 480	 0.003527	 0.01285	 0.0015	 2216	 2216	 2216	 0.0	 0.0	 1	 -30.0	 30.0;
	1564	 480	 0.015042	 0.040539	 0.0164	 683	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	2162	 480	 0.005039	 0.01285	 0.0002	 2140	 2140	 2140	 0.0	 0.0	 1	 -30.0	 30.0;
	2163	 480	 0.003023	 0.013102	 0.0002	 2196	 2196	 2196	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 481	 0.00332	 0.015328	 0.0267	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2007	 482	 0.047972	 0.124465	 0.0037	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	2502	 483	 0.007307	 0.029226	 0.0316	 1010	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 483	 0.006551	 0.01285	 0.0128	 2109	 2109	 2109	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 483	 0.001512	 0.004283	 0.0001	 6697	 6697	 6697	 0.0	 0.0	 1	 -30.0	 30.0;
	5594	 483	 0.001008	 0.003779	 0.0001	 7777	 7777	 7777	 0.0	 0.0	 1	 -30.0	 30.0;
	960	 484	 0.010864	 0.045062	 0.0305	 641	 641	 641	 0.0	 0.0	 1	 -30.0	 30.0;
	4166	 484	 0.010494	 0.04321	 0.0245	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	3538	 485	 0.108088	 0.349458	 0.0048	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	5151	 486	 0.010078	 0.025447	 0.0003	 1112	 1112	 1112	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 487	 0.04642	 0.125432	 0.0058	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	1058	 487	 0.022963	 0.062346	 0.0058	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	653	 488	 0.011338	 0.027715	 0.0	 1016	 1016	 1016	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 488	 0.018896	 0.053666	 0.0	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	2256	 489	 0.035525	 0.097758	 0.0011	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	2611	 489	 0.049131	 0.135047	 0.0013	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	2196	 490	 0.010864	 0.070494	 0.0006	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	5153	 491	 2.4e-05	 9.7e-05	 0.001	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3564	 492	 0.028496	 0.059461	 0.0006	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	5076	 492	 0.074074	 0.152683	 0.002	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	594	 493	 9.9e-05	 0.000198	 0.0223	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	595	 494	 1.4e-05	 0.000145	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	595	 495	 7e-06	 0.000159	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	595	 496	 1.4e-05	 0.000166	 0.0058	 1737.0	 1737.0	 1737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	595	 497	 1.4e-05	 0.00018	 0.0058	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2151	 498	 0.001008	 0.00252	 0.0019	 11206	 11206	 11206	 0.0	 0.0	 1	 -30.0	 30.0;
	2450	 502	 0.018148	 0.085185	 0.004	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	2555	 502	 0.035679	 0.097901	 0.0047	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5191	 502	 0.056173	 0.23963	 0.0121	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	3971	 503	 0.017654	 0.074815	 0.0076	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	3970	 503	 0.017778	 0.074074	 0.0081	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	736	 504	 0.044815	 0.11642	 0.0008	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	1277	 504	 0.040494	 0.104198	 0.0049	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	1811	 504	 0.009753	 0.026049	 0.0013	 1243	 1243	 1243	 0.0	 0.0	 1	 -30.0	 30.0;
	5113	 504	 0.000123	 0.001235	 0.0002	 27851	 27851	 27851	 0.0	 0.0	 1	 -30.0	 30.0;
	5353	 504	 0.009753	 0.026049	 0.0002	 1243	 1243	 1243	 0.0	 0.0	 1	 -30.0	 30.0;
	2660	 506	 0.020408	 0.066264	 0.0013	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 506	 0.009322	 0.02973	 0.0019	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 507	 0.010124	 0.025679	 0.0011	 1077	 1077	 1077	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 507	 0.010247	 0.025926	 0.0013	 1066	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	3974	 508	 0.047329	 0.086634	 0.0007	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	1559	 509	 0.021111	 0.121111	 0.006	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 509	 0.016173	 0.091235	 0.005	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5610	 510	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	5611	 510	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	2993	 511	 0.000251	 0.002177	 0.2187	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3086	 512	 9.9e-05	 0.000741	 0.0	 34920	 34920	 34920	 0.0	 0.0	 1	 -30.0	 30.0;
	2571	 513	 0.013933	 0.049685	 0.0097	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	2961	 514	 0.001084	 0.014247	 0.491	 2232	 2232	 2232	 0.0	 0.0	 1	 -30.0	 30.0;
	3146	 514	 0.000492	 0.006489	 0.2224	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3229	 514	 7e-06	 0.000152	 0.0058	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2962	 514	 0.001112	 0.01462	 0.5054	 2175	 2175	 2175	 0.0	 0.0	 1	 -30.0	 30.0;
	3147	 514	 0.000492	 0.006489	 0.2238	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3230	 514	 7e-06	 0.000104	 0.0029	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1077	 515	 0.023086	 0.061111	 0.0029	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	2580	 515	 0.024938	 0.065802	 0.0031	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	1190	 516	 0.099585	 0.18229	 0.0019	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	5446	 517	 0.011842	 0.032502	 0.0004	 880	 880	 880	 0.0	 0.0	 1	 -30.0	 30.0;
	2260	 518	 0.031746	 0.072058	 0.001	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	3206	 518	 0.028219	 0.069539	 0.0015	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	565	 519	 0.088183	 0.199295	 0.0021	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	4190	 520	 0.044568	 0.11321	 0.0053	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 520	 0.054691	 0.140864	 0.0066	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	1402	 521	 0.016377	 0.102041	 0.0017	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	2883	 521	 0.018392	 0.084908	 0.0021	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	2919	 522	 0.011766	 0.048702	 0.0026	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	3665	 521	 0.005719	 0.022726	 0.0023	 1260	 1260	 1260	 0.0	 0.0	 1	 -30.0	 30.0;
	3830	 522	 0.040816	 0.117914	 0.0061	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	4258	 521	 0.044596	 0.113631	 0.0037	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	5648	 522	 0.004661	 0.018392	 0.0022	 1557	 1557	 1557	 0.0	 0.0	 1	 -30.0	 30.0;
	2919	 521	 0.013883	 0.056009	 0.0025	 512	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 523	 0.001264	 0.00964	 0.0375	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 523	 0.001264	 0.008415	 0.0152	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2873	 523	 0.002627	 0.012188	 0.0218	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2884	 523	 0.001063	 0.007064	 0.0132	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4458	 523	 0.002489	 0.016711	 0.0304	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5432	 523	 0.0016	 0.014933	 0.0537	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 523	 0.001264	 0.009659	 0.0405	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	954	 524	 0.000501	 0.005472	 0.1155	 1429.0	 1429.0	 1429.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2910	 524	 0.000429	 0.004737	 0.1011	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1127	 526	 0.040564	 0.086924	 0.001	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	1916	 526	 0.04006	 0.107836	 0.0012	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	2950	 526	 0.035651	 0.095087	 0.0011	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	3029	 526	 0.011842	 0.031746	 0.0003	 872	 872	 872	 0.0	 0.0	 1	 -30.0	 30.0;
	3309	 526	 0.015117	 0.032502	 0.0004	 824	 824	 824	 0.0	 0.0	 1	 -30.0	 30.0;
	4240	 526	 0.07357	 0.192744	 0.0021	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	4685	 526	 0.013303	 0.035072	 0.0004	 788	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	4761	 526	 0.058201	 0.147644	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	5546	 526	 0.012572	 0.033207	 0.0003	 832	 832	 832	 0.0	 0.0	 1	 -30.0	 30.0;
	5690	 526	 0.065508	 0.233812	 0.0033	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	4684	 526	 0.010834	 0.035777	 0.0004	 790	 790	 790	 0.0	 0.0	 1	 -30.0	 30.0;
	1278	 527	 0.000553	 0.003714	 0.0116	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1441	 527	 0.003951	 0.020148	 0.0511	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4591	 527	 0.007447	 0.034884	 0.0628	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4697	 527	 0.000632	 0.004286	 0.0081	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1278	 527	 0.000553	 0.003714	 0.0121	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3530	 527	 0.001106	 0.005353	 0.0091	 5617	 5617	 5617	 0.0	 0.0	 1	 -30.0	 30.0;
	4697	 527	 0.000672	 0.004543	 0.0081	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	529	 528	 0.003149	 0.007962	 0.0001	 3553	 3553	 3553	 0.0	 0.0	 1	 -30.0	 30.0;
	1350	 528	 0.018166	 0.094533	 0.0071	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 528	 0.019425	 0.101209	 0.0084	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	1080	 530	 0.003527	 0.008818	 0.0003	 3109	 3109	 3109	 0.0	 0.0	 1	 -30.0	 30.0;
	532	 531	 2.5e-05	 0.000252	 0.0003	 113138	 113138	 113138	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 531	 0.013754	 0.025176	 0.0118	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 531	 0.011276	 0.02064	 0.0109	 1219	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	3872	 534	 0.008314	 0.01683	 0.0143	 1527	 1527	 1527	 0.0	 0.0	 1	 -30.0	 30.0;
	3872	 533	 0.008314	 0.016528	 0.014	 1549	 1549	 1549	 0.0	 0.0	 1	 -30.0	 30.0;
	663	 535	 0.008852	 0.029938	 0.0015	 952	 952	 952	 0.0	 0.0	 1	 -30.0	 30.0;
	1351	 535	 0.009049	 0.023296	 0.0011	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	2872	 535	 0.000123	 0.000741	 0.0	 39543	 39543	 39543	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 535	 0.017531	 0.047778	 0.0023	 584	 584	 584	 0.0	 0.0	 1	 -30.0	 30.0;
	5672	 535	 0.010988	 0.02963	 0.0015	 940	 940	 940	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 535	 0.004444	 0.008889	 0.0003	 2989	 2989	 2989	 0.0	 0.0	 1	 -30.0	 30.0;
	663	 535	 0.009259	 0.029333	 0.0015	 966	 966	 966	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 535	 0.009753	 0.040617	 0.0021	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	5529	 535	 0.006049	 0.025062	 0.0013	 1153	 1153	 1153	 0.0	 0.0	 1	 -30.0	 30.0;
	3252	 536	 0.004188	 0.027872	 0.0516	 485.0	 485.0	 485.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4766	 536	 0.00322	 0.022183	 0.0395	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4766	 536	 0.00322	 0.022183	 0.0395	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	646	 537	 0.035049	 0.095617	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	1316	 537	 0.032099	 0.081728	 0.0039	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 537	 0.049876	 0.121235	 0.0058	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	1189	 538	 0.034517	 0.092719	 0.003	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	5376	 538	 0.06198	 0.16125	 0.0021	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	1130	 539	 0.053086	 0.144321	 0.0068	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	2094	 540	 0.029012	 0.081605	 0.0	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	1340	 541	 0.008115	 0.014854	 0.0098	 1745	 1745	 1745	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 542	 0.000217	 0.00081	 0.1013	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 543	 0.000257	 0.000988	 0.1215	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2084	 544	 0.02037	 0.05358	 0.0045	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	2676	 544	 0.017901	 0.057778	 0.0028	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	2979	 544	 0.000988	 0.004074	 0.0005	 7234	 7234	 7234	 0.0	 0.0	 1	 -30.0	 30.0;
	5766	 544	 0.005185	 0.016049	 0.0008	 1798	 1798	 1798	 0.0	 0.0	 1	 -30.0	 30.0;
	2885	 545	 0.003358	 0.02242	 0.0415	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5668	 545	 0.003437	 0.022933	 0.0425	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1679	 546	 0.05417	 0.111111	 0.0012	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	5159	 546	 0.06387	 0.131318	 0.0014	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	5568	 547	 0.02973	 0.081129	 0.0009	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 547	 0.031746	 0.086924	 0.001	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 548	 0.061225	 0.153691	 0.0015	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5123	 548	 0.099043	 0.241547	 0.0023	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	3064	 549	 0.001764	 0.005039	 0.0001	 5697	 5697	 5697	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 550	 0.052154	 0.112623	 0.0013	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	1538	 551	 0.012346	 0.032716	 0.0016	 868	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	2727	 551	 0.075309	 0.190988	 0.0091	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 551	 0.015926	 0.041605	 0.0019	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 551	 0.020123	 0.051111	 0.0024	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	1538	 551	 0.015679	 0.040494	 0.0019	 699	 699	 699	 0.0	 0.0	 1	 -30.0	 30.0;
	1188	 552	 0.045352	 0.114386	 0.0013	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	1551	 552	 0.060721	 0.154699	 0.0021	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	3387	 553	 0.03351	 0.069539	 0.0067	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	5697	 553	 0.031368	 0.064752	 0.001	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 554	 0.017133	 0.054422	 0.0006	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	4889	 554	 0.144873	 0.279919	 0.003	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 554	 0.017133	 0.054422	 0.0006	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 556	 0.002145	 0.009679	 0.017	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 555	 0.002125	 0.009576	 0.0168	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1788	 557	 0.000691	 0.001383	 0.2045	 20021	 20021	 20021	 0.0	 0.0	 1	 -30.0	 30.0;
	3898	 558	 0.001699	 0.011299	 0.0213	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1133	 559	 0.054674	 0.175359	 0.002	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	3066	 559	 0.099017	 0.282187	 0.003	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	3635	 559	 0.029226	 0.09297	 0.001	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	4367	 559	 0.003023	 0.010078	 0.0099	 2807	 2807	 2807	 0.0	 0.0	 1	 -30.0	 30.0;
	5399	 560	 0.003527	 0.00907	 0.0001	 3126	 3126	 3126	 0.0	 0.0	 1	 -30.0	 30.0;
	2994	 561	 0.045603	 0.11615	 0.0013	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	1128	 562	 0.050864	 0.130617	 0.006	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	2461	 562	 0.040741	 0.103704	 0.0049	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	2651	 563	 0.04006	 0.109599	 0.0013	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	4792	 563	 0.035777	 0.09549	 0.0011	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	1441	 564	 0.0048	 0.022637	 0.0405	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 564	 0.003319	 0.015664	 0.0263	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	852	 565	 0.031267	 0.19413	 0.0025	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	2974	 565	 0.003779	 0.010078	 0.0005	 2826	 2826	 2826	 0.0	 0.0	 1	 -30.0	 30.0;
	852	 565	 0.031267	 0.194104	 0.0025	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	1010	 566	 0.024938	 0.068148	 0.0032	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	4227	 566	 0.024198	 0.065802	 0.0031	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	2439	 567	 0.029151	 0.079289	 0.0009	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	5796	 567	 0.030562	 0.083371	 0.0009	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	4528	 568	 0.001008	 0.00252	 0.0	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	2304	 569	 0.016881	 0.055682	 0.0	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	5021	 569	 0.065256	 0.219451	 0.0025	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	585	 570	 0.048803	 0.131973	 0.0015	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	4209	 570	 0.0839	 0.233308	 0.003	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	1068	 571	 0.015369	 0.037541	 0.0	 750	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	3317	 571	 0.094986	 0.236332	 0.0025	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	1898	 572	 0.063668	 0.160393	 0.0018	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	4861	 572	 0.020408	 0.052658	 0.001	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	1180	 574	 0.053704	 0.141111	 0.0066	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	3882	 574	 0.046543	 0.118025	 0.0055	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	4850	 574	 0.02	 0.054691	 0.0026	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	4899	 574	 0.022593	 0.071852	 0.0036	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	3107	 574	 0.042716	 0.116667	 0.0055	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 574	 0.021728	 0.059506	 0.0028	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	1571	 575	 0.175697	 0.321613	 0.003	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	2038	 575	 0.123346	 0.225783	 0.002	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	1820	 576	 0.001696	 0.003104	 0.0005	 8751	 8751	 8751	 0.0	 0.0	 1	 -30.0	 30.0;
	654	 577	 0.000514	 0.001541	 0.1144	 19054	 19054	 19054	 0.0	 0.0	 1	 -30.0	 30.0;
	5162	 578	 0.00252	 0.006878	 0.0001	 4152	 4152	 4152	 0.0	 0.0	 1	 -30.0	 30.0;
	1207	 580	 0.00324	 0.034272	 0.1336	 892	 892	 892	 0.0	 0.0	 1	 -30.0	 30.0;
	1720	 581	 0.005077	 0.023783	 0.0425	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3246	 581	 0.002368	 0.018825	 0.0511	 519.0	 519.0	 519.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3641	 581	 0.003279	 0.043101	 0.1822	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 581	 0.0014	 0.011018	 0.0192	 519.0	 519.0	 519.0	 0.0	 0.0	 1	 -30.0	 30.0;
	580	 579	 4.8e-05	 8.8e-05	 0.004	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3522	 582	 0.000102	 0.001632	 0.0491	 2450.0	 2450.0	 2450.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5027	 583	 0.005291	 0.011338	 0.0102	 2290	 2290	 2290	 0.0	 0.0	 1	 -30.0	 30.0;
	3033	 584	 0.005543	 0.014109	 0.0002	 1948	 1948	 1948	 0.0	 0.0	 1	 -30.0	 30.0;
	1456	 585	 0.038196	 0.104182	 0.0012	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	1152	 586	 0.033762	 0.104056	 0.001	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	4976	 586	 0.017637	 0.050139	 0.001	 556	 556	 556	 0.0	 0.0	 1	 -30.0	 30.0;
	5268	 586	 0.010078	 0.031494	 0.0	 893	 893	 893	 0.0	 0.0	 1	 -30.0	 30.0;
	2423	 587	 0.024213	 0.076921	 0.0015	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	2487	 587	 0.018645	 0.059713	 0.0007	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	5164	 588	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5331	 589	 0.027407	 0.071852	 0.0034	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	5683	 589	 0.017407	 0.045556	 0.0021	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 590	 0.001027	 0.017738	 0.0101	 1954	 1954	 1954	 0.0	 0.0	 1	 -30.0	 30.0;
	2160	 590	 0.000318	 0.002424	 0.0052	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 590	 0.001027	 0.017738	 0.0101	 1954	 1954	 1954	 0.0	 0.0	 1	 -30.0	 30.0;
	2160	 590	 0.000397	 0.002657	 0.0051	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 591	 0.000101	 0.00252	 0.0	 11707	 11707	 11707	 0.0	 0.0	 1	 -30.0	 30.0;
	3200	 592	 0.058201	 0.15873	 0.0017	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	4000	 592	 0.119602	 0.316553	 0.0038	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	4000	 592	 0.119577	 0.316503	 0.004	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	2636	 593	 0.035777	 0.097506	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	3025	 595	 0.000637	 0.008255	 0.2123	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 595	 0.000688	 0.009993	 0.257	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1329	 595	 0.000443	 0.006454	 0.1675	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3508	 595	 0.000688	 0.009993	 0.257	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1329	 595	 0.000464	 0.006766	 0.1762	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1329	 595	 0.000464	 0.006773	 0.1762	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 596	 0.008519	 0.016049	 0.0007	 1635	 1635	 1635	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 597	 0.013328	 0.059864	 0.0006	 496	 496	 496	 0.0	 0.0	 1	 -30.0	 30.0;
	3511	 598	 0.001025	 0.004614	 0.0081	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1513	 599	 0.052963	 0.205926	 0.0119	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	1847	 600	 0.045855	 0.116402	 0.0013	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 600	 0.019148	 0.053162	 0.0006	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	2679	 601	 0.007778	 0.028642	 0.0015	 1022	 1022	 1022	 0.0	 0.0	 1	 -30.0	 30.0;
	5343	 601	 0.024284	 0.063691	 0.003	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	737	 602	 0.023126	 0.042332	 0.0004	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	1883	 602	 0.013354	 0.028219	 0.0398	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	2054	 602	 0.061275	 0.155707	 0.0047	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	3845	 602	 0.001461	 0.004006	 0.0007	 7133	 7133	 7133	 0.0	 0.0	 1	 -30.0	 30.0;
	1883	 602	 0.01232	 0.034543	 0.0298	 830	 830	 830	 0.0	 0.0	 1	 -30.0	 30.0;
	3357	 603	 0.001934	 0.01293	 0.024	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4853	 603	 0.004642	 0.03089	 0.0573	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	608	 606	 0.000968	 0.001975	 0.0081	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	608	 605	 0.000968	 0.001975	 0.001	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	608	 604	 0.000968	 0.001975	 0.001	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2372	 607	 0.076846	 0.209373	 0.0024	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	3936	 607	 0.091711	 0.258251	 0.0049	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 607	 0.026707	 0.072562	 0.0008	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	2777	 608	 0.00348	 0.023956	 0.0456	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3596	 608	 0.002449	 0.017106	 0.0304	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5256	 608	 0.006001	 0.041452	 0.078	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	880	 609	 0.027715	 0.184429	 0.0025	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	4359	 609	 0.006551	 0.04258	 0.0006	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	5499	 611	 4e-05	 0.000198	 0.0	 153231	 153231	 153231	 0.0	 0.0	 1	 -30.0	 30.0;
	3332	 612	 0.047407	 0.129383	 0.006	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	2183	 613	 0.075082	 0.226757	 0.0026	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	5366	 613	 0.03099	 0.114386	 0.0014	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 614	 0.04006	 0.109095	 0.0009	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2258	 615	 0.001205	 0.005511	 0.0091	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2006	 616	 0.01438	 0.065067	 0.1154	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 616	 0.003538	 0.016484	 0.0273	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3594	 616	 0.012634	 0.056573	 0.1008	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5309	 616	 0.003516	 0.016158	 0.0273	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5322	 616	 0.00316	 0.014914	 0.0253	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5777	 616	 0.007704	 0.034647	 0.0607	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 616	 0.002489	 0.016257	 0.0294	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1002	 616	 0.003457	 0.015467	 0.0273	 309.0	 309.0	 309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 617	 0.006579	 0.049467	 1.0137	 640	 640	 640	 0.0	 0.0	 1	 -30.0	 30.0;
	3930	 617	 0.001357	 0.014821	 0.3321	 1171.0	 1171.0	 1171.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5168	 619	 0.000504	 0.003023	 0.0	 9349	 9349	 9349	 0.0	 0.0	 1	 -30.0	 30.0;
	5172	 618	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	5027	 620	 0.003527	 0.006551	 0.0076	 3851	 3851	 3851	 0.0	 0.0	 1	 -30.0	 30.0;
	5027	 621	 0.002771	 0.007307	 0.0077	 3667	 3667	 3667	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 622	 0.022928	 0.060721	 0.0007	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	4893	 623	 0.04258	 0.119678	 0.001	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5031	 623	 0.031494	 0.082137	 0.001	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	5236	 623	 0.004787	 0.013605	 0.001	 2048	 2048	 2048	 0.0	 0.0	 1	 -30.0	 30.0;
	5826	 623	 0.033006	 0.122449	 0.001	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	2697	 624	 0.00352	 0.014823	 0.0263	 2032	 2032	 2032	 0.0	 0.0	 1	 -30.0	 30.0;
	818	 625	 0.004334	 0.011489	 0.013	 2405	 2405	 2405	 0.0	 0.0	 1	 -30.0	 30.0;
	1103	 625	 0.009322	 0.058957	 0.0033	 495	 495	 495	 0.0	 0.0	 1	 -30.0	 30.0;
	2587	 625	 0.017385	 0.110607	 0.004	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 628	 0.001111	 0.003244	 0.0014	 8880	 8880	 8880	 0.0	 0.0	 1	 -30.0	 30.0;
	5182	 629	 0.018395	 0.050099	 0.0023	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	5173	 632	 2e-05	 0.000198	 0.0223	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	5176	 631	 9.9e-05	 0.000296	 0.004	 99170	 99170	 99170	 0.0	 0.0	 1	 -30.0	 30.0;
	4223	 633	 0.024389	 0.066516	 0.0007	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	5174	 634	 0.000756	 0.002016	 0.0	 13714	 13714	 13714	 0.0	 0.0	 1	 -30.0	 30.0;
	1258	 635	 0.157974	 0.39229	 0.0049	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 635	 0.215495	 0.516578	 0.0058	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	2454	 636	 0.01033	 0.028219	 0.0003	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	2534	 636	 0.066264	 0.221718	 0.0027	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	5587	 636	 0.027211	 0.08642	 0.001	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	2785	 637	 0.084656	 0.214916	 0.003	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	4562	 637	 0.049131	 0.124465	 0.001	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5696	 637	 0.066264	 0.147644	 0.002	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 638	 0.035926	 0.100864	 0.0049	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	3973	 638	 0.02037	 0.058272	 0.0028	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	5150	 639	 0.000504	 0.001008	 0.001	 26199	 26199	 26199	 0.0	 0.0	 1	 -30.0	 30.0;
	5055	 640	 0.000936	 0.006236	 0.0146	 441.0	 441.0	 441.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3930	 641	 0.000111	 0.001026	 0.0884	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	996	 643	 0.010859	 0.033384	 0.0319	 842	 842	 842	 0.0	 0.0	 1	 -30.0	 30.0;
	1340	 644	 0.013667	 0.025018	 0.0102	 1036	 1036	 1036	 0.0	 0.0	 1	 -30.0	 30.0;
	1340	 645	 0.014521	 0.026581	 0.0111	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 646	 0.039136	 0.164198	 0.0083	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 647	 0.094054	 0.195112	 0.0064	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	1735	 648	 0.025951	 0.083648	 0.001	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	4450	 648	 0.007811	 0.023432	 0.0137	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	1735	 648	 0.019652	 0.082892	 0.001	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	4921	 648	 0.018443	 0.068178	 0.0152	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	5779	 648	 0.004283	 0.016881	 0.0005	 1696	 1696	 1696	 0.0	 0.0	 1	 -30.0	 30.0;
	1780	 649	 0.006652	 0.028269	 0.0137	 1017	 1017	 1017	 0.0	 0.0	 1	 -30.0	 30.0;
	5179	 649	 0.002419	 0.0064	 0.0072	 4316	 4316	 4316	 0.0	 0.0	 1	 -30.0	 30.0;
	3174	 650	 0.039808	 0.101537	 0.0	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	3570	 650	 0.059965	 0.152431	 0.001	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	5217	 650	 0.042832	 0.121189	 0.0	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	5180	 651	 0.011358	 0.031852	 0.0015	 879	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	5181	 652	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	1999	 653	 0.026405	 0.082792	 0.0072	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 653	 0.078962	 0.217737	 0.0167	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	2854	 653	 0.009977	 0.060393	 0.0031	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	4364	 653	 0.035796	 0.065524	 0.0048	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 653	 0.015344	 0.039103	 0.0014	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 653	 0.041572	 0.119426	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	1073	 653	 0.1581	 0.413883	 0.0054	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	2184	 653	 0.043008	 0.113782	 0.0031	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	5151	 653	 0.006198	 0.037642	 0.002	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	3393	 654	 0.001636	 0.010939	 0.0216	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 655	 0.07677	 0.194835	 0.0021	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	3755	 655	 0.071651	 0.131155	 0.0098	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 656	 0.044344	 0.269085	 0.0001	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	1206	 657	 0.004535	 0.026707	 0.0045	 1090	 1090	 1090	 0.0	 0.0	 1	 -30.0	 30.0;
	3862	 657	 0.008062	 0.015369	 0.0117	 1702	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	1206	 657	 0.015747	 0.039909	 0.0005	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	2737	 658	 0.000257	 0.001758	 0.003	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3807	 658	 0.00162	 0.011121	 0.0213	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1619	 659	 0.00252	 0.006047	 0.0001	 4374	 4374	 4374	 0.0	 0.0	 1	 -30.0	 30.0;
	1429	 660	 0.03477	 0.094734	 0.001	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	5238	 660	 0.003779	 0.008818	 0.0001	 3171	 3171	 3171	 0.0	 0.0	 1	 -30.0	 30.0;
	5632	 661	 0.003173	 0.008432	 0.0005	 3297	 3297	 3297	 0.0	 0.0	 1	 -30.0	 30.0;
	4885	 662	 0.011185	 0.030482	 0.0014	 934	 934	 934	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 667	 1.4e-05	 0.000173	 0.0982	 183736	 183736	 183736	 0.0	 0.0	 1	 -30.0	 30.0;
	4459	 666	 1.4e-05	 0.000187	 0.0809	 170060	 170060	 170060	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 665	 1.4e-05	 0.000201	 0.0058	 158275	 158275	 158275	 0.0	 0.0	 1	 -30.0	 30.0;
	4459	 664	 1.4e-05	 0.000201	 0.0058	 158275	 158275	 158275	 0.0	 0.0	 1	 -30.0	 30.0;
	1816	 668	 0.038297	 0.171403	 0.0026	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	2523	 668	 0.119929	 0.324767	 0.0003	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	2548	 668	 0.044596	 0.286722	 0.0003	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	2759	 668	 0.131771	 0.295792	 0.0038	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	2223	 668	 0.006551	 0.017133	 0.0002	 1698	 1698	 1698	 0.0	 0.0	 1	 -30.0	 30.0;
	3663	 669	 0.005215	 0.035002	 0.0638	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2762	 670	 0.020494	 0.064938	 0.0031	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	4841	 670	 0.016914	 0.072593	 0.0036	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	5809	 670	 0.021482	 0.067284	 0.0032	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	4841	 670	 0.016914	 0.072716	 0.0036	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	1503	 671	 0.02037	 0.085185	 0.0044	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	2018	 671	 0.015309	 0.066296	 0.0029	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	5404	 671	 0.046543	 0.147531	 0.0072	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	1387	 672	 0.064349	 0.163291	 0.0018	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	3841	 672	 0.027916	 0.112976	 0.0013	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 672	 0.09229	 0.251852	 0.0033	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	3373	 673	 0.038801	 0.079617	 0.0009	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	3056	 674	 0.039506	 0.079012	 0.0036	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 675	 0.045603	 0.12522	 0.001	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	1668	 676	 0.001397	 0.009306	 0.0172	 340.0	 340.0	 340.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2706	 676	 0.003415	 0.021827	 0.04	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 677	 0.015815	 0.042765	 0.0038	 656	 656	 656	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 677	 0.01721	 0.046852	 0.0028	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	5184	 678	 2e-05	 9.9e-05	 0.0	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4928	 679	 0.012346	 0.034691	 0.0032	 807	 807	 807	 0.0	 0.0	 1	 -30.0	 30.0;
	2674	 680	 0.051111	 0.129383	 0.0062	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 681	 0.00952	 0.017427	 0.016	 1443	 1443	 1443	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 681	 0.009515	 0.017417	 0.0159	 1444	 1444	 1444	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 681	 0.008818	 0.016377	 0.0112	 1541	 1541	 1541	 0.0	 0.0	 1	 -30.0	 30.0;
	1314	 682	 0.043336	 0.082137	 0.0008	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5185	 682	 0.000171	 0.000313	 0.0	 85273	 85273	 85273	 0.0	 0.0	 1	 -30.0	 30.0;
	3894	 683	 0.0194	 0.081885	 0.0013	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	1994	 684	 0.022222	 0.047407	 0.0002	 499	 499	 499	 0.0	 0.0	 1	 -30.0	 30.0;
	5406	 684	 0.034568	 0.075062	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	1931	 685	 7e-06	 0.000132	 0.0058	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4198	 686	 0.000171	 0.000313	 0.001	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	1931	 687	 7e-06	 0.000104	 0.0029	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2341	 688	 0.000525	 0.000961	 0.0032	 27692	 27692	 27692	 0.0	 0.0	 1	 -30.0	 30.0;
	2342	 689	 0.000483	 0.000885	 0.0031	 30077	 30077	 30077	 0.0	 0.0	 1	 -30.0	 30.0;
	5478	 690	 0.047871	 0.145377	 0.001	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	4578	 691	 0.000237	 0.000573	 0.078	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	886	 692	 0.00716	 0.023086	 0.0014	 1255	 1255	 1255	 0.0	 0.0	 1	 -30.0	 30.0;
	2807	 692	 0.041975	 0.114568	 0.0	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	2329	 694	 0.000869	 0.003891	 0.0116	 414.0	 414.0	 414.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2329	 693	 0.000869	 0.003891	 0.0116	 414.0	 414.0	 414.0	 0.0	 0.0	 1	 -30.0	 30.0;
	736	 695	 0.031099	 0.097333	 0.0045	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	4023	 695	 0.016667	 0.087037	 0.0046	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	5571	 695	 0.00942	 0.025679	 0.0011	 1266	 1266	 1266	 0.0	 0.0	 1	 -30.0	 30.0;
	4678	 695	 0.013951	 0.057901	 0.0033	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	5199	 701	 0.002706	 0.0128	 0.0213	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3888	 703	 0.014074	 0.051235	 0.0119	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	4309	 702	 0.023704	 0.064	 0.0031	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	5186	 703	 0.009136	 0.05358	 0.0028	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 703	 0.016296	 0.044198	 0.0045	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	4309	 702	 0.02337	 0.062988	 0.0053	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 704	 0.00237	 0.015803	 0.0294	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4021	 705	 0.074074	 0.158025	 0.0012	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	5406	 705	 0.02321	 0.051852	 0.0	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 705	 0.044444	 0.09679	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	4847	 705	 0.108938	 0.258025	 0.001	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	5711	 706	 0.010988	 0.03	 0.0015	 930	 930	 930	 0.0	 0.0	 1	 -30.0	 30.0;
	2609	 711	 0.069753	 0.176914	 0.0083	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 711	 0.030741	 0.094568	 0.0082	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	2905	 710	 0.005309	 0.01284	 0.0138	 2138	 2138	 2138	 0.0	 0.0	 1	 -30.0	 30.0;
	3307	 710	 0.010321	 0.037247	 0.0019	 769	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	5426	 710	 0.010963	 0.037037	 0.0019	 769	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	3307	 710	 0.010321	 0.037235	 0.0019	 769	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	1717	 712	 0.003554	 0.024524	 0.0466	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2049	 712	 0.006493	 0.043265	 0.08	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4134	 712	 0.007921	 0.053985	 0.1013	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5391	 712	 0.004543	 0.030262	 0.0557	 485.0	 485.0	 485.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5187	 713	 0.000741	 0.002099	 0.0002	 13344	 13344	 13344	 0.0	 0.0	 1	 -30.0	 30.0;
	5222	 714	 0.038095	 0.105115	 0.0012	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 715	 0.001126	 0.004978	 0.0091	 6053	 6053	 6053	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 716	 0.079869	 0.202822	 0.0023	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	4997	 716	 0.079693	 0.202066	 0.0023	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	1181	 716	 0.035777	 0.090955	 0.001	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	3030	 716	 0.014865	 0.037793	 0.0004	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	1924	 717	 0.002963	 0.012346	 0.0025	 2340	 2340	 2340	 0.0	 0.0	 1	 -30.0	 30.0;
	716	 718	 0.007811	 0.019148	 0.0002	 1471	 1471	 1471	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 719	 0.032346	 0.088148	 0.004	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	5805	 719	 0.024321	 0.06642	 0.0031	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	5338	 720	 0.011086	 0.028723	 0.0003	 988	 988	 988	 0.0	 0.0	 1	 -30.0	 30.0;
	5522	 720	 0.022424	 0.057445	 0.0032	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	4321	 720	 0.027967	 0.071051	 0.0008	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	961	 721	 0.003536	 0.01683	 0.0284	 306.0	 306.0	 306.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4276	 721	 0.001541	 0.009936	 0.0258	 3057	 3057	 3057	 0.0	 0.0	 1	 -30.0	 30.0;
	4730	 721	 0.008375	 0.039704	 0.0658	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 722	 0.007901	 0.020123	 0.001	 1403	 1403	 1403	 0.0	 0.0	 1	 -30.0	 30.0;
	5624	 722	 0.001975	 0.005309	 0.0003	 5354	 5354	 5354	 0.0	 0.0	 1	 -30.0	 30.0;
	1387	 723	 0.070799	 0.179894	 0.002	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	1898	 723	 0.06324	 0.181658	 0.002	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	5667	 723	 0.035273	 0.089947	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	2840	 724	 0.03225	 0.082389	 0.0046	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	4271	 724	 0.001008	 0.003779	 0.0035	 7550	 7550	 7550	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 724	 0.018392	 0.076846	 0.001	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	4270	 724	 0.001008	 0.003779	 0.0006	 7550	 7550	 7550	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 724	 0.0194	 0.079113	 0.001	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	2175	 726	 0.078357	 0.200554	 0.0023	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	2446	 726	 0.081129	 0.214916	 0.0037	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	2716	 725	 0.056185	 0.351474	 0.0047	 88	 88	 88	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 725	 0.024188	 0.098262	 0.0013	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	4138	 725	 0.117158	 0.298312	 0.0033	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	5498	 725	 0.034014	 0.21542	 0.0027	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	5570	 725	 0.035777	 0.081633	 0.0039	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	2175	 726	 0.074326	 0.202066	 0.0023	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 725	 0.02318	 0.094986	 0.0012	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	4583	 725	 0.012598	 0.025951	 0.0003	 1086	 1086	 1086	 0.0	 0.0	 1	 -30.0	 30.0;
	853	 727	 0.011378	 0.053886	 0.0957	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2458	 727	 0.003457	 0.023724	 0.0445	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2648	 727	 0.008415	 0.041422	 0.0739	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 727	 0.003793	 0.017007	 0.0294	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 727	 0.004701	 0.026726	 0.0481	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 727	 0.001877	 0.018252	 0.0638	 604.0	 604.0	 604.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2459	 727	 0.001857	 0.017521	 0.0648	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3342	 729	 0.022424	 0.057193	 0.0006	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3342	 728	 0.021164	 0.056689	 0.0006	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	3342	 730	 0.021668	 0.05543	 0.0006	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	923	 731	 0.01033	 0.043588	 0.0012	 640	 640	 640	 0.0	 0.0	 1	 -30.0	 30.0;
	923	 731	 0.011338	 0.046359	 0.0013	 601	 601	 601	 0.0	 0.0	 1	 -30.0	 30.0;
	967	 732	 0.037037	 0.100988	 0.0052	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 733	 0.000252	 0.000756	 0.0	 37051	 37051	 37051	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 734	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 735	 0.00358	 0.00716	 0.0277	 3789	 3789	 3789	 0.0	 0.0	 1	 -30.0	 30.0;
	4822	 738	 0.015679	 0.040123	 0.0015	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	1557	 739	 4.8e-05	 8.8e-05	 0.0051	 308785	 308785	 308785	 0.0	 0.0	 1	 -30.0	 30.0;
	4039	 739	 0.000533	 0.004642	 0.4647	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2526	 742	 0.045024	 0.12522	 0.008	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	3653	 742	 0.022827	 0.061804	 0.0073	 462	 462	 462	 0.0	 0.0	 1	 -30.0	 30.0;
	4769	 742	 0.034266	 0.095994	 0.001	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	5464	 742	 0.045981	 0.13351	 0.0013	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	1668	 743	 0.002827	 0.011058	 0.0192	 363.0	 363.0	 363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2706	 743	 0.002258	 0.00946	 0.0172	 363.0	 363.0	 363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	745	 744	 0.024691	 0.062232	 0.001	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	5033	 744	 0.025951	 0.058453	 0.001	 462	 462	 462	 0.0	 0.0	 1	 -30.0	 30.0;
	3659	 745	 0.03351	 0.068783	 0.001	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	3610	 746	 0.00358	 0.009753	 0.0005	 2859	 2859	 2859	 0.0	 0.0	 1	 -30.0	 30.0;
	3422	 747	 0.049383	 0.13933	 0.0015	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	487	 748	 0.000617	 0.001358	 0.0018	 19914	 19914	 19914	 0.0	 0.0	 1	 -30.0	 30.0;
	2005	 749	 0.051146	 0.129756	 0.001	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	2036	 749	 0.070547	 0.176871	 0.0165	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 749	 0.082389	 0.208869	 0.0024	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	1215	 750	 0.046107	 0.21416	 0.003	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 750	 0.094986	 0.241875	 0.003	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	4946	 750	 0.152179	 0.27866	 0.003	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	1472	 752	 0.085412	 0.216427	 0.0025	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	3434	 752	 0.068304	 0.173369	 0.002	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 753	 0.025951	 0.07231	 0.001	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	2543	 754	 0.001363	 0.009126	 0.0172	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4736	 754	 0.0016	 0.010825	 0.0203	 470.0	 470.0	 470.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2543	 754	 0.001402	 0.009422	 0.0172	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4736	 754	 0.00162	 0.010963	 0.0213	 470.0	 470.0	 470.0	 0.0	 0.0	 1	 -30.0	 30.0;
	459	 755	 0.001153	 0.010798	 0.283	 1355.0	 1355.0	 1355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	459	 755	 0.00115	 0.010796	 0.283	 1355.0	 1355.0	 1355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2739	 756	 0.03099	 0.078861	 0.0009	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	2950	 756	 0.02328	 0.065306	 0.0008	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	4379	 756	 0.009826	 0.018141	 0.0005	 1432	 1432	 1432	 0.0	 0.0	 1	 -30.0	 30.0;
	5690	 756	 0.040312	 0.100025	 0.0011	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	3626	 757	 0.000377	 0.00069	 0.0273	 39366	 39366	 39366	 0.0	 0.0	 1	 -30.0	 30.0;
	3873	 757	 0.000336	 0.001304	 0.2906	 22986	 22986	 22986	 0.0	 0.0	 1	 -30.0	 30.0;
	759	 758	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4157	 759	 0.005472	 0.024889	 0.0445	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5193	 761	 0.000252	 0.000504	 0.001	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 764	 0.002137	 0.003912	 0.0002	 6823	 6823	 6823	 0.0	 0.0	 1	 -30.0	 30.0;
	1552	 765	 0.040312	 0.103804	 0.0012	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	3304	 765	 0.107811	 0.276493	 0.0035	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	3801	 766	 0.040262	 0.155757	 0.0032	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	4024	 766	 0.052406	 0.133787	 0.0015	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	340	 767	 0.03358	 0.091728	 0.0042	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	5111	 767	 0.002099	 0.005802	 0.0003	 4829	 4829	 4829	 0.0	 0.0	 1	 -30.0	 30.0;
	661	 768	 0.029877	 0.077654	 0.0102	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	1297	 768	 0.023457	 0.066173	 0.0031	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	2214	 768	 0.002222	 0.013951	 0.0013	 2103	 2103	 2103	 0.0	 0.0	 1	 -30.0	 30.0;
	2310	 768	 0.026741	 0.067815	 0.0037	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	3053	 768	 0.028272	 0.076914	 0.0045	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	4107	 768	 0.006049	 0.015679	 0.0006	 1768	 1768	 1768	 0.0	 0.0	 1	 -30.0	 30.0;
	4540	 768	 0.006667	 0.01679	 0.0008	 1645	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	5402	 768	 0.004691	 0.012716	 0.0006	 2192	 2192	 2192	 0.0	 0.0	 1	 -30.0	 30.0;
	5614	 768	 0.055679	 0.199383	 0.0094	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	1297	 768	 0.022346	 0.062716	 0.0057	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	3053	 768	 0.033704	 0.091852	 0.0053	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	1530	 769	 0.002015	 0.013551	 0.0764	 449.0	 449.0	 449.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3730	 769	 0.012484	 0.056454	 0.1002	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3784	 769	 0.000869	 0.003911	 0.0071	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3783	 769	 0.000869	 0.003911	 0.0071	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5749	 769	 0.001001	 0.006712	 0.0121	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1752	 773	 0.003578	 0.013454	 0.0002	 2121	 2121	 2121	 0.0	 0.0	 1	 -30.0	 30.0;
	1872	 773	 0.00126	 0.004535	 0.0	 6273	 6273	 6273	 0.0	 0.0	 1	 -30.0	 30.0;
	3709	 773	 0.001688	 0.00446	 0.0041	 6192	 6192	 6192	 0.0	 0.0	 1	 -30.0	 30.0;
	4842	 773	 0.017385	 0.071806	 0.001	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	5637	 773	 0.001764	 0.01285	 0.0	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	1872	 773	 0.001764	 0.004535	 0.0	 6068	 6068	 6068	 0.0	 0.0	 1	 -30.0	 30.0;
	5639	 773	 0.001512	 0.010582	 0.0	 2763	 2763	 2763	 0.0	 0.0	 1	 -30.0	 30.0;
	2295	 774	 0.069035	 0.192744	 0.0	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	918	 775	 0.026815	 0.072247	 0.0036	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	4822	 775	 0.004605	 0.022	 0.0888	 1363	 1363	 1363	 0.0	 0.0	 1	 -30.0	 30.0;
	899	 776	 0.013605	 0.039808	 0.0005	 723	 723	 723	 0.0	 0.0	 1	 -30.0	 30.0;
	2719	 776	 0.019148	 0.057697	 0.0007	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	3757	 776	 0.027715	 0.083144	 0.001	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	900	 776	 0.013605	 0.039557	 0.0005	 728	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 777	 0.000614	 0.004093	 0.0278	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	948	 780	 0.002016	 0.005543	 0.0001	 5006	 5006	 5006	 0.0	 0.0	 1	 -30.0	 30.0;
	948	 779	 0.001008	 0.003023	 0.0001	 9266	 9266	 9266	 0.0	 0.0	 1	 -30.0	 30.0;
	948	 778	 0.00126	 0.004787	 0.0001	 5965	 5965	 5965	 0.0	 0.0	 1	 -30.0	 30.0;
	5196	 781	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	1755	 782	 0.116679	 0.308919	 0.0037	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	2509	 782	 0.102545	 0.271529	 0.0045	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 784	 0.000523	 0.002596	 0.2992	 342.0	 342.0	 342.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5198	 785	 0.000171	 0.000313	 0.0002	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 789	 0.021416	 0.058201	 0.001	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	3417	 788	 0.048123	 0.15747	 0.002	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	3456	 789	 0.03477	 0.097254	 0.002	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	4319	 788	 0.066516	 0.17284	 0.0051	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	4534	 789	 0.024691	 0.062736	 0.0	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	4771	 788	 0.045603	 0.137566	 0.002	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 789	 0.026959	 0.085664	 0.001	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	5819	 789	 0.001008	 0.004031	 0.0	 7106	 7106	 7106	 0.0	 0.0	 1	 -30.0	 30.0;
	1336	 789	 0.032363	 0.059241	 0.001	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	4534	 788	 0.027715	 0.089443	 0.001	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	700	 790	 0.00484	 0.021393	 0.0385	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 790	 0.001541	 0.007309	 0.0121	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	921	 790	 0.000672	 0.004602	 0.0152	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1977	 790	 0.00243	 0.011477	 0.0192	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4772	 790	 0.002311	 0.011378	 0.0233	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5225	 790	 0.000474	 0.002331	 0.0081	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5265	 790	 0.002825	 0.019082	 0.0344	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1899	 790	 0.004286	 0.029037	 0.0527	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5199	 790	 0.002074	 0.009758	 0.0162	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	954	 791	 0.001566	 0.015874	 0.4101	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1214	 791	 0.001309	 0.01286	 0.335	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2622	 792	 0.005346	 0.009785	 0.0123	 2728	 2728	 2728	 0.0	 0.0	 1	 -30.0	 30.0;
	2342	 793	 0.030617	 0.077654	 0.006	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	4615	 793	 0.019259	 0.05321	 0.0024	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	4895	 794	 0.030234	 0.076846	 0.0009	 369	 369	 369	 0.0	 0.0	 1	 -30.0	 30.0;
	4833	 795	 0.045352	 0.11489	 0.0013	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	4895	 795	 0.030234	 0.076846	 0.0009	 369	 369	 369	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 796	 0.012547	 0.053666	 0.0118	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	922	 796	 0.000504	 0.001764	 0.0021	 16094	 16094	 16094	 0.0	 0.0	 1	 -30.0	 30.0;
	818	 797	 0.00252	 0.006677	 0.0075	 4138	 4138	 4138	 0.0	 0.0	 1	 -30.0	 30.0;
	3117	 797	 0.001764	 0.003779	 0.0	 7080	 7080	 7080	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 797	 0.004913	 0.012976	 0.0147	 2128	 2128	 2128	 0.0	 0.0	 1	 -30.0	 30.0;
	1218	 798	 0.026707	 0.067271	 0.001	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	1982	 799	 0.019904	 0.083144	 0.0091	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	3487	 799	 0.0451	 0.131267	 0.0172	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	4399	 799	 0.003275	 0.011086	 0.0152	 2555	 2555	 2555	 0.0	 0.0	 1	 -30.0	 30.0;
	1982	 799	 0.019652	 0.082892	 0.0091	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	939	 800	 7e-06	 0.000125	 0.0029	 552.0	 552.0	 552.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1956	 800	 0.000693	 0.007687	 0.1704	 1355.0	 1355.0	 1355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5199	 804	 0.000691	 0.003279	 0.0051	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 806	 0.002398	 0.004389	 0.0	 6082	 6082	 6082	 0.0	 0.0	 1	 -30.0	 30.0;
	1760	 807	 0.000171	 0.000313	 0.0	 85273	 85273	 85273	 0.0	 0.0	 1	 -30.0	 30.0;
	3140	 807	 0.053666	 0.152431	 0.0002	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	1475	 809	 0.000277	 0.001916	 0.003	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1475	 808	 0.000277	 0.001936	 0.003	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1607	 810	 0.07609	 0.179642	 0.0017	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	4916	 810	 0.037289	 0.079113	 0.0009	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 811	 0.007811	 0.029	 0.0303	 1013	 1013	 1013	 0.0	 0.0	 1	 -30.0	 30.0;
	5604	 811	 0.010456	 0.02905	 0.0003	 986	 986	 986	 0.0	 0.0	 1	 -30.0	 30.0;
	5599	 811	 0.008818	 0.029982	 0.0003	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 812	 0.000217	 0.001205	 0.0086	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 813	 0.00446	 0.009121	 0.0001	 2909	 2909	 2909	 0.0	 0.0	 1	 -30.0	 30.0;
	4434	 814	 0.052658	 0.134467	 0.0039	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	4915	 814	 0.025598	 0.068405	 0.0012	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 816	 0.000252	 0.001512	 0.0	 19262	 19262	 19262	 0.0	 0.0	 1	 -30.0	 30.0;
	5285	 815	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	1560	 817	 0.00162	 0.007447	 0.0132	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3727	 817	 0.000889	 0.005965	 0.0111	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2435	 818	 0.000252	 0.000504	 0.0005	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	820	 819	 0.001008	 0.003527	 0.0043	 8292	 8292	 8292	 0.0	 0.0	 1	 -30.0	 30.0;
	4317	 819	 0.010834	 0.042328	 0.0101	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 820	 0.056941	 0.155203	 0.0017	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 820	 0.066264	 0.139582	 0.0015	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 821	 0.000533	 0.003536	 0.0061	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 822	 0.000178	 0.001185	 0.002	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4822	 823	 0.008148	 0.020247	 0.0008	 1405	 1405	 1405	 0.0	 0.0	 1	 -30.0	 30.0;
	2127	 824	 0.002889	 0.0064	 0.0022	 4554	 4554	 4554	 0.0	 0.0	 1	 -30.0	 30.0;
	4240	 825	 0.008062	 0.022172	 0.0002	 1252	 1252	 1252	 0.0	 0.0	 1	 -30.0	 30.0;
	2005	 826	 0.13293	 0.358201	 0.0161	 80	 80	 80	 0.0	 0.0	 1	 -30.0	 30.0;
	3658	 827	 0.000205	 0.002108	 0.2577	 546.0	 546.0	 546.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1195	 828	 0.002899	 0.029385	 0.7595	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 828	 0.002045	 0.020735	 0.5343	 1524	 1524	 1524	 0.0	 0.0	 1	 -30.0	 30.0;
	2712	 829	 0.010864	 0.032346	 0.0046	 941	 941	 941	 0.0	 0.0	 1	 -30.0	 30.0;
	3087	 831	 0.028148	 0.076543	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	4037	 831	 0.019753	 0.048889	 0.0	 496	 496	 496	 0.0	 0.0	 1	 -30.0	 30.0;
	4671	 832	 0.002922	 0.005348	 0.0048	 4845	 4845	 4845	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 833	 0.001906	 0.003489	 0.0	 7650	 7650	 7650	 0.0	 0.0	 1	 -30.0	 30.0;
	1672	 834	 0.008889	 0.055185	 0.0031	 543	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 834	 0.006914	 0.043457	 0.0023	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	2229	 835	 0.021416	 0.110355	 0.0205	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	3020	 835	 0.051146	 0.139078	 0.01	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	3373	 835	 0.041068	 0.135551	 0.0215	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 836	 0.05039	 0.120937	 0.0014	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	3650	 836	 0.017637	 0.048375	 0.0006	 591	 591	 591	 0.0	 0.0	 1	 -30.0	 30.0;
	4770	 836	 0.010582	 0.027967	 0.0003	 1018	 1018	 1018	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 838	 0.031903	 0.058397	 0.0006	 458	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 837	 0.053666	 0.119174	 0.0013	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5535	 837	 0.001214	 0.002222	 0.0001	 12012	 12012	 12012	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 839	 0.015092	 0.041673	 0.0005	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 840	 0.081104	 0.188234	 0.0033	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	4116	 840	 0.050139	 0.113631	 0.0013	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	4822	 841	 0.016543	 0.033951	 0.0016	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	5200	 842	 0.000378	 0.001008	 0.0001	 27427	 27427	 27427	 0.0	 0.0	 1	 -30.0	 30.0;
	1877	 843	 0.000988	 0.002716	 0.0133	 10493	 10493	 10493	 0.0	 0.0	 1	 -30.0	 30.0;
	1877	 843	 0.000988	 0.002716	 0.0133	 10493	 10493	 10493	 0.0	 0.0	 1	 -30.0	 30.0;
	1547	 844	 0.059209	 0.148652	 0.0018	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 844	 0.069539	 0.19098	 0.0	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	2992	 846	 0.011298	 0.020682	 0.0088	 1253	 1253	 1253	 0.0	 0.0	 1	 -30.0	 30.0;
	2992	 848	 0.008062	 0.017133	 0.0156	 1560	 1560	 1560	 0.0	 0.0	 1	 -30.0	 30.0;
	2992	 847	 0.007811	 0.016125	 0.0148	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	1918	 849	 0.075838	 0.19224	 0.0021	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3789	 849	 0.010834	 0.027715	 0.0003	 1023	 1023	 1023	 0.0	 0.0	 1	 -30.0	 30.0;
	3948	 849	 0.02973	 0.096246	 0.0218	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	5537	 849	 0.009826	 0.031242	 0.0004	 929	 929	 929	 0.0	 0.0	 1	 -30.0	 30.0;
	5258	 849	 0.043537	 0.154271	 0.0224	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	5538	 849	 0.01285	 0.032754	 0.0004	 865	 865	 865	 0.0	 0.0	 1	 -30.0	 30.0;
	2774	 850	 0.00924	 0.060219	 0.1124	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2995	 850	 0.009007	 0.066726	 0.1192	 462	 462	 462	 0.0	 0.0	 1	 -30.0	 30.0;
	3158	 850	 0.004543	 0.030479	 0.0547	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3158	 850	 0.004326	 0.029037	 0.0527	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4020	 851	 0.001357	 0.017597	 0.3494	 1807	 1807	 1807	 0.0	 0.0	 1	 -30.0	 30.0;
	4020	 851	 0.001343	 0.01741	 0.3437	 1827	 1827	 1827	 0.0	 0.0	 1	 -30.0	 30.0;
	1816	 852	 0.022928	 0.141849	 0.0095	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	1816	 852	 0.022424	 0.140086	 0.0026	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	3663	 853	 0.003615	 0.024178	 0.0445	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2583	 854	 0.001136	 0.012154	 0.2657	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 854	 0.001309	 0.013996	 0.3061	 1917.0	 1917.0	 1917.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1137	 855	 0.053918	 0.138574	 0.0016	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 856	 0.005039	 0.013102	 0.0002	 2104	 2104	 2104	 0.0	 0.0	 1	 -30.0	 30.0;
	2711	 857	 0.092441	 0.276669	 0.0072	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	3104	 857	 0.084152	 0.229781	 0.0025	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 857	 0.036281	 0.092215	 0.001	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	2964	 858	 0.011086	 0.038045	 0.0137	 768	 768	 768	 0.0	 0.0	 1	 -30.0	 30.0;
	4901	 858	 0.002268	 0.007559	 0.0075	 3854	 3854	 3854	 0.0	 0.0	 1	 -30.0	 30.0;
	3210	 860	 0.000257	 0.001521	 0.162	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3335	 860	 0.000259	 0.000506	 0.042	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2372	 861	 0.103301	 0.282187	 0.0032	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	3443	 861	 0.062106	 0.169463	 0.0019	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	3896	 861	 0.068027	 0.185941	 0.0021	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 861	 0.078357	 0.213404	 0.0024	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 863	 0.000928	 0.006202	 0.0111	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 862	 0.000928	 0.006202	 0.0111	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5212	 865	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5209	 864	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	4209	 866	 0.044344	 0.084656	 0.0015	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	1154	 867	 0.01033	 0.028219	 0.0013	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	5382	 868	 0.005679	 0.011358	 0.0005	 2340	 2340	 2340	 0.0	 0.0	 1	 -30.0	 30.0;
	1607	 869	 0.114135	 0.237087	 0.0026	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 869	 0.04258	 0.178634	 0.0021	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	4486	 869	 0.000756	 0.002268	 0.0	 12351	 12351	 12351	 0.0	 0.0	 1	 -30.0	 30.0;
	2482	 871	 0.009245	 0.016923	 0.0002	 1532	 1532	 1532	 0.0	 0.0	 1	 -30.0	 30.0;
	2482	 870	 0.006047	 0.011086	 0.0059	 2339	 2339	 2339	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 872	 0.005062	 0.032222	 0.0048	 930	 930	 930	 0.0	 0.0	 1	 -30.0	 30.0;
	4643	 872	 0.005802	 0.035926	 0.0019	 834	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 873	 0.031494	 0.085412	 0.001	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 873	 0.025951	 0.066516	 0.0007	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	4590	 873	 0.006803	 0.014361	 0.013	 1859	 1859	 1859	 0.0	 0.0	 1	 -30.0	 30.0;
	2660	 874	 0.024213	 0.081355	 0.029	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 874	 0.011338	 0.033006	 0.0133	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 876	 0.014613	 0.03099	 0.0281	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 875	 0.014613	 0.03099	 0.0283	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 877	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5210	 878	 2e-05	 0.000198	 0.001	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3386	 879	 0.079869	 0.176619	 0.0094	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	3724	 879	 0.066667	 0.149232	 0.0017	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4754	 879	 0.003023	 0.01033	 0.0002	 2759	 2759	 2759	 0.0	 0.0	 1	 -30.0	 30.0;
	5041	 879	 0.068027	 0.128748	 0.0014	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	5660	 880	 0.045352	 0.116906	 0.0013	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5763	 880	 0.120181	 0.240867	 0.0026	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	4775	 879	 0.122701	 0.306374	 0.0034	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	2037	 881	 0.001067	 0.00723	 0.0132	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2978	 882	 0.003358	 0.022341	 0.0415	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3605	 881	 0.00318	 0.020938	 0.0395	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 881	 0.000928	 0.008968	 0.0314	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5818	 882	 0.004899	 0.022815	 0.0405	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 882	 0.000889	 0.008415	 0.0314	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 883	 0.004444	 0.028395	 0.0151	 1095	 1095	 1095	 0.0	 0.0	 1	 -30.0	 30.0;
	5287	 883	 0.004691	 0.029012	 0.0016	 1181	 1181	 1181	 0.0	 0.0	 1	 -30.0	 30.0;
	5439	 884	 0.007055	 0.018392	 0.0002	 1499	 1499	 1499	 0.0	 0.0	 1	 -30.0	 30.0;
	5216	 885	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	3300	 886	 0.01037	 0.026173	 0.0013	 1078	 1078	 1078	 0.0	 0.0	 1	 -30.0	 30.0;
	4672	 886	 0.070864	 0.193457	 0.0091	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	5547	 886	 0.022222	 0.056914	 0.0	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	2179	 888	 0.000237	 0.001422	 0.1686	 21471	 21471	 21471	 0.0	 0.0	 1	 -30.0	 30.0;
	2999	 887	 0.000277	 0.001086	 0.1417	 27618	 27618	 27618	 0.0	 0.0	 1	 -30.0	 30.0;
	4118	 887	 0.000296	 0.000672	 0.0678	 42153	 42153	 42153	 0.0	 0.0	 1	 -30.0	 30.0;
	1307	 890	 0.002267	 0.007156	 0.0022	 4057	 4057	 4057	 0.0	 0.0	 1	 -30.0	 30.0;
	2033	 891	 0.016377	 0.102041	 0.0013	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 891	 0.008062	 0.050139	 0.0006	 599	 599	 599	 0.0	 0.0	 1	 -30.0	 30.0;
	2531	 892	 0.001512	 0.004787	 0.004	 5882	 5882	 5882	 0.0	 0.0	 1	 -30.0	 30.0;
	3373	 893	 0.031746	 0.133031	 0.0002	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 893	 0.020912	 0.088939	 0.001	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	4775	 894	 0.05543	 0.147644	 0.0017	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 895	 0.000286	 0.004868	 0.1762	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 896	 0.000287	 0.004892	 0.1776	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 897	 0.000283	 0.004814	 0.1762	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 898	 0.000285	 0.004843	 0.1733	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5071	 901	 0.011852	 0.045062	 0.017	 651	 651	 651	 0.0	 0.0	 1	 -30.0	 30.0;
	5841	 901	 0.000864	 0.002593	 0.0136	 11095	 11095	 11095	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 902	 0.048249	 0.235702	 0.0035	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 903	 0.044321	 0.121605	 0.001	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	4156	 903	 0.028765	 0.078889	 0.0006	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	3373	 904	 0.019652	 0.080877	 0.0014	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 904	 0.017385	 0.073822	 0.0001	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	3567	 905	 0.000514	 0.001383	 0.0952	 20979	 20979	 20979	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 905	 0.000247	 0.001084	 0.1478	 403.0	 403.0	 403.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5792	 906	 0.013857	 0.025447	 0.0002	 1019	 1019	 1019	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 907	 0.00284	 0.011235	 0.001	 2617	 2617	 2617	 0.0	 0.0	 1	 -30.0	 30.0;
	3640	 908	 0.015369	 0.040816	 0.0005	 677	 677	 677	 0.0	 0.0	 1	 -30.0	 30.0;
	5793	 908	 0.041068	 0.104812	 0.0012	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	2478	 909	 0.058957	 0.16125	 0.0018	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	4433	 909	 0.024439	 0.102293	 0.0012	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	1748	 910	 0.006047	 0.016629	 0.014	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	5223	 913	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	2308	 915	 0.013096	 0.066153	 0.12	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 914	 0.002074	 0.009956	 0.0172	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 914	 0.001533	 0.009225	 0.0172	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 915	 0.00156	 0.009343	 0.0172	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2775	 916	 0.001452	 0.020223	 0.6741	 1573	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	4854	 916	 0.001672	 0.022177	 0.7607	 1434	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	2775	 916	 0.001447	 0.020166	 0.6721	 1578	 1578	 1578	 0.0	 0.0	 1	 -30.0	 30.0;
	4854	 916	 0.001669	 0.022168	 0.7624	 1435	 1435	 1435	 0.0	 0.0	 1	 -30.0	 30.0;
	5224	 917	 0.035525	 0.090199	 0.001	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	4822	 918	 0.031568	 0.094272	 0.0992	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	1797	 919	 0.118166	 0.243386	 0.0026	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 919	 0.015621	 0.032754	 0.0003	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	4452	 919	 0.05417	 0.183673	 0.0021	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5160	 920	 0.040338	 0.097909	 0.0009	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5743	 920	 0.022424	 0.053918	 0.0	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	5552	 922	 0.02066	 0.088183	 0.0051	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	1343	 923	 0.014361	 0.059461	 0.006	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	2554	 923	 0.016377	 0.101537	 0.0023	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	1343	 923	 0.014361	 0.059713	 0.006	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	2554	 923	 0.016377	 0.101537	 0.0019	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	3147	 924	 0.002874	 0.022174	 0.4476	 1397.0	 1397.0	 1397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3361	 924	 0.000139	 0.001115	 0.0231	 1486.0	 1486.0	 1486.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2391	 925	 0.00252	 0.006551	 0.0001	 4207	 4207	 4207	 0.0	 0.0	 1	 -30.0	 30.0;
	3831	 925	 0.011842	 0.052658	 0.001	 548	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	2699	 926	 0.089947	 0.390527	 0.0051	 75	 75	 75	 0.0	 0.0	 1	 -30.0	 30.0;
	5314	 926	 0.027463	 0.060721	 0.001	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 927	 0.009877	 0.026959	 0.0003	 1061	 1061	 1061	 0.0	 0.0	 1	 -30.0	 30.0;
	1786	 928	 0.010582	 0.063492	 0.0076	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	1786	 928	 0.009902	 0.059007	 0.0157	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 929	 0.013605	 0.054926	 0.0007	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	5808	 930	 0.042328	 0.160998	 0.0017	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	3478	 931	 0.00322	 0.021136	 0.0395	 460.0	 460.0	 460.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3549	 931	 0.000553	 0.003694	 0.0071	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5414	 932	 0.000494	 0.005689	 0.0142	 720.0	 720.0	 720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5463	 931	 0.000652	 0.004504	 0.0081	 437.0	 437.0	 437.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5465	 931	 0.000652	 0.004504	 0.0081	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5412	 932	 0.000514	 0.005689	 0.0142	 720.0	 720.0	 720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 933	 0.000869	 0.008435	 0.0339	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5356	 933	 0.000889	 0.008553	 0.039	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 934	 0.000686	 0.007091	 0.1747	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4594	 934	 0.000609	 0.006378	 0.1473	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 935	 0.000686	 0.007119	 0.1747	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4595	 935	 0.000609	 0.006406	 0.1487	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2805	 936	 0.027531	 0.074938	 0.0036	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	5665	 936	 0.024198	 0.065802	 0.0031	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	2111	 937	 0.090199	 0.246158	 0.0033	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	2544	 937	 0.005291	 0.022172	 0.0006	 1366	 1366	 1366	 0.0	 0.0	 1	 -30.0	 30.0;
	3204	 937	 0.012346	 0.050894	 0.001	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	3541	 937	 0.053414	 0.224238	 0.0028	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	5469	 937	 0.007811	 0.032502	 0.0004	 1012	 1012	 1012	 0.0	 0.0	 1	 -30.0	 30.0;
	5634	 937	 0.034014	 0.142857	 0.0002	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	2544	 937	 0.005543	 0.022172	 0.0006	 1363	 1363	 1363	 0.0	 0.0	 1	 -30.0	 30.0;
	4879	 938	 0.002074	 0.013847	 0.0253	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4879	 938	 0.002074	 0.013847	 0.0253	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2552	 940	 0.036533	 0.12522	 0.0014	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	1528	 941	 0.009012	 0.025062	 0.0056	 1116	 1116	 1116	 0.0	 0.0	 1	 -30.0	 30.0;
	1528	 941	 0.006667	 0.028025	 0.0015	 1032	 1032	 1032	 0.0	 0.0	 1	 -30.0	 30.0;
	3331	 943	 0.031771	 0.081809	 0.001	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	3908	 943	 0.070799	 0.179894	 0.002	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	2455	 942	 0.075586	 0.191736	 0.0021	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3908	 942	 0.070925	 0.179239	 0.0021	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3300	 944	 0.003901	 0.009877	 0.0005	 2856	 2856	 2856	 0.0	 0.0	 1	 -30.0	 30.0;
	2701	 945	 0.003023	 0.008314	 0.0001	 3338	 3338	 3338	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 945	 0.037793	 0.097002	 0.0011	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	5492	 945	 0.003023	 0.008314	 0.0001	 3338	 3338	 3338	 0.0	 0.0	 1	 -30.0	 30.0;
	2207	 946	 0.020988	 0.058272	 0.0176	 480	 480	 480	 0.0	 0.0	 1	 -30.0	 30.0;
	2805	 946	 0.02679	 0.072222	 0.0034	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	2590	 947	 0.018519	 0.047654	 0.0185	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	3425	 947	 0.029877	 0.080864	 0.0039	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	1040	 948	 0.016125	 0.067775	 0.0051	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	1098	 948	 0.032502	 0.083144	 0.0009	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	2354	 948	 0.025447	 0.08642	 0.0079	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	3065	 948	 0.02192	 0.04384	 0.0383	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	1042	 949	 0.00083	 0.005649	 0.0111	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1194	 949	 0.002193	 0.014894	 0.0284	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2654	 950	 0.002145	 0.011151	 0.0203	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5225	 950	 0.00638	 0.031486	 0.0537	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1513	 951	 0.01037	 0.020741	 0.002	 1281	 1281	 1281	 0.0	 0.0	 1	 -30.0	 30.0;
	1369	 952	 0.002346	 0.006296	 0.0003	 4421	 4421	 4421	 0.0	 0.0	 1	 -30.0	 30.0;
	2294	 953	 0.022096	 0.08841	 0.0011	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	2309	 953	 0.025724	 0.105316	 0.0184	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	2906	 953	 0.029957	 0.121013	 0.0046	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	4403	 953	 0.009322	 0.028471	 0.0	 991	 991	 991	 0.0	 0.0	 1	 -30.0	 30.0;
	4630	 953	 0.046107	 0.130763	 0.001	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 953	 0.006047	 0.041068	 0.001	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	4403	 953	 0.004334	 0.026732	 0.001	 1097	 1097	 1097	 0.0	 0.0	 1	 -30.0	 30.0;
	1214	 954	 0.002877	 0.028829	 0.7494	 1100	 1100	 1100	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 954	 0.002188	 0.024233	 0.5227	 1311	 1311	 1311	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 954	 0.000997	 0.014175	 0.465	 2245	 2245	 2245	 0.0	 0.0	 1	 -30.0	 30.0;
	2910	 954	 0.000376	 0.002891	 0.0606	 1308.0	 1308.0	 1308.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3598	 954	 0.000976	 0.009886	 0.2541	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4459	 954	 0.000389	 0.003951	 0.1011	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 954	 0.001562	 0.01912	 0.4274	 1567.0	 1567.0	 1567.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 954	 0.000998	 0.014177	 0.465	 2244	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	2910	 954	 0.000199	 0.002553	 0.0838	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3598	 954	 0.000976	 0.009891	 0.2541	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 954	 0.000388	 0.003954	 0.1011	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 954	 0.000395	 0.004003	 0.104	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4459	 954	 0.000395	 0.004003	 0.104	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4899	 955	 0.000617	 0.001235	 0.0019	 21515	 21515	 21515	 0.0	 0.0	 1	 -30.0	 30.0;
	5231	 956	 0.00037	 0.000864	 0.0	 31602	 31602	 31602	 0.0	 0.0	 1	 -30.0	 30.0;
	2942	 957	 0.00252	 0.007811	 0.0001	 3706	 3706	 3706	 0.0	 0.0	 1	 -30.0	 30.0;
	1179	 958	 0.029383	 0.08037	 0.0037	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 958	 0.000617	 0.001728	 0.0002	 16188	 16188	 16188	 0.0	 0.0	 1	 -30.0	 30.0;
	2941	 959	 0.066264	 0.181154	 0.0024	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3908	 959	 0.086672	 0.222021	 0.0026	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	4431	 959	 0.020584	 0.054523	 0.0006	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	2733	 960	 0.009506	 0.029383	 0.0094	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	3453	 960	 0.014691	 0.038518	 0.0121	 721	 721	 721	 0.0	 0.0	 1	 -30.0	 30.0;
	3761	 960	 0.030494	 0.079136	 0.0134	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 960	 0.022839	 0.059012	 0.0131	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	4042	 960	 0.01716	 0.081975	 0.005	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 960	 0.002593	 0.006173	 0.0042	 4437	 4437	 4437	 0.0	 0.0	 1	 -30.0	 30.0;
	2734	 960	 0.009506	 0.029506	 0.0096	 959	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	3760	 960	 0.030494	 0.079012	 0.0153	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 961	 0.003101	 0.020859	 0.0375	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 961	 0.004978	 0.022005	 0.0359	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 961	 0.003121	 0.0208	 0.0506	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 963	 0.000499	 0.005048	 0.13	 1380.0	 1380.0	 1380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 962	 0.000499	 0.005042	 0.13	 1380.0	 1380.0	 1380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	968	 964	 0.010985	 0.027891	 0.0014	 1015	 1015	 1015	 0.0	 0.0	 1	 -30.0	 30.0;
	2942	 964	 0.079113	 0.201058	 0.0075	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	1740	 966	 0.002193	 0.010884	 0.0197	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4125	 966	 0.004049	 0.018272	 0.0324	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3308	 967	 0.057284	 0.127778	 0.0057	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 967	 0.015309	 0.041728	 0.0019	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	2256	 968	 0.091711	 0.291509	 0.0034	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	2597	 968	 0.193139	 0.35354	 0.0037	 76	 76	 76	 0.0	 0.0	 1	 -30.0	 30.0;
	4089	 968	 0.056437	 0.143109	 0.0016	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	1846	 968	 0.049131	 0.124969	 0.0078	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	4804	 968	 0.021416	 0.054422	 0.0006	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	1243	 969	 0.011032	 0.050442	 0.0871	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2081	 969	 0.001481	 0.013926	 0.0516	 604.0	 604.0	 604.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2081	 969	 0.001481	 0.013926	 0.0516	 604.0	 604.0	 604.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2766	 970	 0.023935	 0.0645	 0.0007	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	3044	 972	 0.000342	 0.000625	 0.0002	 41442	 41442	 41442	 0.0	 0.0	 1	 -30.0	 30.0;
	3338	 972	 0.059713	 0.152179	 0.003	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	5232	 973	 0.018645	 0.047871	 0.0013	 575	 575	 575	 0.0	 0.0	 1	 -30.0	 30.0;
	2953	 974	 0.019259	 0.052593	 0.0024	 531	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	3358	 974	 0.01716	 0.044938	 0.0021	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	5708	 974	 0.025185	 0.064691	 0.0031	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	3358	 974	 0.00716	 0.029753	 0.0016	 971	 971	 971	 0.0	 0.0	 1	 -30.0	 30.0;
	5352	 974	 0.046667	 0.125926	 0.006	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3358	 974	 0.00716	 0.02963	 0.0016	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	1515	 975	 0.0016	 0.017334	 0.4043	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2451	 975	 0.000312	 0.004044	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 975	 0.000824	 0.010499	 0.3754	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4961	 975	 0.00133	 0.014252	 0.3263	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2451	 975	 0.000312	 0.004044	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 975	 0.000824	 0.010505	 0.3754	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2238	 976	 0.140111	 0.432376	 0.0055	 67	 67	 67	 0.0	 0.0	 1	 -30.0	 30.0;
	2642	 976	 0.1065	 0.298388	 0.0035	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	2766	 976	 0.012346	 0.05039	 0.0012	 587	 587	 587	 0.0	 0.0	 1	 -30.0	 30.0;
	3801	 976	 0.024994	 0.166415	 0.0019	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4024	 976	 0.033686	 0.073394	 0.0008	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 976	 0.009347	 0.042404	 0.0163	 701	 701	 701	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 976	 0.089796	 0.228471	 0.0026	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 976	 0.0097	 0.04457	 0.0192	 667	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	3802	 977	 0.001936	 0.012879	 0.0243	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1110	 978	 0.023432	 0.074578	 0.001	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	4516	 978	 0.010834	 0.028471	 0.0	 992	 992	 992	 0.0	 0.0	 1	 -30.0	 30.0;
	5543	 978	 0.035273	 0.103301	 0.001	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	5773	 978	 0.009322	 0.023935	 0.0002	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	4998	 978	 0.019728	 0.054548	 0.0006	 518	 518	 518	 0.0	 0.0	 1	 -30.0	 30.0;
	2475	 979	 0.010617	 0.044444	 0.0023	 651	 651	 651	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 979	 0.044198	 0.120864	 0.0058	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	2164	 980	 0.010582	 0.027463	 0.0003	 1004	 1004	 1004	 0.0	 0.0	 1	 -30.0	 30.0;
	3830	 980	 0.011842	 0.030486	 0.0003	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 982	 0.020123	 0.052839	 0.0024	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	2709	 982	 0.011482	 0.023086	 0.001	 1152	 1152	 1152	 0.0	 0.0	 1	 -30.0	 30.0;
	1201	 983	 0.001111	 0.00321	 0.0008	 8928	 8928	 8928	 0.0	 0.0	 1	 -30.0	 30.0;
	4414	 984	 0.000164	 0.001106	 0.002	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3194	 985	 0.024188	 0.067523	 0.0031	 412	 412	 412	 0.0	 0.0	 1	 -30.0	 30.0;
	3462	 986	 0.038765	 0.105062	 0.0049	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	2299	 987	 0.011358	 0.022839	 0.001	 1165	 1165	 1165	 0.0	 0.0	 1	 -30.0	 30.0;
	2290	 988	 0.001764	 0.006299	 0.0076	 4380	 4380	 4380	 0.0	 0.0	 1	 -30.0	 30.0;
	3732	 988	 0.004188	 0.007666	 0.006	 3280	 3280	 3280	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 988	 0.004289	 0.007852	 0.0061	 3203	 3203	 3203	 0.0	 0.0	 1	 -30.0	 30.0;
	4788	 988	 0.002016	 0.005039	 0.0054	 5279	 5279	 5279	 0.0	 0.0	 1	 -30.0	 30.0;
	1119	 990	 0.000336	 0.000849	 0.1448	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1182	 989	 0.000178	 0.000691	 0.1002	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4907	 990	 0.000316	 0.001304	 0.1863	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4937	 990	 9.9e-05	 0.000612	 0.082	 387.0	 387.0	 387.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3552	 991	 0.024691	 0.083648	 0.001	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	3767	 991	 0.070547	 0.239607	 0.0028	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	1346	 992	 0.065256	 0.144369	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	2066	 992	 0.024943	 0.10456	 0.001	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	5228	 993	 0.036029	 0.09675	 0.0045	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	1085	 994	 0.074074	 0.201562	 0.0022	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	2105	 994	 0.112119	 0.304107	 0.0034	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	1038	 996	 0.019652	 0.081885	 0.0052	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	1078	 996	 0.010078	 0.039305	 0.0	 728	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 996	 0.019652	 0.082389	 0.0081	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	5269	 996	 0.00252	 0.01033	 0.0	 2777	 2777	 2777	 0.0	 0.0	 1	 -30.0	 30.0;
	4757	 997	 0.001146	 0.007111	 0.2238	 298.0	 298.0	 298.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2068	 998	 0.001136	 0.012874	 0.2917	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3598	 998	 0.000547	 0.010021	 0.2801	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4459	 998	 0.001184	 0.012029	 0.309	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1581	 998	 0.000369	 0.006726	 0.1892	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2067	 998	 0.001136	 0.012874	 0.2917	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 998	 0.001177	 0.012029	 0.309	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4949	 999	 0.007531	 0.019136	 0.0042	 1475	 1475	 1475	 0.0	 0.0	 1	 -30.0	 30.0;
	5703	 999	 0.011975	 0.031975	 0.0065	 889	 889	 889	 0.0	 0.0	 1	 -30.0	 30.0;
	4630	 1000	 0.00861	 0.015761	 0.0002	 1645	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	2121	 1001	 0.008062	 0.022172	 0.0	 1252	 1252	 1252	 0.0	 0.0	 1	 -30.0	 30.0;
	2898	 1001	 0.025951	 0.083144	 0.001	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	5309	 1003	 7.9e-05	 0.000316	 0.001	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1724	 1004	 0.030494	 0.083333	 0.0039	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	5345	 1004	 0.031358	 0.085556	 0.004	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	5471	 1005	 0.005185	 0.014198	 0.0006	 1966	 1966	 1966	 0.0	 0.0	 1	 -30.0	 30.0;
	3920	 1006	 0.001956	 0.008844	 0.0027	 3362	 3362	 3362	 0.0	 0.0	 1	 -30.0	 30.0;
	4443	 1006	 0.000133	 0.000311	 0.0	 90021	 90021	 90021	 0.0	 0.0	 1	 -30.0	 30.0;
	5675	 1008	 0.000198	 0.000672	 0.1509	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5674	 1007	 0.000198	 0.000691	 0.1529	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5233	 1009	 0.000988	 0.001975	 0.0002	 13732	 13732	 13732	 0.0	 0.0	 1	 -30.0	 30.0;
	2207	 1010	 0.037284	 0.094815	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	2856	 1010	 0.024074	 0.065309	 0.0031	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	2856	 1010	 0.025185	 0.064938	 0.0031	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	1248	 1011	 0.002822	 0.013404	 0.02	 2182	 2182	 2182	 0.0	 0.0	 1	 -30.0	 30.0;
	3451	 1011	 0.010834	 0.033006	 0.0146	 860	 860	 860	 0.0	 0.0	 1	 -30.0	 30.0;
	5229	 1011	 0.000171	 0.000313	 0.0001	 83805	 83805	 83805	 0.0	 0.0	 1	 -30.0	 30.0;
	5348	 1011	 0.004082	 0.012295	 0.0107	 2308	 2308	 2308	 0.0	 0.0	 1	 -30.0	 30.0;
	1248	 1011	 0.003956	 0.018569	 0.0074	 1574	 1574	 1574	 0.0	 0.0	 1	 -30.0	 30.0;
	1954	 1012	 0.009264	 0.031822	 0.0567	 289.0	 289.0	 289.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5229	 1013	 0.023331	 0.055304	 0.0038	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	4783	 1014	 0.024074	 0.063086	 0.0031	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 1015	 0.062661	 0.158806	 0.0018	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	4139	 1015	 0.058755	 0.186143	 0.0104	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	2270	 1016	 0.003779	 0.011338	 0.0002	 2545	 2545	 2545	 0.0	 0.0	 1	 -30.0	 30.0;
	4281	 1016	 0.020282	 0.08385	 0.001	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	968	 1017	 0.026203	 0.066264	 0.0008	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	2620	 1017	 0.001409	 0.002579	 0.0012	 10350	 10350	 10350	 0.0	 0.0	 1	 -30.0	 30.0;
	968	 1017	 0.026203	 0.066012	 0.0008	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	968	 1017	 0.027387	 0.067523	 0.0008	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	1353	 1019	 2e-05	 0.000198	 0.0051	 154266	 154266	 154266	 0.0	 0.0	 1	 -30.0	 30.0;
	1353	 1018	 4e-05	 0.000198	 0.0061	 151981	 151981	 151981	 0.0	 0.0	 1	 -30.0	 30.0;
	5382	 1020	 0.024444	 0.074074	 0.0089	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 1021	 0.01037	 0.022222	 0.0	 1065	 1065	 1065	 0.0	 0.0	 1	 -30.0	 30.0;
	3337	 1023	 0.00642	 0.022222	 0.0	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	3337	 1022	 0.014815	 0.03358	 0.0	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	4505	 1024	 0.027617	 0.074617	 0.0036	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	2152	 1025	 0.005432	 0.010988	 0.0318	 2424	 2424	 2424	 0.0	 0.0	 1	 -30.0	 30.0;
	2802	 1025	 0.018765	 0.079506	 0.004	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	1477	 1027	 0.000756	 0.003527	 0.0053	 8700	 8700	 8700	 0.0	 0.0	 1	 -30.0	 30.0;
	1477	 1026	 0.001008	 0.004283	 0.0066	 7132	 7132	 7132	 0.0	 0.0	 1	 -30.0	 30.0;
	4087	 1028	 0.00322	 0.021689	 0.0688	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 1029	 0.015117	 0.027715	 0.0018	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 1030	 0.01037	 0.027778	 0.0013	 1023	 1023	 1023	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 1031	 0.00963	 0.024815	 0.0016	 1140	 1140	 1140	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 1030	 0.009506	 0.025185	 0.0011	 1127	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	4890	 1032	 0.011482	 0.024321	 0.0109	 1105	 1105	 1105	 0.0	 0.0	 1	 -30.0	 30.0;
	2153	 1033	 0.014109	 0.046107	 0.0036	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	3045	 1033	 0.038801	 0.098262	 0.0038	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	4358	 1033	 0.024439	 0.06198	 0.0007	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	2153	 1033	 0.014109	 0.046107	 0.0036	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	3046	 1033	 0.039053	 0.098765	 0.004	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	4357	 1033	 0.024188	 0.060972	 0.0007	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	3774	 1033	 0.011086	 0.030738	 0.0012	 877	 877	 877	 0.0	 0.0	 1	 -30.0	 30.0;
	3774	 1033	 0.011086	 0.028219	 0.0014	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	1382	 1034	 0.003516	 0.016415	 0.0273	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3169	 1034	 0.004168	 0.028346	 0.0537	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3344	 1034	 0.001936	 0.00883	 0.0445	 3425	 3425	 3425	 0.0	 0.0	 1	 -30.0	 30.0;
	3909	 1034	 0.008099	 0.036603	 0.0901	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5003	 1034	 0.000948	 0.005886	 0.0289	 5192	 5192	 5192	 0.0	 0.0	 1	 -30.0	 30.0;
	5004	 1034	 0.000948	 0.005748	 0.0304	 5314	 5314	 5314	 0.0	 0.0	 1	 -30.0	 30.0;
	1382	 1034	 0.002311	 0.015763	 0.0435	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3775	 1034	 0.000336	 0.002331	 0.004	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3048	 1034	 0.000211	 0.001199	 0.0405	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3047	 1034	 0.000209	 0.001189	 0.0405	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1039	 1035	 2.1e-05	 0.000208	 0.0058	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1072	 1035	 0.00126	 0.014141	 0.2845	 1191.0	 1191.0	 1191.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3776	 1036	 7.9e-05	 0.000859	 0.0173	 1204.0	 1204.0	 1204.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4527	 1037	 0.001904	 0.021302	 0.4679	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	4944	 1036	 0.001517	 0.01687	 0.3494	 1659.0	 1659.0	 1659.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5235	 1037	 2.1e-05	 0.000187	 0.0029	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1039	 1037	 2.1e-05	 0.000208	 0.0058	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1072	 1035	 0.00126	 0.01412	 0.2859	 1191.0	 1191.0	 1191.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2961	 1036	 0.000983	 0.010949	 0.2397	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3147	 1036	 0.001711	 0.017348	 0.4476	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4527	 1036	 0.001281	 0.018476	 0.491	 1720	 1720	 1720	 0.0	 0.0	 1	 -30.0	 30.0;
	4527	 1036	 0.001274	 0.018324	 0.4837	 1735	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	1100	 1041	 0.002268	 0.004535	 0.0029	 5823	 5823	 5823	 0.0	 0.0	 1	 -30.0	 30.0;
	2271	 1041	 0.024691	 0.063492	 0.0033	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	3296	 1041	 0.131771	 0.345427	 0.0075	 80	 80	 80	 0.0	 0.0	 1	 -30.0	 30.0;
	4393	 1041	 0.056185	 0.182162	 0.0038	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	4406	 1041	 0.164777	 0.432855	 0.0096	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 1041	 0.026455	 0.070043	 0.004	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 1040	 0.011086	 0.028219	 0.0003	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	1097	 1041	 0.001738	 0.005442	 0.0058	 5169	 5169	 5169	 0.0	 0.0	 1	 -30.0	 30.0;
	5681	 1040	 0.010985	 0.028093	 0.0003	 979	 979	 979	 0.0	 0.0	 1	 -30.0	 30.0;
	1099	 1040	 0.002016	 0.004031	 0.0033	 6551	 6551	 6551	 0.0	 0.0	 1	 -30.0	 30.0;
	2660	 1040	 0.037793	 0.09801	 0.0017	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	1194	 1042	 0.002943	 0.02001	 0.0375	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2857	 1042	 0.005926	 0.04079	 0.077	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3748	 1042	 0.004571	 0.030552	 0.0557	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4876	 1042	 0.002121	 0.009661	 0.0162	 355.0	 355.0	 355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 1042	 0.002969	 0.013217	 0.0233	 400.0	 400.0	 400.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5438	 1042	 0.005551	 0.025146	 0.0445	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1224	 1043	 0.01037	 0.028395	 0.0013	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	1224	 1043	 0.010247	 0.028395	 0.0013	 1001	 1001	 1001	 0.0	 0.0	 1	 -30.0	 30.0;
	3127	 1044	 0.006954	 0.049307	 0.0161	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	4971	 1044	 0.00257	 0.015949	 0.0282	 1828	 1828	 1828	 0.0	 0.0	 1	 -30.0	 30.0;
	1939	 1045	 0.000409	 0.005409	 0.1877	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2460	 1045	 0.001371	 0.013871	 0.361	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5056	 1045	 0.002154	 0.021884	 0.566	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	1939	 1045	 0.000416	 0.005443	 0.1877	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2460	 1045	 0.001364	 0.01383	 0.3596	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5057	 1045	 0.002154	 0.021877	 0.566	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	1183	 1047	 0.000968	 0.002943	 0.3453	 10039	 10039	 10039	 0.0	 0.0	 1	 -30.0	 30.0;
	1265	 1047	 0.000217	 0.000849	 0.0931	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3161	 1047	 0.001205	 0.002746	 0.4668	 10374	 10374	 10374	 0.0	 0.0	 1	 -30.0	 30.0;
	3940	 1047	 0.000454	 0.002331	 0.0516	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 1047	 0.001284	 0.0096	 0.038	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5028	 1046	 0.001225	 0.006104	 0.0203	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1264	 1046	 0.000257	 0.000849	 0.1893	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3939	 1046	 0.000553	 0.002548	 0.0486	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 1047	 0.001284	 0.00956	 0.038	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 1047	 0.000909	 0.00879	 0.039	 833.0	 833.0	 833.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5503	 1047	 0.000533	 0.005096	 0.0248	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5236	 1048	 0.001764	 0.003527	 0.0005	 7488	 7488	 7488	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 1049	 0.000277	 0.002618	 0.0693	 921.0	 921.0	 921.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2404	 1050	 0.058453	 0.13026	 0.001	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	4416	 1050	 0.069035	 0.16906	 0.0026	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	3194	 1051	 0.016629	 0.04258	 0.0005	 680	 680	 680	 0.0	 0.0	 1	 -30.0	 30.0;
	4387	 1057	 0.011235	 0.025679	 0.0113	 1127	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	2207	 1058	 0.045926	 0.11679	 0.0055	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	2805	 1058	 0.037284	 0.100617	 0.0049	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	5180	 1058	 0.032778	 0.088963	 0.0074	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	5371	 1058	 0.029518	 0.074827	 0.0034	 370	 370	 370	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 1059	 0.007802	 0.052444	 0.1018	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2803	 1059	 0.003101	 0.020563	 0.0385	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3748	 1059	 0.003761	 0.025235	 0.0456	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5046	 1059	 0.008889	 0.032197	 0.0537	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 1059	 0.01442	 0.071763	 0.1291	 372.0	 372.0	 372.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4987	 1060	 0.08516	 0.17682	 0.0019	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	2583	 1061	 0.000381	 0.007008	 0.2079	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2583	 1062	 0.000374	 0.006434	 0.2209	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1997	 1063	 0.014361	 0.041824	 0.0006	 688	 688	 688	 0.0	 0.0	 1	 -30.0	 30.0;
	2260	 1063	 0.106576	 0.275384	 0.0031	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	4924	 1063	 0.022676	 0.070043	 0.0013	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	5357	 1063	 0.021164	 0.057949	 0.0001	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	2824	 1064	 0.001679	 0.017284	 0.0582	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2824	 1064	 0.001501	 0.018568	 0.0562	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5024	 1065	 0.066012	 0.134543	 0.0014	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5239	 1065	 0.06576	 0.166793	 0.0019	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	2029	 1066	 0.079113	 0.21542	 0.0024	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	2658	 1066	 0.072058	 0.150668	 0.0017	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	5544	 1066	 7.6e-05	 0.000151	 0.0	 179912	 179912	 179912	 0.0	 0.0	 1	 -30.0	 30.0;
	2399	 1067	 0.020408	 0.055682	 0.0006	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	2996	 1068	 0.03477	 0.078861	 0.0016	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	5707	 1069	 0.058201	 0.120534	 0.0013	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	2213	 1070	 0.168733	 0.377072	 0.004	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	3943	 1070	 0.06329	 0.171429	 0.0019	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	2564	 1071	 0.00079	 0.005345	 0.0354	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2694	 1071	 0.00255	 0.017084	 0.0309	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2564	 1071	 0.000745	 0.005047	 0.0349	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1925	 1072	 0.000741	 0.009716	 0.335	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 1072	 0.000422	 0.004709	 0.0953	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1925	 1072	 0.000741	 0.009709	 0.335	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 1072	 0.000422	 0.004758	 0.0953	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 1072	 0.000644	 0.005035	 0.1112	 1397.0	 1397.0	 1397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2243	 1073	 0.024188	 0.063744	 0.0737	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 1073	 0.107533	 0.274654	 0.0194	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	2829	 1073	 0.017637	 0.051146	 0.0578	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	5592	 1073	 0.047109	 0.086232	 0.0012	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5593	 1073	 0.026203	 0.066516	 0.0007	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	5823	 1073	 0.132023	 0.291509	 0.0	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 1074	 0.004514	 0.029863	 0.1096	 439.0	 439.0	 439.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4767	 1076	 1.4e-05	 0.000208	 0.0058	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4767	 1075	 2.1e-05	 0.000242	 0.0087	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5303	 1077	 7.4e-05	 0.001235	 0.0	 24008	 24008	 24008	 0.0	 0.0	 1	 -30.0	 30.0;
	1946	 1079	 0.035853	 0.12517	 0.0031	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	2337	 1079	 0.076594	 0.195011	 0.003	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 1080	 0.012094	 0.066264	 0.0021	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	4673	 1080	 0.041824	 0.106576	 0.004	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	5543	 1080	 0.037793	 0.122197	 0.0021	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5710	 1080	 0.068531	 0.232804	 0.0027	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	1781	 1081	 0.002402	 0.015149	 0.0582	 472.0	 472.0	 472.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2292	 1081	 0.000889	 0.005333	 0.0101	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1663	 1082	 0.004787	 0.013354	 0.0002	 2144	 2144	 2144	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 1083	 0.066541	 0.175309	 0.002	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 1083	 0.066692	 0.174628	 0.002	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	1933	 1084	 0.002268	 0.004787	 0.0	 5574	 5574	 5574	 0.0	 0.0	 1	 -30.0	 30.0;
	5671	 1084	 0.002016	 0.004031	 0.0	 6551	 6551	 6551	 0.0	 0.0	 1	 -30.0	 30.0;
	1932	 1084	 0.000252	 0.000756	 0.0	 37051	 37051	 37051	 0.0	 0.0	 1	 -30.0	 30.0;
	2735	 1085	 0.096498	 0.261779	 0.0071	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	2504	 1086	 0.057949	 0.147644	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 1086	 0.040564	 0.103301	 0.0012	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	1201	 1087	 0.009383	 0.039506	 0.007	 747	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	4280	 1087	 0.003615	 0.006617	 0.019	 4022	 4022	 4022	 0.0	 0.0	 1	 -30.0	 30.0;
	2137	 1088	 0.000751	 0.004978	 0.0091	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2718	 1088	 0.001738	 0.011694	 0.0213	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2137	 1088	 0.000652	 0.004346	 0.0081	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 1089	 0.000252	 0.00252	 0.0016	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	1466	 1090	 0.000252	 0.00252	 0.0017	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	1482	 1092	 0.000593	 0.002667	 0.0051	 374.0	 374.0	 374.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1482	 1091	 0.000591	 0.00268	 0.0046	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4250	 1093	 0.001764	 0.004787	 0.0001	 5788	 5788	 5788	 0.0	 0.0	 1	 -30.0	 30.0;
	1761	 1094	 0.106296	 0.194573	 0.002	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	2668	 1094	 0.05543	 0.187957	 0.0022	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 1095	 0.006047	 0.013605	 0.0152	 2028	 2028	 2028	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 1095	 0.010834	 0.030234	 0.0051	 940	 940	 940	 0.0	 0.0	 1	 -30.0	 30.0;
	3515	 1096	 0.002469	 0.015319	 0.0271	 1903	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	3515	 1096	 0.002771	 0.009322	 0.0121	 3036	 3036	 3036	 0.0	 0.0	 1	 -30.0	 30.0;
	4546	 1098	 0.007055	 0.014109	 0.0103	 1872	 1872	 1872	 0.0	 0.0	 1	 -30.0	 30.0;
	5241	 1101	 2.5e-05	 0.000252	 0.0003	 113138	 113138	 113138	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 1102	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5568	 1102	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	2416	 1103	 0.059965	 0.158982	 0.0019	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	2587	 1103	 0.007811	 0.051146	 0.0006	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	2416	 1103	 0.059965	 0.158982	 0.0019	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3574	 1104	 0.000972	 0.012113	 0.1636	 1786.0	 1786.0	 1786.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2739	 1105	 0.007811	 0.014361	 0.0107	 1807	 1807	 1807	 0.0	 0.0	 1	 -30.0	 30.0;
	2315	 1106	 0.032099	 0.089506	 0.0044	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	3186	 1106	 0.002469	 0.007284	 0.0154	 3862	 3862	 3862	 0.0	 0.0	 1	 -30.0	 30.0;
	5244	 1107	 0.000493	 0.000902	 0.0001	 29034	 29034	 29034	 0.0	 0.0	 1	 -30.0	 30.0;
	2443	 1109	 0.030617	 0.077778	 0.0037	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	4498	 1109	 0.048765	 0.13716	 0.0068	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	5073	 1109	 0.033827	 0.092222	 0.0044	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	3286	 1110	 0.024943	 0.071806	 0.001	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	3570	 1111	 0.009322	 0.038801	 0.0005	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 1111	 0.097002	 0.245654	 0.0028	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	5217	 1111	 0.006551	 0.019148	 0.0002	 1503	 1503	 1503	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 1111	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 1111	 0.135047	 0.342404	 0.0039	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	3570	 1111	 0.010078	 0.041572	 0.0006	 711	 711	 711	 0.0	 0.0	 1	 -30.0	 30.0;
	3592	 1111	 0.01877	 0.076266	 0.0016	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	3592	 1111	 0.018796	 0.076392	 0.0018	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	1536	 1112	 0.003477	 0.023249	 0.0425	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2119	 1112	 0.006341	 0.042232	 0.078	 415.0	 415.0	 415.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1951	 1113	 0.012824	 0.032552	 0.0004	 870	 870	 870	 0.0	 0.0	 1	 -30.0	 30.0;
	2559	 1114	 0.013681	 0.036029	 0.001	 790	 790	 790	 0.0	 0.0	 1	 -30.0	 30.0;
	1766	 1116	 0.016125	 0.041572	 0.0	 683	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	2495	 1115	 0.009826	 0.034517	 0.0479	 848	 848	 848	 0.0	 0.0	 1	 -30.0	 30.0;
	4432	 1115	 0.003779	 0.010078	 0.0001	 2826	 2826	 2826	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 1116	 0.025699	 0.066012	 0.0	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	2495	 1115	 0.009826	 0.034517	 0.0479	 848	 848	 848	 0.0	 0.0	 1	 -30.0	 30.0;
	3540	 1117	 0.000171	 0.000313	 0.0003	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 1117	 0.001764	 0.010582	 0.0002	 2753	 2753	 2753	 0.0	 0.0	 1	 -30.0	 30.0;
	1496	 1118	 0.014074	 0.038889	 0.0018	 719	 719	 719	 0.0	 0.0	 1	 -30.0	 30.0;
	1913	 1118	 0.026667	 0.072963	 0.0034	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	2076	 1118	 0.022099	 0.067778	 0.0033	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	1540	 1120	 0.004198	 0.011482	 0.0005	 2430	 2430	 2430	 0.0	 0.0	 1	 -30.0	 30.0;
	4954	 1120	 0.038518	 0.103951	 0.005	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	4954	 1120	 0.038518	 0.103827	 0.0053	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	2559	 1121	 0.015873	 0.04258	 0.0039	 670	 670	 670	 0.0	 0.0	 1	 -30.0	 30.0;
	2559	 1122	 0.003754	 0.010557	 0.0129	 2715	 2715	 2715	 0.0	 0.0	 1	 -30.0	 30.0;
	5247	 1123	 4.5e-05	 8.9e-05	 0.0007	 320583	 320583	 320583	 0.0	 0.0	 1	 -30.0	 30.0;
	1302	 1124	 0.023683	 0.0645	 0.001	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	2314	 1125	 0.014109	 0.060217	 0.0	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	4524	 1125	 0.002771	 0.007559	 0.0	 3778	 3778	 3778	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 1126	 0.027778	 0.070494	 0.0032	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	3385	 1126	 0.008272	 0.016543	 0.0007	 1606	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 1128	 0.043803	 0.118383	 0.0061	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 1129	 0.001008	 0.002771	 0.0001	 10315	 10315	 10315	 0.0	 0.0	 1	 -30.0	 30.0;
	1224	 1130	 0.03642	 0.105309	 0.0052	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	2708	 1130	 0.009136	 0.024568	 0.0011	 1134	 1134	 1134	 0.0	 0.0	 1	 -30.0	 30.0;
	5494	 1130	 0.009259	 0.024568	 0.0011	 1132	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	1225	 1131	 0.002601	 0.017284	 0.0324	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5091	 1131	 0.008257	 0.036427	 0.0582	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2450	 1132	 0.033704	 0.10358	 0.0053	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	5640	 1132	 0.022222	 0.058395	 0.0028	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	3066	 1133	 0.047619	 0.141345	 0.002	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	3740	 1133	 0.002016	 0.008566	 0.0013	 3356	 3356	 3356	 0.0	 0.0	 1	 -30.0	 30.0;
	5248	 1133	 0.00126	 0.003527	 0.0	 7884	 7884	 7884	 0.0	 0.0	 1	 -30.0	 30.0;
	3093	 1133	 0.013102	 0.05543	 0.001	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	2258	 1134	 0.001857	 0.014461	 0.0481	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4896	 1134	 0.003202	 0.030829	 0.1164	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 1135	 0.084656	 0.189216	 0.0023	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	3238	 1135	 0.098765	 0.269085	 0.003	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 1135	 0.080373	 0.203326	 0.0023	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	2795	 1137	 0.05543	 0.141597	 0.0018	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	2977	 1136	 0.104308	 0.216175	 0.0023	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	5101	 1137	 0.006047	 0.016377	 0.0002	 1642	 1642	 1642	 0.0	 0.0	 1	 -30.0	 30.0;
	5241	 1136	 0.006475	 0.028395	 0.0436	 984	 984	 984	 0.0	 0.0	 1	 -30.0	 30.0;
	5476	 1137	 0.04384	 0.142101	 0.0017	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	2458	 1138	 0.006005	 0.02878	 0.0496	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2978	 1138	 0.003595	 0.0176	 0.0294	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4992	 1139	 0.002133	 0.014756	 0.0294	 2077	 2077	 2077	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 1140	 0.016377	 0.044596	 0.0005	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	2376	 1141	 0.059965	 0.168556	 0.002	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 1141	 0.018141	 0.05039	 0.0006	 552	 552	 552	 0.0	 0.0	 1	 -30.0	 30.0;
	5215	 1141	 0.051398	 0.2129	 0.0027	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	5436	 1141	 0.094734	 0.259007	 0.0027	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	5439	 1141	 0.0451	 0.186193	 0.0023	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 1141	 0.023432	 0.066264	 0.0007	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	3658	 1142	 0.00642	 0.043852	 0.083	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4174	 1142	 0.003002	 0.020227	 0.0385	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3704	 1143	 8.9e-05	 0.000751	 0.079	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5252	 1144	 0.039557	 0.107886	 0.0012	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	1237	 1146	 0.003477	 0.018074	 0.0304	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 1146	 0.003141	 0.015526	 0.0268	 253.0	 253.0	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3329	 1146	 0.000237	 0.001541	 0.0091	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2579	 1147	 0.068272	 0.212346	 0.0104	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	4340	 1147	 0.051975	 0.158025	 0.0076	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	1809	 1148	 0.074049	 0.166364	 0.0018	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	3552	 1148	 0.074931	 0.204031	 0.0023	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	3610	 1149	 0.020494	 0.046049	 0.0021	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	3801	 1150	 0.004837	 0.017334	 0.0007	 1691	 1691	 1691	 0.0	 0.0	 1	 -30.0	 30.0;
	2131	 1151	 0.022676	 0.075082	 0.0009	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	3014	 1152	 0.006803	 0.018896	 0.0002	 1471	 1471	 1471	 0.0	 0.0	 1	 -30.0	 30.0;
	3458	 1152	 0.003779	 0.009826	 0.0	 2805	 2805	 2805	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 1152	 0.04006	 0.134039	 0.0021	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 1151	 0.006047	 0.028723	 0.0	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	5620	 1151	 0.006047	 0.016125	 0.0	 1715	 1715	 1715	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 1151	 0.022928	 0.065508	 0.001	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	2132	 1153	 0.001086	 0.00642	 0.0121	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2697	 1153	 0.004464	 0.021452	 0.0385	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3355	 1154	 0.023683	 0.043588	 0.0004	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 1154	 0.004283	 0.021164	 0.0156	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	5760	 1154	 0.071554	 0.184177	 0.002	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 1155	 0.00679	 0.018025	 0.0008	 1543	 1543	 1543	 0.0	 0.0	 1	 -30.0	 30.0;
	2447	 1156	 0.000158	 0.000474	 0.0506	 278.0	 278.0	 278.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2999	 1156	 0.000198	 0.00077	 0.0972	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5254	 1157	 1.6e-05	 9.9e-05	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5253	 1158	 1.6e-05	 9.9e-05	 0.001	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4785	 1159	 0.001358	 0.008148	 0.0005	 3672	 3672	 3672	 0.0	 0.0	 1	 -30.0	 30.0;
	4784	 1160	 0.001481	 0.009012	 0.0005	 3321	 3321	 3321	 0.0	 0.0	 1	 -30.0	 30.0;
	4785	 1161	 0.001481	 0.009259	 0.0005	 3234	 3234	 3234	 0.0	 0.0	 1	 -30.0	 30.0;
	1560	 1162	 0.004899	 0.033007	 0.0699	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3897	 1162	 0.005531	 0.037215	 0.0678	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4655	 1162	 0.004365	 0.029491	 0.0537	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3897	 1162	 0.005452	 0.036365	 0.0668	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4558	 1163	 0.008314	 0.034266	 0.0004	 813	 813	 813	 0.0	 0.0	 1	 -30.0	 30.0;
	5107	 1165	 0.04	 0.088889	 0.0	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	2571	 1166	 0.03477	 0.088183	 0.003	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 1167	 0.054271	 0.137566	 0.0016	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5585	 1167	 0.111481	 0.204065	 0.0019	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	1482	 1168	 0.003002	 0.014163	 0.0253	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 1168	 0.001778	 0.009837	 0.0248	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2821	 1169	 0.031975	 0.089753	 0.0042	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	3083	 1169	 0.026296	 0.066667	 0.0031	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 1169	 0.031975	 0.082963	 0.0037	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	4191	 1169	 0.00437	 0.011975	 0.0097	 2331	 2331	 2331	 0.0	 0.0	 1	 -30.0	 30.0;
	4215	 1169	 0.002963	 0.018642	 0.0015	 1574	 1574	 1574	 0.0	 0.0	 1	 -30.0	 30.0;
	4677	 1169	 0.009136	 0.024938	 0.0011	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	5612	 1169	 0.009012	 0.022222	 0.001	 1239	 1239	 1239	 0.0	 0.0	 1	 -30.0	 30.0;
	3083	 1169	 0.026049	 0.071111	 0.0034	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	4214	 1169	 0.006667	 0.01679	 0.0008	 1645	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	5695	 1169	 0.007802	 0.01979	 0.001	 1397	 1397	 1397	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 1170	 0.005491	 0.037076	 0.0658	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4216	 1170	 0.000454	 0.0032	 0.0051	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 1170	 0.00083	 0.005669	 0.0111	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 1170	 0.005412	 0.036543	 0.0658	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 1170	 0.005432	 0.036543	 0.0658	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 1175	 0.109785	 0.20096	 0.0	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	3600	 1176	 0.00877	 0.026489	 0.0435	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	4044	 1176	 0.000968	 0.003516	 0.0061	 8488	 8488	 8488	 0.0	 0.0	 1	 -30.0	 30.0;
	5689	 1176	 0.008099	 0.028247	 0.0466	 1054	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 1176	 0.001521	 0.00721	 0.0121	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5012	 1177	 0.06358	 0.165802	 0.0079	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	1187	 1178	 0.000335	 0.000613	 0.001	 43410	 43410	 43410	 0.0	 0.0	 1	 -30.0	 30.0;
	2643	 1180	 0.011852	 0.030988	 0.0015	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	5834	 1179	 0.019383	 0.052469	 0.0024	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	3220	 1181	 0.034266	 0.089947	 0.001	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	1701	 1182	 0.000138	 0.000573	 0.0699	 259.0	 259.0	 259.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3906	 1184	 0.006296	 0.016914	 0.0008	 1646	 1646	 1646	 0.0	 0.0	 1	 -30.0	 30.0;
	5394	 1184	 0.03321	 0.087778	 0.0042	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	3156	 1185	 0.000198	 0.000731	 0.647	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3383	 1185	 0.000652	 0.002351	 0.5123	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5414	 1185	 0.000593	 0.005649	 0.0223	 656.0	 656.0	 656.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3156	 1185	 0.000182	 0.000622	 0.5559	 468.0	 468.0	 468.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3383	 1185	 0.000652	 0.00237	 0.5133	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5412	 1185	 0.000612	 0.005669	 0.0278	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3156	 1185	 0.000237	 0.002114	 0.1954	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 1185	 0.000217	 0.002054	 0.0197	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5356	 1185	 0.000217	 0.002035	 0.0147	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1957	 1186	 0.065508	 0.1678	 0.0024	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	4612	 1186	 0.036332	 0.092089	 0.001	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 1187	 0.008148	 0.034197	 0.0016	 863	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 1187	 0.005679	 0.021975	 0.0137	 1337	 1337	 1337	 0.0	 0.0	 1	 -30.0	 30.0;
	4150	 1187	 0.000753	 0.001379	 0.0026	 19301	 19301	 19301	 0.0	 0.0	 1	 -30.0	 30.0;
	4073	 1189	 2.5e-05	 0.151172	 0.0	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	4310	 1190	 0.060972	 0.168052	 0.0021	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	5740	 1189	 0.03676	 0.081381	 0.0027	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	4073	 1188	 2.5e-05	 0.000252	 0.0	 116592	 116592	 116592	 0.0	 0.0	 1	 -30.0	 30.0;
	3516	 1192	 0.00287	 0.017709	 0.0334	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5277	 1191	 0.002015	 0.012879	 0.0243	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1954	 1192	 0.00482	 0.03119	 0.0577	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1956	 1193	 0.000529	 0.008085	 0.2498	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3128	 1193	 0.001142	 0.014569	 0.3855	 1746.0	 1746.0	 1746.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2098	 1194	 0.002884	 0.019358	 0.0714	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3539	 1194	 0.004978	 0.024514	 0.0435	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3658	 1194	 0.015328	 0.102262	 0.1903	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	4335	 1194	 0.005531	 0.02797	 0.0567	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5628	 1194	 0.001067	 0.007289	 0.0486	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1171	 1194	 5.9e-05	 0.000889	 0.003	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3539	 1194	 0.002805	 0.019002	 0.0365	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5438	 1194	 0.001027	 0.006775	 0.0121	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1172	 1194	 7.9e-05	 0.00083	 0.002	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1173	 1194	 5.9e-05	 0.000652	 0.001	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1515	 1195	 0.003102	 0.031524	 0.8202	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	2600	 1195	 0.001168	 0.011767	 0.3018	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1515	 1195	 0.00313	 0.031724	 0.8202	 996	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	2599	 1195	 0.001163	 0.011728	 0.3018	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2778	 1195	 0.004905	 0.049964	 1.301	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	1174	 1195	 2.1e-05	 0.000249	 0.0058	 921.0	 921.0	 921.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3381	 1196	 0.082389	 0.220711	 0.0026	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	3995	 1196	 0.083648	 0.172084	 0.0019	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5573	 1196	 0.051398	 0.110355	 0.0015	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	4651	 1197	 0.01479	 0.048677	 0.0187	 564	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	5430	 1197	 0.002595	 0.011665	 0.0285	 2398	 2398	 2398	 0.0	 0.0	 1	 -30.0	 30.0;
	5429	 1197	 0.002595	 0.011665	 0.0285	 2398	 2398	 2398	 0.0	 0.0	 1	 -30.0	 30.0;
	1202	 1198	 0.001027	 0.004721	 0.0081	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2959	 1198	 0.001027	 0.004899	 0.0091	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4169	 1200	 0.000741	 0.002346	 0.0002	 12326	 12326	 12326	 0.0	 0.0	 1	 -30.0	 30.0;
	4973	 1200	 0.042963	 0.117531	 0.0	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 1199	 0.01963	 0.051481	 0.0024	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 1199	 0.020247	 0.055556	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	2717	 1201	 0.011482	 0.051111	 0.0026	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	3949	 1201	 0.014938	 0.037654	 0.013	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	3950	 1201	 0.015185	 0.037531	 0.0133	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	4412	 1201	 0.000123	 0.001235	 0.0016	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	4413	 1201	 0.000123	 0.001235	 0.0016	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	2932	 1202	 0.002548	 0.012346	 0.0203	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3878	 1203	 0.021416	 0.054422	 0.0006	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	4997	 1203	 0.053414	 0.136306	 0.0015	 208	 208	 208	 0.0	 0.0	 1	 -30.0	 30.0;
	1981	 1203	 0.016755	 0.04263	 0.0005	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	3384	 1203	 0.0194	 0.049887	 0.0006	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	1243	 1204	 0.004721	 0.031348	 0.0587	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4897	 1204	 0.003556	 0.023585	 0.0435	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5260	 1205	 0.000123	 0.001235	 0.0002	 27851	 27851	 27851	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 1206	 0.03225	 0.148904	 0.0018	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	3862	 1206	 0.008314	 0.034014	 0.0245	 844	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	4128	 1206	 0.084404	 0.252457	 0.0098	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 1206	 0.032754	 0.15092	 0.0014	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	5717	 1206	 0.014361	 0.038801	 0.0004	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	1633	 1207	 0.00156	 0.01039	 0.0192	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1912	 1207	 0.001084	 0.005086	 0.0111	 361.0	 361.0	 361.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3172	 1207	 0.002153	 0.012978	 0.0243	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1912	 1207	 0.0011	 0.004978	 0.0142	 353.0	 353.0	 353.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3172	 1207	 0.002173	 0.013017	 0.0243	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4601	 1208	 0.002469	 0.009877	 0.0008	 2918	 2918	 2918	 0.0	 0.0	 1	 -30.0	 30.0;
	5019	 1209	 0.00963	 0.025309	 0.0013	 1097	 1097	 1097	 0.0	 0.0	 1	 -30.0	 30.0;
	5708	 1209	 0.037037	 0.094938	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	5262	 1210	 0.000158	 0.000691	 0.001	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3031	 1211	 0.002544	 0.02015	 0.0348	 561.0	 561.0	 561.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 1211	 0.003727	 0.028836	 0.0527	 562.0	 562.0	 562.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3701	 1212	 0.012522	 0.044041	 0.0263	 665	 665	 665	 0.0	 0.0	 1	 -30.0	 30.0;
	4350	 1212	 0.044848	 0.110103	 0.0013	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	2653	 1213	 0.032704	 0.079542	 0.0022	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	2881	 1213	 0.011338	 0.026455	 0.0009	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	1295	 1214	 3.5e-05	 0.000512	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3598	 1214	 0.001887	 0.019088	 0.4938	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4569	 1214	 0.001579	 0.01509	 0.4087	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4706	 1214	 0.000949	 0.009342	 0.2426	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1292	 1214	 3.5e-05	 0.000506	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3598	 1214	 0.001874	 0.018954	 0.491	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4706	 1214	 0.00097	 0.009536	 0.2484	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1294	 1214	 3.5e-05	 0.000547	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4706	 1214	 0.00097	 0.009536	 0.2484	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1293	 1214	 3.5e-05	 0.000547	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1984	 1216	 0.021679	 0.058309	 0.0041	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	1805	 1217	 0.007307	 0.029479	 0.005	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	2744	 1217	 0.000756	 0.00252	 0.0037	 10890	 10890	 10890	 0.0	 0.0	 1	 -30.0	 30.0;
	1346	 1218	 0.081436	 0.149069	 0.001	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3850	 1218	 0.069287	 0.175611	 0.002	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	3421	 1219	 0.047161	 0.123827	 0.0058	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 1220	 0.044198	 0.12058	 0.0057	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	5259	 1221	 0.049876	 0.126444	 0.006	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	5265	 1222	 0.000869	 0.006025	 0.0101	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 1223	 0.035021	 0.091963	 0.0021	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5403	 1224	 0.047901	 0.095926	 0.004	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	1380	 1226	 0.006047	 0.018896	 0.0067	 1489	 1489	 1489	 0.0	 0.0	 1	 -30.0	 30.0;
	3046	 1227	 0.070295	 0.178634	 0.002	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	4431	 1227	 0.061804	 0.156765	 0.0017	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	3489	 1228	 0.001134	 0.002671	 0.0006	 10482	 10482	 10482	 0.0	 0.0	 1	 -30.0	 30.0;
	4430	 1228	 0.065079	 0.165004	 0.0019	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	1338	 1229	 0.00897	 0.050315	 0.0103	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	1647	 1229	 0.028975	 0.081885	 0.0127	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	2422	 1229	 0.048501	 0.135047	 0.0031	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	2487	 1229	 0.02192	 0.071051	 0.0011	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	4340	 1230	 0.034568	 0.087407	 0.004	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	4445	 1230	 0.038642	 0.105309	 0.0049	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	1772	 1232	 0.009506	 0.039259	 0.0021	 743	 743	 743	 0.0	 0.0	 1	 -30.0	 30.0;
	3038	 1232	 0.050124	 0.136543	 0.0073	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	1772	 1232	 0.009506	 0.039259	 0.0021	 743	 743	 743	 0.0	 0.0	 1	 -30.0	 30.0;
	3597	 1234	 0.001764	 0.012346	 0.0011	 2368	 2368	 2368	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 1234	 0.006803	 0.028975	 0.0	 993	 993	 993	 0.0	 0.0	 1	 -30.0	 30.0;
	5232	 1233	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	5738	 1233	 0.008314	 0.018141	 0.0	 1480	 1480	 1480	 0.0	 0.0	 1	 -30.0	 30.0;
	5641	 1233	 0.004686	 0.019829	 0.0002	 1450	 1450	 1450	 0.0	 0.0	 1	 -30.0	 30.0;
	3597	 1234	 0.007307	 0.028975	 0.0018	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	1677	 1237	 0.001027	 0.006677	 0.0121	 488.0	 488.0	 488.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2080	 1236	 0.009521	 0.064237	 0.1215	 375.0	 375.0	 375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 1237	 0.002133	 0.023348	 0.0648	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3329	 1235	 0.002232	 0.007802	 0.0142	 287.0	 287.0	 287.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3958	 1236	 0.000593	 0.002588	 0.0162	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4075	 1236	 2e-05	 0.015803	 0.0	 287.0	 287.0	 287.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4129	 1237	 0.001778	 0.016356	 0.0405	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4520	 1237	 0.011694	 0.078657	 0.1519	 375.0	 375.0	 375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5689	 1237	 0.000237	 0.00156	 0.0142	 19617	 19617	 19617	 0.0	 0.0	 1	 -30.0	 30.0;
	1677	 1236	 0.001027	 0.006657	 0.0121	 464.0	 464.0	 464.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 1236	 0.00476	 0.022499	 0.0375	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4075	 1235	 2e-05	 0.000198	 0.0	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	4821	 1238	 0.000462	 0.006438	 0.1689	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4821	 1238	 0.000462	 0.006434	 0.1689	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5542	 1239	 0.106551	 0.225649	 0.0024	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 1240	 0.003234	 0.01923	 0.0365	 410.0	 410.0	 410.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1954	 1240	 0.019951	 0.071546	 0.1144	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	3305	 1240	 0.016	 0.053472	 0.0861	 555	 555	 555	 0.0	 0.0	 1	 -30.0	 30.0;
	1610	 1241	 0.017637	 0.056185	 0.001	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	1850	 1241	 0.002851	 0.005218	 0.0036	 4966	 4966	 4966	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 1241	 0.018141	 0.057193	 0.001	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	1849	 1241	 0.00126	 0.004535	 0.0046	 6273	 6273	 6273	 0.0	 0.0	 1	 -30.0	 30.0;
	2866	 1242	 0.212444	 0.388876	 0.0042	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	3815	 1242	 0.012598	 0.031998	 0.0004	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	5169	 1242	 0.022928	 0.060721	 0.0007	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	3566	 1243	 0.005472	 0.037728	 0.0709	 411.0	 411.0	 411.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4566	 1243	 0.000968	 0.00638	 0.0111	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5487	 1243	 0.005669	 0.025639	 0.0456	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4281	 1244	 0.147644	 0.301587	 0.0057	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	4320	 1244	 0.125548	 0.318292	 0.0036	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	4281	 1244	 0.179214	 0.32805	 0.0054	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	2257	 1245	 0.082196	 0.171444	 0.0486	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	4560	 1248	 0.001008	 0.002771	 0.0021	 10119	 10119	 10119	 0.0	 0.0	 1	 -30.0	 30.0;
	4618	 1248	 0.001367	 0.002502	 0.0021	 10465	 10465	 10465	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 1249	 0.032963	 0.083704	 0.0039	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	5621	 1249	 0.037901	 0.103457	 0.0049	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	5269	 1250	 0.017133	 0.071806	 0.0071	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	1651	 1253	 0.007037	 0.019012	 0.0002	 1583	 1583	 1583	 0.0	 0.0	 1	 -30.0	 30.0;
	2088	 1254	 0.002825	 0.018765	 0.0349	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2517	 1254	 0.000474	 0.003101	 0.0061	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 1254	 0.00173	 0.01154	 0.0213	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 1254	 0.001719	 0.011496	 0.0289	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4198	 1255	 0.074074	 0.187957	 0.0021	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	5485	 1255	 0.008163	 0.021769	 0.0002	 1309	 1309	 1309	 0.0	 0.0	 1	 -30.0	 30.0;
	2332	 1256	 0.064752	 0.177375	 0.002	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	5271	 1257	 0.000436	 0.000797	 0.0	 32501	 32501	 32501	 0.0	 0.0	 1	 -30.0	 30.0;
	2250	 1259	 0.060897	 0.161552	 0.0022	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	4708	 1259	 0.020433	 0.06062	 0.0007	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	4727	 1258	 0.017611	 0.061779	 0.0101	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	5539	 1258	 0.075787	 0.176316	 0.0041	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5767	 1259	 0.076871	 0.206828	 0.0028	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	4708	 1258	 0.009574	 0.038549	 0.0017	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	4727	 1259	 0.019148	 0.071051	 0.0075	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	1838	 1260	 0.013472	 0.067378	 0.1215	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3890	 1260	 0.004563	 0.02448	 0.0425	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5124	 1260	 0.010627	 0.045511	 0.0749	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5502	 1260	 0.009798	 0.045748	 0.0815	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5650	 1260	 0.011674	 0.053096	 0.0921	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3146	 1261	 0.000812	 0.006278	 0.1271	 1397.0	 1397.0	 1397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3803	 1261	 0.001797	 0.019272	 0.4216	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	4898	 1261	 0.003831	 0.029281	 0.592	 1080	 1080	 1080	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 1262	 0.042076	 0.209121	 0.0025	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	1507	 1263	 0.145125	 0.32124	 0.0037	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	2653	 1263	 0.07609	 0.189468	 0.0021	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	2002	 1265	 0.000198	 0.0016	 0.162	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3944	 1265	 0.000454	 0.001106	 0.1002	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4640	 1264	 0.000316	 0.000948	 0.1094	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 1266	 0.00642	 0.026914	 0.0013	 1096	 1096	 1096	 0.0	 0.0	 1	 -30.0	 30.0;
	2256	 1267	 0.037793	 0.118922	 0.0013	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 1268	 0.067926	 0.165331	 0.0019	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5211	 1268	 0.012598	 0.031242	 0.0003	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	5273	 1269	 0.008566	 0.019652	 0.0017	 1337	 1337	 1337	 0.0	 0.0	 1	 -30.0	 30.0;
	1956	 1270	 0.00077	 0.011178	 0.312	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 1270	 0.00088	 0.012722	 0.3292	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 1270	 0.000312	 0.004467	 0.1155	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1956	 1271	 0.000771	 0.011192	 0.291	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 1271	 0.00088	 0.012715	 0.3292	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4459	 1271	 0.000312	 0.004467	 0.1155	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 1272	 0.028975	 0.073318	 0.0008	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	3194	 1272	 0.036785	 0.093222	 0.001	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	1769	 1274	 2e-05	 0.000198	 0.003	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	4578	 1273	 0.000178	 0.000632	 0.078	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5274	 1275	 0.007559	 0.020912	 0.0002	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	3623	 1276	 0.026914	 0.085062	 0.0049	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	3971	 1276	 0.021235	 0.067654	 0.004	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	4785	 1279	 0.000675	 0.001235	 0.0036	 21546	 21546	 21546	 0.0	 0.0	 1	 -30.0	 30.0;
	2265	 1280	 0.005556	 0.029136	 0.0005	 1079	 1079	 1079	 0.0	 0.0	 1	 -30.0	 30.0;
	2705	 1280	 0.012099	 0.059753	 0.0013	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	2266	 1281	 0.00077	 0.005195	 0.0091	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3631	 1281	 0.000553	 0.003694	 0.0157	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3913	 1281	 0.000514	 0.001007	 0.1499	 27378	 27378	 27378	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 1281	 0.001679	 0.008296	 0.0152	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 1281	 0.002548	 0.016968	 0.0314	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2266	 1281	 0.000731	 0.004938	 0.0091	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3631	 1281	 0.000533	 0.003635	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 1281	 0.000494	 0.001007	 0.1488	 27596	 27596	 27596	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 1282	 0.000514	 0.001185	 0.0719	 23964	 23964	 23964	 0.0	 0.0	 1	 -30.0	 30.0;
	2042	 1283	 0.016327	 0.049786	 0.0024	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	3755	 1283	 0.009574	 0.033006	 0.0017	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	1627	 1284	 0.038889	 0.098889	 0.0047	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	5170	 1284	 0.002049	 0.005617	 0.0124	 4968	 4968	 4968	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 1284	 0.002481	 0.006531	 0.0003	 4252	 4252	 4252	 0.0	 0.0	 1	 -30.0	 30.0;
	5136	 1285	 0.013144	 0.024059	 0.004	 1046	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	5802	 1286	 0.006551	 0.016629	 0.0005	 1702	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	2005	 1287	 0.000756	 0.005795	 0.0001	 5205	 5205	 5205	 0.0	 0.0	 1	 -30.0	 30.0;
	2006	 1288	 0.000138	 0.000573	 0.001	 329.0	 329.0	 329.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5207	 1289	 0.001008	 0.003527	 0.0001	 8292	 8292	 8292	 0.0	 0.0	 1	 -30.0	 30.0;
	5208	 1289	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	2300	 1290	 0.048879	 0.100781	 0.0011	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	3936	 1290	 0.085664	 0.234568	 0.0033	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	3936	 1290	 0.091711	 0.240363	 0.0032	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	2654	 1291	 0.000632	 0.004168	 0.0081	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3442	 1296	 0.011518	 0.029173	 0.0014	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	2026	 1297	 0.03679	 0.10037	 0.0047	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	4636	 1297	 0.03321	 0.090494	 0.0039	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 1298	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	1300	 1299	 0.000504	 0.00252	 0.0001	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	4895	 1299	 0.089695	 0.201058	 0.0022	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	5277	 1301	 2e-05	 0.000198	 0.003	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 1302	 0.006299	 0.017133	 0.0	 1618	 1618	 1618	 0.0	 0.0	 1	 -30.0	 30.0;
	2634	 1304	 0.0125	 0.025	 0.0	 1236	 1236	 1236	 0.0	 0.0	 1	 -30.0	 30.0;
	5814	 1305	 0.095666	 0.21222	 0.0023	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 1306	 0.011867	 0.030083	 0.0003	 941	 941	 941	 0.0	 0.0	 1	 -30.0	 30.0;
	5379	 1306	 0.133787	 0.246914	 0.0025	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 1307	 0.0004	 0.001244	 0.0004	 23302	 23302	 23302	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 1307	 0.019956	 0.0604	 0.0198	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 1307	 0.017467	 0.063733	 0.0216	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	3340	 1308	 0.005543	 0.015621	 0.0015	 1835	 1835	 1835	 0.0	 0.0	 1	 -30.0	 30.0;
	3701	 1308	 0.016125	 0.0516	 0.0253	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	4836	 1308	 0.028723	 0.062484	 0.0007	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 1309	 0.000252	 0.000756	 0.0	 38166	 38166	 38166	 0.0	 0.0	 1	 -30.0	 30.0;
	2920	 1310	 0.019652	 0.082137	 0.001	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	3928	 1310	 0.112875	 0.361048	 0.0037	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 1311	 0.005291	 0.013102	 0.0002	 2153	 2153	 2153	 0.0	 0.0	 1	 -30.0	 30.0;
	2612	 1312	 0.035021	 0.094734	 0.0011	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 1312	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5281	 1312	 0.008566	 0.02318	 0.0002	 1231	 1231	 1231	 0.0	 0.0	 1	 -30.0	 30.0;
	1313	 1314	 0.00252	 0.005039	 0.0	 5399	 5399	 5399	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 1314	 0.039557	 0.078861	 0.0008	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 1315	 0.027901	 0.073951	 0.0036	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	5621	 1315	 0.02358	 0.064198	 0.0031	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 1315	 0.019753	 0.052963	 0.0026	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	2934	 1316	 0.047654	 0.121728	 0.0058	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	2130	 1318	 0.001975	 0.00642	 0.0001	 3887	 3887	 3887	 0.0	 0.0	 1	 -30.0	 30.0;
	2130	 1317	 0.001481	 0.004938	 0.0012	 5064	 5064	 5064	 0.0	 0.0	 1	 -30.0	 30.0;
	3424	 1319	 0.066012	 0.167549	 0.0019	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	1380	 1320	 0.031494	 0.131015	 0.007	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	4401	 1320	 0.01159	 0.04132	 0.0298	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	5579	 1320	 0.028219	 0.117158	 0.0017	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	5431	 1321	 0.001233	 0.008227	 0.0147	 525.0	 525.0	 525.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 1322	 0.014462	 0.046762	 0.0375	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	5642	 1322	 0.002268	 0.005039	 0.011	 5504	 5504	 5504	 0.0	 0.0	 1	 -30.0	 30.0;
	4037	 1323	 0.002761	 0.005054	 0.0	 4533	 4533	 4533	 0.0	 0.0	 1	 -30.0	 30.0;
	3251	 1324	 0.018519	 0.047901	 0.0104	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	3519	 1324	 0.004198	 0.010741	 0.0005	 2576	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	2094	 1325	 0.077407	 0.154691	 0.0	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	5233	 1325	 0.009136	 0.020617	 0.001	 1345	 1345	 1345	 0.0	 0.0	 1	 -30.0	 30.0;
	4420	 1326	 0.000756	 0.00252	 0.0003	 11223	 11223	 11223	 0.0	 0.0	 1	 -30.0	 30.0;
	1661	 1327	 0.086143	 0.234971	 0.0039	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	4263	 1327	 0.035525	 0.095742	 0.0011	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	5736	 1327	 0.035878	 0.096649	 0.002	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	2071	 1328	 0.003911	 0.027062	 0.0486	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 1328	 0.000711	 0.006894	 0.0223	 865.0	 865.0	 865.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3057	 1328	 0.007012	 0.030617	 0.0511	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 1328	 0.007639	 0.051542	 0.2291	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1537	 1329	 0.002597	 0.034127	 1.1812	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	3426	 1329	 0.002999	 0.033656	 0.6729	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	4020	 1329	 0.001302	 0.013172	 0.3408	 1727.0	 1727.0	 1727.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1537	 1329	 0.002597	 0.034127	 1.1783	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	3025	 1329	 0.000256	 0.002701	 0.0693	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4020	 1329	 0.001309	 0.013255	 0.3437	 1727.0	 1727.0	 1727.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5095	 1330	 0.004467	 0.008177	 0.0	 2802	 2802	 2802	 0.0	 0.0	 1	 -30.0	 30.0;
	5346	 1331	 0.010582	 0.066264	 0.0009	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	5822	 1331	 0.003527	 0.025699	 0.0	 1139	 1139	 1139	 0.0	 0.0	 1	 -30.0	 30.0;
	2129	 1332	 0.031242	 0.080121	 0.0009	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	4998	 1332	 0.11615	 0.314437	 0.0036	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 1333	 0.035525	 0.073066	 0.001	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	5164	 1333	 0.004787	 0.009574	 0.001	 2759	 2759	 2759	 0.0	 0.0	 1	 -30.0	 30.0;
	4879	 1334	 0.002765	 0.01843	 0.0344	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2080	 1335	 0.002114	 0.012662	 0.0233	 374.0	 374.0	 374.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5153	 1335	 0.000595	 0.004024	 0.0081	 503.0	 503.0	 503.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2081	 1337	 0.001264	 0.008415	 0.0152	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1840	 1338	 0.000504	 0.00252	 0.0021	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 1338	 0.000504	 0.00252	 0.0021	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	1751	 1340	 0.008987	 0.016452	 0.0116	 1575	 1575	 1575	 0.0	 0.0	 1	 -30.0	 30.0;
	5272	 1340	 0.019123	 0.0484	 0.0008	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	4188	 1341	 0.000731	 0.001383	 0.1853	 19787	 19787	 19787	 0.0	 0.0	 1	 -30.0	 30.0;
	3001	 1342	 0.019652	 0.049131	 0.0006	 575	 575	 575	 0.0	 0.0	 1	 -30.0	 30.0;
	2355	 1348	 0.000617	 0.001235	 0.0021	 21515	 21515	 21515	 0.0	 0.0	 1	 -30.0	 30.0;
	2355	 1347	 0.000617	 0.001235	 0.0016	 21515	 21515	 21515	 0.0	 0.0	 1	 -30.0	 30.0;
	1592	 1349	 0.07963	 0.159259	 0.0092	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 1350	 0.149205	 0.273119	 0.0029	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	1359	 1351	 0.045062	 0.118519	 0.0057	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	2352	 1351	 0.036914	 0.098025	 0.0047	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	1385	 1352	 0.03679	 0.081728	 0.0039	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	1944	 1352	 0.005432	 0.03358	 0.0018	 874	 874	 874	 0.0	 0.0	 1	 -30.0	 30.0;
	2616	 1352	 0.001852	 0.012099	 0.0006	 2427	 2427	 2427	 0.0	 0.0	 1	 -30.0	 30.0;
	2684	 1352	 0.046914	 0.118395	 0.0057	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	2685	 1352	 0.007654	 0.031975	 0.0016	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	2690	 1352	 0.018765	 0.072099	 0.0036	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 1352	 0.03679	 0.081852	 0.0039	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 1353	 0.005867	 0.03919	 0.083	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5326	 1353	 0.003812	 0.025482	 0.0466	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5128	 1354	 0.037289	 0.094734	 0.0001	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	3751	 1355	 0.00316	 0.021017	 0.0375	 528.0	 528.0	 528.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3802	 1355	 0.004612	 0.030706	 0.0547	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 1356	 0.006299	 0.027715	 0.0007	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 1357	 0.006299	 0.028219	 0.0003	 1022	 1022	 1022	 0.0	 0.0	 1	 -30.0	 30.0;
	4467	 1358	 0.0451	 0.082641	 0.0044	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	5350	 1359	 0.063333	 0.161605	 0.0076	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	3825	 1361	 0.000138	 0.001363	 0.2025	 22551	 22551	 22551	 0.0	 0.0	 1	 -30.0	 30.0;
	3825	 1360	 0.000158	 0.001323	 0.1822	 23186	 23186	 23186	 0.0	 0.0	 1	 -30.0	 30.0;
	2450	 1362	 0.000741	 0.001481	 0.0021	 17936	 17936	 17936	 0.0	 0.0	 1	 -30.0	 30.0;
	5760	 1363	 0.034014	 0.086672	 0.001	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	1702	 1366	 0.011633	 0.021293	 0.0127	 1181	 1181	 1181	 0.0	 0.0	 1	 -30.0	 30.0;
	1708	 1365	 0.008062	 0.016377	 0.0115	 1570	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 1364	 0.007307	 0.014613	 0.0112	 1754	 1754	 1754	 0.0	 0.0	 1	 -30.0	 30.0;
	1793	 1367	 0.000559	 0.001024	 0.0729	 26552	 26552	 26552	 0.0	 0.0	 1	 -30.0	 30.0;
	1378	 1368	 0.021083	 0.038593	 0.0279	 672	 672	 672	 0.0	 0.0	 1	 -30.0	 30.0;
	3250	 1368	 0.001512	 0.003779	 0.0001	 7254	 7254	 7254	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 1368	 0.001764	 0.006047	 0.0001	 4688	 4688	 4688	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 1368	 0.031242	 0.127488	 0.0017	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5285	 1368	 0.031494	 0.127992	 0.0023	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 1370	 0.021111	 0.055679	 0.0026	 499	 499	 499	 0.0	 0.0	 1	 -30.0	 30.0;
	2072	 1369	 0.044938	 0.12284	 0.0057	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	3996	 1371	 0.001235	 0.003704	 0.0002	 7767	 7767	 7767	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 1372	 0.000292	 0.002538	 0.2546	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1770	 1373	 0.058201	 0.116654	 0.0012	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	2532	 1374	 0.069035	 0.233308	 0.0028	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	5287	 1375	 0.000123	 0.001235	 0.0002	 27851	 27851	 27851	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 1376	 0.000632	 0.004306	 0.0081	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2340	 1377	 0.071907	 0.195263	 0.0025	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	3698	 1377	 0.001764	 0.003275	 0.0025	 8177	 8177	 8177	 0.0	 0.0	 1	 -30.0	 30.0;
	3908	 1377	 0.067599	 0.182036	 0.0029	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	5228	 1377	 0.015369	 0.04132	 0.0005	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	4442	 1380	 0.004787	 0.01285	 0.0232	 2154	 2154	 2154	 0.0	 0.0	 1	 -30.0	 30.0;
	5267	 1380	 0.003275	 0.014361	 0.0069	 2005	 2005	 2005	 0.0	 0.0	 1	 -30.0	 30.0;
	1659	 1381	 0.041824	 0.180146	 0.0022	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	2045	 1381	 0.04132	 0.14059	 0.0017	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	3268	 1381	 0.041068	 0.16906	 0.0021	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	3994	 1381	 0.067775	 0.174099	 0.0019	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 1381	 0.035928	 0.074502	 0.0135	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	5750	 1381	 0.031998	 0.081129	 0.001	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	2530	 1381	 0.06324	 0.158982	 0.0072	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	3993	 1381	 0.065508	 0.166037	 0.0019	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	4940	 1381	 0.039305	 0.102797	 0.0181	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	5510	 1381	 0.03094	 0.06382	 0.0116	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	3431	 1383	 0.001244	 0.008415	 0.0309	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4087	 1383	 0.002114	 0.014242	 0.0486	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3405	 1385	 0.001852	 0.004198	 0.0002	 6474	 6474	 6474	 0.0	 0.0	 1	 -30.0	 30.0;
	2602	 1384	 0.044198	 0.094074	 0.0044	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	2746	 1386	 0.136558	 0.304107	 0.0033	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	2653	 1388	 0.023935	 0.060469	 0.0007	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	3042	 1388	 0.031494	 0.079869	 0.0009	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	3387	 1389	 0.042983	 0.090073	 0.0047	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5520	 1389	 0.007811	 0.016125	 0.0002	 1600	 1600	 1600	 0.0	 0.0	 1	 -30.0	 30.0;
	2141	 1390	 0.036281	 0.082389	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	3857	 1390	 0.015117	 0.036281	 0.0004	 752	 752	 752	 0.0	 0.0	 1	 -30.0	 30.0;
	5132	 1390	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	5288	 1390	 0.028723	 0.090451	 0.001	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	3186	 1391	 0.000617	 0.001235	 0.0006	 21515	 21515	 21515	 0.0	 0.0	 1	 -30.0	 30.0;
	4967	 1392	 0.046359	 0.095994	 0.0011	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	4966	 1392	 0.046611	 0.09801	 0.0011	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	4968	 1393	 0.001719	 0.008	 0.0132	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 1394	 0.009948	 0.01821	 0.0	 1462	 1462	 1462	 0.0	 0.0	 1	 -30.0	 30.0;
	5246	 1395	 0.013354	 0.034266	 0.0004	 827	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	2559	 1395	 0.043689	 0.110784	 0.0017	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 1396	 0.000252	 0.001008	 0.0	 28417	 28417	 28417	 0.0	 0.0	 1	 -30.0	 30.0;
	2337	 1397	 0.091459	 0.249685	 0.0028	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	4320	 1398	 0.112634	 0.206176	 0.0021	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	5585	 1398	 0.097905	 0.179214	 0.0018	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	5291	 1401	 0.012346	 0.024943	 0.0002	 1093	 1093	 1093	 0.0	 0.0	 1	 -30.0	 30.0;
	1946	 1402	 0.019929	 0.079592	 0.0093	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	3693	 1402	 0.051071	 0.160116	 0.0096	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3856	 1402	 0.008566	 0.018896	 0.0213	 1424	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	3856	 1402	 0.008566	 0.018896	 0.0213	 1424	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	1296	 1405	 0.021482	 0.055185	 0.0026	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	1808	 1405	 0.004568	 0.012716	 0.0457	 2199	 2199	 2199	 0.0	 0.0	 1	 -30.0	 30.0;
	4328	 1405	 0.049012	 0.132963	 0.0062	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	5091	 1406	 0.000608	 0.004067	 0.0071	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 1406	 0.002054	 0.013689	 0.0253	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2863	 1407	 0.001764	 0.005039	 0.0056	 5697	 5697	 5697	 0.0	 0.0	 1	 -30.0	 30.0;
	3166	 1407	 0.063593	 0.161275	 0.0018	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	5562	 1408	 0.00126	 0.003779	 0.0001	 7412	 7412	 7412	 0.0	 0.0	 1	 -30.0	 30.0;
	5793	 1409	 0.000504	 0.001008	 0.0	 26199	 26199	 26199	 0.0	 0.0	 1	 -30.0	 30.0;
	5292	 1410	 0.000504	 0.001764	 0.0018	 16094	 16094	 16094	 0.0	 0.0	 1	 -30.0	 30.0;
	2231	 1411	 0.020937	 0.064651	 0.001	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	4139	 1411	 0.026455	 0.084656	 0.001	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 1411	 0.013605	 0.062938	 0.0076	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 1412	 0.029151	 0.078005	 0.0009	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	5758	 1412	 0.031998	 0.083144	 0.001	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	2476	 1413	 0.049568	 0.127321	 0.006	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	2865	 1413	 0.028876	 0.078765	 0.0039	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	4622	 1413	 0.058988	 0.149741	 0.0071	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	1817	 1414	 0.009826	 0.025951	 0.0003	 1097	 1097	 1097	 0.0	 0.0	 1	 -30.0	 30.0;
	1817	 1414	 0.014865	 0.039808	 0.0005	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	2601	 1416	 0.033086	 0.069383	 0.0032	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	3228	 1415	 0.014938	 0.040494	 0.0018	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	2602	 1416	 0.033086	 0.069506	 0.0032	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	3227	 1416	 0.014938	 0.040494	 0.0018	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	3666	 1417	 0.002716	 0.007519	 0.0391	 3794	 3794	 3794	 0.0	 0.0	 1	 -30.0	 30.0;
	3666	 1417	 0.004631	 0.008476	 0.0207	 3140	 3140	 3140	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 1419	 0.010758	 0.044621	 0.0011	 663	 663	 663	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 1418	 0.034713	 0.063542	 0.0007	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	3599	 1420	 0.007432	 0.019803	 0.0019	 1434	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	2002	 1421	 0.000356	 0.000731	 0.0415	 38266	 38266	 38266	 0.0	 0.0	 1	 -30.0	 30.0;
	3879	 1422	 0.065256	 0.173091	 0.0065	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	5295	 1422	 0.000252	 0.001008	 0.0001	 29272	 29272	 29272	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 1422	 0.000252	 0.001008	 0.0008	 29272	 29272	 29272	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 1423	 0.001167	 0.002137	 0.0	 12455	 12455	 12455	 0.0	 0.0	 1	 -30.0	 30.0;
	974	 1424	 0.07	 0.188889	 0.0091	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	5019	 1424	 0.027654	 0.075309	 0.0036	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	5087	 1424	 0.022222	 0.060741	 0.0029	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	5352	 1424	 0.023086	 0.062346	 0.0031	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	3995	 1425	 0.115646	 0.293777	 0.0033	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	5310	 1425	 0.065508	 0.166793	 0.0019	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	4042	 1426	 0.02642	 0.099012	 0.005	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	4514	 1426	 0.028889	 0.097901	 0.0047	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	1430	 1427	 2e-05	 9.8e-05	 0.0111	 309464	 309464	 309464	 0.0	 0.0	 1	 -30.0	 30.0;
	2543	 1428	 0.000968	 0.005906	 0.0602	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2993	 1428	 0.001331	 0.009015	 0.0906	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1060	 1429	 0.035273	 0.092391	 0.001	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	4531	 1429	 0.000857	 0.002394	 0.0021	 11961	 11961	 11961	 0.0	 0.0	 1	 -30.0	 30.0;
	5025	 1429	 0.012094	 0.05165	 0.0006	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	1060	 1429	 0.034064	 0.09093	 0.001	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	2425	 1430	 0.00561	 0.030894	 0.0567	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4988	 1430	 0.003812	 0.025383	 0.0471	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	925	 1431	 0.010582	 0.046359	 0.001	 621	 621	 621	 0.0	 0.0	 1	 -30.0	 30.0;
	1241	 1431	 0.014109	 0.044596	 0.001	 632	 632	 632	 0.0	 0.0	 1	 -30.0	 30.0;
	1610	 1431	 0.035273	 0.099521	 0.001	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	1768	 1431	 0.001915	 0.011817	 0.0209	 2467	 2467	 2467	 0.0	 0.0	 1	 -30.0	 30.0;
	2531	 1431	 0.005795	 0.023432	 0.004	 1224	 1224	 1224	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 1432	 0.034321	 0.087037	 0.004	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	5300	 1433	 0.000504	 0.001764	 0.0018	 16094	 16094	 16094	 0.0	 0.0	 1	 -30.0	 30.0;
	1678	 1434	 0.081381	 0.179894	 0.0021	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	4217	 1435	 0.008272	 0.018519	 0.0008	 1496	 1496	 1496	 0.0	 0.0	 1	 -30.0	 30.0;
	2486	 1436	 0.005039	 0.019148	 0.0268	 1537	 1537	 1537	 0.0	 0.0	 1	 -30.0	 30.0;
	2728	 1436	 0.070547	 0.192744	 0.0027	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	4197	 1436	 0.003275	 0.011086	 0.013	 2632	 2632	 2632	 0.0	 0.0	 1	 -30.0	 30.0;
	4690	 1436	 0.112371	 0.291509	 0.0033	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	5274	 1436	 0.038801	 0.098514	 0.001	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	2486	 1436	 0.004031	 0.014109	 0.014	 2073	 2073	 2073	 0.0	 0.0	 1	 -30.0	 30.0;
	2728	 1436	 0.107332	 0.198791	 0.0021	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	2486	 1436	 0.010756	 0.019689	 0.0139	 1356	 1356	 1356	 0.0	 0.0	 1	 -30.0	 30.0;
	4897	 1437	 0.005233	 0.024413	 0.0435	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5487	 1437	 0.002252	 0.01037	 0.0182	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4896	 1437	 0.00397	 0.02639	 0.0537	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2953	 1438	 0.034321	 0.088518	 0.0042	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	5788	 1438	 0.031482	 0.083333	 0.0039	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 1440	 0.141597	 0.439657	 0.0056	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	1319	 1440	 0.005291	 0.013605	 0.0002	 2023	 2023	 2023	 0.0	 0.0	 1	 -30.0	 30.0;
	3042	 1439	 0.048123	 0.121945	 0.0013	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	3063	 1440	 0.062484	 0.139834	 0.0016	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	4577	 1440	 0.028219	 0.071554	 0.0014	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	4761	 1439	 0.055682	 0.139078	 0.0016	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	5663	 1440	 0.018392	 0.040312	 0.0005	 667	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 1439	 0.012346	 0.037541	 0.0004	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	2654	 1441	 0.005314	 0.024119	 0.0425	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4697	 1441	 0.003398	 0.017541	 0.0314	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2654	 1441	 0.005412	 0.024571	 0.0461	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1444	 1442	 0.006159	 0.011274	 0.0058	 2231	 2231	 2231	 0.0	 0.0	 1	 -30.0	 30.0;
	1444	 1442	 0.004699	 0.008601	 0.0045	 2924	 2924	 2924	 0.0	 0.0	 1	 -30.0	 30.0;
	5301	 1443	 0.000247	 0.001235	 0.0	 23584	 23584	 23584	 0.0	 0.0	 1	 -30.0	 30.0;
	3976	 1445	 0.00126	 0.003275	 0.0	 8415	 8415	 8415	 0.0	 0.0	 1	 -30.0	 30.0;
	997	 1446	 0.001256	 0.008251	 0.2389	 375.0	 375.0	 375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4757	 1446	 0.000158	 0.000652	 0.0729	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	968	 1447	 0.012346	 0.037037	 0.0015	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	4795	 1449	 0.008209	 0.015026	 0.0002	 1777	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	4795	 1448	 0.008209	 0.015026	 0.0002	 1777	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 1450	 0.008566	 0.022172	 0.0002	 1280	 1280	 1280	 0.0	 0.0	 1	 -30.0	 30.0;
	5274	 1450	 0.007811	 0.020156	 0.0002	 1407	 1407	 1407	 0.0	 0.0	 1	 -30.0	 30.0;
	3454	 1451	 0.149811	 0.308818	 0.0034	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	5302	 1452	 0.001047	 0.006973	 0.0132	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3194	 1453	 0.002771	 0.005795	 0.0056	 4708	 4708	 4708	 0.0	 0.0	 1	 -30.0	 30.0;
	4321	 1456	 0.07483	 0.210632	 0.0024	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	3258	 1457	 0.027901	 0.076173	 0.0036	 367	 367	 367	 0.0	 0.0	 1	 -30.0	 30.0;
	4638	 1457	 0.016914	 0.044691	 0.0021	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	4654	 1457	 0.049383	 0.132222	 0.0063	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	5007	 1457	 0.077037	 0.201605	 0.0094	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	5106	 1457	 0.00284	 0.007531	 0.0003	 3691	 3691	 3691	 0.0	 0.0	 1	 -30.0	 30.0;
	4637	 1457	 0.016914	 0.044444	 0.0021	 625	 625	 625	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 1457	 0.015938	 0.040741	 0.0019	 679	 679	 679	 0.0	 0.0	 1	 -30.0	 30.0;
	2138	 1458	 0.005393	 0.029649	 0.0638	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2139	 1458	 0.005393	 0.02963	 0.0638	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5326	 1458	 0.001877	 0.012543	 0.0344	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1925	 1459	 0.000589	 0.007708	 0.2628	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 1459	 0.00115	 0.01169	 0.3032	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5079	 1459	 0.00241	 0.024446	 0.6325	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	1925	 1459	 0.000589	 0.007708	 0.2628	 2389.0	 2389.0	 2389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 1459	 0.00115	 0.01169	 0.3032	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 1459	 0.00153	 0.015526	 0.4014	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1616	 1460	 0.013605	 0.08516	 0.0011	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	2740	 1460	 0.030434	 0.05571	 0.0001	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	3520	 1460	 0.030486	 0.07735	 0.0057	 375	 375	 375	 0.0	 0.0	 1	 -30.0	 30.0;
	5323	 1460	 0.012598	 0.079365	 0.0017	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	3262	 1460	 0.092215	 0.209121	 0.0022	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	4877	 1461	 0.031975	 0.135062	 0.0069	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	3195	 1462	 0.004464	 0.029669	 0.0547	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4879	 1462	 0.005156	 0.034489	 0.0638	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2526	 1463	 0.027595	 0.050512	 0.0004	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	5012	 1464	 0.033086	 0.086049	 0.004	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	5739	 1464	 0.019753	 0.05	 0.0024	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	3552	 1465	 0.025951	 0.107332	 0.0045	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	3552	 1465	 0.025951	 0.107332	 0.0045	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	1703	 1466	 0.005367	 0.029554	 0.0308	 954	 954	 954	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 1467	 0.002771	 0.013605	 0.0249	 2064	 2064	 2064	 0.0	 0.0	 1	 -30.0	 30.0;
	1703	 1466	 0.004535	 0.023683	 0.026	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	3028	 1468	 0.040312	 0.104056	 0.0023	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	4349	 1468	 0.102797	 0.222978	 0.0025	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 1468	 0.040539	 0.105014	 0.0015	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	3028	 1468	 0.04132	 0.090552	 0.0028	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 1469	 0.008122	 0.036857	 0.0655	 329.0	 329.0	 329.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 1469	 0.011081	 0.049936	 0.0891	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2137	 1470	 0.000336	 0.002173	 0.004	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5269	 1471	 0.02066	 0.055682	 0.001	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 1472	 0.063744	 0.162006	 0.0018	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	3623	 1473	 0.00037	 0.000988	 0.004	 28743	 28743	 28743	 0.0	 0.0	 1	 -30.0	 30.0;
	1884	 1474	 0.000974	 0.001783	 0.0008	 14533	 14533	 14533	 0.0	 0.0	 1	 -30.0	 30.0;
	2001	 1474	 0.000403	 0.001386	 0.0001	 20949	 20949	 20949	 0.0	 0.0	 1	 -30.0	 30.0;
	2693	 1474	 0.027967	 0.082137	 0.002	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	2936	 1474	 0.000504	 0.00126	 0.0	 21757	 21757	 21757	 0.0	 0.0	 1	 -30.0	 30.0;
	2935	 1474	 0.000504	 0.00126	 0.0	 21757	 21757	 21757	 0.0	 0.0	 1	 -30.0	 30.0;
	5523	 1474	 0.011338	 0.044848	 0.0014	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	1749	 1475	 0.00156	 0.01041	 0.0192	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2040	 1475	 0.000178	 0.001659	 0.0061	 818.0	 818.0	 818.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3735	 1475	 0.002035	 0.012563	 0.1094	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3759	 1475	 0.000257	 0.001659	 0.003	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1749	 1475	 0.001432	 0.009557	 0.0223	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3759	 1475	 0.000158	 0.001067	 0.0046	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2509	 1476	 0.059209	 0.159486	 0.0019	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	2509	 1476	 0.059209	 0.159486	 0.0019	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	2545	 1478	 0.068959	 0.28511	 0.0156	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	4168	 1478	 0.050214	 0.205996	 0.0246	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	4269	 1478	 0.006727	 0.018141	 0.0009	 1572	 1572	 1572	 0.0	 0.0	 1	 -30.0	 30.0;
	4437	 1478	 0.100126	 0.274402	 0.0092	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 1478	 0.020408	 0.055933	 0.0023	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	5263	 1478	 0.050516	 0.173747	 0.0192	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 1478	 0.024439	 0.067019	 0.0023	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	5258	 1478	 0.050542	 0.17415	 0.02	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	3542	 1479	 0.004787	 0.011338	 0.006	 2700	 2700	 2700	 0.0	 0.0	 1	 -30.0	 30.0;
	4573	 1479	 0.00907	 0.018141	 0.0088	 1639	 1639	 1639	 0.0	 0.0	 1	 -30.0	 30.0;
	3359	 1479	 0.016125	 0.051398	 0.0004	 617	 617	 617	 0.0	 0.0	 1	 -30.0	 30.0;
	4731	 1480	 0.003457	 0.008395	 0.0	 3272	 3272	 3272	 0.0	 0.0	 1	 -30.0	 30.0;
	4731	 1480	 0.000494	 0.008395	 0.0	 3532	 3532	 3532	 0.0	 0.0	 1	 -30.0	 30.0;
	2127	 1481	 0.008542	 0.029422	 0.0095	 1044	 1044	 1044	 0.0	 0.0	 1	 -30.0	 30.0;
	2790	 1482	 0.003368	 0.036373	 0.0273	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4843	 1483	 0.000375	 0.001383	 0.1711	 313.0	 313.0	 313.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4238	 1484	 0.027337	 0.11678	 0.0047	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	5305	 1484	 0.000171	 0.000313	 0.0	 85273	 85273	 85273	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 1485	 0.003086	 0.006173	 0.01	 4650	 4650	 4650	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 1486	 0.04966	 0.126455	 0.0014	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	5715	 1486	 0.052658	 0.143613	 0.0019	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	1711	 1487	 0.042076	 0.124213	 0.0028	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	5054	 1489	 0.000903	 0.006023	 0.0111	 522.0	 522.0	 522.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 1490	 0.00284	 0.007531	 0.0003	 3724	 3724	 3724	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 1490	 0.039877	 0.104815	 0.0049	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 1495	 0.03284	 0.088765	 0.0042	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	2617	 1497	 0.06321	 0.14284	 0.0065	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	3992	 1497	 0.024074	 0.053704	 0.0024	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 1498	 0.063996	 0.161754	 0.0019	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	3403	 1498	 0.047956	 0.087783	 0.0025	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	4053	 1498	 0.010532	 0.063719	 0.0019	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	4709	 1498	 0.024691	 0.166515	 0.005	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	5059	 1498	 0.027816	 0.117662	 0.0028	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	4053	 1498	 0.010532	 0.063719	 0.0019	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	2755	 1499	 0.002359	 0.016431	 0.0203	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2275	 1500	 4e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4686	 1500	 5.9e-05	 0.001185	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4700	 1500	 4e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5306	 1501	 0.000123	 0.001235	 0.0002	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	4822	 1502	 0.010124	 0.043086	 0.0021	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	3364	 1503	 0.014568	 0.089753	 0.0079	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 1503	 0.00716	 0.044074	 0.0024	 680	 680	 680	 0.0	 0.0	 1	 -30.0	 30.0;
	3069	 1504	 0.059965	 0.163265	 0.0018	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	3034	 1505	 0.063744	 0.153742	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	3244	 1505	 0.058705	 0.149156	 0.0	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	2414	 1506	 0.070093	 0.188461	 0.0025	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	5089	 1506	 0.078357	 0.210708	 0.0088	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	4202	 1508	 0.110545	 0.202352	 0.0021	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	4202	 1508	 0.08642	 0.191232	 0.0021	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	2105	 1509	 0.065356	 0.166238	 0.0019	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	3637	 1509	 0.033333	 0.090829	 0.0021	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	3728	 1510	 0.061476	 0.209625	 0.0025	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	3885	 1510	 0.053918	 0.146888	 0.0017	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 1510	 0.017863	 0.060695	 0.0007	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3422	 1511	 0.049131	 0.204082	 0.0025	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	3728	 1511	 0.005543	 0.018896	 0.0002	 1500	 1500	 1500	 0.0	 0.0	 1	 -30.0	 30.0;
	3728	 1511	 0.005795	 0.0194	 0.0002	 1459	 1459	 1459	 0.0	 0.0	 1	 -30.0	 30.0;
	5803	 1512	 0.000968	 0.00644	 0.0121	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2353	 1513	 0.064815	 0.170741	 0.0081	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	2595	 1513	 0.058778	 0.149012	 0.007	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4036	 1513	 0.010247	 0.027778	 0.0013	 1004	 1004	 1004	 0.0	 0.0	 1	 -30.0	 30.0;
	5519	 1513	 0.022469	 0.057407	 0.0028	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	5704	 1513	 0.012222	 0.026914	 0.0021	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	4036	 1513	 0.012346	 0.027407	 0.0021	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	3252	 1514	 0.011773	 0.053926	 0.0962	 427.0	 427.0	 427.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2345	 1515	 0.000966	 0.009803	 0.2526	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3409	 1515	 0.002015	 0.020838	 0.5401	 1517	 1517	 1517	 0.0	 0.0	 1	 -30.0	 30.0;
	2344	 1515	 0.000963	 0.009792	 0.2541	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4784	 1516	 0.029383	 0.123951	 0.0065	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	4785	 1516	 0.029383	 0.123951	 0.0065	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	1628	 1521	 0.041572	 0.113379	 0.0018	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 1521	 0.014865	 0.061476	 0.0008	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3428	 1521	 0.108088	 0.299824	 0.0027	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	4117	 1521	 0.096246	 0.262283	 0.0029	 106	 106	 106	 0.0	 0.0	 1	 -30.0	 30.0;
	5178	 1521	 0.058201	 0.161502	 0.0017	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 1521	 0.014865	 0.061476	 0.0008	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3730	 1522	 0.004207	 0.029077	 0.0547	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4676	 1522	 0.002805	 0.019378	 0.0365	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2320	 1523	 0.01285	 0.055933	 0.0035	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	4910	 1523	 0.073318	 0.185941	 0.0038	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 1523	 0.074578	 0.22197	 0.007	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	4420	 1524	 0.065004	 0.182414	 0.0021	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	5307	 1525	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	1832	 1526	 0.018392	 0.114386	 0.0015	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 1527	 0.046049	 0.117284	 0.0058	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	2566	 1527	 0.042469	 0.114321	 0.0055	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	1544	 1528	 0.026173	 0.069753	 0.0139	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	1561	 1528	 0.062099	 0.167778	 0.0188	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 1529	 0.012099	 0.030617	 0.0013	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	4928	 1528	 0.049383	 0.128148	 0.006	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	5713	 1528	 0.011111	 0.028518	 0.0015	 971	 971	 971	 0.0	 0.0	 1	 -30.0	 30.0;
	4105	 1528	 0.017901	 0.048395	 0.0023	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	5438	 1530	 0.010311	 0.068543	 0.1276	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	5749	 1530	 0.001017	 0.006912	 0.0633	 449.0	 449.0	 449.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2463	 1531	 0.000976	 0.013206	 0.4448	 2406	 2406	 2406	 0.0	 0.0	 1	 -30.0	 30.0;
	2600	 1531	 0.001017	 0.010325	 0.2657	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2940	 1531	 0.001369	 0.017997	 0.6209	 1759	 1759	 1759	 0.0	 0.0	 1	 -30.0	 30.0;
	3617	 1531	 0.002352	 0.025391	 0.5704	 1245	 1245	 1245	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 1531	 0.002021	 0.026575	 0.9197	 1191	 1191	 1191	 0.0	 0.0	 1	 -30.0	 30.0;
	2463	 1531	 0.000976	 0.013213	 0.4448	 2405	 2405	 2405	 0.0	 0.0	 1	 -30.0	 30.0;
	2599	 1531	 0.001017	 0.010325	 0.2657	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1845	 1532	 0.016661	 0.030497	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	5010	 1532	 0.143109	 0.388511	 0.0044	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	5358	 1532	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5843	 1532	 0.096498	 0.265558	 0.003	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	2923	 1533	 0.047115	 0.12774	 0.0013	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5832	 1533	 0.006299	 0.015873	 0.0002	 1981	 1981	 1981	 0.0	 0.0	 1	 -30.0	 30.0;
	2097	 1534	 0.023935	 0.082389	 0.001	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	3073	 1534	 0.017889	 0.045855	 0.0006	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	3538	 1534	 0.063996	 0.162509	 0.0018	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	5177	 1534	 0.012598	 0.043588	 0.0005	 651	 651	 651	 0.0	 0.0	 1	 -30.0	 30.0;
	5358	 1535	 0.071806	 0.194004	 0.0022	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 1536	 0.005223	 0.034671	 0.076	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2010	 1537	 2.1e-05	 0.000301	 0.0116	 2176.0	 2176.0	 2176.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2511	 1537	 0.000697	 0.009107	 0.3114	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2011	 1537	 1.9e-05	 0.00028	 0.0108	 2176.0	 2176.0	 2176.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4854	 1537	 0.001244	 0.016445	 0.5652	 1934	 1934	 1934	 0.0	 0.0	 1	 -30.0	 30.0;
	1927	 1538	 0.008272	 0.021975	 0.001	 1292	 1292	 1292	 0.0	 0.0	 1	 -30.0	 30.0;
	3599	 1538	 0.026914	 0.111605	 0.0058	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	3969	 1538	 0.026173	 0.06716	 0.0031	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	5624	 1538	 0.014568	 0.03963	 0.0018	 719	 719	 719	 0.0	 0.0	 1	 -30.0	 30.0;
	3599	 1538	 0.026914	 0.111605	 0.0058	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	1731	 1539	 0.005096	 0.033837	 0.0628	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5309	 1539	 0.005057	 0.030084	 0.0567	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3520	 1542	 0.044848	 0.113631	 0.0013	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	2146	 1543	 0.005301	 0.009703	 0.0123	 2751	 2751	 2751	 0.0	 0.0	 1	 -30.0	 30.0;
	2626	 1543	 0.012875	 0.032552	 0.0007	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	2146	 1543	 0.003023	 0.010582	 0.0124	 2764	 2764	 2764	 0.0	 0.0	 1	 -30.0	 30.0;
	2626	 1543	 0.013051	 0.029201	 0.0003	 951	 951	 951	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 1545	 0.082892	 0.223734	 0.0044	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5731	 1545	 0.044671	 0.121995	 0.0013	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 1545	 0.059461	 0.162258	 0.0056	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5310	 1546	 0.123457	 0.228521	 0.0025	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	1831	 1548	 0.038148	 0.078395	 0.0036	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 1549	 2e-06	 0.000198	 0.0066	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3237	 1550	 0.017654	 0.074444	 0.0039	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	4257	 1550	 0.01	 0.041975	 0.0021	 703	 703	 703	 0.0	 0.0	 1	 -30.0	 30.0;
	2738	 1551	 0.05291	 0.134291	 0.001	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	3304	 1552	 0.081633	 0.204334	 0.0052	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	2513	 1554	 0.000336	 0.001481	 0.003	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 1554	 0.000652	 0.004346	 0.0081	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2512	 1554	 0.000336	 0.001501	 0.003	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4668	 1556	 0.009776	 0.020635	 0.0187	 1294	 1294	 1294	 0.0	 0.0	 1	 -30.0	 30.0;
	1843	 1558	 0.000123	 0.000247	 0.001	 109898	 109898	 109898	 0.0	 0.0	 1	 -30.0	 30.0;
	5491	 1558	 0.021975	 0.054815	 0.0026	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	1813	 1558	 0.002335	 0.004274	 0.0002	 6227	 6227	 6227	 0.0	 0.0	 1	 -30.0	 30.0;
	1844	 1558	 0.000123	 0.000247	 0.0006	 109898	 109898	 109898	 0.0	 0.0	 1	 -30.0	 30.0;
	1828	 1559	 0.005679	 0.014198	 0.0104	 1984	 1984	 1984	 0.0	 0.0	 1	 -30.0	 30.0;
	3237	 1559	 0.033457	 0.086173	 0.0044	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	3370	 1559	 0.052346	 0.14037	 0.0168	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	3237	 1559	 0.033086	 0.085432	 0.0045	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	3237	 1559	 0.033333	 0.085556	 0.004	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	1776	 1560	 0.006202	 0.041343	 0.0759	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4655	 1560	 0.001205	 0.008099	 0.0152	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4655	 1560	 0.001225	 0.008099	 0.0152	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2007	 1562	 0.068758	 0.187579	 0.0021	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	4368	 1565	 0.100529	 0.273369	 0.003	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	4851	 1565	 0.018645	 0.06576	 0.005	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 1565	 0.083144	 0.246158	 0.0024	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	5260	 1566	 0.02037	 0.049259	 0.0003	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	5312	 1567	 0.000988	 0.005709	 0.0101	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4426	 1568	 0.056552	 0.103518	 0.001	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 1568	 0.059965	 0.149156	 0.0041	 188	 188	 188	 0.0	 0.0	 1	 -30.0	 30.0;
	5313	 1569	 0.020012	 0.126593	 0.0056	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 1570	 0.001877	 0.012504	 0.0223	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3866	 1570	 0.001462	 0.009758	 0.0182	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3066	 1571	 0.029982	 0.102293	 0.001	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	4327	 1571	 0.016377	 0.05543	 0.002	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	4446	 1571	 0.00379	 0.006937	 0.0042	 3736	 3736	 3736	 0.0	 0.0	 1	 -30.0	 30.0;
	5315	 1571	 0.008566	 0.027463	 0.0	 1027	 1027	 1027	 0.0	 0.0	 1	 -30.0	 30.0;
	3942	 1572	 0.024943	 0.101209	 0.002	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 1572	 0.02973	 0.085412	 0.001	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	5688	 1572	 0.023759	 0.096548	 0.0013	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	2977	 1572	 0.056941	 0.154951	 0.0017	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4527	 1573	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4527	 1574	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4527	 1575	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4527	 1576	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1513	 1577	 0.020617	 0.055556	 0.0026	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	2543	 1578	 0.000672	 0.003891	 0.08	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2543	 1578	 0.000632	 0.003812	 0.0911	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3328	 1579	 0.015873	 0.042328	 0.001	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	5316	 1579	 0.003023	 0.006047	 0.0001	 4368	 4368	 4368	 0.0	 0.0	 1	 -30.0	 30.0;
	1998	 1580	 0.00083	 0.005709	 0.0182	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3848	 1580	 0.001709	 0.016636	 0.0577	 866.0	 866.0	 866.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4141	 1580	 0.001758	 0.017442	 0.0547	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1998	 1580	 0.00083	 0.005709	 0.0223	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3598	 1581	 0.000187	 0.00349	 0.0941	 2250.0	 2250.0	 2250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4223	 1582	 0.026833	 0.059889	 0.0007	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	4990	 1582	 0.073797	 0.187075	 0.0021	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	3270	 1583	 0.001605	 0.010247	 0.0005	 3108	 3108	 3108	 0.0	 0.0	 1	 -30.0	 30.0;
	3282	 1583	 0.003086	 0.009012	 0.0153	 3384	 3384	 3384	 0.0	 0.0	 1	 -30.0	 30.0;
	3992	 1583	 0.027407	 0.070124	 0.0032	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	5048	 1583	 0.005059	 0.009261	 0.035	 3055	 3055	 3055	 0.0	 0.0	 1	 -30.0	 30.0;
	5583	 1583	 0.001975	 0.012222	 0.0006	 2792	 2792	 2792	 0.0	 0.0	 1	 -30.0	 30.0;
	3270	 1583	 0.001481	 0.009383	 0.0005	 3393	 3393	 3393	 0.0	 0.0	 1	 -30.0	 30.0;
	3591	 1583	 0.002782	 0.005093	 0.0092	 5554	 5554	 5554	 0.0	 0.0	 1	 -30.0	 30.0;
	5048	 1583	 0.004198	 0.012963	 0.0091	 2366	 2366	 2366	 0.0	 0.0	 1	 -30.0	 30.0;
	2713	 1584	 0.003773	 0.025264	 0.0466	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4157	 1584	 0.005195	 0.023585	 0.0415	 364.0	 364.0	 364.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2613	 1585	 0.031728	 0.12358	 0.0057	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5695	 1586	 0.000617	 0.001235	 0.0019	 21515	 21515	 21515	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 1587	 0.000222	 0.000938	 0.0	 31460	 31460	 31460	 0.0	 0.0	 1	 -30.0	 30.0;
	3779	 1588	 4e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4705	 1588	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 1588	 7.9e-05	 0.001284	 0.002	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4533	 1589	 0.102797	 0.280675	 0.0032	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	5319	 1589	 0.02318	 0.100529	 0.0046	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	4748	 1590	 0.081556	 0.202099	 0.0097	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5335	 1590	 0.031358	 0.082593	 0.004	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	1606	 1591	 0.022676	 0.073318	 0.0008	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	3922	 1591	 0.081885	 0.259259	 0.0043	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	2350	 1593	 0.055556	 0.14642	 0.007	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	4973	 1592	 0.01	 0.027531	 0.0	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	5394	 1593	 0.011852	 0.030988	 0.0015	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	4362	 1593	 0.042716	 0.112099	 0.0053	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	4972	 1592	 0.01	 0.027531	 0.0	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	2763	 1594	 0.028721	 0.081007	 0.1357	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	2808	 1594	 0.012247	 0.062222	 0.1073	 414.0	 414.0	 414.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3009	 1594	 0.009067	 0.042884	 0.0861	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3067	 1594	 0.020602	 0.068109	 0.1083	 258.0	 258.0	 258.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3252	 1594	 0.016691	 0.075299	 0.1336	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4296	 1594	 0.008158	 0.03516	 0.0582	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4730	 1594	 0.016612	 0.078676	 0.1316	 293.0	 293.0	 293.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 1594	 0.023407	 0.110815	 0.1853	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 1595	 0.001898	 0.021337	 0.4245	 1482	 1482	 1482	 0.0	 0.0	 1	 -30.0	 30.0;
	3426	 1595	 0.001828	 0.020533	 0.4101	 1546	 1546	 1546	 0.0	 0.0	 1	 -30.0	 30.0;
	3930	 1595	 0.004633	 0.051018	 1.1581	 624	 624	 624	 0.0	 0.0	 1	 -30.0	 30.0;
	4767	 1595	 0.001053	 0.013843	 0.4765	 2287	 2287	 2287	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 1595	 0.002888	 0.031752	 0.7595	 996	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	4767	 1595	 0.001053	 0.01383	 0.4765	 2289	 2289	 2289	 0.0	 0.0	 1	 -30.0	 30.0;
	2607	 1596	 0.044596	 0.137365	 0.0425	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	3055	 1596	 0.052658	 0.118418	 0.003	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	3419	 1596	 0.023432	 0.070043	 0.0008	 406	 406	 406	 0.0	 0.0	 1	 -30.0	 30.0;
	4869	 1596	 0.006803	 0.014109	 0.007	 1913	 1913	 1913	 0.0	 0.0	 1	 -30.0	 30.0;
	2607	 1596	 0.045855	 0.139582	 0.0516	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 1596	 0.043336	 0.113883	 0.0031	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	2885	 1597	 0.003319	 0.021472	 0.0405	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 1597	 0.001205	 0.007684	 0.0142	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4201	 1598	 0.002212	 0.014558	 0.0299	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4856	 1598	 0.000435	 0.002923	 0.0091	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5078	 1597	 0.000593	 0.00397	 0.4759	 530.0	 530.0	 530.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 1597	 0.001146	 0.007664	 0.0142	 493.0	 493.0	 493.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5320	 1599	 0.000436	 0.000797	 0.0007	 31883	 31883	 31883	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 1600	 0.000178	 0.001185	 0.002	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3041	 1601	 0.070799	 0.154951	 0.0017	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4518	 1601	 0.042832	 0.241371	 0.0048	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5322	 1602	 9.9e-05	 0.000454	 0.001	 262.0	 262.0	 262.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 1603	 0.03225	 0.097254	 0.0001	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 1603	 0.03225	 0.097254	 0.0001	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	2621	 1604	 0.081129	 0.197531	 0.0019	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	4452	 1604	 0.038045	 0.13026	 0.0015	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5146	 1604	 0.036281	 0.098866	 0.0011	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 1605	 0.024364	 0.10519	 0.0135	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	2301	 1605	 0.026455	 0.104308	 0.0017	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 1606	 0.031242	 0.101537	 0.0012	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 1606	 0.025195	 0.077097	 0.0015	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	4668	 1607	 0.015193	 0.061854	 0.0031	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	2114	 1608	 0.06324	 0.155077	 0.0017	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	3505	 1611	 0.028521	 0.087402	 0.001	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 1610	 0.041824	 0.153691	 0.002	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	5558	 1610	 0.084404	 0.230537	 0.002	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5761	 1610	 0.073621	 0.187352	 0.0023	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	2286	 1612	 0.005669	 0.026094	 0.0476	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4992	 1612	 0.001719	 0.01199	 0.0213	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3364	 1613	 0.006667	 0.042222	 0.0046	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 1613	 0.002593	 0.016049	 0.0008	 1866	 1866	 1866	 0.0	 0.0	 1	 -30.0	 30.0;
	1940	 1614	 0.034517	 0.073318	 0.0009	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	2684	 1615	 0.01284	 0.034444	 0.0016	 809	 809	 809	 0.0	 0.0	 1	 -30.0	 30.0;
	5489	 1615	 0.012716	 0.034321	 0.0016	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	5094	 1617	 0.018272	 0.041481	 0.0	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	5734	 1617	 0.075062	 0.195556	 0.0012	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	3953	 1618	 0.028471	 0.116654	 0.0016	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	5430	 1619	 0.040464	 0.123684	 0.0015	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5429	 1619	 0.040464	 0.123684	 0.0015	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5635	 1620	 0.018889	 0.050988	 0.0024	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	2256	 1621	 0.161829	 0.34389	 0.0034	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	5324	 1624	 1.3e-05	 9.9e-05	 0.001	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3623	 1625	 0.002741	 0.010506	 0.0005	 2793	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	2003	 1626	 0.000138	 0.000336	 0.0314	 85214	 85214	 85214	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 1627	 0.014321	 0.039012	 0.0018	 715	 715	 715	 0.0	 0.0	 1	 -30.0	 30.0;
	3422	 1628	 0.081381	 0.222474	 0.0025	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	2202	 1629	 0.005136	 0.009402	 0.0004	 2839	 2839	 2839	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 1629	 0.001638	 0.004334	 0.0039	 6565	 6565	 6565	 0.0	 0.0	 1	 -30.0	 30.0;
	1851	 1630	 0.038498	 0.097707	 0.0011	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	5109	 1630	 0.039557	 0.100529	 0.0011	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	2041	 1631	 0.029226	 0.125649	 0.0026	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	2524	 1632	 0.007559	 0.015621	 0.0217	 1702	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	3021	 1632	 0.006218	 0.011382	 0.0057	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	3575	 1632	 0.01285	 0.048879	 0.0683	 585	 585	 585	 0.0	 0.0	 1	 -30.0	 30.0;
	4119	 1632	 0.017637	 0.039808	 0.0067	 679	 679	 679	 0.0	 0.0	 1	 -30.0	 30.0;
	4511	 1632	 0.014109	 0.036281	 0.0102	 759	 759	 759	 0.0	 0.0	 1	 -30.0	 30.0;
	2524	 1632	 0.007055	 0.016881	 0.0194	 1614	 1614	 1614	 0.0	 0.0	 1	 -30.0	 30.0;
	4119	 1632	 0.016125	 0.04258	 0.0079	 649	 649	 649	 0.0	 0.0	 1	 -30.0	 30.0;
	4511	 1632	 0.013605	 0.033762	 0.0102	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	3172	 1633	 0.001888	 0.013914	 0.403	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4128	 1634	 0.08642	 0.260015	 0.0073	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	4353	 1634	 0.048375	 0.132275	 0.0015	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	1802	 1635	 0.031998	 0.137062	 0.001	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	4749	 1635	 0.022928	 0.06324	 0.0	 453	 453	 453	 0.0	 0.0	 1	 -30.0	 30.0;
	3127	 1636	 0.006979	 0.034316	 0.0531	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	5325	 1637	 0.000171	 0.000313	 0.0	 85273	 85273	 85273	 0.0	 0.0	 1	 -30.0	 30.0;
	2538	 1638	 0.082137	 0.180398	 0.002	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	2964	 1638	 0.102646	 0.348652	 0.0041	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	4749	 1638	 0.125397	 0.284127	 0.0032	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	5326	 1639	 2e-05	 9.9e-05	 0.0	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1719	 1640	 0.063089	 0.153162	 0.0021	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	3402	 1640	 0.058957	 0.141849	 0.0014	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4452	 1640	 0.046284	 0.109448	 0.0016	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	1936	 1641	 0.018889	 0.057654	 0.0028	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	1936	 1641	 0.018395	 0.057531	 0.0005	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	5327	 1642	 0.004431	 0.00811	 0.0001	 3291	 3291	 3291	 0.0	 0.0	 1	 -30.0	 30.0;
	2856	 1644	 0.008148	 0.033704	 0.0016	 857	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	5328	 1643	 8.6e-05	 0.001235	 0.0	 23993	 23993	 23993	 0.0	 0.0	 1	 -30.0	 30.0;
	1873	 1645	 0.002099	 0.003951	 0.0063	 7204	 7204	 7204	 0.0	 0.0	 1	 -30.0	 30.0;
	5453	 1647	 0.022676	 0.070799	 0.0111	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	5329	 1651	 0.025432	 0.064444	 0.0031	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	5330	 1652	 0.027211	 0.049887	 0.0005	 520	 520	 520	 0.0	 0.0	 1	 -30.0	 30.0;
	2638	 1653	 0.008566	 0.016881	 0.0003	 1607	 1607	 1607	 0.0	 0.0	 1	 -30.0	 30.0;
	2795	 1654	 0.055933	 0.149408	 0.002	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	1712	 1655	 0.002481	 0.012134	 0.0218	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2799	 1655	 0.003398	 0.021373	 0.04	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 1655	 0.00081	 0.005551	 0.0101	 565.0	 565.0	 565.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2121	 1656	 0.022676	 0.071554	 0.0021	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	3601	 1656	 0.036281	 0.101789	 0.002	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	1786	 1657	 0.00383	 0.017133	 0.0265	 1733	 1733	 1733	 0.0	 0.0	 1	 -30.0	 30.0;
	1786	 1657	 0.005442	 0.015923	 0.0269	 1808	 1808	 1808	 0.0	 0.0	 1	 -30.0	 30.0;
	2420	 1658	 0.101789	 0.280927	 0.0031	 102	 102	 102	 0.0	 0.0	 1	 -30.0	 30.0;
	4851	 1658	 0.092467	 0.259033	 0.0068	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	5050	 1658	 0.059662	 0.164903	 0.0018	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3268	 1659	 0.020912	 0.090955	 0.0011	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 1660	 0.000756	 0.002268	 0.0	 12351	 12351	 12351	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 1661	 0.095414	 0.176846	 0.0022	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 1662	 0.000336	 0.000672	 0.0469	 41198	 41198	 41198	 0.0	 0.0	 1	 -30.0	 30.0;
	2000	 1663	 0.065256	 0.177879	 0.002	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	3019	 1663	 0.000512	 0.000938	 0.0005	 28461	 28461	 28461	 0.0	 0.0	 1	 -30.0	 30.0;
	3710	 1663	 0.079315	 0.208944	 0.0023	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	3731	 1663	 0.021164	 0.055682	 0.0006	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	4224	 1663	 0.084908	 0.2323	 0.0026	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	5042	 1663	 0.035777	 0.097758	 0.0029	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	5753	 1663	 0.015117	 0.040312	 0.0015	 707	 707	 707	 0.0	 0.0	 1	 -30.0	 30.0;
	3018	 1663	 0.00126	 0.00252	 0.0006	 10795	 10795	 10795	 0.0	 0.0	 1	 -30.0	 30.0;
	5756	 1664	 0.005294	 0.036464	 0.0618	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 1665	 0.09297	 0.253716	 0.0028	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	4722	 1665	 0.069035	 0.228017	 0.0026	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 1666	 0.002599	 0.004757	 0.0002	 5595	 5595	 5595	 0.0	 0.0	 1	 -30.0	 30.0;
	3398	 1667	 0.005518	 0.02197	 0.0033	 1343	 1343	 1343	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 1667	 0.013756	 0.025179	 0.0011	 1061	 1061	 1061	 0.0	 0.0	 1	 -30.0	 30.0;
	5001	 1667	 0.047518	 0.123104	 0.0017	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	3398	 1667	 0.005392	 0.02187	 0.0027	 1351	 1351	 1351	 0.0	 0.0	 1	 -30.0	 30.0;
	5418	 1668	 0.006558	 0.029807	 0.0516	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 1669	 0.024198	 0.099383	 0.0053	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	3145	 1669	 0.046667	 0.199383	 0.017	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	3546	 1671	 0.046822	 0.085707	 0.0021	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 1672	 0.015803	 0.097531	 0.005	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 1672	 0.012346	 0.056049	 0.0026	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	5493	 1672	 0.03642	 0.092469	 0.0044	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	5739	 1672	 0.026049	 0.065926	 0.0031	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	1674	 1673	 0.008765	 0.022099	 0.001	 1250	 1250	 1250	 0.0	 0.0	 1	 -30.0	 30.0;
	4513	 1673	 0.037407	 0.094938	 0.0044	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	2476	 1674	 0.062099	 0.157531	 0.0073	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	2507	 1675	 0.118166	 0.32124	 0.0036	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	4619	 1675	 0.058201	 0.147392	 0.0017	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	3933	 1676	 0.002696	 0.007155	 0.0081	 3862	 3862	 3862	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 1676	 0.009574	 0.038297	 0.0152	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	5652	 1676	 0.029378	 0.111287	 0.0018	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	5455	 1677	 0.001975	 0.013412	 0.0233	 488.0	 488.0	 488.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3041	 1678	 0.018645	 0.041572	 0.0005	 649	 649	 649	 0.0	 0.0	 1	 -30.0	 30.0;
	3649	 1680	 0.022928	 0.058453	 0.0006	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	4512	 1680	 0.01348	 0.034467	 0.0004	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	5325	 1682	 0.027353	 0.05007	 0.0	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	5598	 1683	 0.012144	 0.049332	 0.0012	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 1683	 0.012094	 0.049206	 0.0009	 583	 583	 583	 0.0	 0.0	 1	 -30.0	 30.0;
	1633	 1684	 0.005017	 0.033403	 0.0618	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1720	 1684	 0.003595	 0.019635	 0.0354	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2818	 1684	 0.001422	 0.008217	 0.1007	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3316	 1684	 0.002212	 0.014044	 0.0253	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3704	 1684	 0.001408	 0.008494	 0.2344	 278.0	 278.0	 278.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 1684	 0.002647	 0.01762	 0.0324	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3316	 1684	 0.002212	 0.013985	 0.0263	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 1684	 0.000336	 0.002232	 0.004	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5338	 1685	 0.001512	 0.003779	 0.0001	 7473	 7473	 7473	 0.0	 0.0	 1	 -30.0	 30.0;
	3706	 1686	 1.2e-05	 0.000123	 0.0003	 240340	 240340	 240340	 0.0	 0.0	 1	 -30.0	 30.0;
	5339	 1687	 0.000302	 0.001033	 0.0	 28260	 28260	 28260	 0.0	 0.0	 1	 -30.0	 30.0;
	2450	 1688	 0.00963	 0.027284	 0.0013	 1027	 1027	 1027	 0.0	 0.0	 1	 -30.0	 30.0;
	2450	 1688	 0.00963	 0.024568	 0.0011	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	2450	 1688	 0.018642	 0.049876	 0.0021	 558	 558	 558	 0.0	 0.0	 1	 -30.0	 30.0;
	4211	 1690	 4.8e-05	 8.8e-05	 0.1993	 318558	 318558	 318558	 0.0	 0.0	 1	 -30.0	 30.0;
	4211	 1689	 4.8e-05	 8.8e-05	 0.1993	 318567	 318567	 318567	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 1691	 4.8e-05	 8.8e-05	 0.0001	 303410	 303410	 303410	 0.0	 0.0	 1	 -30.0	 30.0;
	4210	 1693	 4.8e-05	 8.8e-05	 0.001	 310129	 310129	 310129	 0.0	 0.0	 1	 -30.0	 30.0;
	4210	 1692	 4.8e-05	 8.8e-05	 0.001	 310185	 310185	 310185	 0.0	 0.0	 1	 -30.0	 30.0;
	5327	 1694	 0.008314	 0.028471	 0.0003	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	4523	 1696	 0.011332	 0.020743	 0.0007	 1287	 1287	 1287	 0.0	 0.0	 1	 -30.0	 30.0;
	5726	 1696	 0.00252	 0.011086	 0.0002	 2676	 2676	 2676	 0.0	 0.0	 1	 -30.0	 30.0;
	5724	 1696	 0.00257	 0.010935	 0.0002	 2708	 2708	 2708	 0.0	 0.0	 1	 -30.0	 30.0;
	4344	 1697	 0.033762	 0.085664	 0.0	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	2783	 1698	 0.008062	 0.027463	 0.0003	 1063	 1063	 1063	 0.0	 0.0	 1	 -30.0	 30.0;
	2783	 1699	 0.008768	 0.030209	 0.0003	 967	 967	 967	 0.0	 0.0	 1	 -30.0	 30.0;
	5293	 1699	 0.044344	 0.149912	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5294	 1699	 0.043789	 0.148375	 0.0017	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 1699	 0.001285	 0.004107	 0.0	 7068	 7068	 7068	 0.0	 0.0	 1	 -30.0	 30.0;
	5451	 1699	 0.01033	 0.028471	 0.0003	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 1703	 0.000756	 0.007559	 0.0002	 3772	 3772	 3772	 0.0	 0.0	 1	 -30.0	 30.0;
	2725	 1702	 0.00315	 0.005766	 0.0047	 4361	 4361	 4361	 0.0	 0.0	 1	 -30.0	 30.0;
	3209	 1702	 0.008566	 0.017385	 0.0148	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	3925	 1702	 0.011842	 0.055178	 0.0442	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4065	 1702	 0.001022	 0.001871	 0.0012	 13439	 13439	 13439	 0.0	 0.0	 1	 -30.0	 30.0;
	1708	 1702	 0.000756	 0.007559	 0.0002	 3772	 3772	 3772	 0.0	 0.0	 1	 -30.0	 30.0;
	3209	 1702	 0.008314	 0.016629	 0.0144	 1542	 1542	 1542	 0.0	 0.0	 1	 -30.0	 30.0;
	3925	 1702	 0.012497	 0.039909	 0.0442	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	3209	 1702	 0.009826	 0.019652	 0.0144	 1304	 1304	 1304	 0.0	 0.0	 1	 -30.0	 30.0;
	3209	 1702	 0.014024	 0.025671	 0.0148	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 1705	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 1707	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 1704	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 1706	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	3210	 1710	 0.000316	 0.001067	 0.2359	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4635	 1710	 0.000395	 0.002706	 0.0253	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3210	 1710	 0.000217	 0.001817	 0.1812	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3605	 1710	 0.002193	 0.014736	 0.0461	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5342	 1710	 0.001225	 0.007822	 0.0324	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5341	 1710	 0.001225	 0.007822	 0.0324	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2229	 1711	 0.053414	 0.145881	 0.0017	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	2246	 1711	 0.011791	 0.040716	 0.0005	 739	 739	 739	 0.0	 0.0	 1	 -30.0	 30.0;
	3123	 1711	 0.000504	 0.002771	 0.0001	 11088	 11088	 11088	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 1711	 0.039557	 0.11489	 0.0002	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	2246	 1711	 0.011842	 0.040816	 0.0005	 737	 737	 737	 0.0	 0.0	 1	 -30.0	 30.0;
	2128	 1712	 0.002779	 0.013788	 0.0243	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5342	 1714	 0.000553	 0.001106	 0.163	 25032	 25032	 25032	 0.0	 0.0	 1	 -30.0	 30.0;
	5341	 1713	 0.000553	 0.001106	 0.163	 25032	 25032	 25032	 0.0	 0.0	 1	 -30.0	 30.0;
	2231	 1715	 0.00126	 0.003023	 0.0	 9016	 9016	 9016	 0.0	 0.0	 1	 -30.0	 30.0;
	3859	 1716	 0.022469	 0.065556	 0.0031	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	4626	 1716	 0.032593	 0.100864	 0.005	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	4723	 1716	 0.008519	 0.026543	 0.0013	 1066	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 1716	 0.028889	 0.078889	 0.0037	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 1716	 0.008148	 0.053333	 0.0026	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	2049	 1717	 0.005057	 0.033561	 0.0607	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3104	 1718	 0.031746	 0.08642	 0.001	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 1723	 0.000504	 0.001008	 0.0	 26199	 26199	 26199	 0.0	 0.0	 1	 -30.0	 30.0;
	3970	 1725	 0.029259	 0.122346	 0.0164	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 1725	 0.016049	 0.067901	 0.0138	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 1726	 0.001728	 0.007037	 0.0288	 4341	 4341	 4341	 0.0	 0.0	 1	 -30.0	 30.0;
	5346	 1727	 0.002446	 0.004477	 0.0	 5788	 5788	 5788	 0.0	 0.0	 1	 -30.0	 30.0;
	5347	 1728	 0.057748	 0.157571	 0.0018	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	1987	 1729	 0.067775	 0.141597	 0.0016	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	4007	 1730	 0.127139	 0.232726	 0.0026	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	4076	 1730	 0.000756	 0.103301	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	4159	 1729	 0.003779	 0.019652	 0.0002	 1520	 1520	 1520	 0.0	 0.0	 1	 -30.0	 30.0;
	5560	 1729	 0.017637	 0.087176	 0.0007	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	4076	 1729	 0.000756	 0.103301	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	4537	 1731	 0.004913	 0.032622	 0.0608	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3891	 1733	 0.038395	 0.093951	 0.0158	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	3906	 1733	 0.076914	 0.200864	 0.0096	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	5350	 1733	 0.015679	 0.039877	 0.0019	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	1795	 1734	 0.004535	 0.015369	 0.0194	 1898	 1898	 1898	 0.0	 0.0	 1	 -30.0	 30.0;
	5517	 1734	 0.027538	 0.063013	 0.0011	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	1740	 1737	 0.00033	 0.001503	 0.002	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1740	 1736	 0.000296	 0.001349	 0.002	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3096	 1739	 7e-06	 0.000132	 0.0029	 1737.0	 1737.0	 1737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3096	 1738	 7e-06	 0.000125	 0.0029	 1737.0	 1737.0	 1737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1746	 1740	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	3272	 1740	 0.00322	 0.014835	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4984	 1740	 0.00083	 0.00796	 0.0334	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1745	 1740	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1744	 1740	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2326	 1747	 0.004283	 0.014109	 0.0033	 2003	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	5816	 1748	 0.005291	 0.009826	 0.0044	 2646	 2646	 2646	 0.0	 0.0	 1	 -30.0	 30.0;
	2325	 1748	 0.006218	 0.011382	 0.0068	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	2855	 1748	 0.001764	 0.003527	 0.0025	 7488	 7488	 7488	 0.0	 0.0	 1	 -30.0	 30.0;
	5523	 1747	 0.023683	 0.083396	 0.001	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	2483	 1749	 0.002015	 0.013551	 0.0243	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3463	 1749	 0.001094	 0.011536	 0.036	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3825	 1749	 2e-05	 9.9e-05	 0.0405	 695.0	 695.0	 695.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3854	 1749	 0.001205	 0.008	 0.0152	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4246	 1749	 0.00403	 0.027496	 0.0516	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3463	 1749	 0.001096	 0.011575	 0.0359	 355.0	 355.0	 355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3825	 1749	 2e-05	 0.000119	 0.0506	 695.0	 695.0	 695.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 1750	 0.060217	 0.230537	 0.003	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	3088	 1750	 0.051146	 0.130763	 0.001	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	3092	 1750	 0.048123	 0.145629	 0.002	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 1750	 0.078105	 0.22449	 0.002	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	1752	 4124	 0.012774	 0.04064	 0.0005	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	5348	 1753	 0.001792	 0.00328	 0.0	 7997	 7997	 7997	 0.0	 0.0	 1	 -30.0	 30.0;
	2005	 1754	 0.081129	 0.180902	 0.0021	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	2509	 1755	 0.041043	 0.108844	 0.0025	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2680	 1756	 0.126016	 0.230672	 0.0025	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	2306	 1757	 0.001383	 0.007881	 0.0142	 3869	 3869	 3869	 0.0	 0.0	 1	 -30.0	 30.0;
	2140	 1758	 0.037037	 0.09675	 0.0019	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	2328	 1758	 0.022172	 0.056437	 0.0006	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	3262	 1759	 0.090703	 0.232048	 0.0026	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	2668	 1761	 0.033258	 0.084908	 0.001	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	4091	 1761	 0.036533	 0.093222	 0.001	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 1761	 0.083396	 0.219703	 0.0025	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	1778	 1761	 0.070043	 0.177627	 0.002	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	2668	 1761	 0.03351	 0.08516	 0.001	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	2842	 1764	 0.000256	 0.004377	 0.156	 1994.0	 1994.0	 1994.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2842	 1763	 0.000263	 0.004377	 0.1574	 1994.0	 1994.0	 1994.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2842	 1765	 0.000263	 0.004384	 0.1588	 997.0	 997.0	 997.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2842	 1762	 0.000263	 0.004391	 0.1588	 1592.0	 1592.0	 1592.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 1766	 0.008818	 0.025951	 0.0	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 1767	 0.000134	 0.000245	 0.001	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2698	 1768	 0.007861	 0.049509	 0.0006	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	2675	 1769	 0.000178	 0.000711	 0.079	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3873	 1769	 0.000316	 0.001264	 0.1417	 287.0	 287.0	 287.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2315	 1771	 0.042099	 0.122963	 0.0062	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	3302	 1772	 0.027654	 0.072593	 0.0034	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	3563	 1772	 0.012469	 0.031728	 0.0015	 881	 881	 881	 0.0	 0.0	 1	 -30.0	 30.0;
	3706	 1772	 0.01963	 0.051605	 0.0024	 543	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	3858	 1771	 0.064691	 0.164198	 0.0078	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	3901	 1771	 0.028518	 0.077778	 0.0043	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	5111	 1771	 0.028025	 0.07642	 0.0036	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	3706	 1772	 0.02037	 0.051852	 0.0024	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 1773	 0.010943	 0.072652	 0.1347	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	3057	 1773	 0.014775	 0.052267	 0.083	 566	 566	 566	 0.0	 0.0	 1	 -30.0	 30.0;
	3192	 1773	 0.020543	 0.073482	 0.1174	 279.0	 279.0	 279.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4001	 1773	 0.015921	 0.072375	 0.1281	 329.0	 329.0	 329.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5391	 1773	 0.008435	 0.056138	 0.1043	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4920	 1774	 0.042469	 0.115432	 0.0054	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 1774	 0.045679	 0.124691	 0.0058	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	2566	 1775	 0.041728	 0.112346	 0.0053	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	2975	 1775	 0.063951	 0.162346	 0.0076	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	4925	 1775	 0.054444	 0.138025	 0.0065	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	5299	 1775	 0.018395	 0.047161	 0.0023	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	2462	 1776	 0.009912	 0.044701	 0.1817	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4617	 1776	 0.007605	 0.036603	 0.0658	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5184	 1776	 0.005114	 0.03518	 0.0668	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2307	 1777	 0.110355	 0.300076	 0.0034	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	2491	 1777	 0.040312	 0.086924	 0.0001	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	4943	 1778	 0.035273	 0.089695	 0.001	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	4147	 1779	 0.069539	 0.189972	 0.0002	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	3455	 1780	 0.037037	 0.088183	 0.001	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 1780	 0.003452	 0.021315	 0.0003	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	5179	 1780	 0.0161	 0.065533	 0.005	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	5828	 1780	 0.003452	 0.021819	 0.0002	 1337	 1337	 1337	 0.0	 0.0	 1	 -30.0	 30.0;
	4999	 1781	 0.00557	 0.03362	 0.0628	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5320	 1782	 0.000252	 0.00252	 0.0001	 11433	 11433	 11433	 0.0	 0.0	 1	 -30.0	 30.0;
	4644	 1783	 0.066566	 0.168758	 0.0019	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 1783	 0.047871	 0.121693	 0.0013	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	4298	 1784	 0.055808	 0.141471	 0.0016	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4644	 1784	 0.067271	 0.170824	 0.0019	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 1785	 0.075334	 0.19098	 0.0021	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	4582	 1785	 0.036785	 0.087679	 0.001	 320	 320	 320	 0.0	 0.0	 1	 -30.0	 30.0;
	4965	 1785	 0.013354	 0.036785	 0.0004	 796	 796	 796	 0.0	 0.0	 1	 -30.0	 30.0;
	3965	 1786	 0.059965	 0.152935	 0.0017	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4287	 1786	 0.038851	 0.099975	 0.0058	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	2998	 1787	 0.033704	 0.092222	 0.004	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 1788	 0.002975	 0.019475	 0.0504	 444.0	 444.0	 444.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3393	 1788	 0.002627	 0.017975	 0.0324	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 1788	 0.002993	 0.019532	 0.0472	 444.0	 444.0	 444.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3402	 1789	 0.049131	 0.139078	 0.0016	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	4888	 1789	 0.025397	 0.090728	 0.0016	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	4453	 1790	 0.002923	 0.020543	 0.0365	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3558	 1792	 0.000142	 0.000822	 0.1073	 37155	 37155	 37155	 0.0	 0.0	 1	 -30.0	 30.0;
	3558	 1793	 0.000217	 0.000849	 0.1104	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5442	 1794	 0.003779	 0.009826	 0.0112	 2889	 2889	 2889	 0.0	 0.0	 1	 -30.0	 30.0;
	1794	 1795	 0.003527	 0.009574	 0.0108	 2981	 2981	 2981	 0.0	 0.0	 1	 -30.0	 30.0;
	1796	 4720	 0.000138	 0.000296	 0.0223	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2387	 1797	 0.098262	 0.20257	 0.0022	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	4400	 1798	 0.06576	 0.180146	 0.0024	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	4462	 1798	 0.046359	 0.124465	 0.001	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 1798	 0.015117	 0.044596	 0.001	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	3833	 1799	 0.005965	 0.039901	 0.0739	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5149	 1799	 0.000889	 0.006104	 0.0111	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2751	 1801	 0.005795	 0.015117	 0.0002	 1879	 1879	 1879	 0.0	 0.0	 1	 -30.0	 30.0;
	2751	 1800	 0.005795	 0.015117	 0.0002	 1879	 1879	 1879	 0.0	 0.0	 1	 -30.0	 30.0;
	3369	 1802	 0.041799	 0.175384	 0.0026	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	1930	 1803	 0.000756	 0.003275	 0.0046	 8785	 8785	 8785	 0.0	 0.0	 1	 -30.0	 30.0;
	3182	 1803	 0.005795	 0.020408	 0.0002	 1392	 1392	 1392	 0.0	 0.0	 1	 -30.0	 30.0;
	3924	 1803	 0.113883	 0.281683	 0.0032	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	5410	 1803	 0.065004	 0.217687	 0.0025	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	5573	 1803	 0.003275	 0.01348	 0.0002	 2129	 2129	 2129	 0.0	 0.0	 1	 -30.0	 30.0;
	5815	 1803	 0.024943	 0.106576	 0.0013	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	2159	 1804	 0.004318	 0.007903	 0.0058	 3579	 3579	 3579	 0.0	 0.0	 1	 -30.0	 30.0;
	2159	 1804	 0.004398	 0.00805	 0.0058	 3514	 3514	 3514	 0.0	 0.0	 1	 -30.0	 30.0;
	2744	 1805	 0.006551	 0.028219	 0.0003	 990	 990	 990	 0.0	 0.0	 1	 -30.0	 30.0;
	3354	 1805	 0.038549	 0.156966	 0.0021	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	5273	 1805	 0.02318	 0.098262	 0.0023	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	3354	 1805	 0.038549	 0.156715	 0.0022	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	4533	 1805	 0.032502	 0.134543	 0.0038	 208	 208	 208	 0.0	 0.0	 1	 -30.0	 30.0;
	3266	 1806	 0.004681	 0.021847	 0.1382	 386.0	 386.0	 386.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 1807	 0.000831	 0.001688	 0.0	 16165	 16165	 16165	 0.0	 0.0	 1	 -30.0	 30.0;
	3434	 1809	 0.025951	 0.066516	 0.0007	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	5449	 1810	 0.019876	 0.083482	 0.0042	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	5635	 1810	 0.022839	 0.062346	 0.0029	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	4809	 1812	 0.018395	 0.048148	 0.0019	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 1812	 0.023457	 0.059753	 0.0028	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	1816	 1814	 0.005543	 0.011338	 0.0002	 2468	 2468	 2468	 0.0	 0.0	 1	 -30.0	 30.0;
	1816	 1814	 0.005795	 0.01159	 0.0002	 2403	 2403	 2403	 0.0	 0.0	 1	 -30.0	 30.0;
	5352	 1815	 0.020741	 0.055679	 0.0028	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	2474	 1817	 0.032452	 0.110179	 0.0013	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	2558	 1817	 0.071303	 0.193752	 0.0022	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3999	 1817	 0.017259	 0.056941	 0.002	 512	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 1818	 0.002953	 0.019787	 0.0363	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 1818	 0.002963	 0.019733	 0.0365	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2160	 1819	 0.000494	 0.002212	 0.004	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2160	 1819	 0.000474	 0.002193	 0.004	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3662	 1820	 0.013704	 0.061728	 0.0008	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	3662	 1820	 0.019383	 0.082963	 0.0015	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	3007	 1821	 0.011168	 0.020443	 0.002	 1306	 1306	 1306	 0.0	 0.0	 1	 -30.0	 30.0;
	3535	 1821	 0.053313	 0.199471	 0.0173	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	1956	 1823	 0.002086	 0.025528	 0.4534	 1246	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	2707	 1823	 0.001432	 0.015665	 0.3754	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 1824	 0.036667	 0.102963	 0.0047	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	3078	 1825	 0.020408	 0.085412	 0.0014	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	3547	 1826	 0.010582	 0.022928	 0.0231	 1170	 1170	 1170	 0.0	 0.0	 1	 -30.0	 30.0;
	4404	 1826	 0.04132	 0.114135	 0.0022	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	5759	 1826	 0.015117	 0.04006	 0.0005	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	3547	 1826	 0.011086	 0.02318	 0.0211	 1150	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	4669	 1827	 0.002726	 0.018212	 0.0481	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4669	 1827	 0.002765	 0.018212	 0.0486	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4725	 1829	 0.008314	 0.031494	 0.001	 907	 907	 907	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 1830	 0.010753	 0.029321	 0.0014	 952	 952	 952	 0.0	 0.0	 1	 -30.0	 30.0;
	5416	 1831	 0.051444	 0.105716	 0.0048	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	2015	 1832	 0.034593	 0.087579	 0.0014	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	2413	 1832	 0.025185	 0.046101	 0.0005	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	2847	 1832	 0.039683	 0.14714	 0.0023	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	3628	 1832	 0.003595	 0.00658	 0.0006	 3938	 3938	 3938	 0.0	 0.0	 1	 -30.0	 30.0;
	4859	 1832	 0.086168	 0.187453	 0.0021	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 1832	 0.015873	 0.09801	 0.0013	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 1832	 0.063996	 0.139582	 0.001	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	5455	 1833	 0.000375	 0.002548	 0.0061	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5516	 1833	 0.001969	 0.011678	 0.0223	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 1835	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5356	 1834	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2129	 1836	 0.05805	 0.147443	 0.0017	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	2597	 1836	 0.041068	 0.104812	 0.0012	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	2016	 1837	 0.168002	 0.377601	 0.0079	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	2322	 1837	 0.037289	 0.098262	 0.0077	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	4878	 1837	 0.107987	 0.222827	 0.0057	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	5324	 1838	 0.003832	 0.019733	 0.0359	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 1842	 0.011975	 0.03037	 0.0015	 984	 984	 984	 0.0	 0.0	 1	 -30.0	 30.0;
	2875	 1846	 0.08642	 0.218947	 0.0025	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	4267	 1847	 0.022172	 0.056437	 0.0006	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	2298	 1848	 0.053691	 0.137944	 0.0016	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	2495	 1848	 0.027715	 0.071554	 0.0008	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	2254	 1851	 0.017889	 0.067523	 0.0008	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	2420	 1851	 0.064248	 0.166541	 0.0018	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	4321	 1851	 0.047569	 0.122575	 0.0019	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 1852	 0.014865	 0.039305	 0.0005	 724	 724	 724	 0.0	 0.0	 1	 -30.0	 30.0;
	4000	 1852	 0.023935	 0.075838	 0.0009	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 1853	 0.019904	 0.085412	 0.0039	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	3063	 1854	 0.026959	 0.061225	 0.0007	 442	 442	 442	 0.0	 0.0	 1	 -30.0	 30.0;
	3069	 1854	 0.038801	 0.081885	 0.0009	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	3028	 1855	 0.003779	 0.012598	 0.0021	 2313	 2313	 2313	 0.0	 0.0	 1	 -30.0	 30.0;
	3328	 1856	 0.010834	 0.052658	 0.001	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	4017	 1856	 0.010293	 0.018841	 0.0002	 1376	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	4279	 1856	 0.007055	 0.026707	 0.0	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	3646	 1857	 0.002066	 0.012018	 0.0148	 2495	 2495	 2495	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 1861	 0.005901	 0.019494	 0.001	 1459	 1459	 1459	 0.0	 0.0	 1	 -30.0	 30.0;
	4502	 1862	 0.02321	 0.049259	 0.0023	 546	 546	 546	 0.0	 0.0	 1	 -30.0	 30.0;
	4122	 1863	 0.024198	 0.101728	 0.0052	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	1724	 1864	 0.051728	 0.099383	 0.0042	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	2297	 1864	 0.074815	 0.149753	 0.0066	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	3189	 1864	 0.035494	 0.14963	 0.0076	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	5132	 1866	 0.053162	 0.173343	 0.0021	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	5267	 1867	 0.002771	 0.011338	 0.0002	 2530	 2530	 2530	 0.0	 0.0	 1	 -30.0	 30.0;
	5579	 1867	 0.007307	 0.031242	 0.0059	 921	 921	 921	 0.0	 0.0	 1	 -30.0	 30.0;
	1941	 1868	 0.046863	 0.127992	 0.0014	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	2554	 1868	 0.053414	 0.13681	 0.0018	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	1816	 1869	 0.034517	 0.144621	 0.0024	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	2676	 1870	 0.009787	 0.017916	 0.0319	 1486	 1486	 1486	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 1871	 0.000123	 0.001235	 0.0	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	3647	 1874	 0.018695	 0.036256	 0.0004	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	5361	 1875	 0.000247	 0.001235	 0.0006	 23584	 23584	 23584	 0.0	 0.0	 1	 -30.0	 30.0;
	3661	 1876	 0.023432	 0.074074	 0.001	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	3847	 1876	 0.04384	 0.109851	 0.001	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	4740	 1876	 0.010078	 0.024439	 0.0003	 1117	 1117	 1117	 0.0	 0.0	 1	 -30.0	 30.0;
	5393	 1876	 0.054674	 0.137818	 0.002	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	3996	 1877	 0.004321	 0.019876	 0.0172	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	3996	 1877	 0.004321	 0.019876	 0.0172	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	3738	 1878	 5.9e-05	 0.000138	 0.0081	 206242	 206242	 206242	 0.0	 0.0	 1	 -30.0	 30.0;
	3053	 1880	 0.036667	 0.098889	 0.0049	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	3053	 1881	 0.036667	 0.098889	 0.0049	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	4218	 1882	 0.012469	 0.031482	 0.0015	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	5363	 1885	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5364	 1886	 2e-05	 0.000198	 0.001	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	2686	 1887	 0.000217	 0.00081	 0.1002	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1897	 1895	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1897	 1894	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1897	 1893	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1897	 1892	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	3867	 1896	 0.03036	 0.087856	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5053	 1896	 0.041068	 0.104308	 0.0012	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	4081	 1897	 0.00381	 0.02541	 0.0471	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3962	 1898	 0.007559	 0.050643	 0.001	 577	 577	 577	 0.0	 0.0	 1	 -30.0	 30.0;
	4207	 1898	 0.054422	 0.150214	 0.0844	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	4250	 1898	 0.031746	 0.136054	 0.0016	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	4861	 1898	 0.023432	 0.126228	 0.002	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	5266	 1898	 0.036281	 0.153943	 0.002	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	5466	 1898	 0.021164	 0.073293	 0.0011	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	3976	 1898	 0.008314	 0.035525	 0.0	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	5667	 1898	 0.035273	 0.089947	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	3976	 1898	 0.008314	 0.035525	 0.001	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 1899	 0.00476	 0.032099	 0.0567	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3602	 1899	 0.002825	 0.019082	 0.0344	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3963	 1899	 0.000593	 0.00403	 0.0071	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5265	 1899	 0.0016	 0.010884	 0.0192	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 1901	 0.018712	 0.063684	 0.1073	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	4922	 1901	 0.01297	 0.04896	 0.079	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	4257	 1902	 0.008519	 0.017037	 0.0008	 1592	 1592	 1592	 0.0	 0.0	 1	 -30.0	 30.0;
	5084	 1903	 0.032754	 0.089191	 0.001	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	4775	 1904	 0.049887	 0.127992	 0.0014	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 1905	 0.012716	 0.052593	 0.0034	 561	 561	 561	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 1906	 0.010078	 0.018645	 0.0236	 1394	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	5643	 1906	 0.075334	 0.13807	 0.0024	 188	 188	 188	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 1906	 0.010078	 0.018645	 0.0236	 1394	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	4281	 1907	 0.045881	 0.12197	 0.0017	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5131	 1907	 0.038801	 0.080121	 0.0013	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	5310	 1907	 0.020912	 0.066767	 0.001	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 1908	 0.001363	 0.009106	 0.0304	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5375	 1908	 0.011437	 0.078084	 0.1377	 276.0	 276.0	 276.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5292	 1910	 0.002016	 0.007055	 0.0065	 4122	 4122	 4122	 0.0	 0.0	 1	 -30.0	 30.0;
	5300	 1909	 0.000171	 0.000313	 0.0	 84779	 84779	 84779	 0.0	 0.0	 1	 -30.0	 30.0;
	5717	 1911	 0.007307	 0.019904	 0.0002	 1393	 1393	 1393	 0.0	 0.0	 1	 -30.0	 30.0;
	2248	 1912	 0.000869	 0.004407	 0.4212	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5171	 1913	 0.008642	 0.022346	 0.0011	 1240	 1240	 1240	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 1914	 0.003527	 0.015117	 0.0002	 1903	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	5292	 1914	 0.001764	 0.006047	 0.006	 4688	 4688	 4688	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 1914	 0.003779	 0.015117	 0.0011	 1895	 1895	 1895	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 1915	 0.003527	 0.009322	 0.0106	 3052	 3052	 3052	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 1916	 0.000756	 0.002016	 0.0	 13714	 13714	 13714	 0.0	 0.0	 1	 -30.0	 30.0;
	5009	 1917	 0.001948	 0.003565	 0.0	 7487	 7487	 7487	 0.0	 0.0	 1	 -30.0	 30.0;
	3921	 1918	 0.107332	 0.272109	 0.0031	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	2092	 1919	 0.00069	 0.001263	 0.0032	 21948	 21948	 21948	 0.0	 0.0	 1	 -30.0	 30.0;
	3826	 1919	 0.001728	 0.005679	 0.0003	 5407	 5407	 5407	 0.0	 0.0	 1	 -30.0	 30.0;
	5424	 1920	 0.01033	 0.034014	 0.0004	 806	 806	 806	 0.0	 0.0	 1	 -30.0	 30.0;
	2319	 1921	 0.000217	 0.000474	 0.0445	 59375	 59375	 59375	 0.0	 0.0	 1	 -30.0	 30.0;
	2188	 1922	 0.039136	 0.124321	 0.007	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	2348	 1922	 0.039383	 0.101358	 0.0057	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	2401	 1922	 0.030247	 0.079383	 0.0046	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	4236	 1922	 0.000741	 0.001728	 0.0011	 16129	 16129	 16129	 0.0	 0.0	 1	 -30.0	 30.0;
	4236	 1922	 0.000741	 0.001728	 0.0012	 16129	 16129	 16129	 0.0	 0.0	 1	 -30.0	 30.0;
	5322	 1923	 0.002765	 0.012998	 0.0213	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3416	 1924	 0.012593	 0.078025	 0.004	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	3416	 1924	 0.012099	 0.078272	 0.004	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	1931	 1925	 0.001205	 0.015845	 0.5487	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	4527	 1925	 0.000623	 0.008172	 0.283	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1931	 1925	 0.001205	 0.015852	 0.5487	 1997	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	4527	 1925	 0.000623	 0.008172	 0.283	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3868	 1926	 0.072814	 0.198287	 0.0022	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 1926	 0.017133	 0.072814	 0.0001	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 1926	 0.017133	 0.072814	 0.0001	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	5331	 1927	 0.014938	 0.039012	 0.0018	 726	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	2553	 1928	 0.001622	 0.010949	 0.0816	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2965	 1928	 0.004361	 0.019407	 0.0346	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4453	 1928	 0.00644	 0.043615	 0.081	 537.0	 537.0	 537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2965	 1928	 0.002884	 0.019127	 0.0357	 537.0	 537.0	 537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3930	 1929	 0.003553	 0.040406	 0.8776	 789	 789	 789	 0.0	 0.0	 1	 -30.0	 30.0;
	4543	 1929	 0.001413	 0.020512	 0.5314	 1552	 1552	 1552	 0.0	 0.0	 1	 -30.0	 30.0;
	4854	 1929	 0.002029	 0.020568	 0.5372	 1543	 1543	 1543	 0.0	 0.0	 1	 -30.0	 30.0;
	2283	 1929	 0.001233	 0.012465	 0.3235	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4543	 1929	 0.00141	 0.019927	 0.5463	 1597	 1597	 1597	 0.0	 0.0	 1	 -30.0	 30.0;
	4284	 1931	 0.000983	 0.012909	 0.4476	 2461	 2461	 2461	 0.0	 0.0	 1	 -30.0	 30.0;
	2652	 1934	 0.028647	 0.075032	 0.0049	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	4093	 1935	 0.001058	 0.006576	 0.0116	 4433	 4433	 4433	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 1936	 0.009617	 0.05921	 0.0071	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	2922	 1936	 0.014321	 0.036667	 0.0016	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	3126	 1937	 0.010864	 0.06	 0.019	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	4058	 1936	 0.011728	 0.029753	 0.0015	 1008	 1008	 1008	 0.0	 0.0	 1	 -30.0	 30.0;
	5359	 1937	 0.010988	 0.028518	 0.0003	 1132	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 1936	 0.00963	 0.059247	 0.0071	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	4058	 1936	 0.009506	 0.030864	 0.0022	 998	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 1938	 0.011299	 0.051259	 0.0881	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 1938	 0.002232	 0.012286	 0.0218	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 1938	 0.003714	 0.017975	 0.0405	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3495	 1942	 0.017385	 0.044344	 0.0	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	2041	 1943	 0.003527	 0.009574	 0.0004	 2981	 2981	 2981	 0.0	 0.0	 1	 -30.0	 30.0;
	2690	 1944	 0.003827	 0.010124	 0.0005	 2745	 2745	 2745	 0.0	 0.0	 1	 -30.0	 30.0;
	2883	 1945	 0.017385	 0.074326	 0.0091	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	2906	 1945	 0.013857	 0.056185	 0.0108	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	5371	 1947	 0.000123	 0.000333	 0.0	 83671	 83671	 83671	 0.0	 0.0	 1	 -30.0	 30.0;
	3304	 1948	 0.034417	 0.113429	 0.0021	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	5276	 1949	 0.004938	 0.01	 0.0005	 2664	 2664	 2664	 0.0	 0.0	 1	 -30.0	 30.0;
	5716	 1950	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 1951	 0.026707	 0.070547	 0.0051	 404	 404	 404	 0.0	 0.0	 1	 -30.0	 30.0;
	3265	 1952	 0.065004	 0.171328	 0.0019	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	3304	 1952	 0.029226	 0.073066	 0.0035	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 1953	 0.002268	 0.005291	 0.0001	 5284	 5284	 5284	 0.0	 0.0	 1	 -30.0	 30.0;
	4423	 1953	 0.012774	 0.023558	 0.0002	 1135	 1135	 1135	 0.0	 0.0	 1	 -30.0	 30.0;
	2292	 1955	 0.003812	 0.018568	 0.0557	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4103	 1954	 0.003911	 0.01679	 0.0284	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4999	 1955	 0.005057	 0.031131	 0.0587	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5277	 1954	 0.002785	 0.018153	 0.0334	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4898	 1956	 0.002569	 0.036468	 0.9253	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	4898	 1956	 0.002569	 0.036468	 0.9253	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	4898	 1956	 0.005422	 0.039197	 0.841	 806	 806	 806	 0.0	 0.0	 1	 -30.0	 30.0;
	3006	 1958	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	3601	 1959	 0.005039	 0.013857	 0.0016	 2003	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 1960	 0.082464	 0.277879	 0.0031	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	1973	 1971	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1973	 1970	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1973	 1969	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1973	 1968	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1973	 1967	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1973	 1966	 2e-06	 0.001185	 0.001	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	3806	 1972	 0.054674	 0.149534	 0.0017	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4480	 1972	 0.054926	 0.166289	 0.0019	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3807	 1973	 0.00164	 0.011299	 0.0213	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4482	 1973	 0.002647	 0.018035	 0.0334	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3287	 1975	 0.045855	 0.140338	 0.002	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4104	 1976	 0.031494	 0.076846	 0.001	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	4312	 1978	 0.035097	 0.068405	 0.0007	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	4749	 1978	 0.040816	 0.092719	 0.001	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 1979	 0.057697	 0.151927	 0.0034	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	2241	 1980	 0.018645	 0.037037	 0.0004	 734	 734	 734	 0.0	 0.0	 1	 -30.0	 30.0;
	3220	 1981	 0.059209	 0.153439	 0.0017	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	4249	 1982	 0.078357	 0.222726	 0.003	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	3924	 1983	 0.154926	 0.396699	 0.0098	 70	 70	 70	 0.0	 0.0	 1	 -30.0	 30.0;
	5182	 1984	 0.013025	 0.037111	 0.0018	 769	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	5361	 1984	 0.028568	 0.097111	 0.0062	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	5375	 1985	 2e-05	 0.000138	 0.001	 509.0	 509.0	 509.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5380	 1985	 0.000395	 0.002647	 0.0051	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5376	 1986	 0.000504	 0.00126	 0.0	 21757	 21757	 21757	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 1987	 0.041824	 0.090451	 0.001	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	5725	 1988	 0.036533	 0.159486	 0.0021	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	2298	 1989	 0.081129	 0.207861	 0.0024	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	2307	 1989	 0.095641	 0.247367	 0.0028	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	3196	 1989	 0.056437	 0.148652	 0.0019	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4182	 1990	 0.007055	 0.044596	 0.0006	 674	 674	 674	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 1990	 0.006803	 0.045855	 0.0028	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 1990	 0.019652	 0.05417	 0.0006	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	4182	 1990	 0.006299	 0.039305	 0.0005	 765	 765	 765	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 1990	 0.007055	 0.047367	 0.0006	 636	 636	 636	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 1990	 0.006979	 0.046813	 0.0006	 643	 643	 643	 0.0	 0.0	 1	 -30.0	 30.0;
	2510	 1991	 0.003259	 0.021669	 0.0405	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2510	 1991	 0.00324	 0.021768	 0.0395	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5378	 1992	 0.026102	 0.066087	 0.0011	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 1993	 0.066516	 0.181406	 0.0028	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	4066	 1995	 0.05543	 0.141093	 0.0016	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 1995	 0.054422	 0.138574	 0.0016	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	4066	 1996	 0.055178	 0.140338	 0.0016	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 1996	 0.05417	 0.13807	 0.0016	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5357	 1997	 0.000252	 0.00252	 0.0001	 13395	 13395	 13395	 0.0	 0.0	 1	 -30.0	 30.0;
	2672	 1998	 0.002351	 0.011022	 0.0182	 2747	 2747	 2747	 0.0	 0.0	 1	 -30.0	 30.0;
	3281	 1998	 0.002252	 0.015842	 0.079	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2908	 1998	 0.00132	 0.013076	 0.0385	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4141	 1998	 0.005531	 0.027042	 0.0628	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 1999	 0.016755	 0.051348	 0.0053	 564	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	3710	 2000	 0.058453	 0.15747	 0.0022	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	4640	 2003	 0.000138	 0.000316	 0.0314	 89765	 89765	 89765	 0.0	 0.0	 1	 -30.0	 30.0;
	4153	 2004	 0.020988	 0.055185	 0.0026	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	5171	 2004	 0.016049	 0.040741	 0.0019	 679	 679	 679	 0.0	 0.0	 1	 -30.0	 30.0;
	2810	 2005	 0.076594	 0.194507	 0.0022	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 2005	 0.120106	 0.327186	 0.0042	 88	 88	 88	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 2005	 0.180957	 0.33124	 0.0039	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	3929	 2006	 0.009264	 0.038696	 0.0638	 309.0	 309.0	 309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 2006	 0.022084	 0.061906	 0.1013	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 2006	 0.017185	 0.07921	 0.1336	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3403	 2007	 0.089494	 0.244142	 0.0028	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 2008	 0.001358	 0.003704	 0.0002	 7529	 7529	 7529	 0.0	 0.0	 1	 -30.0	 30.0;
	5384	 2009	 0.000296	 0.001936	 0.0137	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5835	 2012	 0.008818	 0.024188	 0.0002	 1182	 1182	 1182	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 2013	 0.00907	 0.024439	 0.0002	 1167	 1167	 1167	 0.0	 0.0	 1	 -30.0	 30.0;
	5457	 2014	 0.00237	 0.005748	 0.0111	 5032	 5032	 5032	 0.0	 0.0	 1	 -30.0	 30.0;
	3179	 2016	 0.072814	 0.15999	 0.0017	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 2016	 0.104157	 0.283522	 0.0038	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	3607	 2017	 0.000336	 0.002252	 0.004	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2702	 2019	 0.068531	 0.186697	 0.0021	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	4285	 2019	 0.016881	 0.045855	 0.0006	 605	 605	 605	 0.0	 0.0	 1	 -30.0	 30.0;
	2541	 2020	 0.022676	 0.070295	 0.0065	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 2020	 0.035021	 0.081129	 0.0025	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	5645	 2021	 0.001008	 0.00252	 0.001	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 2022	 0.002593	 0.006914	 0.0003	 4107	 4107	 4107	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 2023	 0.002099	 0.006173	 0.0003	 4651	 4651	 4651	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 2024	 0.010124	 0.027296	 0.0045	 1021	 1021	 1021	 0.0	 0.0	 1	 -30.0	 30.0;
	2086	 2025	 0.022593	 0.077901	 0.0045	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	2681	 2025	 0.008395	 0.017531	 0.0826	 1651	 1651	 1651	 0.0	 0.0	 1	 -30.0	 30.0;
	3375	 2025	 0.016173	 0.068395	 0.0044	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	2937	 2027	 0.046667	 0.119136	 0.0057	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	4748	 2027	 0.017531	 0.040123	 0.0019	 693	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	4875	 2028	 0.00358	 0.00716	 0.0194	 3711	 3711	 3711	 0.0	 0.0	 1	 -30.0	 30.0;
	5554	 2029	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5555	 2029	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	4117	 2030	 0.061225	 0.171328	 0.0018	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	5178	 2030	 0.072688	 0.199899	 0.0022	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	5305	 2031	 0.020988	 0.107155	 0.0126	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	5559	 2031	 0.021164	 0.107332	 0.0012	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	5560	 2031	 0.021164	 0.107332	 0.0012	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 2032	 0.047619	 0.129756	 0.0014	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	2054	 2033	 0.117914	 0.298816	 0.0034	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	2817	 2033	 0.059234	 0.162761	 0.0018	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3741	 2033	 0.071429	 0.181532	 0.0021	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	5212	 2033	 0.03225	 0.081885	 0.0009	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 2033	 0.008566	 0.053666	 0.0007	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	5209	 2033	 0.03225	 0.081129	 0.001	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 2034	 0.011556	 0.052998	 0.0942	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4853	 2034	 0.011299	 0.057086	 0.1013	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4722	 2035	 0.075334	 0.243638	 0.0022	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	3861	 2036	 0.109625	 0.278786	 0.0174	 102	 102	 102	 0.0	 0.0	 1	 -30.0	 30.0;
	3605	 2037	 0.002173	 0.014519	 0.0273	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2440	 2039	 0.026449	 0.06568	 0.0207	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	2659	 2039	 0.012133	 0.030178	 0.0095	 972	 972	 972	 0.0	 0.0	 1	 -30.0	 30.0;
	2216	 2042	 0.013253	 0.051348	 0.0013	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 2042	 0.010582	 0.063744	 0.001	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	2267	 2042	 0.014588	 0.067498	 0.0008	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	2834	 2042	 0.012169	 0.032779	 0.001	 870	 870	 870	 0.0	 0.0	 1	 -30.0	 30.0;
	2217	 2043	 0.000942	 0.004946	 0.0182	 6148	 6148	 6148	 0.0	 0.0	 1	 -30.0	 30.0;
	2737	 2043	 0.008533	 0.038716	 0.0678	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2755	 2043	 0.002977	 0.014748	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3756	 2043	 0.002483	 0.016496	 0.0304	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4059	 2043	 0.004188	 0.019082	 0.0334	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4172	 2043	 0.001742	 0.01171	 0.038	 457.0	 457.0	 457.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4482	 2043	 0.001414	 0.009527	 0.0172	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5393	 2044	 0.002771	 0.007307	 0.0	 3779	 3779	 3779	 0.0	 0.0	 1	 -30.0	 30.0;
	2977	 2046	 0.029479	 0.064248	 0.0007	 406	 406	 406	 0.0	 0.0	 1	 -30.0	 30.0;
	2977	 2046	 0.022928	 0.062484	 0.0007	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 2047	 0.008672	 0.04002	 0.084	 256.0	 256.0	 256.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5454	 2047	 0.001237	 0.005636	 0.0256	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4804	 2048	 0.068027	 0.173091	 0.0019	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 2048	 0.012094	 0.031242	 0.0003	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	3191	 2049	 0.003062	 0.020365	 0.0385	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4303	 2049	 0.000786	 0.00524	 0.0273	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5391	 2049	 0.003615	 0.024336	 0.0445	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4304	 2049	 0.001274	 0.008486	 0.0152	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2345	 2050	 0.001634	 0.016835	 0.4361	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 2050	 0.000935	 0.013565	 0.3523	 2335	 2335	 2335	 0.0	 0.0	 1	 -30.0	 30.0;
	4767	 2050	 0.001434	 0.01885	 0.6527	 1679	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	2344	 2050	 0.001634	 0.016842	 0.4361	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3508	 2050	 0.000934	 0.013565	 0.3523	 2335	 2335	 2335	 0.0	 0.0	 1	 -30.0	 30.0;
	4767	 2050	 0.001434	 0.01885	 0.6527	 1679	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	3612	 2053	 0.001512	 0.006803	 0.0001	 4237	 4237	 4237	 0.0	 0.0	 1	 -30.0	 30.0;
	3612	 2052	 0.001512	 0.006803	 0.0001	 4237	 4237	 4237	 0.0	 0.0	 1	 -30.0	 30.0;
	3612	 2051	 0.001512	 0.006803	 0.0001	 4237	 4237	 4237	 0.0	 0.0	 1	 -30.0	 30.0;
	5057	 2055	 0.000111	 0.001604	 0.0416	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5056	 2056	 0.000111	 0.0016	 0.0404	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5056	 2057	 0.000111	 0.0016	 0.0404	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5057	 2058	 0.000111	 0.0016	 0.0404	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5056	 2059	 0.000111	 0.001606	 0.0416	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5057	 2060	 0.000111	 0.001616	 0.0419	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 2061	 0.000756	 0.004283	 0.0002	 6969	 6969	 6969	 0.0	 0.0	 1	 -30.0	 30.0;
	2120	 2063	 0.07357	 0.199647	 0.0022	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	2728	 2063	 0.157697	 0.401864	 0.0045	 71	 71	 71	 0.0	 0.0	 1	 -30.0	 30.0;
	4690	 2063	 0.090955	 0.248425	 0.0058	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	4086	 2064	 0.014696	 0.0269	 0.0656	 935	 935	 935	 0.0	 0.0	 1	 -30.0	 30.0;
	2908	 2065	 0.000988	 0.006953	 0.0273	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3832	 2066	 0.013102	 0.089947	 0.002	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	3850	 2066	 0.016881	 0.071806	 0.001	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 2066	 0.066012	 0.21542	 0.002	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 2069	 0.001481	 0.005309	 0.0002	 5731	 5731	 5731	 0.0	 0.0	 1	 -30.0	 30.0;
	3965	 2070	 0.049635	 0.127992	 0.0014	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	4394	 2070	 0.038549	 0.100277	 0.0011	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	2119	 2071	 0.005195	 0.034528	 0.0648	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4960	 2073	 0.018025	 0.047531	 0.0049	 585	 585	 585	 0.0	 0.0	 1	 -30.0	 30.0;
	5711	 2073	 0.023457	 0.064074	 0.0029	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	4960	 2072	 0.018025	 0.047407	 0.0049	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	5254	 2075	 0.0013	 0.005888	 0.0101	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5253	 2074	 0.001306	 0.005912	 0.0101	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2272	 2076	 0.009506	 0.019136	 0.0008	 1391	 1391	 1391	 0.0	 0.0	 1	 -30.0	 30.0;
	3251	 2076	 0.010124	 0.026296	 0.0013	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	4954	 2077	 0.01321	 0.035185	 0.0018	 791	 791	 791	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 2078	 0.000953	 0.001744	 0.0	 15304	 15304	 15304	 0.0	 0.0	 1	 -30.0	 30.0;
	3041	 2079	 0.184933	 0.456034	 0.0052	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	3604	 2079	 0.031494	 0.11615	 0.0014	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	4043	 2079	 0.111363	 0.3419	 0.0039	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	4518	 2079	 0.039305	 0.161502	 0.002	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	4520	 2080	 0.002094	 0.013294	 0.0243	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2106	 2081	 0.006499	 0.043259	 0.08	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2669	 2081	 0.003737	 0.037823	 0.1088	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5283	 2081	 0.001254	 0.008365	 0.0152	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4460	 2082	 0.00247	 0.027208	 0.5747	 1168	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	4898	 2082	 0.001766	 0.019792	 0.3957	 1605	 1605	 1605	 0.0	 0.0	 1	 -30.0	 30.0;
	3612	 2083	 0.008062	 0.019904	 0.0187	 1375	 1375	 1375	 0.0	 0.0	 1	 -30.0	 30.0;
	3612	 2083	 0.007811	 0.019652	 0.0187	 1397	 1397	 1397	 0.0	 0.0	 1	 -30.0	 30.0;
	2726	 2084	 0.01679	 0.042346	 0.0021	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	2609	 2085	 0.039753	 0.106506	 0.0052	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2196	 2086	 0.014568	 0.090123	 0.0146	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	2278	 2088	 0.000401	 0.001817	 0.003	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5840	 2087	 0.0032	 0.014637	 0.0243	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2087	 1491	 2e-05	 0.000198	 0.0	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	3132	 2089	 0.036256	 0.092492	 0.0034	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	2560	 2090	 0.003401	 0.022763	 0.0415	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4985	 2090	 0.004122	 0.027542	 0.0501	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2442	 2091	 0.090955	 0.247669	 0.0069	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	5456	 2091	 0.040514	 0.110506	 0.0013	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	2479	 2094	 0.010557	 0.019325	 0.0008	 1378	 1378	 1378	 0.0	 0.0	 1	 -30.0	 30.0;
	4295	 2094	 0.004938	 0.01321	 0.0006	 2151	 2151	 2151	 0.0	 0.0	 1	 -30.0	 30.0;
	4295	 2094	 0.004938	 0.01321	 0.0006	 2151	 2151	 2151	 0.0	 0.0	 1	 -30.0	 30.0;
	4373	 2095	 0.048395	 0.119753	 0.0248	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	4373	 2095	 0.048395	 0.119753	 0.0245	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	3106	 2096	 0.006047	 0.016125	 0.0002	 1715	 1715	 1715	 0.0	 0.0	 1	 -30.0	 30.0;
	2197	 2097	 0.037289	 0.154195	 0.0019	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	3073	 2097	 0.017889	 0.045855	 0.0005	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	4691	 2097	 0.00907	 0.025951	 0.0002	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	5177	 2097	 0.011338	 0.038801	 0.0005	 731	 731	 731	 0.0	 0.0	 1	 -30.0	 30.0;
	3073	 2097	 0.019148	 0.051398	 0.0006	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	4383	 2097	 0.023432	 0.09675	 0.0012	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	5754	 2097	 0.017133	 0.071051	 0.0009	 404	 404	 404	 0.0	 0.0	 1	 -30.0	 30.0;
	4384	 2098	 0.001817	 0.008198	 0.0142	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5628	 2098	 0.001857	 0.012504	 0.0233	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2869	 2099	 0.065679	 0.209012	 0.0097	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	5614	 2099	 0.009136	 0.025556	 0.0011	 1095	 1095	 1095	 0.0	 0.0	 1	 -30.0	 30.0;
	2105	 2102	 0.007105	 0.014009	 0.0002	 1937	 1937	 1937	 0.0	 0.0	 1	 -30.0	 30.0;
	2105	 2101	 0.00325	 0.00844	 0.0001	 3363	 3363	 3363	 0.0	 0.0	 1	 -30.0	 30.0;
	2105	 2104	 0.000252	 0.001613	 0.0002	 18630	 18630	 18630	 0.0	 0.0	 1	 -30.0	 30.0;
	2105	 2103	 0.000252	 0.001663	 0.0002	 18082	 18082	 18082	 0.0	 0.0	 1	 -30.0	 30.0;
	2611	 2105	 0.094104	 0.251676	 0.0028	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	3637	 2105	 0.066868	 0.185059	 0.0047	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	4155	 2105	 0.163517	 0.334593	 0.004	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	5105	 2105	 0.069992	 0.202973	 0.002	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	5196	 2105	 0.106122	 0.297178	 0.0032	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	2610	 2106	 0.002844	 0.018884	 0.0354	 402.0	 402.0	 402.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3892	 2107	 0.079365	 0.221466	 0.0025	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	5397	 2107	 0.015293	 0.042328	 0.0005	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	2994	 2108	 0.068783	 0.261779	 0.003	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 2109	 0.075838	 0.216679	 0.0024	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	3691	 2109	 0.074074	 0.211136	 0.0024	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	5398	 2110	 0.004787	 0.033938	 0.0003	 888	 888	 888	 0.0	 0.0	 1	 -30.0	 30.0;
	3262	 2111	 0.081381	 0.225246	 0.0019	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	3006	 2112	 0.023683	 0.052406	 0.001	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	2987	 2113	 0.00025	 0.0025	 0.0	 13742	 13742	 13742	 0.0	 0.0	 1	 -30.0	 30.0;
	2456	 2115	 0.000252	 0.00252	 0.0017	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	3168	 2115	 0.0194	 0.05417	 0.0026	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	3170	 2116	 0.058453	 0.163517	 0.0018	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	3441	 2116	 0.097002	 0.267826	 0.003	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	4175	 2116	 0.040312	 0.109095	 0.0017	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	3403	 2117	 0.024691	 0.074326	 0.0009	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 2117	 0.05543	 0.140842	 0.0016	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	2760	 2118	 0.018645	 0.051146	 0.0006	 559	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	3345	 2118	 0.015369	 0.048627	 0.0721	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	3785	 2118	 0.078357	 0.161754	 0.0018	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	4051	 2118	 0.087402	 0.222525	 0.0272	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	5379	 2118	 0.016629	 0.044092	 0.0006	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	3785	 2118	 0.054926	 0.148652	 0.0017	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	5377	 2118	 0.016629	 0.044092	 0.0006	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	5372	 2120	 0.066037	 0.18002	 0.002	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	2671	 2121	 0.051272	 0.133459	 0.0015	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	3601	 2122	 0.075082	 0.193248	 0.003	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	3946	 2121	 0.065004	 0.162509	 0.002	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	4006	 2122	 0.06198	 0.178634	 0.002	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	1998	 2125	 4e-05	 0.000375	 0.0	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1998	 2124	 5.9e-05	 0.000395	 0.0	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1998	 2123	 5.9e-05	 0.000454	 0.001	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 2126	 0.010988	 0.035432	 0.001	 848	 848	 848	 0.0	 0.0	 1	 -30.0	 30.0;
	2790	 2128	 0.000494	 0.003319	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 2128	 0.00318	 0.016237	 0.0289	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5807	 2128	 0.003565	 0.013003	 0.0218	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2232	 2128	 0.001363	 0.006104	 0.0111	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2790	 2128	 0.000514	 0.003496	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2790	 2128	 0.000988	 0.004879	 0.0091	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4184	 2129	 0.001764	 0.004787	 0.0001	 5962	 5962	 5962	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 2129	 0.001512	 0.004031	 0.0001	 7065	 7065	 7065	 0.0	 0.0	 1	 -30.0	 30.0;
	2490	 2130	 0.006914	 0.021235	 0.0013	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	3218	 2130	 0.008395	 0.019753	 0.0047	 1217	 1217	 1217	 0.0	 0.0	 1	 -30.0	 30.0;
	5243	 2131	 0.008314	 0.028219	 0.0	 1004	 1004	 1004	 0.0	 0.0	 1	 -30.0	 30.0;
	5346	 2131	 0.010078	 0.054926	 0.0021	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	5513	 2131	 0.081633	 0.229277	 0.003	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	5055	 2133	 0.000356	 0.003319	 0.0121	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5054	 2134	 0.00036	 0.003356	 0.0167	 853.0	 853.0	 853.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2423	 2135	 0.003652	 0.006685	 0.0004	 3993	 3993	 3993	 0.0	 0.0	 1	 -30.0	 30.0;
	2423	 2135	 0.003652	 0.006685	 0.0004	 3993	 3993	 3993	 0.0	 0.0	 1	 -30.0	 30.0;
	1905	 2136	 0.011605	 0.06358	 0.004	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	2752	 2136	 0.000247	 0.000691	 0.0024	 41324	 41324	 41324	 0.0	 0.0	 1	 -30.0	 30.0;
	4414	 2137	 0.001086	 0.007289	 0.0132	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4823	 2137	 0.00308	 0.020628	 0.0375	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4414	 2137	 0.001067	 0.007289	 0.0132	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4823	 2137	 0.003022	 0.020109	 0.0375	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4824	 2137	 0.003022	 0.020168	 0.0435	 463.0	 463.0	 463.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3188	 2140	 0.019904	 0.051902	 0.0106	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	3537	 2141	 0.025156	 0.046047	 0.0021	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	4343	 2141	 0.003779	 0.009826	 0.0	 2805	 2805	 2805	 0.0	 0.0	 1	 -30.0	 30.0;
	5288	 2141	 0.0194	 0.103553	 0.001	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	5552	 2141	 0.008062	 0.034266	 0.0	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 2141	 0.003023	 0.009826	 0.0	 2872	 2872	 2872	 0.0	 0.0	 1	 -30.0	 30.0;
	5516	 2142	 0.001705	 0.010438	 0.0304	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4154	 2144	 0.027161	 0.070876	 0.0034	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	5730	 2144	 0.010741	 0.027531	 0.0013	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 2145	 0.000494	 0.001481	 0.0002	 19026	 19026	 19026	 0.0	 0.0	 1	 -30.0	 30.0;
	3535	 2147	 0.099017	 0.241119	 0.0037	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 2148	 0.005896	 0.030713	 0.0396	 973	 973	 973	 0.0	 0.0	 1	 -30.0	 30.0;
	3647	 2149	 0.01008	 0.018452	 0.0006	 1447	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	3535	 2150	 0.037185	 0.068066	 0.0007	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	5542	 2150	 0.080747	 0.147806	 0.0015	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	1990	 2151	 0.004031	 0.017637	 0.0243	 1682	 1682	 1682	 0.0	 0.0	 1	 -30.0	 30.0;
	1990	 2151	 0.004535	 0.018392	 0.0252	 1606	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 2154	 0.002298	 0.004207	 0.0063	 6326	 6326	 6326	 0.0	 0.0	 1	 -30.0	 30.0;
	5306	 2155	 0.000123	 0.001235	 0.0047	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	4823	 2156	 0.001106	 0.007546	 0.0354	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2098	 2157	 0.000158	 0.001343	 0.5594	 654.0	 654.0	 654.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2062	 2159	 0.015148	 0.064062	 0.0037	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	3201	 2159	 0.009383	 0.040123	 0.0005	 779	 779	 779	 0.0	 0.0	 1	 -30.0	 30.0;
	4747	 2159	 0.001111	 0.007284	 0.0013	 4374	 4374	 4374	 0.0	 0.0	 1	 -30.0	 30.0;
	5260	 2159	 0.010617	 0.043704	 0.0016	 769	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	4746	 2159	 0.001235	 0.00642	 0.0013	 4930	 4930	 4930	 0.0	 0.0	 1	 -30.0	 30.0;
	2227	 2160	 0.002264	 0.015056	 0.0273	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3699	 2160	 0.002173	 0.014617	 0.0263	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3918	 2160	 0.000375	 0.002509	 0.004	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5055	 2160	 0.001746	 0.011648	 0.0216	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5066	 2160	 0.000909	 0.00478	 0.0086	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5312	 2160	 0.001936	 0.011239	 0.0203	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5054	 2160	 0.001738	 0.011635	 0.0213	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5065	 2160	 0.000751	 0.004148	 0.0101	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5054	 2160	 0.001679	 0.01122	 0.0203	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 2164	 0.024188	 0.066213	 0.0007	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	2773	 2165	 0.120862	 0.306551	 0.0035	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	4425	 2165	 0.05291	 0.134291	 0.0015	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	3403	 2166	 0.031922	 0.135097	 0.0017	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 2167	 0.040564	 0.153187	 0.0018	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	3867	 2167	 0.06198	 0.158982	 0.0018	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	3403	 2166	 0.031973	 0.135299	 0.0017	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 2167	 0.040564	 0.146888	 0.0018	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 2170	 0.008889	 0.092593	 0.0151	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 2170	 0.008889	 0.092469	 0.0144	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	2216	 2172	 0.005693	 0.01042	 0.0044	 2562	 2562	 2562	 0.0	 0.0	 1	 -30.0	 30.0;
	2216	 2171	 0.005693	 0.01042	 0.0044	 2562	 2562	 2562	 0.0	 0.0	 1	 -30.0	 30.0;
	2675	 2173	 0.000381	 0.000697	 0.0486	 38967	 38967	 38967	 0.0	 0.0	 1	 -30.0	 30.0;
	4009	 2174	 0.007307	 0.017133	 0.0191	 1633	 1633	 1633	 0.0	 0.0	 1	 -30.0	 30.0;
	2874	 2175	 0.000756	 0.00252	 0.0001	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	3868	 2175	 0.094986	 0.240867	 0.0032	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	2181	 2178	 0.000252	 0.00252	 0.0011	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	2288	 2178	 0.000756	 0.002016	 0.0023	 13307	 13307	 13307	 0.0	 0.0	 1	 -30.0	 30.0;
	3090	 2178	 0.007559	 0.015369	 0.0126	 1673	 1673	 1673	 0.0	 0.0	 1	 -30.0	 30.0;
	3289	 2178	 0.009964	 0.01824	 0.0118	 1379	 1379	 1379	 0.0	 0.0	 1	 -30.0	 30.0;
	3700	 2178	 0.002217	 0.004059	 0.0026	 6195	 6195	 6195	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 2178	 0.008296	 0.015186	 0.0096	 1656	 1656	 1656	 0.0	 0.0	 1	 -30.0	 30.0;
	2181	 2178	 0.000252	 0.00252	 0.0011	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 2178	 0.006551	 0.01285	 0.0112	 1987	 1987	 1987	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 2178	 0.004283	 0.01033	 0.0111	 2563	 2563	 2563	 0.0	 0.0	 1	 -30.0	 30.0;
	2319	 2179	 0.000158	 0.000593	 0.0688	 50437	 50437	 50437	 0.0	 0.0	 1	 -30.0	 30.0;
	2844	 2179	 0.000336	 0.001304	 0.162	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2999	 2179	 4e-05	 0.000237	 0.0334	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3954	 2179	 0.000296	 0.002667	 0.1863	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2318	 2179	 0.000362	 0.000664	 0.0466	 40928	 40928	 40928	 0.0	 0.0	 1	 -30.0	 30.0;
	3955	 2179	 0.000435	 0.001659	 0.3351	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5404	 2180	 0.017284	 0.06321	 0.0232	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	5405	 2182	 0.007055	 0.022676	 0.0002	 1226	 1226	 1226	 0.0	 0.0	 1	 -30.0	 30.0;
	3915	 2183	 0.083648	 0.211892	 0.0024	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	5422	 2185	 0.000123	 0.001235	 0.0002	 27888	 27888	 27888	 0.0	 0.0	 1	 -30.0	 30.0;
	5406	 2186	 0.000988	 0.002469	 0.0	 9817	 9817	 9817	 0.0	 0.0	 1	 -30.0	 30.0;
	2796	 2189	 0.001975	 0.004938	 0.0	 5585	 5585	 5585	 0.0	 0.0	 1	 -30.0	 30.0;
	2192	 2190	 2e-05	 0.000198	 0.0233	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3667	 2190	 0.000237	 0.002272	 0.0081	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3667	 2190	 0.000257	 0.002449	 0.0081	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2193	 2190	 2e-05	 0.000198	 0.0132	 870.0	 870.0	 870.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2194	 2191	 1e-05	 0.0001	 0.0462	 895.0	 895.0	 895.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3899	 2191	 0.001143	 0.011399	 0.2946	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3899	 2191	 0.001087	 0.012375	 0.2513	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3804	 2195	 0.043336	 0.109095	 0.0015	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	4923	 2195	 0.028471	 0.078861	 0.0264	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	5754	 2197	 0.019904	 0.082892	 0.001	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	2981	 2198	 0.010582	 0.026455	 0.0003	 1037	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	3131	 2199	 0.000879	 0.0037	 0.085	 8140	 8140	 8140	 0.0	 0.0	 1	 -30.0	 30.0;
	5407	 2199	 0.000533	 0.003556	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3130	 2199	 0.000869	 0.003437	 0.0851	 8731	 8731	 8731	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 2200	 0.031746	 0.082389	 0.001	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	3126	 2203	 0.004444	 0.028148	 0.0211	 1109	 1109	 1109	 0.0	 0.0	 1	 -30.0	 30.0;
	5410	 2204	 0.073066	 0.199043	 0.0022	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 2205	 0.02066	 0.056185	 0.0006	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	2494	 2206	 0.082892	 0.15999	 0.0017	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	2864	 2208	 0.047115	 0.08642	 0.0017	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	5168	 2208	 0.021164	 0.132275	 0.0017	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	5172	 2208	 0.036281	 0.13681	 0.0017	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	5414	 2210	 0.000316	 0.002153	 0.004	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5412	 2209	 0.000316	 0.002153	 0.004	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4800	 2213	 0.056941	 0.156211	 0.0073	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	5415	 2213	 0.078861	 0.176619	 0.0019	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	2573	 2215	 4e-05	 0.000237	 0.0	 483.0	 483.0	 483.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2834	 2216	 0.002897	 0.014412	 0.0002	 2069	 2069	 2069	 0.0	 0.0	 1	 -30.0	 30.0;
	2460	 2218	 0.000852	 0.008636	 0.2224	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 2218	 0.001288	 0.013033	 0.335	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2219	 1493	 0.000595	 0.001089	 0.0	 25273	 25273	 25273	 0.0	 0.0	 1	 -30.0	 30.0;
	4156	 2219	 0.032099	 0.135679	 0.007	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	5416	 2219	 0.000988	 0.003951	 0.0002	 8499	 8499	 8499	 0.0	 0.0	 1	 -30.0	 30.0;
	5417	 2220	 0.002872	 0.01227	 0.0183	 2414	 2414	 2414	 0.0	 0.0	 1	 -30.0	 30.0;
	5052	 2221	 0.026959	 0.073318	 0.0009	 390	 390	 390	 0.0	 0.0	 1	 -30.0	 30.0;
	5418	 2222	 2e-05	 0.000198	 0.001	 393.0	 393.0	 393.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2492	 2224	 0.06324	 0.176367	 0.002	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	2514	 2224	 0.024943	 0.07735	 0.001	 375	 375	 375	 0.0	 0.0	 1	 -30.0	 30.0;
	3755	 2225	 0.014412	 0.039305	 0.0415	 727	 727	 727	 0.0	 0.0	 1	 -30.0	 30.0;
	3755	 2225	 0.01421	 0.039405	 0.0442	 727	 727	 727	 0.0	 0.0	 1	 -30.0	 30.0;
	2985	 2226	 0.033827	 0.086667	 0.0006	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	3827	 2226	 0.017407	 0.111728	 0.0013	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5058	 2226	 0.020148	 0.125259	 0.0092	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 2226	 0.035926	 0.102716	 0.0011	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	2577	 2227	 0.001541	 0.010291	 0.0238	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 2227	 0.000178	 0.001225	 0.002	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5055	 2227	 0.002489	 0.016612	 0.0304	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5840	 2227	 0.002805	 0.01282	 0.0223	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2577	 2227	 0.001541	 0.010252	 0.0192	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5686	 2227	 0.000158	 0.001106	 0.002	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3755	 2228	 0.022928	 0.058881	 0.0013	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	2789	 2230	 0.007284	 0.044321	 0.0059	 718	 718	 718	 0.0	 0.0	 1	 -30.0	 30.0;
	3513	 2230	 0.010124	 0.058519	 0.05	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	2789	 2230	 0.00716	 0.044198	 0.0059	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	4006	 2231	 0.02192	 0.049131	 0.001	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 2232	 0.00243	 0.01357	 0.0248	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 2233	 0.061365	 0.112327	 0.001	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 2233	 0.062911	 0.115158	 0.001	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	2851	 2233	 0.019652	 0.054296	 0.0006	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	5518	 2235	 0.001402	 0.005452	 0.0101	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4018	 2236	 0.012346	 0.057949	 0.1202	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	3319	 2237	 0.011852	 0.031358	 0.0015	 887	 887	 887	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 2237	 0.006889	 0.020272	 0.001	 1388	 1388	 1388	 0.0	 0.0	 1	 -30.0	 30.0;
	2561	 2239	 0.00214	 0.024723	 0.5545	 1286	 1286	 1286	 0.0	 0.0	 1	 -30.0	 30.0;
	3146	 2239	 0.00338	 0.034294	 0.8866	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	3223	 2239	 0.000229	 0.002465	 0.0549	 1487.0	 1487.0	 1487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4913	 2239	 0.000561	 0.006198	 0.1473	 1731.0	 1731.0	 1731.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3147	 2239	 0.00338	 0.034294	 0.8866	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	5325	 2241	 0.005533	 0.010128	 0.0	 2636	 2636	 2636	 0.0	 0.0	 1	 -30.0	 30.0;
	2774	 2242	 0.008535	 0.038929	 0.0678	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2894	 2242	 0.001106	 0.005136	 0.0081	 5892	 5892	 5892	 0.0	 0.0	 1	 -30.0	 30.0;
	2388	 2243	 0.099521	 0.25296	 0.0029	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	4641	 2244	 0.031111	 0.078642	 0.0067	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	4763	 2244	 0.038272	 0.101975	 0.0044	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	5417	 2245	 5e-05	 0.000227	 0.0002	 130845	 130845	 130845	 0.0	 0.0	 1	 -30.0	 30.0;
	2478	 2247	 0.042832	 0.179894	 0.0022	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	3606	 2249	 0.003081	 0.020109	 0.0375	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5465	 2249	 0.000533	 0.003536	 0.0061	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3889	 2250	 0.007559	 0.0194	 0.0002	 1461	 1461	 1461	 0.0	 0.0	 1	 -30.0	 30.0;
	4824	 2252	 0.001067	 0.004306	 0.08	 7026	 7026	 7026	 0.0	 0.0	 1	 -30.0	 30.0;
	4823	 2251	 0.001067	 0.004306	 0.08	 7033	 7033	 7033	 0.0	 0.0	 1	 -30.0	 30.0;
	5419	 2253	 0.004059	 0.007429	 0.0057	 3593	 3593	 3593	 0.0	 0.0	 1	 -30.0	 30.0;
	2265	 2255	 0.004662	 0.008534	 0.0039	 3315	 3315	 3315	 0.0	 0.0	 1	 -30.0	 30.0;
	2611	 2256	 0.066566	 0.17284	 0.0022	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	5105	 2256	 0.090249	 0.228773	 0.0026	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5638	 2257	 0.006444	 0.012667	 0.0036	 2205	 2205	 2205	 0.0	 0.0	 1	 -30.0	 30.0;
	2610	 2258	 0.001936	 0.01284	 0.0243	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5283	 2258	 0.001363	 0.015427	 0.0445	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4643	 2259	 0.047901	 0.15	 0.007	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	5603	 2259	 0.014284	 0.08858	 0.0049	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	4408	 2259	 0.001926	 0.018247	 0.1021	 1653	 1653	 1653	 0.0	 0.0	 1	 -30.0	 30.0;
	5259	 2259	 0.005037	 0.03142	 0.0017	 953	 953	 953	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 2262	 0.012346	 0.051146	 0.0006	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	5420	 2263	 0.000233	 0.00156	 0.003	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3140	 2264	 0.017989	 0.07546	 0.0069	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	2201	 2265	 0.007901	 0.039506	 0.0032	 797	 797	 797	 0.0	 0.0	 1	 -30.0	 30.0;
	2177	 2266	 0.000691	 0.003852	 0.0071	 320.0	 320.0	 320.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2199	 2266	 0.000454	 0.003121	 0.0061	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5062	 2266	 0.001896	 0.011022	 0.0284	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2176	 2266	 0.000514	 0.002331	 0.0116	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2199	 2266	 0.000474	 0.003101	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5061	 2266	 0.002272	 0.011062	 0.0263	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4481	 2267	 0.016982	 0.096271	 0.001	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	5422	 2268	 0.000123	 0.001235	 0.0002	 27888	 27888	 27888	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 2269	 0.009423	 0.017248	 0.0002	 1548	 1548	 1548	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 2269	 0.009423	 0.017248	 0.0002	 1548	 1548	 1548	 0.0	 0.0	 1	 -30.0	 30.0;
	3403	 2273	 0.05506	 0.100786	 0.001	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	3559	 2274	 0.044092	 0.119929	 0.0015	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	3236	 2276	 5.9e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4699	 2276	 5.9e-05	 0.001126	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4698	 2275	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5679	 2277	 0.028471	 0.072562	 0.0008	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	4004	 2279	 0.038395	 0.099136	 0.0047	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	4587	 2279	 0.034444	 0.110123	 0.008	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 2281	 0.01159	 0.031998	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	4777	 2282	 0.068783	 0.23356	 0.0027	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	3793	 2282	 0.032754	 0.111363	 0.0013	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	4854	 2283	 0.00081	 0.008193	 0.2108	 1694.0	 1694.0	 1694.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 2284	 0.011482	 0.031111	 0.0015	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	3219	 2284	 0.037407	 0.100864	 0.0047	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	2819	 2285	 0.000756	 0.002016	 0.0	 13714	 13714	 13714	 0.0	 0.0	 1	 -30.0	 30.0;
	3407	 2285	 0.02287	 0.041864	 0.0004	 619	 619	 619	 0.0	 0.0	 1	 -30.0	 30.0;
	4562	 2285	 0.089947	 0.230537	 0.003	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	5607	 2285	 0.196901	 0.539708	 0.006	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	2533	 2286	 0.002528	 0.016731	 0.0304	 469.0	 469.0	 469.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2820	 2286	 4.8e-05	 8.8e-05	 0.0051	 308785	 308785	 308785	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 2286	 0.008988	 0.060563	 0.1043	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5424	 2287	 0.001008	 0.002016	 0.0	 12712	 12712	 12712	 0.0	 0.0	 1	 -30.0	 30.0;
	3285	 2291	 0.058176	 0.132376	 0.0043	 208	 208	 208	 0.0	 0.0	 1	 -30.0	 30.0;
	5736	 2293	 0.073822	 0.164928	 0.0026	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	5820	 2293	 0.00252	 0.007055	 0.0001	 4060	 4060	 4060	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 2294	 0.065256	 0.259259	 0.0031	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	3301	 2295	 0.085132	 0.155833	 0.0058	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	4083	 2295	 0.067432	 0.123433	 0.0032	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	5291	 2296	 0.038284	 0.070078	 0.0007	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	2724	 2297	 0.013333	 0.026667	 0.0012	 997	 997	 997	 0.0	 0.0	 1	 -30.0	 30.0;
	2336	 2299	 0.018148	 0.036296	 0.0016	 732	 732	 732	 0.0	 0.0	 1	 -30.0	 30.0;
	3860	 2299	 0.018148	 0.036296	 0.0016	 732	 732	 732	 0.0	 0.0	 1	 -30.0	 30.0;
	5613	 2299	 0.082222	 0.183951	 0.0084	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	2485	 2301	 0.009574	 0.018896	 0.0254	 1436	 1436	 1436	 0.0	 0.0	 1	 -30.0	 30.0;
	3097	 2301	 0.005442	 0.014386	 0.0163	 1978	 1978	 1978	 0.0	 0.0	 1	 -30.0	 30.0;
	3849	 2301	 0.013855	 0.025362	 0.0002	 1053	 1053	 1053	 0.0	 0.0	 1	 -30.0	 30.0;
	5052	 2301	 0.097178	 0.252708	 0.0075	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	5606	 2301	 0.007256	 0.030637	 0.0008	 966	 966	 966	 0.0	 0.0	 1	 -30.0	 30.0;
	3849	 2301	 0.014556	 0.026645	 0.0002	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	5605	 2301	 0.007307	 0.030738	 0.0009	 963	 963	 963	 0.0	 0.0	 1	 -30.0	 30.0;
	3394	 2301	 0.005795	 0.018392	 0.0009	 1578	 1578	 1578	 0.0	 0.0	 1	 -30.0	 30.0;
	2628	 2302	 0.002193	 0.014716	 0.0263	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3272	 2302	 0.001323	 0.00883	 0.0162	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2280	 2303	 0.039557	 0.087679	 0.001	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	4759	 2303	 0.04258	 0.09423	 0.001	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 2305	 0.013102	 0.035525	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	3848	 2306	 0.001481	 0.007072	 0.0121	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4141	 2306	 0.001956	 0.013136	 0.0243	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2914	 2307	 0.067523	 0.184429	 0.0021	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	4083	 2307	 0.073056	 0.133728	 0.0043	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 2307	 0.065508	 0.271101	 0.0034	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 2307	 0.065508	 0.271101	 0.0034	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	2510	 2308	 0.011	 0.056595	 0.1027	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 2309	 0.038574	 0.10199	 0.0201	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	3211	 2310	 0.010222	 0.025914	 0.0013	 1067	 1067	 1067	 0.0	 0.0	 1	 -30.0	 30.0;
	4119	 2311	 0.005795	 0.014361	 0.0135	 1907	 1907	 1907	 0.0	 0.0	 1	 -30.0	 30.0;
	4511	 2311	 0.006551	 0.016125	 0.0152	 1697	 1697	 1697	 0.0	 0.0	 1	 -30.0	 30.0;
	3640	 2312	 0.02066	 0.052154	 0.0006	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 2313	 0.012716	 0.052469	 0.0026	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 2314	 0.026984	 0.068808	 0.0022	 412	 412	 412	 0.0	 0.0	 1	 -30.0	 30.0;
	3072	 2317	 0.002383	 0.006457	 0.0003	 4316	 4316	 4316	 0.0	 0.0	 1	 -30.0	 30.0;
	4380	 2320	 0.028219	 0.194004	 0.0023	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	5384	 2321	 0.000691	 0.004563	 0.0081	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3076	 2323	 0.084656	 0.181406	 0.002	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	5430	 2324	 0.007332	 0.024842	 0.0003	 1107	 1107	 1107	 0.0	 0.0	 1	 -30.0	 30.0;
	3188	 2327	 0.07609	 0.171076	 0.0187	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 2327	 0.036533	 0.093726	 0.001	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	3408	 2328	 0.069035	 0.175359	 0.002	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 2328	 0.019501	 0.079516	 0.0085	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	4694	 2328	 0.095742	 0.282691	 0.0062	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	5562	 2328	 0.013605	 0.037541	 0.0019	 740	 740	 740	 0.0	 0.0	 1	 -30.0	 30.0;
	3408	 2327	 0.066264	 0.168304	 0.0019	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	4607	 2327	 0.019652	 0.080625	 0.0102	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	4243	 2329	 0.002449	 0.016336	 0.0354	 479.0	 479.0	 479.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5431	 2329	 0.006461	 0.021728	 0.0385	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4243	 2329	 0.002568	 0.017146	 0.0405	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4569	 2330	 0.000457	 0.005035	 0.1458	 1841.0	 1841.0	 1841.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3056	 2331	 0.059753	 0.161605	 0.0077	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3462	 2331	 0.041728	 0.105802	 0.005	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2850	 2332	 0.110355	 0.310658	 0.0037	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	2420	 2333	 0.004283	 0.008566	 0.0001	 3176	 3176	 3176	 0.0	 0.0	 1	 -30.0	 30.0;
	2880	 2334	 0.029479	 0.121945	 0.0015	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	4434	 2334	 0.076594	 0.160242	 0.0019	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	2880	 2334	 0.02973	 0.124717	 0.0016	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	5810	 2335	 0.04258	 0.079617	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	3346	 2337	 0.015243	 0.050617	 0.0006	 559	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	4198	 2337	 0.055984	 0.153691	 0.0018	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4308	 2338	 0.017561	 0.045906	 0.0035	 601	 601	 601	 0.0	 0.0	 1	 -30.0	 30.0;
	5092	 2338	 0.011842	 0.029982	 0.0	 916	 916	 916	 0.0	 0.0	 1	 -30.0	 30.0;
	2873	 2339	 0.003	 0.013517	 0.0243	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5432	 2339	 0.003812	 0.013017	 0.0213	 2283	 2283	 2283	 0.0	 0.0	 1	 -30.0	 30.0;
	2563	 2341	 0.020161	 0.05458	 0.0192	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	2969	 2341	 0.012963	 0.036667	 0.0084	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	4289	 2341	 0.015556	 0.039877	 0.007	 709	 709	 709	 0.0	 0.0	 1	 -30.0	 30.0;
	2563	 2341	 0.020123	 0.054444	 0.0187	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	4290	 2341	 0.015383	 0.039642	 0.007	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	4614	 2342	 0.043333	 0.109877	 0.0079	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	2563	 2341	 0.020247	 0.054568	 0.019	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	4009	 2346	 0.006223	 0.016956	 0.0002	 1684	 1684	 1684	 0.0	 0.0	 1	 -30.0	 30.0;
	2807	 2347	 0.014568	 0.046543	 0.0023	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	4340	 2347	 0.079753	 0.250247	 0.0123	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	3552	 2349	 0.085412	 0.289746	 0.0034	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	5752	 2350	 0.048518	 0.128025	 0.006	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 2351	 0.004283	 0.008314	 0.0117	 3252	 3252	 3252	 0.0	 0.0	 1	 -30.0	 30.0;
	5187	 2352	 0.010617	 0.028518	 0.0013	 977	 977	 977	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 2354	 0.035525	 0.123457	 0.0069	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	5434	 2355	 0.000123	 0.001235	 0.0002	 23932	 23932	 23932	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 2356	 0.097758	 0.229025	 0.0025	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	2369	 2367	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2369	 2366	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2369	 2365	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2369	 2364	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2369	 2363	 2e-06	 0.001244	 0.0	 24882	 24882	 24882	 0.0	 0.0	 1	 -30.0	 30.0;
	2369	 2362	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2627	 2368	 0.081381	 0.248173	 0.0031	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	3887	 2368	 0.003779	 0.012346	 0.0161	 2356	 2356	 2356	 0.0	 0.0	 1	 -30.0	 30.0;
	5417	 2368	 0.016881	 0.062963	 0.0177	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3887	 2368	 0.010078	 0.040514	 0.0022	 729	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	3272	 2369	 0.002449	 0.011141	 0.0203	 293.0	 293.0	 293.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4125	 2369	 0.000672	 0.003141	 0.0051	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 2370	 0.01285	 0.027463	 0.0004	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	2751	 2371	 0.034014	 0.08642	 0.0017	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	4009	 2371	 0.033006	 0.107836	 0.0204	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	3106	 2373	 0.056412	 0.18453	 0.0021	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	3544	 2373	 0.012195	 0.032225	 0.0364	 857	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	3705	 2373	 0.105518	 0.344898	 0.0039	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	5437	 2374	 0.053414	 0.145629	 0.0017	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	3690	 2374	 0.048627	 0.130511	 0.0068	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5336	 2375	 0.001008	 0.00252	 0.001	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 2377	 0.03351	 0.142857	 0.0043	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	2504	 2378	 0.039078	 0.106576	 0.0012	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	2584	 2379	 0.006299	 0.01159	 0.0125	 2239	 2239	 2239	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 2379	 0.038045	 0.104812	 0.0198	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	4895	 2380	 0.108163	 0.234492	 0.0027	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	3296	 2381	 0.001008	 0.002771	 0.0001	 10014	 10014	 10014	 0.0	 0.0	 1	 -30.0	 30.0;
	4983	 2382	 0.02318	 0.060972	 0.0007	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 2383	 0.011386	 0.020842	 0.0153	 1281	 1281	 1281	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 2383	 0.033485	 0.091333	 0.001	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	2385	 2384	 0.000454	 0.001209	 0.0	 23551	 23551	 23551	 0.0	 0.0	 1	 -30.0	 30.0;
	5462	 2384	 0.070043	 0.23356	 0.0025	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	2902	 2385	 0.102797	 0.260771	 0.0029	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	3324	 2385	 0.078861	 0.267826	 0.0031	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	5537	 2385	 0.053918	 0.183422	 0.0021	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	2902	 2385	 0.103049	 0.261275	 0.0029	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	5538	 2385	 0.054926	 0.185941	 0.0021	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2817	 2386	 0.057697	 0.12522	 0.0002	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	4918	 2387	 0.058453	 0.120433	 0.0013	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	2494	 2388	 0.07609	 0.241875	 0.0029	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	2636	 2389	 0.098765	 0.239607	 0.0026	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	2772	 2390	 0.015672	 0.037591	 0.0066	 747	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	2772	 2390	 0.015672	 0.037591	 0.0066	 747	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	3318	 2392	 0.000252	 0.00126	 0.0	 23670	 23670	 23670	 0.0	 0.0	 1	 -30.0	 30.0;
	3842	 2392	 0.024439	 0.084656	 0.0	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	5447	 2393	 0.000296	 0.000751	 0.001	 38032	 38032	 38032	 0.0	 0.0	 1	 -30.0	 30.0;
	3005	 2394	 0.008314	 0.024691	 0.0305	 1168	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 2394	 0.01033	 0.044848	 0.0	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	3713	 2394	 0.003145	 0.005757	 0.0079	 4637	 4637	 4637	 0.0	 0.0	 1	 -30.0	 30.0;
	5642	 2394	 0.005039	 0.021416	 0.0002	 1383	 1383	 1383	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 2394	 0.011363	 0.047241	 0.0047	 626	 626	 626	 0.0	 0.0	 1	 -30.0	 30.0;
	4697	 2396	 5.9e-05	 0.000198	 0.0091	 148594	 148594	 148594	 0.0	 0.0	 1	 -30.0	 30.0;
	4697	 2395	 4e-05	 0.000198	 0.0051	 151981	 151981	 151981	 0.0	 0.0	 1	 -30.0	 30.0;
	5448	 2397	 0.069892	 0.190653	 0.0021	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	2461	 2398	 0.025556	 0.064691	 0.0032	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	2975	 2398	 0.041543	 0.107901	 0.0316	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	5727	 2399	 0.02318	 0.06324	 0.0007	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 2400	 0.018645	 0.078357	 0.001	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	2405	 2401	 0.000123	 0.00037	 0.0	 77773	 77773	 77773	 0.0	 0.0	 1	 -30.0	 30.0;
	4536	 2401	 0.014198	 0.037654	 0.0019	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	3209	 2402	 0.003779	 0.007559	 0.0052	 3391	 3391	 3391	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 2404	 0.113379	 0.252457	 0.003	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	3922	 2406	 0.044848	 0.131519	 0.0015	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	5758	 2407	 0.036029	 0.081381	 0.0009	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	4831	 2408	 0.005432	 0.014321	 0.0006	 2105	 2105	 2105	 0.0	 0.0	 1	 -30.0	 30.0;
	5655	 2408	 0.004815	 0.012222	 0.0006	 2632	 2632	 2632	 0.0	 0.0	 1	 -30.0	 30.0;
	3156	 2409	 8e-05	 0.000147	 0.0091	 185438	 185438	 185438	 0.0	 0.0	 1	 -30.0	 30.0;
	3156	 2410	 8.7e-05	 0.00016	 0.0091	 170405	 170405	 170405	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 2411	 0.014941	 0.041572	 0.0005	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	5454	 2412	 0.00019	 0.00062	 0.001	 48031	 48031	 48031	 0.0	 0.0	 1	 -30.0	 30.0;
	4209	 2414	 0.085916	 0.238095	 0.0037	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	4209	 2414	 0.091207	 0.235828	 0.0041	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 2415	 0.00284	 0.005802	 0.0003	 4620	 4620	 4620	 0.0	 0.0	 1	 -30.0	 30.0;
	2419	 2416	 0.045603	 0.183422	 0.0021	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2504	 2416	 0.053918	 0.137062	 0.0016	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	3362	 2416	 0.004031	 0.011086	 0.0002	 2503	 2503	 2503	 0.0	 0.0	 1	 -30.0	 30.0;
	3438	 2416	 0.05291	 0.143109	 0.0016	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	5764	 2416	 0.026203	 0.067523	 0.0007	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	2504	 2416	 0.051146	 0.139582	 0.0016	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	2588	 2418	 0.003062	 0.020365	 0.0375	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2777	 2418	 0.000435	 0.002607	 0.0051	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2777	 2417	 0.000494	 0.002923	 0.0051	 463.0	 463.0	 463.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 2419	 0.057697	 0.147392	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	3001	 2420	 0.047921	 0.111968	 0.0059	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	3074	 2420	 0.100781	 0.231293	 0.0058	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	4712	 2420	 0.038297	 0.097002	 0.0011	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	4851	 2420	 0.190843	 0.349335	 0.0091	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 2421	 0.00239	 0.015842	 0.0284	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3075	 2421	 0.002765	 0.018548	 0.0344	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4468	 2421	 0.005539	 0.038098	 0.0719	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4902	 2421	 0.005116	 0.034252	 0.0628	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5420	 2421	 0.004306	 0.019919	 0.0354	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2423	 2422	 0.027967	 0.075435	 0.0039	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	4244	 2424	 0.016881	 0.043084	 0.0054	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	4734	 2424	 0.004913	 0.025044	 0.0229	 1192	 1192	 1192	 0.0	 0.0	 1	 -30.0	 30.0;
	5307	 2423	 0.023432	 0.09801	 0.0054	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	5453	 2424	 0.027463	 0.074326	 0.0009	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 2423	 0.016125	 0.052658	 0.0012	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 2423	 0.016629	 0.057445	 0.0013	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	5526	 2423	 0.012673	 0.053792	 0.0037	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	4244	 2424	 0.021466	 0.053616	 0.0102	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	4734	 2424	 0.005367	 0.025724	 0.0279	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	4244	 2424	 0.023961	 0.054497	 0.0097	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	4484	 2425	 0.007802	 0.036069	 0.0633	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5486	 2425	 0.000257	 0.00164	 0.003	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5702	 2425	 0.005077	 0.023921	 0.0425	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4385	 2426	 0.066767	 0.182162	 0.0021	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	4675	 2426	 0.074326	 0.20131	 0.0023	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	3896	 2427	 0.096498	 0.218443	 0.0024	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5439	 2427	 0.043336	 0.179138	 0.0022	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	5706	 2427	 0.036785	 0.151927	 0.0019	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	2959	 2429	 0.000514	 0.0048	 0.0172	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 2428	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3306	 2430	 0.097279	 0.215092	 0.0025	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	5565	 2430	 0.01326	 0.024272	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	4910	 2432	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	4910	 2431	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	3501	 2433	 0.103301	 0.230033	 0.003	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	5696	 2433	 0.040816	 0.090955	 0.001	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	3785	 2434	 0.089695	 0.185185	 0.002	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	4018	 2434	 0.078055	 0.318443	 0.0378	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	4354	 2434	 0.030206	 0.055292	 0.0006	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	5227	 2434	 0.043059	 0.174679	 0.0345	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	5751	 2434	 0.000252	 0.00252	 0.0007	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5456	 2436	 0.023935	 0.065508	 0.0007	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	2587	 2437	 0.055178	 0.140086	 0.0016	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	2587	 2438	 0.050643	 0.139834	 0.0016	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	4770	 2439	 0.087176	 0.292265	 0.0013	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	5554	 2439	 0.057949	 0.156966	 0.0018	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	5143	 2439	 0.067271	 0.207861	 0.0023	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5126	 2439	 0.014412	 0.037516	 0.0007	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	5123	 2439	 0.013102	 0.035903	 0.0007	 796	 796	 796	 0.0	 0.0	 1	 -30.0	 30.0;
	5536	 2440	 0.010533	 0.0368	 0.0121	 826	 826	 826	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 2441	 0.011206	 0.050285	 0.0899	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3892	 2442	 0.013857	 0.038045	 0.0004	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	3892	 2442	 0.014361	 0.04006	 0.0005	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	2937	 2443	 0.023951	 0.060741	 0.0029	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 2445	 0.000176	 0.000504	 0.0	 56971	 56971	 56971	 0.0	 0.0	 1	 -30.0	 30.0;
	3413	 2446	 0.048123	 0.193752	 0.0027	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	2559	 2449	 0.061225	 0.151675	 0.0027	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4369	 2449	 0.064374	 0.150894	 0.0034	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	2555	 2450	 0.062716	 0.162222	 0.0075	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	3085	 2450	 0.070988	 0.180741	 0.0086	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	4153	 2450	 0.020617	 0.056543	 0.0028	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	4206	 2450	 0.00216	 0.013605	 0.0006	 2157	 2157	 2157	 0.0	 0.0	 1	 -30.0	 30.0;
	5434	 2450	 0.01716	 0.052839	 0.0026	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	5670	 2450	 0.019012	 0.048642	 0.0023	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	4205	 2450	 0.002148	 0.013568	 0.0006	 2163	 2163	 2163	 0.0	 0.0	 1	 -30.0	 30.0;
	4649	 2452	 0.071816	 0.131457	 0.0011	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 2452	 0.006047	 0.011842	 0.0001	 2288	 2288	 2288	 0.0	 0.0	 1	 -30.0	 30.0;
	5457	 2453	 2e-05	 0.000198	 0.001	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3331	 2455	 0.060469	 0.156715	 0.0017	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	3168	 2456	 0.019652	 0.050894	 0.0006	 531	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	3642	 2457	 0.032185	 0.086951	 0.141	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	5032	 2457	 0.042086	 0.112951	 0.0054	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 2459	 0.001975	 0.013235	 0.0309	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3917	 2459	 0.001284	 0.00879	 0.0162	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 2460	 0.002119	 0.02151	 0.5545	 1476	 1476	 1476	 0.0	 0.0	 1	 -30.0	 30.0;
	4232	 2461	 0.062716	 0.114815	 0.004	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	4887	 2461	 0.005556	 0.013827	 0.0006	 2035	 2035	 2035	 0.0	 0.0	 1	 -30.0	 30.0;
	5449	 2461	 0.021605	 0.092222	 0.0045	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	3729	 2462	 0.011536	 0.054933	 0.0931	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4565	 2463	 0.001136	 0.014935	 0.5198	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	4565	 2463	 0.001136	 0.014935	 0.517	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	2899	 2464	 0.078105	 0.191232	 0.0021	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	4448	 2464	 0.046988	 0.086012	 0.0032	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	4652	 2464	 0.030234	 0.073822	 0.0009	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	2827	 2465	 0.027211	 0.070547	 0.0008	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	3627	 2465	 0.028723	 0.073066	 0.0046	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	2482	 2467	 0.002771	 0.007811	 0.0001	 3563	 3563	 3563	 0.0	 0.0	 1	 -30.0	 30.0;
	2482	 2466	 0.003527	 0.010078	 0.0001	 2766	 2766	 2766	 0.0	 0.0	 1	 -30.0	 30.0;
	4561	 2468	 0.049131	 0.140338	 0.0017	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	4080	 2469	 0.023029	 0.09743	 0.0012	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	3844	 2470	 0.000604	 0.001106	 0.0007	 23430	 23430	 23430	 0.0	 0.0	 1	 -30.0	 30.0;
	4859	 2470	 0.03225	 0.070043	 0.0	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 2471	 0.152734	 0.410481	 0.0048	 70	 70	 70	 0.0	 0.0	 1	 -30.0	 30.0;
	5181	 2472	 0.000504	 0.00126	 0.0	 22412	 22412	 22412	 0.0	 0.0	 1	 -30.0	 30.0;
	3734	 2473	 0.009322	 0.017133	 0.0012	 1514	 1514	 1514	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 2475	 0.053086	 0.158148	 0.0076	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	4259	 2475	 0.044691	 0.113457	 0.0053	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	4606	 2475	 0.004802	 0.013457	 0.0483	 2079	 2079	 2079	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 2476	 0.024074	 0.061235	 0.0029	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	5184	 2477	 0.003996	 0.027473	 0.0516	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 2477	 0.007111	 0.048909	 0.0921	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2721	 2479	 0.065524	 0.119941	 0.0052	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3490	 2480	 0.06324	 0.16906	 0.0019	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	4749	 2481	 0.15092	 0.310229	 0.0036	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	5515	 2481	 0.094558	 0.194381	 0.0024	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	2827	 2482	 0.014361	 0.088939	 0.0012	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	3026	 2482	 0.02066	 0.076594	 0.0009	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	2827	 2482	 0.014361	 0.090955	 0.0012	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	3463	 2483	 0.000124	 0.001383	 0.0051	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3590	 2483	 0.001047	 0.006953	 0.0132	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3773	 2483	 9.9e-05	 0.000277	 0.0284	 104366	 104366	 104366	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 2483	 0.003417	 0.022696	 0.0425	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 2483	 9.9e-05	 0.000336	 0.0263	 87644	 87644	 87644	 0.0	 0.0	 1	 -30.0	 30.0;
	3771	 2483	 4e-05	 9.9e-05	 0.0	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 2484	 0.044092	 0.121441	 0.0013	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	5279	 2484	 0.023432	 0.063492	 0.0007	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	3584	 2486	 0.004031	 0.008314	 0.0057	 3292	 3292	 3292	 0.0	 0.0	 1	 -30.0	 30.0;
	4680	 2488	 0.042076	 0.100529	 0.0012	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	2717	 2489	 0.026173	 0.067531	 0.0042	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	2711	 2492	 0.103049	 0.262535	 0.0029	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	3000	 2492	 0.029151	 0.079516	 0.0009	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	4071	 2492	 0.065205	 0.153263	 0.0018	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	5159	 2492	 0.002268	 0.006047	 0.0001	 4710	 4710	 4710	 0.0	 0.0	 1	 -30.0	 30.0;
	5458	 2493	 0.012812	 0.023452	 0.0002	 1105	 1105	 1105	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 2494	 0.058604	 0.159436	 0.018	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	2783	 2494	 0.115797	 0.297682	 0.0097	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	2510	 2496	 0.004484	 0.021195	 0.0365	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3671	 2496	 0.00324	 0.014894	 0.0243	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2773	 2497	 0.084077	 0.265709	 0.005	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	2915	 2498	 0.026914	 0.073457	 0.0034	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	5459	 2499	 5e-05	 0.000252	 0.0	 114924	 114924	 114924	 0.0	 0.0	 1	 -30.0	 30.0;
	4189	 2500	 0.063643	 0.173646	 0.002	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 2500	 0.122197	 0.331066	 0.0038	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	5219	 2500	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5221	 2500	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 2500	 0.123709	 0.335853	 0.0038	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	4987	 2501	 0.04389	 0.107256	 0.0012	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	4987	 2501	 0.062482	 0.114371	 0.0012	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 2502	 0.017133	 0.054926	 0.0006	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	2774	 2503	 0.002143	 0.014358	 0.0264	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2829	 2505	 0.001335	 0.003527	 0.004	 8065	 8065	 8065	 0.0	 0.0	 1	 -30.0	 30.0;
	5722	 2505	 0.102041	 0.278156	 0.0031	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	2828	 2506	 0.007307	 0.021164	 0.0147	 1359	 1359	 1359	 0.0	 0.0	 1	 -30.0	 30.0;
	4389	 2506	 0.006903	 0.018468	 0.0008	 1543	 1543	 1543	 0.0	 0.0	 1	 -30.0	 30.0;
	4000	 2507	 0.029226	 0.079365	 0.0009	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	4000	 2507	 0.025195	 0.079365	 0.001	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	3244	 2509	 0.012018	 0.051298	 0.0006	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	3244	 2509	 0.012094	 0.051474	 0.001	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 2510	 0.00403	 0.018054	 0.0349	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4858	 2510	 0.004484	 0.021156	 0.0365	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4854	 2511	 0.000557	 0.007335	 0.2533	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2710	 2514	 0.020887	 0.068682	 0.0015	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	4770	 2514	 0.075838	 0.202066	 0.0021	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	5159	 2514	 0.089443	 0.243386	 0.0029	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	5711	 2515	 0.00716	 0.014321	 0.0006	 1856	 1856	 1856	 0.0	 0.0	 1	 -30.0	 30.0;
	2529	 2518	 0.013354	 0.03477	 0.005	 770	 770	 770	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 2518	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	3383	 2519	 0.000116	 0.000212	 0.0142	 128418	 128418	 128418	 0.0	 0.0	 1	 -30.0	 30.0;
	4801	 2520	 0.059012	 0.158642	 0.0077	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3928	 2521	 0.072058	 0.233812	 0.0036	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	2552	 2522	 0.086924	 0.209121	 0.0021	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	5339	 2522	 0.026027	 0.062887	 0.0006	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	2552	 2522	 0.060721	 0.207357	 0.0024	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	2923	 2523	 0.172084	 0.417737	 0.0047	 68	 68	 68	 0.0	 0.0	 1	 -30.0	 30.0;
	2526	 2525	 0.028958	 0.053008	 0.0005	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	2680	 2526	 0.039053	 0.08642	 0.001	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	3653	 2526	 0.033258	 0.078357	 0.001	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	4810	 2526	 0.080306	 0.146998	 0.0012	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	5464	 2526	 0.013983	 0.038095	 0.0005	 750	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	2564	 2527	 0.001327	 0.008873	 0.0466	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4951	 2527	 0.002291	 0.01521	 0.0284	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5463	 2528	 0.000179	 0.000327	 0.0233	 83031	 83031	 83031	 0.0	 0.0	 1	 -30.0	 30.0;
	5750	 2529	 0.03351	 0.083396	 0.0069	 320	 320	 320	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 2530	 0.013102	 0.034266	 0.0051	 781	 781	 781	 0.0	 0.0	 1	 -30.0	 30.0;
	2699	 2531	 0.012094	 0.058957	 0.0172	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	2888	 2532	 0.004359	 0.018544	 0.0008	 1550	 1550	 1550	 0.0	 0.0	 1	 -30.0	 30.0;
	3151	 2532	 0.030234	 0.08642	 0.001	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	3151	 2532	 0.030234	 0.08642	 0.001	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 2533	 0.001244	 0.008296	 0.0142	 483.0	 483.0	 483.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4202	 2534	 0.087679	 0.284455	 0.0034	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 2535	 0.008566	 0.026959	 0.0003	 1013	 1013	 1013	 0.0	 0.0	 1	 -30.0	 30.0;
	5468	 2537	 0.004787	 0.014361	 0.0002	 1893	 1893	 1893	 0.0	 0.0	 1	 -30.0	 30.0;
	5497	 2536	 0.00252	 0.007307	 0.0001	 3707	 3707	 3707	 0.0	 0.0	 1	 -30.0	 30.0;
	2964	 2538	 0.115898	 0.248173	 0.0027	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	2964	 2538	 0.072562	 0.248173	 0.0029	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	5466	 2539	 0.005845	 0.012925	 0.0001	 2082	 2082	 2082	 0.0	 0.0	 1	 -30.0	 30.0;
	5467	 2540	 0.091774	 0.167992	 0.0017	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	3676	 2541	 0.042328	 0.173595	 0.001	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	4728	 2541	 0.008062	 0.047619	 0.0006	 612	 612	 612	 0.0	 0.0	 1	 -30.0	 30.0;
	4835	 2541	 0.025447	 0.070295	 0.0008	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	4728	 2541	 0.017637	 0.056437	 0.0019	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	5685	 2542	 0.010667	 0.034444	 0.0112	 845	 845	 845	 0.0	 0.0	 1	 -30.0	 30.0;
	3903	 2543	 0.009857	 0.066884	 0.1266	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	4729	 2543	 0.000632	 0.003931	 0.0243	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4736	 2543	 0.002153	 0.009758	 0.0172	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4168	 2545	 0.063996	 0.163013	 0.0019	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3181	 2546	 0.097758	 0.247518	 0.0089	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	4785	 2547	 0.021482	 0.057407	 0.0032	 495	 495	 495	 0.0	 0.0	 1	 -30.0	 30.0;
	4785	 2547	 0.020494	 0.057654	 0.0026	 496	 496	 496	 0.0	 0.0	 1	 -30.0	 30.0;
	2759	 2548	 0.046107	 0.192996	 0.0083	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 2549	 0.100277	 0.276896	 0.0031	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	3691	 2549	 0.026707	 0.076342	 0.0009	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	3370	 2550	 0.045926	 0.12358	 0.0058	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	4905	 2550	 0.021235	 0.054691	 0.0026	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	3834	 2551	 0.019174	 0.04447	 0.0006	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	4315	 2551	 0.080877	 0.187705	 0.002	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	3639	 2552	 0.113076	 0.249786	 0.0028	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	5563	 2552	 0.007811	 0.047871	 0.0006	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	5564	 2552	 0.007307	 0.022172	 0.0002	 1303	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 2552	 0.075586	 0.24641	 0.0024	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	2621	 2552	 0.011842	 0.072814	 0.001	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	4453	 2553	 0.003279	 0.022637	 0.0415	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5471	 2555	 0.044815	 0.122222	 0.0057	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5472	 2556	 0.000252	 0.00252	 0.0001	 11659	 11659	 11659	 0.0	 0.0	 1	 -30.0	 30.0;
	5473	 2557	 0.015621	 0.043084	 0.0005	 645	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	3932	 2558	 0.055933	 0.146888	 0.0	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	3999	 2558	 0.031545	 0.104006	 0.0043	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	3098	 2559	 0.089695	 0.165281	 0.0025	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	3816	 2559	 0.049383	 0.126228	 0.0022	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 2559	 0.090098	 0.249055	 0.0072	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	5246	 2559	 0.019425	 0.04898	 0.001	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	5757	 2559	 0.027765	 0.082389	 0.0015	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	5484	 2560	 0.001932	 0.012802	 0.0233	 477.0	 477.0	 477.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3096	 2561	 0.00063	 0.006413	 0.1632	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4101	 2562	 0.014691	 0.049876	 0.0024	 584	 584	 584	 0.0	 0.0	 1	 -30.0	 30.0;
	4785	 2562	 0.042716	 0.14963	 0.0071	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5703	 2563	 0.009753	 0.024074	 0.0133	 1168	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	5701	 2563	 0.010247	 0.025309	 0.0133	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 2564	 0.000593	 0.003951	 0.0339	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3994	 2565	 0.031998	 0.081129	 0.001	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	4358	 2565	 0.009322	 0.02318	 0.0002	 1147	 1147	 1147	 0.0	 0.0	 1	 -30.0	 30.0;
	5182	 2567	 0.000802	 0.002173	 0.0001	 12942	 12942	 12942	 0.0	 0.0	 1	 -30.0	 30.0;
	2844	 2568	 0.000198	 0.001699	 0.1731	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3001	 2569	 0.04389	 0.139053	 0.014	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	3001	 2569	 0.04389	 0.139053	 0.014	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 2570	 0.02088	 0.03822	 0.0012	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	5381	 2570	 0.024296	 0.118963	 0.0004	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	5744	 2570	 0.002963	 0.009877	 0.0012	 2532	 2532	 2532	 0.0	 0.0	 1	 -30.0	 30.0;
	5784	 2570	 0.051852	 0.13679	 0.0047	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	5247	 2572	 0.010444	 0.032756	 0.0103	 930	 930	 930	 0.0	 0.0	 1	 -30.0	 30.0;
	5039	 2573	 0.000296	 0.001758	 0.003	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5838	 2573	 0.000356	 0.002054	 0.004	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5661	 2573	 0.006696	 0.029985	 0.0527	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3429	 2574	 0.040247	 0.10963	 0.0052	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	4133	 2574	 0.044815	 0.122346	 0.0057	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	2821	 2575	 0.029136	 0.081605	 0.0037	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	2617	 2576	 0.022963	 0.051728	 0.0023	 566	 566	 566	 0.0	 0.0	 1	 -30.0	 30.0;
	4388	 2576	 0.000988	 0.005926	 0.0863	 5342	 5342	 5342	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 2576	 0.00321	 0.02	 0.0002	 1707	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	4387	 2576	 0.000988	 0.005926	 0.0002	 5342	 5342	 5342	 0.0	 0.0	 1	 -30.0	 30.0;
	5102	 2576	 0.00321	 0.02	 0.0002	 1707	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	2731	 2578	 0.074074	 0.177879	 0.001	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	5743	 2578	 0.074074	 0.177879	 0.001	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3162	 2580	 0.015839	 0.041543	 0.0019	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	5475	 2581	 0.001764	 0.005039	 0.0	 5531	 5531	 5531	 0.0	 0.0	 1	 -30.0	 30.0;
	2977	 2582	 0.031494	 0.0645	 0.0007	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	2825	 2583	 0.000222	 0.002327	 0.0578	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 2583	 0.001565	 0.020568	 0.7076	 1547	 1547	 1547	 0.0	 0.0	 1	 -30.0	 30.0;
	5714	 2583	 0.000914	 0.009875	 0.2238	 1704.0	 1704.0	 1704.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 2583	 0.001641	 0.021544	 0.7451	 1476	 1476	 1476	 0.0	 0.0	 1	 -30.0	 30.0;
	2825	 2583	 0.000229	 0.002313	 0.0578	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3003	 2583	 0.001558	 0.020568	 0.7076	 1547	 1547	 1547	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 2583	 0.001634	 0.021503	 0.7451	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 2584	 0.014109	 0.089443	 0.0011	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 2584	 0.014109	 0.089443	 0.0011	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	5373	 2585	 0.060972	 0.168808	 0.0019	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	5623	 2585	 0.000252	 0.001008	 0.0	 33358	 33358	 33358	 0.0	 0.0	 1	 -30.0	 30.0;
	5477	 2586	 0.021852	 0.059753	 0.0028	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 2587	 0.036483	 0.090854	 0.0011	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	4405	 2587	 0.050643	 0.140842	 0.0015	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 2587	 0.037995	 0.094835	 0.0011	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	4405	 2587	 0.050643	 0.140842	 0.0015	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	2777	 2588	 0.003378	 0.02242	 0.0415	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5392	 2589	 0.002222	 0.004444	 0.0002	 5979	 5979	 5979	 0.0	 0.0	 1	 -30.0	 30.0;
	2593	 2591	 0.000176	 0.000454	 0.0005	 62462	 62462	 62462	 0.0	 0.0	 1	 -30.0	 30.0;
	4667	 2591	 0.021668	 0.052154	 0.0005	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	5478	 2592	 0.000171	 0.000313	 0.0	 83282	 83282	 83282	 0.0	 0.0	 1	 -30.0	 30.0;
	3106	 2594	 0.07231	 0.206853	 0.0023	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	4046	 2594	 0.04384	 0.122953	 0.0013	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	3106	 2594	 0.072058	 0.206601	 0.0023	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	5479	 2596	 0.026296	 0.071728	 0.0028	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 2597	 0.171076	 0.313152	 0.0033	 86	 86	 86	 0.0	 0.0	 1	 -30.0	 30.0;
	4440	 2597	 0.025699	 0.065508	 0.0008	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	2869	 2598	 0.075556	 0.205309	 0.0097	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	3219	 2598	 0.048642	 0.131481	 0.0063	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	3341	 2598	 0.058765	 0.152099	 0.0073	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 2598	 0.087161	 0.224198	 0.0107	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	3405	 2601	 0.04284	 0.091728	 0.0042	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	3402	 2603	 0.071504	 0.176997	 0.0018	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	3612	 2604	 0.039305	 0.102293	 0.0012	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 2605	 0.116906	 0.242126	 0.0026	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	5448	 2605	 0.03477	 0.072814	 0.0008	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	4785	 2606	 0.021605	 0.091111	 0.0049	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	3353	 2607	 0.011838	 0.02167	 0.0235	 1161	 1161	 1161	 0.0	 0.0	 1	 -30.0	 30.0;
	3969	 2608	 0.033086	 0.089876	 0.0042	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	4672	 2608	 0.088642	 0.185679	 0.0079	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	3017	 2609	 0.033086	 0.09	 0.0042	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5805	 2609	 0.048889	 0.124321	 0.0059	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 2612	 0.08642	 0.23608	 0.0026	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5087	 2613	 0.018642	 0.050617	 0.0024	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 2614	 0.000756	 0.00252	 0.0001	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 2614	 0.00068	 0.002268	 0.0001	 12845	 12845	 12845	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 2615	 0.04515	 0.122222	 0.0025	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5796	 2615	 0.00126	 0.003779	 0.0	 7635	 7635	 7635	 0.0	 0.0	 1	 -30.0	 30.0;
	5797	 2615	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	2923	 2618	 0.010078	 0.04258	 0.0005	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	4582	 2618	 0.009826	 0.041068	 0.0016	 738	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	2824	 2619	 0.003826	 0.018665	 0.0334	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2925	 2619	 0.00077	 0.003536	 0.0066	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4468	 2619	 0.005037	 0.034785	 0.0653	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2824	 2619	 0.003615	 0.01762	 0.0314	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2924	 2619	 0.000711	 0.004583	 0.0081	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5563	 2621	 0.004283	 0.025951	 0.0003	 1157	 1157	 1157	 0.0	 0.0	 1	 -30.0	 30.0;
	2630	 2622	 0.133006	 0.305266	 0.0033	 92	 92	 92	 0.0	 0.0	 1	 -30.0	 30.0;
	3552	 2622	 0.129252	 0.306374	 0.004	 92	 92	 92	 0.0	 0.0	 1	 -30.0	 30.0;
	3883	 2622	 0.05039	 0.117158	 0.0013	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	2903	 2623	 0.024074	 0.054198	 0.0024	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	5240	 2623	 0.048148	 0.108148	 0.005	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 2625	 0.009574	 0.017637	 0.0289	 1516	 1516	 1516	 0.0	 0.0	 1	 -30.0	 30.0;
	2782	 2626	 0.066264	 0.166289	 0.0074	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	3132	 2626	 0.035525	 0.091459	 0.0032	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 2626	 0.020257	 0.117108	 0.0127	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 2627	 0.020433	 0.117914	 0.0121	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	4125	 2628	 0.002726	 0.018193	 0.0334	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4629	 2628	 0.002596	 0.01165	 0.0203	 326.0	 326.0	 326.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4125	 2628	 0.002726	 0.018193	 0.0334	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2943	 2629	 0.06125	 0.156866	 0.0017	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4061	 2629	 0.035047	 0.090098	 0.001	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	3434	 2630	 0.080121	 0.194255	 0.0021	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	5223	 2631	 0.066012	 0.179894	 0.0	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 2632	 0.003086	 0.008148	 0.0005	 3410	 3410	 3410	 0.0	 0.0	 1	 -30.0	 30.0;
	5824	 2632	 0.017037	 0.044691	 0.0021	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 2633	 0.001512	 0.003023	 0.0	 8999	 8999	 8999	 0.0	 0.0	 1	 -30.0	 30.0;
	2637	 2636	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5212	 2636	 0.029226	 0.080625	 0.001	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	5209	 2637	 0.031746	 0.080121	 0.0009	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	3495	 2638	 0.024439	 0.064752	 0.0016	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	4164	 2638	 0.039305	 0.111363	 0.0012	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	3644	 2638	 0.017385	 0.049383	 0.0006	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	4165	 2641	 0.004507	 0.013102	 0.0043	 2280	 2280	 2280	 0.0	 0.0	 1	 -30.0	 30.0;
	5536	 2641	 0.012933	 0.044356	 0.0144	 684	 684	 684	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 2641	 0.002711	 0.008889	 0.0032	 3399	 3399	 3399	 0.0	 0.0	 1	 -30.0	 30.0;
	4986	 2642	 0.106828	 0.220207	 0.0024	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	5811	 2642	 0.034575	 0.063288	 0.0007	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	3761	 2643	 0.036543	 0.096173	 0.0045	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	3369	 2644	 0.095238	 0.206097	 0.0	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	3482	 2644	 0.04384	 0.111867	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 2645	 0.003275	 0.014109	 0.0002	 2100	 2100	 2100	 0.0	 0.0	 1	 -30.0	 30.0;
	5181	 2645	 0.01852	 0.033901	 0.0003	 788	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	5777	 2646	 0.000198	 0.000909	 0.002	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4138	 2647	 0.036029	 0.15873	 0.0029	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4508	 2647	 0.052658	 0.144117	 0.0016	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	5347	 2647	 0.006551	 0.027211	 0.0003	 1209	 1209	 1209	 0.0	 0.0	 1	 -30.0	 30.0;
	4509	 2648	 0.002252	 0.010509	 0.0187	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4886	 2648	 0.008	 0.03998	 0.0709	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3532	 2649	 0.000109	 0.000494	 0.001	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2710	 2650	 0.054926	 0.133535	 0.0013	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 2650	 0.024439	 0.058957	 0.0006	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	3979	 2651	 0.06576	 0.17939	 0.002	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 2652	 0.007811	 0.027211	 0.0	 1043	 1043	 1043	 0.0	 0.0	 1	 -30.0	 30.0;
	2585	 2653	 0.022928	 0.094734	 0.0012	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	3523	 2653	 0.039053	 0.144117	 0.0086	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4031	 2653	 0.014865	 0.033006	 0.0004	 816	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	5421	 2653	 0.012094	 0.033006	 0.0004	 840	 840	 840	 0.0	 0.0	 1	 -30.0	 30.0;
	2585	 2653	 0.02318	 0.093978	 0.0013	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	4772	 2654	 0.005827	 0.02703	 0.0476	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3484	 2659	 0.006409	 0.016431	 0.005	 1792	 1792	 1792	 0.0	 0.0	 1	 -30.0	 30.0;
	5680	 2660	 0.024691	 0.067271	 0.0013	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	5681	 2660	 0.026203	 0.066516	 0.0013	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	3504	 2661	 0.039753	 0.104568	 0.005	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	4154	 2661	 0.006259	 0.020988	 0.0013	 1357	 1357	 1357	 0.0	 0.0	 1	 -30.0	 30.0;
	4875	 2661	 0.001481	 0.006667	 0.0288	 4350	 4350	 4350	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 2665	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 2664	 0.000252	 0.00252	 0.0001	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	4247	 2666	 0.013102	 0.03477	 0.0004	 819	 819	 819	 0.0	 0.0	 1	 -30.0	 30.0;
	4882	 2666	 0.074326	 0.157218	 0.0017	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4247	 2666	 0.017889	 0.045855	 0.0006	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	4393	 2667	 0.07483	 0.202822	 0.0029	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	5485	 2668	 0.007559	 0.021164	 0.0002	 1354	 1354	 1354	 0.0	 0.0	 1	 -30.0	 30.0;
	3875	 2668	 0.047871	 0.125976	 0.0014	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	5432	 2669	 0.001956	 0.020958	 0.0871	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2668	 2670	 0.014613	 0.040816	 0.0005	 702	 702	 702	 0.0	 0.0	 1	 -30.0	 30.0;
	4350	 2673	 0.057823	 0.168178	 0.0102	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 2674	 0.009136	 0.019259	 0.0062	 1405	 1405	 1405	 0.0	 0.0	 1	 -30.0	 30.0;
	5392	 2674	 0.026914	 0.070741	 0.0034	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	5752	 2674	 0.047654	 0.124815	 0.0058	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 2674	 0.009012	 0.018889	 0.0062	 1431	 1431	 1431	 0.0	 0.0	 1	 -30.0	 30.0;
	3476	 2676	 0.013704	 0.043333	 0.0021	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	4690	 2677	 0.059133	 0.16198	 0.0018	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	5487	 2678	 5.9e-05	 0.000435	 0.0025	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5488	 2679	 0.002593	 0.010741	 0.0005	 2745	 2745	 2745	 0.0	 0.0	 1	 -30.0	 30.0;
	3753	 2680	 0.058026	 0.106216	 0.001	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	4775	 2682	 0.036231	 0.098262	 0.0023	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 2683	 0.099622	 0.273217	 0.0149	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	2685	 2684	 0.020988	 0.088518	 0.0045	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	5489	 2684	 1.2e-05	 0.001235	 0.0002	 24050	 24050	 24050	 0.0	 0.0	 1	 -30.0	 30.0;
	3160	 2686	 0.000336	 0.001225	 0.1529	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3874	 2686	 0.000138	 0.00079	 0.1063	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4908	 2686	 0.000138	 0.000889	 0.1215	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2827	 2687	 0.001764	 0.004787	 0.0042	 5788	 5788	 5788	 0.0	 0.0	 1	 -30.0	 30.0;
	3889	 2689	 0.02066	 0.052406	 0.0006	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	4727	 2689	 0.006551	 0.027463	 0.009	 1078	 1078	 1078	 0.0	 0.0	 1	 -30.0	 30.0;
	4822	 2691	 0.015309	 0.031728	 0.0013	 870	 870	 870	 0.0	 0.0	 1	 -30.0	 30.0;
	4314	 2692	 0.049887	 0.12648	 0.0014	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	3649	 2693	 0.011086	 0.028471	 0.0003	 967	 967	 967	 0.0	 0.0	 1	 -30.0	 30.0;
	3431	 2694	 0.001041	 0.006967	 0.0152	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3168	 2695	 0.076846	 0.267826	 0.0033	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	4049	 2695	 0.000604	 0.001106	 0.0006	 22736	 22736	 22736	 0.0	 0.0	 1	 -30.0	 30.0;
	4662	 2695	 0.071303	 0.194759	 0.0022	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	4050	 2695	 0.000773	 0.001416	 0.0007	 17760	 17760	 17760	 0.0	 0.0	 1	 -30.0	 30.0;
	4893	 2696	 0.019728	 0.057546	 0.0029	 486	 486	 486	 0.0	 0.0	 1	 -30.0	 30.0;
	5198	 2696	 0.006047	 0.020912	 0.0	 1357	 1357	 1357	 0.0	 0.0	 1	 -30.0	 30.0;
	5826	 2696	 0.011086	 0.057445	 0.0021	 505	 505	 505	 0.0	 0.0	 1	 -30.0	 30.0;
	3339	 2697	 0.009067	 0.029116	 0.0486	 262.0	 262.0	 262.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2888	 2699	 0.024439	 0.101789	 0.001	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	3831	 2698	 0.040539	 0.128168	 0.0015	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	4609	 2699	 0.087931	 0.279667	 0.0033	 102	 102	 102	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 2698	 0.025195	 0.159486	 0.0021	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 2698	 0.009826	 0.047115	 0.001	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 2700	 0.000701	 0.004599	 0.0082	 484.0	 484.0	 484.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 2700	 0.000705	 0.00463	 0.0083	 484.0	 484.0	 484.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3922	 2702	 0.026959	 0.112875	 0.0023	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	3923	 2703	 0.001956	 0.008691	 0.0248	 3468	 3468	 3468	 0.0	 0.0	 1	 -30.0	 30.0;
	5493	 2704	 0.026543	 0.066296	 0.0031	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	3305	 2706	 0.012496	 0.043621	 0.0734	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3536	 2706	 0.018805	 0.069215	 0.1235	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	3553	 2706	 0.012306	 0.062598	 0.1109	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3305	 2706	 0.00717	 0.042726	 0.0749	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 2707	 0.001627	 0.017031	 0.3812	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5160	 2711	 0.018392	 0.045074	 0.0004	 625	 625	 625	 0.0	 0.0	 1	 -30.0	 30.0;
	5162	 2711	 0.020106	 0.048828	 0.0046	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	3022	 2712	 0.017284	 0.108148	 0.0075	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	4718	 2713	 0.000257	 0.000612	 0.0547	 46632	 46632	 46632	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 2713	 0.000237	 0.000553	 0.0496	 51447	 51447	 51447	 0.0	 0.0	 1	 -30.0	 30.0;
	4716	 2713	 0.000237	 0.000553	 0.0496	 51447	 51447	 51447	 0.0	 0.0	 1	 -30.0	 30.0;
	5057	 2714	 0.000395	 0.005229	 0.1791	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 2715	 0.008062	 0.054926	 0.0006	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 2715	 0.008062	 0.054926	 0.0006	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	3576	 2717	 0.002963	 0.008642	 0.0024	 3320	 3320	 3320	 0.0	 0.0	 1	 -30.0	 30.0;
	4809	 2717	 0.00679	 0.028642	 0.0034	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	4809	 2717	 0.007284	 0.03037	 0.0028	 971	 971	 971	 0.0	 0.0	 1	 -30.0	 30.0;
	4219	 2718	 0.005017	 0.033521	 0.0607	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3907	 2719	 0.049131	 0.127488	 0.0014	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 2720	 0.001679	 0.007526	 0.0132	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3593	 2721	 0.055595	 0.101765	 0.0043	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 2722	 0.005926	 0.016173	 0.0008	 1725	 1725	 1725	 0.0	 0.0	 1	 -30.0	 30.0;
	4139	 2723	 0.003275	 0.010582	 0.0002	 2715	 2715	 2715	 0.0	 0.0	 1	 -30.0	 30.0;
	4217	 2726	 0.018025	 0.045679	 0.0021	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	4949	 2730	 0.009753	 0.018272	 0.0008	 1465	 1465	 1465	 0.0	 0.0	 1	 -30.0	 30.0;
	4949	 2729	 0.003185	 0.008914	 0.0319	 3204	 3204	 3204	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 2731	 0.054422	 0.127236	 0.0021	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	5641	 2732	 0.000579	 0.001587	 0.0	 17478	 17478	 17478	 0.0	 0.0	 1	 -30.0	 30.0;
	3637	 2735	 0.128484	 0.235189	 0.0033	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	3806	 2736	 0.066264	 0.1678	 0.0019	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	4983	 2736	 0.060217	 0.164021	 0.0019	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	3114	 2737	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4059	 2737	 0.004326	 0.019694	 0.0344	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4985	 2737	 0.003338	 0.015091	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3113	 2737	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4985	 2737	 0.003338	 0.015091	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3112	 2737	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4621	 2738	 0.008818	 0.022172	 0.0	 1246	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	3415	 2739	 0.025951	 0.072814	 0.0085	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	2937	 2741	 0.000951	 0.003593	 0.0002	 8159	 8159	 8159	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 2742	 0.000138	 0.000593	 0.0	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4723	 2743	 0.041975	 0.106543	 0.0049	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	4779	 2743	 0.034568	 0.094444	 0.024	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 2743	 0.031111	 0.084938	 0.004	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	4779	 2743	 0.034568	 0.094444	 0.024	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	2838	 2746	 0.15873	 0.35349	 0.0	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	4196	 2746	 0.000756	 0.005291	 0.0001	 5525	 5525	 5525	 0.0	 0.0	 1	 -30.0	 30.0;
	4417	 2746	 0.068531	 0.165961	 0.0018	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	5093	 2746	 0.096246	 0.238851	 0.0027	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	5728	 2746	 0.005039	 0.012598	 0.0002	 2177	 2177	 2177	 0.0	 0.0	 1	 -30.0	 30.0;
	4195	 2746	 0.002771	 0.006047	 0.0001	 4439	 4439	 4439	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 2747	 0.007723	 0.032119	 0.0527	 937	 937	 937	 0.0	 0.0	 1	 -30.0	 30.0;
	3929	 2747	 0.009541	 0.039585	 0.0648	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5500	 2748	 0.00397	 0.007268	 0.0102	 3615	 3615	 3615	 0.0	 0.0	 1	 -30.0	 30.0;
	3417	 2749	 0.03094	 0.093298	 0.0011	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	4797	 2749	 0.015621	 0.04132	 0.0	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	5497	 2750	 0.000252	 0.001008	 0.0	 27575	 27575	 27575	 0.0	 0.0	 1	 -30.0	 30.0;
	3655	 2751	 0.007055	 0.016629	 0.0007	 1684	 1684	 1684	 0.0	 0.0	 1	 -30.0	 30.0;
	5496	 2753	 0.000705	 0.002973	 0.0001	 9377	 9377	 9377	 0.0	 0.0	 1	 -30.0	 30.0;
	5501	 2754	 0.00252	 0.004787	 0.0001	 6271	 6271	 6271	 0.0	 0.0	 1	 -30.0	 30.0;
	2945	 2755	 0.001519	 0.010582	 0.0162	 510.0	 510.0	 510.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3756	 2755	 0.002216	 0.014805	 0.0273	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2944	 2755	 0.001529	 0.010637	 0.0162	 477.0	 477.0	 477.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3756	 2755	 0.002206	 0.014728	 0.0273	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4060	 2756	 0.000457	 0.006025	 0.2079	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 2756	 0.001856	 0.025166	 0.8563	 1264	 1264	 1264	 0.0	 0.0	 1	 -30.0	 30.0;
	4620	 2757	 0.056941	 0.143613	 0.0016	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	3359	 2758	 0.014865	 0.045855	 0.0002	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	3359	 2758	 0.014865	 0.046107	 0.0002	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	5498	 2759	 0.055178	 0.139834	 0.0016	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	5678	 2760	 0.090703	 0.190476	 0.0021	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	5377	 2760	 0.006551	 0.017637	 0.0002	 1617	 1617	 1617	 0.0	 0.0	 1	 -30.0	 30.0;
	2833	 2762	 0.013086	 0.045803	 0.0021	 624	 624	 624	 0.0	 0.0	 1	 -30.0	 30.0;
	3254	 2762	 0.005185	 0.031975	 0.0023	 917	 917	 917	 0.0	 0.0	 1	 -30.0	 30.0;
	4275	 2762	 0.015803	 0.053086	 0.0026	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	4402	 2762	 0.039506	 0.113457	 0.0053	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	4899	 2762	 0.025802	 0.106914	 0.0057	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	5809	 2762	 0.018519	 0.065679	 0.0036	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	4275	 2762	 0.024815	 0.071975	 0.0032	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	5231	 2762	 0.025679	 0.106543	 0.0055	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	3009	 2763	 0.014914	 0.055309	 0.0896	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 2763	 0.009383	 0.042607	 0.0759	 276.0	 276.0	 276.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4527	 2764	 0.002597	 0.020332	 0.4202	 1408.0	 1408.0	 1408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4527	 2764	 0.001932	 0.021399	 0.4448	 1391.0	 1391.0	 1391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5493	 2765	 0.020988	 0.052469	 0.0024	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	5766	 2765	 0.018025	 0.045926	 0.0021	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	3895	 2767	 0.068783	 0.155959	 0.0021	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	5074	 2767	 0.026707	 0.07483	 0.0008	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	5499	 2768	 0.000198	 0.000909	 0.001	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3801	 2769	 0.148778	 0.326556	 0.0036	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	5128	 2769	 0.028924	 0.07672	 0.0001	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	5502	 2770	 0.001106	 0.007328	 0.0132	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4000	 2771	 0.028471	 0.074326	 0.0	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	2954	 2772	 0.031973	 0.079441	 0.0041	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	3323	 2772	 0.005039	 0.021416	 0.0002	 1383	 1383	 1383	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 2773	 0.071454	 0.242605	 0.0033	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5443	 2773	 0.018267	 0.062031	 0.0007	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	5444	 2773	 0.018392	 0.06198	 0.0007	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	5590	 2773	 0.022525	 0.13933	 0.0018	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	3323	 2772	 0.005039	 0.021668	 0.0002	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 2773	 0.068531	 0.219955	 0.0026	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 2774	 0.015488	 0.067417	 0.1205	 298.0	 298.0	 298.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3477	 2776	 0.010247	 0.020494	 0.0015	 1324	 1324	 1324	 0.0	 0.0	 1	 -30.0	 30.0;
	4174	 2777	 0.005985	 0.041383	 0.0739	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5803	 2777	 0.000243	 0.001614	 0.003	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 2780	 0.033762	 0.092215	 0.001	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 2781	 0.022147	 0.129554	 0.004	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 2781	 0.023658	 0.133686	 0.0041	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 2782	 0.064669	 0.118376	 0.0067	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	4062	 2783	 0.054422	 0.143613	 0.0017	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 2783	 0.074779	 0.202444	 0.0048	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 2783	 0.074049	 0.255959	 0.0301	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	5462	 2783	 0.077123	 0.256362	 0.0254	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	4062	 2783	 0.054422	 0.143865	 0.0017	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	3393	 2784	 0.003737	 0.024798	 0.0456	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 2784	 0.000869	 0.005886	 0.0415	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 2785	 0.119224	 0.218238	 0.002	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	4949	 2786	 0.004074	 0.028025	 0.0058	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	4951	 2787	 0.000514	 0.004247	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5503	 2788	 5.9e-05	 0.000474	 0.002	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3374	 2790	 0.004286	 0.020405	 0.0344	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3663	 2790	 0.007625	 0.035378	 0.0668	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3850	 2792	 0.008818	 0.024943	 0.0	 1117	 1117	 1117	 0.0	 0.0	 1	 -30.0	 30.0;
	4190	 2793	 0.042963	 0.084938	 0.0038	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 2794	 0.038045	 0.116402	 0.0013	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	3790	 2795	 0.000252	 0.00252	 0.0002	 11330	 11330	 11330	 0.0	 0.0	 1	 -30.0	 30.0;
	3916	 2795	 0.027715	 0.170824	 0.0132	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	5242	 2795	 0.045528	 0.124112	 0.0016	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	3662	 2798	 0.010988	 0.042963	 0.0003	 724	 724	 724	 0.0	 0.0	 1	 -30.0	 30.0;
	3663	 2799	 0.001146	 0.005551	 0.0101	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4919	 2800	 0.097506	 0.263794	 0.0029	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	5448	 2800	 0.054674	 0.112623	 0.0012	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	3691	 2801	 0.00126	 0.00252	 0.0018	 10480	 10480	 10480	 0.0	 0.0	 1	 -30.0	 30.0;
	3504	 2802	 0.033827	 0.143333	 0.0073	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	4167	 2802	 0.012716	 0.034321	 0.0058	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	4371	 2802	 0.004198	 0.017407	 0.003	 1659	 1659	 1659	 0.0	 0.0	 1	 -30.0	 30.0;
	4876	 2803	 0.008296	 0.038795	 0.0648	 309.0	 309.0	 309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4247	 2804	 0.024969	 0.106223	 0.0026	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	5506	 2806	 0.000756	 0.00252	 0.0001	 12969	 12969	 12969	 0.0	 0.0	 1	 -30.0	 30.0;
	3300	 2807	 0.024691	 0.063827	 0.0031	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	4363	 2807	 0.000864	 0.00284	 0.0002	 10216	 10216	 10216	 0.0	 0.0	 1	 -30.0	 30.0;
	4386	 2807	 0.019506	 0.052593	 0.0024	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	5030	 2807	 0.034197	 0.093951	 0.0	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 2807	 0.011358	 0.026914	 0.0013	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	5545	 2807	 0.014938	 0.039383	 0.0018	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	5547	 2807	 0.014198	 0.039012	 0.0	 731	 731	 731	 0.0	 0.0	 1	 -30.0	 30.0;
	5561	 2807	 0.036667	 0.116049	 0.0057	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	5029	 2807	 0.034321	 0.094691	 0.0	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	3594	 2808	 0.00528	 0.029102	 0.0496	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2937	 2809	 0.052593	 0.119012	 0.0039	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5742	 2809	 0.065556	 0.146914	 0.0068	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 2811	 0.033762	 0.137566	 0.0018	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 2811	 0.085528	 0.156557	 0.0016	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5450	 2811	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 2812	 0.011417	 0.020898	 0.0002	 1278	 1278	 1278	 0.0	 0.0	 1	 -30.0	 30.0;
	4339	 2814	 9.9e-05	 0.001007	 0.003	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4339	 2813	 0.000119	 0.001067	 0.004	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4306	 2816	 0.177421	 0.324767	 0.0071	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	4326	 2816	 0.084656	 0.216427	 0.0025	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 2817	 0.052154	 0.104308	 0.0011	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	3704	 2818	 0.000395	 0.001126	 0.1043	 25728	 25728	 25728	 0.0	 0.0	 1	 -30.0	 30.0;
	3175	 2822	 0.101481	 0.203086	 0.0089	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	3839	 2822	 0.00642	 0.02	 0.0154	 1415	 1415	 1415	 0.0	 0.0	 1	 -30.0	 30.0;
	5313	 2822	 0.005864	 0.036531	 0.0019	 803	 803	 803	 0.0	 0.0	 1	 -30.0	 30.0;
	5809	 2822	 0.013951	 0.044321	 0.0021	 640	 640	 640	 0.0	 0.0	 1	 -30.0	 30.0;
	5142	 2823	 0.000849	 0.003812	 0.0071	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3800	 2825	 7.6e-05	 0.000554	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3799	 2825	 7.6e-05	 0.000554	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3798	 2825	 7.6e-05	 0.000554	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3797	 2825	 7.6e-05	 0.000568	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 2826	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	4389	 2828	 0.003679	 0.018418	 0.0286	 1620	 1620	 1620	 0.0	 0.0	 1	 -30.0	 30.0;
	5507	 2830	 0.000756	 0.00252	 0.0	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	5509	 2831	 1.5e-05	 9.9e-05	 0.001	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3338	 2832	 0.044973	 0.126127	 0.0015	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5085	 2833	 0.002963	 0.008889	 0.0005	 3170	 3170	 3170	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 2835	 0.005543	 0.014865	 0.0002	 1862	 1862	 1862	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 2836	 0.054568	 0.138519	 0.0065	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 2837	 2.5e-05	 0.000252	 0.0001	 114403	 114403	 114403	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 2838	 0.125894	 0.230447	 0.0021	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	4556	 2838	 0.109599	 0.26455	 0.003	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 2840	 0.04006	 0.101033	 0.0068	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 2841	 0.000277	 0.001244	 0.0886	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4565	 2842	 0.000499	 0.006557	 0.2282	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4642	 2842	 0.000298	 0.003019	 0.078	 1971.0	 1971.0	 1971.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4565	 2842	 0.000505	 0.006637	 0.231	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4642	 2842	 0.000298	 0.003012	 0.078	 1971.0	 1971.0	 1971.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4565	 2842	 0.000499	 0.006557	 0.2282	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4565	 2842	 0.000499	 0.006557	 0.2282	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5243	 2843	 0.074578	 0.210632	 0.0025	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	5513	 2843	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	3095	 2845	 0.000158	 0.001284	 0.1185	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3558	 2845	 0.000178	 0.001521	 0.1397	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5782	 2846	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	5516	 2848	 1.5e-05	 9.9e-05	 0.0	 309124	 309124	 309124	 0.0	 0.0	 1	 -30.0	 30.0;
	5515	 2849	 0.000454	 0.001008	 0.0	 27511	 27511	 27511	 0.0	 0.0	 1	 -30.0	 30.0;
	5514	 2851	 0.006299	 0.016377	 0.0002	 1734	 1734	 1734	 0.0	 0.0	 1	 -30.0	 30.0;
	5514	 2852	 0.001208	 0.002211	 0.0	 12072	 12072	 12072	 0.0	 0.0	 1	 -30.0	 30.0;
	5518	 2853	 0.000158	 0.000652	 0.001	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3392	 2854	 0.011262	 0.075762	 0.0018	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	3749	 2856	 0.015148	 0.040877	 0.0019	 682	 682	 682	 0.0	 0.0	 1	 -30.0	 30.0;
	5328	 2856	 0.008395	 0.034815	 0.0018	 830	 830	 830	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 2856	 0.028025	 0.174815	 0.0096	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	4134	 2857	 0.002983	 0.020385	 0.0375	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4163	 2857	 0.005136	 0.034548	 0.0628	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2989	 2860	 0.003049	 0.012824	 0.0194	 2246	 2246	 2246	 0.0	 0.0	 1	 -30.0	 30.0;
	4842	 2858	 0.003275	 0.012094	 0.0132	 2395	 2395	 2395	 0.0	 0.0	 1	 -30.0	 30.0;
	4842	 2859	 0.005382	 0.009851	 0.0091	 2672	 2672	 2672	 0.0	 0.0	 1	 -30.0	 30.0;
	5519	 2861	 0.000123	 0.001235	 0.0	 23932	 23932	 23932	 0.0	 0.0	 1	 -30.0	 30.0;
	4678	 2862	 0.000247	 0.000741	 0.0005	 38824	 38824	 38824	 0.0	 0.0	 1	 -30.0	 30.0;
	4440	 2863	 0.059939	 0.151978	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 2866	 0.002875	 0.005263	 0.0001	 5072	 5072	 5072	 0.0	 0.0	 1	 -30.0	 30.0;
	4925	 2867	 0.054568	 0.138889	 0.0065	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 2868	 0.007004	 0.015142	 0.0002	 1823	 1823	 1823	 0.0	 0.0	 1	 -30.0	 30.0;
	5609	 2869	 0.037494	 0.102284	 0.0049	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	5523	 2870	 0.003779	 0.014865	 0.0018	 1925	 1925	 1925	 0.0	 0.0	 1	 -30.0	 30.0;
	5522	 2871	 0.010632	 0.026228	 0.0027	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	3030	 2875	 0.025447	 0.064575	 0.0007	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	3068	 2876	 0.069035	 0.148652	 0.0021	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	3001	 2877	 0.01033	 0.02842	 0.0003	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 2878	 0.005795	 0.022424	 0.0002	 1275	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 2878	 0.000504	 0.002268	 0.0	 12709	 12709	 12709	 0.0	 0.0	 1	 -30.0	 30.0;
	3028	 2879	 0.091963	 0.211892	 0.0021	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 2879	 0.048375	 0.10708	 0.0012	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	4285	 2880	 0.02973	 0.124969	 0.0027	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	4577	 2881	 0.055682	 0.13933	 0.0016	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	4560	 2882	 0.003527	 0.013354	 0.0	 2161	 2161	 2161	 0.0	 0.0	 1	 -30.0	 30.0;
	2909	 2884	 0.001323	 0.008824	 0.0339	 411.0	 411.0	 411.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3478	 2885	 0.000731	 0.00484	 0.0091	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4856	 2885	 0.002884	 0.018686	 0.0375	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5556	 2885	 0.001817	 0.012168	 0.0223	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 2885	 0.002785	 0.018884	 0.0334	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3478	 2885	 0.00077	 0.005136	 0.0091	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5669	 2885	 0.003121	 0.020859	 0.0385	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3478	 2885	 0.000731	 0.00482	 0.0091	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3472	 2886	 9.7e-05	 0.00097	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4632	 2886	 0.001468	 0.014903	 0.3841	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	5079	 2886	 0.00036	 0.003636	 0.0953	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3471	 2886	 9.7e-05	 0.00097	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4633	 2886	 0.001461	 0.014785	 0.3812	 2147	 2147	 2147	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 2886	 0.001247	 0.012673	 0.3263	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 2886	 9.7e-05	 0.000983	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3469	 2886	 9.7e-05	 0.001025	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3319	 2887	 0.007037	 0.019259	 0.001	 1449	 1449	 1449	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 2887	 0.003827	 0.010864	 0.0005	 2579	 2579	 2579	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 2888	 0.024439	 0.096498	 0.0194	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	3174	 2889	 0.046259	 0.11736	 0.0013	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	5526	 2890	 0.001638	 0.004334	 0.0048	 6565	 6565	 6565	 0.0	 0.0	 1	 -30.0	 30.0;
	3836	 2891	 0.046687	 0.127387	 0.0014	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 2891	 0.108592	 0.275636	 0.0031	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 2891	 0.0839	 0.23356	 0.0027	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 2895	 0.001512	 0.004031	 0.0001	 7065	 7065	 7065	 0.0	 0.0	 1	 -30.0	 30.0;
	5527	 2895	 0.001461	 0.003704	 0.0001	 7639	 7639	 7639	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 2896	 0.013444	 0.026877	 0.0011	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 2897	 0.001644	 0.005778	 0.0018	 5259	 5259	 5259	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 2898	 0.038272	 0.114311	 0.0065	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	2902	 2901	 0.008844	 0.024112	 0.0003	 1185	 1185	 1185	 0.0	 0.0	 1	 -30.0	 30.0;
	5613	 2903	 0.007741	 0.017333	 0.0008	 1565	 1565	 1565	 0.0	 0.0	 1	 -30.0	 30.0;
	3892	 2904	 0.047367	 0.131267	 0.0014	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5397	 2904	 0.027841	 0.076594	 0.0008	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	4849	 2906	 0.028471	 0.113883	 0.0032	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 2908	 0.011753	 0.05438	 0.0931	 294.0	 294.0	 294.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2991	 2908	 0.00083	 0.008375	 0.0263	 866.0	 866.0	 866.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3602	 2908	 0.00241	 0.016435	 0.0273	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4458	 2907	 0.007585	 0.028128	 0.0456	 1063	 1063	 1063	 0.0	 0.0	 1	 -30.0	 30.0;
	4843	 2909	 0.000652	 0.005946	 0.0172	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 2907	 0.000632	 0.004346	 0.0233	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2990	 2907	 0.000869	 0.008514	 0.0273	 866.0	 866.0	 866.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4843	 2907	 0.000632	 0.00559	 0.0476	 494.0	 494.0	 494.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2913	 2911	 0.000252	 0.000504	 0.0003	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	3785	 2912	 0.004443	 0.008133	 0.0048	 3282	 3282	 3282	 0.0	 0.0	 1	 -30.0	 30.0;
	3922	 2913	 0.057949	 0.137062	 0.0015	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	4245	 2913	 0.011665	 0.066465	 0.0027	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	5769	 2913	 0.006475	 0.017259	 0.001	 1602	 1602	 1602	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 2916	 0.060141	 0.152532	 0.0017	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 2916	 0.078357	 0.21416	 0.0024	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	3842	 2917	 0.078105	 0.208617	 0.0024	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	3842	 2917	 0.076594	 0.202822	 0.0025	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	3078	 2918	 0.046359	 0.100781	 0.0011	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	4374	 2919	 0.001981	 0.003626	 0.0025	 7146	 7146	 7146	 0.0	 0.0	 1	 -30.0	 30.0;
	3290	 2920	 0.079365	 0.215923	 0.0025	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	5530	 2921	 0.000436	 0.000797	 0.0004	 32501	 32501	 32501	 0.0	 0.0	 1	 -30.0	 30.0;
	3206	 2923	 0.046863	 0.11867	 0.0013	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	3674	 2923	 0.045855	 0.121693	 0.0039	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	2978	 2926	 0.007862	 0.038716	 0.0658	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3605	 2926	 0.001719	 0.00881	 0.0203	 358.0	 358.0	 358.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3092	 2927	 0.067775	 0.178382	 0.002	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	5771	 2927	 0.068279	 0.174855	 0.002	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3841	 2929	 0.022676	 0.06576	 0.001	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	4990	 2928	 0.024188	 0.061728	 0.001	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	5600	 2929	 0.003779	 0.024943	 0.0	 1171	 1171	 1171	 0.0	 0.0	 1	 -30.0	 30.0;
	3841	 2928	 0.016377	 0.066264	 0.001	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	5602	 2928	 0.003779	 0.024439	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	5533	 2931	 0.000504	 0.001512	 0.001	 18638	 18638	 18638	 0.0	 0.0	 1	 -30.0	 30.0;
	5281	 2933	 0.034266	 0.094482	 0.001	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	5835	 2933	 0.084908	 0.220711	 0.0025	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	4840	 2934	 0.05037	 0.129877	 0.0062	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	3232	 2937	 0.010049	 0.026543	 0.0041	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	5017	 2937	 0.005148	 0.013309	 0.0006	 2126	 2126	 2126	 0.0	 0.0	 1	 -30.0	 30.0;
	5073	 2937	 0.016914	 0.04642	 0.0021	 614	 614	 614	 0.0	 0.0	 1	 -30.0	 30.0;
	3929	 2938	 0.014262	 0.067397	 0.1124	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4296	 2938	 0.021077	 0.088869	 0.1468	 301.0	 301.0	 301.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4397	 2938	 0.00016	 0.000755	 0.0013	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3929	 2938	 0.013452	 0.063625	 0.1063	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3959	 2939	 0.002815	 0.017518	 0.097	 1675	 1675	 1675	 0.0	 0.0	 1	 -30.0	 30.0;
	4920	 2939	 0.002395	 0.014938	 0.0828	 1964	 1964	 1964	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 2940	 0.00065	 0.008537	 0.2946	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3233	 2943	 0.013102	 0.081129	 0.001	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	5059	 2943	 0.044041	 0.186369	 0.0022	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 2943	 0.013983	 0.038045	 0.0005	 751	 751	 751	 0.0	 0.0	 1	 -30.0	 30.0;
	4417	 2946	 0.081129	 0.199043	 0.002	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	5045	 2947	 0.022235	 0.057469	 0.0047	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	5665	 2947	 0.009296	 0.024593	 0.0011	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 2948	 0.056941	 0.148652	 0.0017	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4234	 2949	 0.03679	 0.103704	 0.0053	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	5535	 2951	 0.028723	 0.057193	 0.0006	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	5536	 2952	 0.000347	 0.000813	 0.0018	 35735	 35735	 35735	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 2955	 0.011208	 0.020517	 0.0771	 1271	 1271	 1271	 0.0	 0.0	 1	 -30.0	 30.0;
	2960	 2956	 4e-05	 0.000198	 0.0223	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2959	 2957	 2e-05	 0.000198	 0.0152	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4074	 2959	 0.000138	 0.019753	 0.001	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4149	 2959	 0.000494	 0.003002	 0.242	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5028	 2958	 0.002726	 0.013728	 0.084	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5582	 2960	 0.000356	 0.003358	 0.0121	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4074	 2958	 9.9e-05	 0.000198	 0.0091	 446.0	 446.0	 446.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4149	 2959	 0.000514	 0.003101	 0.2521	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 2959	 0.000909	 0.006005	 0.0142	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 2961	 0.000166	 0.002749	 0.1069	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5235	 2962	 0.001004	 0.010997	 0.2339	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 2962	 0.000159	 0.002701	 0.0982	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5537	 2963	 0.00126	 0.00252	 0.0	 10795	 10795	 10795	 0.0	 0.0	 1	 -30.0	 30.0;
	3990	 2964	 0.03613	 0.097783	 0.0021	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	4901	 2964	 0.028975	 0.07483	 0.0008	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	5208	 2964	 0.103049	 0.264802	 0.0132	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	3989	 2964	 0.036004	 0.09743	 0.0011	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	3033	 2966	 0.081633	 0.15999	 0.0021	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	5193	 2966	 0.040564	 0.110859	 0.001	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	3974	 2967	 0.163976	 0.300156	 0.003	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	4249	 2967	 0.119224	 0.218238	 0.0021	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	5539	 2968	 0.002091	 0.004308	 0.0001	 6352	 6352	 6352	 0.0	 0.0	 1	 -30.0	 30.0;
	5609	 2970	 0.024815	 0.063086	 0.0028	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	5632	 2970	 0.023679	 0.060074	 0.0028	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	3307	 2971	 0.02037	 0.050988	 0.0608	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	3595	 2972	 0.023683	 0.09801	 0.0012	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 2972	 0.074074	 0.1678	 0.0018	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	5456	 2972	 0.030738	 0.084354	 0.017	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 2972	 0.010078	 0.041824	 0.0005	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	5634	 2973	 0.014865	 0.027211	 0.0001	 1095	 1095	 1095	 0.0	 0.0	 1	 -30.0	 30.0;
	3996	 2976	 0.001358	 0.006049	 0.0003	 4892	 4892	 4892	 0.0	 0.0	 1	 -30.0	 30.0;
	3396	 2977	 0.023683	 0.083648	 0.001	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	4088	 2977	 0.054926	 0.145377	 0.0017	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	4359	 2977	 0.012598	 0.077853	 0.001	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 2977	 0.024943	 0.071051	 0.0008	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	5839	 2977	 0.038549	 0.133031	 0.0016	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	4088	 2977	 0.053918	 0.147392	 0.0017	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	3477	 2979	 0.030864	 0.096667	 0.0053	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	4047	 2981	 0.004283	 0.026959	 0.0003	 1082	 1082	 1082	 0.0	 0.0	 1	 -30.0	 30.0;
	4152	 2981	 0.042076	 0.093222	 0.001	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 2981	 0.003275	 0.02066	 0.0002	 1412	 1412	 1412	 0.0	 0.0	 1	 -30.0	 30.0;
	5732	 2981	 0.044848	 0.114135	 0.0013	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	3900	 2982	 0.000395	 0.002686	 0.0051	 490.0	 490.0	 490.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3546	 2983	 0.000252	 0.000504	 0.0004	 52855	 52855	 52855	 0.0	 0.0	 1	 -30.0	 30.0;
	4976	 2984	 0.032754	 0.09675	 0.001	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 2984	 0.049887	 0.143109	 0.0021	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 2986	 0.021416	 0.054674	 0.001	 503	 503	 503	 0.0	 0.0	 1	 -30.0	 30.0;
	4786	 2986	 0.028219	 0.071303	 0.001	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	3280	 2989	 0.005291	 0.028219	 0.0	 1032	 1032	 1032	 0.0	 0.0	 1	 -30.0	 30.0;
	3672	 2988	 0.01914	 0.035035	 0.0329	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	4307	 2988	 0.001512	 0.005543	 0.0055	 5196	 5196	 5196	 0.0	 0.0	 1	 -30.0	 30.0;
	5533	 2988	 0.007055	 0.029479	 0.001	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	5637	 2988	 0.003023	 0.021164	 0.001	 1391	 1391	 1391	 0.0	 0.0	 1	 -30.0	 30.0;
	5639	 2989	 0.003275	 0.022676	 0.001	 1292	 1292	 1292	 0.0	 0.0	 1	 -30.0	 30.0;
	3281	 2991	 0.000316	 0.002351	 0.0061	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3382	 2991	 0.000512	 0.001327	 0.159	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4762	 2992	 0.029479	 0.062988	 0.0015	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	5610	 2992	 0.026329	 0.069866	 0.0021	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	4762	 2992	 0.029479	 0.062988	 0.0007	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	3613	 2993	 0.001146	 0.008296	 0.0663	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3167	 2994	 0.039128	 0.099824	 0.0012	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	5161	 2994	 0.008062	 0.022424	 0.0002	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 2994	 0.059965	 0.165029	 0.0002	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3039	 2994	 0.023683	 0.099017	 0.0013	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	3167	 2994	 0.043865	 0.11038	 0.0016	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	4555	 2995	 0.000711	 0.00324	 0.2916	 293.0	 293.0	 293.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 2996	 0.093474	 0.228773	 0.0025	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	3641	 2997	 0.001857	 0.008435	 0.0152	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4591	 2997	 0.002647	 0.013254	 0.0243	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3459	 2998	 0.036543	 0.095926	 0.0045	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 2999	 0.001146	 0.010923	 0.1706	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 2999	 0.001185	 0.010844	 0.1671	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5037	 3001	 0.021668	 0.057193	 0.0007	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	5109	 3001	 0.026153	 0.066289	 0.0016	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 3003	 0.000852	 0.011233	 0.387	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 3003	 0.000852	 0.011226	 0.387	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3074	 3004	 0.04132	 0.10582	 0.002	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 3005	 0.014084	 0.042001	 0.014	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	4771	 3006	 0.011338	 0.048627	 0.001	 592	 592	 592	 0.0	 0.0	 1	 -30.0	 30.0;
	4771	 3006	 0.011338	 0.048627	 0.001	 592	 592	 592	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 3008	 0.018025	 0.047407	 0.0023	 591	 591	 591	 0.0	 0.0	 1	 -30.0	 30.0;
	4921	 3010	 0.047115	 0.196523	 0.0068	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	5161	 3011	 0.000176	 0.000504	 0.0	 56971	 56971	 56971	 0.0	 0.0	 1	 -30.0	 30.0;
	5569	 3011	 0.027337	 0.074553	 0.0008	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	4783	 3012	 0.01321	 0.02642	 0.0011	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	3535	 3013	 0.062736	 0.151424	 0.0075	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	4764	 3013	 0.066012	 0.177879	 0.002	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	5543	 3015	 0.000252	 0.001008	 0.0	 28670	 28670	 28670	 0.0	 0.0	 1	 -30.0	 30.0;
	5768	 3016	 0.00126	 0.003275	 0.0001	 9667	 9667	 9667	 0.0	 0.0	 1	 -30.0	 30.0;
	5774	 3016	 0.007559	 0.019148	 0.0002	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	3512	 3020	 0.030486	 0.102545	 0.0012	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	5583	 3022	 0.011111	 0.054568	 0.0028	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 3023	 0.049559	 0.13424	 0.002	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	5129	 3023	 0.057344	 0.129478	 0.0031	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	4020	 3025	 0.001101	 0.012181	 0.2599	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3589	 3026	 0.013303	 0.036306	 0.0053	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	3392	 3027	 0.058503	 0.157596	 0.0063	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 3028	 0.325276	 0.595412	 0.0048	 45	 45	 45	 0.0	 0.0	 1	 -30.0	 30.0;
	4453	 3031	 0.003356	 0.026424	 0.0458	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 3032	 0.014046	 0.025712	 0.0002	 978	 978	 978	 0.0	 0.0	 1	 -30.0	 30.0;
	4456	 3033	 0.035273	 0.150164	 0.0021	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4504	 3033	 0.015873	 0.066012	 0.001	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	4630	 3033	 0.075586	 0.202822	 0.0021	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 3034	 0.001512	 0.004031	 0.0001	 7065	 7065	 7065	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 3035	 0.007181	 0.044797	 0.0006	 671	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 3035	 0.01615	 0.043638	 0.0046	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	4221	 3036	 0.006551	 0.017889	 0.0002	 1597	 1597	 1597	 0.0	 0.0	 1	 -30.0	 30.0;
	4834	 3036	 0.083198	 0.152293	 0.0016	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3304	 3037	 0.00839	 0.023507	 0.0286	 1219	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	4294	 3037	 0.002973	 0.012673	 0.0189	 2337	 2337	 2337	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 3040	 0.000573	 0.003832	 0.0071	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 3040	 0.003615	 0.025225	 0.0486	 549.0	 549.0	 549.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4806	 3041	 0.026707	 0.112371	 0.0013	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	4577	 3042	 0.017637	 0.044848	 0.0086	 613	 613	 613	 0.0	 0.0	 1	 -30.0	 30.0;
	3056	 3043	 0.033333	 0.089383	 0.0043	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	3261	 3045	 0.112371	 0.281179	 0.0032	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	3489	 3046	 0.070295	 0.178131	 0.0027	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3051	 3049	 2.1e-05	 0.000127	 0.1141	 1092.0	 1092.0	 1092.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3930	 3049	 0.000111	 0.001932	 0.0289	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3050	 3049	 2.1e-05	 0.000127	 0.1155	 1053.0	 1053.0	 1053.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 3052	 0.026707	 0.059965	 0.0009	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 3058	 0.049506	 0.125556	 0.0058	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 3058	 0.025442	 0.046572	 0.0018	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	3666	 3059	 0.002963	 0.016914	 0.0314	 1766	 1766	 1766	 0.0	 0.0	 1	 -30.0	 30.0;
	3970	 3059	 0.004074	 0.025309	 0.0026	 1183	 1183	 1183	 0.0	 0.0	 1	 -30.0	 30.0;
	4949	 3060	 0.005432	 0.022222	 0.0073	 1326	 1326	 1326	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 3062	 2e-05	 0.000198	 0.0172	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5551	 3061	 2e-05	 0.000198	 0.0142	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 3064	 0.079718	 0.1935	 0.0031	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	4327	 3066	 0.017637	 0.059713	 0.0021	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	5315	 3066	 0.027715	 0.086924	 0.001	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 3066	 0.03225	 0.087931	 0.0015	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	3094	 3067	 0.003461	 0.013896	 0.0243	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5648	 3068	 0.013605	 0.033258	 0.003	 822	 822	 822	 0.0	 0.0	 1	 -30.0	 30.0;
	4761	 3069	 0.069035	 0.150416	 0.0016	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	5817	 3069	 0.001512	 0.004031	 0.0001	 6858	 6858	 6858	 0.0	 0.0	 1	 -30.0	 30.0;
	4791	 3069	 0.004283	 0.011842	 0.0002	 2345	 2345	 2345	 0.0	 0.0	 1	 -30.0	 30.0;
	5552	 3070	 0.009826	 0.026455	 0.0003	 1047	 1047	 1047	 0.0	 0.0	 1	 -30.0	 30.0;
	3194	 3071	 0.086672	 0.236332	 0.0026	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	4765	 3072	 0.03358	 0.090741	 0.0151	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 3072	 1.2e-05	 0.000123	 0.0	 240340	 240340	 240340	 0.0	 0.0	 1	 -30.0	 30.0;
	5150	 3073	 0.005039	 0.010078	 0.01	 2621	 2621	 2621	 0.0	 0.0	 1	 -30.0	 30.0;
	4652	 3076	 0.064752	 0.145629	 0.0016	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	5221	 3077	 0.050643	 0.138322	 0.0016	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	5727	 3077	 0.026203	 0.071554	 0.0008	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	3701	 3078	 0.048879	 0.16125	 0.0018	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	5354	 3078	 0.023683	 0.060217	 0.0006	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 3078	 0.04006	 0.101789	 0.0011	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	3400	 3079	 0.001462	 0.006677	 0.1488	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 3079	 0.001231	 0.008198	 0.0587	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5649	 3079	 0.000865	 0.005772	 0.0101	 436.0	 436.0	 436.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 3079	 0.002588	 0.015862	 0.0304	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3306	 3080	 0.063316	 0.146813	 0.0025	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	5651	 3080	 0.017385	 0.037541	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 3081	 0.011804	 0.05293	 0.0942	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5252	 3082	 0.036533	 0.075334	 0.0008	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	3959	 3083	 0.062963	 0.160123	 0.0075	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	5134	 3084	 0.053011	 0.144318	 0.0025	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 3084	 0.042555	 0.1161	 0.002	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	4067	 3085	 0.046049	 0.118025	 0.0057	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	4993	 3088	 0.046082	 0.122827	 0.0025	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 3089	 0.00907	 0.022928	 0.0276	 1162	 1162	 1162	 0.0	 0.0	 1	 -30.0	 30.0;
	3337	 3091	 0.043457	 0.090864	 0.0011	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	4946	 3093	 0.05417	 0.137818	 0.001	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5248	 3093	 0.01285	 0.052658	 0.001	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	4060	 3096	 0.001101	 0.012445	 0.3105	 1488.0	 1488.0	 1488.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4126	 3096	 0.0009	 0.007479	 0.0982	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4913	 3096	 0.002209	 0.024924	 0.5733	 1275	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 3096	 0.0009	 0.00741	 0.13	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 3100	 0.07609	 0.180146	 0.003	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 3099	 0.082892	 0.184933	 0.002	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	3450	 3101	 0.024188	 0.091459	 0.0064	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	5369	 3101	 0.017637	 0.057445	 0.0012	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	5349	 3101	 0.011842	 0.031746	 0.0007	 846	 846	 846	 0.0	 0.0	 1	 -30.0	 30.0;
	5556	 3102	 0.000395	 0.002607	 0.0051	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4912	 3103	 0.01022	 0.054673	 0.0997	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5324	 3103	 0.003488	 0.015777	 0.0284	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 3104	 0.041572	 0.112623	 0.0013	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 3104	 0.043084	 0.110103	 0.0013	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	3262	 3105	 0.013102	 0.056437	 0.0433	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	5575	 3105	 0.024439	 0.099269	 0.0013	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	3544	 3106	 0.064248	 0.163517	 0.0019	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	3752	 3106	 0.041068	 0.103804	 0.0021	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	4385	 3106	 0.068279	 0.18972	 0.0021	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	4752	 3106	 0.069287	 0.193248	 0.0024	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	5615	 3106	 0.155455	 0.425548	 0.0042	 66	 66	 66	 0.0	 0.0	 1	 -30.0	 30.0;
	5472	 3106	 0.05543	 0.153943	 0.0032	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4850	 3108	 0.024938	 0.068395	 0.0032	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	5085	 3107	 0.028642	 0.064568	 0.0029	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	5276	 3108	 0.022346	 0.061235	 0.0029	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 3107	 0.040741	 0.111358	 0.0052	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	5557	 3115	 0.003951	 0.010864	 0.0005	 2570	 2570	 2570	 0.0	 0.0	 1	 -30.0	 30.0;
	3501	 3116	 0.003275	 0.007307	 0.0	 3688	 3688	 3688	 0.0	 0.0	 1	 -30.0	 30.0;
	5558	 3118	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	4344	 3119	 0.0237	 0.043383	 0.0	 616	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	5604	 3120	 0.024969	 0.073268	 0.0013	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	5808	 3120	 0.025951	 0.090955	 0.001	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	5599	 3120	 0.024969	 0.083094	 0.001	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	3171	 3121	 0.029978	 0.100778	 0.0366	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	2923	 3122	 0.053666	 0.125724	 0.0014	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3804	 3122	 0.078861	 0.206752	 0.0062	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	4260	 3124	 0.002016	 0.005291	 0.0001	 5215	 5215	 5215	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 3124	 0.092467	 0.244898	 0.0028	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	4355	 3125	 0.027457	 0.074876	 0.0036	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	4971	 3127	 0.008566	 0.067523	 0.0496	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	5561	 3129	 0.002099	 0.00642	 0.0003	 4490	 4490	 4490	 0.0	 0.0	 1	 -30.0	 30.0;
	4604	 3132	 0.017637	 0.045352	 0.0005	 626	 626	 626	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 3133	 0.001025	 0.008148	 0.0142	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3157	 3134	 0.012371	 0.032199	 0.0049	 882	 882	 882	 0.0	 0.0	 1	 -30.0	 30.0;
	3921	 3134	 0.139529	 0.255404	 0.0024	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	3157	 3134	 0.034517	 0.089695	 0.001	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 3135	 0.007386	 0.013519	 0.0001	 1975	 1975	 1975	 0.0	 0.0	 1	 -30.0	 30.0;
	5562	 3136	 0.001512	 0.003779	 0.0001	 7254	 7254	 7254	 0.0	 0.0	 1	 -30.0	 30.0;
	3139	 3137	 4.3e-05	 9e-05	 0.004	 310318	 310318	 310318	 0.0	 0.0	 1	 -30.0	 30.0;
	3894	 3138	 0.025195	 0.103804	 0.0015	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	4967	 3138	 0.025951	 0.088687	 0.0133	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	5090	 3138	 0.027967	 0.085412	 0.001	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	4966	 3138	 0.025951	 0.089695	 0.0132	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	4039	 3139	 0.00079	 0.003931	 0.0071	 339.0	 339.0	 339.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4968	 3139	 0.001442	 0.006696	 0.0121	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3977	 3140	 0.013983	 0.047468	 0.0025	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 3140	 0.087075	 0.287932	 0.0029	 102	 102	 102	 0.0	 0.0	 1	 -30.0	 30.0;
	5769	 3141	 0.04006	 0.07735	 0.0008	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	3463	 3142	 3.6e-05	 9.3e-05	 0.0121	 655.0	 655.0	 655.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3464	 3143	 2.8e-05	 0.000277	 0.0058	 2187.0	 2187.0	 2187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 3144	 0.067775	 0.171832	 0.0019	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 3145	 0.024321	 0.097901	 0.007	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	4122	 3145	 0.033827	 0.143951	 0.0071	 208	 208	 208	 0.0	 0.0	 1	 -30.0	 30.0;
	5011	 3145	 0.018765	 0.07663	 0.0079	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	5040	 3145	 0.000173	 0.00079	 0.0034	 36728	 36728	 36728	 0.0	 0.0	 1	 -30.0	 30.0;
	4880	 3147	 0.001734	 0.018573	 0.4072	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4898	 3147	 0.002181	 0.031662	 0.8231	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	5235	 3146	 0.001711	 0.017313	 0.4476	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4898	 3146	 0.002181	 0.031648	 0.8202	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	5060	 3150	 0.004568	 0.008395	 0.0224	 3291	 3291	 3291	 0.0	 0.0	 1	 -30.0	 30.0;
	3593	 3152	 0.050988	 0.129259	 0.0062	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	4885	 3152	 0.040988	 0.107531	 0.0052	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	3251	 3153	 0.035926	 0.091235	 0.0044	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	3519	 3153	 0.000988	 0.002716	 0.0002	 10278	 10278	 10278	 0.0	 0.0	 1	 -30.0	 30.0;
	3268	 3154	 0.025195	 0.053414	 0.0079	 486	 486	 486	 0.0	 0.0	 1	 -30.0	 30.0;
	3558	 3156	 0.000198	 0.000652	 0.5832	 475.0	 475.0	 475.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3927	 3156	 0.000316	 0.001442	 0.1326	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3558	 3156	 0.000237	 0.001422	 0.1873	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3926	 3156	 0.000257	 0.001007	 0.1215	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3378	 3157	 0.083724	 0.227488	 0.0026	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	4425	 3157	 0.050643	 0.13026	 0.0015	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	5195	 3157	 0.019904	 0.133031	 0.0015	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 3157	 0.034517	 0.2129	 0.0029	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	5563	 3159	 0.004283	 0.012346	 0.0002	 2328	 2328	 2328	 0.0	 0.0	 1	 -30.0	 30.0;
	4517	 3162	 0.004568	 0.009259	 0.0003	 2877	 2877	 2877	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 3162	 0.012222	 0.032222	 0.0015	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	5565	 3163	 0.000773	 0.001416	 0.0006	 18302	 18302	 18302	 0.0	 0.0	 1	 -30.0	 30.0;
	5566	 3164	 0.000252	 0.00126	 0.0	 23670	 23670	 23670	 0.0	 0.0	 1	 -30.0	 30.0;
	4715	 3165	 0.011111	 0.030124	 0.0	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	5335	 3165	 0.034938	 0.092222	 0.0045	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	3664	 3166	 0.035979	 0.091207	 0.001	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	5569	 3167	 0.000454	 0.001209	 0.0002	 23551	 23551	 23551	 0.0	 0.0	 1	 -30.0	 30.0;
	4662	 3168	 0.073318	 0.259007	 0.0031	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	4955	 3169	 0.003319	 0.022716	 0.0415	 1346	 1346	 1346	 0.0	 0.0	 1	 -30.0	 30.0;
	5617	 3170	 0.030738	 0.084152	 0.001	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	3259	 3171	 0.024307	 0.078747	 0.0251	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 3172	 3.4e-05	 9.4e-05	 0.002	 286.0	 286.0	 286.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4917	 3172	 0.003297	 0.021902	 0.0466	 477.0	 477.0	 477.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3744	 3173	 0.001496	 0.014148	 0.3697	 1537.0	 1537.0	 1537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3744	 3173	 0.001496	 0.014148	 0.3697	 1537.0	 1537.0	 1537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4670	 3173	 0.000942	 0.009536	 0.2455	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3389	 3176	 0.018645	 0.050894	 0.0006	 575	 575	 575	 0.0	 0.0	 1	 -30.0	 30.0;
	4101	 3177	 0.024568	 0.066296	 0.0031	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	4631	 3177	 0.008642	 0.054198	 0.0061	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	5571	 3178	 0.043012	 0.146025	 0.0071	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5113	 3178	 0.045309	 0.147654	 0.0073	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	4878	 3179	 0.095792	 0.23361	 0.0026	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5572	 3180	 0.012346	 0.033258	 0.0004	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	5607	 3181	 0.042051	 0.106601	 0.0012	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	5778	 3181	 0.015369	 0.04258	 0.0	 672	 672	 672	 0.0	 0.0	 1	 -30.0	 30.0;
	4281	 3183	 0.006803	 0.027715	 0.0004	 1066	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	5368	 3183	 0.002771	 0.011338	 0.0002	 2606	 2606	 2606	 0.0	 0.0	 1	 -30.0	 30.0;
	4391	 3185	 0.000277	 0.000632	 0.0607	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4391	 3184	 0.000395	 0.000731	 0.0628	 37253	 37253	 37253	 0.0	 0.0	 1	 -30.0	 30.0;
	3507	 3186	 0.028025	 0.114815	 0.0016	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	4243	 3187	 0.000178	 0.000928	 0.3564	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4242	 3188	 0.021416	 0.07735	 0.0093	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 3189	 0.021482	 0.054568	 0.0026	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 3189	 0.003951	 0.008025	 0.0233	 3321	 3321	 3321	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 3190	 0.007037	 0.017901	 0.0008	 1545	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	5345	 3190	 0.059876	 0.15284	 0.0071	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 3189	 0.025926	 0.065556	 0.0031	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	5046	 3192	 0.012247	 0.044385	 0.0739	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4570	 3191	 9.9e-05	 0.000988	 0.004	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 3194	 0.006803	 0.018392	 0.0002	 1740	 1740	 1740	 0.0	 0.0	 1	 -30.0	 30.0;
	3263	 3195	 0.006918	 0.046044	 0.0851	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3873	 3197	 0.000158	 0.000289	 0.0203	 93975	 93975	 93975	 0.0	 0.0	 1	 -30.0	 30.0;
	3874	 3198	 0.000145	 0.000265	 0.0182	 102466	 102466	 102466	 0.0	 0.0	 1	 -30.0	 30.0;
	5491	 3199	 0.011482	 0.028765	 0.0015	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	4619	 3200	 0.094734	 0.240363	 0.0027	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 3201	 0.005926	 0.016914	 0.0018	 1932	 1932	 1932	 0.0	 0.0	 1	 -30.0	 30.0;
	4209	 3202	 0.002771	 0.011086	 0.0002	 2662	 2662	 2662	 0.0	 0.0	 1	 -30.0	 30.0;
	4492	 3202	 0.001764	 0.006803	 0.0001	 4328	 4328	 4328	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 3203	 0.000222	 0.000711	 0.0004	 42408	 42408	 42408	 0.0	 0.0	 1	 -30.0	 30.0;
	3262	 3204	 0.029226	 0.119174	 0.0015	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	5556	 3205	 0.000968	 0.00644	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5576	 3207	 0.036684	 0.06715	 0.0006	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 3211	 0.008395	 0.021358	 0.001	 1295	 1295	 1295	 0.0	 0.0	 1	 -30.0	 30.0;
	5570	 3212	 0.08516	 0.20131	 0.0022	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	3817	 3213	 0.047544	 0.093827	 0.001	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	3915	 3213	 0.0451	 0.19224	 0.0025	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	3916	 3213	 0.045855	 0.194004	 0.0027	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	4949	 3214	 0.001481	 0.00358	 0.0002	 7828	 7828	 7828	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 3215	 0.044848	 0.113379	 0.0013	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	4221	 3215	 0.050894	 0.128748	 0.0014	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	3292	 3216	 0.044394	 0.112547	 0.0013	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	4220	 3216	 0.05039	 0.128244	 0.0014	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	4758	 3217	 0.073318	 0.197531	 0.0035	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	5817	 3217	 0.052406	 0.141345	 0.0028	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	3814	 3219	 0.034197	 0.096049	 0.0044	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	3623	 3221	 0.008642	 0.021975	 0.0011	 1285	 1285	 1285	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 3222	 0.022575	 0.071151	 0.0008	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	3420	 3226	 0.000229	 0.000419	 0.0527	 64823	 64823	 64823	 0.0	 0.0	 1	 -30.0	 30.0;
	3420	 3225	 0.000229	 0.000419	 0.0527	 64823	 64823	 64823	 0.0	 0.0	 1	 -30.0	 30.0;
	3420	 3224	 0.000284	 0.00052	 0.0461	 52241	 52241	 52241	 0.0	 0.0	 1	 -30.0	 30.0;
	4600	 3228	 0.027037	 0.055556	 0.0026	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	4601	 3227	 0.027037	 0.055556	 0.0026	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 3233	 0.107332	 0.252457	 0.0028	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	5530	 3234	 0.028219	 0.062736	 0.0007	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 3235	 0.014361	 0.028975	 0.0003	 914	 914	 914	 0.0	 0.0	 1	 -30.0	 30.0;
	4687	 3236	 4e-05	 0.001086	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4701	 3236	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4257	 3237	 0.012469	 0.051852	 0.0028	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 3237	 0.01284	 0.037037	 0.0016	 774	 774	 774	 0.0	 0.0	 1	 -30.0	 30.0;
	5323	 3238	 0.038549	 0.083144	 0.001	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	4627	 3239	 0.031998	 0.068027	 0.0007	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	5021	 3239	 0.045352	 0.09675	 0.001	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	5579	 3240	 0.050894	 0.128748	 0.0014	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	5580	 3241	 0.002041	 0.003736	 0.0002	 7124	 7124	 7124	 0.0	 0.0	 1	 -30.0	 30.0;
	4609	 3242	 0.124501	 0.227898	 0.0024	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	3429	 3243	 0.021605	 0.058765	 0.0028	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	4313	 3243	 0.042469	 0.107778	 0.005	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	5557	 3243	 0.029259	 0.074074	 0.0036	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	5830	 3244	 0.017637	 0.046611	 0.0006	 611	 611	 611	 0.0	 0.0	 1	 -30.0	 30.0;
	5745	 3244	 0.030234	 0.082389	 0.001	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	4780	 3245	 0.01	 0.027407	 0.0013	 1019	 1019	 1019	 0.0	 0.0	 1	 -30.0	 30.0;
	5640	 3245	 0.008642	 0.022222	 0.001	 1246	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	4136	 3246	 0.009007	 0.043872	 0.0749	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 3246	 0.002738	 0.018562	 0.04	 503.0	 503.0	 503.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5509	 3246	 0.002078	 0.008442	 0.0152	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3643	 3248	 0.004082	 0.00907	 0.0031	 3058	 3058	 3058	 0.0	 0.0	 1	 -30.0	 30.0;
	3643	 3247	 0.004082	 0.00907	 0.0031	 3058	 3058	 3058	 0.0	 0.0	 1	 -30.0	 30.0;
	3643	 3249	 0.004707	 0.008615	 0.0033	 3099	 3099	 3099	 0.0	 0.0	 1	 -30.0	 30.0;
	3430	 3251	 0.024568	 0.105062	 0.0049	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	4439	 3251	 0.01963	 0.05321	 0.0038	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	5187	 3251	 0.047284	 0.121728	 0.0058	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	4785	 3253	 0.043457	 0.183457	 0.0094	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	5313	 3254	 0.002704	 0.018296	 0.0008	 1606	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	4665	 3255	 0.021099	 0.079901	 0.0235	 375	 375	 375	 0.0	 0.0	 1	 -30.0	 30.0;
	3572	 3256	 2.8e-05	 0.000172	 0.0243	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5581	 3257	 0.009582	 0.017539	 0.0002	 1522	 1522	 1522	 0.0	 0.0	 1	 -30.0	 30.0;
	4551	 3259	 0.020569	 0.065387	 0.0217	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	3940	 3260	 0.000126	 0.000261	 0.0152	 107251	 107251	 107251	 0.0	 0.0	 1	 -30.0	 30.0;
	4228	 3262	 0.008062	 0.034266	 0.0004	 864	 864	 864	 0.0	 0.0	 1	 -30.0	 30.0;
	4230	 3263	 0.00083	 0.003931	 0.0071	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4879	 3263	 0.002825	 0.018943	 0.0344	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4886	 3263	 0.003338	 0.019161	 0.0349	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4229	 3263	 0.00083	 0.003832	 0.0071	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4879	 3263	 0.002588	 0.017264	 0.0314	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4391	 3264	 0.000356	 0.000988	 0.1094	 280.0	 280.0	 280.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4764	 3265	 0.119848	 0.219381	 0.0023	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	4969	 3266	 0.002568	 0.011358	 0.1539	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5582	 3266	 0.000454	 0.00399	 0.3675	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4969	 3266	 0.000909	 0.007901	 0.4445	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 3267	 0.090955	 0.301083	 0.0031	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	5122	 3267	 0.03351	 0.067271	 0.0007	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	5534	 3267	 0.039305	 0.132527	 0.0015	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	4467	 3269	 0.067271	 0.186445	 0.0021	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	3277	 3271	 2.5e-05	 0.015117	 0.0	 2012	 2012	 2012	 0.0	 0.0	 1	 -30.0	 30.0;
	3645	 3271	 0.013694	 0.025067	 0.0002	 1065	 1065	 1065	 0.0	 0.0	 1	 -30.0	 30.0;
	5606	 3271	 0.018392	 0.078105	 0.001	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	3276	 3271	 2.5e-05	 0.015117	 0.0	 2012	 2012	 2012	 0.0	 0.0	 1	 -30.0	 30.0;
	3645	 3271	 0.003729	 0.007886	 0.0071	 3487	 3487	 3487	 0.0	 0.0	 1	 -30.0	 30.0;
	5605	 3271	 0.018392	 0.078105	 0.001	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	3279	 3272	 2e-06	 0.001185	 0.0	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3278	 3272	 2e-06	 0.001185	 0.0	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4030	 3280	 0.000943	 0.001727	 0.0008	 15045	 15045	 15045	 0.0	 0.0	 1	 -30.0	 30.0;
	4323	 3284	 0.000425	 0.001934	 0.003	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4861	 3287	 0.045603	 0.140338	 0.002	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5584	 3288	 0.006803	 0.014109	 0.001	 1885	 1885	 1885	 0.0	 0.0	 1	 -30.0	 30.0;
	3493	 3290	 0.009574	 0.051902	 0.0006	 577	 577	 577	 0.0	 0.0	 1	 -30.0	 30.0;
	3861	 3290	 0.015319	 0.073998	 0.0104	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	3929	 3291	 0.005798	 0.039696	 0.0724	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5772	 3291	 0.004938	 0.033165	 0.0607	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4644	 3293	 0.048123	 0.122197	 0.0013	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	4644	 3292	 0.048123	 0.122197	 0.0013	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	4267	 3294	 0.015569	 0.028499	 0.0003	 927	 927	 927	 0.0	 0.0	 1	 -30.0	 30.0;
	3392	 3295	 0.010859	 0.046964	 0.0052	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	4538	 3295	 0.003527	 0.008566	 0.0001	 3284	 3284	 3284	 0.0	 0.0	 1	 -30.0	 30.0;
	3392	 3295	 0.048375	 0.191988	 0.0019	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	4406	 3296	 0.015369	 0.043336	 0.0373	 643	 643	 643	 0.0	 0.0	 1	 -30.0	 30.0;
	5397	 3297	 0.043109	 0.117511	 0.0012	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	4199	 3299	 0.042026	 0.104837	 0.0139	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	5162	 3301	 0.028219	 0.071554	 0.0008	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 3301	 0.041068	 0.105568	 0.0012	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	5824	 3302	 0.000123	 0.001235	 0.0	 23932	 23932	 23932	 0.0	 0.0	 1	 -30.0	 30.0;
	4294	 3304	 0.006853	 0.042454	 0.075	 708	 708	 708	 0.0	 0.0	 1	 -30.0	 30.0;
	5372	 3304	 0.029353	 0.078786	 0.0009	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	5576	 3304	 0.007055	 0.02066	 0.0011	 1394	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	5741	 3304	 0.035021	 0.089065	 0.0016	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	3683	 3305	 0.001058	 0.001937	 0.161	 14024	 14024	 14024	 0.0	 0.0	 1	 -30.0	 30.0;
	4815	 3307	 0.003704	 0.008519	 0.0037	 3198	 3198	 3198	 0.0	 0.0	 1	 -30.0	 30.0;
	5167	 3308	 0.031728	 0.080494	 0.0037	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	5730	 3308	 0.048642	 0.123333	 0.0058	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5300	 3314	 0.004031	 0.013102	 0.0121	 2154	 2154	 2154	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 3314	 0.015621	 0.039808	 0.0017	 691	 691	 691	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 3315	 0.011842	 0.041824	 0.0472	 680	 680	 680	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 3316	 0.001027	 0.012543	 0.0243	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 3316	 0.006935	 0.036516	 0.0663	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 3316	 0.001798	 0.012089	 0.0223	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3527	 3316	 4.8e-05	 8.8e-05	 0.001	 308192	 308192	 308192	 0.0	 0.0	 1	 -30.0	 30.0;
	3526	 3316	 4.8e-05	 8.8e-05	 0.001	 308192	 308192	 308192	 0.0	 0.0	 1	 -30.0	 30.0;
	3842	 3317	 0.008062	 0.019904	 0.0002	 1417	 1417	 1417	 0.0	 0.0	 1	 -30.0	 30.0;
	3421	 3319	 0.02037	 0.053951	 0.0026	 516	 516	 516	 0.0	 0.0	 1	 -30.0	 30.0;
	4275	 3320	 0.001111	 0.004568	 0.0002	 6319	 6319	 6319	 0.0	 0.0	 1	 -30.0	 30.0;
	3696	 3321	 0.005906	 0.026627	 0.0456	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3696	 3322	 0.005906	 0.026627	 0.0445	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 3324	 0.064979	 0.182263	 0.0021	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	5566	 3324	 0.044092	 0.112119	 0.0	 253	 253	 253	 0.0	 0.0	 1	 -30.0	 30.0;
	4842	 3326	 0.001039	 0.001902	 0.0048	 13848	 13848	 13848	 0.0	 0.0	 1	 -30.0	 30.0;
	4842	 3325	 0.00126	 0.004031	 0.0056	 7105	 7105	 7105	 0.0	 0.0	 1	 -30.0	 30.0;
	4279	 3328	 0.017385	 0.047367	 0.0102	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	5033	 3328	 0.07483	 0.18972	 0.0071	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	5316	 3328	 0.008617	 0.035097	 0.0015	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	5586	 3330	 0.02066	 0.056437	 0.0006	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	5240	 3332	 0.081975	 0.191605	 0.0088	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	5027	 3334	 0.003522	 0.006446	 0.0038	 3901	 3901	 3901	 0.0	 0.0	 1	 -30.0	 30.0;
	5027	 3333	 0.003522	 0.006446	 0.0036	 3901	 3901	 3901	 0.0	 0.0	 1	 -30.0	 30.0;
	4434	 3336	 0.068783	 0.125976	 0.0013	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 3337	 0.000988	 0.001975	 0.0	 11822	 11822	 11822	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 3338	 0.010582	 0.028219	 0.0	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	3516	 3339	 0.004573	 0.020316	 0.0405	 289.0	 289.0	 289.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5609	 3341	 0.009259	 0.023457	 0.0011	 1178	 1178	 1178	 0.0	 0.0	 1	 -30.0	 30.0;
	3765	 3342	 0.028975	 0.194759	 0.0031	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	4605	 3342	 0.010834	 0.038801	 0.0005	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	5086	 3342	 0.005291	 0.022172	 0.0002	 1257	 1257	 1257	 0.0	 0.0	 1	 -30.0	 30.0;
	3765	 3342	 0.029226	 0.194507	 0.0031	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	5629	 3342	 0.009574	 0.037793	 0.0005	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	5762	 3342	 0.041068	 0.104308	 0.0012	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 3343	 0.002825	 0.019239	 0.0476	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5591	 3347	 0.014613	 0.029226	 0.0003	 931	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	5592	 3347	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	3349	 3348	 0.007559	 0.025447	 0.0239	 1146	 1146	 1146	 0.0	 0.0	 1	 -30.0	 30.0;
	5590	 3349	 0.030738	 0.075586	 0.0009	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 3350	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5477	 3351	 0.013086	 0.035309	 0.0016	 789	 789	 789	 0.0	 0.0	 1	 -30.0	 30.0;
	4954	 3351	 0.036173	 0.097654	 0.0047	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	3925	 3352	 0.00952	 0.017427	 0.0134	 1443	 1443	 1443	 0.0	 0.0	 1	 -30.0	 30.0;
	3925	 3352	 0.010756	 0.019689	 0.0156	 1278	 1278	 1278	 0.0	 0.0	 1	 -30.0	 30.0;
	5319	 3354	 0.093726	 0.249685	 0.0028	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 3357	 0.007723	 0.044444	 0.082	 472.0	 472.0	 472.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3480	 3358	 0.002222	 0.005556	 0.0198	 4964	 4964	 4964	 0.0	 0.0	 1	 -30.0	 30.0;
	4660	 3358	 0.015309	 0.065926	 0.0032	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	4660	 3358	 0.015309	 0.065926	 0.0032	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	4573	 3359	 0.014916	 0.060544	 0.0006	 533	 533	 533	 0.0	 0.0	 1	 -30.0	 30.0;
	4339	 3360	 0.001659	 0.011575	 0.0091	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4339	 3360	 0.001659	 0.011575	 0.0091	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 3363	 0.03351	 0.084404	 0.001	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 3363	 0.03351	 0.084656	 0.001	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	3366	 3365	 2.1e-05	 0.000339	 0.0087	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3367	 3365	 2.1e-05	 0.000325	 0.0087	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5598	 3368	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5115	 3369	 0.011338	 0.038549	 0.0	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	5216	 3369	 0.025498	 0.054926	 0.0008	 503	 503	 503	 0.0	 0.0	 1	 -30.0	 30.0;
	5600	 3371	 0.006299	 0.018392	 0.0	 1519	 1519	 1519	 0.0	 0.0	 1	 -30.0	 30.0;
	5601	 3372	 2.5e-05	 0.000123	 0.0002	 241598	 241598	 241598	 0.0	 0.0	 1	 -30.0	 30.0;
	3828	 3373	 0.039808	 0.137566	 0.0016	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	4329	 3373	 0.078861	 0.250945	 0.0029	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	5718	 3373	 0.033762	 0.143865	 0.0017	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	3828	 3373	 0.039808	 0.13681	 0.0025	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 3374	 0.004741	 0.022124	 0.038	 320.0	 320.0	 320.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4398	 3375	 0.03321	 0.071358	 0.0032	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	5532	 3376	 0.014361	 0.039053	 0.0005	 815	 815	 815	 0.0	 0.0	 1	 -30.0	 30.0;
	5531	 3377	 0.013857	 0.039808	 0.0001	 805	 805	 805	 0.0	 0.0	 1	 -30.0	 30.0;
	5083	 3379	 0.14768	 0.270326	 0.001	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	3892	 3380	 0.030738	 0.083648	 0.0009	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	3892	 3380	 0.031746	 0.08642	 0.0009	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	5131	 3381	 0.199295	 0.440917	 0.005	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	4584	 3383	 0.000198	 0.000751	 0.0921	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3878	 3384	 0.01285	 0.032754	 0.0004	 865	 865	 865	 0.0	 0.0	 1	 -30.0	 30.0;
	4833	 3384	 0.041572	 0.105316	 0.0012	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	3915	 3389	 0.035273	 0.120181	 0.0014	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	5532	 3389	 0.048123	 0.131771	 0.0032	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	3916	 3389	 0.035273	 0.120181	 0.0014	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	5531	 3389	 0.045603	 0.131519	 0.0002	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	3917	 3390	 0.002133	 0.009659	 0.0162	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4285	 3391	 0.044848	 0.142857	 0.0017	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	3534	 3392	 0.03351	 0.11295	 0.0033	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 3392	 0.076846	 0.262535	 0.003	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	5294	 3392	 0.044092	 0.149912	 0.0017	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	5507	 3392	 0.019652	 0.062232	 0.0007	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	4019	 3393	 0.002438	 0.016458	 0.0314	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4019	 3393	 0.00243	 0.016454	 0.0319	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5605	 3395	 0.001764	 0.007811	 0.0001	 3799	 3799	 3799	 0.0	 0.0	 1	 -30.0	 30.0;
	5476	 3396	 0.007307	 0.029982	 0.0004	 929	 929	 929	 0.0	 0.0	 1	 -30.0	 30.0;
	3398	 3397	 0.001512	 0.006551	 0.0001	 4524	 4524	 4524	 0.0	 0.0	 1	 -30.0	 30.0;
	4123	 3399	 0.057445	 0.119678	 0.0019	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	4035	 3400	 0.000356	 0.001422	 0.0	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5607	 3401	 0.000227	 0.000605	 0.0	 46388	 46388	 46388	 0.0	 0.0	 1	 -30.0	 30.0;
	4053	 3404	 0.029982	 0.082892	 0.001	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	3904	 3408	 0.077324	 0.210154	 0.0033	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	4962	 3409	 0.000616	 0.006627	 0.1531	 1754.0	 1754.0	 1754.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5610	 3410	 0.004975	 0.009106	 0.0065	 2846	 2846	 2846	 0.0	 0.0	 1	 -30.0	 30.0;
	4448	 3411	 0.009574	 0.026707	 0.0	 1072	 1072	 1072	 0.0	 0.0	 1	 -30.0	 30.0;
	3973	 3412	 0.00716	 0.029506	 0.0015	 979	 979	 979	 0.0	 0.0	 1	 -30.0	 30.0;
	4027	 3412	 0.039877	 0.111605	 0.0052	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	3973	 3412	 0.00716	 0.029506	 0.0015	 979	 979	 979	 0.0	 0.0	 1	 -30.0	 30.0;
	4138	 3413	 0.034517	 0.135551	 0.0025	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	5755	 3414	 0.012593	 0.034444	 0.0016	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	5271	 3415	 0.036489	 0.066792	 0.0007	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	5546	 3415	 0.049887	 0.126732	 0.0014	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	4100	 3416	 0.038272	 0.080494	 0.0037	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	4319	 3417	 0.043084	 0.144873	 0.002	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	5405	 3419	 0.054674	 0.165281	 0.002	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	3874	 3420	 0.000776	 0.004612	 0.1736	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5117	 3420	 0.000119	 0.000691	 0.0076	 397.0	 397.0	 397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5116	 3420	 0.000119	 0.000711	 0.0071	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5363	 3420	 0.001126	 0.005965	 0.0162	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3728	 3422	 0.051146	 0.212094	 0.0081	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	3885	 3422	 0.104208	 0.284303	 0.0028	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 3424	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	4340	 3425	 0.013901	 0.039222	 0.002	 729	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 3425	 0.011605	 0.032963	 0.0	 868	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	4340	 3425	 0.01358	 0.039012	 0.0019	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	5614	 3427	 0.017778	 0.049753	 0.0023	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	3517	 3430	 0.043827	 0.090247	 0.0454	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	4602	 3432	 0.050643	 0.136054	 0.0015	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 3432	 0.034266	 0.093978	 0.001	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	3764	 3434	 0.066112	 0.16775	 0.0019	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	4911	 3435	 0.032364	 0.095227	 0.0297	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	5615	 3436	 0.028219	 0.078105	 0.0008	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	3440	 3437	 0.063492	 0.168556	 0.002	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	4233	 3437	 0.01033	 0.019148	 0.0204	 1358	 1358	 1358	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 3437	 0.017889	 0.045603	 0.0021	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	5764	 3438	 0.035273	 0.121693	 0.0014	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5616	 3439	 0.000302	 0.00252	 0.0001	 13444	 13444	 13444	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 3440	 0.102797	 0.27614	 0.003	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 3441	 0.05039	 0.138574	 0.0015	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 3442	 0.008284	 0.020679	 0.001	 1334	 1334	 1334	 0.0	 0.0	 1	 -30.0	 30.0;
	5617	 3444	 0.02066	 0.056689	 0.0006	 490	 490	 490	 0.0	 0.0	 1	 -30.0	 30.0;
	5226	 3446	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5227	 3446	 0.000252	 0.00252	 0.0006	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 3446	 0.079012	 0.200277	 0.0023	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 3447	 0.008272	 0.021111	 0.0042	 1340	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 3448	 0.004568	 0.012963	 0.0463	 2162	 2162	 2162	 0.0	 0.0	 1	 -30.0	 30.0;
	4960	 3448	 0.004444	 0.018889	 0.0028	 1531	 1531	 1531	 0.0	 0.0	 1	 -30.0	 30.0;
	4960	 3448	 0.004444	 0.018765	 0.0028	 1541	 1541	 1541	 0.0	 0.0	 1	 -30.0	 30.0;
	5618	 3449	 0.016377	 0.0451	 0.0005	 634	 634	 634	 0.0	 0.0	 1	 -30.0	 30.0;
	3548	 3450	 0.023683	 0.137818	 0.0132	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	5529	 3452	 0.00379	 0.015753	 0.0008	 1834	 1834	 1834	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 3453	 0.007407	 0.020247	 0.001	 1378	 1378	 1378	 0.0	 0.0	 1	 -30.0	 30.0;
	5767	 3454	 0.062988	 0.171328	 0.005	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	5619	 3455	 0.042555	 0.090678	 0.001	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	4771	 3456	 0.017637	 0.075334	 0.002	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	5264	 3459	 0.024568	 0.065432	 0.0031	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	5620	 3461	 0.001008	 0.002771	 0.0	 10014	 10014	 10014	 0.0	 0.0	 1	 -30.0	 30.0;
	3507	 3462	 0.022593	 0.102222	 0.005	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 3463	 0.001993	 0.020458	 0.0638	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 3463	 0.001993	 0.020472	 0.0638	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 3466	 0.001966	 0.003599	 0.0024	 6987	 6987	 6987	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 3468	 0.001367	 0.002502	 0.0013	 10050	 10050	 10050	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 3465	 0.001284	 0.00235	 0.0013	 10699	 10699	 10699	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 3467	 0.001025	 0.001876	 0.001	 13403	 13403	 13403	 0.0	 0.0	 1	 -30.0	 30.0;
	4871	 3474	 0.003527	 0.007055	 0.0069	 3633	 3633	 3633	 0.0	 0.0	 1	 -30.0	 30.0;
	4871	 3473	 0.003527	 0.007055	 0.0069	 3633	 3633	 3633	 0.0	 0.0	 1	 -30.0	 30.0;
	5320	 3475	 0.027463	 0.092215	 0.001	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	5369	 3475	 0.018141	 0.058957	 0.0007	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	5468	 3475	 0.002016	 0.01285	 0.0002	 2203	 2203	 2203	 0.0	 0.0	 1	 -30.0	 30.0;
	5349	 3475	 0.027211	 0.0839	 0.001	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	5497	 3475	 0.006551	 0.019652	 0.0002	 1384	 1384	 1384	 0.0	 0.0	 1	 -30.0	 30.0;
	5548	 3475	 0.006803	 0.02066	 0.0002	 1318	 1318	 1318	 0.0	 0.0	 1	 -30.0	 30.0;
	3712	 3477	 0.077161	 0.214321	 0.0341	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	3549	 3478	 0.002686	 0.018173	 0.0324	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4219	 3478	 0.005748	 0.03836	 0.0688	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4393	 3479	 0.122222	 0.31804	 0.0041	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	4406	 3479	 0.03477	 0.095238	 0.0012	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	3538	 3481	 0.097254	 0.284455	 0.0034	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	4115	 3481	 0.039808	 0.166793	 0.0021	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	5540	 3483	 0.005562	 0.010181	 0.0001	 2546	 2546	 2546	 0.0	 0.0	 1	 -30.0	 30.0;
	5621	 3485	 0.007037	 0.023951	 0.0011	 1190	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	4449	 3486	 0.000277	 0.002588	 0.0051	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4310	 3487	 0.043739	 0.148602	 0.0017	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	4399	 3487	 0.044696	 0.118317	 0.0016	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5474	 3487	 0.02973	 0.08516	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5475	 3487	 0.029982	 0.085664	 0.0	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	5622	 3488	 0.027715	 0.077601	 0.0009	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	4380	 3490	 0.008566	 0.055682	 0.0007	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	4744	 3490	 0.052381	 0.142605	 0.0019	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 3490	 0.007559	 0.017385	 0.0015	 1605	 1605	 1605	 0.0	 0.0	 1	 -30.0	 30.0;
	4380	 3490	 0.008566	 0.055682	 0.0007	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	3560	 3491	 0.035556	 0.097037	 0.0045	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5045	 3491	 0.024198	 0.064444	 0.0242	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	5045	 3491	 0.024198	 0.064444	 0.0242	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	5623	 3492	 0.027211	 0.062988	 0.0007	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	3861	 3493	 0.008566	 0.03477	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	3496	 1494	 2e-05	 0.000198	 0.0	 393.0	 393.0	 393.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5268	 3499	 0.000252	 0.001008	 0.0	 28417	 28417	 28417	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 3500	 0.006608	 0.012096	 0.0002	 2143	 2143	 2143	 0.0	 0.0	 1	 -30.0	 30.0;
	4002	 3501	 0.067422	 0.186621	 0.0021	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	4561	 3501	 0.06198	 0.216931	 0.002	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	5093	 3501	 0.059965	 0.147896	 0.0017	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	5625	 3501	 0.003527	 0.007811	 0.0	 3446	 3446	 3446	 0.0	 0.0	 1	 -30.0	 30.0;
	4003	 3502	 0.002647	 0.011911	 0.0213	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4602	 3503	 0.010582	 0.02973	 0.0003	 936	 936	 936	 0.0	 0.0	 1	 -30.0	 30.0;
	4781	 3504	 0.020741	 0.058272	 0.0026	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 3505	 0.014059	 0.045578	 0.0006	 620	 620	 620	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 3506	 0.108592	 0.296548	 0.0033	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	3973	 3507	 0.008272	 0.056173	 0.0028	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	4828	 3507	 0.047654	 0.197901	 0.0102	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	5789	 3507	 0.011482	 0.072099	 0.0039	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	3973	 3507	 0.007531	 0.052593	 0.0028	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	3973	 3507	 0.007778	 0.055556	 0.0029	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	4026	 3510	 0.083648	 0.239859	 0.0026	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	4026	 3510	 0.0839	 0.240615	 0.0026	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 3511	 0.001659	 0.011081	 0.0203	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 3511	 0.002509	 0.011319	 0.0203	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3828	 3512	 0.012346	 0.039053	 0.0005	 743	 743	 743	 0.0	 0.0	 1	 -30.0	 30.0;
	4544	 3515	 0.008818	 0.038045	 0.0	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	5000	 3514	 0.013857	 0.047115	 0.001	 602	 602	 602	 0.0	 0.0	 1	 -30.0	 30.0;
	5376	 3515	 0.030486	 0.07735	 0.003	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	5780	 3514	 0.008818	 0.037793	 0.0	 761	 761	 761	 0.0	 0.0	 1	 -30.0	 30.0;
	4787	 3516	 0.004523	 0.026983	 0.0506	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4040	 3521	 0.000928	 0.006183	 0.0111	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5705	 3521	 0.000217	 0.001481	 0.003	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5812	 3522	 7e-06	 0.00013	 0.0029	 2694.0	 2694.0	 2694.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4416	 3523	 0.04258	 0.102797	 0.0067	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	5629	 3525	 0.001764	 0.003527	 0.0013	 7266	 7266	 7266	 0.0	 0.0	 1	 -30.0	 30.0;
	5631	 3528	 0.00068	 0.00126	 0.0	 21242	 21242	 21242	 0.0	 0.0	 1	 -30.0	 30.0;
	4164	 3529	 0.004031	 0.01285	 0.0002	 2259	 2259	 2259	 0.0	 0.0	 1	 -30.0	 30.0;
	4808	 3531	 0.001605	 0.007407	 0.0296	 4085	 4085	 4085	 0.0	 0.0	 1	 -30.0	 30.0;
	5060	 3531	 0.016173	 0.061728	 0.0005	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	5422	 3531	 0.001235	 0.004938	 0.0141	 6818	 6818	 6818	 0.0	 0.0	 1	 -30.0	 30.0;
	4096	 3532	 0.000111	 0.000741	 0.0014	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 3532	 0.001857	 0.008375	 0.0142	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4095	 3532	 9.9e-05	 0.000711	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4254	 3533	 0.000198	 0.000909	 0.001	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5820	 3534	 0.070547	 0.232552	 0.0026	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	4052	 3538	 0.08642	 0.205341	 0.0029	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	4115	 3538	 0.032754	 0.137818	 0.0022	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 3538	 0.049131	 0.134039	 0.0015	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	5634	 3541	 0.019652	 0.082389	 0.0001	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 3543	 0.016377	 0.041572	 0.0005	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	5068	 3543	 0.008566	 0.027715	 0.0006	 1049	 1049	 1049	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 3543	 0.01285	 0.040816	 0.0005	 711	 711	 711	 0.0	 0.0	 1	 -30.0	 30.0;
	5635	 3545	 0.000494	 0.001358	 0.0	 20555	 20555	 20555	 0.0	 0.0	 1	 -30.0	 30.0;
	5008	 3546	 0.000252	 0.00126	 0.0012	 23178	 23178	 23178	 0.0	 0.0	 1	 -30.0	 30.0;
	4352	 3547	 0.076846	 0.15999	 0.009	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	4883	 3548	 0.039305	 0.134039	 0.0016	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5168	 3548	 0.007055	 0.0451	 0.0006	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	5468	 3548	 0.033006	 0.10456	 0.005	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	5520	 3548	 0.056689	 0.119174	 0.0099	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	5697	 3548	 0.069539	 0.23608	 0.0028	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	5172	 3548	 0.007055	 0.044596	 0.0006	 635	 635	 635	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 3551	 0.007811	 0.014297	 0.0088	 1867	 1867	 1867	 0.0	 0.0	 1	 -30.0	 30.0;
	4881	 3552	 0.015117	 0.051146	 0.003	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	4881	 3552	 0.020912	 0.056941	 0.0007	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	3871	 3553	 0.013274	 0.060326	 0.1043	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 3554	 0.000252	 0.00252	 0.001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	3558	 3555	 2e-05	 0.000198	 0.0091	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3558	 3556	 2e-05	 0.000198	 0.0051	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4009	 3559	 0.045352	 0.126984	 0.0081	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 3559	 0.114215	 0.20907	 0.0039	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	5328	 3560	 0.031605	 0.086173	 0.004	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	5122	 3561	 0.023683	 0.0645	 0.0007	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	4715	 3562	 0.022728	 0.059679	 0.0032	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 3563	 0.019136	 0.049012	 0.0023	 567	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	4002	 3564	 0.053918	 0.133787	 0.002	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	4561	 3564	 0.023683	 0.056941	 0.001	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	4002	 3564	 0.053666	 0.133787	 0.001	 208	 208	 208	 0.0	 0.0	 1	 -30.0	 30.0;
	3974	 3565	 0.105064	 0.214412	 0.002	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	4999	 3566	 0.004701	 0.030064	 0.0547	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 3569	 0.105064	 0.275888	 0.0034	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	5622	 3569	 0.044596	 0.125472	 0.0013	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	4038	 3572	 0.001343	 0.007862	 0.0142	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4499	 3574	 2.8e-05	 0.000145	 0.0606	 855.0	 855.0	 855.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 3573	 5e-06	 0.0001	 0.0	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3573	 1492	 1e-05	 0.0001	 0.0	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4511	 3575	 0.026455	 0.072562	 0.0008	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	5707	 3575	 0.032552	 0.067674	 0.0007	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	3837	 3577	 0.002431	 0.004449	 0.0121	 5982	 5982	 5982	 0.0	 0.0	 1	 -30.0	 30.0;
	5275	 3577	 0.052839	 0.133951	 0.0084	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 3577	 0.020123	 0.051358	 0.0123	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	5827	 3577	 0.022839	 0.058025	 0.007	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	4644	 3578	 0.000504	 0.00252	 0.0004	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5637	 3581	 0.000252	 0.000504	 0.001	 52417	 52417	 52417	 0.0	 0.0	 1	 -30.0	 30.0;
	5639	 3582	 0.000252	 0.000504	 0.001	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	3384	 3583	 0.00907	 0.0226	 0.0002	 1249	 1249	 1249	 0.0	 0.0	 1	 -30.0	 30.0;
	3878	 3583	 0.003779	 0.015873	 0.0133	 1864	 1864	 1864	 0.0	 0.0	 1	 -30.0	 30.0;
	5638	 3585	 9.9e-05	 0.000182	 0.0004	 151236	 151236	 151236	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 3586	 0.00073	 0.001335	 0.1104	 20343	 20343	 20343	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 3587	 0.002016	 0.005543	 0.0001	 5006	 5006	 5006	 0.0	 0.0	 1	 -30.0	 30.0;
	3979	 3587	 0.028975	 0.121945	 0.0015	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 3588	 0.018038	 0.057792	 0.0916	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	5447	 3588	 0.001798	 0.004543	 0.0081	 6284	 6284	 6284	 0.0	 0.0	 1	 -30.0	 30.0;
	3734	 3589	 0.015873	 0.106828	 0.0018	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	5446	 3592	 0.02973	 0.080877	 0.0009	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 3593	 0.016864	 0.057074	 0.0042	 510	 510	 510	 0.0	 0.0	 1	 -30.0	 30.0;
	5561	 3593	 0.009136	 0.029136	 0.0015	 994	 994	 994	 0.0	 0.0	 1	 -30.0	 30.0;
	4297	 3595	 0.005039	 0.03351	 0.0009	 872	 872	 872	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 3595	 0.013605	 0.056437	 0.0007	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	4180	 3598	 8e-06	 0.0001	 0.002	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 3598	 8e-06	 0.0001	 0.002	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 3599	 0.006543	 0.017284	 0.0008	 1641	 1641	 1641	 0.0	 0.0	 1	 -30.0	 30.0;
	4316	 3600	 0.000909	 0.003299	 0.0051	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4225	 3601	 0.058201	 0.159486	 0.0021	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 3603	 0.02318	 0.078609	 0.0018	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 3603	 0.023935	 0.098765	 0.0019	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5616	 3603	 0.005039	 0.022424	 0.0005	 1476	 1476	 1476	 0.0	 0.0	 1	 -30.0	 30.0;
	5643	 3604	 0.049635	 0.125976	 0.0014	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	3388	 3607	 0.002627	 0.017284	 0.0435	 1771	 1771	 1771	 0.0	 0.0	 1	 -30.0	 30.0;
	4040	 3607	 0.002272	 0.011239	 0.0203	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 3607	 0.002574	 0.013541	 0.0349	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4635	 3605	 0.001817	 0.012207	 0.0223	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5016	 3605	 0.000375	 0.002509	 0.0051	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5385	 3607	 0.000356	 0.002311	 0.004	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5463	 3606	 0.003081	 0.020089	 0.0375	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5015	 3606	 0.000375	 0.002528	 0.0051	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5173	 3607	 0.001798	 0.010133	 0.0182	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 3607	 0.00097	 0.009481	 0.037	 720.0	 720.0	 720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5342	 3605	 0.001067	 0.007091	 0.0132	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5176	 3607	 0.000751	 0.007423	 0.0248	 833.0	 833.0	 833.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5341	 3605	 0.001067	 0.007091	 0.0132	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3361	 3608	 0.00099	 0.007576	 0.156	 1486.0	 1486.0	 1486.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4041	 3609	 0.000298	 0.003262	 0.0693	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4595	 3609	 0.000561	 0.006288	 0.1574	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4594	 3609	 0.000554	 0.006163	 0.1588	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4595	 3608	 0.000382	 0.005002	 0.1718	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4594	 3608	 0.000381	 0.005	 0.1733	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 3608	 0.000547	 0.006046	 0.1242	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4502	 3611	 0.040741	 0.087161	 0.004	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	5192	 3610	 0.003333	 0.008889	 0.0005	 3129	 3129	 3129	 0.0	 0.0	 1	 -30.0	 30.0;
	3399	 3612	 0.026455	 0.054674	 0.002	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	3399	 3612	 0.010859	 0.026153	 0.0501	 1043	 1043	 1043	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 3614	 0.048324	 0.129478	 0.0026	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	5794	 3614	 0.078045	 0.142861	 0.0014	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 3614	 0.048803	 0.125926	 0.0021	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	4609	 3615	 0.063492	 0.141345	 0.001	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	3893	 3616	 0.006262	 0.043595	 0.078	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4676	 3616	 0.001659	 0.011022	 0.0203	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5256	 3616	 0.002744	 0.018746	 0.0349	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4676	 3616	 0.001659	 0.011042	 0.0203	 538.0	 538.0	 538.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5645	 3618	 0.001764	 0.004283	 0.0001	 6375	 6375	 6375	 0.0	 0.0	 1	 -30.0	 30.0;
	3623	 3620	 0.000936	 0.001713	 0.0023	 15535	 15535	 15535	 0.0	 0.0	 1	 -30.0	 30.0;
	3623	 3619	 0.000936	 0.001713	 0.0023	 15535	 15535	 15535	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 3622	 0.022424	 0.054926	 0.0064	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 3621	 0.02318	 0.056437	 0.0066	 484	 484	 484	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 3623	 0.00284	 0.009877	 0.0018	 2951	 2951	 2951	 0.0	 0.0	 1	 -30.0	 30.0;
	5577	 3623	 0.004593	 0.011444	 0.0005	 2460	 2460	 2460	 0.0	 0.0	 1	 -30.0	 30.0;
	4464	 3623	 0.000345	 0.000632	 0.0011	 42115	 42115	 42115	 0.0	 0.0	 1	 -30.0	 30.0;
	3457	 3623	 0.001131	 0.00207	 0.0032	 12856	 12856	 12856	 0.0	 0.0	 1	 -30.0	 30.0;
	3738	 3624	 0.003694	 0.02481	 0.0456	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3898	 3624	 0.002963	 0.019793	 0.0694	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3997	 3624	 0.002647	 0.017659	 0.0324	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4823	 3624	 0.00719	 0.033264	 0.0618	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3872	 3625	 0.016813	 0.030776	 0.0213	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	5330	 3627	 0.014361	 0.048375	 0.0006	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	4093	 3627	 0.030234	 0.092719	 0.0025	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 3629	 0.006803	 0.015621	 0.0002	 1778	 1778	 1778	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 3630	 0.054321	 0.138148	 0.0063	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 3633	 0.007813	 0.014301	 0.0087	 1789	 1789	 1789	 0.0	 0.0	 1	 -30.0	 30.0;
	5510	 3634	 0.007569	 0.013855	 0.0089	 1815	 1815	 1815	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 3636	 0.000123	 0.001235	 0.0002	 23932	 23932	 23932	 0.0	 0.0	 1	 -30.0	 30.0;
	4795	 3638	 0.023935	 0.076846	 0.0009	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	5564	 3639	 0.096926	 0.251323	 0.0028	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	5200	 3640	 0.002771	 0.011842	 0.0177	 2428	 2428	 2428	 0.0	 0.0	 1	 -30.0	 30.0;
	3923	 3641	 0.003457	 0.015704	 0.0284	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4567	 3641	 0.00164	 0.021709	 0.0911	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3524	 3643	 0.006327	 0.011581	 0.0051	 2305	 2305	 2305	 0.0	 0.0	 1	 -30.0	 30.0;
	3647	 3643	 0.012572	 0.03865	 0.0009	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	3851	 3643	 0.002645	 0.01091	 0.0145	 2710	 2710	 2710	 0.0	 0.0	 1	 -30.0	 30.0;
	3647	 3643	 0.01101	 0.04447	 0.0006	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	4164	 3644	 0.022525	 0.063492	 0.0007	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	4481	 3646	 0.007307	 0.035525	 0.0005	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	4480	 3646	 0.0097	 0.039632	 0.0004	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	4172	 3648	 2e-05	 9.9e-05	 0.0121	 457.0	 457.0	 457.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4482	 3648	 0.000435	 0.002878	 0.0051	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5555	 3650	 0.017385	 0.044344	 0.0005	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	3652	 3651	 0.00252	 0.005039	 0.0	 5241	 5241	 5241	 0.0	 0.0	 1	 -30.0	 30.0;
	3976	 3651	 0.006922	 0.012671	 0.004	 2045	 2045	 2045	 0.0	 0.0	 1	 -30.0	 30.0;
	3976	 3652	 0.001512	 0.003527	 0.0	 7695	 7695	 7695	 0.0	 0.0	 1	 -30.0	 30.0;
	5758	 3654	 0.022676	 0.041824	 0.0004	 621	 621	 621	 0.0	 0.0	 1	 -30.0	 30.0;
	3668	 3655	 0.007559	 0.020156	 0.0002	 1413	 1413	 1413	 0.0	 0.0	 1	 -30.0	 30.0;
	3669	 3655	 0.017889	 0.044344	 0.0005	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	4208	 3655	 0.03477	 0.080625	 0.022	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	4010	 3656	 0.003931	 0.020365	 0.037	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4210	 3656	 0.002805	 0.012484	 0.0319	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3691	 3657	 0.069035	 0.197531	 0.0021	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	4428	 3657	 0.000151	 0.000479	 0.0002	 58788	 58788	 58788	 0.0	 0.0	 1	 -30.0	 30.0;
	5615	 3657	 0.029226	 0.080877	 0.0009	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	5472	 3657	 0.080373	 0.238095	 0.0649	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	4174	 3658	 0.007309	 0.049876	 0.0881	 538.0	 538.0	 538.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4603	 3658	 0.006044	 0.042114	 0.0729	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 3659	 0.009826	 0.020912	 0.0009	 1278	 1278	 1278	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 3659	 0.030234	 0.082389	 0.001	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	5647	 3660	 0.0052	 0.009518	 0.0	 2723	 2723	 2723	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 3661	 0.043084	 0.135047	 0.002	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	3686	 3662	 0.020864	 0.088765	 0.0064	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	3884	 3664	 0.040237	 0.102268	 0.0012	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	3996	 3666	 0.016444	 0.060815	 0.0046	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	4151	 3666	 0.000988	 0.002099	 0.0006	 13072	 13072	 13072	 0.0	 0.0	 1	 -30.0	 30.0;
	3738	 3667	 0.000612	 0.004128	 0.0081	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3972	 3667	 0.001225	 0.006854	 0.1397	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3997	 3667	 0.001738	 0.011615	 0.0213	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4120	 3670	 0.036105	 0.110809	 0.0021	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	3303	 3671	 0.001059	 0.003597	 0.0458	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3843	 3671	 0.009699	 0.044839	 0.0749	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4390	 3671	 0.001426	 0.009276	 0.0292	 366.0	 366.0	 366.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4552	 3671	 0.014143	 0.064395	 0.1134	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	4853	 3671	 0.003502	 0.02318	 0.0547	 366.0	 366.0	 366.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4853	 3671	 0.004543	 0.024889	 0.0435	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4842	 3673	 0.018645	 0.037037	 0.0183	 724	 724	 724	 0.0	 0.0	 1	 -30.0	 30.0;
	5649	 3675	 2e-05	 9.8e-05	 0.0	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3304	 3677	 0.02192	 0.062232	 0.0027	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	5576	 3677	 0.016125	 0.044596	 0.0005	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	5651	 3678	 0.003275	 0.00907	 0.0	 3062	 3062	 3062	 0.0	 0.0	 1	 -30.0	 30.0;
	5650	 3679	 2e-05	 0.000198	 0.001	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5411	 3680	 0.014361	 0.036029	 0.001	 762	 762	 762	 0.0	 0.0	 1	 -30.0	 30.0;
	5652	 3680	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5671	 3680	 0.022172	 0.046107	 0.001	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	4939	 3680	 0.014555	 0.026643	 0.0004	 973	 973	 973	 0.0	 0.0	 1	 -30.0	 30.0;
	5654	 3681	 5.9e-05	 0.000356	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 3682	 0.016352	 0.067347	 0.0015	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	4314	 3687	 0.065004	 0.177375	 0.002	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	4602	 3687	 0.069287	 0.190224	 0.0021	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 3688	 0.048963	 0.089626	 0.0009	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 3689	 0.119678	 0.248929	 0.0034	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 3692	 0.006803	 0.027967	 0.0073	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	5436	 3692	 0.002771	 0.009826	 0.0001	 2893	 2893	 2893	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 3692	 0.006803	 0.027967	 0.0073	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	4222	 3693	 0.012497	 0.033132	 0.0009	 834	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	4454	 3694	 0.06389	 0.11695	 0.0012	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	5657	 3695	 0.001126	 0.005037	 0.0091	 5986	 5986	 5986	 0.0	 0.0	 1	 -30.0	 30.0;
	4235	 3696	 0.004642	 0.030854	 0.0557	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5091	 3696	 0.001578	 0.010526	 0.0192	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 3696	 0.000119	 0.000889	 0.002	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 3702	 0.001351	 0.008986	 0.0303	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 3703	 0.001512	 0.005039	 0.0123	 5613	 5613	 5613	 0.0	 0.0	 1	 -30.0	 30.0;
	4489	 3703	 0.003779	 0.014865	 0.0185	 1925	 1925	 1925	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 3704	 0.001027	 0.006123	 0.2162	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4170	 3706	 0.010741	 0.027407	 0.0013	 1010	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	4783	 3706	 0.018272	 0.047901	 0.0023	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	4305	 3707	 0.000123	 0.000247	 0.0003	 109898	 109898	 109898	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 3708	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	4910	 3710	 0.084404	 0.230234	 0.0026	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 3711	 0.000454	 0.001235	 0.0001	 22757	 22757	 22757	 0.0	 0.0	 1	 -30.0	 30.0;
	4356	 3715	 0.026455	 0.058957	 0.0092	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	5083	 3719	 0.005926	 0.013827	 0.0	 1736	 1736	 1736	 0.0	 0.0	 1	 -30.0	 30.0;
	5094	 3719	 0.059259	 0.141284	 0.0005	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5661	 3722	 0.000194	 0.000624	 0.0009	 47367	 47367	 47367	 0.0	 0.0	 1	 -30.0	 30.0;
	4321	 3723	 0.015621	 0.066264	 0.0014	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	5660	 3725	 0.019331	 0.035384	 0.0003	 711	 711	 711	 0.0	 0.0	 1	 -30.0	 30.0;
	5762	 3724	 0.062736	 0.175611	 0.0017	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	4257	 3726	 0.003333	 0.026667	 0.0959	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 3727	 0.001146	 0.007625	 0.0142	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3714	 3728	 0.00126	 0.00252	 0.0031	 10480	 10480	 10480	 0.0	 0.0	 1	 -30.0	 30.0;
	4420	 3728	 0.007811	 0.043588	 0.0154	 667	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 3728	 0.044596	 0.151927	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	4420	 3728	 0.007811	 0.04384	 0.0155	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	3718	 3730	 9.9e-05	 0.000198	 0.0142	 138682	 138682	 138682	 0.0	 0.0	 1	 -30.0	 30.0;
	3717	 3730	 9.9e-05	 0.000198	 0.0182	 138682	 138682	 138682	 0.0	 0.0	 1	 -30.0	 30.0;
	4571	 3729	 9.9e-05	 0.000988	 0.004	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3716	 3730	 0.000111	 0.000223	 0.0213	 123245	 123245	 123245	 0.0	 0.0	 1	 -30.0	 30.0;
	4788	 3733	 0.001512	 0.002771	 0.0018	 9077	 9077	 9077	 0.0	 0.0	 1	 -30.0	 30.0;
	3923	 3735	 0.003477	 0.023822	 0.0456	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3864	 3738	 0.000324	 0.000992	 0.0729	 29661	 29661	 29661	 0.0	 0.0	 1	 -30.0	 30.0;
	5394	 3739	 0.019259	 0.038642	 0.0016	 688	 688	 688	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 3742	 0.017709	 0.032416	 0.0003	 824	 824	 824	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 3743	 0.00081	 0.005472	 0.0101	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 3743	 0.000751	 0.005057	 0.0127	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4569	 3744	 0.001884	 0.019197	 0.4621	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4569	 3744	 0.001891	 0.019134	 0.4621	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 3745	 0.046173	 0.123827	 0.0061	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5663	 3746	 0.029226	 0.076846	 0.0009	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	5180	 3747	 0.015667	 0.042753	 0.0019	 653	 653	 653	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 3749	 0.007889	 0.021309	 0.001	 1308	 1308	 1308	 0.0	 0.0	 1	 -30.0	 30.0;
	4483	 3750	 0.047367	 0.19224	 0.0025	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	4521	 3750	 0.083396	 0.277904	 0.0035	 102	 102	 102	 0.0	 0.0	 1	 -30.0	 30.0;
	5282	 3751	 0.001462	 0.009817	 0.0177	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 3754	 0.00126	 0.00252	 0.0024	 10170	 10170	 10170	 0.0	 0.0	 1	 -30.0	 30.0;
	3851	 3755	 0.007357	 0.027438	 0.0096	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	3867	 3755	 0.056614	 0.174528	 0.0021	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	4709	 3755	 0.021794	 0.095692	 0.012	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5053	 3755	 0.042504	 0.080071	 0.0011	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	4321	 3757	 0.03545	 0.095036	 0.0018	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	5403	 3758	 0.048148	 0.135062	 0.0062	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	4796	 3762	 0.000237	 0.001501	 0.003	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4612	 3764	 0.090199	 0.224994	 0.0258	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	4380	 3764	 0.016377	 0.067271	 0.0008	 440	 440	 440	 0.0	 0.0	 1	 -30.0	 30.0;
	5496	 3765	 0.015923	 0.064727	 0.0034	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	5825	 3765	 0.009574	 0.062232	 0.0008	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	4722	 3765	 0.01159	 0.073822	 0.001	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	4594	 3766	 0.000402	 0.005242	 0.1791	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4595	 3766	 0.000402	 0.005242	 0.1819	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5035	 3767	 0.057697	 0.196271	 0.0023	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	4745	 3778	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4703	 3779	 5.9e-05	 0.001126	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4702	 3778	 5.9e-05	 0.001126	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4719	 3786	 0.012099	 0.031852	 0.0015	 890	 890	 890	 0.0	 0.0	 1	 -30.0	 30.0;
	5683	 3786	 0.020617	 0.054198	 0.0026	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	4434	 3787	 0.009826	 0.032754	 0.0037	 864	 864	 864	 0.0	 0.0	 1	 -30.0	 30.0;
	5587	 3787	 0.004031	 0.013605	 0.0002	 2081	 2081	 2081	 0.0	 0.0	 1	 -30.0	 30.0;
	4447	 3788	 0.111867	 0.241875	 0.0026	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	5802	 3788	 0.02318	 0.062988	 0.0007	 454	 454	 454	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 3791	 0.023683	 0.101789	 0.0012	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	5667	 3792	 0.038801	 0.073066	 0.0008	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	4814	 3794	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	4816	 3794	 0.005795	 0.014865	 0.0	 1851	 1851	 1851	 0.0	 0.0	 1	 -30.0	 30.0;
	4813	 3794	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 3796	 0.000366	 0.000669	 0.0476	 40590	 40590	 40590	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 3795	 0.000352	 0.000645	 0.0466	 42124	 42124	 42124	 0.0	 0.0	 1	 -30.0	 30.0;
	3987	 3801	 0.003779	 0.007055	 0.0001	 3801	 3801	 3801	 0.0	 0.0	 1	 -30.0	 30.0;
	4274	 3801	 0.090627	 0.196951	 0.0022	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	4365	 3801	 0.17158	 0.354497	 0.0037	 78	 78	 78	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 3801	 0.082766	 0.238524	 0.0024	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5506	 3801	 0.066767	 0.18191	 0.002	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	3987	 3801	 0.003864	 0.007073	 0.0001	 3774	 3774	 3774	 0.0	 0.0	 1	 -30.0	 30.0;
	4724	 3802	 0.003121	 0.020997	 0.0385	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5502	 3802	 0.004602	 0.0208	 0.0365	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 3803	 0.002694	 0.028476	 0.6599	 1115	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	4985	 3805	 0.000751	 0.003417	 0.0061	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 3806	 0.075107	 0.190199	 0.0033	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	3813	 3807	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	3812	 3807	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	3811	 3807	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 3816	 0.041245	 0.109851	 0.0051	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	5241	 3817	 0.004233	 0.018695	 0.0293	 1495	 1495	 1495	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 3818	 0.018392	 0.117158	 0.0001	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	5669	 3819	 0.00083	 0.005491	 0.0101	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4149	 3821	 0.000375	 0.001422	 0.1893	 263.0	 263.0	 263.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4149	 3820	 0.000395	 0.001422	 0.1903	 20973	 20973	 20973	 0.0	 0.0	 1	 -30.0	 30.0;
	3877	 3823	 0.01741	 0.068582	 0.0008	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	3967	 3823	 0.013782	 0.036886	 0.0063	 773	 773	 773	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 3822	 0.00907	 0.038549	 0.0005	 768	 768	 768	 0.0	 0.0	 1	 -30.0	 30.0;
	3966	 3822	 0.013706	 0.045931	 0.0042	 635	 635	 635	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 3823	 0.00907	 0.038801	 0.0005	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	4323	 3824	 0.000494	 0.002963	 0.0051	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5058	 3827	 0.018889	 0.071482	 0.0006	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 3829	 0.129252	 0.352734	 0.005	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	5272	 3830	 0.004006	 0.010129	 0.0054	 2711	 2711	 2711	 0.0	 0.0	 1	 -30.0	 30.0;
	4991	 3831	 0.017133	 0.054674	 0.001	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	5084	 3831	 0.078105	 0.213656	 0.002	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	5459	 3832	 0.02968	 0.124313	 0.0015	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	5504	 3832	 0.021164	 0.079365	 0.001	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	5130	 3834	 0.029554	 0.078534	 0.0013	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	5671	 3834	 0.005291	 0.011842	 0.0	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	3882	 3835	 0.037284	 0.100247	 0.0052	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	4736	 3838	 0.000435	 0.0016	 0.1974	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4736	 3838	 0.000435	 0.00162	 0.2005	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4275	 3839	 0.004111	 0.013074	 0.0006	 2168	 2168	 2168	 0.0	 0.0	 1	 -30.0	 30.0;
	5673	 3840	 0.008272	 0.022222	 0.0011	 1253	 1253	 1253	 0.0	 0.0	 1	 -30.0	 30.0;
	5442	 3842	 0.065356	 0.160494	 0.0078	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	4552	 3843	 0.006499	 0.029472	 0.0506	 301.0	 301.0	 301.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4341	 3847	 0.067271	 0.170824	 0.002	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	5786	 3847	 0.012598	 0.054674	 0.001	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 3846	 0.004283	 0.051398	 0.0	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	4682	 3848	 0.004879	 0.022479	 0.0375	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4963	 3850	 0.017511	 0.074351	 0.0009	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	5504	 3850	 0.008541	 0.023154	 0.0007	 1197	 1197	 1197	 0.0	 0.0	 1	 -30.0	 30.0;
	5675	 3853	 9.9e-05	 0.000573	 0.0511	 53230	 53230	 53230	 0.0	 0.0	 1	 -30.0	 30.0;
	5674	 3852	 0.000138	 0.000435	 0.0445	 67907	 67907	 67907	 0.0	 0.0	 1	 -30.0	 30.0;
	5755	 3855	 0.046494	 0.092988	 0.0039	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5676	 3856	 0.001864	 0.007508	 0.0001	 3817	 3817	 3817	 0.0	 0.0	 1	 -30.0	 30.0;
	4723	 3859	 0.014198	 0.038148	 0.0018	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	3867	 3863	 0.019829	 0.137868	 0.0015	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	4500	 3865	 0.080877	 0.204334	 0.0043	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 3865	 0.038297	 0.131771	 0.0319	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 3865	 0.014613	 0.037289	 0.0025	 738	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	3923	 3866	 0.002943	 0.019773	 0.0354	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4246	 3866	 0.001679	 0.011101	 0.0203	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5677	 3869	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5678	 3869	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	4948	 3870	 0.102545	 0.213656	 0.0023	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	4948	 3870	 0.102545	 0.213656	 0.0023	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	5650	 3871	 0.006301	 0.028622	 0.0496	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4968	 3873	 0.002746	 0.014183	 0.1868	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4969	 3874	 0.002469	 0.013827	 0.1757	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5364	 3873	 0.002094	 0.010607	 0.1822	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4308	 3875	 0.074628	 0.18962	 0.0021	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	5679	 3876	 0.001008	 0.00252	 0.0027	 11206	 11206	 11206	 0.0	 0.0	 1	 -30.0	 30.0;
	4505	 3882	 0.035062	 0.095679	 0.0045	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	4612	 3883	 0.141245	 0.284127	 0.0032	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	5378	 3883	 0.065709	 0.181255	 0.002	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	4245	 3886	 0.000436	 0.000797	 0.001	 32501	 32501	 32501	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 3888	 0.007901	 0.029877	 0.0257	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	5302	 3890	 0.009323	 0.046598	 0.08	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5617	 3892	 0.06261	 0.148501	 0.0072	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5256	 3893	 0.004425	 0.029349	 0.0547	 578.0	 578.0	 578.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4581	 3895	 0.079365	 0.163517	 0.0021	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	4385	 3896	 0.069791	 0.190224	 0.0021	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	5072	 3898	 0.0032	 0.021472	 0.0385	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4632	 3899	 0.000824	 0.008373	 0.2166	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4656	 3899	 0.001211	 0.017571	 0.4563	 1811	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	4633	 3899	 0.000824	 0.008373	 0.2166	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4656	 3899	 0.001205	 0.017438	 0.4534	 1825	 1825	 1825	 0.0	 0.0	 1	 -30.0	 30.0;
	4435	 3902	 0.021244	 0.060489	 0.0193	 480	 480	 480	 0.0	 0.0	 1	 -30.0	 30.0;
	5735	 3903	 0.000553	 0.003793	 0.0071	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5522	 3907	 0.033006	 0.086672	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 3908	 0.054699	 0.138675	 0.0016	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	5049	 3908	 0.000504	 0.00252	 0.0004	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5228	 3908	 0.052406	 0.141345	 0.0021	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	5709	 3908	 0.06198	 0.157218	 0.0017	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 3909	 0.007546	 0.034173	 0.0607	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 3910	 0.068027	 0.150416	 0.0017	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	4749	 3911	 0.014613	 0.030234	 0.0	 906	 906	 906	 0.0	 0.0	 1	 -30.0	 30.0;
	4027	 3914	 0.022593	 0.058519	 0.0084	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	5789	 3914	 0.027901	 0.104444	 0.0099	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	4827	 3916	 0.079113	 0.215671	 0.0024	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	4827	 3915	 0.087679	 0.239103	 0.0027	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	5685	 3920	 0.009156	 0.040044	 0.0135	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	4500	 3922	 0.017133	 0.043336	 0.0005	 634	 634	 634	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 3922	 0.005039	 0.014109	 0.0002	 1971	 1971	 1971	 0.0	 0.0	 1	 -30.0	 30.0;
	3988	 3923	 0.000928	 0.004148	 0.0071	 7269	 7269	 7269	 0.0	 0.0	 1	 -30.0	 30.0;
	4286	 3923	 0.002844	 0.018627	 0.0334	 468.0	 468.0	 468.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5431	 3923	 0.00257	 0.017083	 0.0314	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4056	 3929	 0.009936	 0.040059	 0.0658	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5262	 3929	 0.001679	 0.011062	 0.0203	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5454	 3929	 0.004958	 0.022716	 0.0395	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5699	 3929	 0.000178	 0.00077	 0.5083	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5731	 3936	 0.071554	 0.192996	 0.0029	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	5764	 3936	 0.045352	 0.123961	 0.0014	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 3937	 0.039808	 0.089695	 0.001	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 3941	 0.000237	 0.001541	 0.003	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5408	 3943	 0.053338	 0.12769	 0.0015	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	4006	 3946	 0.025447	 0.063996	 0.001	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	4006	 3947	 0.003117	 0.005706	 0.0001	 4542	 4542	 4542	 0.0	 0.0	 1	 -30.0	 30.0;
	5263	 3948	 0.013026	 0.0451	 0.0048	 648	 648	 648	 0.0	 0.0	 1	 -30.0	 30.0;
	3952	 3951	 0.014564	 0.026659	 0.0021	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	4454	 3951	 0.066767	 0.212648	 0.0025	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	5169	 3951	 0.007811	 0.024943	 0.0003	 1164	 1164	 1164	 0.0	 0.0	 1	 -30.0	 30.0;
	4558	 3953	 0.018392	 0.076846	 0.0073	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 3954	 0.000948	 0.009185	 0.0324	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 3955	 0.000889	 0.008652	 0.0304	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4608	 3956	 0.000173	 0.001235	 0.0009	 23861	 23861	 23861	 0.0	 0.0	 1	 -30.0	 30.0;
	5167	 3956	 0.008395	 0.021235	 0.001	 1304	 1304	 1304	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 3956	 0.024161	 0.061506	 0.0029	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	5790	 3956	 2.5e-05	 0.001235	 0.0	 24089	 24089	 24089	 0.0	 0.0	 1	 -30.0	 30.0;
	5691	 3957	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	4920	 3959	 0.010617	 0.028765	 0.0013	 969	 969	 969	 0.0	 0.0	 1	 -30.0	 30.0;
	5690	 3964	 0.001008	 0.00252	 0.0	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	4902	 3968	 0.001738	 0.011595	 0.0213	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4077	 3969	 0.00037	 0.050617	 0.0	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	4077	 3969	 0.00037	 0.050617	 0.0	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 3971	 0.01321	 0.055926	 0.0029	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	5072	 3972	 0.008652	 0.039447	 0.0724	 374.0	 374.0	 374.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4190	 3973	 0.040741	 0.104444	 0.0049	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 3973	 0.015185	 0.106049	 0.0053	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	4998	 3974	 0.088939	 0.22575	 0.003	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 3978	 0.00358	 0.007284	 0.0003	 3660	 3660	 3660	 0.0	 0.0	 1	 -30.0	 30.0;
	4916	 3980	 0.073822	 0.198539	 0.0119	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5076	 3981	 0.107178	 0.196187	 0.0016	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 3982	 0.047048	 0.08612	 0.0009	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5692	 3983	 0.001067	 0.004346	 0.0182	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4921	 3984	 0.023735	 0.043446	 0.0005	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	5694	 3985	 0.017385	 0.031998	 0.0003	 811	 811	 811	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 3986	 0.041572	 0.133283	 0.001	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5696	 3991	 0.005543	 0.012094	 0.0002	 2220	 2220	 2220	 0.0	 0.0	 1	 -30.0	 30.0;
	4692	 3992	 0.037407	 0.101605	 0.0048	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	4357	 3993	 0.037289	 0.094482	 0.001	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	5815	 3995	 0.066516	 0.139078	 0.0015	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	4305	 3996	 0.025185	 0.098272	 0.0058	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	4461	 3996	 0.003457	 0.008642	 0.0023	 3258	 3258	 3258	 0.0	 0.0	 1	 -30.0	 30.0;
	5496	 3998	 0.007206	 0.029252	 0.0019	 952	 952	 952	 0.0	 0.0	 1	 -30.0	 30.0;
	4326	 4000	 0.067019	 0.169463	 0.0019	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	4360	 4000	 0.056437	 0.143613	 0.0017	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 4001	 0.008332	 0.037879	 0.0663	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5478	 4002	 0.033006	 0.072814	 0.001	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	4682	 4003	 0.008774	 0.031285	 0.0491	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 4005	 0.018395	 0.048395	 0.0023	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 4007	 0.10112	 0.1851	 0.0019	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	5698	 4010	 0.002311	 0.015467	 0.0284	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5699	 4012	 0.001264	 0.005136	 0.0091	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5699	 4012	 0.001264	 0.005136	 0.0091	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5408	 4013	 0.039557	 0.087176	 0.0013	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 4014	 0.005886	 0.031546	 0.0567	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4897	 4014	 0.011239	 0.050647	 0.0901	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 4015	 0.000705	 0.001663	 0.0006	 16838	 16838	 16838	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 4015	 0.077097	 0.213656	 0.0024	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	4602	 4016	 0.084152	 0.241119	 0.0026	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	4602	 4016	 0.0839	 0.241119	 0.0027	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	5226	 4018	 0.056992	 0.23167	 0.0042	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 4019	 0.001817	 0.012089	 0.0223	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4452	 4022	 0.037339	 0.123054	 0.0015	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	5146	 4022	 0.000504	 0.00126	 0.0	 22412	 22412	 22412	 0.0	 0.0	 1	 -30.0	 30.0;
	4452	 4022	 0.037339	 0.123054	 0.0015	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	5145	 4022	 0.000504	 0.00126	 0.0	 22412	 22412	 22412	 0.0	 0.0	 1	 -30.0	 30.0;
	4678	 4023	 0.013827	 0.075309	 0.0042	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	5701	 4025	 0.000123	 0.001235	 0.0005	 24434	 24434	 24434	 0.0	 0.0	 1	 -30.0	 30.0;
	5089	 4028	 0.007785	 0.032955	 0.0036	 899	 899	 899	 0.0	 0.0	 1	 -30.0	 30.0;
	5702	 4029	 5.9e-05	 0.000403	 0.001	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4872	 4032	 0.000316	 0.001936	 0.2551	 397.0	 397.0	 397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4895	 4033	 0.146611	 0.40005	 0.0062	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 4034	 0.000221	 0.001357	 0.1974	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 4035	 0.003818	 0.024421	 0.1136	 366.0	 366.0	 366.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5704	 4036	 8.6e-05	 0.001235	 0.0	 23993	 23993	 23993	 0.0	 0.0	 1	 -30.0	 30.0;
	4370	 4037	 0.003457	 0.007901	 0.0	 3027	 3027	 3027	 0.0	 0.0	 1	 -30.0	 30.0;
	5785	 4037	 0.000335	 0.000613	 0.0	 37370	 37370	 37370	 0.0	 0.0	 1	 -30.0	 30.0;
	5838	 4038	 0.00162	 0.009284	 0.0162	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4968	 4039	 0.001956	 0.009146	 0.0152	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5385	 4040	 0.001837	 0.008988	 0.0203	 403.0	 403.0	 403.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5705	 4040	 0.000672	 0.004543	 0.0167	 403.0	 403.0	 403.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 4041	 0.000242	 0.002735	 0.0549	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 4042	 0.003951	 0.016296	 0.0008	 1772	 1772	 1772	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 4051	 0.131519	 0.333585	 0.0038	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	5705	 4054	 0.000237	 0.000494	 0.0294	 56492	 56492	 56492	 0.0	 0.0	 1	 -30.0	 30.0;
	4300	 4055	 0.041068	 0.098765	 0.001	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	4539	 4055	 0.004535	 0.010078	 0.0	 2760	 2760	 2760	 0.0	 0.0	 1	 -30.0	 30.0;
	5778	 4055	 0.003779	 0.010582	 0.0	 2714	 2714	 2714	 0.0	 0.0	 1	 -30.0	 30.0;
	5706	 4057	 0.027715	 0.075838	 0.0009	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	5059	 4061	 0.096825	 0.303855	 0.0034	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	4597	 4062	 0.016881	 0.036684	 0.0005	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	5224	 4062	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	4221	 4066	 0.052658	 0.133283	 0.0015	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	4220	 4066	 0.05291	 0.134543	 0.0015	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	5770	 4067	 0.022099	 0.056296	 0.0026	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	4391	 4070	 0.000316	 0.001132	 0.1529	 297.0	 297.0	 297.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4391	 4070	 0.000316	 0.001132	 0.1529	 297.0	 297.0	 297.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5173	 4070	 0.000563	 0.003372	 0.0116	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5176	 4070	 0.000211	 0.002058	 0.0111	 789.0	 789.0	 789.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4224	 4072	 0.095112	 0.255404	 0.0092	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	4369	 4072	 0.061779	 0.156085	 0.02	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 4078	 0.000252	 0.125976	 0.0	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	4675	 4078	 0.000252	 0.125976	 0.0	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	4769	 4079	 0.019652	 0.043588	 0.0005	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	5708	 4082	 0.001235	 0.003333	 0.0002	 8357	 8357	 8357	 0.0	 0.0	 1	 -30.0	 30.0;
	5080	 4084	 0.017637	 0.048375	 0.0006	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	5843	 4084	 2.5e-05	 0.000252	 0.0	 116592	 116592	 116592	 0.0	 0.0	 1	 -30.0	 30.0;
	5295	 4089	 0.036936	 0.093651	 0.001	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	4613	 4090	 0.030988	 0.082716	 0.0039	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	4943	 4091	 0.066516	 0.16906	 0.0019	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 4093	 0.026707	 0.095994	 0.0264	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	5330	 4093	 0.012346	 0.041572	 0.0005	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	5492	 4093	 0.016377	 0.042076	 0.0005	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	4646	 4097	 0.002746	 0.018746	 0.0329	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5795	 4097	 0.003002	 0.015052	 0.0268	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4898	 4098	 0.002043	 0.022929	 0.4592	 1386	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	4944	 4098	 0.000776	 0.008497	 0.1805	 1659.0	 1659.0	 1659.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4722	 4099	 0.018896	 0.120433	 0.0014	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	5827	 4101	 0.034815	 0.086914	 0.004	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	4441	 4104	 0.037541	 0.092467	 0.001	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	5713	 4105	 0.013333	 0.033951	 0.0016	 815	 815	 815	 0.0	 0.0	 1	 -30.0	 30.0;
	4926	 4106	 0.036533	 0.092719	 0.001	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	5710	 4106	 0.010834	 0.030234	 0.0004	 920	 920	 920	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 4108	 0.000512	 0.000938	 0.0	 28461	 28461	 28461	 0.0	 0.0	 1	 -30.0	 30.0;
	4329	 4110	 0.016125	 0.100277	 0.0013	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	5570	 4110	 0.010078	 0.06198	 0.0008	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	5005	 4112	 0.047115	 0.198287	 0.0024	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	5714	 4114	 1e-05	 0.0001	 0.0029	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5716	 4121	 0.036785	 0.118922	 0.001	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	4237	 4123	 0.046863	 0.11867	 0.0013	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	5418	 4125	 0.003121	 0.014183	 0.0243	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4138	 4130	 0.113379	 0.253968	 0.0028	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	4535	 4131	 0.056437	 0.156966	 0.0017	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	5167	 4133	 0.01716	 0.046296	 0.0023	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	5557	 4133	 0.044444	 0.115309	 0.0055	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	5790	 4133	 0.026543	 0.067531	 0.0032	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	5805	 4132	 0.00242	 0.00658	 0.0003	 4237	 4237	 4237	 0.0	 0.0	 1	 -30.0	 30.0;
	4202	 4135	 0.059461	 0.146384	 0.0028	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	4845	 4135	 0.0451	 0.153187	 0.0017	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	5153	 4136	 0.003099	 0.020113	 0.0385	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5692	 4136	 0.002528	 0.016672	 0.0304	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 4137	 0.001605	 0.003333	 0.0017	 8030	 8030	 8030	 0.0	 0.0	 1	 -30.0	 30.0;
	4844	 4138	 0.020962	 0.053162	 0.0006	 533	 533	 533	 0.0	 0.0	 1	 -30.0	 30.0;
	4993	 4140	 0.022928	 0.142857	 0.003	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	5786	 4140	 0.011086	 0.047871	 0.001	 605	 605	 605	 0.0	 0.0	 1	 -30.0	 30.0;
	4994	 4141	 0.001679	 0.011397	 0.0223	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5718	 4144	 0.000252	 0.00252	 0.0001	 13354	 13354	 13354	 0.0	 0.0	 1	 -30.0	 30.0;
	5717	 4145	 0.013152	 0.03487	 0.0021	 793	 793	 793	 0.0	 0.0	 1	 -30.0	 30.0;
	4467	 4147	 0.063744	 0.176367	 0.0002	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	4467	 4147	 0.063492	 0.173847	 0.0031	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	4247	 4148	 0.036029	 0.092467	 0.001	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	5719	 4148	 0.124717	 0.316201	 0.0036	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	4377	 4149	 0.00077	 0.001659	 0.2106	 16924	 16924	 16924	 0.0	 0.0	 1	 -30.0	 30.0;
	5720	 4152	 0.01159	 0.031494	 0.0003	 880	 880	 880	 0.0	 0.0	 1	 -30.0	 30.0;
	5196	 4155	 0.004157	 0.012094	 0.0002	 2379	 2379	 2379	 0.0	 0.0	 1	 -30.0	 30.0;
	4692	 4156	 0.021482	 0.058148	 0.0028	 518	 518	 518	 0.0	 0.0	 1	 -30.0	 30.0;
	5416	 4156	 0.031358	 0.131975	 0.0068	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 4158	 0.001764	 0.005039	 0.0001	 5531	 5531	 5531	 0.0	 0.0	 1	 -30.0	 30.0;
	5559	 4159	 0.014613	 0.07231	 0.0005	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	5722	 4160	 0.000227	 0.000605	 0.0	 47067	 47067	 47067	 0.0	 0.0	 1	 -30.0	 30.0;
	4313	 4162	 0.034321	 0.083827	 0.0039	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	4373	 4162	 0.030988	 0.064074	 0.003	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	5776	 4162	 0.003951	 0.025185	 0.0013	 1166	 1166	 1166	 0.0	 0.0	 1	 -30.0	 30.0;
	4313	 4162	 0.006173	 0.025679	 0.1053	 1125	 1125	 1125	 0.0	 0.0	 1	 -30.0	 30.0;
	4373	 4162	 0.024815	 0.064691	 0.0031	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	5723	 4164	 0.006299	 0.026808	 0.0003	 1105	 1105	 1105	 0.0	 0.0	 1	 -30.0	 30.0;
	5631	 4164	 0.006299	 0.013605	 0.0002	 2029	 2029	 2029	 0.0	 0.0	 1	 -30.0	 30.0;
	5382	 4166	 0.000494	 0.001728	 0.0002	 16527	 16527	 16527	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 4166	 0.004691	 0.015803	 0.0008	 1802	 1802	 1802	 0.0	 0.0	 1	 -30.0	 30.0;
	5030	 4169	 0.03963	 0.103951	 0.005	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	4663	 4170	 0.015309	 0.03963	 0.0019	 700	 700	 700	 0.0	 0.0	 1	 -30.0	 30.0;
	5174	 4173	 0.037037	 0.099773	 0.0012	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	5336	 4173	 0.014109	 0.036029	 0.0004	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	5622	 4173	 0.051398	 0.145629	 0.0033	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	5803	 4174	 0.005628	 0.038669	 0.0729	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 4175	 0.138322	 0.372386	 0.0048	 75	 75	 75	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 4176	 0.007307	 0.030335	 0.0018	 967	 967	 967	 0.0	 0.0	 1	 -30.0	 30.0;
	5726	 4176	 0.000252	 0.00252	 0.0005	 11909	 11909	 11909	 0.0	 0.0	 1	 -30.0	 30.0;
	4178	 4177	 0.004535	 0.013605	 0.0051	 2059	 2059	 2059	 0.0	 0.0	 1	 -30.0	 30.0;
	5288	 4177	 0.020156	 0.087176	 0.001	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	5727	 4181	 0.050894	 0.138574	 0.0016	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	5745	 4182	 0.021416	 0.058453	 0.0006	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	5022	 4183	 0.049635	 0.135299	 0.0041	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	4841	 4186	 0.067654	 0.145679	 0.0071	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 4186	 0.03716	 0.100247	 0.0049	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	4757	 4187	 0.000652	 0.001244	 0.1833	 22038	 22038	 22038	 0.0	 0.0	 1	 -30.0	 30.0;
	5186	 4191	 0.026296	 0.066296	 0.012	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 4193	 0.009753	 0.019506	 0.0008	 1362	 1362	 1362	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 4192	 0.009753	 0.019506	 0.0008	 1362	 1362	 1362	 0.0	 0.0	 1	 -30.0	 30.0;
	4194	 4195	 0.003731	 0.006829	 0.0	 3795	 3795	 3795	 0.0	 0.0	 1	 -30.0	 30.0;
	4572	 4199	 0.008818	 0.018141	 0.0254	 1421	 1421	 1421	 0.0	 0.0	 1	 -30.0	 30.0;
	4870	 4199	 0.018317	 0.059486	 0.0256	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	5782	 4199	 0.014361	 0.044344	 0.014	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	4872	 4201	 0.00083	 0.002588	 0.32	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 4200	 0.000395	 0.002291	 0.0182	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5551	 4200	 0.001659	 0.011062	 0.0203	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 4203	 0.009956	 0.035773	 0.0572	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5509	 4203	 0.002102	 0.008286	 0.0142	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5692	 4203	 0.001185	 0.008	 0.0152	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 4204	 0.000252	 0.00252	 0.0003	 11659	 11659	 11659	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 4209	 0.003117	 0.005706	 0.0028	 4678	 4678	 4678	 0.0	 0.0	 1	 -30.0	 30.0;
	4492	 4209	 0.004031	 0.009574	 0.01	 2928	 2928	 2928	 0.0	 0.0	 1	 -30.0	 30.0;
	5211	 4208	 0.013354	 0.033258	 0.0004	 849	 849	 849	 0.0	 0.0	 1	 -30.0	 30.0;
	4492	 4209	 0.005217	 0.00955	 0.0093	 2795	 2795	 2795	 0.0	 0.0	 1	 -30.0	 30.0;
	4491	 4208	 0.004975	 0.009106	 0.0087	 2932	 2932	 2932	 0.0	 0.0	 1	 -30.0	 30.0;
	4484	 4210	 0.00371	 0.01789	 0.0359	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4902	 4210	 0.001428	 0.019629	 0.0754	 638.0	 638.0	 638.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5698	 4210	 0.001244	 0.016316	 0.0699	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5702	 4210	 0.006728	 0.030596	 0.0587	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 4211	 0.000471	 0.006184	 0.2368	 954.0	 954.0	 954.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5381	 4212	 0.021926	 0.055062	 0.0002	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	5734	 4212	 0.019753	 0.05037	 0.0	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 4218	 0.010494	 0.045185	 0.0021	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 4217	 0.010494	 0.02679	 0.0013	 1054	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	4947	 4222	 0.016503	 0.044394	 0.0027	 624	 624	 624	 0.0	 0.0	 1	 -30.0	 30.0;
	4341	 4226	 0.089695	 0.171832	 0.0018	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	5730	 4227	 0.014815	 0.04037	 0.0019	 691	 691	 691	 0.0	 0.0	 1	 -30.0	 30.0;
	5449	 4231	 3.7e-05	 0.000148	 0.0002	 194699	 194699	 194699	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 4233	 0.006299	 0.015621	 0.0202	 1753	 1753	 1753	 0.0	 0.0	 1	 -30.0	 30.0;
	4890	 4234	 0.059012	 0.159259	 0.0075	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	5157	 4234	 0.021852	 0.058765	 0.0029	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 4234	 0.040494	 0.102963	 0.0047	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	4317	 4238	 0.019652	 0.083648	 0.001	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	4671	 4240	 0.036029	 0.093222	 0.0011	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	5203	 4239	 0.008566	 0.023432	 0.0002	 1184	 1184	 1184	 0.0	 0.0	 1	 -30.0	 30.0;
	4239	 4262	 0.008062	 0.022172	 0.0002	 1252	 1252	 1252	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 4241	 0.067523	 0.184177	 0.0021	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 4242	 0.05417	 0.137314	 0.0019	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	4882	 4242	 0.03351	 0.113631	 0.0013	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	4248	 4243	 0.006084	 0.023072	 0.24	 282.0	 282.0	 282.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4734	 4244	 0.006198	 0.011346	 0.0088	 2353	 2353	 2353	 0.0	 0.0	 1	 -30.0	 30.0;
	4837	 4247	 0.051524	 0.124313	 0.003	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 4247	 0.046863	 0.109851	 0.0012	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	5649	 4248	 0.004454	 0.01571	 0.0253	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4998	 4249	 0.057697	 0.158982	 0.0021	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	5647	 4249	 0.014025	 0.025673	 0.0	 1010	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	4816	 4250	 0.032754	 0.083396	 0.001	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	5174	 4252	 0.032502	 0.088939	 0.001	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	5731	 4252	 0.053162	 0.145377	 0.0017	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	5434	 4253	 0.009012	 0.023457	 0.001	 1183	 1183	 1183	 0.0	 0.0	 1	 -30.0	 30.0;
	5232	 4256	 0.021668	 0.066516	 0.0013	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	5232	 4255	 0.020912	 0.063996	 0.0013	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 4259	 0.002877	 0.007284	 0.0003	 3793	 3793	 3793	 0.0	 0.0	 1	 -30.0	 30.0;
	5735	 4261	 0.000375	 0.001679	 0.003	 17958	 17958	 17958	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 4263	 0.097048	 0.177645	 0.0018	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	5737	 4264	 0.029907	 0.101512	 0.0016	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5707	 4265	 0.001512	 0.004787	 0.0045	 5882	 5882	 5882	 0.0	 0.0	 1	 -30.0	 30.0;
	5685	 4268	 0.019867	 0.059067	 0.0189	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	5753	 4273	 0.018796	 0.037365	 0.0178	 728	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 4278	 2.8e-05	 0.000409	 0.0116	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4855	 4277	 2.8e-05	 0.000422	 0.0116	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4996	 4279	 0.029982	 0.075838	 0.0	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	5368	 4281	 0.005795	 0.019652	 0.0002	 1485	 1485	 1485	 0.0	 0.0	 1	 -30.0	 30.0;
	5586	 4281	 0.04384	 0.108592	 0.0018	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	4975	 4283	 0.010667	 0.052109	 0.0901	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 4286	 0.003931	 0.026686	 0.0506	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5608	 4287	 0.011565	 0.029453	 0.0031	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	5739	 4288	 0.008395	 0.022963	 0.0011	 1241	 1241	 1241	 0.0	 0.0	 1	 -30.0	 30.0;
	4279	 4291	 0.002268	 0.006803	 0.0005	 4118	 4118	 4118	 0.0	 0.0	 1	 -30.0	 30.0;
	5740	 4292	 0.000882	 0.002973	 0.0	 9521	 9521	 9521	 0.0	 0.0	 1	 -30.0	 30.0;
	4312	 4293	 0.109851	 0.269841	 0.003	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	4563	 4293	 0.049887	 0.166767	 0.0019	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	5741	 4294	 0.008012	 0.019678	 0.0013	 1432	 1432	 1432	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 4299	 0.007811	 0.019904	 0.0002	 1423	 1423	 1423	 0.0	 0.0	 1	 -30.0	 30.0;
	5528	 4299	 0.055682	 0.141345	 0.0016	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	5527	 4298	 0.055933	 0.141849	 0.0016	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4301	 4300	 0.017385	 0.039053	 0.004	 706	 706	 706	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 4302	 0.001111	 0.002963	 0.0002	 9387	 9387	 9387	 0.0	 0.0	 1	 -30.0	 30.0;
	5841	 4305	 0.027901	 0.118272	 0.0058	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	5742	 4311	 0.010247	 0.032716	 0.0016	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	5530	 4315	 0.024943	 0.053918	 0.0	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	5584	 4315	 0.057445	 0.124465	 0.001	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	4415	 4319	 0.022172	 0.057697	 0.001	 478	 478	 478	 0.0	 0.0	 1	 -30.0	 30.0;
	4616	 4322	 0.01285	 0.053968	 0.0006	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	4712	 4321	 0.06707	 0.182137	 0.0028	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	5337	 4321	 0.011842	 0.039053	 0.0006	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	5338	 4321	 0.014059	 0.037868	 0.0005	 753	 753	 753	 0.0	 0.0	 1	 -30.0	 30.0;
	5419	 4322	 0.020081	 0.087226	 0.001	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	5679	 4322	 0.021416	 0.056689	 0.0006	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	5726	 4322	 0.006551	 0.027967	 0.0003	 1059	 1059	 1059	 0.0	 0.0	 1	 -30.0	 30.0;
	5724	 4322	 0.006299	 0.026455	 0.0003	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 4323	 0.000415	 0.002785	 0.0051	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5420	 4324	 0.001225	 0.005981	 0.0111	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4902	 4323	 0.002133	 0.014289	 0.0263	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 4324	 0.000474	 0.003149	 0.0061	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5293	 4325	 0.04772	 0.162081	 0.0019	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	4547	 4334	 0.007811	 0.015873	 0.01	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	4545	 4334	 0.007307	 0.0193	 0.0173	 1431	 1431	 1431	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 4335	 0.000644	 0.002929	 0.0051	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4765	 4336	 0.010494	 0.026667	 0.0171	 1037	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	5747	 4337	 0.013102	 0.025951	 0.0002	 1047	 1047	 1047	 0.0	 0.0	 1	 -30.0	 30.0;
	4889	 4338	 0.115646	 0.315445	 0.0036	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	5068	 4338	 0.007559	 0.023935	 0.0012	 1212	 1212	 1212	 0.0	 0.0	 1	 -30.0	 30.0;
	5068	 4338	 0.007559	 0.023935	 0.0012	 1212	 1212	 1212	 0.0	 0.0	 1	 -30.0	 30.0;
	4902	 4339	 0.000849	 0.005728	 0.0101	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4902	 4339	 0.000849	 0.005728	 0.0101	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4902	 4339	 0.000435	 0.002963	 0.0208	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 4340	 0.024198	 0.045679	 0.0021	 587	 587	 587	 0.0	 0.0	 1	 -30.0	 30.0;
	5393	 4341	 0.009322	 0.023935	 0.0	 1150	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	5771	 4341	 0.032502	 0.084152	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5821	 4341	 0.037541	 0.089695	 0.001	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 4344	 0.001764	 0.004283	 0.0001	 6566	 6566	 6566	 0.0	 0.0	 1	 -30.0	 30.0;
	5144	 4344	 0.076594	 0.184681	 0.0017	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	5370	 4346	 0.000741	 0.002099	 0.0002	 13344	 13344	 13344	 0.0	 0.0	 1	 -30.0	 30.0;
	5749	 4347	 5.9e-05	 0.000336	 0.001	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4580	 4349	 0.049887	 0.102293	 0.0011	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 4349	 0.046611	 0.118166	 0.0013	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 4349	 0.069539	 0.191232	 0.0021	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 4351	 0.043034	 0.117309	 0.0053	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	5569	 4351	 0.043411	 0.118418	 0.0013	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	4433	 4352	 0.057697	 0.120685	 0.0013	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	4794	 4353	 0.042328	 0.167297	 0.0021	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 4355	 0.030988	 0.078765	 0.0037	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	5240	 4355	 0.020123	 0.050988	 0.0024	 542	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	4420	 4356	 0.011086	 0.045352	 0.0043	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	4420	 4356	 0.011086	 0.045603	 0.0044	 630	 630	 630	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 4360	 0.084404	 0.214664	 0.0025	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 4361	 0.046863	 0.158982	 0.002	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 4361	 0.012094	 0.033006	 0.0	 840	 840	 840	 0.0	 0.0	 1	 -30.0	 30.0;
	5392	 4362	 0.020864	 0.054691	 0.0026	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	4483	 4365	 0.105316	 0.287226	 0.0033	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	5753	 4366	 0.001008	 0.002771	 0.0001	 10315	 10315	 10315	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 4368	 0.062988	 0.17158	 0.0019	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	5371	 4371	 0.018099	 0.045877	 0.0021	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	5586	 4372	 0.070043	 0.177375	 0.002	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	5171	 4375	 0.021111	 0.042346	 0.0018	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	5806	 4376	 0.03477	 0.064752	 0.0006	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	5756	 4381	 0.003927	 0.026153	 0.0486	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5754	 4383	 0.013102	 0.03477	 0.0004	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	4885	 4386	 0.03879	 0.102605	 0.0049	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	4853	 4390	 0.002035	 0.014025	 0.0263	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4720	 4391	 0.000237	 0.00083	 0.1843	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 4393	 0.051902	 0.118922	 0.0013	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	5114	 4394	 0.08642	 0.222222	 0.0	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	5757	 4396	 0.000277	 0.001285	 0.0015	 23137	 23137	 23137	 0.0	 0.0	 1	 -30.0	 30.0;
	4585	 4398	 0.00037	 0.000988	 0.0002	 30291	 30291	 30291	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 4403	 0.002394	 0.014865	 0.0002	 1962	 1962	 1962	 0.0	 0.0	 1	 -30.0	 30.0;
	5760	 4407	 0.000756	 0.001512	 0.0	 17466	 17466	 17466	 0.0	 0.0	 1	 -30.0	 30.0;
	5761	 4409	 0.000151	 0.000428	 0.0	 65055	 65055	 65055	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 4411	 0.000454	 0.002114	 0.0061	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 4410	 0.000454	 0.002114	 0.004	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5002	 4416	 0.069791	 0.171328	 0.0023	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	4989	 4418	 0.103301	 0.241371	 0.003	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	5761	 4418	 0.068178	 0.17357	 0.0021	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5303	 4419	 0.007099	 0.017988	 0.0008	 1536	 1536	 1536	 0.0	 0.0	 1	 -30.0	 30.0;
	5763	 4421	 0.013481	 0.024677	 0.0002	 1019	 1019	 1019	 0.0	 0.0	 1	 -30.0	 30.0;
	5762	 4422	 0.002771	 0.007055	 0.0001	 3780	 3780	 3780	 0.0	 0.0	 1	 -30.0	 30.0;
	5360	 4424	 0.027642	 0.093889	 0.0046	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 4426	 0.014613	 0.049383	 0.001	 587	 587	 587	 0.0	 0.0	 1	 -30.0	 30.0;
	4873	 4426	 0.041572	 0.101789	 0.002	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	4681	 4426	 0.015873	 0.050643	 0.001	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	4620	 4427	 0.054343	 0.099474	 0.001	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 4429	 0.028471	 0.104308	 0.0458	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	4957	 4429	 0.085916	 0.17745	 0.0023	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	5709	 4430	 0.004031	 0.01033	 0.0001	 2743	 2743	 2743	 0.0	 0.0	 1	 -30.0	 30.0;
	4668	 4433	 0.053666	 0.303603	 0.0034	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	4668	 4433	 0.053918	 0.303855	 0.0034	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	4750	 4434	 0.000252	 0.00252	 0.0001	 11659	 11659	 11659	 0.0	 0.0	 1	 -30.0	 30.0;
	4915	 4434	 0.03933	 0.101789	 0.0025	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	4751	 4434	 0.000252	 0.00252	 0.0001	 11659	 11659	 11659	 0.0	 0.0	 1	 -30.0	 30.0;
	5657	 4436	 0.002627	 0.017778	 0.0334	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5266	 4441	 0.006047	 0.025195	 0.0	 1140	 1140	 1140	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 4444	 0.094986	 0.266566	 0.0	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	5088	 4447	 0.063265	 0.13613	 0.0015	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	5810	 4447	 0.011842	 0.033006	 0.0	 868	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	5772	 4449	 0.001462	 0.010114	 0.0182	 442.0	 442.0	 442.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4921	 4450	 0.01033	 0.037541	 0.0005	 759	 759	 759	 0.0	 0.0	 1	 -30.0	 30.0;
	5766	 4451	 0.006667	 0.012346	 0.0225	 2162	 2162	 2162	 0.0	 0.0	 1	 -30.0	 30.0;
	4888	 4452	 0.075334	 0.198639	 0.0041	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 4452	 0.070295	 0.145377	 0.0016	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	5145	 4452	 0.042832	 0.10834	 0.0013	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	5741	 4454	 0.061602	 0.156135	 0.0017	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	5823	 4455	 0.001008	 0.002016	 0.0	 13494	 13494	 13494	 0.0	 0.0	 1	 -30.0	 30.0;
	4529	 4456	 0.006173	 0.025145	 0.0018	 1141	 1141	 1141	 0.0	 0.0	 1	 -30.0	 30.0;
	4630	 4457	 0.022676	 0.095994	 0.001	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	5138	 4456	 0.044344	 0.189216	 0.0021	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	5141	 4457	 0.048123	 0.206349	 0.003	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	4898	 4459	 0.002749	 0.039259	 1.1855	 811	 811	 811	 0.0	 0.0	 1	 -30.0	 30.0;
	4672	 4463	 0.014321	 0.040617	 0.0	 705	 705	 705	 0.0	 0.0	 1	 -30.0	 30.0;
	4492	 4465	 0.001512	 0.003275	 0.0001	 8432	 8432	 8432	 0.0	 0.0	 1	 -30.0	 30.0;
	5768	 4467	 0.058705	 0.159738	 0.0018	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4770	 4469	 0.008314	 0.022424	 0.0	 1272	 1272	 1272	 0.0	 0.0	 1	 -30.0	 30.0;
	4480	 4475	 2.5e-05	 0.015117	 0.0	 2012	 2012	 2012	 0.0	 0.0	 1	 -30.0	 30.0;
	4482	 4479	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4482	 4478	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4482	 4477	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4482	 4476	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	5005	 4483	 0.142605	 0.361804	 0.0041	 78	 78	 78	 0.0	 0.0	 1	 -30.0	 30.0;
	5506	 4483	 0.120685	 0.404888	 0.0046	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 4485	 0.006758	 0.01237	 0.0087	 2033	 2033	 2033	 0.0	 0.0	 1	 -30.0	 30.0;
	5769	 4487	 0.000454	 0.001209	 0.0013	 23415	 23415	 23415	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 4495	 0.006533	 0.022267	 0.0072	 1313	 1313	 1313	 0.0	 0.0	 1	 -30.0	 30.0;
	5247	 4495	 0.017067	 0.058356	 0.0193	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	5558	 4497	 0.100277	 0.301839	 0.004	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	4601	 4501	 0.043333	 0.092099	 0.0042	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	4801	 4505	 0.027531	 0.074074	 0.0036	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 4505	 0.031111	 0.084074	 0.004	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	5771	 4506	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	5772	 4507	 1.4e-05	 9.9e-05	 0.0002	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4045	 4508	 0.033006	 0.204838	 0.0073	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	4138	 4508	 0.039305	 0.100529	 0.0011	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	5239	 4508	 0.005669	 0.036206	 0.0087	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 4509	 0.002807	 0.014445	 0.0259	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5479	 4513	 0.046914	 0.119012	 0.0055	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5361	 4514	 0.007432	 0.025235	 0.0013	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	5774	 4515	 0.007055	 0.013102	 0.0001	 2280	 2280	 2280	 0.0	 0.0	 1	 -30.0	 30.0;
	4845	 4518	 0.114059	 0.346964	 0.004	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	4136	 4520	 0.006933	 0.033403	 0.0607	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5775	 4522	 0.004435	 0.008118	 0.0001	 3667	 3667	 3667	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 4523	 0.012346	 0.04384	 0.0006	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	4322	 4523	 0.013354	 0.0451	 0.0006	 647	 647	 647	 0.0	 0.0	 1	 -30.0	 30.0;
	5700	 4525	 0.046359	 0.117662	 0.0013	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	5375	 4526	 0.001383	 0.009343	 0.0172	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5380	 4526	 0.001027	 0.006815	 0.0121	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 4528	 0.014361	 0.039053	 0.0005	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	4882	 4528	 0.012346	 0.03351	 0.0004	 827	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	5273	 4533	 0.007307	 0.030738	 0.0019	 907	 907	 907	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 4535	 0.000995	 0.001821	 0.001	 14657	 14657	 14657	 0.0	 0.0	 1	 -30.0	 30.0;
	5742	 4536	 0.041481	 0.100494	 0.0047	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	5777	 4537	 5.9e-05	 0.000296	 0.0	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5507	 4538	 0.000504	 0.001764	 0.0014	 16578	 16578	 16578	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 4538	 0.000756	 0.001764	 0.0017	 15848	 15848	 15848	 0.0	 0.0	 1	 -30.0	 30.0;
	5779	 4541	 0.006047	 0.024691	 0.0003	 1162	 1162	 1162	 0.0	 0.0	 1	 -30.0	 30.0;
	4569	 4543	 0.00141	 0.020003	 0.4967	 1589	 1589	 1589	 0.0	 0.0	 1	 -30.0	 30.0;
	4569	 4543	 0.00141	 0.02	 0.4967	 1589	 1589	 1589	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 4548	 0.000988	 0.001852	 0.0	 14447	 14447	 14447	 0.0	 0.0	 1	 -30.0	 30.0;
	5515	 4550	 0.019778	 0.053943	 0.0006	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	5691	 4550	 0.004787	 0.021416	 0.0002	 1386	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	5813	 4550	 0.012396	 0.033837	 0.0004	 844	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	5814	 4550	 0.011414	 0.031166	 0.0004	 917	 917	 917	 0.0	 0.0	 1	 -30.0	 30.0;
	5518	 4552	 0.006696	 0.028583	 0.0496	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5601	 4564	 0.000827	 0.003815	 0.0661	 279.0	 279.0	 279.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4589	 4565	 0.000194	 0.00255	 0.0895	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4588	 4565	 0.000194	 0.00255	 0.0895	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4922	 4568	 0.005709	 0.036049	 0.0881	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4922	 4568	 0.005748	 0.036247	 0.0997	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4706	 4569	 0.000893	 0.008663	 0.2253	 1644.0	 1644.0	 1644.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5812	 4569	 0.001707	 0.022772	 0.7812	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	4706	 4569	 0.000893	 0.008663	 0.2253	 1644.0	 1644.0	 1644.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4706	 4569	 0.00117	 0.010658	 0.2946	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4706	 4569	 0.000409	 0.006946	 0.2513	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4706	 4569	 0.000409	 0.006946	 0.2513	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5581	 4574	 0.003527	 0.00907	 0.0001	 3126	 3126	 3126	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 4575	 0.01033	 0.027463	 0.0003	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	4576	 4577	 0.009574	 0.025195	 0.0003	 1096	 1096	 1096	 0.0	 0.0	 1	 -30.0	 30.0;
	4792	 4577	 0.159234	 0.297304	 0.0033	 88	 88	 88	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 4577	 0.00907	 0.024691	 0.0002	 1123	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	5785	 4579	 0.016769	 0.030696	 0.0	 747	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	4739	 4580	 0.074931	 0.154195	 0.0023	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	5138	 4581	 0.064248	 0.133283	 0.001	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5259	 4587	 0.021728	 0.134321	 0.0075	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	4656	 4589	 0.001015	 0.014744	 0.3841	 2158	 2158	 2158	 0.0	 0.0	 1	 -30.0	 30.0;
	4656	 4588	 0.001018	 0.014778	 0.3841	 2153	 2153	 2153	 0.0	 0.0	 1	 -30.0	 30.0;
	5786	 4592	 0.001008	 0.002016	 0.0	 13183	 13183	 13183	 0.0	 0.0	 1	 -30.0	 30.0;
	5788	 4596	 0.017654	 0.048148	 0.0023	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	5789	 4598	 0.00284	 0.007901	 0.0003	 3538	 3538	 3538	 0.0	 0.0	 1	 -30.0	 30.0;
	4798	 4602	 0.014613	 0.049383	 0.0025	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	5473	 4602	 0.057445	 0.156715	 0.0017	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 4602	 0.014361	 0.036785	 0.0005	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	5626	 4602	 0.006299	 0.016881	 0.0002	 1639	 1639	 1639	 0.0	 0.0	 1	 -30.0	 30.0;
	5729	 4602	 0.01033	 0.042328	 0.0006	 678	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	5628	 4603	 0.008119	 0.054084	 0.1002	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5051	 4605	 0.003202	 0.00586	 0.0022	 4291	 4291	 4291	 0.0	 0.0	 1	 -30.0	 30.0;
	5629	 4605	 0.000252	 0.00252	 0.0001	 11313	 11313	 11313	 0.0	 0.0	 1	 -30.0	 30.0;
	5458	 4607	 0.024188	 0.060972	 0.0008	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 4609	 0.022676	 0.14714	 0.002	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	5314	 4609	 0.021164	 0.046359	 0.001	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	5467	 4609	 0.06324	 0.11615	 0.0	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	5616	 4610	 0.018896	 0.078357	 0.0013	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	5653	 4610	 0.005039	 0.020912	 0.0002	 1573	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	4774	 4611	 0.001067	 0.004899	 0.0081	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5654	 4611	 0.000119	 0.00077	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 4613	 0.03	 0.076543	 0.0039	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	4637	 4614	 0.04284	 0.112716	 0.0053	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	4971	 4620	 0.066767	 0.157344	 0.0185	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	5612	 4622	 0.039136	 0.100741	 0.0045	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	5792	 4623	 0.019652	 0.040816	 0.0005	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	5519	 4624	 0.034568	 0.090123	 0.0042	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	5101	 4625	 0.02192	 0.055178	 0.0006	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	5242	 4625	 0.00708	 0.019325	 0.0002	 1393	 1393	 1393	 0.0	 0.0	 1	 -30.0	 30.0;
	5216	 4627	 0.025447	 0.066767	 0.0007	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	5794	 4628	 0.001008	 0.00252	 0.0	 11206	 11206	 11206	 0.0	 0.0	 1	 -30.0	 30.0;
	4793	 4631	 0.038148	 0.102099	 0.0049	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	4661	 4638	 0.012346	 0.032593	 0.0016	 853	 853	 853	 0.0	 0.0	 1	 -30.0	 30.0;
	4643	 4641	 0.010617	 0.065679	 0.0076	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	4658	 4641	 0.008025	 0.020988	 0.001	 1350	 1350	 1350	 0.0	 0.0	 1	 -30.0	 30.0;
	5121	 4641	 0.034938	 0.069876	 0.0032	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	4658	 4641	 0.008148	 0.021235	 0.0021	 1334	 1334	 1334	 0.0	 0.0	 1	 -30.0	 30.0;
	5795	 4645	 0.001244	 0.006301	 0.0111	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5501	 4647	 0.000252	 0.00252	 0.0001	 13395	 13395	 13395	 0.0	 0.0	 1	 -30.0	 30.0;
	4785	 4650	 0.035803	 0.092469	 0.005	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	4805	 4650	 0.038025	 0.099012	 0.0392	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 4653	 0.033667	 0.090667	 0.0044	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 4655	 0.000612	 0.004069	 0.0071	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4737	 4657	 0.004938	 0.013333	 0.0	 1837	 1837	 1837	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 4659	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	4894	 4668	 0.053666	 0.098262	 0.001	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	4917	 4669	 0.004464	 0.030933	 0.0547	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 4671	 0.05543	 0.140842	 0.0016	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	5134	 4673	 0.030612	 0.077198	 0.0024	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	5178	 4674	 0.077601	 0.212396	 0.0024	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	5804	 4677	 0.00358	 0.009877	 0.0005	 2828	 2828	 2828	 0.0	 0.0	 1	 -30.0	 30.0;
	4845	 4680	 0.061728	 0.148652	 0.0017	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 4681	 0.000252	 0.000504	 0.001	 53761	 53761	 53761	 0.0	 0.0	 1	 -30.0	 30.0;
	4745	 4688	 4e-05	 0.000968	 0.003	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5806	 4693	 0.009826	 0.025447	 0.0002	 1083	 1083	 1083	 0.0	 0.0	 1	 -30.0	 30.0;
	5807	 4695	 2e-05	 0.000198	 0.0	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5807	 4696	 2e-05	 0.000198	 0.0	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4745	 4704	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5808	 4707	 0.000756	 0.00252	 0.0	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	5810	 4710	 0.001008	 0.00252	 0.0	 11206	 11206	 11206	 0.0	 0.0	 1	 -30.0	 30.0;
	5137	 4713	 0.03225	 0.087931	 0.001	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	5135	 4713	 0.015369	 0.095339	 0.0012	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	5450	 4713	 0.033762	 0.140086	 0.0017	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5343	 4719	 0.010741	 0.028025	 0.0013	 1011	 1011	 1011	 0.0	 0.0	 1	 -30.0	 30.0;
	5811	 4721	 0.003527	 0.00907	 0.0001	 3126	 3126	 3126	 0.0	 0.0	 1	 -30.0	 30.0;
	5825	 4722	 0.002016	 0.013354	 0.0002	 2122	 2122	 2122	 0.0	 0.0	 1	 -30.0	 30.0;
	4796	 4724	 0.010815	 0.050299	 0.0876	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4613	 4726	 1.2e-05	 0.000123	 0.0002	 246667	 246667	 246667	 0.0	 0.0	 1	 -30.0	 30.0;
	5822	 4733	 0.001512	 0.007307	 0.0	 3957	 3957	 3957	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 4736	 0.002509	 0.015921	 0.0294	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 4739	 0.065256	 0.165457	 0.0019	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	5677	 4739	 0.046863	 0.100277	 0.0011	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	5765	 4742	 0.001512	 0.004031	 0.0001	 7065	 7065	 7065	 0.0	 0.0	 1	 -30.0	 30.0;
	4921	 4753	 0.169312	 0.378181	 0.0044	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	5458	 4753	 0.070295	 0.177879	 0.002	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	4969	 4756	 0.000316	 0.001971	 0.0273	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4968	 4755	 0.000245	 0.00302	 0.0061	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5203	 4758	 0.078609	 0.2129	 0.0024	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	5618	 4768	 0.016677	 0.030527	 0.0003	 875	 875	 875	 0.0	 0.0	 1	 -30.0	 30.0;
	5540	 4771	 0.009574	 0.024943	 0.001	 1106	 1106	 1106	 0.0	 0.0	 1	 -30.0	 30.0;
	4801	 4773	 0.010494	 0.028272	 0.0013	 985	 985	 985	 0.0	 0.0	 1	 -30.0	 30.0;
	5654	 4774	 0.000356	 0.00241	 0.004	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5366	 4775	 0.048879	 0.12648	 0.0014	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	5660	 4775	 0.073066	 0.187957	 0.0021	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	5818	 4776	 0.000375	 0.004741	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5166	 4777	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5816	 4778	 0.000171	 0.000313	 0.0001	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	5670	 4780	 0.060494	 0.158889	 0.0073	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	5315	 4782	 0.080877	 0.209373	 0.0023	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	4805	 4784	 0.047284	 0.164691	 0.0083	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	5275	 4784	 0.001358	 0.003333	 0.0002	 8426	 8426	 8426	 0.0	 0.0	 1	 -30.0	 30.0;
	5229	 4786	 0.052028	 0.131872	 0.0017	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	5817	 4790	 0.004787	 0.010078	 0.0001	 2647	 2647	 2647	 0.0	 0.0	 1	 -30.0	 30.0;
	5651	 4792	 0.042479	 0.09035	 0.001	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	4916	 4794	 0.008818	 0.035777	 0.0005	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	4916	 4794	 0.008818	 0.035777	 0.0005	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	4986	 4795	 0.145805	 0.502746	 0.0056	 59	 59	 59	 0.0	 0.0	 1	 -30.0	 30.0;
	5819	 4797	 0.014361	 0.048879	 0.001	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	5626	 4798	 0.008314	 0.032502	 0.0023	 881	 881	 881	 0.0	 0.0	 1	 -30.0	 30.0;
	5526	 4800	 0.009801	 0.041144	 0.0005	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	5191	 4802	 0.001728	 0.004815	 0.0002	 5807	 5807	 5807	 0.0	 0.0	 1	 -30.0	 30.0;
	5770	 4802	 0.019753	 0.053333	 0.0026	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 4806	 0.070547	 0.17284	 0.002	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5299	 4807	 0.045679	 0.115802	 0.0055	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 4822	 0.018272	 0.076667	 0.0062	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	5306	 4822	 0.00642	 0.04321	 0.0034	 700	 700	 700	 0.0	 0.0	 1	 -30.0	 30.0;
	5404	 4822	 0.026667	 0.082222	 0.0039	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 4822	 0.009259	 0.024568	 0.001	 1168	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	5072	 4824	 0.002825	 0.012998	 0.0299	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4993	 4830	 0.004283	 0.010834	 0.002	 2535	 2535	 2535	 0.0	 0.0	 1	 -30.0	 30.0;
	4993	 4830	 0.001764	 0.007559	 0.0114	 3804	 3804	 3804	 0.0	 0.0	 1	 -30.0	 30.0;
	5720	 4832	 0.029982	 0.076594	 0.0009	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	4895	 4834	 0.155732	 0.364676	 0.004	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 4838	 0.011086	 0.024943	 0.0003	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	5142	 4839	 0.001481	 0.006696	 0.0111	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4960	 4840	 0.032222	 0.135679	 0.0084	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	5788	 4840	 0.021852	 0.055309	 0.0026	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	4960	 4840	 0.032222	 0.135062	 0.0083	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 4841	 0.016914	 0.045556	 0.0023	 612	 612	 612	 0.0	 0.0	 1	 -30.0	 30.0;
	4884	 4845	 0.120937	 0.267322	 0.003	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	4846	 4847	 0.001184	 0.002167	 0.0003	 10572	 10572	 10572	 0.0	 0.0	 1	 -30.0	 30.0;
	5800	 4847	 0.036049	 0.098272	 0.0012	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 4847	 0.064198	 0.139753	 0.0012	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	4961	 4855	 0.000561	 0.005658	 0.1444	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4962	 4855	 0.000561	 0.005665	 0.1473	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5505	 4857	 0.046611	 0.099521	 0.0011	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	5130	 4859	 0.03477	 0.081381	 0.001	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	5584	 4859	 0.017637	 0.039305	 0.0	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	5822	 4862	 0.000604	 0.001106	 0.0007	 23430	 23430	 23430	 0.0	 0.0	 1	 -30.0	 30.0;
	4895	 4867	 0.05039	 0.127715	 0.0014	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	4895	 4868	 0.05039	 0.132023	 0.0015	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	5244	 4869	 0.005442	 0.023003	 0.0003	 1263	 1263	 1263	 0.0	 0.0	 1	 -30.0	 30.0;
	5076	 4873	 0.034014	 0.072814	 0.0	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 4874	 0.001501	 0.010023	 0.0182	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5282	 4879	 0.002029	 0.013533	 0.025	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5714	 4880	 0.000693	 0.007389	 0.1617	 1704.0	 1704.0	 1704.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5826	 4892	 0.000252	 0.000504	 0.0021	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5618	 4895	 0.176619	 0.324767	 0.0035	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	5302	 4896	 0.010864	 0.050469	 0.0845	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5231	 4899	 0.000123	 0.001235	 0.0	 23932	 23932	 23932	 0.0	 0.0	 1	 -30.0	 30.0;
	5827	 4900	 0.003457	 0.009383	 0.0005	 3033	 3033	 3033	 0.0	 0.0	 1	 -30.0	 30.0;
	5163	 4901	 0.078105	 0.19098	 0.0019	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 4902	 0.001719	 0.011457	 0.0213	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 4902	 0.00079	 0.00798	 0.0284	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 4902	 0.001434	 0.009559	 0.0172	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5415	 4910	 0.027211	 0.068531	 0.0029	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	4935	 4910	 0.053893	 0.336558	 0.0056	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 4912	 0.004186	 0.02786	 0.0516	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5384	 4912	 0.002173	 0.014242	 0.0273	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5486	 4912	 0.004109	 0.027417	 0.0486	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5756	 4912	 0.001106	 0.007407	 0.0132	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5694	 4921	 0.010582	 0.04384	 0.0006	 655	 655	 655	 0.0	 0.0	 1	 -30.0	 30.0;
	5719	 4921	 0.047871	 0.201058	 0.0068	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	5779	 4921	 0.026455	 0.109095	 0.0013	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	4924	 4923	 0.000504	 0.00252	 0.0001	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	5828	 4926	 2.5e-05	 0.000252	 0.0	 116592	 116592	 116592	 0.0	 0.0	 1	 -30.0	 30.0;
	5663	 4938	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 4941	 0.000988	 0.002469	 0.0	 9817	 9817	 9817	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 4942	 0.000247	 0.003489	 0.0462	 1786.0	 1786.0	 1786.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5092	 4947	 0.01159	 0.029479	 0.0	 933	 933	 933	 0.0	 0.0	 1	 -30.0	 30.0;
	5580	 4949	 0.011358	 0.034938	 0.0016	 826	 826	 826	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 4949	 0.004074	 0.017407	 0.0026	 1697	 1697	 1697	 0.0	 0.0	 1	 -30.0	 30.0;
	5701	 4949	 0.021111	 0.054568	 0.0024	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	4959	 4951	 0.00083	 0.007052	 0.0724	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 4950	 0.000731	 0.003121	 0.0051	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 4951	 0.001025	 0.006888	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 4951	 0.000553	 0.003595	 0.0071	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5551	 4951	 0.000533	 0.003575	 0.0061	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5675	 4951	 0.000849	 0.00796	 0.0284	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5210	 4950	 0.000731	 0.003121	 0.0051	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5674	 4950	 0.000849	 0.008237	 0.0284	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5503	 4950	 0.000375	 0.003733	 0.0121	 833.0	 833.0	 833.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5477	 4954	 0.023086	 0.062346	 0.0031	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	5380	 4955	 0.004109	 0.027911	 0.0516	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5276	 4956	 0.018395	 0.050247	 0.0023	 556	 556	 556	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 4956	 0.024568	 0.064691	 0.0031	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	5830	 4957	 0.055178	 0.150416	 0.0017	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	5831	 4958	 0.005795	 0.011842	 0.0002	 2174	 2174	 2174	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 4960	 0.007284	 0.019383	 0.001	 1435	 1435	 1435	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 4960	 0.007407	 0.019506	 0.001	 1424	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	5459	 4963	 0.017561	 0.072436	 0.0009	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	5304	 4964	 0.030234	 0.078105	 0.0092	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	5832	 4965	 0.000756	 0.00252	 0.0001	 12855	 12855	 12855	 0.0	 0.0	 1	 -30.0	 30.0;
	5831	 4966	 0.086168	 0.179138	 0.0019	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	5117	 4969	 0.001916	 0.009323	 0.0223	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5582	 4969	 0.000514	 0.004859	 0.0182	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5116	 4969	 0.002212	 0.010114	 0.0233	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5363	 4969	 0.000948	 0.004602	 0.0081	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5364	 4968	 0.000909	 0.004385	 0.0081	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 4972	 0.022469	 0.061358	 0.0	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 4976	 0.013354	 0.03477	 0.0	 793	 793	 793	 0.0	 0.0	 1	 -30.0	 30.0;
	4984	 4982	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4984	 4981	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	4985	 4980	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	5238	 4987	 0.083346	 0.172487	 0.0018	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 4987	 0.028597	 0.075712	 0.001	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	5821	 4993	 0.004258	 0.011338	 0.0029	 2438	 2438	 2438	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 4995	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	5600	 4996	 0.006551	 0.043084	 0.001	 678	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	5645	 4996	 0.006803	 0.017637	 0.0	 1562	 1562	 1562	 0.0	 0.0	 1	 -30.0	 30.0;
	5388	 4996	 0.003023	 0.020156	 0.0	 1449	 1449	 1449	 0.0	 0.0	 1	 -30.0	 30.0;
	5647	 4998	 0.077118	 0.141163	 0.001	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	5773	 4998	 0.012245	 0.032527	 0.0004	 865	 865	 865	 0.0	 0.0	 1	 -30.0	 30.0;
	5740	 5000	 0.034845	 0.116528	 0.0013	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	5291	 5001	 0.057447	 0.105156	 0.0011	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	5623	 5002	 0.015621	 0.066767	 0.0008	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	5834	 5006	 0.009012	 0.017975	 0.0008	 1478	 1478	 1478	 0.0	 0.0	 1	 -30.0	 30.0;
	5835	 5009	 0.003779	 0.009322	 0.0001	 3024	 3024	 3024	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 5009	 0.004031	 0.009826	 0.0001	 2864	 2864	 2864	 0.0	 0.0	 1	 -30.0	 30.0;
	5539	 5013	 0.056437	 0.116049	 0.0012	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	5090	 5014	 0.028975	 0.096498	 0.0011	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	5670	 5020	 0.001481	 0.002716	 0.0002	 9602	 9602	 9602	 0.0	 0.0	 1	 -30.0	 30.0;
	5653	 5022	 0.017889	 0.048879	 0.0006	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 5023	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	5252	 5026	 0.089191	 0.183422	 0.002	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	5136	 5027	 0.001008	 0.003023	 0.0016	 8991	 8991	 8991	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 5029	 0.020741	 0.054444	 0.0026	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	5236	 5031	 0.015369	 0.044848	 0.0061	 623	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 5032	 0.040161	 0.101815	 0.0048	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	5640	 5038	 0.000988	 0.001975	 0.0002	 13450	 13450	 13450	 0.0	 0.0	 1	 -30.0	 30.0;
	4983	 5043	 0.009826	 0.032578	 0.0038	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	5757	 5043	 0.037339	 0.126455	 0.0048	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	5513	 5047	 0.016629	 0.046107	 0.0006	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 5056	 0.001127	 0.014433	 0.3408	 2203	 2203	 2203	 0.0	 0.0	 1	 -30.0	 30.0;
	5840	 5067	 0.000217	 0.000988	 0.002	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 5069	 0.055169	 0.100986	 0.001	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 5071	 0.033827	 0.084444	 0.0049	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	5842	 5071	 0.016049	 0.048765	 0.0048	 591	 591	 591	 0.0	 0.0	 1	 -30.0	 30.0;
	5841	 5077	 0.03043	 0.055702	 0.0023	 478	 478	 478	 0.0	 0.0	 1	 -30.0	 30.0;
	5844	 5081	 2.5e-05	 0.001235	 0.0	 24046	 24046	 24046	 0.0	 0.0	 1	 -30.0	 30.0;
	5763	 5086	 0.021164	 0.054674	 0.0006	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 5099	 0.015394	 0.030008	 0.0003	 902	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	5544	 5099	 0.036861	 0.075762	 0.0008	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	5744	 5107	 0.025185	 0.08	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 5112	 0.002756	 0.007867	 0.0022	 3790	 3790	 3790	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 5120	 0.006299	 0.025472	 0.0173	 1156	 1156	 1156	 0.0	 0.0	 1	 -30.0	 30.0;
	5144	 5126	 0.067523	 0.166289	 0.0017	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 5127	 0.00126	 0.004787	 0.0001	 5965	 5965	 5965	 0.0	 0.0	 1	 -30.0	 30.0;
	5748	 5158	 0.048879	 0.117158	 0.0012	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 5166	 0.083144	 0.200756	 0.0019	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	5844	 5192	 0.009383	 0.024938	 0.0013	 1115	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	5222	 5200	 0.021416	 0.048879	 0.0006	 554	 554	 554	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 5206	 0.002963	 0.008025	 0.0003	 3584	 3584	 3584	 0.0	 0.0	 1	 -30.0	 30.0;
	5339	 5207	 0.065004	 0.15747	 0.0016	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 5214	 0.031746	 0.083648	 0.001	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	5706	 5215	 0.000101	 0.00252	 0.0	 11707	 11707	 11707	 0.0	 0.0	 1	 -30.0	 30.0;
	5457	 5262	 0.000356	 0.00241	 0.004	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 5271	 0.000252	 0.000756	 0.0	 37051	 37051	 37051	 0.0	 0.0	 1	 -30.0	 30.0;
	5233	 5289	 0.015803	 0.035679	 0.0016	 778	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 5350	 0.03284	 0.089753	 0.0042	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	5588	 5354	 0.015369	 0.039808	 0.0005	 713	 713	 713	 0.0	 0.0	 1	 -30.0	 30.0;
	5713	 5370	 0.012469	 0.031605	 0.0015	 875	 875	 875	 0.0	 0.0	 1	 -30.0	 30.0;
	5602	 5388	 0.003527	 0.022928	 0.0	 1273	 1273	 1273	 0.0	 0.0	 1	 -30.0	 30.0;
	5494	 5403	 0.004444	 0.012222	 0.0006	 2284	 2284	 2284	 0.0	 0.0	 1	 -30.0	 30.0;
	5738	 5411	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	5548	 5424	 0.002771	 0.008314	 0.0001	 3270	 3270	 3270	 0.0	 0.0	 1	 -30.0	 30.0;
	5443	 5684	 0.131796	 0.441093	 0.0047	 67	 67	 67	 0.0	 0.0	 1	 -30.0	 30.0;
	5644	 5467	 0.007559	 0.018896	 0.0002	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	5575	 5469	 0.004031	 0.016125	 0.0002	 2052	 2052	 2052	 0.0	 0.0	 1	 -30.0	 30.0;
	5723	 5480	 0.042026	 0.178735	 0.0022	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	5545	 5488	 0.040383	 0.110198	 0.0053	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	5244	 5500	 0.015923	 0.067372	 0.0008	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 5500	 0.006198	 0.021819	 0.0112	 1321	 1321	 1321	 0.0	 0.0	 1	 -30.0	 30.0;
	5775	 5501	 0.00252	 0.004787	 0.0001	 6303	 6303	 6303	 0.0	 0.0	 1	 -30.0	 30.0;
	5581	 5514	 0.043739	 0.10582	 0.001	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	5813	 5517	 0.037541	 0.082389	 0.0009	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	5444	 5534	 0.009322	 0.031494	 0.0004	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	5565	 5625	 0.163559	 0.299393	 0.003	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	5591	 5593	 0.014613	 0.029226	 0.0003	 931	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	5603	 5601	 1.2e-05	 0.000123	 0.0002	 245373	 245373	 245373	 0.0	 0.0	 1	 -30.0	 30.0;
	5759	 5611	 0.102041	 0.22323	 0.0025	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5631	 5633	 0.00126	 0.003023	 0.0	 9287	 9287	 9287	 0.0	 0.0	 1	 -30.0	 30.0;
	5806	 5643	 0.046107	 0.116906	 0.0013	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	5735	 5657	 0.000691	 0.004681	 0.0091	 503.0	 503.0	 503.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5755	 5672	 0.008395	 0.022716	 0.0011	 1227	 1227	 1227	 0.0	 0.0	 1	 -30.0	 30.0;
	5830	 5746	 0.030234	 0.082389	 0.001	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	5832	 5775	 0.00252	 0.004787	 0.0001	 6303	 6303	 6303	 0.0	 0.0	 1	 -30.0	 30.0;
	2583	 5947	 0.001087	 0.013684	 0.3523	 1474.0	 1474.0	 1474.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 5947	 0.00079	 0.008375	 0.2042	 398.0	 398.0	 398.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6044	 5948	 0.000402	 0.004307	 0.1022	 7982	 7982	 7982	 0.0	 0.0	 1	 -30.0	 30.0;
	6076	 5948	 0.000997	 0.011039	 0.2632	 3115	 3115	 3115	 0.0	 0.0	 1	 -30.0	 30.0;
	5952	 5949	 0.001593	 0.015104	 0.3904	 2274	 2274	 2274	 0.0	 0.0	 1	 -30.0	 30.0;
	5952	 5949	 0.001593	 0.015104	 0.3904	 2274	 2274	 2274	 0.0	 0.0	 1	 -30.0	 30.0;
	6035	 5949	 0.000298	 0.002805	 0.0661	 281.0	 281.0	 281.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 5949	 0.001094	 0.012098	 0.277	 2843	 2843	 2843	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 5949	 0.001551	 0.01509	 0.3841	 2276	 2276	 2276	 0.0	 0.0	 1	 -30.0	 30.0;
	6140	 5949	 0.001517	 0.015533	 0.3631	 2213	 2213	 2213	 0.0	 0.0	 1	 -30.0	 30.0;
	4408	 5950	 0.001457	 0.002852	 0.0121	 10754	 10754	 10754	 0.0	 0.0	 1	 -30.0	 30.0;
	140	 5951	 0.004444	 0.028249	 0.0587	 470.0	 470.0	 470.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 5951	 0.001521	 0.007467	 0.0239	 4531	 4531	 4531	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 5951	 0.001501	 0.007407	 0.024	 4569	 4569	 4569	 0.0	 0.0	 1	 -30.0	 30.0;
	6037	 5952	 0.001205	 0.011669	 0.2917	 544.0	 544.0	 544.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6144	 5952	 0.003026	 0.029875	 0.7447	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 5952	 0.003199	 0.030803	 0.8002	 633.0	 633.0	 633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 5952	 0.003199	 0.030803	 0.8002	 633.0	 633.0	 633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 5952	 0.000796	 0.007798	 0.2032	 4405	 4405	 4405	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 5952	 0.000796	 0.007798	 0.2032	 4405	 4405	 4405	 0.0	 0.0	 1	 -30.0	 30.0;
	4126	 5953	 0.000644	 0.006295	 0.2022	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6048	 5953	 0.000893	 0.009709	 0.2373	 3541	 3541	 3541	 0.0	 0.0	 1	 -30.0	 30.0;
	6085	 5953	 0.00054	 0.004979	 0.1786	 6894	 6894	 6894	 0.0	 0.0	 1	 -30.0	 30.0;
	6091	 5953	 0.00047	 0.00528	 0.1219	 6513	 6513	 6513	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 5954	 0.001562	 0.012494	 0.0213	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3133	 5954	 0.000464	 0.003712	 0.0061	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5984	 5956	 0.00204	 0.02166	 0.5788	 1587	 1587	 1587	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 5957	 0.001323	 0.016184	 0.6007	 1474.0	 1474.0	 1474.0	 0.0	 0.0	 1	 -30.0	 30.0;
	264	 5957	 0.000741	 0.009398	 0.2238	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5846	 5957	 0.000852	 0.009017	 0.2123	 754.0	 754.0	 754.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 5957	 0.00117	 0.012223	 0.3004	 743.0	 743.0	 743.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6155	 5958	 0.008312	 0.049213	 0.0872	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	6211	 5958	 0.003747	 0.022341	 0.0429	 1525	 1525	 1525	 0.0	 0.0	 1	 -30.0	 30.0;
	6228	 5958	 0.000618	 0.002706	 0.0074	 12439	 12439	 12439	 0.0	 0.0	 1	 -30.0	 30.0;
	6044	 5959	 0.001198	 0.012597	 0.2888	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6072	 5959	 0.000596	 0.006004	 0.1374	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5980	 5960	 0.000286	 0.004044	 0.1418	 709.0	 709.0	 709.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6135	 5960	 0.000152	 0.002175	 0.0741	 481.0	 481.0	 481.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6152	 5960	 0.000538	 0.007833	 0.2593	 781.0	 781.0	 781.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6159	 5960	 0.001731	 0.01662	 0.0	 2067	 2067	 2067	 0.0	 0.0	 1	 -30.0	 30.0;
	6208	 5960	 0.00034	 0.004993	 0.1619	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6027	 5961	 0.000593	 0.070993	 0.001	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 5961	 0.000395	 0.11121	 0.001	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	6234	 5961	 0.000395	 0.083751	 0.001	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	6243	 5961	 0.000592	 0.38957	 0.001	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	6059	 5962	 0.003006	 0.026904	 0.8404	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	6064	 5962	 0.001198	 0.012396	 0.2882	 260.0	 260.0	 260.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6076	 5962	 0.001898	 0.017299	 0.5141	 588.0	 588.0	 588.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6101	 5962	 0.001219	 0.011711	 0.3408	 2933	 2933	 2933	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 5962	 0.00223	 0.022922	 0.5256	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2707	 5964	 0.001087	 0.011378	 0.2498	 1253.0	 1253.0	 1253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4126	 5964	 0.000914	 0.010325	 0.2296	 1316.0	 1316.0	 1316.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6145	 5963	 0.000861	 0.010961	 0.0479	 3141	 3141	 3141	 0.0	 0.0	 1	 -30.0	 30.0;
	5975	 5964	 0.001053	 0.012119	 0.2726	 2839	 2839	 2839	 0.0	 0.0	 1	 -30.0	 30.0;
	6091	 5964	 0.00147	 0.01699	 0.3812	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4787	 5965	 0.001462	 0.010351	 0.0213	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6155	 5965	 0.001681	 0.011068	 0.0203	 3084	 3084	 3084	 0.0	 0.0	 1	 -30.0	 30.0;
	6180	 5965	 0.002467	 0.014972	 0.0294	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6041	 5966	 0.008435	 0.033165	 0.1033	 1009	 1009	 1009	 0.0	 0.0	 1	 -30.0	 30.0;
	6161	 5966	 0.000593	 0.003733	 0.0119	 9134	 9134	 9134	 0.0	 0.0	 1	 -30.0	 30.0;
	6037	 5967	 0.001586	 0.015422	 0.387	 638.0	 638.0	 638.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6043	 5967	 0.000796	 0.008663	 0.2079	 363.0	 363.0	 363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6144	 5967	 0.000554	 0.005187	 0.1271	 6619	 6619	 6619	 0.0	 0.0	 1	 -30.0	 30.0;
	6165	 5967	 0.000699	 0.006801	 0.1687	 5050	 5050	 5050	 0.0	 0.0	 1	 -30.0	 30.0;
	6115	 5968	 0.001086	 0.012632	 0.2902	 315.0	 315.0	 315.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6178	 5968	 0.00183	 0.02106	 0.491	 1634	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	2659	 5969	 0.010933	 0.033333	 0.005	 977	 977	 977	 0.0	 0.0	 1	 -30.0	 30.0;
	6077	 5970	 0.002943	 0.018035	 0.0333	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 5970	 0.004998	 0.030578	 0.0553	 1115	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 5971	 0.00142	 0.014529	 0.4488	 483.0	 483.0	 483.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6223	 5971	 0.000741	 0.007645	 0.2343	 4495	 4495	 4495	 0.0	 0.0	 1	 -30.0	 30.0;
	5982	 5972	 0.000803	 0.008906	 0.2079	 892.0	 892.0	 892.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6090	 5972	 0.000301	 0.003384	 0.0797	 10163	 10163	 10163	 0.0	 0.0	 1	 -30.0	 30.0;
	6093	 5972	 0.000139	 0.00214	 0.0632	 785.0	 785.0	 785.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6204	 5972	 0.000215	 0.002285	 0.0522	 15043	 15043	 15043	 0.0	 0.0	 1	 -30.0	 30.0;
	6007	 5974	 0.005899	 0.068291	 0.1799	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	6007	 5973	 0.005899	 0.067267	 0.1882	 512	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	6123	 5974	 0.004081	 0.027771	 0.0474	 1230	 1230	 1230	 0.0	 0.0	 1	 -30.0	 30.0;
	6130	 5973	 0.004798	 0.032109	 0.0581	 1064	 1064	 1064	 0.0	 0.0	 1	 -30.0	 30.0;
	6090	 5975	 0.001553	 0.017918	 0.4069	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3496	 5976	 0.008751	 0.040276	 0.0654	 393.0	 393.0	 393.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6167	 5976	 0.002864	 0.011378	 0.0179	 398.0	 398.0	 398.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5982	 5977	 0.002249	 0.025153	 0.5805	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	6107	 5977	 0.000353	 0.003945	 0.0915	 258.0	 258.0	 258.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6178	 5977	 0.000281	 0.003141	 0.0728	 293.0	 293.0	 293.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6178	 5977	 0.000277	 0.003137	 0.0727	 294.0	 294.0	 294.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 5977	 0.000547	 0.00624	 0.1444	 5512	 5512	 5512	 0.0	 0.0	 1	 -30.0	 30.0;
	6045	 5978	 0.001648	 0.019287	 0.5958	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 5978	 0.00088	 0.00982	 0.2714	 884.0	 884.0	 884.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6123	 5979	 0.007409	 0.028518	 0.0894	 1172	 1172	 1172	 0.0	 0.0	 1	 -30.0	 30.0;
	6180	 5979	 0.0064	 0.034193	 0.0682	 993	 993	 993	 0.0	 0.0	 1	 -30.0	 30.0;
	5986	 5980	 0.000435	 0.005367	 0.1219	 6412	 6412	 6412	 0.0	 0.0	 1	 -30.0	 30.0;
	5997	 5980	 0.00022	 0.00322	 0.105	 528.0	 528.0	 528.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6046	 5980	 0.001385	 0.01108	 0.0	 760.0	 760.0	 760.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6135	 5980	 0.000194	 0.002771	 0.0952	 680.0	 680.0	 680.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6159	 5980	 0.001385	 0.014197	 0.0	 289.0	 289.0	 289.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6018	 5981	 0.000699	 0.008116	 0.2498	 4239	 4239	 4239	 0.0	 0.0	 1	 -30.0	 30.0;
	6102	 5981	 0.00097	 0.011288	 0.3483	 3048	 3048	 3048	 0.0	 0.0	 1	 -30.0	 30.0;
	6091	 5982	 0.001098	 0.012329	 0.2859	 253.0	 253.0	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6107	 5982	 0.001895	 0.021197	 0.491	 1623	 1623	 1623	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 5982	 0.002071	 0.023103	 0.5343	 1489	 1489	 1489	 0.0	 0.0	 1	 -30.0	 30.0;
	5845	 5983	 0.00031	 0.0032	 0.0783	 10739	 10739	 10739	 0.0	 0.0	 1	 -30.0	 30.0;
	5859	 5983	 0.00042	 0.00354	 0.0864	 9685	 9685	 9685	 0.0	 0.0	 1	 -30.0	 30.0;
	5858	 5983	 0.00034	 0.00361	 0.0884	 9522	 9522	 9522	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 5983	 0.00102	 0.01074	 0.2625	 3201	 3201	 3201	 0.0	 0.0	 1	 -30.0	 30.0;
	6000	 5984	 4e-05	 0.00045	 0.0113	 76420	 76420	 76420	 0.0	 0.0	 1	 -30.0	 30.0;
	5999	 5984	 4e-05	 0.00045	 0.0113	 76420	 76420	 76420	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 5984	 0.00095	 0.01006	 0.231	 3417	 3417	 3417	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 5984	 0.000907	 0.009626	 0.2429	 3571	 3571	 3571	 0.0	 0.0	 1	 -30.0	 30.0;
	6012	 5985	 0.004757	 0.023662	 0.0811	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6239	 5985	 0.003358	 0.01681	 0.0566	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	6179	 5986	 0.001644	 0.019926	 0.4375	 654.0	 654.0	 654.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5852	 5987	 0.002148	 0.018414	 0.6671	 1863	 1863	 1863	 0.0	 0.0	 1	 -30.0	 30.0;
	6074	 5987	 0.002278	 0.019508	 0.7042	 1758	 1758	 1758	 0.0	 0.0	 1	 -30.0	 30.0;
	6074	 5987	 0.002278	 0.019508	 0.7042	 1758	 1758	 1758	 0.0	 0.0	 1	 -30.0	 30.0;
	5997	 5988	 0.000256	 0.003788	 0.1238	 421.0	 421.0	 421.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 5988	 0.000425	 0.006233	 0.2037	 488.0	 488.0	 488.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5990	 5989	 0.006044	 0.04399	 0.0809	 778	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	6236	 5989	 0.003526	 0.024948	 0.0597	 283.0	 283.0	 283.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5512	 6187	 0.001521	 0.009047	 0.0172	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5996	 5991	 0.000977	 0.009199	 0.2111	 3733	 3733	 3733	 0.0	 0.0	 1	 -30.0	 30.0;
	6105	 5991	 0.000672	 0.009862	 0.3233	 3493	 3493	 3493	 0.0	 0.0	 1	 -30.0	 30.0;
	6147	 5991	 0.000564	 0.006641	 0.1565	 324.0	 324.0	 324.0	 0.0	 0.0	 1	 -30.0	 30.0;
	800	 5993	 0.002171	 0.033086	 0.8404	 1033	 1033	 1033	 0.0	 0.0	 1	 -30.0	 30.0;
	6062	 5992	 0.00499	 0.029882	 0.053	 1140	 1140	 1140	 0.0	 0.0	 1	 -30.0	 30.0;
	6123	 5992	 0.011619	 0.075838	 0.1313	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	6155	 5992	 0.000168	 0.002564	 0.0077	 13437	 13437	 13437	 0.0	 0.0	 1	 -30.0	 30.0;
	6155	 5992	 0.000442	 0.003311	 0.006	 10336	 10336	 10336	 0.0	 0.0	 1	 -30.0	 30.0;
	6155	 5992	 0.000442	 0.003311	 0.006	 10336	 10336	 10336	 0.0	 0.0	 1	 -30.0	 30.0;
	6122	 5994	 0.00144	 0.007267	 0.014	 4661	 4661	 4661	 0.0	 0.0	 1	 -30.0	 30.0;
	6154	 5994	 0.001699	 0.006835	 0.0207	 4902	 4902	 4902	 0.0	 0.0	 1	 -30.0	 30.0;
	6211	 5994	 0.004595	 0.023202	 0.0448	 1460	 1460	 1460	 0.0	 0.0	 1	 -30.0	 30.0;
	6161	 5995	 0.00697	 0.028385	 0.0825	 1182	 1182	 1182	 0.0	 0.0	 1	 -30.0	 30.0;
	6180	 5995	 0.002121	 0.00944	 0.025	 3569	 3569	 3569	 0.0	 0.0	 1	 -30.0	 30.0;
	6164	 5996	 0.000208	 0.001994	 0.0458	 671.0	 671.0	 671.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6154	 5998	 0.001464	 0.005926	 0.018	 5656	 5656	 5656	 0.0	 0.0	 1	 -30.0	 30.0;
	6228	 5998	 0.001867	 0.007704	 0.0228	 4356	 4356	 4356	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 6001	 0.002765	 0.015802	 0.0284	 459.0	 459.0	 459.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 6001	 0.001481	 0.008435	 0.0153	 4032	 4032	 4032	 0.0	 0.0	 1	 -30.0	 30.0;
	6168	 6001	 0.007546	 0.023803	 0.0719	 1383	 1383	 1383	 0.0	 0.0	 1	 -30.0	 30.0;
	6006	 6002	 0.000949	 0.010021	 0.2458	 544.0	 544.0	 544.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 6002	 0.000693	 0.007271	 0.1793	 755.0	 755.0	 755.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6041	 6003	 0.002449	 0.009363	 0.0294	 3568	 3568	 3568	 0.0	 0.0	 1	 -30.0	 30.0;
	6161	 6003	 0.006281	 0.025146	 0.078	 1333	 1333	 1333	 0.0	 0.0	 1	 -30.0	 30.0;
	6126	 6004	 0.001018	 0.011565	 0.3581	 2974	 2974	 2974	 0.0	 0.0	 1	 -30.0	 30.0;
	6126	 6004	 0.001018	 0.011537	 0.361	 2981	 2981	 2981	 0.0	 0.0	 1	 -30.0	 30.0;
	6176	 6004	 0.000125	 0.001627	 0.0549	 21158	 21158	 21158	 0.0	 0.0	 1	 -30.0	 30.0;
	6176	 6004	 0.000125	 0.001627	 0.0549	 21158	 21158	 21158	 0.0	 0.0	 1	 -30.0	 30.0;
	1756	 6005	 0.05359	 0.118644	 0.0025	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	5464	 6005	 0.097506	 0.227891	 0.0026	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	5845	 6006	 0.00072	 0.007589	 0.1851	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 6006	 0.00027	 0.00286	 0.0702	 459.0	 459.0	 459.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6054	 6006	 1e-05	 0.0001	 0.0	 281.0	 281.0	 281.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6053	 6006	 1e-05	 0.0001	 0.0	 266.0	 266.0	 266.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5992	 6007	 0.002887	 0.021424	 0.0407	 1598	 1598	 1598	 0.0	 0.0	 1	 -30.0	 30.0;
	5992	 6007	 0.002887	 0.021424	 0.0407	 1598	 1598	 1598	 0.0	 0.0	 1	 -30.0	 30.0;
	6206	 6008	 0.000826	 0.012161	 0.3935	 2833	 2833	 2833	 0.0	 0.0	 1	 -30.0	 30.0;
	6225	 6008	 0.000489	 0.007064	 0.2338	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6229	 6008	 0.000118	 0.001725	 0.057	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6127	 6010	 0.001189	 0.010138	 0.3687	 421.0	 421.0	 421.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6127	 6009	 0.001189	 0.010138	 0.3672	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6129	 6010	 0.001236	 0.010554	 0.3821	 527.0	 527.0	 527.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6129	 6009	 0.001236	 0.010554	 0.3821	 529.0	 529.0	 529.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5850	 6011	 0.001165	 0.008938	 0.0484	 429.0	 429.0	 429.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6025	 6014	 0.002507	 0.02106	 0.7903	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6025	 6013	 0.002508	 0.021481	 0.7829	 478.0	 478.0	 478.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 6014	 0.004181	 0.035773	 1.2967	 259.0	 259.0	 259.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 6013	 0.000407	 0.006051	 0.2001	 602.0	 602.0	 602.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 6014	 0.000407	 0.006051	 0.2001	 847.0	 847.0	 847.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 6014	 0.000609	 0.005665	 0.2079	 6060	 6060	 6060	 0.0	 0.0	 1	 -30.0	 30.0;
	5848	 6015	 0.000731	 0.003457	 0.0077	 9771	 9771	 9771	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 6015	 0.00077	 0.003457	 0.0077	 9748	 9748	 9748	 0.0	 0.0	 1	 -30.0	 30.0;
	6060	 6016	 0.024931	 0.154432	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	6061	 6016	 0.018006	 0.119806	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	6162	 6016	 0.031856	 0.161357	 0.0	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	6081	 6017	 0.000963	 0.01117	 0.3449	 3080	 3080	 3080	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 6017	 0.000838	 0.009778	 0.3018	 3518	 3518	 3518	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 6017	 0.000838	 0.009778	 0.3018	 3518	 3518	 3518	 0.0	 0.0	 1	 -30.0	 30.0;
	6132	 6017	 0.00024	 0.00296	 0.0921	 269.0	 269.0	 269.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6020	 6018	 0.000769	 0.00865	 0.2718	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6020	 6018	 0.000769	 0.00865	 0.2718	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6103	 6018	 0.001662	 0.019321	 0.5969	 1781	 1781	 1781	 0.0	 0.0	 1	 -30.0	 30.0;
	5846	 6019	 0.00157	 0.01564	 0.3832	 824.0	 824.0	 824.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 6019	 0.00049	 0.00518	 0.1271	 703.0	 703.0	 703.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 6019	 0.00049	 0.00518	 0.1271	 703.0	 703.0	 703.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 6019	 0.00055	 0.00474	 0.1157	 766.0	 766.0	 766.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6242	 6019	 0.00017	 0.00166	 0.0347	 729.0	 729.0	 729.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 6020	 0.00099	 0.011177	 0.3515	 684.0	 684.0	 684.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 6020	 0.00099	 0.011177	 0.3515	 684.0	 684.0	 684.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5845	 6021	 0.00026	 0.00273	 0.067	 12590	 12590	 12590	 0.0	 0.0	 1	 -30.0	 30.0;
	5846	 6022	 0.00026	 0.002717	 0.067	 12649	 12649	 12649	 0.0	 0.0	 1	 -30.0	 30.0;
	4984	 6023	 0.00212	 0.011757	 0.0051	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3096	 6025	 0.000528	 0.005682	 0.1011	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6066	 6024	 0.009193	 0.044869	 0.1296	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	6067	 6023	 0.009193	 0.044869	 0.1296	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	6239	 6024	 0.002892	 0.022074	 0.1215	 1551	 1551	 1551	 0.0	 0.0	 1	 -30.0	 30.0;
	6238	 6023	 0.005687	 0.02834	 0.0952	 1195	 1195	 1195	 0.0	 0.0	 1	 -30.0	 30.0;
	6085	 6025	 0.001732	 0.014836	 0.5408	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 6025	 0.001731	 0.014547	 0.5457	 2357	 2357	 2357	 0.0	 0.0	 1	 -30.0	 30.0;
	6045	 6026	 0.00106	 0.012389	 0.3827	 342.0	 342.0	 342.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6045	 6026	 0.00106	 0.012389	 0.3827	 342.0	 342.0	 342.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6045	 6026	 0.00106	 0.012389	 0.3827	 342.0	 342.0	 342.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6103	 6026	 0.00081	 0.009439	 0.2916	 3645	 3645	 3645	 0.0	 0.0	 1	 -30.0	 30.0;
	6102	 6026	 0.00081	 0.009439	 0.2916	 3645	 3645	 3645	 0.0	 0.0	 1	 -30.0	 30.0;
	6063	 6027	 0.000593	 0.171854	 0.001	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	6075	 6027	 0.00162	 0.013057	 0.0391	 2624	 2624	 2624	 0.0	 0.0	 1	 -30.0	 30.0;
	6233	 6027	 0.000395	 0.036148	 0.001	 956	 956	 956	 0.0	 0.0	 1	 -30.0	 30.0;
	6243	 6027	 0.000592	 0.001679	 0.001	 275.0	 275.0	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5854	 6028	 0.000596	 0.006247	 0.2108	 645.0	 645.0	 645.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5860	 6028	 0.000769	 0.010215	 0.3422	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6128	 6028	 0.000596	 0.006219	 0.2079	 643.0	 643.0	 643.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6207	 6028	 0.000526	 0.006881	 0.2313	 516.0	 516.0	 516.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4903	 6032	 0.000512	 0.007112	 0.2585	 1790.0	 1790.0	 1790.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4904	 6031	 0.000506	 0.007112	 0.2585	 1790.0	 1790.0	 1790.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5848	 6030	 0.000705	 0.003692	 0.0118	 9186	 9186	 9186	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 6030	 0.00067	 0.003579	 0.012	 9482	 9482	 9482	 0.0	 0.0	 1	 -30.0	 30.0;
	6189	 6029	 0.000119	 0.007901	 0.0	 779.0	 779.0	 779.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6210	 6032	 0.000443	 0.004077	 0.1429	 306.0	 306.0	 306.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6210	 6031	 0.000443	 0.004078	 0.1429	 8417	 8417	 8417	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 6033	 0.000353	 0.004072	 0.1257	 8447	 8447	 8447	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 6033	 0.000353	 0.004072	 0.1257	 8447	 8447	 8447	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 6033	 0.00054	 0.006094	 0.1916	 315.0	 315.0	 315.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 6033	 0.00054	 0.006094	 0.1916	 315.0	 315.0	 315.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5853	 6034	 0.00099	 0.007918	 0.014	 4327	 4327	 4327	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 6034	 0.003899	 0.025983	 0.0509	 1315	 1315	 1315	 0.0	 0.0	 1	 -30.0	 30.0;
	6059	 6035	 7.3e-05	 0.003959	 0.0029	 253.0	 253.0	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 6035	 7.3e-05	 0.003635	 0.0029	 9496	 9496	 9496	 0.0	 0.0	 1	 -30.0	 30.0;
	6111	 6036	 0.000593	 0.549393	 0.001	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 6036	 0.000593	 0.274647	 0.001	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	6203	 6036	 9.9e-05	 0.000672	 0.001	 50827	 50827	 50827	 0.0	 0.0	 1	 -30.0	 30.0;
	6149	 6038	 0.000751	 0.002609	 0.0006	 12717	 12717	 12717	 0.0	 0.0	 1	 -30.0	 30.0;
	6200	 6038	 0.00124	 0.004622	 0.0016	 7215	 7215	 7215	 0.0	 0.0	 1	 -30.0	 30.0;
	6157	 6039	 0.00111	 0.0124	 0.2946	 519.0	 519.0	 519.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6178	 6039	 0.000368	 0.004359	 0.0947	 516.0	 516.0	 516.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6046	 6040	 0.001039	 0.007479	 0.0	 4573	 4573	 4573	 0.0	 0.0	 1	 -30.0	 30.0;
	6136	 6040	 0.017313	 0.182133	 0.0	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	6159	 6040	 0.002424	 0.019391	 0.0	 1767	 1767	 1767	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 6040	 0.002424	 0.01385	 0.0	 2456	 2456	 2456	 0.0	 0.0	 1	 -30.0	 30.0;
	1064	 6118	 0.006104	 0.044405	 0.0552	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 6041	 0.001659	 0.0064	 0.0237	 5222	 5222	 5222	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 6041	 0.001659	 0.0064	 0.0237	 5222	 5222	 5222	 0.0	 0.0	 1	 -30.0	 30.0;
	6138	 6042	 0.0016	 0.011773	 0.0203	 459.0	 459.0	 459.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6158	 6042	 0.002173	 0.015388	 0.0172	 347.0	 347.0	 347.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 6043	 0.001828	 0.019868	 0.4794	 580.0	 580.0	 580.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6064	 6044	 0.000796	 0.008698	 0.201	 733.0	 733.0	 733.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6081	 6045	 0.000568	 0.006586	 0.205	 284.0	 284.0	 284.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6081	 6045	 0.000568	 0.006586	 0.205	 284.0	 284.0	 284.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 6045	 0.00113	 0.01283	 0.3286	 2681	 2681	 2681	 0.0	 0.0	 1	 -30.0	 30.0;
	6142	 6046	 0.000418	 0.006302	 0.1928	 5467	 5467	 5467	 0.0	 0.0	 1	 -30.0	 30.0;
	6156	 6046	 0.0016	 0.023587	 0.68	 493.0	 493.0	 493.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6089	 6047	 0.001284	 0.014657	 0.0554	 2347	 2347	 2347	 0.0	 0.0	 1	 -30.0	 30.0;
	6090	 6048	 0.000422	 0.005118	 0.1184	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6115	 6048	 0.000637	 0.009162	 0.2316	 532.0	 532.0	 532.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6115	 6048	 0.000852	 0.009571	 0.2189	 509.0	 509.0	 509.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6051	 6050	 0.005329	 0.016298	 0.0056	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	6051	 6049	 0.005329	 0.016298	 0.0056	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	6200	 6050	 0.004529	 0.020129	 0.0072	 1674	 1674	 1674	 0.0	 0.0	 1	 -30.0	 30.0;
	6200	 6049	 0.004529	 0.020129	 0.0072	 1674	 1674	 1674	 0.0	 0.0	 1	 -30.0	 30.0;
	6117	 6051	 0.003818	 0.0204	 0.0074	 1664	 1664	 1664	 0.0	 0.0	 1	 -30.0	 30.0;
	6117	 6051	 0.003818	 0.0204	 0.0074	 1664	 1664	 1664	 0.0	 0.0	 1	 -30.0	 30.0;
	6060	 6055	 0.038781	 0.237535	 0.0	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	6136	 6055	 0.025623	 0.202909	 0.0	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6055	 0.024931	 0.09903	 0.0	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 6055	 0.022161	 0.168283	 0.0	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	5851	 6056	 0.00087	 0.00968	 0.2313	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 6056	 0.00121	 0.01281	 0.3145	 753.0	 753.0	 753.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6205	 6056	 6e-05	 0.00059	 0.0144	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6063	 6057	 0.000395	 0.145778	 0.001	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	6073	 6059	 0.001295	 0.011302	 0.3812	 3035	 3035	 3035	 0.0	 0.0	 1	 -30.0	 30.0;
	6073	 6059	 0.000104	 0.003904	 0.0029	 8841	 8841	 8841	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 6059	 7.3e-05	 0.039586	 0.0029	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	6148	 6059	 7.3e-05	 0.016832	 0.0029	 2052	 2052	 2052	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 6059	 7.3e-05	 0.009151	 0.0029	 3773	 3773	 3773	 0.0	 0.0	 1	 -30.0	 30.0;
	6202	 6059	 7.3e-05	 0.069075	 0.0029	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	6235	 6059	 0.000547	 0.004696	 1.2794	 835.0	 835.0	 835.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6061	 6060	 0.032549	 0.126731	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 6060	 0.033934	 0.182133	 0.0	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 6061	 0.000407	 0.004079	 0.1162	 759.0	 759.0	 759.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 6061	 0.000407	 0.004079	 0.1162	 759.0	 759.0	 759.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6190	 6061	 4.8e-05	 0.001177	 0.0029	 29308	 29308	 29308	 0.0	 0.0	 1	 -30.0	 30.0;
	6123	 6062	 0.006744	 0.045697	 0.0819	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	6232	 6063	 0.000395	 0.202864	 0.001	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	6243	 6063	 0.000593	 0.087308	 0.001	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	6170	 6064	 0.000298	 0.003006	 0.0713	 544.0	 544.0	 544.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6226	 6064	 0.00162	 0.016378	 0.3829	 429.0	 429.0	 429.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6111	 6065	 0.000593	 0.32164	 0.001	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	6139	 6065	 0.000593	 0.023506	 0.001	 1469	 1469	 1469	 0.0	 0.0	 1	 -30.0	 30.0;
	6167	 6065	 0.010588	 0.054894	 0.1043	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6088	 6066	 0.001754	 0.012251	 0.0484	 2790	 2790	 2790	 0.0	 0.0	 1	 -30.0	 30.0;
	6089	 6067	 0.001762	 0.012148	 0.049	 2813	 2813	 2813	 0.0	 0.0	 1	 -30.0	 30.0;
	6123	 6068	 0.004508	 0.017357	 0.0537	 1926	 1926	 1926	 0.0	 0.0	 1	 -30.0	 30.0;
	6180	 6068	 0.0093	 0.045353	 0.1033	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 6069	 0.001018	 0.011454	 0.3604	 3003	 3003	 3003	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 6069	 0.001018	 0.011454	 0.3604	 3003	 3003	 3003	 0.0	 0.0	 1	 -30.0	 30.0;
	6074	 6070	 0.003133	 0.026821	 0.6166	 1279	 1279	 1279	 0.0	 0.0	 1	 -30.0	 30.0;
	6204	 6070	 0.002718	 0.024668	 0.5747	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 6070	 0.00277	 0.01662	 0.0	 2050	 2050	 2050	 0.0	 0.0	 1	 -30.0	 30.0;
	141	 6072	 0.001088	 0.01173	 0.2548	 1624.0	 1624.0	 1624.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6075	 6071	 0.004583	 0.024	 0.0701	 1413	 1413	 1413	 0.0	 0.0	 1	 -30.0	 30.0;
	6075	 6071	 0.004583	 0.025185	 0.0701	 1349	 1349	 1349	 0.0	 0.0	 1	 -30.0	 30.0;
	6076	 6072	 0.000796	 0.007999	 0.1863	 777.0	 777.0	 777.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6101	 6073	 0.000873	 0.007825	 0.2541	 4385	 4385	 4385	 0.0	 0.0	 1	 -30.0	 30.0;
	6148	 6073	 7.3e-05	 0.058542	 0.0029	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 6073	 7.3e-05	 0.032502	 0.0029	 1063	 1063	 1063	 0.0	 0.0	 1	 -30.0	 30.0;
	6202	 6073	 7.3e-05	 0.024529	 0.0029	 1408	 1408	 1408	 0.0	 0.0	 1	 -30.0	 30.0;
	6226	 6073	 0.00153	 0.014349	 0.3379	 299.0	 299.0	 299.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6074	 0.000184	 0.002407	 0.0079	 14302	 14302	 14302	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 6074	 0.002299	 0.020665	 0.0	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 6075	 0.011477	 0.037472	 0.1077	 881	 881	 881	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 6075	 0.007763	 0.037649	 0.1241	 899	 899	 899	 0.0	 0.0	 1	 -30.0	 30.0;
	6243	 6075	 0.000573	 0.003911	 0.0071	 8735	 8735	 8735	 0.0	 0.0	 1	 -30.0	 30.0;
	6235	 6076	 0.000796	 0.0075	 0.1952	 671.0	 671.0	 671.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 6077	 0.007921	 0.048632	 0.0885	 701	 701	 701	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 6079	 3.7e-05	 9.3e-05	 0.0029	 344932	 344932	 344932	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 6079	 3.7e-05	 9.3e-05	 0.0029	 344932	 344932	 344932	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 6078	 8.3e-05	 0.000152	 0.0029	 609.0	 609.0	 609.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 6078	 3.7e-05	 9.3e-05	 0.0029	 1057.0	 1057.0	 1057.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5849	 6080	 6.9e-05	 0.000139	 0.0029	 222473	 222473	 222473	 0.0	 0.0	 1	 -30.0	 30.0;
	6132	 6081	 0.0012	 0.014039	 0.4369	 2451	 2451	 2451	 0.0	 0.0	 1	 -30.0	 30.0;
	6089	 6083	 0.001126	 0.005707	 0.0166	 5936	 5936	 5936	 0.0	 0.0	 1	 -30.0	 30.0;
	6087	 6082	 0.001286	 0.006688	 0.0202	 5070	 5070	 5070	 0.0	 0.0	 1	 -30.0	 30.0;
	5860	 6085	 0.001066	 0.012292	 0.4641	 2799	 2799	 2799	 0.0	 0.0	 1	 -30.0	 30.0;
	6090	 6084	 0.00018	 0.001517	 0.0578	 22600	 22600	 22600	 0.0	 0.0	 1	 -30.0	 30.0;
	6091	 6085	 0.00018	 0.001517	 0.0578	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6090	 6084	 0.00018	 0.001517	 0.0578	 22600	 22600	 22600	 0.0	 0.0	 1	 -30.0	 30.0;
	5850	 6086	 1.6e-05	 0.000136	 0.0007	 252116	 252116	 252116	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 6091	 0.000938	 0.010451	 0.2253	 1487.0	 1487.0	 1487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6097	 6087	 0.005965	 0.04239	 0.1009	 807	 807	 807	 0.0	 0.0	 1	 -30.0	 30.0;
	6130	 6088	 0.003315	 0.023518	 0.0665	 1454	 1454	 1454	 0.0	 0.0	 1	 -30.0	 30.0;
	6093	 6090	 0.000202	 0.003026	 0.0921	 702.0	 702.0	 702.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6204	 6090	 0.000558	 0.004985	 0.1219	 6883	 6883	 6883	 0.0	 0.0	 1	 -30.0	 30.0;
	6207	 6091	 0.001205	 0.014626	 0.5164	 2353	 2353	 2353	 0.0	 0.0	 1	 -30.0	 30.0;
	6115	 6092	 0.002119	 0.023913	 0.0052	 494.0	 494.0	 494.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 6092	 0.001177	 0.012465	 0.3177	 788.0	 788.0	 788.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6122	 6095	 0.010317	 0.052128	 0.099	 650	 650	 650	 0.0	 0.0	 1	 -30.0	 30.0;
	6163	 6095	 0.001126	 0.010031	 0.0313	 269.0	 269.0	 269.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6211	 6095	 0.0096	 0.078696	 0.1357	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	6146	 6096	 0.000341	 0.005024	 0.3259	 6857	 6857	 6857	 0.0	 0.0	 1	 -30.0	 30.0;
	6146	 6096	 0.000341	 0.005024	 0.3259	 6857	 6857	 6857	 0.0	 0.0	 1	 -30.0	 30.0;
	6164	 6096	 0.000268	 0.003944	 0.1279	 583.0	 583.0	 583.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6123	 6097	 0.005432	 0.036524	 0.0651	 935	 935	 935	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 6099	 0.00032	 0.00305	 0.0723	 256.0	 256.0	 256.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 6098	 0.00045	 0.00479	 0.1066	 7176	 7176	 7176	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 6099	 0.00045	 0.00479	 0.1066	 7176	 7176	 7176	 0.0	 0.0	 1	 -30.0	 30.0;
	5851	 6100	 0.00022	 0.00232	 0.0544	 456.0	 456.0	 456.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6162	 6102	 0.001644	 0.01558	 0.4807	 927.0	 927.0	 927.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 6103	 0.000693	 0.00682	 0.2072	 683.0	 683.0	 683.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6198	 6102	 0.000225	 0.002472	 0.071	 823.0	 823.0	 823.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6197	 6103	 0.000222	 0.00247	 0.0817	 1067.0	 1067.0	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6140	 6104	 0.00196	 0.020187	 0.4812	 1703	 1703	 1703	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 6104	 0.000533	 0.005305	 0.1304	 6476	 6476	 6476	 0.0	 0.0	 1	 -30.0	 30.0;
	6176	 6104	 0.001517	 0.015623	 0.3738	 2200	 2200	 2200	 0.0	 0.0	 1	 -30.0	 30.0;
	6202	 6104	 0.00196	 0.019813	 0.4881	 1735	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	6147	 6105	 0.000832	 0.012165	 0.3939	 2832	 2832	 2832	 0.0	 0.0	 1	 -30.0	 30.0;
	6237	 6105	 0.000819	 0.013667	 0.3493	 2522	 2522	 2522	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 6106	 0.000533	 0.004564	 0.1069	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6165	 6106	 0.00286	 0.029584	 0.6931	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6110	 6108	 0.0007	 0.007379	 0.1808	 601.0	 601.0	 601.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 6108	 0.00076	 0.008	 0.1779	 4297	 4297	 4297	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 6109	 0.001101	 0.017299	 0.7474	 483.0	 483.0	 483.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 6109	 0.001101	 0.017299	 0.7474	 483.0	 483.0	 483.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6214	 6110	 0.001233	 0.013054	 0.3191	 1058.0	 1058.0	 1058.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 6113	 0.000542	 0.007881	 0.2605	 279.0	 279.0	 279.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6208	 6113	 0.000357	 0.005187	 0.1718	 6641	 6641	 6641	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 6114	 0.00074	 0.007769	 0.1906	 884.0	 884.0	 884.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5859	 6114	 0.00041	 0.00348	 0.0846	 334.0	 334.0	 334.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5858	 6114	 0.00033	 0.00352	 0.0864	 308.0	 308.0	 308.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5852	 6116	 2e-05	 9.8e-05	 0.0	 345173	 345173	 345173	 0.0	 0.0	 1	 -30.0	 30.0;
	6210	 6116	 0.000414	 0.003537	 0.2573	 9695	 9695	 9695	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 6116	 0.002424	 0.021053	 0.7624	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6119	 6117	 0.00332	 0.010222	 0.0143	 3213	 3213	 3213	 0.0	 0.0	 1	 -30.0	 30.0;
	6149	 6119	 0.003351	 0.012302	 0.0042	 2708	 2708	 2708	 0.0	 0.0	 1	 -30.0	 30.0;
	6148	 6120	 0.000155	 0.001518	 0.3148	 22626	 22626	 22626	 0.0	 0.0	 1	 -30.0	 30.0;
	5853	 6121	 0.000198	 0.001975	 0.0	 17394	 17394	 17394	 0.0	 0.0	 1	 -30.0	 30.0;
	6182	 6121	 0.004429	 0.025092	 0.0871	 1355	 1355	 1355	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 6121	 0.001414	 0.020346	 0.0707	 1693	 1693	 1693	 0.0	 0.0	 1	 -30.0	 30.0;
	6145	 6123	 0.001033	 0.013049	 0.0551	 2638	 2638	 2638	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 6125	 0.002923	 0.016731	 0.0304	 459.0	 459.0	 459.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6134	 6127	 0.000942	 0.008047	 0.2917	 4262	 4262	 4262	 0.0	 0.0	 1	 -30.0	 30.0;
	6210	 6127	 0.00194	 0.016614	 0.6003	 2064	 2064	 2064	 0.0	 0.0	 1	 -30.0	 30.0;
	5854	 6128	 3.5e-05	 0.000139	 0.0058	 259.0	 259.0	 259.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6128	 0.000807	 0.008383	 0.281	 872.0	 872.0	 872.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6137	 6129	 0.000408	 0.003572	 0.1288	 1268.0	 1268.0	 1268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 6129	 0.000846	 0.007839	 0.2833	 4379	 4379	 4379	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 6129	 0.000846	 0.007839	 0.2823	 4379	 4379	 4379	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 6129	 0.000455	 0.00419	 0.1532	 833.0	 833.0	 833.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 6131	 0.004523	 0.022716	 0.0699	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	6185	 6131	 0.001146	 0.005669	 0.0172	 5970	 5970	 5970	 0.0	 0.0	 1	 -30.0	 30.0;
	6185	 6133	 0.004405	 0.022756	 0.0697	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	6210	 6134	 0.001004	 0.008546	 0.309	 4013	 4013	 4013	 0.0	 0.0	 1	 -30.0	 30.0;
	6150	 6136	 0.000554	 0.007756	 0.0	 444.0	 444.0	 444.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6159	 6136	 0.018006	 0.189058	 0.0	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 6136	 0.00277	 0.01662	 0.0	 628.0	 628.0	 628.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6162	 6137	 0.00025	 0.002292	 0.0829	 1324.0	 1324.0	 1324.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6173	 6138	 0.001561	 0.011595	 0.0172	 459.0	 459.0	 459.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6141	 0.00094	 0.012774	 0.412	 2696	 2696	 2696	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6141	 0.00094	 0.012762	 0.411	 2698	 2698	 2698	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 6142	 0.00042	 0.006343	 0.1933	 5431	 5431	 5431	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 6144	 0.000921	 0.009017	 0.2236	 3809	 3809	 3809	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 6144	 0.000956	 0.008996	 0.2224	 3817	 3817	 3817	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 6144	 0.002424	 0.024785	 0.621	 642.0	 642.0	 642.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6223	 6144	 0.001537	 0.016662	 0.3851	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6147	 6146	 0.000341	 0.005024	 0.3259	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6216	 6147	 0.000861	 0.009919	 0.2325	 801.0	 801.0	 801.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6166	 6148	 7.3e-05	 0.011484	 0.0029	 3007	 3007	 3007	 0.0	 0.0	 1	 -30.0	 30.0;
	6202	 6148	 7.3e-05	 0.008668	 0.0029	 3983	 3983	 3983	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 6148	 0.003303	 0.035104	 0.7903	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	5855	 6150	 0.000945	 0.010861	 0.226	 444.0	 444.0	 444.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5854	 6151	 0.00081	 0.008386	 0.2801	 867.0	 867.0	 867.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 6151	 0.019391	 0.119806	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 6151	 0.00277	 0.16205	 0.0	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	6229	 6152	 0.000118	 0.001725	 0.057	 19968	 19968	 19968	 0.0	 0.0	 1	 -30.0	 30.0;
	2234	 6153	 0.006791	 0.019711	 0.0099	 1752	 1752	 1752	 0.0	 0.0	 1	 -30.0	 30.0;
	1192	 6155	 0.011176	 0.069403	 0.1286	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6180	 6155	 0.00127	 0.019504	 0.0592	 281.0	 281.0	 281.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6211	 6155	 0.007526	 0.044761	 0.0829	 761	 761	 761	 0.0	 0.0	 1	 -30.0	 30.0;
	5855	 6156	 0.00062	 0.00665	 0.1707	 496.0	 496.0	 496.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 6157	 0.000796	 0.011669	 0.3166	 393.0	 393.0	 393.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 6158	 0.004978	 0.036425	 0.0648	 459.0	 459.0	 459.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 6160	 0.0	 0.0005	 0.0012	 69049	 69049	 69049	 0.0	 0.0	 1	 -30.0	 30.0;
	36	 6195	 0.001724	 0.039197	 0.5453	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 6194	 0.001724	 0.039197	 0.5453	 956	 956	 956	 0.0	 0.0	 1	 -30.0	 30.0;
	6215	 6161	 0.000527	 0.008085	 0.0244	 4262	 4262	 4262	 0.0	 0.0	 1	 -30.0	 30.0;
	6221	 6161	 0.001679	 0.025659	 0.0779	 329.0	 329.0	 329.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5849	 6162	 0.000438	 0.003941	 0.1411	 1275.0	 1275.0	 1275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6195	 6164	 2.1e-05	 0.000139	 0.0	 245589	 245589	 245589	 0.0	 0.0	 1	 -30.0	 30.0;
	6206	 6164	 0.000275	 0.004076	 0.1317	 8451	 8451	 8451	 0.0	 0.0	 1	 -30.0	 30.0;
	6208	 6164	 0.000958	 0.014044	 0.4598	 444.0	 444.0	 444.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 6165	 0.002881	 0.02894	 0.7249	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6202	 6166	 7.3e-05	 0.000789	 0.0029	 43571	 43571	 43571	 0.0	 0.0	 1	 -30.0	 30.0;
	6168	 6167	 0.015585	 0.053156	 0.1438	 624	 624	 624	 0.0	 0.0	 1	 -30.0	 30.0;
	6203	 6167	 0.007388	 0.039506	 0.0658	 860	 860	 860	 0.0	 0.0	 1	 -30.0	 30.0;
	5853	 6171	 0.004648	 0.037179	 0.0658	 922	 922	 922	 0.0	 0.0	 1	 -30.0	 30.0;
	6236	 6171	 0.000277	 0.003773	 0.0175	 353.0	 353.0	 353.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5849	 6172	 0.000241	 0.002382	 0.078	 1263.0	 1263.0	 1263.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 6176	 0.001427	 0.014647	 0.3362	 478.0	 478.0	 478.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5855	 6178	 0.000855	 0.010109	 0.2201	 3404	 3404	 3404	 0.0	 0.0	 1	 -30.0	 30.0;
	6179	 6178	 0.001187	 0.012493	 0.2917	 720.0	 720.0	 720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1191	 6180	 0.008751	 0.05361	 0.0972	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6221	 6180	 0.000689	 0.010295	 0.0336	 3347	 3347	 3347	 0.0	 0.0	 1	 -30.0	 30.0;
	6173	 6181	 0.006341	 0.033679	 0.0557	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 6181	 0.005472	 0.030775	 0.0557	 326.0	 326.0	 326.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 6182	 0.007955	 0.045827	 0.0843	 743	 743	 743	 0.0	 0.0	 1	 -30.0	 30.0;
	6016	 6192	 0.000474	 0.005325	 0.1567	 1316.0	 1316.0	 1316.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6016	 6191	 0.000474	 0.005325	 0.1567	 1317.0	 1317.0	 1317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 6199	 4.2e-05	 0.004848	 0.0289	 1013.0	 1013.0	 1013.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 6201	 0.00016	 0.0017	 0.04	 308.0	 308.0	 308.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6135	 6208	 0.00034	 0.004993	 0.1619	 556.0	 556.0	 556.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5848	 6209	 0.001884	 0.010078	 0.0338	 3368	 3368	 3368	 0.0	 0.0	 1	 -30.0	 30.0;
	5847	 6209	 0.001881	 0.01006	 0.0338	 3374	 3374	 3374	 0.0	 0.0	 1	 -30.0	 30.0;
	5852	 6210	 0.000415	 0.003543	 0.2573	 9679	 9679	 9679	 0.0	 0.0	 1	 -30.0	 30.0;
	5851	 6213	 0.000859	 0.009605	 0.2181	 823.0	 823.0	 823.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 6215	 0.002272	 0.033284	 0.1153	 1035	 1035	 1035	 0.0	 0.0	 1	 -30.0	 30.0;
	4942	 6216	 0.000665	 0.008026	 0.1256	 1316.0	 1316.0	 1316.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5859	 6218	 0.00046	 0.00479	 0.1207	 7175	 7175	 7175	 0.0	 0.0	 1	 -30.0	 30.0;
	5858	 6217	 0.00047	 0.00493	 0.1207	 6972	 6972	 6972	 0.0	 0.0	 1	 -30.0	 30.0;
	1955	 6219	 0.002785	 0.018588	 0.0354	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1955	 6219	 0.002785	 0.018607	 0.0354	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	800	 6220	 0.000125	 0.001711	 0.0462	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	323	 6223	 0.002087	 0.022763	 0.6108	 1498	 1498	 1498	 0.0	 0.0	 1	 -30.0	 30.0;
	5860	 6227	 0.000312	 0.002645	 0.1129	 12963	 12963	 12963	 0.0	 0.0	 1	 -30.0	 30.0;
	6243	 6231	 0.000395	 0.198321	 0.001	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	6225	 6237	 0.000855	 0.014271	 0.3697	 648.0	 648.0	 648.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5850	 6238	 0.002815	 0.02159	 0.1187	 324.0	 324.0	 324.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 27	 0.00318	 0.114765	 0.0	 266	 266	 266	 0.976558	 0.0	 1	 -30.0	 30.0;
	26	 27	 0.003062	 0.115753	 0.0	 264	 264	 264	 0.968992	 0.0	 1	 -30.0	 30.0;
	26	 27	 0.00318	 0.117926	 0.0	 259	 259	 259	 0.967118	 0.0	 1	 -30.0	 30.0;
	31	 33	 0.001975	 0.126617	 0.0	 243	 243	 243	 0.989123	 0.0	 1	 -30.0	 30.0;
	31	 34	 0.003635	 0.123062	 0.0	 250	 250	 250	 0.976559	 0.0	 1	 -30.0	 30.0;
	32	 33	 0.003556	 0.120296	 0.0	 265	 265	 265	 0.983284	 0.0	 1	 -30.0	 30.0;
	33	 5889	 0.00018	 -0.006163	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	34	 5913	 0.00018	 -0.006163	 0.0	 1188.0	 1188.0	 1188.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	35	 5889	 0.000291	 0.030817	 0.0	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 5913	 0.000291	 0.030817	 0.0	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	50	 51	 0.00316	 0.125432	 0.0	 246	 246	 246	 1.040584	 0.0	 1	 -30.0	 30.0;
	50	 51	 0.003951	 0.125235	 0.0	 246	 246	 246	 1.026695	 0.0	 1	 -30.0	 30.0;
	50	 51	 0.00316	 0.125432	 0.0	 246	 246	 246	 1.026695	 0.0	 1	 -30.0	 30.0;
	103	 104	 0.003951	 0.110025	 0.0	 281	 281	 281	 0.97561	 0.0	 1	 -30.0	 30.0;
	103	 104	 0.00397	 0.111605	 0.0	 277	 277	 277	 0.973708	 0.0	 1	 -30.0	 30.0;
	109	 110	 0.003556	 0.119309	 0.0	 258	 258	 258	 1.053742	 0.0	 1	 -30.0	 30.0;
	109	 110	 0.00316	 0.125037	 0.0	 246	 246	 246	 1.040584	 0.0	 1	 -30.0	 30.0;
	112	 113	 0.003279	 0.11358	 0.0	 271	 271	 271	 0.98619	 0.0	 1	 -30.0	 30.0;
	112	 113	 0.00324	 0.117531	 0.0	 262	 262	 262	 0.98912	 0.0	 1	 -30.0	 30.0;
	112	 113	 0.003753	 0.112395	 0.0	 273	 273	 273	 0.97561	 0.0	 1	 -30.0	 30.0;
	128	 130	 0.003338	 0.116543	 0.0	 262	 262	 262	 0.987165	 0.0	 1	 -30.0	 30.0;
	129	 130	 0.003595	 0.128593	 0.0	 237	 237	 237	 0.999001	 0.0	 1	 -30.0	 30.0;
	137	 138	 0.002178	 0.149156	 0.0	 203	 203	 203	 0.987165	 0.0	 1	 -30.0	 30.0;
	139	 140	 0.001719	 0.122074	 0.0	 253	 253	 253	 0.98912	 0.0	 1	 -30.0	 30.0;
	140	 141	 0.000332	 0.025	 0.0	 1187.0	 1187.0	 1187.0	 1.001	 0.0	 1	 -30.0	 30.0;
	142	 143	 0.001857	 0.114963	 0.0	 269	 269	 269	 0.999001	 0.0	 1	 -30.0	 30.0;
	142	 143	 0.001936	 0.117926	 0.0	 262	 262	 262	 0.998004	 0.0	 1	 -30.0	 30.0;
	144	 145	 0.003062	 0.112593	 0.0	 285	 285	 285	 0.986197	 0.0	 1	 -30.0	 30.0;
	144	 146	 0.003158	 0.160111	 0.0	 201	 201	 201	 0.982323	 0.0	 1	 -30.0	 30.0;
	144	 146	 0.003144	 0.160319	 0.0	 201	 201	 201	 0.982323	 0.0	 1	 -30.0	 30.0;
	145	 5861	 0.000145	 -0.006302	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	145	 5914	 0.000125	 -0.006787	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	146	 5861	 0.000194	 0.031302	 0.0	 1094	 1094	 1094	 0.0	 0.0	 1	 -30.0	 30.0;
	146	 5914	 0.000215	 0.031995	 0.0	 1070	 1070	 1070	 0.0	 0.0	 1	 -30.0	 30.0;
	156	 152	 0.000252	 0.00252	 0.0003	 11659	 11659	 11659	 1.0	 -1.3	 1	 -30.0	 30.0;
	153	 154	 0.003437	 0.094815	 0.0	 324	 324	 324	 0.98912	 0.0	 1	 -30.0	 30.0;
	157	 159	 0.025195	 0.195515	 0.0	 150	 150	 150	 0.888893	 0.0	 1	 -30.0	 30.0;
	165	 168	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	166	 168	 0.00316	 0.10884	 0.0	 281	 281	 281	 0.974655	 0.0	 1	 -30.0	 30.0;
	166	 168	 0.00316	 0.11358	 0.0	 269	 269	 269	 0.974655	 0.0	 1	 -30.0	 30.0;
	166	 168	 0.00318	 0.113185	 0.0	 270	 270	 270	 0.974655	 0.0	 1	 -30.0	 30.0;
	167	 168	 0.003121	 0.116148	 0.0	 263	 263	 263	 0.985226	 0.0	 1	 -30.0	 30.0;
	171	 172	 0.003951	 0.113185	 0.0	 273	 273	 273	 0.973708	 0.0	 1	 -30.0	 30.0;
	171	 172	 0.003951	 0.113185	 0.0	 273	 273	 273	 0.973708	 0.0	 1	 -30.0	 30.0;
	179	 5890	 0.000909	 -0.006716	 0.0	 444.0	 444.0	 444.0	 0.974656	 0.0	 1	 -30.0	 30.0;
	179	 5915	 0.001304	 -0.006123	 0.0	 444.0	 444.0	 444.0	 0.94697	 0.0	 1	 -30.0	 30.0;
	180	 5890	 0.002252	 0.11358	 0.0	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	180	 5915	 0.002449	 0.127407	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	203	 204	 0.001758	 0.091062	 0.0	 346	 346	 346	 1.006036	 0.0	 1	 -30.0	 30.0;
	203	 204	 0.001758	 0.091062	 0.0	 346	 346	 346	 1.006036	 0.0	 1	 -30.0	 30.0;
	204	 205	 0.000665	 0.048338	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	204	 205	 0.000783	 0.039612	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	210	 212	 0.000277	 0.009481	 0.001	 446.0	 446.0	 446.0	 0.957854	 0.0	 1	 -30.0	 30.0;
	211	 213	 0.000277	 0.009481	 0.001	 446.0	 446.0	 446.0	 0.957854	 0.0	 1	 -30.0	 30.0;
	211	 213	 0.000277	 0.009481	 0.0	 446.0	 446.0	 446.0	 0.957854	 0.0	 1	 -30.0	 30.0;
	214	 215	 0.00324	 0.117728	 0.0	 262	 262	 262	 0.997009	 0.0	 1	 -30.0	 30.0;
	214	 215	 0.003101	 0.118321	 0.0	 261	 261	 261	 0.997009	 0.0	 1	 -30.0	 30.0;
	214	 215	 0.00324	 0.117728	 0.0	 262	 262	 262	 0.973708	 0.0	 1	 -30.0	 30.0;
	221	 222	 0.004741	 0.156049	 0.0	 199	 199	 199	 0.946073	 0.0	 1	 -30.0	 30.0;
	233	 234	 0.015309	 0.465432	 0.0	 74	 74	 74	 1.0	 0.0	 1	 -30.0	 30.0;
	246	 247	 0.004543	 0.160988	 0.0	 191	 191	 191	 0.967124	 0.0	 1	 -30.0	 30.0;
	256	 257	 0.003378	 0.105679	 0.0	 292	 292	 292	 0.968054	 0.0	 1	 -30.0	 30.0;
	259	 260	 0.014262	 0.231111	 0.0	 134	 134	 134	 0.978474	 0.0	 1	 -30.0	 30.0;
	259	 260	 0.012504	 0.325926	 0.0	 95	 95	 95	 1.005025	 0.0	 1	 -30.0	 30.0;
	262	 264	 0.000346	 0.025139	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	262	 264	 0.000339	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	263	 264	 0.000339	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	272	 273	 0.003437	 0.122469	 0.0	 249	 249	 249	 1.011122	 0.0	 1	 -30.0	 30.0;
	272	 273	 0.003733	 0.122667	 0.0	 249	 249	 249	 0.990101	 0.0	 1	 -30.0	 30.0;
	275	 276	 0.000803	 0.042452	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	277	 278	 0.003062	 0.116148	 0.0	 263	 263	 263	 0.973708	 0.0	 1	 -30.0	 30.0;
	277	 278	 0.003279	 0.110222	 0.0	 277	 277	 277	 0.972763	 0.0	 1	 -30.0	 30.0;
	313	 314	 0.003872	 0.123852	 0.0	 249	 249	 249	 0.98619	 0.0	 1	 -30.0	 30.0;
	313	 314	 0.003872	 0.123852	 0.0	 249	 249	 249	 0.956938	 0.0	 1	 -30.0	 30.0;
	321	 323	 0.002916	 0.161475	 0.0	 196	 196	 196	 1.033058	 0.0	 1	 -30.0	 30.0;
	321	 323	 0.001801	 0.100416	 0.0	 316	 316	 316	 1.003009	 0.0	 1	 -30.0	 30.0;
	321	 323	 0.002825	 0.153927	 0.0	 206	 206	 206	 1.034126	 0.0	 1	 -30.0	 30.0;
	322	 323	 0.000734	 0.045014	 0.0	 593.0	 593.0	 593.0	 0.956938	 0.0	 1	 -30.0	 30.0;
	322	 323	 0.000727	 0.044668	 0.0	 593.0	 593.0	 593.0	 0.956938	 0.0	 1	 -30.0	 30.0;
	326	 327	 0.003931	 0.12484	 0.0	 247	 247	 247	 1.037344	 0.0	 1	 -30.0	 30.0;
	326	 327	 0.004662	 0.160988	 0.0	 192	 192	 192	 1.012146	 0.0	 1	 -30.0	 30.0;
	330	 331	 0.003516	 0.12563	 0.0	 246	 246	 246	 1.0	 0.0	 1	 -30.0	 30.0;
	330	 331	 0.003536	 0.126617	 0.0	 244	 244	 244	 1.0	 0.0	 1	 -30.0	 30.0;
	342	 343	 0.003081	 0.118123	 0.0	 261	 261	 261	 1.012146	 0.0	 1	 -30.0	 30.0;
	360	 361	 0.016	 0.324444	 0.0	 97	 97	 97	 0.984252	 0.0	 1	 -30.0	 30.0;
	360	 361	 0.013333	 0.328889	 0.0	 96	 96	 96	 0.971817	 0.0	 1	 -30.0	 30.0;
	360	 361	 0.016889	 0.398222	 0.0	 79	 79	 79	 0.984252	 0.0	 1	 -30.0	 30.0;
	360	 362	 0.003852	 0.123457	 0.0	 250	 250	 250	 0.968054	 0.0	 1	 -30.0	 30.0;
	378	 379	 0.003951	 0.123457	 0.0	 249	 249	 249	 1.001002	 0.0	 1	 -30.0	 30.0;
	378	 379	 0.003753	 0.12563	 0.0	 245	 245	 245	 1.001002	 0.0	 1	 -30.0	 30.0;
	379	 380	 0.000803	 0.03892	 0.0	 600.0	 600.0	 600.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	379	 380	 0.000845	 0.03982	 0.0	 598.0	 598.0	 598.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	379	 5916	 0.000374	 -0.009003	 0.0	 600.0	 600.0	 600.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	380	 5916	 0.000471	 0.048892	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	422	 423	 0.003062	 0.117136	 0.0	 264	 264	 264	 0.968054	 0.0	 1	 -30.0	 30.0;
	422	 423	 0.003615	 0.114568	 0.0	 270	 270	 270	 0.968054	 0.0	 1	 -30.0	 30.0;
	424	 425	 0.003911	 0.111012	 0.0	 278	 278	 278	 0.953289	 0.0	 1	 -30.0	 30.0;
	424	 425	 0.003911	 0.111012	 0.0	 278	 278	 278	 0.987167	 0.0	 1	 -30.0	 30.0;
	424	 425	 0.003911	 0.111012	 0.0	 278	 278	 278	 0.986189	 0.0	 1	 -30.0	 30.0;
	445	 446	 0.00318	 0.117728	 0.0	 272	 272	 272	 1.089325	 0.0	 1	 -30.0	 30.0;
	443	 446	 0.003062	 0.115753	 0.0	 277	 277	 277	 1.075269	 0.0	 1	 -30.0	 30.0;
	444	 446	 0.002983	 0.118716	 0.0	 270	 270	 270	 1.075269	 0.0	 1	 -30.0	 30.0;
	448	 449	 0.004365	 0.168296	 0.0	 185	 185	 185	 0.956938	 0.0	 1	 -30.0	 30.0;
	448	 449	 0.004464	 0.169284	 0.0	 184	 184	 184	 0.937207	 0.0	 1	 -30.0	 30.0;
	449	 450	 0.000893	 0.043767	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	449	 450	 0.000693	 0.048615	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	452	 453	 0.001936	 0.116148	 0.0	 263	 263	 263	 0.97466	 0.0	 1	 -30.0	 30.0;
	452	 453	 0.001936	 0.117728	 0.0	 259	 259	 259	 0.97466	 0.0	 1	 -30.0	 30.0;
	457	 458	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.910747	 0.0	 1	 -30.0	 30.0;
	458	 5862	 0.000249	 -0.004501	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	458	 5891	 0.000152	 -0.00644	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	459	 5862	 6.9e-05	 0.029294	 0.0	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	459	 5891	 0.00018	 0.03151	 0.0	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	464	 465	 0.011111	 0.384074	 0.0	 93	 93	 93	 1.103753	 0.0	 1	 -30.0	 30.0;
	478	 479	 0.013354	 0.299824	 0.0	 98	 98	 98	 1.02564	 0.0	 1	 -30.0	 30.0;
	480	 481	 0.003951	 0.124444	 0.0	 247	 247	 247	 1.0142	 0.0	 1	 -30.0	 30.0;
	480	 481	 0.003753	 0.124642	 0.0	 247	 247	 247	 1.0142	 0.0	 1	 -30.0	 30.0;
	480	 481	 0.002568	 0.164346	 0.0	 187	 187	 187	 0.991081	 0.0	 1	 -30.0	 30.0;
	504	 505	 0.00397	 0.120296	 0.0	 266	 266	 266	 0.997009	 0.0	 1	 -30.0	 30.0;
	504	 505	 0.0032	 0.117333	 0.0	 273	 273	 273	 0.997009	 0.0	 1	 -30.0	 30.0;
	512	 513	 0.003527	 0.103804	 0.0	 284	 284	 284	 0.933707	 0.0	 1	 -30.0	 30.0;
	521	 523	 0.003951	 0.118519	 0.0	 260	 260	 260	 1.0142	 0.0	 1	 -30.0	 30.0;
	522	 523	 0.003358	 0.118519	 0.0	 260	 260	 260	 1.001002	 0.0	 1	 -30.0	 30.0;
	523	 524	 0.000319	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	523	 524	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	526	 527	 0.001679	 0.122272	 0.0	 250	 250	 250	 0.964324	 0.0	 1	 -30.0	 30.0;
	526	 527	 0.00316	 0.117333	 0.0	 260	 260	 260	 0.975606	 0.0	 1	 -30.0	 30.0;
	526	 527	 0.001679	 0.122272	 0.0	 250	 250	 250	 0.975606	 0.0	 1	 -30.0	 30.0;
	535	 536	 0.003042	 0.116148	 0.0	 263	 263	 263	 0.997009	 0.0	 1	 -30.0	 30.0;
	535	 536	 0.00316	 0.11437	 0.0	 267	 267	 267	 0.992064	 0.0	 1	 -30.0	 30.0;
	535	 536	 0.003101	 0.118321	 0.0	 258	 258	 258	 0.997009	 0.0	 1	 -30.0	 30.0;
	544	 545	 0.003516	 0.122469	 0.0	 252	 252	 252	 0.962466	 0.0	 1	 -30.0	 30.0;
	550	 551	 0.012963	 0.267901	 0.0	 114	 114	 114	 1.002005	 0.0	 1	 -30.0	 30.0;
	563	 564	 0.004899	 0.162173	 0.0	 188	 188	 188	 0.968054	 0.0	 1	 -30.0	 30.0;
	581	 579	 2e-05	 0.004741	 0.004	 935.0	 935.0	 935.0	 1.0	 4.66	 1	 -30.0	 30.0;
	581	 582	 0.000319	 0.024307	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	581	 582	 0.000319	 0.024307	 0.0	 1188.0	 1188.0	 1188.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	594	 595	 0.000886	 0.043837	 0.0	 632.0	 632.0	 632.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	602	 603	 0.003081	 0.125432	 0.0	 246	 246	 246	 0.974664	 0.0	 1	 -30.0	 30.0;
	602	 603	 0.003121	 0.125037	 0.0	 247	 247	 247	 0.974664	 0.0	 1	 -30.0	 30.0;
	607	 608	 0.004346	 0.164938	 0.0	 185	 185	 185	 0.968054	 0.0	 1	 -30.0	 30.0;
	607	 608	 0.004543	 0.162568	 0.0	 188	 188	 188	 0.968054	 0.0	 1	 -30.0	 30.0;
	610	 611	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	616	 5892	 0.000519	 -0.007825	 0.0	 606.0	 606.0	 606.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	617	 5892	 0.000277	 0.047507	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	627	 628	 0.003733	 0.175822	 0.0	 173	 173	 173	 0.938971	 0.0	 1	 -30.0	 30.0;
	653	 654	 0.00162	 0.122272	 0.0	 253	 253	 253	 1.0	 0.0	 1	 -30.0	 30.0;
	653	 654	 0.001798	 0.119506	 0.0	 258	 258	 258	 1.0	 0.0	 1	 -30.0	 30.0;
	668	 669	 0.004346	 0.169877	 0.0	 184	 184	 184	 0.968054	 0.0	 1	 -30.0	 30.0;
	677	 678	 0.001393	 0.097699	 0.0	 313	 313	 313	 1.009082	 0.0	 1	 -30.0	 30.0;
	695	 696	 0.00316	 0.112	 0.0	 281	 281	 281	 1.002004	 0.0	 1	 -30.0	 30.0;
	695	 696	 0.003931	 0.115951	 0.0	 272	 272	 272	 1.002004	 0.0	 1	 -30.0	 30.0;
	697	 700	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	698	 700	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	699	 701	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	702	 704	 0.003022	 0.115951	 0.0	 264	 264	 264	 0.984254	 0.0	 1	 -30.0	 30.0;
	702	 704	 0.003536	 0.121877	 0.0	 251	 251	 251	 0.984254	 0.0	 1	 -30.0	 30.0;
	709	 712	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	708	 712	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	707	 712	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	711	 712	 0.0032	 0.113185	 0.0	 270	 270	 270	 0.970872	 0.0	 1	 -30.0	 30.0;
	710	 712	 0.0032	 0.113185	 0.0	 270	 270	 270	 0.957856	 0.0	 1	 -30.0	 30.0;
	710	 712	 0.003062	 0.116148	 0.0	 263	 263	 263	 0.950573	 0.0	 1	 -30.0	 30.0;
	725	 727	 0.003062	 0.116741	 0.0	 268	 268	 268	 1.0	 0.0	 1	 -30.0	 30.0;
	726	 727	 0.00318	 0.115753	 0.0	 270	 270	 270	 1.0142	 0.0	 1	 -30.0	 30.0;
	725	 727	 0.003062	 0.117728	 0.0	 266	 266	 266	 1.0	 0.0	 1	 -30.0	 30.0;
	742	 743	 0.003358	 0.122469	 0.0	 252	 252	 252	 0.97561	 0.0	 1	 -30.0	 30.0;
	742	 743	 0.003358	 0.122469	 0.0	 252	 252	 252	 0.97371	 0.0	 1	 -30.0	 30.0;
	754	 5863	 0.000249	 -0.004501	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	754	 5893	 0.000152	 -0.00644	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	755	 5863	 6.9e-05	 0.029294	 0.0	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	755	 5893	 0.00018	 0.03151	 0.0	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	762	 763	 0.068027	 0.942303	 0.0	 37	 37	 37	 0.550361	 0.0	 1	 -30.0	 30.0;
	768	 769	 0.003733	 0.120296	 0.0	 254	 254	 254	 0.984254	 0.0	 1	 -30.0	 30.0;
	768	 769	 0.003081	 0.116938	 0.0	 261	 261	 261	 0.972767	 0.0	 1	 -30.0	 30.0;
	768	 769	 0.003615	 0.123654	 0.0	 247	 247	 247	 0.984254	 0.0	 1	 -30.0	 30.0;
	770	 773	 0.012346	 0.453263	 0.0	 77	 77	 77	 1.001	 0.0	 1	 -30.0	 30.0;
	771	 773	 0.012346	 0.456286	 0.0	 76	 76	 76	 1.001	 0.0	 1	 -30.0	 30.0;
	772	 773	 0.012598	 0.456034	 0.0	 76	 76	 76	 1.001	 0.0	 1	 -30.0	 30.0;
	776	 777	 0.003635	 0.119704	 0.0	 258	 258	 258	 0.97561	 0.0	 1	 -30.0	 30.0;
	787	 788	 0.03225	 0.602419	 0.0	 58	 58	 58	 1.001	 0.0	 1	 -30.0	 30.0;
	786	 789	 0.03225	 0.602419	 0.0	 58	 58	 58	 1.001	 0.0	 1	 -30.0	 30.0;
	788	 790	 0.001975	 0.124444	 0.0	 247	 247	 247	 1.001002	 0.0	 1	 -30.0	 30.0;
	789	 790	 0.00316	 0.125037	 0.001	 246	 246	 246	 1.001002	 0.0	 1	 -30.0	 30.0;
	799	 800	 0.002832	 0.155817	 0.0	 203	 203	 203	 0.971818	 0.0	 1	 -30.0	 30.0;
	803	 805	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	802	 805	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	801	 804	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	827	 828	 0.000312	 0.024979	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	849	 850	 0.003062	 0.117136	 0.0	 265	 265	 265	 0.98912	 0.0	 1	 -30.0	 30.0;
	849	 850	 0.003615	 0.114568	 0.0	 271	 271	 271	 0.98912	 0.0	 1	 -30.0	 30.0;
	849	 850	 0.004563	 0.161975	 0.0	 192	 192	 192	 0.978474	 0.0	 1	 -30.0	 30.0;
	850	 851	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	850	 851	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	852	 853	 0.003378	 0.122864	 0.0	 255	 255	 255	 0.987167	 0.0	 1	 -30.0	 30.0;
	852	 853	 0.003338	 0.122667	 0.0	 255	 255	 255	 1.012146	 0.0	 1	 -30.0	 30.0;
	853	 854	 6.9e-05	 0.056094	 0.0	 566	 566	 566	 1.0	 0.0	 1	 -30.0	 30.0;
	879	 881	 0.003121	 0.12484	 0.0	 247	 247	 247	 1.037344	 0.0	 1	 -30.0	 30.0;
	880	 881	 0.003081	 0.125412	 0.0	 245	 245	 245	 1.02459	 0.0	 1	 -30.0	 30.0;
	879	 881	 0.003575	 0.126222	 0.0	 244	 244	 244	 1.064963	 0.0	 1	 -30.0	 30.0;
	889	 890	 0.006133	 0.237422	 0.0	 145	 145	 145	 0.938967	 0.0	 1	 -30.0	 30.0;
	915	 5864	 0.000499	 -0.008379	 0.0	 606.0	 606.0	 606.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	914	 5894	 0.000325	 -0.008726	 0.0	 557.0	 557.0	 557.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	916	 5864	 0.000298	 0.048407	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	916	 5894	 0.000381	 0.047715	 0.0	 557.0	 557.0	 557.0	 0.0	 0.0	 1	 -30.0	 30.0;
	923	 924	 0.001814	 0.099308	 0.0	 320	 320	 320	 0.956942	 0.0	 1	 -30.0	 30.0;
	923	 924	 0.001814	 0.099308	 0.0	 320	 320	 320	 0.973709	 0.0	 1	 -30.0	 30.0;
	932	 5865	 0.000166	 -0.005062	 0.0	 1168.0	 1168.0	 1168.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	933	 5917	 0.000166	 -0.010873	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	933	 5931	 0.000152	 -0.007756	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	932	 5941	 0.000118	 -0.007618	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	934	 5865	 0.000201	 0.026437	 0.0	 1168.0	 1168.0	 1168.0	 0.0	 0.0	 1	 -30.0	 30.0;
	935	 5917	 0.000166	 0.038296	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	934	 5931	 0.000187	 0.03518	 0.0	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	935	 5941	 0.00018	 0.034695	 0.0	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	937	 938	 0.00397	 0.11121	 0.0	 281	 281	 281	 1.037344	 0.0	 1	 -30.0	 30.0;
	937	 938	 0.003773	 0.123457	 0.0	 253	 253	 253	 1.051525	 0.0	 1	 -30.0	 30.0;
	937	 938	 0.003279	 0.118914	 0.0	 263	 263	 263	 1.037344	 0.0	 1	 -30.0	 30.0;
	948	 949	 0.003556	 0.111605	 0.0	 274	 274	 274	 0.98619	 0.0	 1	 -30.0	 30.0;
	948	 949	 0.003378	 0.121481	 0.0	 251	 251	 251	 0.977522	 0.0	 1	 -30.0	 30.0;
	953	 954	 0.001801	 0.09903	 0.0	 320	 320	 320	 0.991081	 0.0	 1	 -30.0	 30.0;
	953	 954	 0.001801	 0.099723	 0.0	 318	 318	 318	 0.991081	 0.0	 1	 -30.0	 30.0;
	960	 961	 0.001778	 0.091062	 0.0	 335	 335	 335	 0.994038	 0.0	 1	 -30.0	 30.0;
	960	 961	 0.001738	 0.092444	 0.0	 330	 330	 330	 0.994038	 0.0	 1	 -30.0	 30.0;
	960	 961	 0.001758	 0.092049	 0.0	 332	 332	 332	 0.994038	 0.0	 1	 -30.0	 30.0;
	961	 963	 0.000325	 0.026801	 0.0	 1177	 1177	 1177	 1.0	 0.0	 1	 -30.0	 30.0;
	961	 962	 0.000319	 0.026593	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	965	 966	 0.007664	 0.250785	 0.0	 137	 137	 137	 1.0	 0.0	 1	 -30.0	 30.0;
	965	 966	 0.007664	 0.250785	 0.0	 137	 137	 137	 1.0	 0.0	 1	 -30.0	 30.0;
	965	 966	 0.007664	 0.250785	 0.0	 137	 137	 137	 1.0	 0.0	 1	 -30.0	 30.0;
	968	 969	 0.001936	 0.117926	 0.0	 262	 262	 262	 1.009082	 0.0	 1	 -30.0	 30.0;
	968	 969	 0.001995	 0.118716	 0.0	 260	 260	 260	 1.009082	 0.0	 1	 -30.0	 30.0;
	974	 975	 0.001849	 0.101524	 0.0	 310	 310	 310	 0.974656	 0.0	 1	 -30.0	 30.0;
	974	 975	 0.001794	 0.100831	 0.0	 313	 313	 313	 0.974656	 0.0	 1	 -30.0	 30.0;
	976	 977	 0.001837	 0.140247	 0.0	 220	 220	 220	 0.998004	 0.0	 1	 -30.0	 30.0;
	988	 990	 0.003378	 0.105481	 0.0	 291	 291	 291	 0.94697	 0.0	 1	 -30.0	 30.0;
	988	 990	 0.003338	 0.113185	 0.0	 272	 272	 272	 0.952382	 0.0	 1	 -30.0	 30.0;
	996	 997	 0.001778	 0.119309	 0.0	 258	 258	 258	 0.95329	 0.0	 1	 -30.0	 30.0;
	995	 5866	 0.004224	 0.148199	 0.0	 233	 233	 233	 1.0	 0.0	 1	 -30.0	 30.0;
	996	 998	 0.001801	 0.101108	 0.0	 313	 313	 313	 0.981355	 0.0	 1	 -30.0	 30.0;
	996	 998	 0.001399	 0.101177	 0.0	 313	 313	 313	 0.971818	 0.0	 1	 -30.0	 30.0;
	997	 5866	 0.000388	 -0.009003	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	997	 5895	 0.00063	 -0.005194	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	998	 5866	 0.000395	 0.049169	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	998	 5895	 3.5e-05	 0.048476	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1011	 1012	 0.003556	 0.114568	 0.0	 269	 269	 269	 1.0142	 0.0	 1	 -30.0	 30.0;
	1011	 1012	 0.003951	 0.124444	 0.0	 247	 247	 247	 1.0142	 0.0	 1	 -30.0	 30.0;
	1026	 1028	 0.003101	 0.124049	 0.0	 253	 253	 253	 1.023541	 0.0	 1	 -30.0	 30.0;
	1033	 1034	 0.001699	 0.122864	 0.0	 250	 250	 250	 0.953285	 0.0	 1	 -30.0	 30.0;
	1033	 1034	 0.001699	 0.122469	 0.0	 251	 251	 251	 1.009082	 0.0	 1	 -30.0	 30.0;
	1034	 1035	 0.000325	 0.027147	 0.0	 1168	 1168	 1168	 0.999001	 0.0	 1	 -30.0	 30.0;
	1034	 1035	 0.000319	 0.027216	 0.0	 1165	 1165	 1165	 0.999001	 0.0	 1	 -30.0	 30.0;
	1034	 5918	 0.000229	 -0.008102	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1037	 5918	 8.3e-05	 0.035734	 0.0	 959	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	1041	 1042	 0.00125	 0.11844	 0.0	 258	 258	 258	 0.975614	 0.0	 1	 -30.0	 30.0;
	1041	 1042	 0.001294	 0.118222	 0.0	 258	 258	 258	 0.994036	 0.0	 1	 -30.0	 30.0;
	1040	 1042	 0.003911	 0.110815	 0.0	 275	 275	 275	 0.987167	 0.0	 1	 -30.0	 30.0;
	1058	 1059	 0.003101	 0.117531	 0.0	 260	 260	 260	 0.985226	 0.0	 1	 -30.0	 30.0;
	1058	 1059	 0.00322	 0.11358	 0.0	 269	 269	 269	 0.974655	 0.0	 1	 -30.0	 30.0;
	1058	 1059	 0.003081	 0.115753	 0.0	 264	 264	 264	 0.992063	 0.0	 1	 -30.0	 30.0;
	1058	 1059	 0.003101	 0.115556	 0.0	 264	 264	 264	 0.983282	 0.0	 1	 -30.0	 30.0;
	1063	 1064	 0.007704	 0.229136	 0.0	 135	 135	 135	 1.001002	 0.0	 1	 -30.0	 30.0;
	1063	 1064	 0.007388	 0.234074	 0.0	 132	 132	 132	 0.989123	 0.0	 1	 -30.0	 30.0;
	1063	 1064	 0.007486	 0.229136	 0.0	 135	 135	 135	 0.976559	 0.0	 1	 -30.0	 30.0;
	1071	 1072	 0.000339	 0.027285	 0.0	 1162	 1162	 1162	 1.0	 0.0	 1	 -30.0	 30.0;
	1071	 1072	 0.000339	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	1071	 5919	 0.000132	 -0.007479	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1072	 5919	 0.000173	 0.034764	 0.0	 985	 985	 985	 0.0	 0.0	 1	 -30.0	 30.0;
	1073	 1074	 0.003773	 0.119506	 0.0	 259	 259	 259	 0.956938	 0.0	 1	 -30.0	 30.0;
	1073	 1074	 0.003516	 0.125037	 0.0	 248	 248	 248	 0.94697	 0.0	 1	 -30.0	 30.0;
	1087	 1088	 0.00316	 0.112988	 0.0	 273	 273	 273	 0.983282	 0.0	 1	 -30.0	 30.0;
	1108	 1109	 0.014568	 0.185185	 0.0	 186	 186	 186	 1.0	 0.0	 1	 -30.0	 30.0;
	1111	 1112	 0.001798	 0.118716	 0.0	 260	 260	 260	 1.0	 0.0	 1	 -30.0	 30.0;
	1111	 1112	 0.001798	 0.118716	 0.0	 260	 260	 260	 1.048218	 0.0	 1	 -30.0	 30.0;
	1130	 1131	 0.003951	 0.113383	 0.0	 269	 269	 269	 0.973708	 0.0	 1	 -30.0	 30.0;
	1130	 1131	 0.003062	 0.118321	 0.0	 258	 258	 258	 0.962466	 0.0	 1	 -30.0	 30.0;
	1136	 1138	 0.004286	 0.164741	 0.0	 187	 187	 187	 0.978474	 0.0	 1	 -30.0	 30.0;
	1137	 1138	 0.005077	 0.17284	 0.0	 178	 178	 178	 0.978474	 0.0	 1	 -30.0	 30.0;
	1141	 1142	 0.003595	 0.120889	 0.0	 253	 253	 253	 0.97561	 0.0	 1	 -30.0	 30.0;
	1141	 1142	 0.003121	 0.130963	 0.0	 233	 233	 233	 0.97561	 0.0	 1	 -30.0	 30.0;
	1145	 1146	 0.002469	 0.533333	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	1152	 1153	 0.00316	 0.125037	 0.0	 246	 246	 246	 0.989123	 0.0	 1	 -30.0	 30.0;
	1152	 1153	 0.004741	 0.161185	 0.0	 191	 191	 191	 0.990101	 0.0	 1	 -30.0	 30.0;
	1151	 1153	 0.004938	 0.16237	 0.0	 190	 190	 190	 0.990101	 0.0	 1	 -30.0	 30.0;
	1159	 1162	 0.00162	 0.099279	 0.0	 311	 311	 311	 0.980391	 0.0	 1	 -30.0	 30.0;
	1160	 1162	 0.001679	 0.099457	 0.0	 310	 310	 310	 0.992067	 0.0	 1	 -30.0	 30.0;
	1161	 1162	 0.001659	 0.099496	 0.0	 310	 310	 310	 0.98619	 0.0	 1	 -30.0	 30.0;
	1169	 1170	 0.001778	 0.092385	 0.0	 331	 331	 331	 0.973708	 0.0	 1	 -30.0	 30.0;
	1169	 1170	 0.001817	 0.091654	 0.0	 333	 333	 333	 0.982323	 0.0	 1	 -30.0	 30.0;
	1169	 1170	 0.001798	 0.091457	 0.0	 334	 334	 334	 0.982323	 0.0	 1	 -30.0	 30.0;
	1169	 1170	 0.001817	 0.091654	 0.0	 333	 333	 333	 0.982323	 0.0	 1	 -30.0	 30.0;
	1190	 1191	 0.003556	 0.123654	 0.0	 249	 249	 249	 0.965249	 0.0	 1	 -30.0	 30.0;
	1189	 1191	 0.003753	 0.120494	 0.0	 255	 255	 255	 0.976559	 0.0	 1	 -30.0	 30.0;
	1190	 1192	 0.00316	 0.12563	 0.0	 245	 245	 245	 0.965249	 0.0	 1	 -30.0	 30.0;
	1191	 1193	 0.000325	 0.025139	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1192	 1193	 0.000325	 0.025346	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1194	 1195	 0.000332	 0.027078	 0.0	 1165	 1165	 1165	 1.0	 0.0	 1	 -30.0	 30.0;
	1194	 1195	 0.000325	 0.027355	 0.0	 1153	 1153	 1153	 0.999001	 0.0	 1	 -30.0	 30.0;
	1194	 1195	 0.000817	 0.042313	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1194	 1195	 0.000686	 0.043075	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1197	 1198	 0.001896	 0.120296	 0.0	 256	 256	 256	 0.974661	 0.0	 1	 -30.0	 30.0;
	1197	 1198	 0.002153	 0.116543	 0.0	 264	 264	 264	 0.986189	 0.0	 1	 -30.0	 30.0;
	1203	 1204	 0.00324	 0.116543	 0.0	 265	 265	 265	 0.956938	 0.0	 1	 -30.0	 30.0;
	1203	 1204	 0.001679	 0.122667	 0.0	 252	 252	 252	 0.986189	 0.0	 1	 -30.0	 30.0;
	1206	 1207	 0.003417	 0.126222	 0.0	 242	 242	 242	 0.987167	 0.0	 1	 -30.0	 30.0;
	1206	 1207	 0.003812	 0.111605	 0.0	 274	 274	 274	 0.987167	 0.0	 1	 -30.0	 30.0;
	1206	 1207	 0.002035	 0.111605	 0.0	 274	 274	 274	 0.987167	 0.0	 1	 -30.0	 30.0;
	1224	 1225	 0.003575	 0.123062	 0.0	 248	 248	 248	 0.951472	 0.0	 1	 -30.0	 30.0;
	1232	 1231	 0.000494	 0.005222	 0.0	 6589	 6589	 6589	 1.0	 0.0	 1	 -30.0	 30.0;
	1234	 1236	 0.003753	 0.122864	 0.0	 250	 250	 250	 0.965249	 0.0	 1	 -30.0	 30.0;
	1233	 1236	 0.003556	 0.127802	 0.0	 241	 241	 241	 0.95329	 0.0	 1	 -30.0	 30.0;
	1234	 1237	 0.003951	 0.125235	 0.0	 246	 246	 246	 0.965249	 0.0	 1	 -30.0	 30.0;
	1237	 1238	 0.000319	 0.024723	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1236	 1238	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1239	 1240	 0.004523	 0.16	 0.0	 193	 193	 193	 0.956938	 0.0	 1	 -30.0	 30.0;
	1242	 1243	 0.004622	 0.159012	 0.0	 194	 194	 194	 1.012146	 0.0	 1	 -30.0	 30.0;
	1242	 1243	 0.004622	 0.16	 0.0	 193	 193	 193	 1.001002	 0.0	 1	 -30.0	 30.0;
	1242	 1243	 0.004286	 0.165333	 0.0	 187	 187	 187	 1.023541	 0.0	 1	 -30.0	 30.0;
	1244	 1245	 0.009956	 0.365333	 0.0	 86	 86	 86	 1.059322	 0.0	 1	 -30.0	 30.0;
	1244	 1245	 0.016578	 0.457778	 0.0	 69	 69	 69	 1.037345	 0.0	 1	 -30.0	 30.0;
	1246	 1247	 0.068027	 0.942303	 0.0	 37	 37	 37	 0.550361	 0.0	 1	 -30.0	 30.0;
	1253	 1254	 0.003575	 0.121481	 0.0	 264	 264	 264	 1.009082	 0.0	 1	 -30.0	 30.0;
	1253	 1254	 0.003081	 0.115951	 0.0	 276	 276	 276	 1.009082	 0.0	 1	 -30.0	 30.0;
	1258	 1260	 0.003279	 0.117926	 0.0	 262	 262	 262	 1.0	 0.0	 1	 -30.0	 30.0;
	1259	 1260	 0.00324	 0.116543	 0.0	 265	 265	 265	 1.0	 0.0	 1	 -30.0	 30.0;
	1258	 1260	 0.003042	 0.116938	 0.0	 264	 264	 264	 1.0	 0.0	 1	 -30.0	 30.0;
	5942	 1260	 0.000402	 -0.007341	 0.0	 581.0	 581.0	 581.0	 1.049318	 0.0	 1	 -30.0	 30.0;
	1260	 1261	 0.000263	 0.025277	 0.0	 585.0	 585.0	 585.0	 0.959693	 0.0	 1	 -30.0	 30.0;
	1260	 1261	 0.000319	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1261	 5942	 0.000242	 0.03144	 0.0	 581.0	 581.0	 581.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1303	 1305	 0.070799	 1.73847	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	1304	 1305	 0.075586	 1.51172	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	1320	 1321	 0.003437	 0.122469	 0.0	 249	 249	 249	 0.999001	 0.0	 1	 -30.0	 30.0;
	1320	 1321	 0.004286	 0.162765	 0.0	 188	 188	 188	 1.0	 0.0	 1	 -30.0	 30.0;
	1327	 1328	 0.004642	 0.163556	 0.0	 189	 189	 189	 0.96712	 0.0	 1	 -30.0	 30.0;
	1327	 1328	 0.004642	 0.163556	 0.0	 189	 189	 189	 0.980392	 0.0	 1	 -30.0	 30.0;
	1328	 1329	 0.000332	 0.024654	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1328	 1329	 0.000312	 0.024654	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1330	 1331	 0.012598	 0.307382	 0.0	 96	 96	 96	 0.951479	 0.0	 1	 -30.0	 30.0;
	1338	 1339	 0.002094	 0.115753	 0.0	 268	 268	 268	 0.96432	 0.0	 1	 -30.0	 30.0;
	1340	 1341	 0.003951	 0.124642	 0.0	 247	 247	 247	 0.965249	 0.0	 1	 -30.0	 30.0;
	1340	 1341	 0.001975	 0.108642	 0.0	 283	 283	 283	 0.967124	 0.0	 1	 -30.0	 30.0;
	1344	 1345	 0.006133	 0.237422	 0.0	 145	 145	 145	 0.938967	 0.0	 1	 -30.0	 30.0;
	1352	 1353	 0.001758	 0.090469	 0.0	 338	 338	 338	 1.006036	 0.0	 1	 -30.0	 30.0;
	1352	 1353	 0.001936	 0.092049	 0.0	 332	 332	 332	 0.995025	 0.0	 1	 -30.0	 30.0;
	1352	 1353	 0.001857	 0.092444	 0.0	 330	 330	 330	 1.006036	 0.0	 1	 -30.0	 30.0;
	1354	 1355	 0.004346	 0.169481	 0.0	 182	 182	 182	 1.012146	 0.0	 1	 -30.0	 30.0;
	1354	 1355	 0.004247	 0.169086	 0.0	 183	 183	 183	 1.012146	 0.0	 1	 -30.0	 30.0;
	1354	 1355	 0.004267	 0.169679	 0.0	 182	 182	 182	 1.012146	 0.0	 1	 -30.0	 30.0;
	1375	 1376	 0.003496	 0.111407	 0.0	 288	 288	 288	 1.009082	 0.0	 1	 -30.0	 30.0;
	1381	 1382	 0.001699	 0.122469	 0.0	 251	 251	 251	 1.046025	 0.0	 1	 -30.0	 30.0;
	1381	 1382	 0.001956	 0.117531	 0.0	 262	 262	 262	 0.998004	 0.0	 1	 -30.0	 30.0;
	1381	 1382	 0.003101	 0.125235	 0.0	 246	 246	 246	 1.010101	 0.0	 1	 -30.0	 30.0;
	1402	 1403	 0.003062	 0.125432	 0.0	 245	 245	 245	 0.978473	 0.0	 1	 -30.0	 30.0;
	1404	 1406	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	1405	 1406	 0.002588	 0.115358	 0.0	 265	 265	 265	 0.996016	 0.0	 1	 -30.0	 30.0;
	1405	 1406	 0.003081	 0.115358	 0.0	 265	 265	 265	 0.972767	 0.0	 1	 -30.0	 30.0;
	1429	 1430	 0.003081	 0.117531	 0.0	 263	 263	 263	 0.953289	 0.0	 1	 -30.0	 30.0;
	1429	 1430	 0.003911	 0.111605	 0.0	 277	 277	 277	 0.96432	 0.0	 1	 -30.0	 30.0;
	1436	 1437	 0.001679	 0.122667	 0.0	 252	 252	 252	 0.998004	 0.0	 1	 -30.0	 30.0;
	1436	 1437	 0.001995	 0.118716	 0.0	 260	 260	 260	 0.998004	 0.0	 1	 -30.0	 30.0;
	1440	 1441	 0.003852	 0.12642	 0.0	 242	 242	 242	 0.987165	 0.0	 1	 -30.0	 30.0;
	1439	 1441	 0.003812	 0.12484	 0.0	 245	 245	 245	 0.987165	 0.0	 1	 -30.0	 30.0;
	1451	 1452	 0.003812	 0.146963	 0.0	 210	 210	 210	 0.964324	 0.0	 1	 -30.0	 30.0;
	1454	 1455	 0.068027	 0.942303	 0.0	 37	 37	 37	 0.550361	 0.0	 1	 -30.0	 30.0;
	1457	 1458	 0.003002	 0.115951	 0.0	 264	 264	 264	 0.939847	 0.0	 1	 -30.0	 30.0;
	1457	 1458	 0.003615	 0.123062	 0.0	 248	 248	 248	 0.939847	 0.0	 1	 -30.0	 30.0;
	1458	 5867	 0.000263	 -0.005471	 0.0	 1184.0	 1184.0	 1184.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1459	 5867	 6.2e-05	 0.032895	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	1460	 1461	 0.001358	 0.10963	 0.0	 293	 293	 293	 1.001002	 0.0	 1	 -30.0	 30.0;
	1460	 1462	 0.00324	 0.111605	 0.0	 280	 280	 280	 1.048219	 0.0	 1	 -30.0	 30.0;
	1460	 1462	 0.004148	 0.112	 0.0	 279	 279	 279	 1.038422	 0.0	 1	 -30.0	 30.0;
	1468	 1469	 0.003891	 0.129185	 0.0	 239	 239	 239	 0.98619	 0.0	 1	 -30.0	 30.0;
	1474	 1475	 0.003931	 0.125373	 0.0	 244	 244	 244	 0.963394	 0.0	 1	 -30.0	 30.0;
	1474	 1475	 0.003931	 0.125373	 0.0	 244	 244	 244	 0.963394	 0.0	 1	 -30.0	 30.0;
	1480	 1482	 0.003081	 0.117728	 0.0	 261	 261	 261	 0.972767	 0.0	 1	 -30.0	 30.0;
	1498	 1499	 0.002607	 0.115279	 0.0	 268	 268	 268	 1.090512	 0.0	 1	 -30.0	 30.0;
	1513	 1514	 0.000768	 0.089185	 0.0	 343	 343	 343	 0.983284	 0.0	 1	 -30.0	 30.0;
	1513	 1514	 0.004306	 0.158025	 0.0	 193	 193	 193	 0.978474	 0.0	 1	 -30.0	 30.0;
	1513	 1514	 0.004306	 0.159407	 0.0	 192	 192	 192	 0.978474	 0.0	 1	 -30.0	 30.0;
	1514	 1515	 0.000325	 0.027355	 0.0	 1153	 1153	 1153	 0.999001	 0.0	 1	 -30.0	 30.0;
	1514	 1515	 0.000796	 0.041551	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1514	 1515	 0.000727	 0.048753	 0.0	 607.0	 607.0	 607.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1514	 1515	 0.000325	 0.027562	 0.0	 1145	 1145	 1145	 1.0	 0.0	 1	 -30.0	 30.0;
	1518	 1520	 0.003714	 0.086361	 0.001	 403	 403	 403	 0.883392	 0.0	 1	 -30.0	 30.0;
	1517	 1520	 0.00156	 0.048494	 0.001	 717	 717	 717	 1.0101	 0.0	 1	 -30.0	 30.0;
	1521	 1522	 0.003121	 0.117531	 0.0	 260	 260	 260	 0.941619	 0.0	 1	 -30.0	 30.0;
	1521	 1522	 0.003635	 0.122469	 0.0	 249	 249	 249	 0.941619	 0.0	 1	 -30.0	 30.0;
	1528	 1530	 0.00316	 0.11516	 0.0	 268	 268	 268	 0.966187	 0.0	 1	 -30.0	 30.0;
	1529	 1530	 0.003042	 0.117728	 0.0	 262	 262	 262	 0.962466	 0.0	 1	 -30.0	 30.0;
	1528	 1530	 0.003891	 0.111407	 0.0	 277	 277	 277	 0.962466	 0.0	 1	 -30.0	 30.0;
	1528	 1531	 0.001357	 0.09973	 0.0	 316	 316	 316	 0.974656	 0.0	 1	 -30.0	 30.0;
	1530	 5932	 0.000159	 -0.007133	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1530	 5943	 0.000277	 -0.005609	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1531	 5932	 0.000173	 0.033726	 0.0	 1016	 1016	 1016	 0.0	 0.0	 1	 -30.0	 30.0;
	1531	 5943	 6.2e-05	 0.032964	 0.0	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	1536	 1537	 0.000325	 0.024792	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1538	 1539	 0.001778	 0.101333	 0.0	 305	 305	 305	 0.996016	 0.0	 1	 -30.0	 30.0;
	1538	 1539	 0.001778	 0.101136	 0.0	 305	 305	 305	 0.996016	 0.0	 1	 -30.0	 30.0;
	1559	 1560	 0.00316	 0.108049	 0.0	 286	 286	 286	 1.002004	 0.0	 1	 -30.0	 30.0;
	1559	 1560	 0.003002	 0.118519	 0.0	 260	 260	 260	 1.009082	 0.0	 1	 -30.0	 30.0;
	1559	 1560	 0.00316	 0.109037	 0.0	 283	 283	 283	 1.011122	 0.0	 1	 -30.0	 30.0;
	1580	 1581	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1580	 1581	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1583	 1584	 0.003062	 0.116543	 0.0	 275	 275	 275	 1.02145	 0.0	 1	 -30.0	 30.0;
	1583	 1584	 0.003101	 0.116938	 0.0	 274	 274	 274	 1.009082	 0.0	 1	 -30.0	 30.0;
	1592	 1594	 0.003042	 0.115753	 0.0	 267	 267	 267	 0.950573	 0.0	 1	 -30.0	 30.0;
	1593	 1594	 0.003951	 0.112395	 0.0	 275	 275	 275	 0.939847	 0.0	 1	 -30.0	 30.0;
	1594	 5868	 0.000145	 -0.007548	 0.0	 1187.0	 1187.0	 1187.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1594	 5896	 0.000533	 -0.004848	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1595	 5868	 0.000187	 0.03428	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	1595	 5896	 0.000173	 0.053186	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1596	 1597	 0.00241	 0.126222	 0.0	 244	 244	 244	 0.995025	 0.0	 1	 -30.0	 30.0;
	1596	 1597	 0.003852	 0.12563	 0.0	 245	 245	 245	 0.999001	 0.0	 1	 -30.0	 30.0;
	1596	 1598	 0.003793	 0.120889	 0.0	 255	 255	 255	 1.012146	 0.0	 1	 -30.0	 30.0;
	1608	 1609	 0.005378	 0.132356	 0.0	 229	 229	 229	 0.919963	 0.0	 1	 -30.0	 30.0;
	1608	 1609	 0.004356	 0.137467	 0.0	 221	 221	 221	 0.932835	 0.0	 1	 -30.0	 30.0;
	1611	 1612	 0.00316	 0.125037	 0.0	 246	 246	 246	 1.0142	 0.0	 1	 -30.0	 30.0;
	1610	 1612	 0.003951	 0.12563	 0.0	 245	 245	 245	 1.026695	 0.0	 1	 -30.0	 30.0;
	1610	 1612	 0.001778	 0.111012	 0.0	 277	 277	 277	 1.0142	 0.0	 1	 -30.0	 30.0;
	1614	 1615	 0.011482	 0.318519	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	1632	 1633	 0.001778	 0.121481	 0.0	 251	 251	 251	 1.012146	 0.0	 1	 -30.0	 30.0;
	1632	 1633	 0.001778	 0.121481	 0.0	 251	 251	 251	 1.012146	 0.0	 1	 -30.0	 30.0;
	1632	 1633	 0.001778	 0.121481	 0.0	 251	 251	 251	 1.012146	 0.0	 1	 -30.0	 30.0;
	1663	 1664	 0.003358	 0.121481	 0.0	 254	 254	 254	 0.964319	 0.0	 1	 -30.0	 30.0;
	1663	 1664	 0.003694	 0.120494	 0.0	 256	 256	 256	 0.976559	 0.0	 1	 -30.0	 30.0;
	1667	 1668	 0.001857	 0.114963	 0.0	 269	 269	 269	 0.965246	 0.0	 1	 -30.0	 30.0;
	1667	 1668	 0.001857	 0.115358	 0.0	 268	 268	 268	 0.999001	 0.0	 1	 -30.0	 30.0;
	1676	 1677	 0.00316	 0.125827	 0.0	 245	 245	 245	 1.001002	 0.0	 1	 -30.0	 30.0;
	1676	 1677	 0.003951	 0.124247	 0.0	 248	 248	 248	 0.989123	 0.0	 1	 -30.0	 30.0;
	1683	 1684	 0.003931	 0.111605	 0.0	 273	 273	 273	 0.990104	 0.0	 1	 -30.0	 30.0;
	1683	 1684	 0.003931	 0.111605	 0.0	 273	 273	 273	 0.990104	 0.0	 1	 -30.0	 30.0;
	1702	 1705	 0.003279	 0.110222	 0.0	 279	 279	 279	 0.968054	 0.0	 1	 -30.0	 30.0;
	1703	 1707	 0.003338	 0.113975	 0.0	 270	 270	 270	 0.96432	 0.0	 1	 -30.0	 30.0;
	1703	 1704	 0.00318	 0.125432	 0.0	 245	 245	 245	 0.96432	 0.0	 1	 -30.0	 30.0;
	1702	 1706	 0.003002	 0.107062	 0.0	 287	 287	 287	 0.947871	 0.0	 1	 -30.0	 30.0;
	1711	 1712	 0.00399	 0.113383	 0.0	 276	 276	 276	 1.037344	 0.0	 1	 -30.0	 30.0;
	1711	 1712	 0.003872	 0.110617	 0.0	 283	 283	 283	 1.037344	 0.0	 1	 -30.0	 30.0;
	1716	 1717	 0.003556	 0.122864	 0.0	 249	 249	 249	 0.962466	 0.0	 1	 -30.0	 30.0;
	1716	 1717	 0.00316	 0.112593	 0.0	 271	 271	 271	 0.957856	 0.0	 1	 -30.0	 30.0;
	1722	 1723	 0.045352	 0.942555	 0.0	 37	 37	 37	 1.001	 0.0	 1	 -30.0	 30.0;
	1729	 1731	 0.003101	 0.118519	 0.0	 261	 261	 261	 1.011122	 0.0	 1	 -30.0	 30.0;
	1729	 1731	 0.003101	 0.118914	 0.0	 260	 260	 260	 0.999001	 0.0	 1	 -30.0	 30.0;
	1743	 1746	 0.007901	 0.341728	 0.0	 101	 101	 101	 1.0	 0.0	 1	 -30.0	 30.0;
	1742	 1745	 0.007901	 0.341728	 0.0	 101	 101	 101	 1.0	 0.0	 1	 -30.0	 30.0;
	1741	 1744	 0.007901	 0.341728	 0.0	 101	 101	 101	 1.0	 0.0	 1	 -30.0	 30.0;
	1747	 1749	 0.003635	 0.123654	 0.0	 247	 247	 247	 0.952382	 0.0	 1	 -30.0	 30.0;
	1748	 1749	 0.004484	 0.118716	 0.0	 257	 257	 257	 0.96432	 0.0	 1	 -30.0	 30.0;
	1770	 1773	 0.004286	 0.165531	 0.0	 185	 185	 185	 0.968054	 0.0	 1	 -30.0	 30.0;
	1771	 1773	 0.00316	 0.112395	 0.0	 273	 273	 273	 0.992063	 0.0	 1	 -30.0	 30.0;
	1772	 1773	 0.003042	 0.116938	 0.0	 262	 262	 262	 0.997009	 0.0	 1	 -30.0	 30.0;
	1772	 1773	 0.003951	 0.111605	 0.0	 274	 274	 274	 0.997009	 0.0	 1	 -30.0	 30.0;
	1772	 1773	 0.003931	 0.112198	 0.0	 273	 273	 273	 1.009082	 0.0	 1	 -30.0	 30.0;
	1775	 1776	 0.001778	 0.100148	 0.0	 311	 311	 311	 1.01833	 0.0	 1	 -30.0	 30.0;
	1775	 1776	 0.001778	 0.100346	 0.0	 311	 311	 311	 1.01833	 0.0	 1	 -30.0	 30.0;
	1775	 1776	 0.000968	 0.105481	 0.0	 296	 296	 296	 1.00705	 0.0	 1	 -30.0	 30.0;
	1780	 1781	 0.00316	 0.12563	 0.0	 245	 245	 245	 1.0142	 0.0	 1	 -30.0	 30.0;
	1780	 1781	 0.00316	 0.125432	 0.0	 245	 245	 245	 1.0142	 0.0	 1	 -30.0	 30.0;
	1786	 1787	 0.012963	 0.267901	 0.0	 114	 114	 114	 1.020408	 0.0	 1	 -30.0	 30.0;
	1786	 1788	 0.004563	 0.161975	 0.0	 191	 191	 191	 0.978474	 0.0	 1	 -30.0	 30.0;
	1786	 1788	 0.003081	 0.106272	 0.0	 291	 291	 291	 0.968054	 0.0	 1	 -30.0	 30.0;
	1786	 1788	 0.003852	 0.116543	 0.0	 265	 265	 265	 0.974664	 0.0	 1	 -30.0	 30.0;
	1787	 1788	 0.001778	 0.12721	 0.0	 243	 243	 243	 0.996016	 0.0	 1	 -30.0	 30.0;
	1789	 1790	 0.003635	 0.118519	 0.0	 261	 261	 261	 0.999001	 0.0	 1	 -30.0	 30.0;
	1789	 1790	 0.003279	 0.125235	 0.0	 247	 247	 247	 0.974664	 0.0	 1	 -30.0	 30.0;
	1798	 1799	 0.00316	 0.125037	 0.0	 246	 246	 246	 1.001002	 0.0	 1	 -30.0	 30.0;
	1805	 1806	 0.003477	 0.145185	 0.0	 212	 212	 212	 0.974659	 0.0	 1	 -30.0	 30.0;
	1805	 1806	 0.003536	 0.147556	 0.0	 208	 208	 208	 0.96618	 0.0	 1	 -30.0	 30.0;
	1817	 1818	 0.003081	 0.125037	 0.0	 247	 247	 247	 1.023541	 0.0	 1	 -30.0	 30.0;
	1817	 1818	 0.001956	 0.126025	 0.0	 245	 245	 245	 0.974664	 0.0	 1	 -30.0	 30.0;
	1821	 1822	 0.003121	 0.125432	 0.0	 246	 246	 246	 0.97561	 0.0	 1	 -30.0	 30.0;
	1822	 1823	 0.000735	 0.044668	 0.0	 593.0	 593.0	 593.0	 0.959693	 0.0	 1	 -30.0	 30.0;
	1826	 1827	 0.001857	 0.121086	 0.0	 252	 252	 252	 1.012146	 0.0	 1	 -30.0	 30.0;
	1826	 1827	 0.001857	 0.121086	 0.0	 252	 252	 252	 1.012146	 0.0	 1	 -30.0	 30.0;
	1832	 1833	 0.004543	 0.112395	 0.0	 274	 274	 274	 0.989123	 0.0	 1	 -30.0	 30.0;
	1832	 1833	 0.00316	 0.116938	 0.0	 263	 263	 263	 1.001002	 0.0	 1	 -30.0	 30.0;
	1837	 1838	 0.003654	 0.122074	 0.0	 253	 253	 253	 1.010101	 0.0	 1	 -30.0	 30.0;
	1837	 1838	 0.003496	 0.122074	 0.0	 253	 253	 253	 0.999001	 0.0	 1	 -30.0	 30.0;
	1877	 1878	 0.003536	 0.122864	 0.0	 251	 251	 251	 0.929369	 0.0	 1	 -30.0	 30.0;
	1891	 1895	 0.000395	 0.238025	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	1890	 1894	 0.000395	 0.238025	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	1889	 1893	 0.000395	 0.238025	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	1888	 1892	 0.000395	 0.238025	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	1898	 1899	 0.001778	 0.122864	 0.0	 250	 250	 250	 1.022495	 0.0	 1	 -30.0	 30.0;
	1898	 1899	 0.00158	 0.122272	 0.0	 252	 252	 252	 1.010101	 0.0	 1	 -30.0	 30.0;
	1900	 1901	 0.004543	 0.163556	 0.0	 189	 189	 189	 0.95511	 0.0	 1	 -30.0	 30.0;
	1907	 1908	 0.003595	 0.126222	 0.0	 245	 245	 245	 0.97561	 0.0	 1	 -30.0	 30.0;
	1907	 1908	 0.003615	 0.125432	 0.0	 246	 246	 246	 0.97561	 0.0	 1	 -30.0	 30.0;
	1922	 1923	 0.004267	 0.165136	 0.0	 187	 187	 187	 0.98135	 0.0	 1	 -30.0	 30.0;
	1922	 1923	 0.005926	 0.23763	 0.0	 130	 130	 130	 0.98135	 0.0	 1	 -30.0	 30.0;
	1924	 1925	 0.003026	 0.155471	 0.0	 203	 203	 203	 0.966188	 0.0	 1	 -30.0	 30.0;
	1928	 1929	 0.000803	 0.034418	 0.0	 605.0	 605.0	 605.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1928	 5897	 0.000277	 -0.004709	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1929	 5897	 4.8e-05	 0.029571	 0.0	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	1930	 1931	 0.001807	 0.100554	 0.0	 313	 313	 313	 0.9311	 0.0	 1	 -30.0	 30.0;
	1936	 1938	 0.00316	 0.115753	 0.0	 277	 277	 277	 1.070664	 0.0	 1	 -30.0	 30.0;
	1936	 1939	 0.001835	 0.099792	 0.0	 323	 323	 323	 0.994038	 0.0	 1	 -30.0	 30.0;
	1937	 1939	 0.001842	 0.10097	 0.0	 319	 319	 319	 1.043841	 0.0	 1	 -30.0	 30.0;
	1938	 1939	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1955	 1956	 0.000332	 0.024723	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1955	 1956	 0.000305	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1965	 1971	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	1964	 1969	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	1963	 1968	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	1962	 1967	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	1961	 1966	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	1974	 1977	 0.001975	 0.157432	 0.0	 218	 218	 218	 1.0	 0.0	 1	 -30.0	 30.0;
	1983	 1984	 0.01284	 0.265432	 0.0	 114	 114	 114	 0.956024	 0.0	 1	 -30.0	 30.0;
	1983	 1985	 0.002449	 0.118736	 0.0	 257	 257	 257	 0.929369	 0.0	 1	 -30.0	 30.0;
	1984	 1985	 0.003002	 0.116543	 0.0	 263	 263	 263	 1.009082	 0.0	 1	 -30.0	 30.0;
	1984	 1985	 0.003042	 0.116148	 0.0	 264	 264	 264	 1.009082	 0.0	 1	 -30.0	 30.0;
	1990	 1991	 0.001798	 0.122667	 0.0	 252	 252	 252	 0.974664	 0.0	 1	 -30.0	 30.0;
	1990	 1991	 0.001798	 0.119704	 0.0	 258	 258	 258	 0.98619	 0.0	 1	 -30.0	 30.0;
	1990	 1991	 0.002173	 0.119783	 0.0	 258	 258	 258	 0.975606	 0.0	 1	 -30.0	 30.0;
	2005	 2006	 0.003595	 0.119506	 0.0	 258	 258	 258	 0.974664	 0.0	 1	 -30.0	 30.0;
	2005	 2006	 0.004642	 0.160988	 0.0	 192	 192	 192	 0.978474	 0.0	 1	 -30.0	 30.0;
	2033	 2034	 0.003891	 0.124444	 0.0	 248	 248	 248	 0.937207	 0.0	 1	 -30.0	 30.0;
	2033	 2034	 0.003911	 0.11279	 0.0	 274	 274	 274	 0.94697	 0.0	 1	 -30.0	 30.0;
	2042	 2043	 0.003141	 0.110775	 0.0	 279	 279	 279	 0.97656	 0.0	 1	 -30.0	 30.0;
	2041	 2043	 0.00324	 0.116543	 0.0	 265	 265	 265	 0.968054	 0.0	 1	 -30.0	 30.0;
	2049	 2050	 0.000319	 0.02687	 0.0	 1174	 1174	 1174	 1.0	 0.0	 1	 -30.0	 30.0;
	2049	 2050	 0.000339	 0.02687	 0.0	 1174	 1174	 1174	 1.0	 0.0	 1	 -30.0	 30.0;
	2049	 2050	 0.00036	 0.027285	 0.0	 1156	 1156	 1156	 1.0	 0.0	 1	 -30.0	 30.0;
	2066	 2068	 0.002909	 0.158587	 0.0	 200	 200	 200	 1.031993	 0.0	 1	 -30.0	 30.0;
	2066	 2067	 0.002832	 0.157202	 0.0	 202	 202	 202	 1.021451	 0.0	 1	 -30.0	 30.0;
	2070	 2071	 0.003812	 0.121481	 0.0	 254	 254	 254	 0.999001	 0.0	 1	 -30.0	 30.0;
	2070	 2071	 0.004642	 0.163556	 0.0	 189	 189	 189	 0.993049	 0.0	 1	 -30.0	 30.0;
	2079	 2080	 0.003437	 0.128395	 0.0	 238	 238	 238	 0.978473	 0.0	 1	 -30.0	 30.0;
	2079	 2080	 0.003437	 0.128395	 0.0	 238	 238	 238	 0.978473	 0.0	 1	 -30.0	 30.0;
	5869	 2081	 0.000152	 -0.006163	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2081	 2082	 0.000312	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2082	 5869	 0.000159	 0.031163	 0.0	 1099	 1099	 1099	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 2088	 0.000119	 0.00796	 0.0	 418.0	 418.0	 418.0	 1.0	 -1.94	 1	 -30.0	 30.0;
	2086	 2088	 0.00322	 0.112	 0.0	 286	 286	 286	 1.047121	 0.0	 1	 -30.0	 30.0;
	2086	 2088	 0.003081	 0.116346	 0.0	 275	 275	 275	 1.047121	 0.0	 1	 -30.0	 30.0;
	2089	 2090	 0.003358	 0.122469	 0.0	 252	 252	 252	 0.974664	 0.0	 1	 -30.0	 30.0;
	2089	 2090	 0.003358	 0.122469	 0.0	 252	 252	 252	 0.963394	 0.0	 1	 -30.0	 30.0;
	2097	 2098	 0.00399	 0.110815	 0.0	 275	 275	 275	 0.96432	 0.0	 1	 -30.0	 30.0;
	2097	 2098	 0.00397	 0.110222	 0.0	 277	 277	 277	 0.96432	 0.0	 1	 -30.0	 30.0;
	2097	 2098	 0.003951	 0.111012	 0.0	 275	 275	 275	 0.97561	 0.0	 1	 -30.0	 30.0;
	2105	 2106	 0.001995	 0.125432	 0.0	 246	 246	 246	 1.0	 0.0	 1	 -30.0	 30.0;
	2105	 2106	 0.001936	 0.117926	 0.0	 262	 262	 262	 0.999001	 0.0	 1	 -30.0	 30.0;
	2105	 2106	 0.003753	 0.123654	 0.0	 250	 250	 250	 0.999001	 0.0	 1	 -30.0	 30.0;
	2118	 2119	 0.003852	 0.126815	 0.0	 244	 244	 244	 1.011122	 0.0	 1	 -30.0	 30.0;
	2118	 2119	 0.003022	 0.116741	 0.0	 265	 265	 265	 1.011122	 0.0	 1	 -30.0	 30.0;
	2122	 2125	 0.003951	 0.124444	 0.0	 247	 247	 247	 1.001002	 0.0	 1	 -30.0	 30.0;
	2121	 2124	 0.003358	 0.118519	 0.0	 260	 260	 260	 0.989123	 0.0	 1	 -30.0	 30.0;
	2121	 2123	 0.00316	 0.112593	 0.0	 273	 273	 273	 1.001002	 0.0	 1	 -30.0	 30.0;
	2126	 2128	 0.002193	 0.126914	 0.0	 248	 248	 248	 1.034126	 0.0	 1	 -30.0	 30.0;
	2127	 2128	 0.005096	 0.143921	 0.0	 221	 221	 221	 1.0	 0.0	 1	 -30.0	 30.0;
	2127	 2128	 0.005531	 0.188247	 0.0	 169	 169	 169	 1.012149	 0.0	 1	 -30.0	 30.0;
	2130	 2131	 0.013354	 0.302343	 0.0	 98	 98	 98	 0.933703	 0.0	 1	 -30.0	 30.0;
	2130	 2131	 0.013354	 0.302343	 0.0	 98	 98	 98	 0.919967	 0.0	 1	 -30.0	 30.0;
	2130	 2132	 0.004938	 0.159012	 0.0	 197	 197	 197	 0.919114	 0.0	 1	 -30.0	 30.0;
	2130	 2132	 0.004938	 0.159012	 0.0	 197	 197	 197	 0.909091	 0.0	 1	 -30.0	 30.0;
	2136	 2137	 0.003279	 0.109827	 0.0	 281	 281	 281	 0.957856	 0.0	 1	 -30.0	 30.0;
	2136	 2137	 0.003121	 0.117728	 0.0	 262	 262	 262	 0.939847	 0.0	 1	 -30.0	 30.0;
	2141	 2142	 0.004741	 0.164148	 0.0	 188	 188	 188	 0.990101	 0.0	 1	 -30.0	 30.0;
	2141	 2142	 0.003358	 0.106667	 0.0	 288	 288	 288	 1.001002	 0.0	 1	 -30.0	 30.0;
	2142	 2143	 0.000713	 0.043283	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	2142	 2143	 0.000769	 0.043837	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	2155	 2156	 0.001877	 0.093037	 0.0	 334	 334	 334	 0.983284	 0.0	 1	 -30.0	 30.0;
	2159	 2160	 0.003259	 0.109235	 0.0	 292.0	 292.0	 292.0	 1.002004	 0.0	 1	 -30.0	 30.0;
	2159	 2160	 0.00322	 0.109235	 0.0	 292.0	 292.0	 292.0	 0.992064	 0.0	 1	 -30.0	 30.0;
	2159	 2160	 0.00316	 0.113778	 0.0	 282	 282	 282	 0.997009	 0.0	 1	 -30.0	 30.0;
	2166	 2169	 0.003832	 0.11437	 0.0	 270	 270	 270	 1.086957	 0.0	 1	 -30.0	 30.0;
	2166	 2168	 0.003832	 0.11437	 0.0	 270	 270	 270	 1.074114	 0.0	 1	 -30.0	 30.0;
	2178	 2179	 0.003635	 0.114963	 0.0	 267	 267	 267	 0.942507	 0.0	 1	 -30.0	 30.0;
	2178	 5920	 0.001343	 -0.004543	 0.0	 446.0	 446.0	 446.0	 0.94697	 0.0	 1	 -30.0	 30.0;
	2178	 5933	 0.001679	 0.012642	 0.0	 446.0	 446.0	 446.0	 0.937207	 0.0	 1	 -30.0	 30.0;
	2179	 5920	 0.001817	 0.123654	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	2179	 5933	 0.001877	 0.098765	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	2190	 2191	 0.000319	 0.027424	 0.0	 1157	 1157	 1157	 1.0	 0.0	 1	 -30.0	 30.0;
	2190	 2191	 0.000319	 0.027355	 0.0	 1160	 1160	 1160	 1.0	 0.0	 1	 -30.0	 30.0;
	2216	 2217	 0.002983	 0.115951	 0.0	 266	 266	 266	 0.970878	 0.0	 1	 -30.0	 30.0;
	2221	 2222	 0.003358	 0.109827	 0.0	 281	 281	 281	 0.995025	 0.0	 1	 -30.0	 30.0;
	2226	 2227	 0.003852	 0.11279	 0.0	 284	 284	 284	 0.997009	 0.0	 1	 -30.0	 30.0;
	2226	 2227	 0.003852	 0.11279	 0.0	 284	 284	 284	 1.004017	 0.0	 1	 -30.0	 30.0;
	2229	 2230	 0.005679	 0.116173	 0.0	 276	 276	 276	 1.001002	 0.0	 1	 -30.0	 30.0;
	2234	 2235	 0.002074	 0.161778	 0.0	 193	 193	 193	 0.7446	 0.0	 1	 -30.0	 30.0;
	2234	 2235	 0.002074	 0.161778	 0.0	 193	 193	 193	 0.875657	 0.0	 1	 -30.0	 30.0;
	2240	 5870	 0.002864	 0.068543	 0.0	 504	 504	 504	 1.0	 0.0	 1	 -30.0	 30.0;
	2241	 5870	 0.0	 0.001185	 0.0	 29046	 29046	 29046	 0.968054	 0.0	 1	 -30.0	 30.0;
	2242	 5870	 0.006499	 0.143802	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	2247	 2248	 0.001896	 0.119704	 0.0	 255	 255	 255	 1.012146	 0.0	 1	 -30.0	 30.0;
	2247	 2248	 0.001896	 0.119704	 0.0	 255	 255	 255	 1.012146	 0.0	 1	 -30.0	 30.0;
	2256	 2257	 0.009733	 0.388889	 0.0	 81	 81	 81	 1.061571	 0.0	 1	 -30.0	 30.0;
	2256	 2258	 0.003911	 0.147161	 0.0	 210	 210	 210	 0.97561	 0.0	 1	 -30.0	 30.0;
	2256	 2258	 0.003951	 0.118519	 0.0	 261	 261	 261	 0.987167	 0.0	 1	 -30.0	 30.0;
	2257	 2258	 0.005472	 0.190025	 0.0	 166	 166	 166	 1.0	 0.0	 1	 -30.0	 30.0;
	2261	 2263	 0.003338	 0.12484	 0.0	 262	 262	 262	 1.03627	 0.0	 1	 -30.0	 30.0;
	2265	 2266	 0.00316	 0.113778	 0.0	 282	 282	 282	 1.029866	 0.0	 1	 -30.0	 30.0;
	2265	 2266	 0.00316	 0.113778	 0.0	 282	 282	 282	 1.02145	 0.0	 1	 -30.0	 30.0;
	2265	 2266	 0.003635	 0.120494	 0.0	 266	 266	 266	 1.034126	 0.0	 1	 -30.0	 30.0;
	2282	 2283	 0.00295	 0.163504	 0.0	 194	 194	 194	 0.994033	 0.0	 1	 -30.0	 30.0;
	2285	 2286	 0.003951	 0.112988	 0.0	 272	 272	 272	 1.0142	 0.0	 1	 -30.0	 30.0;
	2285	 2286	 0.003951	 0.124247	 0.0	 248	 248	 248	 1.001002	 0.0	 1	 -30.0	 30.0;
	2291	 2292	 0.003121	 0.125037	 0.0	 247	 247	 247	 1.026695	 0.0	 1	 -30.0	 30.0;
	2291	 2292	 0.003556	 0.119309	 0.0	 259	 259	 259	 1.026695	 0.0	 1	 -30.0	 30.0;
	2301	 2302	 0.003338	 0.121679	 0.0	 254	 254	 254	 0.963394	 0.0	 1	 -30.0	 30.0;
	2301	 2302	 0.003279	 0.117531	 0.0	 263	 263	 263	 0.963394	 0.0	 1	 -30.0	 30.0;
	2307	 2308	 0.003635	 0.126222	 0.0	 245	 245	 245	 0.968054	 0.0	 1	 -30.0	 30.0;
	2307	 2308	 0.003635	 0.126222	 0.0	 245	 245	 245	 0.968054	 0.0	 1	 -30.0	 30.0;
	2307	 2308	 0.003101	 0.12484	 0.0	 247	 247	 247	 0.968054	 0.0	 1	 -30.0	 30.0;
	2320	 2321	 0.003496	 0.118123	 0.0	 261	 261	 261	 0.985222	 0.0	 1	 -30.0	 30.0;
	2327	 2329	 0.00397	 0.124049	 0.0	 246	 246	 246	 1.012147	 0.0	 1	 -30.0	 30.0;
	2328	 2329	 0.003062	 0.117728	 0.0	 259	 259	 259	 0.999001	 0.0	 1	 -30.0	 30.0;
	2328	 2329	 0.003101	 0.125432	 0.0	 243	 243	 243	 0.999001	 0.0	 1	 -30.0	 30.0;
	2329	 2330	 0.000319	 0.024307	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2337	 2339	 0.004543	 0.120691	 0.0	 255	 255	 255	 1.001002	 0.0	 1	 -30.0	 30.0;
	2337	 2339	 0.004346	 0.120691	 0.0	 255	 255	 255	 1.001002	 0.0	 1	 -30.0	 30.0;
	2338	 2339	 0.004741	 0.157432	 0.0	 196	 196	 196	 0.990101	 0.0	 1	 -30.0	 30.0;
	2343	 2345	 0.000693	 0.048753	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2343	 2344	 0.000796	 0.042452	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2361	 2367	 0.003951	 0.185679	 0.0	 185	 185	 185	 1.0	 0.0	 1	 -30.0	 30.0;
	2360	 2365	 0.003951	 0.185679	 0.0	 185	 185	 185	 1.0	 0.0	 1	 -30.0	 30.0;
	2359	 2364	 0.003951	 0.185679	 0.0	 185	 185	 185	 1.0	 0.0	 1	 -30.0	 30.0;
	2358	 2363	 0.003951	 0.185679	 0.0	 185	 185	 185	 1.0	 0.0	 1	 -30.0	 30.0;
	2357	 2362	 0.003951	 0.185679	 0.0	 185	 185	 185	 1.0	 0.0	 1	 -30.0	 30.0;
	2368	 2369	 0.003556	 0.111407	 0.0	 277	 277	 277	 0.952382	 0.0	 1	 -30.0	 30.0;
	2368	 2369	 0.003496	 0.122469	 0.0	 252	 252	 252	 0.94697	 0.0	 1	 -30.0	 30.0;
	2416	 2418	 0.001144	 0.13043	 0.0	 234	 234	 234	 0.962464	 0.0	 1	 -30.0	 30.0;
	2416	 2417	 0.001237	 0.119565	 0.0	 255	 255	 255	 0.985218	 0.0	 1	 -30.0	 30.0;
	2420	 2421	 0.004286	 0.168889	 0.0	 183	 183	 183	 0.968054	 0.0	 1	 -30.0	 30.0;
	2424	 2425	 0.00324	 0.116543	 0.0	 265	 265	 265	 0.978474	 0.0	 1	 -30.0	 30.0;
	2424	 2425	 0.003338	 0.111605	 0.0	 277	 277	 277	 0.963394	 0.0	 1	 -30.0	 30.0;
	2423	 2425	 0.003872	 0.11121	 0.0	 278	 278	 278	 0.987167	 0.0	 1	 -30.0	 30.0;
	2423	 2425	 0.003062	 0.116741	 0.0	 265	 265	 265	 0.97561	 0.0	 1	 -30.0	 30.0;
	2439	 2440	 0.001473	 0.177164	 0.0	 178	 178	 178	 0.905801	 0.0	 1	 -30.0	 30.0;
	2439	 2441	 0.003496	 0.10884	 0.0	 284	 284	 284	 0.963394	 0.0	 1	 -30.0	 30.0;
	2439	 2441	 0.003279	 0.111802	 0.0	 276	 276	 276	 0.963394	 0.0	 1	 -30.0	 30.0;
	2440	 2441	 0.0032	 0.124444	 0.0	 253	 253	 253	 1.0	 0.0	 1	 -30.0	 30.0;
	2450	 2451	 0.00187	 0.104571	 0.0	 301	 301	 301	 0.984249	 0.0	 1	 -30.0	 30.0;
	2450	 2451	 0.001842	 0.099931	 0.0	 315	 315	 315	 0.984249	 0.0	 1	 -30.0	 30.0;
	2459	 2460	 0.000332	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2459	 5898	 0.000145	 -0.006371	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2458	 5921	 0.000132	 -0.006302	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2460	 5898	 0.000187	 0.031163	 0.0	 1099	 1099	 1099	 0.0	 0.0	 1	 -30.0	 30.0;
	2460	 5921	 0.000187	 0.03144	 0.0	 1089	 1089	 1089	 0.0	 0.0	 1	 -30.0	 30.0;
	2461	 2462	 0.003022	 0.115951	 0.0	 266	 266	 266	 0.997009	 0.0	 1	 -30.0	 30.0;
	2461	 2462	 0.003832	 0.111802	 0.0	 276	 276	 276	 0.985226	 0.0	 1	 -30.0	 30.0;
	2461	 2463	 0.001752	 0.102285	 0.0	 310	 310	 310	 0.948768	 0.0	 1	 -30.0	 30.0;
	2461	 2463	 0.001759	 0.101177	 0.0	 313	 313	 313	 0.966188	 0.0	 1	 -30.0	 30.0;
	2462	 2463	 0.000845	 0.042729	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2475	 2477	 0.001778	 0.091062	 0.0	 335	 335	 335	 0.971818	 0.0	 1	 -30.0	 30.0;
	2476	 2477	 0.001758	 0.092247	 0.0	 331	 331	 331	 0.981358	 0.0	 1	 -30.0	 30.0;
	2475	 2477	 0.001798	 0.092049	 0.0	 332	 332	 332	 0.949664	 0.0	 1	 -30.0	 30.0;
	2482	 2483	 0.003951	 0.124247	 0.0	 246	 246	 246	 0.98619	 0.0	 1	 -30.0	 30.0;
	2482	 2483	 0.003062	 0.124444	 0.0	 245	 245	 245	 0.97561	 0.0	 1	 -30.0	 30.0;
	2495	 2496	 0.001778	 0.118519	 0.0	 261	 261	 261	 0.978474	 0.0	 1	 -30.0	 30.0;
	2495	 2496	 0.003931	 0.12484	 0.0	 247	 247	 247	 0.978474	 0.0	 1	 -30.0	 30.0;
	2502	 2503	 0.001936	 0.115358	 0.0	 268	 268	 268	 1.023541	 0.0	 1	 -30.0	 30.0;
	2507	 2508	 0.022222	 0.37037	 0.0	 82	 82	 82	 0.985227	 0.0	 1	 -30.0	 30.0;
	2507	 2508	 0.022222	 0.37037	 0.0	 82	 82	 82	 0.992065	 0.0	 1	 -30.0	 30.0;
	2509	 2510	 0.001798	 0.122667	 0.0	 252	 252	 252	 0.98619	 0.0	 1	 -30.0	 30.0;
	2509	 2510	 0.001798	 0.122667	 0.0	 252	 252	 252	 1.011122	 0.0	 1	 -30.0	 30.0;
	2510	 2511	 0.000332	 0.024238	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	2510	 2511	 0.000332	 0.024238	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	2516	 2517	 0.00318	 0.114765	 0.0	 301	 301	 301	 1.082251	 0.0	 1	 -30.0	 30.0;
	2532	 2533	 0.001975	 0.117531	 0.0	 262	 262	 262	 1.0142	 0.0	 1	 -30.0	 30.0;
	2541	 2542	 0.003867	 0.109333	 0.0	 277	 277	 277	 1.028807	 0.0	 1	 -30.0	 30.0;
	2541	 2543	 0.001975	 0.126025	 0.0	 242	 242	 242	 0.963394	 0.0	 1	 -30.0	 30.0;
	2541	 2543	 0.003852	 0.112	 0.0	 273	 273	 273	 0.96432	 0.0	 1	 -30.0	 30.0;
	2542	 2543	 0.004543	 0.137284	 0.0	 224	 224	 224	 0.952381	 0.0	 1	 -30.0	 30.0;
	2552	 2553	 0.000636	 0.120237	 0.0	 257	 257	 257	 0.926784	 0.0	 1	 -30.0	 30.0;
	2552	 2553	 0.000636	 0.120237	 0.0	 257	 257	 257	 0.937207	 0.0	 1	 -30.0	 30.0;
	2559	 2560	 0.003714	 0.124642	 0.0	 248	 248	 248	 1.0	 0.0	 1	 -30.0	 30.0;
	2559	 2560	 0.003081	 0.116346	 0.0	 265	 265	 265	 1.0	 0.0	 1	 -30.0	 30.0;
	2559	 2560	 0.003121	 0.118519	 0.0	 261	 261	 261	 0.953289	 0.0	 1	 -30.0	 30.0;
	2560	 2561	 0.00081	 0.039266	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2560	 2561	 0.00081	 0.039612	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2563	 2564	 0.001778	 0.100148	 0.0	 308	 308	 308	 0.995025	 0.0	 1	 -30.0	 30.0;
	2563	 2564	 0.001778	 0.100148	 0.0	 308	 308	 308	 0.995025	 0.0	 1	 -30.0	 30.0;
	2570	 2571	 0.007055	 0.203578	 0.0	 145	 145	 145	 0.981352	 0.0	 1	 -30.0	 30.0;
	2570	 2573	 0.00322	 0.165926	 0.0	 189	 189	 189	 0.901711	 0.0	 1	 -30.0	 30.0;
	2571	 2573	 0.002686	 0.169877	 0.0	 181	 181	 181	 0.978477	 0.0	 1	 -30.0	 30.0;
	2571	 2573	 0.002686	 0.169877	 0.0	 181	 181	 181	 0.967124	 0.0	 1	 -30.0	 30.0;
	2572	 2573	 0.003338	 0.158025	 0.0	 202	 202	 202	 0.977517	 0.0	 1	 -30.0	 30.0;
	2576	 2577	 0.001778	 0.092049	 0.0	 348	 348	 348	 1.01833	 0.0	 1	 -30.0	 30.0;
	2576	 2577	 0.001837	 0.093827	 0.0	 341	 341	 341	 1.01833	 0.0	 1	 -30.0	 30.0;
	2587	 2588	 0.003951	 0.111605	 0.0	 273	 273	 273	 0.952382	 0.0	 1	 -30.0	 30.0;
	2587	 2588	 0.00316	 0.116148	 0.0	 263	 263	 263	 0.942507	 0.0	 1	 -30.0	 30.0;
	2587	 2588	 0.003279	 0.11516	 0.0	 265	 265	 265	 0.952382	 0.0	 1	 -30.0	 30.0;
	2587	 2588	 0.003081	 0.118123	 0.0	 259	 259	 259	 0.942507	 0.0	 1	 -30.0	 30.0;
	2598	 2600	 0.001842	 0.101731	 0.0	 310	 310	 310	 0.984249	 0.0	 1	 -30.0	 30.0;
	2598	 2599	 0.001821	 0.100762	 0.0	 313	 313	 313	 0.987171	 0.0	 1	 -30.0	 30.0;
	2618	 2619	 0.00399	 0.111605	 0.0	 280	 280	 280	 0.988142	 0.0	 1	 -30.0	 30.0;
	2626	 2628	 0.003615	 0.123062	 0.0	 251	 251	 251	 1.0	 0.0	 1	 -30.0	 30.0;
	2627	 2628	 0.003141	 0.116741	 0.0	 265	 265	 265	 0.987167	 0.0	 1	 -30.0	 30.0;
	2626	 2628	 0.003516	 0.121679	 0.0	 254	 254	 254	 0.978474	 0.0	 1	 -30.0	 30.0;
	2640	 2641	 0.001956	 0.003956	 0.0	 974.0	 974.0	 974.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2647	 2648	 0.003062	 0.116741	 0.0	 268	 268	 268	 1.02459	 0.0	 1	 -30.0	 30.0;
	2653	 2654	 0.003852	 0.12642	 0.0	 242	 242	 242	 1.0	 0.0	 1	 -30.0	 30.0;
	2653	 2654	 0.003852	 0.12642	 0.0	 242	 242	 242	 0.978474	 0.0	 1	 -30.0	 30.0;
	2656	 2658	 0.002016	 0.004031	 0.0	 7637	 7637	 7637	 1.0	 0.0	 1	 -30.0	 30.0;
	2655	 5922	 0.012444	 0.152889	 0.0	 226	 226	 226	 1.0	 0.0	 1	 -30.0	 30.0;
	2657	 2659	 0.003956	 0.039511	 0.0	 863	 863	 863	 1.0	 0.0	 1	 -30.0	 30.0;
	2658	 5922	 0.000889	 0.002667	 0.0	 12244	 12244	 12244	 0.964319	 0.0	 1	 -30.0	 30.0;
	2659	 5922	 0.005333	 0.308444	 0.0	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	2660	 2661	 0.002099	 0.116049	 0.0	 256	 256	 256	 0.978469	 0.0	 1	 -30.0	 30.0;
	2662	 2663	 0.068027	 0.942303	 0.0	 37	 37	 37	 0.550361	 0.0	 1	 -30.0	 30.0;
	2668	 2669	 0.00399	 0.124642	 0.0	 248	 248	 248	 1.0	 0.0	 1	 -30.0	 30.0;
	2668	 2669	 0.003556	 0.126025	 0.0	 245	 245	 245	 1.0	 0.0	 1	 -30.0	 30.0;
	2668	 2669	 0.001936	 0.117926	 0.0	 262	 262	 262	 0.999001	 0.0	 1	 -30.0	 30.0;
	2677	 2678	 0.003121	 0.125235	 0.0	 247	 247	 247	 0.974664	 0.0	 1	 -30.0	 30.0;
	2696	 2697	 0.003753	 0.12879	 0.0	 239	 239	 239	 0.989123	 0.0	 1	 -30.0	 30.0;
	2696	 2697	 0.00316	 0.125235	 0.0	 246	 246	 246	 1.001002	 0.0	 1	 -30.0	 30.0;
	2698	 2700	 0.00158	 0.117531	 0.0	 263	 263	 263	 1.037345	 0.0	 1	 -30.0	 30.0;
	2698	 2700	 0.001975	 0.11358	 0.0	 272	 272	 272	 1.053742	 0.0	 1	 -30.0	 30.0;
	2699	 2700	 0.001778	 0.118716	 0.0	 260	 260	 260	 1.053742	 0.0	 1	 -30.0	 30.0;
	2706	 2707	 0.000665	 0.043075	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2706	 2707	 0.000672	 0.04356	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	5923	 2706	 0.000554	 -0.004224	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2707	 5923	 0.000118	 0.047576	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2713	 2714	 0.000679	 0.04536	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2713	 2714	 0.000686	 0.045083	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2717	 2718	 0.003259	 0.123852	 0.0	 249	 249	 249	 0.978474	 0.0	 1	 -30.0	 30.0;
	2717	 2718	 0.003081	 0.117728	 0.0	 262	 262	 262	 0.982323	 0.0	 1	 -30.0	 30.0;
	2746	 2747	 0.00316	 0.162963	 0.0	 189	 189	 189	 0.965253	 0.0	 1	 -30.0	 30.0;
	2746	 2747	 0.002765	 0.170864	 0.0	 180	 180	 180	 0.956935	 0.0	 1	 -30.0	 30.0;
	2755	 2756	 0.000332	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2755	 2756	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2755	 2756	 0.000319	 0.025139	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2762	 2763	 0.001758	 0.092247	 0.0	 331	 331	 331	 0.971818	 0.0	 1	 -30.0	 30.0;
	2761	 5871	 0.004993	 0.223892	 0.0	 155	 155	 155	 1.0	 0.0	 1	 -30.0	 30.0;
	2762	 2764	 0.001828	 0.102562	 0.0	 307	 307	 307	 0.956942	 0.0	 1	 -30.0	 30.0;
	2762	 2764	 0.001807	 0.100416	 0.0	 314	 314	 314	 0.956942	 0.0	 1	 -30.0	 30.0;
	2763	 5871	 0.000651	 -0.005055	 0.0	 547.0	 547.0	 547.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2764	 5871	 4.2e-05	 0.05374	 0.0	 547.0	 547.0	 547.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2767	 2768	 0.004938	 0.163556	 0.0	 188	 188	 188	 1.037345	 0.0	 1	 -30.0	 30.0;
	2769	 2770	 0.003654	 0.173235	 0.0	 178	 178	 178	 0.974661	 0.0	 1	 -30.0	 30.0;
	2773	 2774	 0.003378	 0.105679	 0.0	 292	 292	 292	 0.978474	 0.0	 1	 -30.0	 30.0;
	2773	 2774	 0.003299	 0.107654	 0.0	 287	 287	 287	 0.978474	 0.0	 1	 -30.0	 30.0;
	2772	 2775	 0.001807	 0.100831	 0.0	 314	 314	 314	 0.95602	 0.0	 1	 -30.0	 30.0;
	2772	 2775	 0.00178	 0.100139	 0.0	 316	 316	 316	 0.95602	 0.0	 1	 -30.0	 30.0;
	2774	 2775	 0.000759	 0.035838	 0.0	 885	 885	 885	 1.001	 0.0	 1	 -30.0	 30.0;
	2777	 5872	 0.000145	 -0.011219	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2777	 5899	 0.000139	 -0.007687	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2778	 5872	 0.000194	 0.038781	 0.0	 883	 883	 883	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 5899	 0.000187	 0.034903	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	2783	 2784	 0.002074	 0.116741	 0.0	 265	 265	 265	 0.98912	 0.0	 1	 -30.0	 30.0;
	2783	 2784	 0.001936	 0.115951	 0.0	 266	 266	 266	 0.98912	 0.0	 1	 -30.0	 30.0;
	2789	 2791	 0.001752	 0.100485	 0.0	 320	 320	 320	 1.029866	 0.0	 1	 -30.0	 30.0;
	2790	 2791	 0.000319	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2790	 2791	 0.000325	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2796	 2799	 0.003081	 0.117728	 0.0	 261	 261	 261	 0.929371	 0.0	 1	 -30.0	 30.0;
	2797	 2799	 0.004504	 0.162568	 0.0	 189	 189	 189	 0.929371	 0.0	 1	 -30.0	 30.0;
	2798	 2799	 0.003575	 0.121481	 0.0	 259	 259	 259	 1.054854	 0.0	 1	 -30.0	 30.0;
	2802	 2803	 0.003062	 0.116148	 0.0	 263	 263	 263	 0.970872	 0.0	 1	 -30.0	 30.0;
	2802	 2803	 0.003595	 0.123654	 0.0	 247	 247	 247	 0.961535	 0.0	 1	 -30.0	 30.0;
	2807	 2808	 0.003062	 0.116543	 0.0	 265	 265	 265	 1.022495	 0.0	 1	 -30.0	 30.0;
	2807	 2808	 0.003101	 0.115753	 0.0	 267	 267	 267	 1.010101	 0.0	 1	 -30.0	 30.0;
	2824	 5873	 0.000443	 -0.004848	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2824	 5900	 0.000305	 -0.007133	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2824	 2825	 0.000734	 0.024654	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2825	 5873	 0.000249	 0.047992	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2825	 5900	 0.000506	 0.046814	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2840	 2841	 0.003081	 0.12563	 0.0	 243	 243	 243	 0.964324	 0.0	 1	 -30.0	 30.0;
	2856	 2857	 0.001778	 0.099753	 0.0	 306	 306	 306	 1.009082	 0.0	 1	 -30.0	 30.0;
	2856	 2857	 0.001778	 0.098765	 0.0	 309	 309	 309	 1.009082	 0.0	 1	 -30.0	 30.0;
	2885	 5874	 0.000152	 -0.011219	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2885	 5901	 0.000443	 -0.011011	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2885	 5924	 0.000215	 -0.005194	 0.0	 1186.0	 1186.0	 1186.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2885	 5934	 0.000145	 -0.011496	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2886	 5874	 0.000187	 0.038296	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 5901	 0.000374	 0.053463	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 5924	 9.7e-05	 0.032064	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 5934	 0.000194	 0.038435	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	2892	 5875	 0.002568	 0.070124	 0.0	 493	 493	 493	 1.0	 0.0	 1	 -30.0	 30.0;
	2893	 5875	 0.000494	 0.013037	 0.0	 2625	 2625	 2625	 1.023541	 0.0	 1	 -30.0	 30.0;
	2894	 5875	 0.002765	 0.132148	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	2906	 2907	 0.003556	 0.118321	 0.0	 260	 260	 260	 0.989123	 0.0	 1	 -30.0	 30.0;
	2907	 5876	 0.000229	 -0.004571	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	2908	 5902	 0.000215	 -0.004432	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	2909	 2910	 0.000312	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	2910	 5876	 9.7e-05	 0.029363	 0.0	 1166	 1166	 1166	 0.0	 0.0	 1	 -30.0	 30.0;
	2910	 5902	 9.7e-05	 0.029086	 0.0	 1178	 1178	 1178	 0.0	 0.0	 1	 -30.0	 30.0;
	2923	 2925	 0.002983	 0.117926	 0.0	 262	 262	 262	 0.976562	 0.0	 1	 -30.0	 30.0;
	2923	 2924	 0.00322	 0.115951	 0.0	 267	 267	 267	 0.976562	 0.0	 1	 -30.0	 30.0;
	2929	 2930	 0.00316	 0.12484	 0.0	 246	 246	 246	 1.001002	 0.0	 1	 -30.0	 30.0;
	2928	 2930	 0.003753	 0.128	 0.0	 240	 240	 240	 1.001002	 0.0	 1	 -30.0	 30.0;
	2928	 2930	 0.003556	 0.121877	 0.0	 252	 252	 252	 1.001002	 0.0	 1	 -30.0	 30.0;
	2937	 2938	 0.004306	 0.159605	 0.0	 195	 195	 195	 0.974655	 0.0	 1	 -30.0	 30.0;
	2937	 2938	 0.003022	 0.115358	 0.0	 269	 269	 269	 0.973708	 0.0	 1	 -30.0	 30.0;
	2939	 2940	 0.001385	 0.099162	 0.0	 318	 318	 318	 0.948768	 0.0	 1	 -30.0	 30.0;
	2943	 2945	 0.001857	 0.115358	 0.0	 268	 268	 268	 0.999001	 0.0	 1	 -30.0	 30.0;
	2943	 2944	 0.001857	 0.115358	 0.0	 268	 268	 268	 0.987165	 0.0	 1	 -30.0	 30.0;
	2951	 2952	 0.0164	 0.342222	 0.0	 92	 92	 92	 0.971817	 0.0	 1	 -30.0	 30.0;
	2959	 2961	 0.000325	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	2960	 5903	 0.000152	 -0.011357	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2959	 5925	 0.000145	 -0.00741	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2959	 5935	 0.000125	 -0.007756	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2961	 5903	 0.000187	 0.038435	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	2962	 5925	 0.000194	 0.034626	 0.0	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	2962	 5935	 0.000215	 0.034903	 0.0	 981	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	2964	 2965	 0.003121	 0.125037	 0.0	 247	 247	 247	 0.968054	 0.0	 1	 -30.0	 30.0;
	2964	 2965	 0.003793	 0.12642	 0.0	 244	 244	 244	 0.98912	 0.0	 1	 -30.0	 30.0;
	2977	 2978	 0.001936	 0.116741	 0.0	 263	 263	 263	 0.998004	 0.0	 1	 -30.0	 30.0;
	2977	 2978	 0.001936	 0.116741	 0.0	 263	 263	 263	 0.986189	 0.0	 1	 -30.0	 30.0;
	2987	 2988	 0.03225	 0.602419	 0.0	 58	 58	 58	 1.001	 0.0	 1	 -30.0	 30.0;
	2988	 2991	 0.00316	 0.125037	 0.0	 246	 246	 246	 1.013172	 0.0	 1	 -30.0	 30.0;
	2989	 2991	 0.001679	 0.121679	 0.0	 253	 253	 253	 1.008064	 0.0	 1	 -30.0	 30.0;
	2992	 2993	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.97561	 0.0	 1	 -30.0	 30.0;
	2992	 2993	 0.003398	 0.118716	 0.0	 257	 257	 257	 0.975606	 0.0	 1	 -30.0	 30.0;
	2992	 2993	 0.003852	 0.11121	 0.0	 274	 274	 274	 0.987167	 0.0	 1	 -30.0	 30.0;
	2994	 2995	 0.001719	 0.122074	 0.0	 253	 253	 253	 0.978474	 0.0	 1	 -30.0	 30.0;
	2994	 2995	 0.001758	 0.122469	 0.0	 252	 252	 252	 0.963394	 0.0	 1	 -30.0	 30.0;
	2994	 2995	 0.001758	 0.122469	 0.0	 252	 252	 252	 0.968054	 0.0	 1	 -30.0	 30.0;
	3001	 3002	 0.003338	 0.11121	 0.0	 278	 278	 278	 0.963394	 0.0	 1	 -30.0	 30.0;
	3001	 3002	 0.003121	 0.119704	 0.0	 258	 258	 258	 0.974664	 0.0	 1	 -30.0	 30.0;
	3002	 3003	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	3002	 3003	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	3008	 3009	 0.003081	 0.116543	 0.0	 263	 263	 263	 1.009082	 0.0	 1	 -30.0	 30.0;
	3008	 3009	 0.003101	 0.116148	 0.0	 263	 263	 263	 1.009082	 0.0	 1	 -30.0	 30.0;
	3023	 3024	 0.004543	 0.160395	 0.0	 193	 193	 193	 0.978474	 0.0	 1	 -30.0	 30.0;
	3023	 3024	 0.002825	 0.170469	 0.0	 181	 181	 181	 0.978474	 0.0	 1	 -30.0	 30.0;
	3024	 5877	 0.00045	 -0.014404	 0.0	 567.0	 567.0	 567.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3024	 5904	 0.000471	 -0.013712	 0.0	 581.0	 581.0	 581.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3024	 3025	 0.000803	 0.034903	 0.0	 581.0	 581.0	 581.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3025	 5877	 0.000381	 0.050623	 0.0	 567.0	 567.0	 567.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3025	 5904	 0.000367	 0.050554	 0.0	 581.0	 581.0	 581.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3056	 3057	 0.003911	 0.112	 0.0	 273	 273	 273	 0.985226	 0.0	 1	 -30.0	 30.0;
	3056	 3057	 0.003062	 0.117136	 0.0	 261	 261	 261	 0.985226	 0.0	 1	 -30.0	 30.0;
	3066	 3067	 0.004346	 0.165136	 0.0	 186	 186	 186	 1.001002	 0.0	 1	 -30.0	 30.0;
	3066	 3067	 0.00316	 0.126025	 0.0	 244	 244	 244	 1.001002	 0.0	 1	 -30.0	 30.0;
	3074	 3075	 0.000395	 0.130568	 0.0	 237	 237	 237	 0.946073	 0.0	 1	 -30.0	 30.0;
	3074	 3075	 0.000395	 0.130568	 0.0	 237	 237	 237	 0.956935	 0.0	 1	 -30.0	 30.0;
	3078	 3079	 0.003279	 0.113383	 0.0	 272	 272	 272	 0.98912	 0.0	 1	 -30.0	 30.0;
	3078	 3079	 0.003931	 0.12484	 0.0	 247	 247	 247	 0.98912	 0.0	 1	 -30.0	 30.0;
	3078	 3079	 0.003891	 0.11279	 0.0	 274	 274	 274	 0.98912	 0.0	 1	 -30.0	 30.0;
	3080	 3081	 0.00316	 0.118519	 0.0	 260	 260	 260	 0.976559	 0.0	 1	 -30.0	 30.0;
	3093	 3094	 0.003753	 0.129778	 0.0	 237	 237	 237	 0.989123	 0.0	 1	 -30.0	 30.0;
	3093	 3094	 0.004741	 0.16079	 0.0	 191	 191	 191	 0.967124	 0.0	 1	 -30.0	 30.0;
	3111	 3114	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3110	 3113	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3109	 3112	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3120	 3121	 0.003067	 0.132444	 0.0	 237	 237	 237	 1.118569	 0.0	 1	 -30.0	 30.0;
	3120	 3121	 0.003067	 0.132444	 0.0	 237	 237	 237	 1.118569	 0.0	 1	 -30.0	 30.0;
	3127	 3128	 0.001918	 0.160035	 0.0	 198	 198	 198	 0.994036	 0.0	 1	 -30.0	 30.0;
	3127	 3128	 0.001918	 0.160035	 0.0	 198	 198	 198	 0.985218	 0.0	 1	 -30.0	 30.0;
	3138	 3139	 0.003812	 0.122469	 0.0	 251	 251	 251	 0.987167	 0.0	 1	 -30.0	 30.0;
	3138	 3139	 0.003812	 0.122469	 0.0	 251	 251	 251	 0.987167	 0.0	 1	 -30.0	 30.0;
	3145	 3146	 0.003158	 0.158795	 0.0	 200	 200	 200	 0.948768	 0.0	 1	 -30.0	 30.0;
	3145	 3147	 0.003137	 0.159834	 0.0	 198	 198	 198	 0.939851	 0.0	 1	 -30.0	 30.0;
	3145	 3147	 0.001364	 0.112881	 0.0	 281	 281	 281	 0.939851	 0.0	 1	 -30.0	 30.0;
	3157	 3158	 0.001995	 0.126025	 0.0	 247	 247	 247	 0.926784	 0.0	 1	 -30.0	 30.0;
	3157	 3158	 0.003951	 0.125432	 0.0	 248	 248	 248	 0.937207	 0.0	 1	 -30.0	 30.0;
	3168	 3169	 0.003081	 0.110617	 0.0	 278	 278	 278	 1.02459	 0.0	 1	 -30.0	 30.0;
	3168	 3169	 0.001995	 0.12642	 0.0	 243	 243	 243	 1.0	 0.0	 1	 -30.0	 30.0;
	3172	 5878	 0.000235	 -0.004294	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3172	 5905	 0.000145	 -0.006233	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3173	 5878	 9e-05	 0.029086	 0.0	 1178	 1178	 1178	 0.0	 0.0	 1	 -30.0	 30.0;
	3173	 5905	 0.000194	 0.031233	 0.0	 1097	 1097	 1097	 0.0	 0.0	 1	 -30.0	 30.0;
	4570	 3192	 0.000119	 0.009086	 0.0	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3190	 3192	 0.003062	 0.116938	 0.0	 261	 261	 261	 0.973708	 0.0	 1	 -30.0	 30.0;
	3190	 3192	 0.00316	 0.109037	 0.0	 280	 280	 280	 0.974655	 0.0	 1	 -30.0	 30.0;
	3190	 3192	 0.003911	 0.111407	 0.0	 274	 274	 274	 0.973708	 0.0	 1	 -30.0	 30.0;
	3194	 3195	 0.003141	 0.115556	 0.0	 266	 266	 266	 1.012146	 0.0	 1	 -30.0	 30.0;
	3194	 3195	 0.003141	 0.115556	 0.0	 266	 266	 266	 1.012146	 0.0	 1	 -30.0	 30.0;
	3208	 3210	 0.003081	 0.116543	 0.0	 265	 265	 265	 1.02459	 0.0	 1	 -30.0	 30.0;
	3251	 3252	 0.001699	 0.099358	 0.0	 308	 308	 308	 0.971818	 0.0	 1	 -30.0	 30.0;
	3251	 3252	 0.001679	 0.098765	 0.0	 309	 309	 309	 0.971818	 0.0	 1	 -30.0	 30.0;
	3262	 3263	 0.00316	 0.116543	 0.0	 265	 265	 265	 1.02459	 0.0	 1	 -30.0	 30.0;
	3262	 3263	 0.004365	 0.167704	 0.0	 184	 184	 184	 1.023541	 0.0	 1	 -30.0	 30.0;
	3262	 3263	 0.00401	 0.111012	 0.0	 278	 278	 278	 1.038422	 0.0	 1	 -30.0	 30.0;
	3271	 3272	 0.007348	 0.24	 0.0	 129	 129	 129	 0.968054	 0.0	 1	 -30.0	 30.0;
	3271	 3272	 0.003714	 0.123062	 0.0	 251	 251	 251	 0.96432	 0.0	 1	 -30.0	 30.0;
	3275	 3277	 0.015873	 0.256992	 0.0	 134	 134	 134	 1.001	 0.0	 1	 -30.0	 30.0;
	3274	 3276	 0.015873	 0.256992	 0.0	 134	 134	 134	 1.001	 0.0	 1	 -30.0	 30.0;
	3273	 3279	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3283	 3284	 0.000198	 0.118716	 0.0	 262	 262	 262	 1.006036	 0.0	 1	 -30.0	 30.0;
	3290	 3291	 0.003417	 0.116543	 0.0	 265	 265	 265	 1.0	 0.0	 1	 -30.0	 30.0;
	3304	 3305	 0.003378	 0.112988	 0.0	 273	 273	 273	 1.0	 0.0	 1	 -30.0	 30.0;
	3304	 3305	 0.003832	 0.125037	 0.0	 247	 247	 247	 1.02459	 0.0	 1	 -30.0	 30.0;
	3304	 3305	 0.003911	 0.123457	 0.0	 250	 250	 250	 1.023541	 0.0	 1	 -30.0	 30.0;
	3314	 3316	 0.004049	 0.124049	 0.0	 246	 246	 246	 0.964324	 0.0	 1	 -30.0	 30.0;
	3314	 3316	 0.003358	 0.124247	 0.0	 246	 246	 246	 0.978473	 0.0	 1	 -30.0	 30.0;
	3315	 3316	 0.001956	 0.124642	 0.0	 245	 245	 245	 0.955109	 0.0	 1	 -30.0	 30.0;
	3328	 3329	 0.00397	 0.113383	 0.0	 271	 271	 271	 0.976559	 0.0	 1	 -30.0	 30.0;
	3328	 3329	 0.003951	 0.119111	 0.0	 258	 258	 258	 0.974657	 0.0	 1	 -30.0	 30.0;
	3327	 3329	 0.001975	 0.116938	 0.0	 263	 263	 263	 0.989123	 0.0	 1	 -30.0	 30.0;
	3337	 3338	 0.013857	 0.312421	 0.0	 95	 95	 95	 0.947864	 0.0	 1	 -30.0	 30.0;
	3337	 3338	 0.02066	 0.410935	 0.0	 72	 72	 72	 0.933703	 0.0	 1	 -30.0	 30.0;
	3338	 3339	 0.004543	 0.120691	 0.001	 255	 255	 255	 0.989123	 0.0	 1	 -30.0	 30.0;
	3338	 3339	 0.003951	 0.124247	 0.0	 248	 248	 248	 0.989123	 0.0	 1	 -30.0	 30.0;
	3342	 3343	 0.003556	 0.120296	 0.0	 256	 256	 256	 0.97561	 0.0	 1	 -30.0	 30.0;
	3342	 3343	 0.003081	 0.116346	 0.0	 264	 264	 264	 0.97561	 0.0	 1	 -30.0	 30.0;
	3356	 3357	 0.001798	 0.118716	 0.0	 260	 260	 260	 1.0	 0.0	 1	 -30.0	 30.0;
	3356	 3357	 0.001719	 0.122272	 0.0	 253	 253	 253	 0.98619	 0.0	 1	 -30.0	 30.0;
	3359	 3360	 0.00399	 0.11121	 0.0	 296	 296	 296	 1.037344	 0.0	 1	 -30.0	 30.0;
	3359	 3360	 0.00399	 0.11121	 0.0	 296	 296	 296	 1.037344	 0.0	 1	 -30.0	 30.0;
	3359	 3360	 0.003733	 0.123654	 0.0	 267	 267	 267	 1.037344	 0.0	 1	 -30.0	 30.0;
	3364	 3365	 0.001738	 0.100139	 0.0	 322	 322	 322	 0.956942	 0.0	 1	 -30.0	 30.0;
	3364	 3365	 0.001738	 0.100139	 0.0	 322	 322	 322	 0.939851	 0.0	 1	 -30.0	 30.0;
	3373	 3374	 0.004405	 0.165926	 0.0	 189	 189	 189	 0.98912	 0.0	 1	 -30.0	 30.0;
	3373	 3374	 0.004484	 0.166321	 0.0	 188	 188	 188	 1.0	 0.0	 1	 -30.0	 30.0;
	3373	 3374	 0.003674	 0.162568	 0.0	 193	 193	 193	 0.98912	 0.0	 1	 -30.0	 30.0;
	3389	 3390	 0.003556	 0.126815	 0.0	 247	 247	 247	 1.02459	 0.0	 1	 -30.0	 30.0;
	3389	 3390	 0.003556	 0.126815	 0.0	 247	 247	 247	 1.012146	 0.0	 1	 -30.0	 30.0;
	3392	 3393	 0.003279	 0.125235	 0.0	 247	 247	 247	 1.011122	 0.0	 1	 -30.0	 30.0;
	3392	 3393	 0.003773	 0.116543	 0.0	 265	 265	 265	 1.012146	 0.0	 1	 -30.0	 30.0;
	3392	 3393	 0.001141	 0.12083	 0.0	 256	 256	 256	 1.009082	 0.0	 1	 -30.0	 30.0;
	3425	 3426	 0.003047	 0.155125	 0.0	 204	 204	 204	 0.953289	 0.0	 1	 -30.0	 30.0;
	3425	 3426	 0.003186	 0.160873	 0.0	 197	 197	 197	 0.976558	 0.0	 1	 -30.0	 30.0;
	3434	 3435	 0.009556	 0.309778	 0.0	 102	 102	 102	 1.015229	 0.0	 1	 -30.0	 30.0;
	3434	 3435	 0.009911	 0.307556	 0.0	 102	 102	 102	 1.015229	 0.0	 1	 -30.0	 30.0;
	3463	 3464	 0.000284	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.046025	 0.0	 1	 -30.0	 30.0;
	3475	 3478	 0.001679	 0.122074	 0.0	 252	 252	 252	 0.953285	 0.0	 1	 -30.0	 30.0;
	3475	 3478	 0.001679	 0.122074	 0.0	 252	 252	 252	 0.96432	 0.0	 1	 -30.0	 30.0;
	3477	 3478	 0.002963	 0.085531	 0.0	 351.0	 351.0	 351.0	 1.004017	 0.0	 1	 -30.0	 30.0;
	3476	 3478	 0.003042	 0.117531	 0.0	 263	 263	 263	 0.992063	 0.0	 1	 -30.0	 30.0;
	1494	 3497	 0.003951	 0.029126	 0.0162	 398.0	 398.0	 398.0	 1.0	 10.82	 1	 -30.0	 30.0;
	3495	 3497	 0.003081	 0.125452	 0.0	 246	 246	 246	 0.974664	 0.0	 1	 -30.0	 30.0;
	3498	 3499	 0.03225	 0.602419	 0.0	 58	 58	 58	 1.001	 0.0	 1	 -30.0	 30.0;
	3501	 3502	 0.004148	 0.165531	 0.0	 186	 186	 186	 0.978477	 0.0	 1	 -30.0	 30.0;
	3507	 3509	 0.00187	 0.101731	 0.0	 310	 310	 310	 0.984249	 0.0	 1	 -30.0	 30.0;
	3507	 3508	 0.001773	 0.099862	 0.0	 316	 316	 316	 0.994033	 0.0	 1	 -30.0	 30.0;
	3510	 3511	 0.004662	 0.16	 0.0	 193	 193	 193	 0.98912	 0.0	 1	 -30.0	 30.0;
	3510	 3511	 0.00476	 0.166123	 0.0	 186	 186	 186	 0.968054	 0.0	 1	 -30.0	 30.0;
	3510	 3511	 0.004523	 0.160988	 0.0	 192	 192	 192	 0.968054	 0.0	 1	 -30.0	 30.0;
	3512	 3513	 0.005679	 0.116173	 0.0	 266	 266	 266	 1.001002	 0.0	 1	 -30.0	 30.0;
	3514	 3516	 0.00316	 0.125432	 0.0	 245	 245	 245	 1.0142	 0.0	 1	 -30.0	 30.0;
	3515	 3516	 0.00316	 0.125827	 0.0	 245	 245	 245	 1.0142	 0.0	 1	 -30.0	 30.0;
	3515	 3516	 0.001817	 0.118716	 0.0	 259	 259	 259	 1.001002	 0.0	 1	 -30.0	 30.0;
	3531	 3532	 0.00316	 0.112	 0.0	 277	 277	 277	 1.029866	 0.0	 1	 -30.0	 30.0;
	3531	 3532	 0.00316	 0.112	 0.0	 277	 277	 277	 1.029866	 0.0	 1	 -30.0	 30.0;
	3535	 3536	 0.004543	 0.163951	 0.0	 188	 188	 188	 1.0	 0.0	 1	 -30.0	 30.0;
	3538	 3539	 0.003556	 0.111407	 0.0	 274	 274	 274	 1.011122	 0.0	 1	 -30.0	 30.0;
	3538	 3539	 0.00401	 0.110222	 0.0	 277	 277	 277	 1.010101	 0.0	 1	 -30.0	 30.0;
	3538	 3539	 0.003338	 0.109037	 0.0	 280	 280	 280	 0.999001	 0.0	 1	 -30.0	 30.0;
	3548	 3549	 0.003891	 0.12484	 0.0	 246	 246	 246	 0.999001	 0.0	 1	 -30.0	 30.0;
	3548	 3549	 0.003674	 0.124642	 0.0	 247	 247	 247	 0.963394	 0.0	 1	 -30.0	 30.0;
	3552	 3553	 0.003556	 0.111605	 0.0	 277	 277	 277	 0.974664	 0.0	 1	 -30.0	 30.0;
	3552	 3553	 0.004405	 0.165926	 0.0	 186	 186	 186	 0.968059	 0.0	 1	 -30.0	 30.0;
	3552	 3553	 0.004227	 0.169481	 0.0	 182	 182	 182	 0.968054	 0.0	 1	 -30.0	 30.0;
	3554	 3555	 0.002311	 0.119506	 0.0	 258	 258	 258	 0.974664	 0.0	 1	 -30.0	 30.0;
	3554	 3556	 0.002311	 0.119506	 0.0	 258	 258	 258	 0.97371	 0.0	 1	 -30.0	 30.0;
	3557	 3558	 0.003595	 0.126815	 0.0	 243	 243	 243	 0.96432	 0.0	 1	 -30.0	 30.0;
	3565	 3566	 0.004326	 0.167506	 0.0	 185	 185	 185	 0.995022	 0.0	 1	 -30.0	 30.0;
	3565	 3566	 0.004583	 0.162963	 0.0	 190	 190	 190	 0.995022	 0.0	 1	 -30.0	 30.0;
	1492	 3574	 4.2e-05	 0.000339	 0.0061	 1184.0	 1184.0	 1184.0	 1.0	 -9.95	 1	 -30.0	 30.0;
	3571	 3572	 0.00316	 0.125037	 0.0	 246	 246	 246	 0.990101	 0.0	 1	 -30.0	 30.0;
	3572	 3574	 0.000679	 0.042867	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	3579	 3581	 0.002016	 0.239355	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	3580	 3582	 0.002016	 0.239355	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	3587	 3588	 0.004622	 0.227951	 0.0	 134	 134	 134	 0.926784	 0.0	 1	 -30.0	 30.0;
	3589	 3590	 0.00484	 0.165926	 0.0	 184	 184	 184	 0.968054	 0.0	 1	 -30.0	 30.0;
	3593	 3594	 0.00316	 0.113185	 0.0	 273	 273	 273	 1.002004	 0.0	 1	 -30.0	 30.0;
	3595	 3596	 0.001481	 0.128395	 0.0	 238	 238	 238	 0.96432	 0.0	 1	 -30.0	 30.0;
	3601	 3602	 0.003951	 0.12484	 0.0	 246	 246	 246	 1.001002	 0.0	 1	 -30.0	 30.0;
	3605	 5879	 0.000111	 -0.007895	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3607	 5906	 0.00027	 -0.005402	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3605	 5926	 0.000152	 -0.007964	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3606	 5936	 0.000152	 -0.007271	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3607	 3608	 0.000325	 0.027078	 0.0	 1171	 1171	 1171	 1.0	 0.0	 1	 -30.0	 30.0;
	3609	 5879	 0.000222	 0.03518	 0.0	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 5906	 5.5e-05	 0.032756	 0.0	 1046	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	3608	 5926	 0.000201	 0.034764	 0.0	 985	 985	 985	 0.0	 0.0	 1	 -30.0	 30.0;
	3608	 5936	 0.000194	 0.034141	 0.0	 1003	 1003	 1003	 0.0	 0.0	 1	 -30.0	 30.0;
	3612	 3613	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.974664	 0.0	 1	 -30.0	 30.0;
	3612	 3613	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.974664	 0.0	 1	 -30.0	 30.0;
	3612	 3613	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.963394	 0.0	 1	 -30.0	 30.0;
	3616	 3617	 0.000339	 0.027285	 0.0	 1156	 1156	 1156	 1.0	 0.0	 1	 -30.0	 30.0;
	3623	 3624	 0.002983	 0.117333	 0.0	 263	 263	 263	 0.973708	 0.0	 1	 -30.0	 30.0;
	3623	 3624	 0.004444	 0.159407	 0.0	 194	 194	 194	 0.965253	 0.0	 1	 -30.0	 30.0;
	3623	 3624	 0.003694	 0.116148	 0.0	 266	 266	 266	 0.985226	 0.0	 1	 -30.0	 30.0;
	3640	 3641	 0.003437	 0.122469	 0.0	 249	 249	 249	 0.999001	 0.0	 1	 -30.0	 30.0;
	3640	 3641	 0.003437	 0.122469	 0.0	 249	 249	 249	 1.011122	 0.0	 1	 -30.0	 30.0;
	3647	 3648	 0.003081	 0.116286	 0.0	 266	 266	 266	 1.040583	 0.0	 1	 -30.0	 30.0;
	3646	 3648	 0.003081	 0.116563	 0.0	 265	 265	 265	 1.040583	 0.0	 1	 -30.0	 30.0;
	3655	 3656	 0.005926	 0.114568	 0.0	 269	 269	 269	 0.974656	 0.0	 1	 -30.0	 30.0;
	3657	 3658	 0.001956	 0.117136	 0.0	 261	 261	 261	 0.97561	 0.0	 1	 -30.0	 30.0;
	3657	 3658	 0.001896	 0.11516	 0.0	 265	 265	 265	 0.942507	 0.0	 1	 -30.0	 30.0;
	3657	 3658	 0.001916	 0.116543	 0.0	 262	 262	 262	 0.96432	 0.0	 1	 -30.0	 30.0;
	3657	 3658	 0.000766	 0.116583	 0.0	 262	 262	 262	 0.95238	 0.0	 1	 -30.0	 30.0;
	3662	 3663	 0.00316	 0.112988	 0.0	 284	 284	 284	 1.002004	 0.0	 1	 -30.0	 30.0;
	3662	 3663	 0.003951	 0.112198	 0.0	 286	 286	 286	 0.975607	 0.0	 1	 -30.0	 30.0;
	3666	 3667	 0.003259	 0.109037	 0.0	 283	 283	 283	 0.983282	 0.0	 1	 -30.0	 30.0;
	3666	 3667	 0.00316	 0.112988	 0.0	 273	 273	 273	 0.992064	 0.0	 1	 -30.0	 30.0;
	3666	 3667	 0.0032	 0.114568	 0.0	 269	 269	 269	 0.974655	 0.0	 1	 -30.0	 30.0;
	3670	 3671	 0.001817	 0.118716	 0.0	 260	 260	 260	 1.012146	 0.0	 1	 -30.0	 30.0;
	3670	 3671	 0.001798	 0.118716	 0.0	 260	 260	 260	 1.0	 0.0	 1	 -30.0	 30.0;
	3670	 3671	 0.001798	 0.118716	 0.0	 260	 260	 260	 1.012146	 0.0	 1	 -30.0	 30.0;
	3696	 5880	 0.000215	 -0.00554	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3696	 3697	 0.000325	 0.027355	 0.0	 1153	 1153	 1153	 1.0	 0.0	 1	 -30.0	 30.0;
	3697	 5880	 0.000125	 0.033241	 0.0	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	3701	 3702	 0.003121	 0.125432	 0.0	 246	 246	 246	 0.98912	 0.0	 1	 -30.0	 30.0;
	3703	 3704	 0.00397	 0.124049	 0.0	 246	 246	 246	 0.931096	 0.0	 1	 -30.0	 30.0;
	3703	 3704	 0.003121	 0.125827	 0.0	 243	 243	 243	 0.931096	 0.0	 1	 -30.0	 30.0;
	3719	 3720	 0.007055	 0.203578	 0.0	 145	 145	 145	 0.914916	 0.0	 1	 -30.0	 30.0;
	3719	 3721	 0.004489	 0.280756	 0.0	 117	 117	 117	 0.860587	 0.0	 1	 -30.0	 30.0;
	3720	 3722	 0.004543	 0.120691	 0.0	 255	 255	 255	 0.94251	 0.0	 1	 -30.0	 30.0;
	3726	 3727	 0.00164	 0.090864	 0.0	 340	 340	 340	 0.950567	 0.0	 1	 -30.0	 30.0;
	4571	 3730	 0.000119	 0.009086	 0.0	 473.0	 473.0	 473.0	 1.0	 -6.32	 1	 -30.0	 30.0;
	3728	 3730	 0.003062	 0.117136	 0.0	 261	 261	 261	 0.987167	 0.0	 1	 -30.0	 30.0;
	3728	 3730	 0.003852	 0.123654	 0.0	 247	 247	 247	 0.987167	 0.0	 1	 -30.0	 30.0;
	3728	 3730	 0.003615	 0.124444	 0.0	 245	 245	 245	 0.975606	 0.0	 1	 -30.0	 30.0;
	3728	 3730	 0.003615	 0.124444	 0.0	 245	 245	 245	 0.987165	 0.0	 1	 -30.0	 30.0;
	3734	 3735	 0.00484	 0.162568	 0.0	 188	 188	 188	 0.968054	 0.0	 1	 -30.0	 30.0;
	3737	 3738	 0.003062	 0.116741	 0.0	 264	 264	 264	 0.985226	 0.0	 1	 -30.0	 30.0;
	3737	 3738	 0.003062	 0.116741	 0.0	 264	 264	 264	 0.985226	 0.0	 1	 -30.0	 30.0;
	3743	 3744	 0.000319	 0.024307	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3743	 3744	 0.000339	 0.025	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3743	 3744	 0.000325	 0.024584	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3750	 3751	 0.003832	 0.121284	 0.0	 254	 254	 254	 1.0	 0.0	 1	 -30.0	 30.0;
	3750	 3751	 0.004464	 0.156049	 0.0	 197	 197	 197	 1.0	 0.0	 1	 -30.0	 30.0;
	3755	 3756	 0.003081	 0.116286	 0.0	 266	 266	 266	 0.985218	 0.0	 1	 -30.0	 30.0;
	3755	 3756	 0.003081	 0.116563	 0.0	 265	 265	 265	 0.987172	 0.0	 1	 -30.0	 30.0;
	3755	 3756	 0.003081	 0.114983	 0.0	 269	 269	 269	 0.980388	 0.0	 1	 -30.0	 30.0;
	3765	 3766	 0.001766	 0.10097	 0.0	 314	 314	 314	 0.956942	 0.0	 1	 -30.0	 30.0;
	3765	 3766	 0.001787	 0.100208	 0.0	 317	 317	 317	 0.956942	 0.0	 1	 -30.0	 30.0;
	3769	 3773	 0.00158	 0.124049	 0.0	 246	 246	 246	 0.957854	 0.0	 1	 -30.0	 30.0;
	3770	 3772	 0.00158	 0.124049	 0.0	 246	 246	 246	 0.957854	 0.0	 1	 -30.0	 30.0;
	3769	 3773	 0.00158	 0.124049	 0.0	 246	 246	 246	 0.957854	 0.0	 1	 -30.0	 30.0;
	3768	 3771	 0.00158	 0.124049	 0.0	 246	 246	 246	 0.957854	 0.0	 1	 -30.0	 30.0;
	3782	 3784	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	3781	 3784	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	3780	 3783	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	3801	 3802	 0.001837	 0.11516	 0.0	 268	 268	 268	 0.953285	 0.0	 1	 -30.0	 30.0;
	3801	 3802	 0.001817	 0.11516	 0.0	 268	 268	 268	 0.96432	 0.0	 1	 -30.0	 30.0;
	3802	 3803	 0.000817	 0.04349	 0.0	 608.0	 608.0	 608.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3802	 3803	 0.000319	 0.027978	 0.0	 1134	 1134	 1134	 1.005027	 0.0	 1	 -30.0	 30.0;
	3810	 3813	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3809	 3812	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3808	 3811	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3822	 3824	 0.000395	 0.13037	 0.0	 237	 237	 237	 0.946073	 0.0	 1	 -30.0	 30.0;
	3823	 3824	 0.000395	 0.127407	 0.0	 243	 243	 243	 0.93633	 0.0	 1	 -30.0	 30.0;
	3832	 3833	 0.003951	 0.124247	 0.0	 248	 248	 248	 0.989123	 0.0	 1	 -30.0	 30.0;
	3842	 3843	 0.00478	 0.163358	 0.0	 189	 189	 189	 0.98912	 0.0	 1	 -30.0	 30.0;
	3842	 3843	 0.004286	 0.164346	 0.0	 188	 188	 188	 0.968054	 0.0	 1	 -30.0	 30.0;
	3846	 3848	 0.00316	 0.126025	 0.0	 244	 244	 244	 1.001002	 0.0	 1	 -30.0	 30.0;
	3847	 3848	 0.00316	 0.124049	 0.0	 248	 248	 248	 1.0142	 0.0	 1	 -30.0	 30.0;
	3865	 3866	 0.003358	 0.124049	 0.0	 246	 246	 246	 0.974664	 0.0	 1	 -30.0	 30.0;
	3865	 3866	 0.003911	 0.111407	 0.0	 274	 274	 274	 0.974664	 0.0	 1	 -30.0	 30.0;
	3870	 3871	 0.004346	 0.16158	 0.0	 191	 191	 191	 0.978474	 0.0	 1	 -30.0	 30.0;
	3870	 3871	 0.004365	 0.167901	 0.0	 184	 184	 184	 0.968054	 0.0	 1	 -30.0	 30.0;
	3870	 3871	 0.004642	 0.164741	 0.0	 188	 188	 188	 0.94697	 0.0	 1	 -30.0	 30.0;
	3872	 3873	 0.003793	 0.119309	 0.0	 258	 258	 258	 0.931966	 0.0	 1	 -30.0	 30.0;
	3872	 5927	 0.001481	 0.00316	 0.0	 482.0	 482.0	 482.0	 0.926784	 0.0	 1	 -30.0	 30.0;
	3873	 5927	 0.001956	 0.108444	 0.0	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	3880	 3881	 0.002099	 0.116049	 0.0	 261	 261	 261	 0.999001	 0.0	 1	 -30.0	 30.0;
	3889	 3890	 0.003714	 0.119506	 0.0	 258	 258	 258	 0.98619	 0.0	 1	 -30.0	 30.0;
	3892	 3893	 0.001159	 0.118874	 0.0	 257	 257	 257	 0.975614	 0.0	 1	 -30.0	 30.0;
	3892	 3893	 0.001254	 0.119427	 0.0	 256	 256	 256	 0.975614	 0.0	 1	 -30.0	 30.0;
	3898	 3899	 0.000713	 0.048546	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	3897	 3899	 0.000332	 0.026939	 0.0	 1180	 1180	 1180	 1.0	 0.0	 1	 -30.0	 30.0;
	3897	 3899	 0.000319	 0.026385	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3908	 3909	 0.003635	 0.124444	 0.0	 248	 248	 248	 1.024591	 0.0	 1	 -30.0	 30.0;
	3908	 3909	 0.002983	 0.12484	 0.0	 247	 247	 247	 1.010101	 0.0	 1	 -30.0	 30.0;
	3908	 3909	 0.003674	 0.129778	 0.0	 238	 238	 238	 0.978474	 0.0	 1	 -30.0	 30.0;
	3915	 3917	 0.003556	 0.126815	 0.0	 247	 247	 247	 1.064963	 0.0	 1	 -30.0	 30.0;
	3916	 3917	 0.003635	 0.120691	 0.0	 259	 259	 259	 1.02459	 0.0	 1	 -30.0	 30.0;
	3919	 3920	 0.005911	 0.119689	 0.0	 253	 253	 253	 0.976562	 0.0	 1	 -30.0	 30.0;
	3922	 3923	 0.00164	 0.116938	 0.0	 261	 261	 261	 0.98912	 0.0	 1	 -30.0	 30.0;
	3922	 3923	 0.001699	 0.122212	 0.0	 250	 250	 250	 0.987167	 0.0	 1	 -30.0	 30.0;
	3928	 3929	 0.004286	 0.165333	 0.0	 189	 189	 189	 0.968054	 0.0	 1	 -30.0	 30.0;
	3929	 5881	 0.000519	 -0.00831	 0.0	 600.0	 600.0	 600.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	3929	 5907	 0.000471	 -0.008033	 0.0	 600.0	 600.0	 600.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	3930	 5881	 0.000277	 0.047922	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3930	 5907	 0.00036	 0.049584	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3934	 3935	 0.000796	 0.041413	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	3934	 3935	 0.000831	 0.039681	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	3961	 3962	 0.002016	 0.079113	 0.0	 438	 438	 438	 1.0	 0.0	 1	 -30.0	 30.0;
	3960	 3963	 0.001975	 0.079012	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	3970	 3972	 0.002963	 0.118321	 0.0	 261	 261	 261	 0.985226	 0.0	 1	 -30.0	 30.0;
	3971	 3972	 0.003595	 0.123654	 0.0	 250	 250	 250	 0.985226	 0.0	 1	 -30.0	 30.0;
	3996	 3997	 0.00316	 0.11437	 0.0	 270	 270	 270	 0.974655	 0.0	 1	 -30.0	 30.0;
	3996	 3997	 0.003101	 0.116543	 0.0	 265	 265	 265	 0.970872	 0.0	 1	 -30.0	 30.0;
	4000	 4001	 0.001995	 0.118123	 0.0	 261	 261	 261	 0.999001	 0.0	 1	 -30.0	 30.0;
	4000	 4001	 0.002035	 0.116741	 0.0	 265	 265	 265	 0.999001	 0.0	 1	 -30.0	 30.0;
	4002	 4003	 0.004346	 0.164543	 0.0	 187	 187	 187	 1.037345	 0.0	 1	 -30.0	 30.0;
	4009	 4010	 0.00399	 0.143407	 0.0	 215	 215	 215	 0.97561	 0.0	 1	 -30.0	 30.0;
	4009	 4010	 0.003872	 0.146173	 0.0	 211	 211	 211	 0.97561	 0.0	 1	 -30.0	 30.0;
	4018	 4019	 0.003773	 0.111802	 0.0	 276	 276	 276	 0.94697	 0.0	 1	 -30.0	 30.0;
	4018	 4019	 0.00399	 0.112988	 0.0	 273	 273	 273	 0.98912	 0.0	 1	 -30.0	 30.0;
	4019	 4020	 0.000332	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4019	 4020	 0.000332	 0.024792	 0.0	 1182.0	 1182.0	 1182.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4028	 4029	 0.004227	 0.169481	 0.0	 182	 182	 182	 0.956938	 0.0	 1	 -30.0	 30.0;
	4037	 4038	 0.004938	 0.159012	 0.0	 197	 197	 197	 0.912407	 0.0	 1	 -30.0	 30.0;
	4040	 5882	 0.000118	 -0.005956	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4039	 4041	 0.000325	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4041	 5882	 0.000187	 0.032964	 0.0	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 4056	 0.004346	 0.158025	 0.0	 196	 196	 196	 1.013172	 0.0	 1	 -30.0	 30.0;
	4059	 4060	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4069	 5883	 0.001284	 0.126973	 0.0	 276	 276	 276	 0.956935	 0.0	 1	 -30.0	 30.0;
	4068	 5908	 0.001284	 0.126973	 0.0	 276	 276	 276	 0.964324	 0.0	 1	 -30.0	 30.0;
	4070	 5883	 0.00081	 -0.007802	 0.0	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 5908	 0.00081	 -0.007802	 0.0	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4080	 4081	 0.003951	 0.115951	 0.0	 266	 266	 266	 1.016261	 0.0	 1	 -30.0	 30.0;
	4080	 4081	 0.003951	 0.117965	 0.0	 262	 262	 262	 1.016261	 0.0	 1	 -30.0	 30.0;
	4084	 4085	 0.001975	 0.126025	 0.0	 244	 244	 244	 1.022496	 0.0	 1	 -30.0	 30.0;
	4086	 4087	 0.003595	 0.123062	 0.0	 250	 250	 250	 0.931965	 0.0	 1	 -30.0	 30.0;
	4093	 4094	 0.003951	 0.125235	 0.0	 244	 244	 244	 0.987165	 0.0	 1	 -30.0	 30.0;
	4093	 4094	 0.001975	 0.126025	 0.0	 242	 242	 242	 0.987165	 0.0	 1	 -30.0	 30.0;
	5884	 4097	 0.000277	 -0.00464	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4097	 4098	 0.000339	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4098	 5884	 6.2e-05	 0.029571	 0.0	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 4103	 0.00316	 0.124642	 0.0	 247	 247	 247	 0.976559	 0.0	 1	 -30.0	 30.0;
	4102	 4103	 0.004741	 0.161975	 0.0	 190	 190	 190	 0.978477	 0.0	 1	 -30.0	 30.0;
	4110	 4111	 0.003081	 0.115358	 0.0	 271	 271	 271	 1.0	 0.0	 1	 -30.0	 30.0;
	4110	 4111	 0.003556	 0.122864	 0.0	 255	 255	 255	 1.0	 0.0	 1	 -30.0	 30.0;
	4112	 4113	 0.005309	 0.110123	 0.0	 291	 291	 291	 1.001002	 0.0	 1	 -30.0	 30.0;
	4113	 4114	 0.002015	 0.158657	 0.0	 203	 203	 203	 1.018331	 0.0	 1	 -30.0	 30.0;
	4125	 4126	 0.001177	 0.042382	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5928	 4125	 0.000499	 -0.006925	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5937	 4125	 0.000353	 -0.010873	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4126	 5928	 0.000201	 0.055402	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 5937	 0.000429	 0.05374	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 4134	 0.003062	 0.116938	 0.0	 261	 261	 261	 0.973708	 0.0	 1	 -30.0	 30.0;
	4133	 4134	 0.00316	 0.116741	 0.0	 262	 262	 262	 0.985226	 0.0	 1	 -30.0	 30.0;
	4133	 4134	 0.003733	 0.115753	 0.0	 265	 265	 265	 0.985226	 0.0	 1	 -30.0	 30.0;
	4133	 4134	 0.003931	 0.111802	 0.0	 274	 274	 274	 0.985226	 0.0	 1	 -30.0	 30.0;
	4135	 4136	 0.004484	 0.168494	 0.0	 181	 181	 181	 0.968054	 0.0	 1	 -30.0	 30.0;
	4135	 4136	 0.004484	 0.168494	 0.0	 181	 181	 181	 0.978474	 0.0	 1	 -30.0	 30.0;
	4140	 4141	 0.003951	 0.12563	 0.0	 245	 245	 245	 1.0142	 0.0	 1	 -30.0	 30.0;
	4139	 4141	 0.003951	 0.118123	 0.0	 261	 261	 261	 1.0142	 0.0	 1	 -30.0	 30.0;
	4139	 4141	 0.00316	 0.12484	 0.0	 247	 247	 247	 1.026695	 0.0	 1	 -30.0	 30.0;
	4156	 4157	 0.003081	 0.116543	 0.0	 275	 275	 275	 1.034126	 0.0	 1	 -30.0	 30.0;
	4156	 4157	 0.003022	 0.116938	 0.0	 274	 274	 274	 1.034126	 0.0	 1	 -30.0	 30.0;
	4162	 4163	 0.001778	 0.098765	 0.0	 309	 309	 309	 0.939847	 0.0	 1	 -30.0	 30.0;
	4164	 4165	 0.001333	 0.002667	 0.0	 10522	 10522	 10522	 0.964319	 0.0	 1	 -30.0	 30.0;
	4173	 4174	 0.001837	 0.114765	 0.0	 266	 266	 266	 0.986189	 0.0	 1	 -30.0	 30.0;
	4173	 4174	 0.001857	 0.114963	 0.0	 266	 266	 266	 0.96432	 0.0	 1	 -30.0	 30.0;
	4199	 4201	 0.003694	 0.123852	 0.0	 248	 248	 248	 0.963394	 0.0	 1	 -30.0	 30.0;
	4199	 4201	 0.004543	 0.16	 0.0	 192	 192	 192	 0.956938	 0.0	 1	 -30.0	 30.0;
	4202	 4203	 0.003358	 0.11121	 0.0	 275	 275	 275	 0.999001	 0.0	 1	 -30.0	 30.0;
	4202	 4203	 0.003812	 0.130963	 0.0	 233	 233	 233	 1.0	 0.0	 1	 -30.0	 30.0;
	4208	 4210	 0.003042	 0.111407	 0.0	 278	 278	 278	 0.985222	 0.0	 1	 -30.0	 30.0;
	4209	 4210	 0.005965	 0.11121	 0.0	 278	 278	 278	 0.953289	 0.0	 1	 -30.0	 30.0;
	4209	 4210	 0.002963	 0.110815	 0.0	 280	 280	 280	 0.97561	 0.0	 1	 -30.0	 30.0;
	4208	 4210	 0.00397	 0.111605	 0.0	 278	 278	 278	 0.942507	 0.0	 1	 -30.0	 30.0;
	4210	 4211	 0.000291	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4216	 4213	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4218	 4219	 0.003121	 0.114765	 0.0	 269	 269	 269	 1.002004	 0.0	 1	 -30.0	 30.0;
	4217	 4219	 0.00316	 0.115358	 0.0	 268	 268	 268	 1.002004	 0.0	 1	 -30.0	 30.0;
	4234	 4235	 0.001758	 0.100543	 0.0	 307	 307	 307	 0.939846	 0.0	 1	 -30.0	 30.0;
	4240	 4262	 0.000171	 0.000313	 0.0003	 82782	 82782	 82782	 1.0	 6.48	 1	 -30.0	 30.0;
	4242	 4243	 0.003891	 0.112198	 0.0	 272	 272	 272	 0.999001	 0.0	 1	 -30.0	 30.0;
	4242	 4243	 0.003556	 0.124642	 0.0	 245	 245	 245	 0.999001	 0.0	 1	 -30.0	 30.0;
	4245	 4246	 0.003931	 0.125373	 0.0	 244	 244	 244	 1.012146	 0.0	 1	 -30.0	 30.0;
	4247	 4248	 0.001699	 0.122469	 0.0	 252	 252	 252	 1.0	 0.0	 1	 -30.0	 30.0;
	4247	 4248	 0.001679	 0.122469	 0.0	 252	 252	 252	 1.012146	 0.0	 1	 -30.0	 30.0;
	4266	 5885	 0.013911	 0.133333	 0.0	 258	 258	 258	 1.0	 0.0	 1	 -30.0	 30.0;
	4267	 5885	 0.008933	 0.147111	 0.0	 235	 235	 235	 1.0	 0.0	 1	 -30.0	 30.0;
	4268	 5885	 0.0036	 0.008933	 0.0	 3573	 3573	 3573	 0.0	 0.0	 1	 -30.0	 30.0;
	4282	 4283	 0.004267	 0.238617	 0.0	 138	 138	 138	 1.035197	 0.0	 1	 -30.0	 30.0;
	4281	 4283	 0.004642	 0.22321	 0.0	 139	 139	 139	 0.956938	 0.0	 1	 -30.0	 30.0;
	4281	 4283	 0.004523	 0.216296	 0.0	 143	 143	 143	 0.956938	 0.0	 1	 -30.0	 30.0;
	4281	 4283	 0.00484	 0.237037	 0.0	 131	 131	 131	 0.968054	 0.0	 1	 -30.0	 30.0;
	5944	 4283	 0.000457	 -0.005194	 0.0	 557.0	 557.0	 557.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4283	 4284	 0.000796	 0.048199	 0.0	 557.0	 557.0	 557.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4284	 5944	 0.000242	 0.047438	 0.0	 557.0	 557.0	 557.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4285	 4286	 0.003911	 0.111407	 0.0	 274	 274	 274	 0.984254	 0.0	 1	 -30.0	 30.0;
	4295	 4296	 0.002331	 0.132741	 0.0	 234	 234	 234	 0.973708	 0.0	 1	 -30.0	 30.0;
	4302	 4303	 0.002015	 0.106667	 0.0	 286	 286	 286	 0.971818	 0.0	 1	 -30.0	 30.0;
	4302	 4304	 0.001363	 0.098528	 0.0	 310	 310	 310	 0.963387	 0.0	 1	 -30.0	 30.0;
	4315	 4316	 0.004741	 0.160593	 0.0	 192	 192	 192	 0.946073	 0.0	 1	 -30.0	 30.0;
	4321	 4324	 0.003338	 0.109037	 0.0	 283	 283	 283	 0.963394	 0.0	 1	 -30.0	 30.0;
	4322	 4324	 0.003042	 0.118519	 0.0	 261	 261	 261	 0.953289	 0.0	 1	 -30.0	 30.0;
	4322	 4323	 0.003694	 0.111407	 0.0	 277	 277	 277	 0.952382	 0.0	 1	 -30.0	 30.0;
	4321	 4323	 0.004089	 0.12484	 0.0	 247	 247	 247	 0.96432	 0.0	 1	 -30.0	 30.0;
	4333	 4335	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4332	 4335	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4331	 4335	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4334	 4335	 0.00316	 0.118321	 0.0	 258	 258	 258	 0.987167	 0.0	 1	 -30.0	 30.0;
	4334	 4335	 0.00324	 0.116543	 0.0	 262	 262	 262	 0.981351	 0.0	 1	 -30.0	 30.0;
	4338	 4339	 0.003753	 0.122074	 0.0	 253	 253	 253	 0.97561	 0.0	 1	 -30.0	 30.0;
	4338	 4339	 0.00399	 0.109235	 0.0	 283	 283	 283	 0.953289	 0.0	 1	 -30.0	 30.0;
	4338	 4339	 0.00399	 0.11121	 0.0	 278	 278	 278	 0.97561	 0.0	 1	 -30.0	 30.0;
	4347	 4345	 7.9e-05	 0.000836	 0.0	 40897	 40897	 40897	 1.0	 0.0	 1	 -30.0	 30.0;
	4380	 4381	 0.00318	 0.117333	 0.0	 263	 263	 263	 0.97561	 0.0	 1	 -30.0	 30.0;
	4380	 4381	 0.003338	 0.122469	 0.0	 252	 252	 252	 0.97561	 0.0	 1	 -30.0	 30.0;
	4382	 4384	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4389	 4390	 0.003595	 0.118716	 0.0	 260	 260	 260	 0.97561	 0.0	 1	 -30.0	 30.0;
	4389	 4390	 0.003753	 0.119309	 0.0	 259	 259	 259	 0.968054	 0.0	 1	 -30.0	 30.0;
	1493	 4398	 0.055185	 0.114444	 0.0052	 239	 239	 239	 1.0	 -0.9	 1	 -30.0	 30.0;
	4412	 4414	 0.003575	 0.123457	 0.0	 250	 250	 250	 0.997009	 0.0	 1	 -30.0	 30.0;
	4413	 4414	 0.003022	 0.117728	 0.0	 262	 262	 262	 0.985226	 0.0	 1	 -30.0	 30.0;
	4434	 4436	 0.003951	 0.12484	 0.0	 245	 245	 245	 0.96432	 0.0	 1	 -30.0	 30.0;
	4434	 4436	 0.003951	 0.12484	 0.0	 245	 245	 245	 0.968059	 0.0	 1	 -30.0	 30.0;
	4435	 4436	 0.003556	 0.127407	 0.0	 242	 242	 242	 1.02459	 0.0	 1	 -30.0	 30.0;
	4447	 4449	 0.003141	 0.117136	 0.0	 264	 264	 264	 0.963394	 0.0	 1	 -30.0	 30.0;
	4452	 4453	 0.003319	 0.108444	 0.0	 285	 285	 285	 0.978474	 0.0	 1	 -30.0	 30.0;
	4452	 4453	 0.003753	 0.124642	 0.0	 248	 248	 248	 0.968054	 0.0	 1	 -30.0	 30.0;
	4452	 4453	 0.003081	 0.116346	 0.0	 265	 265	 265	 0.978474	 0.0	 1	 -30.0	 30.0;
	4457	 4458	 0.004938	 0.161383	 0.0	 191	 191	 191	 1.013172	 0.0	 1	 -30.0	 30.0;
	4457	 4458	 0.004938	 0.163951	 0.0	 188	 188	 188	 1.001002	 0.0	 1	 -30.0	 30.0;
	4456	 4458	 0.004346	 0.118914	 0.0	 259	 259	 259	 0.989123	 0.0	 1	 -30.0	 30.0;
	4467	 4468	 0.004286	 0.164938	 0.0	 187	 187	 187	 0.968054	 0.0	 1	 -30.0	 30.0;
	4467	 4468	 0.007368	 0.229136	 0.0	 135	 135	 135	 0.956938	 0.0	 1	 -30.0	 30.0;
	4470	 4475	 0.012598	 0.428319	 0.0	 81	 81	 81	 1.001	 0.0	 1	 -30.0	 30.0;
	4474	 4479	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	4473	 4478	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	4472	 4477	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	4471	 4476	 0.001857	 0.114963	 0.0	 299	 299	 299	 1.0	 0.0	 1	 -30.0	 30.0;
	4493	 4495	 0.004356	 0.137467	 0.0	 230	 230	 230	 1.036269	 0.0	 1	 -30.0	 30.0;
	4494	 4495	 0.008711	 0.1592	 0.0	 198	 198	 198	 1.036269	 0.0	 1	 -30.0	 30.0;
	4496	 4497	 0.019652	 0.553288	 0.0	 63	 63	 63	 1.0	 0.0	 1	 -30.0	 30.0;
	4503	 4504	 0.002016	 0.079113	 0.0	 438	 438	 438	 1.0	 0.0	 1	 -30.0	 30.0;
	4508	 4509	 0.00397	 0.118123	 0.0	 261	 261	 261	 1.02459	 0.0	 1	 -30.0	 30.0;
	4508	 4509	 0.003654	 0.146765	 0.0	 211	 211	 211	 1.012146	 0.0	 1	 -30.0	 30.0;
	4518	 4520	 0.003951	 0.12484	 0.0	 245	 245	 245	 0.978474	 0.0	 1	 -30.0	 30.0;
	4519	 4520	 0.00164	 0.118519	 0.0	 259	 259	 259	 1.007049	 0.0	 1	 -30.0	 30.0;
	4526	 4527	 0.000783	 0.042936	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4526	 4527	 0.000776	 0.043075	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4530	 4531	 0.068027	 0.942303	 0.0	 37	 37	 37	 0.550361	 0.0	 1	 -30.0	 30.0;
	4535	 4536	 0.021975	 0.446914	 0.0	 68	 68	 68	 1.027749	 0.0	 1	 -30.0	 30.0;
	4535	 4536	 0.021975	 0.446914	 0.0	 68	 68	 68	 1.027749	 0.0	 1	 -30.0	 30.0;
	4535	 4537	 0.003259	 0.119506	 0.0	 258	 258	 258	 0.978474	 0.0	 1	 -30.0	 30.0;
	4542	 5886	 0.000159	 -0.006025	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4542	 5909	 0.000229	 -0.004571	 0.0	 1174.0	 1174.0	 1174.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4542	 4543	 0.000332	 0.025623	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4543	 5886	 0.000173	 0.031163	 0.0	 1099	 1099	 1099	 0.0	 0.0	 1	 -30.0	 30.0;
	4543	 5909	 9e-05	 0.029363	 0.0	 1166	 1166	 1166	 0.0	 0.0	 1	 -30.0	 30.0;
	4550	 4551	 0.001222	 0.132	 0.0	 238	 238	 238	 0.971818	 0.0	 1	 -30.0	 30.0;
	4550	 4552	 0.003911	 0.12484	 0.0	 247	 247	 247	 0.978474	 0.0	 1	 -30.0	 30.0;
	4551	 4552	 0.003186	 0.137758	 0.0	 229	 229	 229	 1.0	 0.0	 1	 -30.0	 30.0;
	4564	 4565	 0.000996	 0.10831	 0.0	 293	 293	 293	 0.984249	 0.0	 1	 -30.0	 30.0;
	4567	 4569	 0.000686	 0.047922	 0.0	 606.0	 606.0	 606.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4568	 4569	 0.000325	 0.027493	 0.0	 1148	 1148	 1148	 1.0	 0.0	 1	 -30.0	 30.0;
	4568	 4569	 0.000325	 0.027493	 0.0	 1148	 1148	 1148	 1.0	 0.0	 1	 -30.0	 30.0;
	4587	 4589	 0.001835	 0.101524	 0.0	 312	 312	 312	 1.013171	 0.0	 1	 -30.0	 30.0;
	4587	 4588	 0.001828	 0.102078	 0.0	 311	 311	 311	 1.003009	 0.0	 1	 -30.0	 30.0;
	4590	 4591	 0.00397	 0.125235	 0.0	 244	 244	 244	 1.02459	 0.0	 1	 -30.0	 30.0;
	4590	 4591	 0.00397	 0.125235	 0.0	 244	 244	 244	 1.02459	 0.0	 1	 -30.0	 30.0;
	4593	 4594	 0.000319	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	4593	 4595	 0.000339	 0.029778	 0.0	 1065	 1065	 1065	 1.0	 0.0	 1	 -30.0	 30.0;
	4602	 4603	 0.001244	 0.137877	 0.0	 222	 222	 222	 0.952378	 0.0	 1	 -30.0	 30.0;
	4602	 4603	 0.000731	 0.153284	 0.0	 199	 199	 199	 0.963387	 0.0	 1	 -30.0	 30.0;
	4602	 4603	 0.001244	 0.137284	 0.0	 223	 223	 223	 0.96432	 0.0	 1	 -30.0	 30.0;
	4610	 4611	 0.003081	 0.115556	 0.0	 271	 271	 271	 0.987167	 0.0	 1	 -30.0	 30.0;
	4610	 4611	 0.003081	 0.115556	 0.0	 271	 271	 271	 0.987167	 0.0	 1	 -30.0	 30.0;
	4631	 4633	 0.001752	 0.102285	 0.0	 310	 310	 310	 0.984249	 0.0	 1	 -30.0	 30.0;
	4631	 4632	 0.001752	 0.102285	 0.0	 310	 310	 310	 0.984249	 0.0	 1	 -30.0	 30.0;
	4641	 4642	 0.003068	 0.155609	 0.0	 204	 204	 204	 0.984249	 0.0	 1	 -30.0	 30.0;
	4641	 4642	 0.001364	 0.100069	 0.0	 317	 317	 317	 0.966188	 0.0	 1	 -30.0	 30.0;
	4641	 4642	 0.003061	 0.156163	 0.0	 203	 203	 203	 0.974656	 0.0	 1	 -30.0	 30.0;
	4644	 4646	 0.003931	 0.124247	 0.0	 249	 249	 249	 0.96432	 0.0	 1	 -30.0	 30.0;
	4644	 4645	 0.003101	 0.124642	 0.0	 248	 248	 248	 0.96432	 0.0	 1	 -30.0	 30.0;
	4655	 5929	 0.00018	 -0.007687	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4655	 5938	 0.000125	 -0.007618	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4656	 5929	 0.000166	 0.035111	 0.0	 976	 976	 976	 0.0	 0.0	 1	 -30.0	 30.0;
	4656	 5938	 0.000201	 0.034834	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	4666	 4667	 0.002016	 0.004031	 0.0	 7637	 7637	 7637	 1.0	 0.0	 1	 -30.0	 30.0;
	4668	 4669	 0.001857	 0.121086	 0.0	 252	 252	 252	 0.987167	 0.0	 1	 -30.0	 30.0;
	4668	 4669	 0.003773	 0.122667	 0.0	 249	 249	 249	 0.974664	 0.0	 1	 -30.0	 30.0;
	4668	 4669	 0.001857	 0.121086	 0.0	 252	 252	 252	 0.987167	 0.0	 1	 -30.0	 30.0;
	4669	 4670	 6.2e-05	 0.031787	 0.0	 993	 993	 993	 1.0	 0.0	 1	 -30.0	 30.0;
	4669	 4670	 6.2e-05	 0.031856	 0.0	 991	 991	 991	 1.0	 0.0	 1	 -30.0	 30.0;
	4674	 4676	 0.003556	 0.112	 0.0	 273	 273	 273	 0.963394	 0.0	 1	 -30.0	 30.0;
	4674	 4676	 0.003556	 0.118519	 0.0	 258	 258	 258	 0.963394	 0.0	 1	 -30.0	 30.0;
	4674	 4676	 0.003615	 0.113185	 0.0	 270	 270	 270	 0.963394	 0.0	 1	 -30.0	 30.0;
	4674	 4676	 0.003674	 0.123062	 0.0	 248	 248	 248	 0.96432	 0.0	 1	 -30.0	 30.0;
	4681	 4682	 0.00316	 0.125432	 0.0	 246	 246	 246	 1.040584	 0.0	 1	 -30.0	 30.0;
	4681	 4682	 0.003951	 0.112988	 0.0	 273	 273	 273	 1.040584	 0.0	 1	 -30.0	 30.0;
	4705	 4706	 0.000208	 0.016413	 0.0	 1769.0	 1769.0	 1769.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	4704	 4706	 0.000208	 0.014751	 0.0	 1746.0	 1746.0	 1746.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	4703	 4706	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	4702	 4706	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	4701	 4706	 0.000208	 0.016413	 0.0	 1769.0	 1769.0	 1769.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	4700	 4706	 0.000208	 0.016413	 0.0	 1769.0	 1769.0	 1769.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	4699	 4706	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	4698	 4706	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	4697	 4706	 0.000319	 0.024307	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4713	 4714	 0.003121	 0.125827	 0.0	 245	 245	 245	 1.036269	 0.0	 1	 -30.0	 30.0;
	4713	 4714	 0.003852	 0.126815	 0.0	 244	 244	 244	 1.023541	 0.0	 1	 -30.0	 30.0;
	4735	 4736	 0.001975	 0.126025	 0.0	 242	 242	 242	 0.974664	 0.0	 1	 -30.0	 30.0;
	4735	 4736	 0.001956	 0.125037	 0.0	 244	 244	 244	 0.963394	 0.0	 1	 -30.0	 30.0;
	4735	 4736	 0.001956	 0.125037	 0.0	 244	 244	 244	 0.974664	 0.0	 1	 -30.0	 30.0;
	4737	 4738	 0.005057	 0.160988	 0.0	 194	 194	 194	 0.933709	 0.0	 1	 -30.0	 30.0;
	4737	 4738	 0.005057	 0.160988	 0.0	 194	 194	 194	 0.933709	 0.0	 1	 -30.0	 30.0;
	4759	 4760	 0.017333	 0.441333	 0.0	 69	 69	 69	 0.971818	 0.0	 1	 -30.0	 30.0;
	4765	 4766	 0.004247	 0.159407	 0.0	 192	 192	 192	 0.959693	 0.0	 1	 -30.0	 30.0;
	4766	 5887	 0.000699	 -0.004709	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4766	 4767	 0.000686	 0.048546	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4767	 5887	 1.4e-05	 0.052839	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4771	 4772	 0.00316	 0.125235	 0.0	 246	 246	 246	 1.026695	 0.0	 1	 -30.0	 30.0;
	4771	 4772	 0.001675	 0.121284	 0.0	 254	 254	 254	 1.026695	 0.0	 1	 -30.0	 30.0;
	4775	 4776	 0.003812	 0.120099	 0.0	 256	 256	 256	 0.96432	 0.0	 1	 -30.0	 30.0;
	4795	 4796	 0.003556	 0.118519	 0.0	 262	 262	 262	 0.946073	 0.0	 1	 -30.0	 30.0;
	4795	 4796	 0.003279	 0.113185	 0.0	 275	 275	 275	 0.95329	 0.0	 1	 -30.0	 30.0;
	4801	 4803	 0.001679	 0.099753	 0.0	 306	 306	 306	 0.961535	 0.0	 1	 -30.0	 30.0;
	4801	 4803	 0.001659	 0.099556	 0.0	 307	 307	 307	 0.961535	 0.0	 1	 -30.0	 30.0;
	4812	 4814	 0.002016	 0.079113	 0.0	 438	 438	 438	 1.0	 0.0	 1	 -30.0	 30.0;
	4811	 4813	 0.002016	 0.079113	 0.0	 438	 438	 438	 1.0	 0.0	 1	 -30.0	 30.0;
	4817	 4821	 0.002431	 0.093213	 0.0	 368	 368	 368	 1.0	 0.0	 1	 -30.0	 30.0;
	4820	 4821	 0.002431	 0.09349	 0.0	 367	 367	 367	 1.0	 0.0	 1	 -30.0	 30.0;
	4818	 4821	 0.002431	 0.093428	 0.0	 367	 367	 367	 1.0	 0.0	 1	 -30.0	 30.0;
	4819	 4821	 0.008906	 0.093352	 0.0	 366	 366	 366	 1.0	 0.0	 1	 -30.0	 30.0;
	4822	 4824	 0.003062	 0.115951	 0.0	 268	 268	 268	 0.997009	 0.0	 1	 -30.0	 30.0;
	4822	 4823	 0.004267	 0.15763	 0.0	 198	 198	 198	 1.043841	 0.0	 1	 -30.0	 30.0;
	4822	 4823	 0.003101	 0.117531	 0.0	 265	 265	 265	 0.985226	 0.0	 1	 -30.0	 30.0;
	4822	 4823	 0.003615	 0.121284	 0.0	 257	 257	 257	 0.973708	 0.0	 1	 -30.0	 30.0;
	4824	 4825	 0.000339	 0.027008	 0.0	 1176	 1176	 1176	 1.0	 0.0	 1	 -30.0	 30.0;
	4823	 4825	 0.000395	 0.027216	 0.0	 1167	 1167	 1167	 1.0	 0.0	 1	 -30.0	 30.0;
	4823	 4825	 0.000325	 0.027632	 0.0	 1149	 1149	 1149	 1.0	 0.0	 1	 -30.0	 30.0;
	4842	 4843	 0.00316	 0.110617	 0.0	 279	 279	 279	 1.013172	 0.0	 1	 -30.0	 30.0;
	4842	 4843	 0.00316	 0.118519	 0.0	 260	 260	 260	 1.013172	 0.0	 1	 -30.0	 30.0;
	4847	 4848	 0.005136	 0.160988	 0.0	 194	 194	 194	 0.863561	 0.0	 1	 -30.0	 30.0;
	4852	 4853	 0.001975	 0.165926	 0.0	 186	 186	 186	 1.00705	 0.0	 1	 -30.0	 30.0;
	4852	 4853	 0.003002	 0.173235	 0.0	 178	 178	 178	 0.978477	 0.0	 1	 -30.0	 30.0;
	4853	 4854	 0.000332	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4853	 5910	 0.000229	 -0.004363	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	4854	 5910	 9.7e-05	 0.029155	 0.0	 1175	 1175	 1175	 0.0	 0.0	 1	 -30.0	 30.0;
	4857	 4858	 0.003911	 0.124642	 0.0	 248	 248	 248	 0.961543	 0.0	 1	 -30.0	 30.0;
	4857	 4858	 0.003951	 0.124247	 0.0	 249	 249	 249	 0.961543	 0.0	 1	 -30.0	 30.0;
	4857	 4858	 0.003556	 0.126222	 0.0	 245	 245	 245	 0.97182	 0.0	 1	 -30.0	 30.0;
	4875	 4876	 0.003516	 0.122667	 0.0	 249	 249	 249	 0.973708	 0.0	 1	 -30.0	 30.0;
	4875	 4876	 0.003062	 0.116741	 0.0	 262	 262	 262	 0.973708	 0.0	 1	 -30.0	 30.0;
	4879	 4880	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4879	 4880	 0.000319	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4895	 4897	 0.003062	 0.12484	 0.0	 247	 247	 247	 0.955109	 0.0	 1	 -30.0	 30.0;
	4895	 4896	 0.003121	 0.12484	 0.0	 247	 247	 247	 0.96432	 0.0	 1	 -30.0	 30.0;
	4896	 4898	 0.000803	 0.039335	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4897	 4898	 0.000325	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4896	 4898	 0.000796	 0.039266	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	4902	 4904	 0.000305	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4910	 4912	 0.005037	 0.159012	 0.0	 194	 194	 194	 0.978474	 0.0	 1	 -30.0	 30.0;
	4909	 4912	 0.004523	 0.156049	 0.0	 198	 198	 198	 0.978474	 0.0	 1	 -30.0	 30.0;
	4910	 4912	 0.004919	 0.159012	 0.0	 194	 194	 194	 0.978474	 0.0	 1	 -30.0	 30.0;
	4911	 4912	 0.002212	 0.125432	 0.0	 251	 251	 251	 0.928505	 0.0	 1	 -30.0	 30.0;
	4912	 4913	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4912	 4913	 0.000325	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	4916	 4917	 0.003002	 0.118716	 0.0	 257	 257	 257	 0.956938	 0.0	 1	 -30.0	 30.0;
	4916	 4917	 0.003002	 0.118716	 0.0	 257	 257	 257	 1.0	 0.0	 1	 -30.0	 30.0;
	4921	 4922	 0.003121	 0.12563	 0.0	 243	 243	 243	 0.999001	 0.0	 1	 -30.0	 30.0;
	4921	 4922	 0.003951	 0.125235	 0.0	 244	 244	 244	 0.999001	 0.0	 1	 -30.0	 30.0;
	4921	 4922	 0.003121	 0.12563	 0.0	 243	 243	 243	 0.999001	 0.0	 1	 -30.0	 30.0;
	4935	 4936	 0.003378	 0.121481	 0.0	 254	 254	 254	 0.974664	 0.0	 1	 -30.0	 30.0;
	4949	 4951	 0.00316	 0.11516	 0.0	 268	 268	 268	 1.020408	 0.0	 1	 -30.0	 30.0;
	4949	 4951	 0.003595	 0.120889	 0.0	 255	 255	 255	 1.029866	 0.0	 1	 -30.0	 30.0;
	4950	 5888	 0.00027	 -0.005332	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4950	 5911	 0.000249	 -0.005471	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4951	 5930	 0.000125	 -0.007687	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4950	 5939	 0.000173	 -0.007895	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4950	 5945	 0.000132	 -0.010942	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4952	 5888	 5.5e-05	 0.032756	 0.0	 1046	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 5911	 6.9e-05	 0.032895	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 5930	 0.000201	 0.034834	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 5939	 0.000166	 0.034834	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 5945	 0.000208	 0.038643	 0.0	 886	 886	 886	 0.0	 0.0	 1	 -30.0	 30.0;
	4953	 4955	 7.9e-05	 0.000836	 0.0	 40922	 40922	 40922	 1.0	 0.0	 1	 -30.0	 30.0;
	4954	 4955	 0.004207	 0.160988	 0.0	 190	 190	 190	 1.010101	 0.0	 1	 -30.0	 30.0;
	4954	 4955	 0.004227	 0.159012	 0.0	 192	 192	 192	 1.0	 0.0	 1	 -30.0	 30.0;
	4954	 4955	 0.003516	 0.121086	 0.0	 252	 252	 252	 1.009082	 0.0	 1	 -30.0	 30.0;
	4960	 4962	 0.001925	 0.101801	 0.0	 310	 310	 310	 0.939851	 0.0	 1	 -30.0	 30.0;
	4960	 4961	 0.001835	 0.101177	 0.0	 311	 311	 311	 0.956942	 0.0	 1	 -30.0	 30.0;
	4966	 4968	 0.001956	 0.126025	 0.0	 244	 244	 244	 0.987167	 0.0	 1	 -30.0	 30.0;
	4967	 4968	 0.001956	 0.125037	 0.0	 246	 246	 246	 0.97561	 0.0	 1	 -30.0	 30.0;
	4969	 5912	 0.000145	 -0.011288	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4968	 4970	 0.000319	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	4969	 5940	 0.000291	 -0.00554	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4968	 4970	 0.000693	 0.048615	 0.0	 605.0	 605.0	 605.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4968	 5946	 0.000471	 -0.005263	 0.0	 605.0	 605.0	 605.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	4970	 5912	 0.000187	 0.038712	 0.0	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 5940	 2.8e-05	 0.032895	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 5946	 0.000235	 0.053324	 0.0	 605.0	 605.0	 605.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 4975	 0.004563	 0.160988	 0.0	 192	 192	 192	 0.978477	 0.0	 1	 -30.0	 30.0;
	4974	 4975	 0.00721	 0.231704	 0.0	 134	 134	 134	 0.956935	 0.0	 1	 -30.0	 30.0;
	4979	 4982	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	4978	 4981	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	4977	 4980	 0.011852	 0.355556	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	4983	 4985	 0.003378	 0.121481	 0.0	 254	 254	 254	 0.964319	 0.0	 1	 -30.0	 30.0;
	4987	 4988	 0.003378	 0.121936	 0.0	 253	 253	 253	 0.96432	 0.0	 1	 -30.0	 30.0;
	4991	 4992	 0.001975	 0.115951	 0.0	 266	 266	 266	 1.040584	 0.0	 1	 -30.0	 30.0;
	4993	 4994	 0.001817	 0.118716	 0.0	 259	 259	 259	 1.001002	 0.0	 1	 -30.0	 30.0;
	4998	 4999	 0.003358	 0.12563	 0.0	 245	 245	 245	 1.026695	 0.0	 1	 -30.0	 30.0;
	4998	 4999	 0.00316	 0.116938	 0.0	 264	 264	 264	 1.0142	 0.0	 1	 -30.0	 30.0;
	5027	 5028	 0.003536	 0.12563	 0.0	 245	 245	 245	 0.96432	 0.0	 1	 -30.0	 30.0;
	5045	 5046	 0.001679	 0.089482	 0.0	 342	 342	 342	 0.983284	 0.0	 1	 -30.0	 30.0;
	5055	 5057	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5055	 5056	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5054	 5056	 0.000339	 0.024446	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5054	 5057	 0.000332	 0.025069	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5063	 5064	 0.000346	 0.025346	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5063	 5064	 0.000332	 0.025208	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5071	 5072	 0.003042	 0.118321	 0.0	 261	 261	 261	 0.985226	 0.0	 1	 -30.0	 30.0;
	5078	 5079	 0.000325	 0.027701	 0.0	 1145	 1145	 1145	 1.0	 0.0	 1	 -30.0	 30.0;
	5955	 5956	 0.000694	 0.05125	 0.0	 674	 674	 674	 1.035197	 0.0	 1	 -30.0	 30.0;
	5954	 5956	 0.000631	 0.05	 0.0	 691	 691	 691	 0.967118	 0.0	 1	 -30.0	 30.0;
	5961	 5962	 0.0006	 0.028981	 0.0	 1192	 1192	 1192	 0.980392	 0.0	 1	 -30.0	 30.0;
	5963	 5964	 0.000419	 0.025313	 0.0	 1364	 1364	 1364	 1.001	 0.0	 1	 -30.0	 30.0;
	5970	 5971	 0.000212	 0.018819	 0.0	 599.0	 599.0	 599.0	 0.929366	 0.0	 1	 -30.0	 30.0;
	5973	 5975	 0.000403	 0.025619	 0.0	 1348	 1348	 1348	 1.001	 0.0	 1	 -30.0	 30.0;
	5974	 5975	 0.000403	 0.025619	 0.0	 1348	 1348	 1348	 1.001	 0.0	 1	 -30.0	 30.0;
	5990	 6187	 0.003714	 0.012701	 0.0	 425.0	 425.0	 425.0	 1.0	 -16.6	 1	 -30.0	 30.0;
	6188	 5993	 0.000125	 0.003125	 0.0	 11039	 11039	 11039	 1.04384	 0.0	 1	 -30.0	 30.0;
	5992	 6188	 0.000198	 0.004938	 0.0	 6986	 6986	 6986	 1.126727	 -6.75	 1	 -30.0	 30.0;
	6011	 6013	 6.8e-05	 0.01825	 0.0	 1892	 1892	 1892	 0.989122	 0.0	 1	 -30.0	 30.0;
	6012	 6014	 0.000151	 0.017549	 0.0	 1968	 1968	 1968	 0.989122	 0.0	 1	 -30.0	 30.0;
	6024	 6025	 9.3e-05	 0.01825	 0.0	 1892	 1892	 1892	 1.004018	 0.0	 1	 -30.0	 30.0;
	6029	 6031	 0.0004	 0.03	 0.0	 1151	 1151	 1151	 0.971818	 0.0	 1	 -30.0	 30.0;
	6189	 6030	 0.000119	 0.013827	 0.0	 599.0	 599.0	 599.0	 1.0	 -2.9	 1	 -30.0	 30.0;
	6047	 6048	 0.000139	 0.013299	 0.0	 2596	 2596	 2596	 1.013171	 0.0	 1	 -30.0	 30.0;
	6051	 6054	 0.000719	 0.04375	 0.0	 790	 790	 790	 1.058201	 0.0	 1	 -30.0	 30.0;
	6052	 6053	 0.000719	 0.04375	 0.0	 790	 790	 790	 0.998004	 0.0	 1	 -30.0	 30.0;
	6057	 6059	 0.000125	 0.046125	 0.0	 749	 749	 749	 1.0142	 0.0	 1	 -30.0	 30.0;
	6058	 6059	 0.000125	 0.046125	 0.0	 749	 749	 749	 1.0142	 0.0	 1	 -30.0	 30.0;
	6061	 6190	 4.4e-05	 0.001063	 0.0	 1966.0	 1966.0	 1966.0	 1.0	 1.91	 1	 -30.0	 30.0;
	6063	 6064	 0.0006	 0.030687	 0.0	 1125	 1125	 1125	 0.980393	 0.0	 1	 -30.0	 30.0;
	6063	 6064	 0.000381	 0.026838	 0.0	 1287	 1287	 1287	 0.971819	 0.0	 1	 -30.0	 30.0;
	6071	 6072	 0.0005	 0.03015	 0.0	 1145	 1145	 1145	 0.980392	 0.0	 1	 -30.0	 30.0;
	6075	 6076	 0.0006	 0.030081	 0.0	 1148	 1148	 1148	 0.932835	 0.0	 1	 -30.0	 30.0;
	6075	 6076	 0.0005	 0.026231	 0.0	 1316	 1316	 1316	 0.980393	 0.0	 1	 -30.0	 30.0;
	6083	 6085	 0.000136	 0.015151	 0.0	 2279	 2279	 2279	 0.949669	 0.0	 1	 -30.0	 30.0;
	6088	 6090	 0.000313	 0.01875	 0.0	 1842	 1842	 1842	 0.990095	 0.0	 1	 -30.0	 30.0;
	6095	 6096	 0.0003	 0.027769	 0.0	 1244	 1244	 1244	 0.971821	 0.0	 1	 -30.0	 30.0;
	6192	 6109	 2.7e-05	 0.009838	 0.0	 999.0	 999.0	 999.0	 0.950029	 0.0	 1	 -30.0	 30.0;
	6191	 6109	 2.7e-05	 0.009838	 0.0	 999.0	 999.0	 999.0	 0.950029	 0.0	 1	 -30.0	 30.0;
	6111	 6112	 0.0004	 0.044413	 0.0	 778	 778	 778	 0.92937	 0.0	 1	 -30.0	 30.0;
	6193	 6118	 0.000119	 0.014321	 0.0	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 6126	 0.0002	 0.0188	 0.0	 1837	 1837	 1837	 0.939853	 0.0	 1	 -30.0	 30.0;
	6139	 6140	 0.000731	 0.045162	 0.0	 765	 765	 765	 0.947864	 0.0	 1	 -30.0	 30.0;
	6139	 6140	 0.000731	 0.045231	 0.0	 764	 764	 764	 0.94877	 0.0	 1	 -30.0	 30.0;
	6143	 6144	 0.0003	 0.022881	 0.0	 1509	 1509	 1509	 0.978474	 0.0	 1	 -30.0	 30.0;
	6163	 6164	 0.000338	 0.020438	 0.0	 1689	 1689	 1689	 0.971821	 0.0	 1	 -30.0	 30.0;
	6194	 6164	 6.2e-05	 0.00675	 0.0	 1629.0	 1629.0	 1629.0	 1.133606	 -15.01	 1	 -30.0	 30.0;
	6169	 6170	 0.000554	 0.031524	 0.0	 1096	 1096	 1096	 0.961538	 0.0	 1	 -30.0	 30.0;
	6173	 6174	 0.0004	 0.025687	 0.0	 1344	 1344	 1344	 0.953291	 0.0	 1	 -30.0	 30.0;
	6173	 6174	 0.0003	 0.025487	 0.0	 1355	 1355	 1355	 0.955109	 0.0	 1	 -30.0	 30.0;
	6173	 6174	 0.0004	 0.025413	 0.0	 1359	 1359	 1359	 0.946974	 0.0	 1	 -30.0	 30.0;
	6175	 6176	 0.0005	 0.02805	 0.0	 1231	 1231	 1231	 0.980392	 0.0	 1	 -30.0	 30.0;
	6117	 6193	 2.1e-05	 0.016116	 0.0	 399.0	 399.0	 399.0	 1.026694	 0.0	 1	 -30.0	 30.0;
	6200	 6201	 0.00055	 0.04302	 0.0	 803	 803	 803	 0.990093	 0.0	 1	 -30.0	 30.0;
	6196	 6210	 6e-06	 0.000625	 0.0	 55237	 55237	 55237	 0.97561	 0.0	 1	 -30.0	 30.0;
	6196	 6209	 0.000632	 0.015684	 0.0	 2200	 2200	 2200	 1.014351	 1.32	 1	 -30.0	 30.0;
	6214	 6197	 7.5e-05	 0.007931	 0.0	 1399.0	 1399.0	 1399.0	 1.0	 -2.93	 1	 -30.0	 30.0;
	6213	 6198	 7.5e-05	 0.007931	 0.0	 1399.0	 1399.0	 1399.0	 1.0	 -2.93	 1	 -30.0	 30.0;
	6219	 6220	 0.000181	 0.01425	 0.0	 1866.0	 1866.0	 1866.0	 0.991083	 0.0	 1	 -30.0	 30.0;
	6222	 6223	 0.0012	 0.08215	 0.0	 421	 421	 421	 0.971818	 0.0	 1	 -30.0	 30.0;
	6222	 6223	 0.000397	 0.049841	 0.0	 693	 693	 693	 0.995025	 0.0	 1	 -30.0	 30.0;
	6222	 6223	 0.0002	 0.018669	 0.0	 1850	 1850	 1850	 0.956943	 0.0	 1	 -30.0	 30.0;
	6224	 6225	 0.000312	 0.028362	 0.0	 399.0	 399.0	 399.0	 0.97182	 0.0	 1	 -30.0	 30.0;
	6234	 6235	 0.000125	 0.026499	 0.0	 1303	 1303	 1303	 1.0142	 0.0	 1	 -30.0	 30.0;
	6232	 6235	 0.000125	 0.026499	 0.0	 1303	 1303	 1303	 1.0142	 0.0	 1	 -30.0	 30.0;
	6233	 6235	 0.000125	 0.026499	 0.0	 1303	 1303	 1303	 1.0142	 0.0	 1	 -30.0	 30.0;
	6231	 6235	 0.000125	 0.026499	 0.0	 1303	 1303	 1303	 1.0142	 0.0	 1	 -30.0	 30.0;
	6236	 6237	 0.00015	 0.023481	 0.0	 1471	 1471	 1471	 0.971817	 0.0	 1	 -30.0	 30.0;
	6236	 6237	 0.000287	 0.026931	 0.0	 1282	 1282	 1282	 0.971817	 0.0	 1	 -30.0	 30.0;
	6242	 6199	 3.8e-05	 0.00375	 0.0	 1399.0	 1399.0	 1399.0	 1.0	 5.86	 1	 -30.0	 30.0;
	115	 6245	 0.0	 0.019737	 0.0	 1735	 1735	 1735	 1.092105	 0.0	 1	 -30.0	 30.0;
	116	 6246	 0.0	 0.019737	 0.0	 1735	 1735	 1735	 1.092105	 0.0	 1	 -30.0	 30.0;
	200	 6247	 0.0	 0.54184	 0.0	 64	 64	 64	 1.044444	 0.0	 1	 -30.0	 30.0;
	200	 6248	 0.0	 0.54184	 0.0	 64	 64	 64	 1.044444	 0.0	 1	 -30.0	 30.0;
	200	 6249	 0.0	 0.54184	 0.0	 64	 64	 64	 1.044444	 0.0	 1	 -30.0	 30.0;
	230	 6250	 0.0	 0.142857	 0.0	 241	 241	 241	 1.111111	 0.0	 1	 -30.0	 30.0;
	230	 6251	 0.0	 0.219149	 0.0	 157	 157	 157	 1.111111	 0.0	 1	 -30.0	 30.0;
	247	 6252	 0.0	 0.090928	 0.0	 378	 378	 378	 1.066667	 0.0	 1	 -30.0	 30.0;
	271	 6253	 0.0	 0.366794	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	271	 6254	 0.0	 0.366794	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	270	 6255	 0.0	 0.366794	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	270	 6256	 0.0	 0.366794	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	366	 6257	 0.0	 0.128409	 0.0	 268	 268	 268	 1.048889	 0.0	 1	 -30.0	 30.0;
	366	 6258	 0.0	 0.128409	 0.0	 268	 268	 268	 1.048889	 0.0	 1	 -30.0	 30.0;
	367	 6259	 0.0	 0.15	 0.0	 229	 229	 229	 1.060526	 0.0	 1	 -30.0	 30.0;
	367	 6260	 0.0	 0.15	 0.0	 229	 229	 229	 1.060526	 0.0	 1	 -30.0	 30.0;
	368	 6261	 0.0	 0.15	 0.0	 229	 229	 229	 1.060526	 0.0	 1	 -30.0	 30.0;
	368	 6262	 0.0	 0.15	 0.0	 229	 229	 229	 1.060526	 0.0	 1	 -30.0	 30.0;
	494	 6263	 0.0	 0.012611	 0.0	 1088.0	 1088.0	 1088.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	495	 6264	 0.0	 0.012611	 0.0	 1133.0	 1133.0	 1133.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	496	 6265	 0.0	 0.012611	 0.0	 1126.0	 1126.0	 1126.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	497	 6266	 0.0	 0.012611	 0.0	 1080.0	 1080.0	 1080.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	500	 6268	 0.0	 0.048207	 0.0	 711	 711	 711	 1.080978	 0.0	 1	 -30.0	 30.0;
	499	 6269	 0.0	 0.048207	 0.0	 711	 711	 711	 1.080978	 0.0	 1	 -30.0	 30.0;
	501	 6270	 0.0	 0.043965	 0.0	 779	 779	 779	 1.065789	 0.0	 1	 -30.0	 30.0;
	501	 6271	 0.0	 0.03442	 0.0	 289.0	 289.0	 289.0	 1.060526	 0.0	 1	 -30.0	 30.0;
	501	 6272	 0.0	 0.06506	 0.0	 527	 527	 527	 1.060526	 0.0	 1	 -30.0	 30.0;
	527	 6273	 0.0	 0.161429	 0.0	 213	 213	 213	 1.054667	 0.0	 1	 -30.0	 30.0;
	527	 6274	 0.0	 0.17931	 0.0	 192	 192	 192	 1.054667	 0.0	 1	 -30.0	 30.0;
	527	 6275	 0.0	 0.161429	 0.0	 213	 213	 213	 1.054667	 0.0	 1	 -30.0	 30.0;
	527	 6276	 0.0	 0.17931	 0.0	 192	 192	 192	 1.054667	 0.0	 1	 -30.0	 30.0;
	527	 6277	 0.0	 0.17931	 0.0	 192	 192	 192	 1.054667	 0.0	 1	 -30.0	 30.0;
	2790	 6278	 0.0	 0.044965	 0.0	 764	 764	 764	 1.080978	 0.0	 1	 -30.0	 30.0;
	616	 6279	 0.0	 0.112429	 0.0	 306	 306	 306	 1.042667	 0.0	 1	 -30.0	 30.0;
	616	 6280	 0.0	 0.183397	 0.0	 188	 188	 188	 1.093334	 0.0	 1	 -30.0	 30.0;
	616	 6281	 0.0	 0.183397	 0.0	 188	 188	 188	 1.088889	 0.0	 1	 -30.0	 30.0;
	623	 6282	 0.0	 0.33346	 0.0	 104	 104	 104	 0.985494	 0.0	 1	 -30.0	 30.0;
	624	 6283	 0.0	 0.166743	 0.0	 206	 206	 206	 1.026879	 0.0	 1	 -30.0	 30.0;
	624	 6284	 0.0	 0.300114	 0.0	 115	 115	 115	 1.020096	 0.0	 1	 -30.0	 30.0;
	667	 6285	 0.0	 0.012685	 0.0	 1093.0	 1093.0	 1093.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	666	 6286	 0.0	 0.012685	 0.0	 1082.0	 1082.0	 1082.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	665	 6287	 0.0	 0.012685	 0.0	 1072.0	 1072.0	 1072.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	664	 6288	 0.0	 0.012685	 0.0	 1010.0	 1010.0	 1010.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	685	 6289	 0.0	 0.009303	 0.0	 1541.0	 1541.0	 1541.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	687	 6290	 0.0	 0.009303	 0.0	 1541.0	 1541.0	 1541.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	694	 6291	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	694	 6292	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	694	 6293	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	693	 6294	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	693	 6295	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	693	 6296	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	715	 6297	 0.0	 0.453182	 0.0	 76	 76	 76	 1.088889	 0.0	 1	 -30.0	 30.0;
	895	 6298	 0.0	 0.008909	 0.0	 1551.0	 1551.0	 1551.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	897	 6299	 0.0	 0.008909	 0.0	 1571.0	 1571.0	 1571.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	898	 6300	 0.0	 0.008909	 0.0	 1519.0	 1519.0	 1519.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1002	 6301	 0.0	 0.133372	 0.0	 258	 258	 258	 1.043111	 0.0	 1	 -30.0	 30.0;
	1042	 6302	 0.0	 0.048207	 0.0	 713	 713	 713	 1.080978	 0.0	 1	 -30.0	 30.0;
	1049	 6303	 0.0	 0.054074	 0.0	 634	 634	 634	 1.077631	 0.0	 1	 -30.0	 30.0;
	1052	 6304	 0.0	 0.012685	 0.0	 1091.0	 1091.0	 1091.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1056	 6306	 0.0	 0.012611	 0.0	 1104.0	 1104.0	 1104.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1055	 6307	 0.0	 0.012611	 0.0	 1102.0	 1102.0	 1102.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1061	 6308	 0.0	 0.009257	 0.0	 1908.0	 1908.0	 1908.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1062	 6309	 0.0	 0.009257	 0.0	 1846.0	 1846.0	 1846.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1076	 6310	 0.0	 0.009257	 0.0	 1805.0	 1805.0	 1805.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	1075	 6311	 0.0	 0.009257	 0.0	 1803.0	 1803.0	 1803.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	73	 6312	 0.0	 0.06579	 0.0	 522	 522	 522	 1.096667	 0.0	 1	 -30.0	 30.0;
	72	 6313	 0.0	 0.06579	 0.0	 522	 522	 522	 1.096667	 0.0	 1	 -30.0	 30.0;
	2100	 6314	 0.0	 0.1	 0.0	 344	 344	 344	 1.057778	 0.0	 1	 -30.0	 30.0;
	1171	 6315	 0.0	 0.01954	 0.0	 1759	 1759	 1759	 1.088844	 0.0	 1	 -30.0	 30.0;
	1172	 6316	 0.0	 0.020227	 0.0	 549.0	 549.0	 549.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	1173	 6317	 0.0	 0.01954	 0.0	 697.0	 697.0	 697.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	1174	 6319	 0.0	 0.021576	 0.0	 1588	 1588	 1588	 1.092105	 0.0	 1	 -30.0	 30.0;
	1176	 6320	 0.0	 0.411923	 0.0	 84	 84	 84	 1.08	 0.0	 1	 -30.0	 30.0;
	1176	 6321	 0.0	 0.314286	 0.0	 110	 110	 110	 1.024888	 0.0	 1	 -30.0	 30.0;
	1441	 6322	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1441	 6323	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1441	 6324	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1441	 6325	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1441	 6326	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1441	 6327	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	1295	 6328	 0.0	 0.012685	 0.0	 1099.0	 1099.0	 1099.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1292	 6329	 0.0	 0.012685	 0.0	 1120.0	 1120.0	 1120.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1294	 6330	 0.0	 0.012611	 0.0	 1136.0	 1136.0	 1136.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1293	 6331	 0.0	 0.012611	 0.0	 1091.0	 1091.0	 1091.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1335	 6332	 0.0	 0.181818	 0.0	 189	 189	 189	 1.044444	 0.0	 1	 -30.0	 30.0;
	1335	 6333	 0.0	 0.181818	 0.0	 189	 189	 189	 1.044444	 0.0	 1	 -30.0	 30.0;
	1361	 6334	 0.0	 0.041231	 0.0	 833	 833	 833	 1.0948	 0.0	 1	 -30.0	 30.0;
	1360	 6335	 0.0	 0.273494	 0.0	 126	 126	 126	 1.062667	 0.0	 1	 -30.0	 30.0;
	1427	 6336	 0.0	 0.032831	 0.0	 474.0	 474.0	 474.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	1573	 6337	 0.0	 0.012685	 0.0	 1062.0	 1062.0	 1062.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1574	 6338	 0.0	 0.012685	 0.0	 1060.0	 1060.0	 1060.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1575	 6339	 0.0	 0.012685	 0.0	 1070.0	 1070.0	 1070.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1576	 6340	 0.0	 0.012685	 0.0	 1087.0	 1087.0	 1087.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1602	 6341	 0.0	 0.345838	 0.0	 100	 100	 100	 1.044444	 0.0	 1	 -30.0	 30.0;
	1764	 6342	 0.0	 0.009303	 0.0	 1573.0	 1573.0	 1573.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	1763	 6343	 0.0	 0.009303	 0.0	 1435.0	 1435.0	 1435.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	1866	 6344	 0.0	 0.3396	 0.0	 103	 103	 103	 1.0	 0.0	 1	 -30.0	 30.0;
	1954	 6345	 0.0	 0.128214	 0.0	 268	 268	 268	 1.056743	 0.0	 1	 -30.0	 30.0;
	1955	 6346	 0.0	 0.128214	 0.0	 268	 268	 268	 1.056743	 0.0	 1	 -30.0	 30.0;
	1955	 6347	 0.0	 0.128214	 0.0	 268	 268	 268	 1.056743	 0.0	 1	 -30.0	 30.0;
	1955	 6348	 0.0	 0.148375	 0.0	 232	 232	 232	 1.057778	 0.0	 1	 -30.0	 30.0;
	1954	 6349	 0.0	 0.148375	 0.0	 232	 232	 232	 1.057778	 0.0	 1	 -30.0	 30.0;
	2010	 6350	 0.0	 0.008909	 0.0	 1570.0	 1570.0	 1570.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	2011	 6351	 0.0	 0.008909	 0.0	 1574.0	 1574.0	 1574.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	2014	 6352	 0.0	 0.457282	 0.0	 75	 75	 75	 1.066667	 0.0	 1	 -30.0	 30.0;
	2014	 6353	 0.0	 0.457282	 0.0	 75	 75	 75	 1.066667	 0.0	 1	 -30.0	 30.0;
	2040	 6354	 0.0	 0.042476	 0.0	 449.0	 449.0	 449.0	 1.062222	 0.0	 1	 -30.0	 30.0;
	2047	 6355	 0.0	 0.302795	 0.0	 114	 114	 114	 1.053333	 0.0	 1	 -30.0	 30.0;
	2047	 6356	 0.0	 0.302795	 0.0	 114	 114	 114	 1.053333	 0.0	 1	 -30.0	 30.0;
	2055	 6357	 0.0	 0.012685	 0.0	 1107.0	 1107.0	 1107.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2056	 6358	 0.0	 0.012685	 0.0	 1099.0	 1099.0	 1099.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2057	 6359	 0.0	 0.012685	 0.0	 1106.0	 1106.0	 1106.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2058	 6360	 0.0	 0.012685	 0.0	 1101.0	 1101.0	 1101.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2059	 6361	 0.0	 0.012685	 0.0	 1108.0	 1108.0	 1108.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2060	 6362	 0.0	 0.012685	 0.0	 990.0	 990.0	 990.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2128	 6363	 0.0	 0.041112	 0.0	 835	 835	 835	 1.081067	 0.0	 1	 -30.0	 30.0;
	2157	 6364	 0.0	 0.029081	 0.0	 502.0	 502.0	 502.0	 1.080888	 0.0	 1	 -30.0	 30.0;
	2192	 6365	 0.0	 0.044965	 0.0	 286.0	 286.0	 286.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	2193	 6366	 0.0	 0.020227	 0.0	 1697	 1697	 1697	 1.088844	 0.0	 1	 -30.0	 30.0;
	2194	 6367	 0.0	 0.021197	 0.0	 1616	 1616	 1616	 1.103079	 0.0	 1	 -30.0	 30.0;
	2215	 6369	 0.0	 0.203226	 0.0	 169	 169	 169	 1.048889	 0.0	 1	 -30.0	 30.0;
	2215	 6370	 0.0	 0.203226	 0.0	 169	 169	 169	 1.048889	 0.0	 1	 -30.0	 30.0;
	2235	 6371	 0.0	 0.372846	 0.0	 93	 93	 93	 1.076889	 0.0	 1	 -30.0	 30.0;
	2235	 6372	 0.0	 0.372846	 0.0	 93	 93	 93	 1.076889	 0.0	 1	 -30.0	 30.0;
	2393	 6373	 0.0	 0.525174	 0.0	 66	 66	 66	 1.0	 0.0	 1	 -30.0	 30.0;
	2393	 6374	 0.0	 0.525174	 0.0	 66	 66	 66	 1.0	 0.0	 1	 -30.0	 30.0;
	2453	 6375	 0.0	 0.460144	 0.0	 75	 75	 75	 1.035556	 0.0	 1	 -30.0	 30.0;
	2654	 6376	 0.0	 0.312857	 0.0	 110	 110	 110	 1.054667	 0.0	 1	 -30.0	 30.0;
	2654	 6377	 0.0	 0.312857	 0.0	 110	 110	 110	 1.054667	 0.0	 1	 -30.0	 30.0;
	2654	 6378	 0.0	 0.312857	 0.0	 110	 110	 110	 1.054667	 0.0	 1	 -30.0	 30.0;
	2654	 6379	 0.0	 0.312857	 0.0	 110	 110	 110	 1.054667	 0.0	 1	 -30.0	 30.0;
	2610	 6380	 0.0	 0.048207	 0.0	 712	 712	 712	 1.080978	 0.0	 1	 -30.0	 30.0;
	2646	 6381	 0.0	 0.220078	 0.0	 156	 156	 156	 1.07511	 0.0	 1	 -30.0	 30.0;
	2646	 6382	 0.0	 0.220078	 0.0	 156	 156	 156	 1.07511	 0.0	 1	 -30.0	 30.0;
	2697	 6383	 0.0	 0.120375	 0.0	 286	 286	 286	 1.053333	 0.0	 1	 -30.0	 30.0;
	2697	 6384	 0.0	 0.17125	 0.0	 201	 201	 201	 1.053333	 0.0	 1	 -30.0	 30.0;
	2697	 6385	 0.0	 0.13875	 0.0	 248	 248	 248	 1.049777	 0.0	 1	 -30.0	 30.0;
	2697	 6386	 0.0	 0.120375	 0.0	 286	 286	 286	 1.053333	 0.0	 1	 -30.0	 30.0;
	2703	 6387	 0.0	 0.329412	 0.0	 105	 105	 105	 1.053333	 0.0	 1	 -30.0	 30.0;
	2703	 6388	 0.0	 0.329412	 0.0	 105	 105	 105	 1.053333	 0.0	 1	 -30.0	 30.0;
	2703	 6389	 0.0	 0.329412	 0.0	 105	 105	 105	 1.053333	 0.0	 1	 -30.0	 30.0;
	2720	 6390	 0.0	 0.181636	 0.0	 189	 189	 189	 1.088889	 0.0	 1	 -30.0	 30.0;
	2742	 6391	 0.0	 0.360113	 0.0	 96	 96	 96	 1.075556	 0.0	 1	 -30.0	 30.0;
	2742	 6392	 0.0	 0.360113	 0.0	 96	 96	 96	 1.075556	 0.0	 1	 -30.0	 30.0;
	2742	 6393	 0.0	 0.360113	 0.0	 96	 96	 96	 1.075556	 0.0	 1	 -30.0	 30.0;
	2742	 6394	 0.0	 0.360113	 0.0	 96	 96	 96	 1.075556	 0.0	 1	 -30.0	 30.0;
	2814	 6395	 0.0	 0.044965	 0.0	 764	 764	 764	 1.080978	 0.0	 1	 -30.0	 30.0;
	2813	 6396	 0.0	 0.044965	 0.0	 255.0	 255.0	 255.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	2853	 6397	 0.0	 0.482751	 0.0	 72	 72	 72	 1.137778	 0.0	 1	 -30.0	 30.0;
	2853	 6398	 0.0	 0.482751	 0.0	 72	 72	 72	 1.137778	 0.0	 1	 -30.0	 30.0;
	4397	 6399	 0.0	 0.084636	 0.0	 406	 406	 406	 1.097778	 0.0	 1	 -30.0	 30.0;
	379	 6400	 0.0	 0.031723	 0.0	 445.0	 445.0	 445.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	3031	 6401	 0.0	 0.25608	 0.0	 135	 135	 135	 1.072445	 0.0	 1	 -30.0	 30.0;
	3031	 6402	 0.0	 0.25608	 0.0	 135	 135	 135	 1.072445	 0.0	 1	 -30.0	 30.0;
	3048	 6403	 0.0	 0.0516	 0.0	 666	 666	 666	 1.07511	 0.0	 1	 -30.0	 30.0;
	3047	 6404	 0.0	 0.0516	 0.0	 666	 666	 666	 1.07511	 0.0	 1	 -30.0	 30.0;
	3051	 6405	 0.0	 0.0592	 0.0	 579	 579	 579	 1.092105	 0.0	 1	 -30.0	 30.0;
	3051	 6406	 0.0	 0.0596	 0.0	 575	 575	 575	 1.092105	 0.0	 1	 -30.0	 30.0;
	3050	 6407	 0.0	 0.0596	 0.0	 575	 575	 575	 1.092105	 0.0	 1	 -30.0	 30.0;
	3050	 6408	 0.0	 0.05972	 0.0	 574	 574	 574	 1.092105	 0.0	 1	 -30.0	 30.0;
	3081	 6409	 0.0	 0.15879	 0.0	 217	 217	 217	 1.052889	 0.0	 1	 -30.0	 30.0;
	3081	 6410	 0.0	 0.15879	 0.0	 217	 217	 217	 1.052889	 0.0	 1	 -30.0	 30.0;
	1739	 6411	 0.0	 0.012685	 0.0	 1072.0	 1072.0	 1072.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1738	 6412	 0.0	 0.012685	 0.0	 1063.0	 1063.0	 1063.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3142	 6413	 0.0	 0.03299	 0.0	 276.0	 276.0	 276.0	 1.04	 0.0	 1	 -30.0	 30.0;
	3142	 6414	 0.0	 0.04269	 0.0	 804	 804	 804	 1.081	 0.0	 1	 -30.0	 30.0;
	3143	 6415	 0.0	 0.034269	 0.0	 1000	 1000	 1000	 1.060526	 0.0	 1	 -30.0	 30.0;
	3229	 6416	 0.0	 0.009303	 0.0	 1567.0	 1567.0	 1567.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3246	 6417	 0.0	 0.144154	 0.0	 239	 239	 239	 1.066667	 0.0	 1	 -30.0	 30.0;
	3246	 6418	 0.0	 0.144154	 0.0	 239	 239	 239	 1.066667	 0.0	 1	 -30.0	 30.0;
	3256	 6419	 0.0	 0.297059	 0.0	 116	 116	 116	 1.066667	 0.0	 1	 -30.0	 30.0;
	3311	 6420	 0.0	 0.008909	 0.0	 1587.0	 1587.0	 1587.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3312	 6421	 0.0	 0.008909	 0.0	 1631.0	 1631.0	 1631.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3313	 6422	 0.0	 0.008909	 0.0	 1630.0	 1630.0	 1630.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3310	 6423	 0.0	 0.008909	 0.0	 1622.0	 1622.0	 1622.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3339	 6424	 0.0	 0.389792	 0.0	 89	 89	 89	 1.044444	 0.0	 1	 -30.0	 30.0;
	3366	 6425	 0.0	 0.009303	 0.0	 1634.0	 1634.0	 1634.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3367	 6426	 0.0	 0.009303	 0.0	 1584.0	 1584.0	 1584.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	3472	 6427	 0.0	 0.021485	 0.0	 1594	 1594	 1594	 1.103079	 0.0	 1	 -30.0	 30.0;
	3471	 6428	 0.0	 0.021485	 0.0	 1594	 1594	 1594	 1.103079	 0.0	 1	 -30.0	 30.0;
	3470	 6429	 0.0	 0.021485	 0.0	 717.0	 717.0	 717.0	 1.103079	 0.0	 1	 -30.0	 30.0;
	3469	 6430	 0.0	 0.019737	 0.0	 1735	 1735	 1735	 1.092105	 0.0	 1	 -30.0	 30.0;
	3486	 6431	 0.0	 0.314388	 0.0	 110	 110	 110	 1.048889	 0.0	 1	 -30.0	 30.0;
	3486	 6432	 0.0	 0.314388	 0.0	 110	 110	 110	 1.048889	 0.0	 1	 -30.0	 30.0;
	3486	 6433	 0.0	 0.314388	 0.0	 110	 110	 110	 1.048889	 0.0	 1	 -30.0	 30.0;
	3497	 6434	 0.0	 0.156299	 0.0	 220	 220	 220	 1.053333	 0.0	 1	 -30.0	 30.0;
	3527	 6435	 0.0	 0.044965	 0.0	 261.0	 261.0	 261.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	3526	 6436	 0.0	 0.020227	 0.0	 707.0	 707.0	 707.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	3588	 6437	 0.0	 0.214367	 0.0	 161	 161	 161	 1.026667	 0.0	 1	 -30.0	 30.0;
	3588	 6438	 0.0	 0.214367	 0.0	 161	 161	 161	 1.026667	 0.0	 1	 -30.0	 30.0;
	3600	 6439	 0.0	 0.733548	 0.0	 47	 47	 47	 1.044444	 0.0	 1	 -30.0	 30.0;
	3680	 6440	 0.0	 0.431133	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	3680	 6441	 0.0	 0.431017	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	3663	 6442	 0.0	 0.046748	 0.0	 498.0	 498.0	 498.0	 1.066667	 0.0	 1	 -30.0	 30.0;
	3695	 6443	 0.0	 0.283636	 0.0	 122	 122	 122	 1.022222	 0.0	 1	 -30.0	 30.0;
	3718	 6444	 0.0	 0.155048	 0.0	 222	 222	 222	 1.0	 0.0	 1	 -30.0	 30.0;
	3717	 6445	 0.0	 0.155048	 0.0	 222	 222	 222	 1.0	 0.0	 1	 -30.0	 30.0;
	3716	 6446	 0.0	 0.155048	 0.0	 222	 222	 222	 1.0	 0.0	 1	 -30.0	 30.0;
	3721	 6447	 0.0	 0.327904	 0.0	 105	 105	 105	 1.05641	 0.0	 1	 -30.0	 30.0;
	3721	 6448	 0.0	 0.327904	 0.0	 105	 105	 105	 1.05641	 0.0	 1	 -30.0	 30.0;
	3721	 6449	 0.0	 0.327904	 0.0	 105	 105	 105	 1.05641	 0.0	 1	 -30.0	 30.0;
	3721	 6450	 0.0	 0.327904	 0.0	 105	 105	 105	 1.05641	 0.0	 1	 -30.0	 30.0;
	3799	 6451	 0.0	 0.06037	 0.0	 568	 568	 568	 1.031422	 0.0	 1	 -30.0	 30.0;
	3983	 6452	 0.0	 0.317591	 0.0	 109	 109	 109	 1.022222	 0.0	 1	 -30.0	 30.0;
	3988	 6453	 0.0	 0.329412	 0.0	 105	 105	 105	 1.044444	 0.0	 1	 -30.0	 30.0;
	3988	 6454	 0.0	 0.329412	 0.0	 105	 105	 105	 1.044444	 0.0	 1	 -30.0	 30.0;
	4012	 6455	 0.0	 0.302312	 0.0	 114	 114	 114	 1.034667	 0.0	 1	 -30.0	 30.0;
	4012	 6456	 0.0	 0.290091	 0.0	 119	 119	 119	 1.04	 0.0	 1	 -30.0	 30.0;
	4012	 6457	 0.0	 0.290101	 0.0	 119	 119	 119	 1.04	 0.0	 1	 -30.0	 30.0;
	4012	 6458	 0.0	 0.175059	 0.0	 196	 196	 196	 1.103555	 0.0	 1	 -30.0	 30.0;
	4038	 6459	 0.0	 0.167949	 0.0	 205	 205	 205	 1.048889	 0.0	 1	 -30.0	 30.0;
	4038	 6460	 0.0	 0.167949	 0.0	 205	 205	 205	 1.048889	 0.0	 1	 -30.0	 30.0;
	4044	 6461	 0.0	 0.733625	 0.0	 47	 47	 47	 1.08	 0.0	 1	 -30.0	 30.0;
	4044	 6462	 0.0	 0.733625	 0.0	 47	 47	 47	 1.08	 0.0	 1	 -30.0	 30.0;
	4136	 6463	 0.0	 0.088828	 0.0	 387	 387	 387	 1.022222	 0.0	 1	 -30.0	 30.0;
	4180	 6464	 0.0	 0.009303	 0.0	 1587.0	 1587.0	 1587.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	4179	 6465	 0.0	 0.009303	 0.0	 1557.0	 1557.0	 1557.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1693	 6466	 0.0	 0.035942	 0.0	 336.0	 336.0	 336.0	 1.081023	 0.0	 1	 -30.0	 30.0;
	1692	 6467	 0.0	 0.019697	 0.0	 655.0	 655.0	 655.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	1690	 6468	 0.0	 0.037419	 0.0	 447.0	 447.0	 447.0	 1.11579	 0.0	 1	 -30.0	 30.0;
	1689	 6469	 0.0	 0.037117	 0.0	 505.0	 505.0	 505.0	 1.11579	 0.0	 1	 -30.0	 30.0;
	4246	 6470	 0.0	 0.244364	 0.0	 141	 141	 141	 1.044444	 0.0	 1	 -30.0	 30.0;
	4246	 6471	 0.0	 0.244364	 0.0	 141	 141	 141	 1.044444	 0.0	 1	 -30.0	 30.0;
	4254	 6472	 0.0	 0.226	 0.0	 152	 152	 152	 1.048889	 0.0	 1	 -30.0	 30.0;
	4254	 6473	 0.0	 0.226	 0.0	 152	 152	 152	 1.048889	 0.0	 1	 -30.0	 30.0;
	4256	 6474	 0.0	 0.3396	 0.0	 103	 103	 103	 1.069841	 0.0	 1	 -30.0	 30.0;
	4255	 6475	 0.0	 0.3396	 0.0	 103	 103	 103	 1.069841	 0.0	 1	 -30.0	 30.0;
	4261	 6476	 0.0	 0.148936	 0.0	 231	 231	 231	 1.073333	 0.0	 1	 -30.0	 30.0;
	4278	 6477	 0.0	 0.012611	 0.0	 1065.0	 1065.0	 1065.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	4277	 6478	 0.0	 0.012611	 0.0	 1057.0	 1057.0	 1057.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	4286	 6479	 0.0	 0.1992	 0.0	 173	 173	 173	 1.044444	 0.0	 1	 -30.0	 30.0;
	4286	 6480	 0.0	 0.1992	 0.0	 173	 173	 173	 1.044444	 0.0	 1	 -30.0	 30.0;
	4286	 6481	 0.0	 0.1992	 0.0	 173	 173	 173	 1.044444	 0.0	 1	 -30.0	 30.0;
	4499	 6482	 0.0	 0.092765	 0.0	 370	 370	 370	 1.065789	 0.0	 1	 -30.0	 30.0;
	4520	 6483	 0.0	 0.1195	 0.0	 288	 288	 288	 1.044444	 0.0	 1	 -30.0	 30.0;
	4520	 6484	 0.0	 0.1195	 0.0	 288	 288	 288	 1.044444	 0.0	 1	 -30.0	 30.0;
	4686	 6485	 0.0	 0.012769	 0.0	 1108.0	 1108.0	 1108.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	4687	 6486	 0.0	 0.012769	 0.0	 1070.0	 1070.0	 1070.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	4688	 6487	 0.0	 0.012769	 0.0	 1140.0	 1140.0	 1140.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	4689	 6488	 0.0	 0.012769	 0.0	 1146.0	 1146.0	 1146.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	4756	 6489	 0.0	 0.050588	 0.0	 679	 679	 679	 1.048889	 0.0	 1	 -30.0	 30.0;
	4756	 6490	 0.0	 0.050588	 0.0	 679	 679	 679	 1.048889	 0.0	 1	 -30.0	 30.0;
	4755	 6491	 0.0	 0.050588	 0.0	 679	 679	 679	 1.048889	 0.0	 1	 -30.0	 30.0;
	4787	 6492	 0.0	 0.16148	 0.0	 213	 213	 213	 1.155555	 0.0	 1	 -30.0	 30.0;
	4787	 6493	 0.0	 0.16148	 0.0	 213	 213	 213	 1.155555	 0.0	 1	 -30.0	 30.0;
	4787	 6494	 0.0	 0.16148	 0.0	 213	 213	 213	 1.155555	 0.0	 1	 -30.0	 30.0;
	4934	 6495	 0.0	 0.044965	 0.0	 764	 764	 764	 1.080978	 0.0	 1	 -30.0	 30.0;
	4933	 6496	 0.0	 0.044965	 0.0	 764	 764	 764	 1.080978	 0.0	 1	 -30.0	 30.0;
	4942	 6497	 0.0	 0.070769	 0.0	 484	 484	 484	 1.026316	 0.0	 1	 -30.0	 30.0;
	4999	 6498	 0.0	 0.15125	 0.0	 227	 227	 227	 1.044444	 0.0	 1	 -30.0	 30.0;
	4999	 6499	 0.0	 0.15125	 0.0	 227	 227	 227	 1.044444	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Line Capacity Model:         ub
% INFO    : Gen Active Cost Model:       stat
% INFO    : Setting Flat Start
% INFO    : Line Capacity PAB:           15.0 (deg.)
% INFO    : 
% INFO    : === Generator Classification Notes ===
% INFO    : PEL    366 -     5.97
% INFO    : NUC    19  -    14.56
% INFO    : SYNC   20  -     0.00
% INFO    : COW    240 -    55.38
% INFO    : NG     727 -    24.10
% INFO    : 
% INFO    : === Generator Active Cost Stat Model Notes ===
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 53.5043912621 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.5083749493 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 10.7164347155 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 129.027919481 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 100.545331496 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 15.8890826279 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 118.691084862 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.3189625645 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.7093107132 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.7705610129 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.007581038 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 27.4180903128 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.8331332231 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.3528512685 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 129.030581406 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.84116923 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.7460028984 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4944134907 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.664437147 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 14.4148455017 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.1401057962 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 134.972243628 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.1655834041 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.9523128925 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.2965653064 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.9980051365 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.2066235131 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3959639982 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 54.0773432864 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.061703101 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.3690397939 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 6.32167609081 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.466108748 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 91.8977416849 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.294976754 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 11.152294438 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.3883689891 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.5468108971 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 121.131138332 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 51.5147404854 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.490797922 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 14.6197510242 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.413178979 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.7799211447 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.726624118 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.100245382 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.006697258 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.0126980775 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.7312814733 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 121.021000066 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.8958764074 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.057743139 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.81571337 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 9.09666402267 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 97.2289578389 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.7203005778 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.635346851 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1649945633 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.728595446 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.9285708899 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.7620800373 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.9894072504 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.621263536 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.4602801352 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.108740407 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.0451060429 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 133.217831273 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.1229230582 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.8343375419 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.0087528872 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.424625817 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.1496036328 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 17.4330947984 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 88.8547292998 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 121.482491731 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.558002565 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.192971674 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.621395323 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.202183834 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6181447233 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 104.658891653 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.9399164052 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.8209991153 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.9941290832 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.2898661077 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.795835856 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 92.1692374289 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 95.6416172393 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.503477074 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.747566513 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.470558324 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.562995962 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.4873786199 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 15.9410051871 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.547378654 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.410253814 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.3029988479 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.7475643144 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.9189070653 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 30.1361922207 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.662852923 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.8322885797 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1466539083 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.099223831 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 33.9470055003 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.763597262 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.9476860889 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 35.3847783933 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 50.1618352357 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 16.173482539 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.3290666014 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8307716833 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.4391677753 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.7665525574 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.034252073 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.256660952 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.9036920259 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5714608223 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.8244180189 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 9.52270792874 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.1487536521 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.1071045194 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.903003465 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 18.9689897931 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0252695503 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.667930559 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 115.801775613 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.500034168 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.2187406493 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 29.9861235607 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.2872703934 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.6957022886 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 16.0419353345 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 124.968065943 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.9003624546 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 19.7468085108 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.4194028365 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4365050913 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 130.177918094 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.83310247036 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.5563419436 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.9710759234 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.5532804947 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8598241703 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6305326198 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.6669345022 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.167120701 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2204551995 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9278728637 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 11.6745294488 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.8465503848 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.7137745813 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 15.8470046179 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.8641132119 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8797013682 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.5116665727 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 132.395456178 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.0790789516 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.404017205 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 122.272007564 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.745818726 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 100.162213732 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.482600461 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.346571967 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.1567018533 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 98.0898554357 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.2004352425 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.577846453 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3913936117 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.7702501851 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 115.744771316 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 138.641656665 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.864791397 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.2836293416 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.4700977848 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.8398444806 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.9704889746 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 6.35438402392 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.132302951 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.870541081 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.6992115372 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.298901416 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.034773878 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.150146075 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.9688468996 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7884199105 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 128.248742919 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.8754021357 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.050134886 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.3771642926 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.598025113 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.263035488 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.9395887289 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 20.6791945699 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 100.517788896 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.3347683914 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 19.3914581175 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.56194758 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.9557386189 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7610499853 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.494228114 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.5718876582 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 115.026723668 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.3946771135 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.636319785 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.9823910686 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.5046505192 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 29.80558599 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.3794636369 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.7579146772 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.6767665778 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.7156952394 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 119.47601869 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5458345243 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 92.0780917232 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2858350835 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.334015717 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.731996138 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.72331812 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 50.8696011124 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.8177609676 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.3098501298 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.924163465 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.5566446285 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 48.7548621628 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 122.302038191 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.6530674953 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.594260469 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.615332232 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.8027555982 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 121.101408033 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.038287323 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.7209311907 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.4256199964 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1478822689 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 36.7540822376 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.8277754511 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 27.7153244527 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.578581401 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8697110432 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.87011496 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.1813342542 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 19.5399395266 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 41.8485556063 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.9403253003 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.3268938763 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 31.815730864 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.0119418866 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.2626568785 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 29.9944616841 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.3717092744 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.1386895082 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.744818057 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.3608770749 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.886360552 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.216732119 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 121.104955851 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.0556058653 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.6386791683 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 134.638269124 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.761227489 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.3697809066 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.8457894126 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.553580835 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 37.6019848881 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 15.0183909829 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.5894963809 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.917491689 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.357952795 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.542482488 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.3358445772 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9934001048 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 17.9188548945 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 11.727762303 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.1538956317 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.286856836 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9159117495 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.117753842 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 124.289113368 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0739663766 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.4212719553 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 0.133192135549 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.3311509028 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.5202428595 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.8412387032 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.3998369005 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.617246131 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.3153840862 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.536590394 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.07264623 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.0572929165 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 87.795878501 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.8371210699 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 135.532859986 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.8718429646 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.231328122 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4647181731 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.897480036 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.1260857569 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.1873259123 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.451627493 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 19.6775886734 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 128.302657091 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.0397614956 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 118.824371017 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.244243301 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.3412297172 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.3069877758 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.642352162 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.702597118 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.4265513769 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.849093615 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 17.8957549858 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1572517944 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 126.112119528 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.6060185465 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3868046314 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0874176692 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.2722636167 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 97.8199815518 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 18.5878482927 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 53.1953868081 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7762891542 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3118739916 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.646978976 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 110.004483319 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.0106246929 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.6017674916 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.9221034293 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.5909639309 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 20.7385230681 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 53.1939882839 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.0035846492 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.519030695 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.724858 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 27.9999747342 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.7043864953 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 100.772810002 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.1901880604 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 98.1919625142 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.368400457 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.889789664 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.0558134207 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.6833860642 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.6784932831 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3061140151 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8969880876 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.1655159303 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.6420111351 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 13.3740064892 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.8002230927 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0833241923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.5017153436 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.8966264788 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 12.73528579 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.4050069886 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.3185133935 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 110.181664567 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.633308851 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.8329491227 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.915855633 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.139503873 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.322037788 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.2841255156 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9400315411 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 4.33192527241 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1490496096 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.5272509 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.6448928401 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.064947343 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 125.781764678 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 118.262997601 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.9545835993 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.2929254977 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 50.1505106995 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.223458902 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.857253099 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.2805061991 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9133972797 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 95.5848312006 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.494743148 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 97.8806406002 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.1113536711 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.613212941 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.5657326823 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.2134455629 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.305747947 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.4395285206 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.500586713 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.4312102513 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.3402119986 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.781023187 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.936706554 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9625652606 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.3777477477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.2496670855 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 18.6222341511 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.834478134 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.1492939965 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.150373087 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.4255582006 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1274997106 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.32111728 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.5065487633 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.070454 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.7357307215 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.344315858 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.024000294 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.451467636 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.9647826857 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.2274987405 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.6505530572 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.8801685465 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.5179039521 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 104.070664854 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.9545349132 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1701730498 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1887129667 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.0264364373 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.8521763317 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.3826341811 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.2499865311 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.0504066155 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.417656433 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.2127090116 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 19.401372368 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.677057446 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8595941257 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.4036547862 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.1467894549 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.2002404851 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.4140066349 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.1963545157 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0285804213 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.86657241 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8485187407 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.6011471145 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 9.76611919814 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.16871734 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.078798302 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9831445676 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.3838117254 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.2571682932 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.341794893 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.2936313146 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.9996836783 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.90335269 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.6688686506 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0472013506 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 110.484977945 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.6442063758 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.6380696145 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.707770883 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 48.1542378429 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 138.506829023 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0305665608 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.927216946 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.2151723862 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.8858438901 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.0883298933 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.2764647886 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 97.8473309815 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.848192582 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.716749423 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.4771185204 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.8467563356 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.751601535 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 22.8683788396 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7216002915 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9972369871 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 65.5079176814 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3133738811 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.9648432503 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 92.0751292827 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.3933009411 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.1078120536 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 12.7250456377 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 119.605194551 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 132.003039447 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 96.3553319666 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 124.422127519 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.086485628 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.5341100572 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.0858383918 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 16.4050891754 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.662443406 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 15.536947646 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.4877813817 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.2484769699 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 124.512549651 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.8389044775 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.2764763959 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.565328206 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 30.2383504906 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.5954013475 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.261471002 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.513455633 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.6644637384 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.260844976 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.742603246 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.190346819 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.096903639 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4099864479 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.4703538655 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.9202282836 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.812344355 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.3398351643 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 115.717086666 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.1019275877 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 97.4551195197 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.712617717 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7940784825 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 96.9858905898 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 14.5060693412 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1970936799 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.34080565 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.8531834329 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.6891103322 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.6909783615 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.2109893452 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.1711930838 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.1072891588 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 20.4114383652 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.2180398775 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 133.775849763 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 92.6289764229 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.237875072 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.1504208783 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.841165134 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.053767358 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.8531433353 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.7677240194 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.3326269663 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.315050155 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.495736704 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 131.245704345 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.054415147 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 102.584784692 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9331771171 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 121.449934363 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.1210303289 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9911317378 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.997478554 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.524262406 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.664502786 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 17.9916888682 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 118.637487845 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 14.9574975457 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 96.2819635263 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 115.268185424 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.1436361902 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.9861736518 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.864283955 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.8109898806 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 13.5951480471 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 19.188045758 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.253533169 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.0573169519 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.5050480592 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.8217133 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 7.01033836832 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.297507846 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.479085098 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 123.167607568 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 97.1820262568 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8827646651 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.0235432723 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.945657041 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 18.8762674125 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.2734090573 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.5130133615 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 48.2965112343 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 104.806044219 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.1853427812 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.7827201876 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.830132958 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.5020183719 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.6497427544 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 18.6306198991 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.640081524 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.431664265 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.9200551207 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 29.2472374959 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 51.0527314673 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 19.3433639543 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3962540606 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7215899115 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.1562116432 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.241672024 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 47.4293708309 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.501720838 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.8440562421 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.400621353 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 12.9045248455 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 54.4390863824 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.8876423614 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.4340082173 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6664617693 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 11.8287476208 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 14.8761016864 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 98.5462563764 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.2947473268 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.3112796603 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 35.2324862871 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.639583407 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.1094631375 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.142084735 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.920231454 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 36.6399380188 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.5219175525 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 16.9237674053 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 50.2815152565 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2319511721 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.8069352001 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.7690399009 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.362765143 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9604266324 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.644307893 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3919089874 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.1747889035 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.4850403317 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.300910952 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.2005598795 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.9702908116 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.551098063 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.9051709135 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.3589607 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.8225664355 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2128787625 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1429915883 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 104.599628561 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.2819814087 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6339089409 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7290965941 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.418031705 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.862767211 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7045753797 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.172382779 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.1844908927 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 119.531884549 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4050207328 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.6953056534 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.1759932292 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.6492993395 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.840106001 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.9023031806 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.607767544 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.742165376 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 43.9567316393 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.4863930343 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.89127862 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.1633968279 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 96.9741568642 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 143.864171154 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.749825441 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.660064832 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 98.1931805081 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.4459227381 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.411411964 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.593913591 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.83680103 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 23.2393867467 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.173513235 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 94.84979746 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.39183147 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 110.707712549 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.883368228 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.6736271556 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.4712605176 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7670800327 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.1607973332 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.479473709 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.731236466 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 18.3364550898 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.5830011215 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.2692860974 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.7121486239 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 123.660500486 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5357415806 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 15.8517285952 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.957786611 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9595881014 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.764055902 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 97.2493946221 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 42.8361130041 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.7409527071 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 122.774514321 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.4491119087 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 20.4709476232 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.289996276 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0605779955 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.0860748572 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.1149084043 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.738011287 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8592651215 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8657821442 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.128479866 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.4046409358 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.979384329 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.1823054608 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1621622963 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.2551628731 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 21.0388614743 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 7.07249259588 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.184459285 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.169231631 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 56.3625018728 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.7466670863 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1057249491 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.2937512078 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.220248866 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.764868106 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.0262989988 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.54324661 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.772780021 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.3370615469 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.4792859314 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.462204743 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.7578047235 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8200818319 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.7280318854 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2148816537 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8389331582 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.026714911 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 97.1689910452 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.140529636 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2710005983 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.0588364602 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.613946884 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.3909910892 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.291675987 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.2632138571 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 129.823149408 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1625436251 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.144457554 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.810632711 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.739198596 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 118.23767416 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.4489000583 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.4552940502 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.9319324477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.6229139065 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.745894446 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.9224018647 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.5296405563 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 51.9385324994 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.1066572089 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 37.4495236196 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.8248041023 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.486693958 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.4730234583 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.726453119 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.754008619 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 47.1226468823 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5582976198 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 15.2364593285 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.7416180274 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.3300731088 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 125.681780732 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3384364254 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.253470067 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.9136117274 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.3948857656 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.0242200053 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 46.1273092407 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.093697676 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 21.0076787229 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.315560148 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 31.7287230023 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7365980314 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 22.6045257565 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.465622807 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.102652078 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 56.5306591445 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 102.222540896 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 9.49719599225 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.21034198 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.433174895 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.4456966966 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.7977372313 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 123.584552618 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 17.4871621437 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.7954164978 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.6518980776 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.1477238483 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.334882661 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.473939343 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.092701585 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9035203913 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.847230387 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.8201387105 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.7652454833 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 123.908024278 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.867838389 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 29.6218313154 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6325120278 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.596281504 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.284079022 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.79716749 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7141614249 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1226009025 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.4900315325 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.072655687 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 13.5053712433 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8536122854 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.666099008 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 123.727478385 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 26.2701610207 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.4086212635 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.4155388618 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.3027342178 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.759389688 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 4.07218645889 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 17.3548365473 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.9370480064 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 103.33778883 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.1711531072 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.653994134 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.359756956 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.607071204 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 47.0657164887 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.12396657 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.594654306 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.5937150566 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.2636896552 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 122.585600414 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.653161348 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.3432437289 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 65.4832513327 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 124.723218986 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.7415814799 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.9882364606 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 109.30640327 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 110.847342201 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.3286796078 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.9308726215 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.249097905 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 91.2038478425 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.8555219027 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.737148923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.8202968285 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.9488068063 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 16.3991188094 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5473738871 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.2044235036 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.108851927 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.465202256 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.3014867658 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.672917857 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.619634992 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.310665485 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.6974388216 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6547136211 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.428617753 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.5769190073 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.0230333584 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.0469674311 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 44.9834430777 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 16.6742903708 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 106.102244878 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.443376458 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.9595515616 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3709879431 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.1378868366 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.6093075069 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.848316372 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 20.6981386 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7375412749 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.380911146 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.6570853105 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 33.0751541956 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 18.4687357958 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.0133349135 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.6279809556 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 99.8389629085 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 33.0341323637 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.5563528194 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 19.6981232021 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.889535469 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 113.401669938 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.4566259328 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 96.4012532325 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.359153397 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.849954813 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2805001227 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 107.471322285 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.31454529 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 104.244389475 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 123.007953893 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 115.499049689 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4514568847 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.0659666117 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.3989640441 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 110.211982636 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.7408848491 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7899439305 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.34034722 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.296567619 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 19.1598883846 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.196148062 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.0958310885 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.7330303831 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 92.1177117111 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2332829462 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 123.799252833 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.8703902394 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 19.4920902788 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 22.458224017 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.1185833329 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7347427765 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.726065847 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.4980107241 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.158729642 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.2871200546 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.6990037763 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.0372063747 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 48.9596530298 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.9073044392 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4277632479 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.1775328307 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.4149539518 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.7782056936 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.9483908684 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.6911674151 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 48.8275329145 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.0892632227 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.5153296789 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 10.7441650021 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.3268675905 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.2468224668 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 131.102428559 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 104.173079518 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.152532631 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.096129984 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4662376158 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.2753334388 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 92.6647222956 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2597314824 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6678494239 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.771739696 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.649248219 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.515063647 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.3400184104 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.8812996171 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.6817588763 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 137.516744537 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6711861598 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.5262875405 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1485170849 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.287178332 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5154241065 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.2488579214 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.3122798811 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 51.7220133087 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.466431317 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.4223850569 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 125.5791883 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 116.300095902 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.59571591 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.06980706 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.2252436615 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 96.5916567981 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.1887301665 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.1516464704 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 105.697845611 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.966962439 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 10.5442637689 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.1941778953 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 22.909957885 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.3755913292 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 112.549725069 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.95437575 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.4369930171 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 46.600347154 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.9593126452 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 16.1386055955 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 34.0992338395 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8400257933 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.8627032852 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.3888451902 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.2202390288 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 27.4439325276 0
% INFO    : Updated Generator Cost: NUC - 0.0 2.0 0.0 -> 0 7.49141042289 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.376419248 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 111.803953324 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.5190764388 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9985394547 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.5924810892 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 52.7259209915 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.6276640015 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 35.4397550602 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.8533793637 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.3615727011 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2322089725 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NUC - 0.0 2.0 0.0 -> 0 6.85435017811 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.0732942945 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3647340449 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.3755726604 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.3727716311 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 21.7727268155 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.45340010193 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 3.77928064777 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0308406056 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.8939047309 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.3368078668 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.3061486716 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6525623529 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.4590169777 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2818927706 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1258895812 0
% INFO    : Updated Generator Cost: NUC - 0.0 2.0 0.0 -> 0 6.89185933482 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.234366286 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.5873072652 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9056975449 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3709309719 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 36.9952667824 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.0511843225 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8987516377 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.978435198 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.4960063896 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.6460626127 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8092361782 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.3675021673 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2161559465 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.5202586321 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.8190769182 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 15.3485196711 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 18.4349199466 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 19.7072565463 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 15.6777473929 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.0939365302 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 9.05070828477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9449371356 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.5086949314 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.7913020291 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7540218325 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.7131909536 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7487533938 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 6.19361377091 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.8532449125 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.6486209602 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0076616399 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1879530874 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 18.2201979225 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 108.776015112 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.3043308394 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.224365692 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6571560821 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5183211916 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.5964807841 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.3219922724 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1780902813 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.4739260347 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3032824266 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.0620698408 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5805376977 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.517322613 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5473051913 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.5103795686 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 23.9297442461 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 31.3277368013 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 13.5057504347 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7720849733 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 2.99330295322 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.4241496226 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.9712112778 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4145302903 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.404067054 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9050276463 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 14.9493643386 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.8589009532 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.3171989471 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9904462519 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9564710103 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.4320031505 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.6565706201 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.74014823353 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 13.4684821815 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.669501596 0
% INFO    : Updated Generator Cost: NUC - 0.0 2.0 0.0 -> 0 6.87149153629 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 26.3963890862 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 8.48971132739 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.5146544664 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 26.5707866682 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 20.4430211237 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.3857195303 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.0020742014 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8222460658 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 26.8208526668 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.7779854848 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3873948861 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.9222529288 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.8035471736 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 97.2382206927 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.1966947774 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8990005033 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.1158248483 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 16.7319988508 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.2503864302 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.0805823761 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.0482035045 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 30.3663120437 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 20.9080333337 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.728270967 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.292867177 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5675973022 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.540257488 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.7345230116 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.5584143026 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.1584683211 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.2490630481 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.0386857772 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.441779512 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2083207158 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1647639786 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.4180783234 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6459299634 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.808832218 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.2213094419 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.90134700118 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.23064893715 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.5674952277 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.2898798624 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.3836677264 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2615800067 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.6166153442 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1355487251 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.5113331618 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.1803615903 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4989955924 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5310414791 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.4405096782 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.618730706 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.242966429 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.7202737867 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3500168072 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2010421034 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.2403920892 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.2984617507 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7365787345 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.2458101374 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.29549977948 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.5796618688 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7689452571 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.4500018211 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.7331119929 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.8556873954 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.3683823564 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.250207832 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.2971670127 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0429423597 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5445261712 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.5681314344 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.76879566753 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.4222643432 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.3746860725 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.5182873672 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.094091316 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6747183377 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.3746465621 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.60467076143 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.7520364635 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.00498169901 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.5284825224 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3794995087 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.187341188 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.5089892034 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2032452249 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9573235295 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 20.9301857499 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.5427532712 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.7081640746 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 16.8975142888 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.796662666 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.667639795 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.3552362926 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.9443829923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8976795983 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.7624358884 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.757003013 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.839658749 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.01581892221 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.56127826772 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.4956962647 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.5569459441 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8261202603 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8240606278 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.9941098499 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.886295631 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.1971455978 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.4352624623 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5047061826 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.6818959719 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.2162354973 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 48.4760760801 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 96.8427405658 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.1146354714 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.0617891625 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.1104724633 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.219919305 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.6996063838 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.5871957162 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.236064991 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.5969233973 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.53285321869 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.2964944225 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 61.7377853884 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.593143178 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.599997934 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 93.6975060377 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.4174962031 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.8142077328 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.38377070757 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.3272774852 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.7177751666 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.9703770986 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.7313792103 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2724390357 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7991620414 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 22.0715857923 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.0456298087 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.149055512 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6764971238 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4096396752 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.322287527 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.433521936 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4525825844 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.0229461526 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.824477037 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.7088677024 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.2741460935 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.91157194 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 17.629003616 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.7042113651 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7411338492 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7844077774 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.5291919647 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2667365535 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.5585231 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4168327069 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.671138909 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.512347304 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1019863211 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.4479290861 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4649053164 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.9767541024 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.831324318 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.0630115981 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2939307331 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8212703941 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 94.3298693548 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5641625113 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.7821308744 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0245123873 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.3971007143 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.7275742132 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.4746618784 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.8850837825 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.4600632237 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0069669462 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.8699384982 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.317695628 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 92.210437756 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.6505713505 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.4242893352 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1872908858 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0689923828 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.9463836595 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.3044795446 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.3318192191 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.6870338401 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.252428746 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.9792781507 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.473339677 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.1318922694 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.5295843545 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.670388552 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.059519873 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.8140513255 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.5098833204 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 28.3106629627 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.7679889399 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 26.7021197942 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0886504296 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0457490273 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.436943966 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 44.7190669657 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.8790978109 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.2565878188 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.347433949 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1434283698 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.2002213783 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.9777078166 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9240145572 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.8480089246 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.4739040753 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 25.6662979858 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.9391578451 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.8817819789 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.649510386 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 11.3024035188 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.8942823115 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.6613724534 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.2543355167 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3212005437 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.131475343 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9644555551 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.3065139571 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2984028698 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0039555775 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.908630889 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.9484255691 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.376720161 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.144248641 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.772411934 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4558504081 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.7836029887 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7036891461 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.9958662036 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.7397083533 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4502019505 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9548784744 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5250956506 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7997240262 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.733866397 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0440869406 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.677509437 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.2421754764 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9995154305 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.9897350097 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.7547479395 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.9915803098 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.7401996178 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.373078869 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.7951758916 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4105241039 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.2587140111 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.13974797332 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.770177546 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.6649295375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.5366725099 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.9307740267 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.445173729 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.0631210549 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.931619524 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.8434519123 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4147492036 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.66415121 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.3084770158 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6696928467 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.5557587453 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.1515553524 0
% INFO    : 
% INFO    : === Generator Bounds Update Notes ===
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% WARNING : Transformer 4639-1 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5234-1 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1676-2 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1667-3 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2296-3 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 695-4 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3931-4 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5036-4 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4405-5 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2772-6 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2773-7 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2459-8 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 470-9 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 11-10 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 11-10 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 30-11 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2922-11 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2174-12 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4009-12 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4011-12 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 115-13 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2330-13 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4569-13 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 116-13 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1220-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2867-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4587-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4945-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5220-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2867-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4587-14 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2899-15 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4116-15 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4447-15 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 249-16 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 337-16 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5824-17 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3719-18 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5084-19 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3719-20 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1349-21 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1592-21 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1837-22 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5013-22 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1152-23 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2696-23 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3418-23 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 144-24 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1277-24 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 490-25 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2086-25 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 612-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1860-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2595-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2915-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3332-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4624-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2915-26 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 536-27 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2343-27 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2677-28 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3884-28 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2880-29 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3314-29 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3314-29 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 144-30 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1548-30 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4831-30 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 150-31 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3155-31 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3684-31 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4733-31 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 150-31 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3721-32 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 366-34 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1012-33 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1153-33 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2573-34 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2697-34 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4738-33 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4848-34 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5661-33 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 368-35 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1104-35 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2143-35 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3128-35 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 367-36 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2143-35 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2143-36 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5219-37 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5505-37 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 725-38 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1224-39 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5799-39 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1224-39 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2244-40 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4587-40 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 430-41 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3945-41 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1479-42 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2758-42 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2717-43 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3481-44 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4314-44 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5087-45 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1080-46 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2187-46 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3298-46 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1080-47 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5353-48 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1218-49 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2338-49 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 470-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1670-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3546-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4621-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3546-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4621-50 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1191-51 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1192-51 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 166-52 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5479-52 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3342-53 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2762-54 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 373-55 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2686-56 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3420-56 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5088-57 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3383-58 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3558-58 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 142-59 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1646-59 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2469-60 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3518-60 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2221-61 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2627-61 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2041-62 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2943-62 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 371-63 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3074-63 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 145-64 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5098-64 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4599-65 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4599-65 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1541-66 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2285-66 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3242-66 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3023-67 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2876-68 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4529-68 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5141-68 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4602-69 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5089-70 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2158-71 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3138-71 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5090-71 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3138-71 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3738-72 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3738-73 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5098-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5118-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 145-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4954-75 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2077-75 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3075-76 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3824-76 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2337-77 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 240-78 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4554-78 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 630-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1865-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2403-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4069-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 630-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4068-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4070-81 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4070-80 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 675-82 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 798-82 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2066-82 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3478-83 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2122-84 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3794-84 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5093-85 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2802-86 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3504-86 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3763-87 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4338-87 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3763-87 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1611-88 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1700-88 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3635-88 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5549-88 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2489-89 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4218-89 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5094-90 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3719-91 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 648-92 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4048-92 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5719-92 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2130-93 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3760-94 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5834-94 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 283-95 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1169-95 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5695-95 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4102-96 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2994-97 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4168-97 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4437-97 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2994-97 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1247-98 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3510-98 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4644-98 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2626-99 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2627-99 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 552-100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1189-100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1190-100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1898-101 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4441-101 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1474-102 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1957-103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2480-103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4273-103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1957-103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1664-104 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5484-104 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 263-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1554-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2088-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3532-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2201-106 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2265-106 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3255-106 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5060-106 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2993-107 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2993-107 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3971-108 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3970-108 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 633-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 672-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 760-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5193-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5197-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4732-109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 481-110 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5395-110 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5499-110 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 714-111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4434-111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1163-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1650-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2289-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5304-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1164-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1649-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2289-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1648-112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1028-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1071-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5254-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1028-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1071-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5253-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1071-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3514-114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3986-114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1239-117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1242-117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5399-117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5521-117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4954-118 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 996-119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4549-119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 996-119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2696-120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5224-121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5451-121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5096-122 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5096-123 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5097-124 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1259-125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1258-125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4301-126 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5728-126 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 179-127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2739-129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4251-129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5286-129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5732-128 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2739-128 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5285-128 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2982-130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3406-130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4567-130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4568-130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4568-130 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 783-131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1143-131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4034-131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4094-131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2188-132 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2727-132 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1703-133 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1185-135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1710-134 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3383-135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1879-136 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4807-136 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 626-137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3041-137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4519-138 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5175-138 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3550-139 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4743-139 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2995-140 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2995-140 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 851-141 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 185-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1646-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2211-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2212-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3883-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5715-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3883-142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1668-143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4125-143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1548-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1555-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3685-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5036-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5655-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1555-144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 505-145 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 696-145 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 759-145 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1045-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2714-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3365-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4594-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1045-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2714-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3365-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4595-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4594-146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4971-147 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 480-148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4234-149 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1988-150 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4260-152 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4512-151 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4694-152 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 156-151 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3568-153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5474-153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5716-153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5475-153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1955-154 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5099-155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 684-157 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4737-158 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5800-157 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1721-159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2757-159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2832-159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3684-159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5063-161 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5063-160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4615-162 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4661-162 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2216-164 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2216-163 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1405-167 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1585-167 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3611-167 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3777-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4171-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4488-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5133-167 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5183-167 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5400-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3442-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5844-166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3696-168 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5656-168 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3696-168 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5100-169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2563-170 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5580-170 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1558-171 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4613-171 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5791-171 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1558-171 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5668-172 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5669-172 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5103-173 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 445-174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5359-174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1937-174 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5143-175 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5158-175 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4711-176 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5112-176 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 180-177 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 180-178 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 911-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1444-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1488-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3460-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4927-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4932-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5664-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 912-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1444-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1444-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4930-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4931-179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 989-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1046-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1119-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1264-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2100-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2959-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4378-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4937-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5028-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 989-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2959-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4934-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4933-180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5104-181 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4403-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5105-183 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1031-184 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5378-185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5106-186 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5396-187 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2893-188 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2241-189 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5594-189 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5107-190 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2743-191 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4828-191 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 317-192 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5088-192 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4087-193 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2497-194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2773-194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5327-194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3208-195 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3208-196 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 321-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 573-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 930-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 321-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 826-198 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1754-198 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5108-199 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2448-200 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4552-200 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1376-201 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1482-201 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 392-202 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 829-203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1919-203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2062-203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2712-203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2985-203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 829-203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1919-203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1584-204 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2713-204 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5686-204 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2714-205 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5056-205 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 392-206 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1683-206 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5127-206 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 563-207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 563-207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5577-208 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5842-208 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3922-209 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1791-211 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4829-210 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1791-211 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3866-212 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3866-213 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 525-214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1177-214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1415-214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1732-214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1879-214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4063-214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4905-214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 352-215 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1131-215 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2885-215 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4617-215 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1983-216 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5410-216 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1513-217 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1577-217 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2762-218 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5111-219 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5109-220 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 255-221 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2038-221 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4392-221 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1594-222 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2938-222 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2307-223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4146-223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2307-223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5112-224 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3825-226 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3825-225 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1545-228 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1545-227 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 422-229 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3134-229 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4557-229 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 422-229 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2483-230 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 520-231 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1863-232 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4877-232 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3662-234 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3663-235 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 504-236 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1011-237 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3937-237 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2690-238 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5007-238 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2374-239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4602-239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5437-239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5729-239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 360-240 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4553-240 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 692-241 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4445-241 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5488-241 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1683-242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5682-242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3148-243 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3349-243 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1922-244 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2348-244 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5114-245 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 282-246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 479-246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 751-246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2444-246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4725-246 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3572-247 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3160-248 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2108-249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3561-249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1267-250 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1621-250 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2256-250 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2939-251 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4005-252 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5106-252 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3510-253 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3510-253 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1113-254 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3815-254 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4634-254 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 559-255 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1681-255 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4161-256 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4550-256 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4552-257 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1109-258 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 763-259 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1455-259 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4975-260 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5795-260 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5115-261 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1376-263 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1623-262 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2790-262 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4839-263 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5407-262 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1622-262 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2199-262 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1939-264 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2791-264 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5064-264 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2791-264 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5057-264 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 728-265 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 739-266 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1273-267 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1372-267 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3521-267 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3873-266 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1900-268 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2673-268 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 549-269 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5278-269 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2982-271 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2982-270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1409-272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1695-272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4442-272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4832-272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5245-272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5792-272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4442-272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1321-273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2982-273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1937-274 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1937-274 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 278-275 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1052-276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1515-276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2451-276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1515-276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2451-276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1056-276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1055-276 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 740-277 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 981-277 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1054-277 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 741-277 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1053-277 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-278 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3696-278 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2980-279 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2461-280 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4945-280 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5075-280 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2461-280 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1258-281 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5712-283 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 448-284 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2663-284 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3638-284 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5117-285 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5116-286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 960-287 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2316-288 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2905-288 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4626-288 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5426-288 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2619-289 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2789-290 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2165-291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2624-291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3148-291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5195-291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 292-293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 480-293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1564-293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1239-294 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5118-295 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1299-296 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1750-297 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4315-298 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2159-299 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2160-300 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5119-301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1340-302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1340-302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 197-303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4586-303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5737-303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 197-303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4586-303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4826-304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5401-304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 690-305 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4681-305 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3889-306 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2476-307 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4928-307 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1305-308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4574-308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1632-310 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1632-309 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5613-311 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3145-312 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2635-313 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5152-313 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5151-313 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 654-314 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3024-314 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1031-315 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5121-315 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2282-316 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5278-316 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5280-316 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2282-316 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3290-317 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3268-318 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5122-319 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1253-320 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1651-320 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 830-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2304-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3120-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3140-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4563-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2304-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3120-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3140-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3120-321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4142-322 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4143-322 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1929-323 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1929-323 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2305-324 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1676-324 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 522-325 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 521-325 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1839-326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2603-326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2918-326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4109-326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5367-326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4109-326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1790-327 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3079-327 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1789-328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1789-328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2265-329 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2265-329 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4389-330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4648-330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4741-330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4664-331 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4853-331 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4853-331 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1363-332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3676-332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1006-333 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1609-333 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2542-333 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4760-333 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5257-334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1133-335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2817-336 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4918-336 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2497-337 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2639-337 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1694-338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1858-338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3290-339 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3494-339 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5794-339 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3056-340 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3378-341 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3231-342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3880-342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5398-342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5124-343 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1859-344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4518-344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5290-344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 671-345 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1725-345 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1278-346 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5447-346 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4916-347 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 444-348 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3375-348 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3311-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3365-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3766-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3899-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4594-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4825-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3312-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3365-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3766-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3899-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4595-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4825-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3313-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3310-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4019-351 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 558-352 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 880-353 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2688-353 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5839-353 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5126-354 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1354-355 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 358-356 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1350-357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3144-357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3870-357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2293-358 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3023-358 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5129-358 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5608-358 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1683-359 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4015-360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4553-360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4919-360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5147-360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2440-361 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2441-362 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 490-363 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5103-363 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5102-363 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4391-364 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4733-365 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2132-366 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 859-369 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3383-369 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 860-370 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3004-371 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3074-371 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1897-372 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2169-372 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2755-372 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3756-372 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2168-372 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3383-373 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3544-374 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3657-374 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1169-375 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1774-375 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2575-375 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2093-376 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2097-376 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2097-376 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 647-377 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2322-377 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2766-377 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 401-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1252-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1532-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1903-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4084-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4891-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5010-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4891-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5010-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 469-379 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3094-379 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3934-379 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4085-379 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4992-379 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5149-379 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1931-380 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2068-380 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2764-380 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3935-380 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2067-380 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2764-380 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4284-380 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4004-381 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5270-381 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2423-382 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3689-382 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5415-382 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 937-383 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3791-383 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 937-383 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3791-383 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2434-384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5223-384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5751-384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2923-385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5768-385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3024-386 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1590-387 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2937-387 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2705-388 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3531-388 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1400-389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1876-389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3846-389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4681-389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1399-389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4590-390 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5720-390 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1719-391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1817-391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2323-391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2464-391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3932-391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5598-392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1907-393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 395-394 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1786-395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4559-395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1786-395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3863-396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4080-396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2392-397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3842-397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5186-398 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 849-399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2236-400 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2783-400 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2299-402 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2807-402 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2767-403 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5164-403 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2291-404 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3286-404 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1079-405 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1020-406 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1861-406 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4005-406 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2355-407 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2450-407 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2811-408 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3919-409 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 487-410 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1058-410 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1864-411 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3190-411 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1631-412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2041-412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3233-412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4072-412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1141-413 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1141-413 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4185-414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5134-414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1242-415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3664-415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4438-415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 545-416 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 857-417 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3670-417 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4120-417 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3733-418 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4306-419 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5137-419 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5135-419 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5135-420 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3547-421 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1478-422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1478-422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 850-423 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2774-423 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1562-424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3404-424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4013-424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4525-424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1562-424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4013-424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4013-424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2755-425 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5698-425 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5136-426 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1151-427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4674-428 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3865-429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5201-429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3865-429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1660-429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1047-430 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1265-430 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3290-431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3200-432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4000-432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 879-433 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1445-434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5466-434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 982-435 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2839-435 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3056-435 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5264-435 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3056-435 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3979-436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5694-436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2544-437 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2977-438 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1667-439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2212-439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5001-439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5140-440 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5138-441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2751-442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4208-442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1553-443 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1645-445 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2025-443 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4865-445 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5329-443 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1645-445 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2025-444 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4865-445 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4839-446 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5142-446 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3587-447 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1229-448 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2900-448 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3975-448 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2900-448 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1339-449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1430-449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4796-449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5595-449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 500-449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4796-449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 499-449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2239-450 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2756-450 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-450 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2239-450 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4904-450 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 501-450 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5146-451 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 462-452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2332-452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2692-452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3705-452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2332-452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3433-452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3539-453 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3658-453 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5147-454 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4058-456 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4058-455 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4237-457 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2993-458 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3613-458 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4670-459 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4670-459 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3167-460 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4013-461 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5473-462 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5148-463 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2705-465 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5150-466 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2178-467 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3474-467 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3554-468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2178-467 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3473-467 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3554-468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2178-467 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2980-470 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 972-471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3338-471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3736-471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2714-473 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2714-472 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4289-474 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4290-474 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2167-475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3867-475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5566-476 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3755-477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3755-477 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4037-478 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 642-479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1829-479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3571-479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 971-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1563-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2141-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2161-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3149-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1564-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2162-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2163-480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2142-481 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2007-482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2502-483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5433-483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5589-483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5594-483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 960-484 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4166-484 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3538-485 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5151-486 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1025-487 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1058-487 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 653-488 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3632-488 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2256-489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2611-489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2196-490 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5153-491 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3564-492 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5076-492 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 594-493 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 595-494 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 595-495 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 595-496 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 595-497 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2151-498 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2450-502 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2555-502 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5191-502 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3971-503 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3970-503 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 736-504 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1277-504 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1811-504 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5113-504 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5353-504 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2660-506 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4334-506 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5154-507 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5155-507 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3974-508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1559-509 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5220-509 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5610-510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5611-510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2993-511 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3086-512 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2571-513 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2961-514 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3146-514 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3229-514 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2962-514 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3147-514 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3230-514 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1077-515 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2580-515 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1190-516 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5446-517 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2260-518 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3206-518 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 565-519 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4190-520 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4302-520 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1402-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2883-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2919-522 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3665-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3830-522 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4258-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5648-522 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2919-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1341-523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1403-523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2873-523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2884-523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4458-523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5432-523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1341-523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 954-524 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2910-524 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1127-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1916-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2950-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3029-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3309-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4240-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4685-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4761-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5546-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5690-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4684-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1278-527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1441-527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4591-527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4697-527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1278-527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3530-527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4697-527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 529-528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1350-528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1837-528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1080-530 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 532-531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1392-531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1392-531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3872-534 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3872-533 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 663-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1351-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2872-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3452-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5672-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5673-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 663-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3452-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5529-535 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3252-536 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4766-536 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4766-536 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 646-537 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1316-537 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1352-537 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1189-538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5376-538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1130-539 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2094-540 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1340-541 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1341-542 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1341-543 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2084-544 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2676-544 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2979-544 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5766-544 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2885-545 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5668-545 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1679-546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5159-546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5568-547 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5589-547 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2591-548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5123-548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3064-549 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3193-550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1538-551 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2727-551 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3562-551 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5188-551 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1538-551 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1188-552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1551-552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3387-553 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5697-553 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4338-554 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4889-554 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4338-554 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2938-556 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2938-555 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1788-557 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3898-558 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1133-559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3066-559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3635-559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4367-559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5399-560 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2994-561 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1128-562 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2461-562 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2651-563 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4792-563 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1441-564 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3081-564 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 852-565 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2974-565 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 852-565 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1010-566 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4227-566 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2439-567 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5796-567 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4528-568 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2304-569 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5021-569 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 585-570 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4209-570 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1068-571 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3317-571 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1898-572 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4861-572 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1180-574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3882-574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4850-574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4899-574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3107-574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5693-574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1571-575 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2038-575 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1820-576 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 654-577 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5162-578 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1207-580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1720-581 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3246-581 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3641-581 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4436-581 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 580-579 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3522-582 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5027-583 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3033-584 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1456-585 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1152-586 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4976-586 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5268-586 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2423-587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2487-587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5164-588 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5331-589 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5683-589 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1520-590 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2160-590 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1519-590 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2160-590 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5165-591 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3200-592 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4000-592 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4000-592 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2636-593 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3025-595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3509-595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1329-595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3508-595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1329-595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1329-595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5781-596 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3510-597 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3511-598 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1513-599 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1847-600 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5721-600 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2679-601 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5343-601 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 737-602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1883-602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2054-602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3845-602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1883-602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3357-603 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4853-603 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 608-606 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 608-605 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 608-604 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2372-607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3936-607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4318-607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2777-608 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3596-608 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5256-608 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 880-609 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4359-609 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5499-611 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3332-612 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2183-613 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5366-613 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3082-614 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2258-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2006-616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2938-616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3594-616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5309-616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5322-616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5777-616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2938-616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1002-616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2764-617 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3930-617 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5168-619 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5172-618 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5027-620 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5027-621 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1242-622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4893-623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5031-623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5236-623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5826-623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2697-624 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 818-625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1103-625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2587-625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5175-628 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5182-629 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5173-632 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5176-631 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4223-633 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5174-634 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1258-635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4274-635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2454-636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2534-636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5587-636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2785-637 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4562-637 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5696-637 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1106-638 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3973-638 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5150-639 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5055-640 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3930-641 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 996-643 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1340-644 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1340-645 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1352-646 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4274-647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1735-648 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4450-648 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1735-648 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4921-648 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5779-648 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1780-649 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5179-649 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3174-650 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3570-650 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5217-650 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5180-651 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5181-652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1999-653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2745-653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2854-653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4364-653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5152-653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5423-653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1073-653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2184-653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5151-653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3393-654 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2166-655 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3755-655 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4110-656 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1206-657 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3862-657 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1206-657 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2737-658 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3807-658 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1619-659 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1429-660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5238-660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5632-661 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4885-662 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4460-667 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4459-666 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4460-665 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4459-664 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1816-668 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2523-668 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2548-668 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2759-668 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2223-668 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3663-669 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2762-670 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4841-670 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5809-670 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4841-670 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1503-671 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2018-671 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5404-671 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1387-672 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3841-672 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4906-672 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3373-673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3056-674 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1750-675 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1668-676 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2706-676 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2815-677 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5389-677 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5184-678 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4928-679 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2674-680 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3554-681 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3554-681 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3554-681 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1314-682 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5185-682 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3894-683 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1994-684 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5406-684 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1931-685 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4198-686 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1931-687 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2341-688 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2342-689 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5478-690 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4578-691 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 886-692 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2807-692 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2329-694 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2329-693 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 736-695 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4023-695 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5571-695 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4678-695 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5199-701 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3888-703 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4309-702 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5186-703 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5712-703 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4309-702 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5255-704 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4021-705 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5406-705 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5829-705 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4847-705 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5711-706 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2609-711 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2724-711 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2905-710 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3307-710 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5426-710 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3307-710 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1717-712 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2049-712 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4134-712 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5391-712 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5187-713 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5222-714 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4436-715 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 957-716 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4997-716 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1181-716 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3030-716 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1924-717 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 716-718 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3560-719 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5805-719 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5338-720 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5522-720 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4321-720 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 961-721 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4276-721 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4730-721 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5188-722 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5624-722 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1387-723 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1898-723 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5667-723 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2840-724 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4271-724 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4735-724 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4270-724 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4735-724 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2175-726 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2446-726 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2716-725 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4130-725 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4138-725 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5498-725 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5570-725 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2175-726 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4130-725 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4583-725 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 853-727 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2458-727 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2648-727 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4111-727 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5687-727 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2459-727 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2459-727 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3342-729 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3342-728 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3342-730 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 923-731 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 923-731 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 967-732 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5189-733 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5190-734 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2155-735 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4822-738 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1557-739 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4039-739 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2526-742 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3653-742 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4769-742 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5464-742 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1668-743 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2706-743 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 745-744 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5033-744 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3659-745 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3610-746 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3422-747 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 487-748 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2005-749 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2036-749 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5044-749 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1215-750 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4084-750 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4946-750 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1472-752 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3434-752 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4681-753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2543-754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4736-754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2543-754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4736-754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 459-755 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 459-755 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2739-756 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2950-756 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4379-756 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5690-756 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3626-757 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3873-757 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 759-758 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4157-759 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5193-761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1841-764 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1552-765 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3304-765 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3801-766 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4024-766 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 340-767 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5111-767 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 661-768 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1297-768 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2214-768 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2310-768 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3053-768 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4107-768 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4540-768 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5402-768 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5614-768 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1297-768 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3053-768 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1530-769 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3730-769 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3784-769 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3783-769 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5749-769 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1752-773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1872-773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3709-773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4842-773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5637-773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1872-773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5639-773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2295-774 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 918-775 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4822-775 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 899-776 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2719-776 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3757-776 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 900-776 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5194-777 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 948-780 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 948-779 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 948-778 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5196-781 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1755-782 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2509-782 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1684-784 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5198-785 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1124-789 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3417-788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3456-789 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4319-788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4534-789 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4771-788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5798-789 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5819-789 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1336-789 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4534-788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 700-790 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 805-790 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 921-790 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1977-790 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4772-790 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5225-790 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5265-790 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1899-790 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5199-790 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 954-791 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1214-791 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2622-792 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2342-793 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4615-793 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4895-794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4833-795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4895-795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 480-796 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 922-796 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 818-797 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3117-797 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4395-797 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1218-798 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1982-799 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3487-799 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4399-799 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1982-799 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 939-800 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1956-800 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5199-804 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3670-806 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1760-807 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3140-807 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1475-809 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1475-808 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1607-810 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4916-810 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 845-811 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5604-811 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5599-811 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3743-812 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4926-813 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4434-814 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4915-814 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5286-816 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5285-815 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1560-817 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3727-817 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2435-818 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 820-819 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4317-819 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1067-820 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5525-820 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1684-821 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5202-822 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4822-823 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2127-824 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4240-825 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2005-826 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3658-827 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1195-828 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2779-828 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2712-829 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3087-831 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4037-831 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4671-832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5205-833 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1672-834 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4631-834 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2229-835 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3020-835 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3373-835 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3445-836 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3650-836 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4770-836 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2951-838 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5396-837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5535-837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5204-839 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2946-840 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4116-840 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4822-841 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5200-842 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1877-843 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1877-843 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1547-844 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5034-844 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2992-846 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2992-848 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2992-847 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1918-849 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3789-849 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3948-849 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5537-849 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5258-849 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5538-849 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2774-850 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2995-850 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3158-850 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3158-850 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4020-851 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4020-851 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1816-852 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1816-852 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3663-853 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2583-854 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2791-854 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1137-855 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5680-856 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2711-857 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3104-857 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5747-857 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2964-858 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4901-858 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3210-860 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3335-860 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2372-861 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3443-861 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3896-861 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4318-861 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4097-863 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4097-862 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5212-865 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5209-864 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4209-866 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1154-867 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5382-868 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1607-869 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2247-869 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4486-869 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2482-871 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2482-870 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4641-872 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4643-872 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4590-873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5250-873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4590-873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2660-874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4334-874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2247-876 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2247-875 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5213-877 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5210-878 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3386-879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3724-879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4754-879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5041-879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5660-880 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5763-880 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4775-879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2037-881 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2978-882 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3605-881 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4593-881 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5818-882 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4593-882 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2203-883 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5287-883 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5439-884 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5216-885 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3300-886 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4672-886 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5547-886 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2179-888 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2999-887 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4118-887 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1307-890 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2033-891 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5214-891 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2531-892 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3373-893 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4144-893 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4775-894 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-895 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-896 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4904-897 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4904-898 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5071-901 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5841-901 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4713-902 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3931-903 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4156-903 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3373-904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4144-904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3567-905 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4070-905 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5792-906 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5220-907 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3640-908 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5793-908 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2478-909 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4433-909 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1748-910 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5223-913 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2308-915 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2441-914 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2441-914 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2441-915 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2775-916 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4854-916 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2775-916 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4854-916 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5224-917 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4822-918 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1797-919 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5662-919 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4452-919 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5160-920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5743-920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5552-922 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1343-923 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2554-923 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1343-923 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2554-923 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3147-924 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3361-924 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2391-925 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3831-925 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2699-926 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5314-926 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2166-927 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1786-928 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1786-928 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4112-929 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5808-930 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3478-931 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3549-931 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5414-932 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5463-931 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5465-931 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5412-932 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5355-933 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5356-933 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2886-934 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4594-934 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2886-935 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4595-935 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2805-936 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5665-936 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2111-937 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2544-937 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3204-937 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3541-937 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5469-937 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5634-937 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2544-937 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4879-938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4879-938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2552-940 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1528-941 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1528-941 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3331-943 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3908-943 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2455-942 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3908-942 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3300-944 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2701-945 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3314-945 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5492-945 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2207-946 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2805-946 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2590-947 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3425-947 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1040-948 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1098-948 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2354-948 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3065-948 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1042-949 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1194-949 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2654-950 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5225-950 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1513-951 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1369-952 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2294-953 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2309-953 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2906-953 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4403-953 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4630-953 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4864-953 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4403-953 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1214-954 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1238-954 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2143-954 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2910-954 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3598-954 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4459-954 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1238-954 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2143-954 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2910-954 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3598-954 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4460-954 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4460-954 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4459-954 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4899-955 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5231-956 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2942-957 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1179-958 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5693-958 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2941-959 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3908-959 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4431-959 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2733-960 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3453-960 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3761-960 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4005-960 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4042-960 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5301-960 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2734-960 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3760-960 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1458-961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1458-961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1458-961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4855-963 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4855-962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 968-964 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2942-964 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1740-966 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4125-966 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3308-967 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5776-967 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2256-968 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2597-968 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4089-968 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1846-968 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4804-968 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1243-969 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2081-969 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2081-969 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2766-970 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3044-972 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3338-972 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5232-973 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2953-974 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3358-974 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5708-974 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3358-974 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5352-974 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3358-974 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1515-975 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2451-975 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3697-975 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4961-975 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2451-975 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3697-975 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2238-976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2642-976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2766-976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3801-976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4024-976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4274-976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4721-976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4274-976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3802-977 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1110-978 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4516-978 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5543-978 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5773-978 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4998-978 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2475-979 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2815-979 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2164-980 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3830-980 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1379-982 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2709-982 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1201-983 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4414-984 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3194-985 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3462-986 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2299-987 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2290-988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3732-988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4789-988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4788-988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1119-990 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1182-989 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4907-990 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4937-990 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3552-991 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3767-991 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1346-992 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2066-992 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5228-993 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1085-994 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2105-994 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1038-996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1078-996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1251-996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5269-996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4757-997 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2068-998 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3598-998 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4459-998 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1581-998 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2067-998 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4460-998 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4949-999 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5703-999 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4630-1000 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2121-1001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2898-1001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5309-1003 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1724-1004 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5345-1004 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5471-1005 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3920-1006 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4443-1006 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5675-1008 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5674-1007 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5233-1009 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2207-1010 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2856-1010 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2856-1010 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1248-1011 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3451-1011 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5229-1011 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5348-1011 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1248-1011 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1954-1012 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5229-1013 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4783-1014 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1750-1015 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4139-1015 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2270-1016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4281-1016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 968-1017 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2620-1017 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 968-1017 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 968-1017 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1353-1019 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1353-1018 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5382-1020 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5234-1021 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3337-1023 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3337-1022 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4505-1024 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2152-1025 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2802-1025 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1477-1027 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1477-1026 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4087-1028 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1354-1029 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4641-1030 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4641-1031 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4641-1030 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4890-1032 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2153-1033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3045-1033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4358-1033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2153-1033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3046-1033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4357-1033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3774-1033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3774-1033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1382-1034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3169-1034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3344-1034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3909-1034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5003-1034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5004-1034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1382-1034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3775-1034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3048-1034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3047-1034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1039-1035 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1072-1035 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3776-1036 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4527-1037 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4944-1036 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5235-1037 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1039-1037 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1072-1035 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2961-1036 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3147-1036 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4527-1036 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4527-1036 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1100-1041 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2271-1041 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3296-1041 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4393-1041 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4406-1041 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5165-1041 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5680-1040 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1097-1041 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5681-1040 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1099-1040 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2660-1040 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1194-1042 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2857-1042 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3748-1042 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4876-1042 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5311-1042 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5438-1042 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1224-1043 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1224-1043 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3127-1044 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4971-1044 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1939-1045 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2460-1045 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5056-1045 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1939-1045 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2460-1045 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5057-1045 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1183-1047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1265-1047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3161-1047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3940-1047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4950-1047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5028-1046 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1264-1046 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3939-1046 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4950-1047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4950-1047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5503-1047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5236-1048 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2143-1049 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2404-1050 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4416-1050 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3194-1051 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4387-1057 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2207-1058 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2805-1058 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5180-1058 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5371-1058 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-1059 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2803-1059 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3748-1059 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5046-1059 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-1059 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4987-1060 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2583-1061 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2583-1062 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1997-1063 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2260-1063 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4924-1063 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5357-1063 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2824-1064 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2824-1064 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5024-1065 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5239-1065 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2029-1066 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2658-1066 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5544-1066 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2399-1067 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2996-1068 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5707-1069 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2213-1070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3943-1070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2564-1071 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2694-1071 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2564-1071 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1925-1072 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4952-1072 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1925-1072 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4952-1072 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4952-1072 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2243-1073 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2745-1073 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2829-1073 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5592-1073 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5593-1073 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5823-1073 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3024-1074 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4767-1076 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4767-1075 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5303-1077 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1946-1079 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2337-1079 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2291-1080 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4673-1080 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5543-1080 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5710-1080 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1781-1081 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2292-1081 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1663-1082 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4974-1083 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4974-1083 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1933-1084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5671-1084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1932-1084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2735-1085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2504-1086 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4348-1086 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1201-1087 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4280-1087 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2137-1088 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2718-1088 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2137-1088 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1467-1089 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1466-1090 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1482-1092 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1482-1091 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4250-1093 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1761-1094 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2668-1094 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2291-1095 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2291-1095 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3515-1096 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3515-1096 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4546-1098 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5241-1101 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5567-1102 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5568-1102 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2416-1103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2587-1103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2416-1103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3574-1104 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2739-1105 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2315-1106 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3186-1106 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5244-1107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2443-1109 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4498-1109 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5073-1109 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3286-1110 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3570-1111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5034-1111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5217-1111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5218-1111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5836-1111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3570-1111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3592-1111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3592-1111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1536-1112 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2119-1112 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1951-1113 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2559-1114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1766-1116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2495-1115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4432-1115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4510-1116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2495-1115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3540-1117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5245-1117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1496-1118 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1913-1118 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2076-1118 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1540-1120 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4954-1120 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4954-1120 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2559-1121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2559-1122 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5247-1123 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1302-1124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2314-1125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4524-1125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1379-1126 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3385-1126 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4679-1128 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5249-1129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1224-1130 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2708-1130 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5494-1130 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1225-1131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5091-1131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2450-1132 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5640-1132 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3066-1133 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3740-1133 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5248-1133 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3093-1133 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2258-1134 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4896-1134 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1354-1135 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3238-1135 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1354-1135 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2795-1137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2977-1136 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5101-1137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5241-1136 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5476-1137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2458-1138 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2978-1138 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4992-1139 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5250-1140 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2376-1141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2835-1141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5215-1141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5436-1141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5439-1141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5257-1141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3658-1142 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4174-1142 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3704-1143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5252-1144 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1237-1146 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2930-1146 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3329-1146 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2579-1147 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4340-1147 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1809-1148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3552-1148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3610-1149 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3801-1150 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2131-1151 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3014-1152 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3458-1152 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3499-1152 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5541-1151 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5620-1151 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5658-1151 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2132-1153 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2697-1153 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3355-1154 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4735-1154 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5760-1154 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5251-1155 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2447-1156 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2999-1156 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5254-1157 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5253-1158 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4785-1159 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4784-1160 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4785-1161 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1560-1162 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3897-1162 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4655-1162 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3897-1162 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4558-1163 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5107-1165 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2571-1166 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4974-1167 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5585-1167 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1482-1168 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1938-1168 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2821-1169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3083-1169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3630-1169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4191-1169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4215-1169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4677-1169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5612-1169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3083-1169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4214-1169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5695-1169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-1170 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4216-1170 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5255-1170 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-1170 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-1170 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3356-1175 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3600-1176 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4044-1176 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5689-1176 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3533-1176 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5012-1177 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1187-1178 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2643-1180 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5834-1179 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3220-1181 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1701-1182 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3906-1184 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5394-1184 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3156-1185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3383-1185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5414-1185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3156-1185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3383-1185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5412-1185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3156-1185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5355-1185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5356-1185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1957-1186 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4612-1186 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2136-1187 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2155-1187 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4150-1187 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4073-1189 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4310-1190 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5740-1189 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4073-1188 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3516-1192 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5277-1191 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1954-1192 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1956-1193 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3128-1193 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2098-1194 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3539-1194 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3658-1194 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4335-1194 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5628-1194 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1171-1194 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3539-1194 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5438-1194 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1172-1194 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1173-1194 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1515-1195 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2600-1195 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1515-1195 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2599-1195 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2778-1195 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1174-1195 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3381-1196 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3995-1196 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5573-1196 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4651-1197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5430-1197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5429-1197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1202-1198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2959-1198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4169-1200 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4973-1200 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5082-1199 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5156-1199 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2717-1201 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3949-1201 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3950-1201 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4412-1201 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4413-1201 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2932-1202 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3878-1203 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4997-1203 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1981-1203 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3384-1203 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1243-1204 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4897-1204 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5260-1205 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2247-1206 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3862-1206 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4128-1206 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2247-1206 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5717-1206 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1633-1207 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1912-1207 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3172-1207 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1912-1207 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3172-1207 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4601-1208 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5019-1209 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5708-1209 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5262-1210 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3031-1211 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4449-1211 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3701-1212 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4350-1212 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2653-1213 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2881-1213 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1295-1214 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3598-1214 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4569-1214 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4706-1214 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1292-1214 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3598-1214 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4706-1214 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1294-1214 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4706-1214 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1293-1214 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1984-1216 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1805-1217 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2744-1217 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1346-1218 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3850-1218 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3421-1219 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5075-1220 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5259-1221 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5265-1222 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1242-1223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5403-1224 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1380-1226 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3046-1227 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4431-1227 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3489-1228 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4430-1228 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1338-1229 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1647-1229 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2422-1229 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2487-1229 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4340-1230 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4445-1230 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1772-1232 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3038-1232 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1772-1232 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3597-1234 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4272-1234 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5232-1233 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5738-1233 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5641-1233 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3597-1234 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1677-1237 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2080-1236 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2930-1237 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3329-1235 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3958-1236 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4075-1236 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4129-1237 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4520-1237 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5689-1237 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1677-1236 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3533-1236 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4075-1235 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4821-1238 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4821-1238 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5542-1239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-1240 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1954-1240 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3305-1240 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1610-1241 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1850-1241 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1611-1241 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1849-1241 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2866-1242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3815-1242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5169-1242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3566-1243 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4566-1243 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5487-1243 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4281-1244 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4320-1244 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4281-1244 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2257-1245 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4560-1248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4618-1248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5108-1249 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5621-1249 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5269-1250 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1651-1253 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2088-1254 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2517-1254 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5063-1254 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5063-1254 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4198-1255 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5485-1255 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2332-1256 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5271-1257 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2250-1259 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4708-1259 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4727-1258 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5539-1258 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5767-1259 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4708-1258 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4727-1259 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1838-1260 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3890-1260 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5124-1260 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5502-1260 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5650-1260 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3146-1261 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3803-1261 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4898-1261 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4084-1262 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1507-1263 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2653-1263 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2002-1265 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3944-1265 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4640-1264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5270-1266 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2256-1267 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4208-1268 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5211-1268 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5273-1269 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1956-1270 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2143-1270 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4460-1270 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1956-1271 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2143-1271 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4459-1271 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1542-1272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3194-1272 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1769-1274 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4578-1273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5274-1275 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3623-1276 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3971-1276 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4785-1279 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2265-1280 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2705-1280 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2266-1281 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3631-1281 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3913-1281 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4874-1281 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5063-1281 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2266-1281 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3631-1281 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3912-1281 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1833-1282 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2042-1283 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3755-1283 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1627-1284 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5170-1284 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5781-1284 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5136-1285 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5802-1286 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2005-1287 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2006-1288 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5207-1289 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5208-1289 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2300-1290 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3936-1290 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3936-1290 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2654-1291 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3442-1296 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2026-1297 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4636-1297 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5833-1298 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1300-1299 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4895-1299 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5277-1301 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2112-1302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2634-1304 connects the same voltage levels (20.0, 20.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5814-1305 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5140-1306 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5379-1306 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1345-1307 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1609-1307 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3902-1307 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3340-1308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3701-1308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4836-1308 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5280-1309 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2920-1310 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3928-1310 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5279-1311 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2612-1312 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5279-1312 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5281-1312 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1313-1314 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1980-1314 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2598-1315 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5621-1315 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2598-1315 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2934-1316 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2130-1318 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2130-1317 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3424-1319 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1380-1320 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4401-1320 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5579-1320 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5431-1321 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3670-1322 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5642-1322 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4037-1323 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3251-1324 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3519-1324 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2094-1325 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5233-1325 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4420-1326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1661-1327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4263-1327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5736-1327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2071-1328 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3024-1328 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3057-1328 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4714-1328 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1537-1329 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3426-1329 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4020-1329 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1537-1329 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3025-1329 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4020-1329 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5095-1330 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5346-1331 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5822-1331 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2129-1332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4998-1332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4102-1333 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5164-1333 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4879-1334 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2080-1335 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5153-1335 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2081-1337 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1840-1338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1841-1338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1751-1340 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5272-1340 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4188-1341 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3001-1342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2355-1348 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2355-1347 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1592-1349 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3870-1350 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1359-1351 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2352-1351 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1385-1352 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1944-1352 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2616-1352 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2684-1352 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2685-1352 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2690-1352 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1384-1352 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1458-1353 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5326-1353 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5128-1354 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3751-1355 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3802-1355 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4102-1356 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4102-1357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4467-1358 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5350-1359 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3825-1361 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3825-1360 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2450-1362 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5760-1363 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1702-1366 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1708-1365 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1709-1364 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1793-1367 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1378-1368 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3250-1368 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5284-1368 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5286-1368 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5285-1368 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5301-1370 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2072-1369 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3996-1371 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4070-1372 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1770-1373 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2532-1374 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5287-1375 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4839-1376 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2340-1377 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3698-1377 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3908-1377 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5228-1377 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4442-1380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5267-1380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1659-1381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2045-1381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3268-1381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3994-1381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5511-1381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5750-1381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2530-1381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3993-1381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4940-1381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5510-1381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3431-1383 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4087-1383 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3405-1385 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2602-1384 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2746-1386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2653-1388 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3042-1388 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3387-1389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5520-1389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2141-1390 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3857-1390 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5132-1390 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5288-1390 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3186-1391 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4967-1392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4966-1392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4968-1393 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5289-1394 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5246-1395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2559-1395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5290-1396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2337-1397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4320-1398 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5585-1398 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5291-1401 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1946-1402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3693-1402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3856-1402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3856-1402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1296-1405 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1808-1405 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4328-1405 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5091-1406 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5656-1406 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2863-1407 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3166-1407 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5562-1408 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5793-1409 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5292-1410 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2231-1411 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4139-1411 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5787-1411 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4674-1412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5758-1412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2476-1413 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2865-1413 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4622-1413 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1817-1414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1817-1414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2601-1416 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3228-1415 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2602-1416 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3227-1416 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3666-1417 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3666-1417 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3870-1419 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3870-1418 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3599-1420 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2002-1421 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3879-1422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5295-1422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5296-1422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5298-1423 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 974-1424 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5019-1424 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5087-1424 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5352-1424 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3995-1425 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5310-1425 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4042-1426 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4514-1426 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1430-1427 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2543-1428 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2993-1428 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1060-1429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4531-1429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5025-1429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1060-1429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2425-1430 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4988-1430 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 925-1431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1241-1431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1610-1431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1768-1431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2531-1431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1775-1432 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5300-1433 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1678-1434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4217-1435 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2486-1436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2728-1436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4197-1436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4690-1436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5274-1436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2486-1436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2728-1436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2486-1436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4897-1437 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5487-1437 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4896-1437 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2953-1438 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5788-1438 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1263-1440 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1319-1440 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3042-1439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3063-1440 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4577-1440 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4761-1439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5663-1440 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5783-1439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2654-1441 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4697-1441 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2654-1441 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1444-1442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1444-1442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5301-1443 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3976-1445 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 997-1446 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4757-1446 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 968-1447 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4795-1449 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4795-1448 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2677-1450 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5274-1450 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3454-1451 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5302-1452 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3194-1453 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4321-1456 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3258-1457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4638-1457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4654-1457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5007-1457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5106-1457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4637-1457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5237-1457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2138-1458 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2139-1458 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5326-1458 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1925-1459 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4855-1459 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5079-1459 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1925-1459 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4855-1459 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4952-1459 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1616-1460 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2740-1460 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3520-1460 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5323-1460 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3262-1460 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4877-1461 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3195-1462 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4879-1462 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2526-1463 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5012-1464 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5739-1464 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3552-1465 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3552-1465 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1703-1466 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3554-1467 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1703-1466 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3028-1468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4349-1468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5034-1468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3028-1468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4714-1469 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4858-1469 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2137-1470 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5269-1471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4935-1472 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3623-1473 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1884-1474 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2001-1474 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2693-1474 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2936-1474 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2935-1474 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5523-1474 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1749-1475 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2040-1475 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3735-1475 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3759-1475 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1749-1475 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3759-1475 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2509-1476 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2509-1476 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2545-1478 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4168-1478 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4269-1478 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4437-1478 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5104-1478 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5263-1478 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5684-1478 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5258-1478 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3542-1479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4573-1479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3359-1479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4731-1480 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4731-1480 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2127-1481 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2790-1482 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4843-1483 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4238-1484 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5305-1484 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2798-1485 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1667-1486 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5715-1486 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1711-1487 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5054-1489 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3008-1490 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4956-1490 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2598-1495 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2617-1497 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3992-1497 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2273-1498 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3403-1498 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4053-1498 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4709-1498 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5059-1498 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4053-1498 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2755-1499 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2275-1500 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4686-1500 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4700-1500 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5306-1501 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4822-1502 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3364-1503 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5666-1503 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3069-1504 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3034-1505 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3244-1505 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2414-1506 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5089-1506 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4202-1508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4202-1508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2105-1509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3637-1509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3728-1510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3885-1510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4532-1510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3422-1511 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3728-1511 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3728-1511 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5803-1512 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2353-1513 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2595-1513 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4036-1513 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5519-1513 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5704-1513 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4036-1513 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3252-1514 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2345-1515 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3409-1515 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2344-1515 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4784-1516 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4785-1516 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1628-1521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2407-1521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3428-1521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4117-1521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5178-1521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2407-1521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3730-1522 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4676-1522 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2320-1523 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4910-1523 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4909-1523 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4420-1524 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5307-1525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1832-1526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1775-1527 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2566-1527 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1544-1528 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1561-1528 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4863-1529 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4928-1528 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5713-1528 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4105-1528 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5438-1530 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5749-1530 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2463-1531 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2600-1531 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2940-1531 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3617-1531 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3697-1531 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2463-1531 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2599-1531 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1845-1532 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5010-1532 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5358-1532 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5843-1532 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2923-1533 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5832-1533 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2097-1534 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3073-1534 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3538-1534 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5177-1534 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5358-1535 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4858-1536 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2010-1537 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2511-1537 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2011-1537 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4854-1537 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1927-1538 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3599-1538 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3969-1538 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5624-1538 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3599-1538 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1731-1539 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5309-1539 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3520-1542 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2146-1543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2626-1543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2146-1543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2626-1543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4173-1545 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5731-1545 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4173-1545 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5310-1546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1831-1548 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5311-1549 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3237-1550 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4257-1550 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2738-1551 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3304-1552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2513-1554 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4839-1554 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2512-1554 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4668-1556 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1843-1558 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5491-1558 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1813-1558 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1844-1558 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1828-1559 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3237-1559 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3370-1559 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3237-1559 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3237-1559 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1776-1560 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4655-1560 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4655-1560 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2007-1562 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4368-1565 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4851-1565 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5190-1565 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5260-1566 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5312-1567 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4426-1568 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4681-1568 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5313-1569 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3743-1570 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3866-1570 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3066-1571 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4327-1571 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4446-1571 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5315-1571 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3942-1572 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5139-1572 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5688-1572 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2977-1572 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4527-1573 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4527-1574 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4527-1575 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4527-1576 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1513-1577 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2543-1578 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2543-1578 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3328-1579 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5316-1579 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1998-1580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3848-1580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4141-1580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1998-1580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3598-1581 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4223-1582 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4990-1582 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3270-1583 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3282-1583 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3992-1583 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5048-1583 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5583-1583 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3270-1583 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3591-1583 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5048-1583 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2713-1584 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4157-1584 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2613-1585 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5695-1586 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5317-1587 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3779-1588 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4705-1588 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4689-1588 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4533-1589 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5319-1589 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4748-1590 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5335-1590 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1606-1591 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3922-1591 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2350-1593 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4973-1592 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5394-1593 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4362-1593 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4972-1592 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2763-1594 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2808-1594 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3009-1594 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3067-1594 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3252-1594 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4296-1594 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4730-1594 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2938-1594 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2764-1595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3426-1595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3930-1595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4767-1595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4855-1595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4767-1595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2607-1596 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3055-1596 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3419-1596 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4869-1596 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2607-1596 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3054-1596 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2885-1597 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4032-1597 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4201-1598 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4856-1598 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5078-1597 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4032-1597 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5320-1599 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5321-1600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3041-1601 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4518-1601 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5322-1602 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4338-1603 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4338-1603 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2621-1604 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4452-1604 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5146-1604 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2089-1605 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2301-1605 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3314-1606 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3314-1606 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4668-1607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2114-1608 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3505-1611 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4008-1610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5558-1610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5761-1610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2286-1612 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4992-1612 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3364-1613 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5666-1613 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1940-1614 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2684-1615 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5489-1615 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5094-1617 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5734-1617 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3953-1618 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5430-1619 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5429-1619 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5635-1620 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2256-1621 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5324-1624 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3623-1625 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2003-1626 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5389-1627 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3422-1628 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2202-1629 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5409-1629 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1851-1630 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5109-1630 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2041-1631 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2524-1632 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3021-1632 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3575-1632 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4119-1632 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4511-1632 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2524-1632 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4119-1632 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4511-1632 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3172-1633 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4128-1634 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4353-1634 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1802-1635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4749-1635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3127-1636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5325-1637 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2538-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2964-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4749-1638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5326-1639 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1719-1640 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3402-1640 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4452-1640 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1936-1641 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1936-1641 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5327-1642 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2856-1644 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5328-1643 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1873-1645 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5453-1647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5329-1651 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5330-1652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2638-1653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2795-1654 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1712-1655 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2799-1655 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4774-1655 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2121-1656 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3601-1656 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1786-1657 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1786-1657 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2420-1658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4851-1658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5050-1658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3268-1659 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5332-1660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5018-1661 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1938-1662 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2000-1663 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3019-1663 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3710-1663 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3731-1663 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4224-1663 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5042-1663 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5753-1663 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3018-1663 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5756-1664 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2035-1665 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4722-1665 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5333-1666 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3398-1667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4079-1667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5001-1667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3398-1667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5418-1668 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1863-1669 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3145-1669 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3546-1671 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4631-1672 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5298-1672 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5493-1672 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5739-1672 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1674-1673 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4513-1673 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2476-1674 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2507-1675 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4619-1675 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3933-1676 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5524-1676 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5652-1676 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5455-1677 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3041-1678 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3649-1680 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4512-1680 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5325-1682 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5598-1683 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5596-1683 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1633-1684 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1720-1684 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2818-1684 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3316-1684 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3704-1684 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3743-1684 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3316-1684 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5202-1684 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5338-1685 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3706-1686 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5339-1687 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2450-1688 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2450-1688 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2450-1688 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4211-1690 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4211-1689 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4208-1691 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4210-1693 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4210-1692 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5327-1694 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4523-1696 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5726-1696 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5724-1696 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4344-1697 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2783-1698 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2783-1699 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5293-1699 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5294-1699 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5340-1699 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5451-1699 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1709-1703 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2725-1702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3209-1702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3925-1702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4065-1702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1708-1702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3209-1702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3925-1702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3209-1702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3209-1702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1710-1705 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1710-1707 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1710-1704 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1710-1706 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3210-1710 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4635-1710 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3210-1710 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3605-1710 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5342-1710 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5341-1710 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2229-1711 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2246-1711 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3123-1711 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4610-1711 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2246-1711 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2128-1712 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5342-1714 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5341-1713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2231-1715 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3859-1716 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4626-1716 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4723-1716 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5100-1716 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5097-1716 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2049-1717 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3104-1718 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5344-1723 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3970-1725 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5317-1725 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2798-1726 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5346-1727 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5347-1728 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1987-1729 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4007-1730 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4076-1730 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4159-1729 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5560-1729 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4076-1729 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4537-1731 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3891-1733 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3906-1733 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5350-1733 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1795-1734 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5517-1734 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1740-1737 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1740-1736 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3096-1739 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3096-1738 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1746-1740 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3272-1740 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4984-1740 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1745-1740 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1744-1740 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2326-1747 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5816-1748 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2325-1748 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2855-1748 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5523-1747 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2483-1749 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3463-1749 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3825-1749 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3854-1749 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4246-1749 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3463-1749 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3825-1749 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2927-1750 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3088-1750 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3092-1750 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5572-1750 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1752-4124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5348-1753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2005-1754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2509-1755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2680-1756 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2306-1757 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2140-1758 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2328-1758 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3262-1759 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2668-1761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4091-1761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5833-1761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1778-1761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2668-1761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2842-1764 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2842-1763 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2842-1765 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2842-1762 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4510-1766 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5063-1767 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2698-1768 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2675-1769 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3873-1769 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2315-1771 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3302-1772 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3563-1772 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3706-1772 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3858-1771 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3901-1771 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5111-1771 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3706-1772 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3024-1773 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3057-1773 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3192-1773 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4001-1773 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5391-1773 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4920-1774 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5183-1774 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2566-1775 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2975-1775 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4925-1775 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5299-1775 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2462-1776 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4617-1776 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5184-1776 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2307-1777 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2491-1777 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4943-1778 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4147-1779 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3455-1780 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4926-1780 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5179-1780 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5828-1780 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4999-1781 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5320-1782 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4644-1783 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5374-1783 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4298-1784 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4644-1784 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3269-1785 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4582-1785 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4965-1785 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3965-1786 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4287-1786 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2998-1787 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3024-1788 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3393-1788 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3024-1788 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3402-1789 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4888-1789 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4453-1790 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3558-1792 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3558-1793 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5442-1794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1794-1795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1796-4720 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2387-1797 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4400-1798 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4462-1798 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4891-1798 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3833-1799 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5149-1799 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2751-1801 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2751-1800 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3369-1802 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1930-1803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3182-1803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3924-1803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5410-1803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5573-1803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5815-1803 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2159-1804 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2159-1804 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2744-1805 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3354-1805 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5273-1805 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3354-1805 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4533-1805 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3266-1806 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5351-1807 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3434-1809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5449-1810 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5635-1810 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4809-1812 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5362-1812 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1816-1814 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1816-1814 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5352-1815 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2474-1817 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2558-1817 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3999-1817 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4542-1818 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4542-1818 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2160-1819 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2160-1819 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3662-1820 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3662-1820 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3007-1821 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3535-1821 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1956-1823 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2707-1823 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4064-1824 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3078-1825 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3547-1826 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4404-1826 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5759-1826 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3547-1826 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4669-1827 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4669-1827 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4725-1829 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5799-1830 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5416-1831 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2015-1832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2413-1832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2847-1832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3628-1832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4859-1832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5308-1832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2470-1832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5455-1833 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5516-1833 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5355-1835 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5356-1834 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2129-1836 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2597-1836 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2016-1837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2322-1837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4878-1837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5324-1838 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1937-1842 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2875-1846 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4267-1847 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2298-1848 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2495-1848 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2254-1851 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2420-1851 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4321-1851 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2771-1852 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4000-1852 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4735-1853 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3063-1854 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3069-1854 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3028-1855 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3328-1856 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4017-1856 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4279-1856 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3646-1857 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4005-1861 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4502-1862 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4122-1863 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1724-1864 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2297-1864 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3189-1864 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5132-1866 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5267-1867 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5579-1867 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1941-1868 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2554-1868 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1816-1869 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2676-1870 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5360-1871 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3647-1874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5361-1875 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3661-1876 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3847-1876 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4740-1876 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5393-1876 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3996-1877 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3996-1877 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3738-1878 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3053-1880 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3053-1881 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4218-1882 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5363-1885 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5364-1886 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2686-1887 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1897-1895 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1897-1894 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1897-1893 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1897-1892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3867-1896 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5053-1896 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4081-1897 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3962-1898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4207-1898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4250-1898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4861-1898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5266-1898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5466-1898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3976-1898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5667-1898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3976-1898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2907-1899 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3602-1899 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3963-1899 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5265-1899 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4449-1901 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4922-1901 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4257-1902 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5084-1903 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4775-1904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5070-1905 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2079-1906 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5643-1906 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2079-1906 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4281-1907 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5131-1907 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5310-1907 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4283-1908 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5375-1908 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5292-1910 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5300-1909 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5717-1911 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2248-1912 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5171-1913 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3314-1914 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5292-1914 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3314-1914 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5367-1915 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5119-1916 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5009-1917 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3921-1918 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2092-1919 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3826-1919 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5424-1920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2319-1921 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2188-1922 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2348-1922 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2401-1922 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4236-1922 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4236-1922 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5322-1923 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3416-1924 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3416-1924 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1931-1925 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4527-1925 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1931-1925 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4527-1925 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3868-1926 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4110-1926 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4110-1926 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5331-1927 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2553-1928 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2965-1928 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4453-1928 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2965-1928 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3930-1929 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4543-1929 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4854-1929 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2283-1929 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4543-1929 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4284-1931 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2652-1934 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4093-1935 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2203-1936 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2922-1936 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3126-1937 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4058-1936 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5359-1937 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2203-1936 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4058-1936 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3390-1938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4839-1938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4839-1938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3495-1942 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2041-1943 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2690-1944 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2883-1945 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2906-1945 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5371-1947 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3304-1948 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5276-1949 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5716-1950 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2677-1951 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3265-1952 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3304-1952 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3445-1953 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4423-1953 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2292-1955 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4103-1954 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4999-1955 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5277-1954 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4898-1956 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4898-1956 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4898-1956 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3006-1958 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3601-1959 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3510-1960 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1973-1971 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1973-1970 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1973-1969 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1973-1968 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1973-1967 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1973-1966 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3806-1972 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4480-1972 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3807-1973 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4482-1973 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3287-1975 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4104-1976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4312-1978 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4749-1978 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4334-1979 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2241-1980 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3220-1981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4249-1982 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3924-1983 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5182-1984 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5361-1984 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5375-1985 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5380-1985 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5376-1986 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3193-1987 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5725-1988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2298-1989 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2307-1989 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3196-1989 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4182-1990 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4510-1990 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4741-1990 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4182-1990 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4510-1990 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4510-1990 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2510-1991 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2510-1991 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5378-1992 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4935-1993 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4066-1995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4867-1995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4066-1996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4868-1996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5357-1997 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2672-1998 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3281-1998 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2908-1998 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4141-1998 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5508-1999 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3710-2000 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4640-2003 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4153-2004 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5171-2004 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2810-2005 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5044-2005 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5205-2005 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3929-2006 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4449-2006 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4858-2006 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3403-2007 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4302-2008 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5384-2009 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5835-2012 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5836-2013 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5457-2014 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3179-2016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4935-2016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3607-2017 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2702-2019 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4285-2019 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2541-2020 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4735-2020 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5645-2021 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5387-2022 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5386-2023 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5389-2024 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2086-2025 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2681-2025 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3375-2025 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2937-2027 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4748-2027 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4875-2028 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5554-2029 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5555-2029 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4117-2030 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5178-2030 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5305-2031 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5559-2031 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5560-2031 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2427-2032 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2054-2033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2817-2033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3741-2033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5212-2033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5214-2033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5209-2033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4449-2034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4853-2034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4722-2035 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3861-2036 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3605-2037 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2440-2039 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2659-2039 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2216-2042 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2228-2042 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2267-2042 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2834-2042 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2217-2043 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2737-2043 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2755-2043 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3756-2043 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4059-2043 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4172-2043 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4482-2043 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5393-2044 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2977-2046 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2977-2046 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3502-2047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5454-2047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4804-2048 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5296-2048 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3191-2049 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4303-2049 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5391-2049 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4304-2049 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2345-2050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3509-2050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4767-2050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2344-2050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3508-2050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4767-2050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3612-2053 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3612-2052 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3612-2051 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5057-2055 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5056-2056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5056-2057 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5057-2058 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5056-2059 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5057-2060 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5390-2061 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2120-2063 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2728-2063 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4690-2063 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4086-2064 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2908-2065 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3832-2066 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3850-2066 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5572-2066 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2798-2069 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3965-2070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4394-2070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2119-2071 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4960-2073 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5711-2073 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4960-2072 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5254-2075 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5253-2074 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2272-2076 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3251-2076 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4954-2077 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5396-2078 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3041-2079 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3604-2079 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4043-2079 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4518-2079 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4520-2080 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2106-2081 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2669-2081 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5283-2081 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4460-2082 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4898-2082 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3612-2083 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3612-2083 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2726-2084 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2609-2085 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2196-2086 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2278-2088 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5840-2087 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2087-1491 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3132-2089 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2560-2090 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4985-2090 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2442-2091 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5456-2091 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2479-2094 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4295-2094 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4295-2094 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4373-2095 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4373-2095 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3106-2096 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2197-2097 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3073-2097 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4691-2097 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5177-2097 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3073-2097 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4383-2097 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5754-2097 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4384-2098 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5628-2098 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2869-2099 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5614-2099 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2105-2102 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2105-2101 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2105-2104 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2105-2103 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2611-2105 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3637-2105 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4155-2105 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5105-2105 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5196-2105 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2610-2106 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3892-2107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5397-2107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2994-2108 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3657-2109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3691-2109 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5398-2110 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3262-2111 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3006-2112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2987-2113 connects the same voltage levels (20.0, 20.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2456-2115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3168-2115 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3170-2116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3441-2116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4175-2116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3403-2117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3518-2117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2760-2118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3345-2118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3785-2118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4051-2118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5379-2118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3785-2118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5377-2118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5372-2120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2671-2121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3601-2122 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3946-2121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4006-2122 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1998-2125 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1998-2124 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1998-2123 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4665-2126 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2790-2128 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4774-2128 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5807-2128 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2232-2128 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2790-2128 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2790-2128 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4184-2129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4185-2129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2490-2130 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3218-2130 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5243-2131 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5346-2131 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5513-2131 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5055-2133 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5054-2134 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2423-2135 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2423-2135 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1905-2136 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2752-2136 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4414-2137 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4823-2137 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4414-2137 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4823-2137 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4824-2137 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3188-2140 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3537-2141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4343-2141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5288-2141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5552-2141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4342-2141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5516-2142 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4154-2144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5730-2144 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5400-2145 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3535-2147 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5401-2148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3647-2149 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3535-2150 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5542-2150 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1990-2151 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1990-2151 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2155-2154 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5306-2155 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4823-2156 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2098-2157 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2062-2159 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3201-2159 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4747-2159 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5260-2159 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4746-2159 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2227-2160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3699-2160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3918-2160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5055-2160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5066-2160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5312-2160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5054-2160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5065-2160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5054-2160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5676-2164 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2773-2165 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4425-2165 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3403-2166 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3518-2167 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3867-2167 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3403-2166 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3518-2167 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4641-2170 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4641-2170 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2216-2172 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2216-2171 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2675-2173 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4009-2174 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2874-2175 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3868-2175 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2181-2178 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2288-2178 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3090-2178 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3289-2178 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3700-2178 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4799-2178 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2181-2178 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4799-2178 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4799-2178 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2319-2179 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2844-2179 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2999-2179 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3954-2179 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2318-2179 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3955-2179 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5404-2180 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5405-2182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3915-2183 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5422-2185 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5406-2186 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2796-2189 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2192-2190 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3667-2190 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3667-2190 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2193-2190 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2194-2191 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3899-2191 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3899-2191 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3804-2195 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4923-2195 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5754-2197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2981-2198 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3131-2199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5407-2199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3130-2199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4013-2200 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3126-2203 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5410-2204 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5413-2205 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2494-2206 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2864-2208 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5168-2208 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5172-2208 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5414-2210 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5412-2209 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4800-2213 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5415-2213 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2573-2215 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2834-2216 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2460-2218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4970-2218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2219-1493 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4156-2219 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5416-2219 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5417-2220 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5052-2221 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5418-2222 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2492-2224 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2514-2224 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3755-2225 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3755-2225 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2985-2226 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3827-2226 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5058-2226 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5261-2226 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2577-2227 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3938-2227 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5055-2227 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5840-2227 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2577-2227 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5686-2227 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3755-2228 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2789-2230 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3513-2230 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2789-2230 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4006-2231 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4774-2232 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3482-2233 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3482-2233 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2851-2233 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5518-2235 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4018-2236 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3319-2237 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3452-2237 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2561-2239 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3146-2239 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3223-2239 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4913-2239 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3147-2239 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5325-2241 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2774-2242 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2894-2242 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2388-2243 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4641-2244 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4763-2244 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5417-2245 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2478-2247 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3606-2249 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5465-2249 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3889-2250 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4824-2252 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4823-2251 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5419-2253 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2265-2255 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2611-2256 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5105-2256 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5638-2257 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2610-2258 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5283-2258 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4643-2259 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5603-2259 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4408-2259 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5259-2259 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4322-2262 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5420-2263 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3140-2264 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2201-2265 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2177-2266 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2199-2266 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5062-2266 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2176-2266 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2199-2266 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5061-2266 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4481-2267 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5422-2268 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4013-2269 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4013-2269 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3403-2273 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3559-2274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3236-2276 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4699-2276 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4698-2275 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5679-2277 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4004-2279 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4587-2279 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5423-2281 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4777-2282 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3793-2282 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4854-2283 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2598-2284 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3219-2284 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2819-2285 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3407-2285 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4562-2285 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5607-2285 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2533-2286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2820-2286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3502-2286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5424-2287 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3285-2291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5736-2293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5820-2293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5197-2294 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3301-2295 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4083-2295 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5291-2296 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2724-2297 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2336-2299 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3860-2299 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5613-2299 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2485-2301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3097-2301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3849-2301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5052-2301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5606-2301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3849-2301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5605-2301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3394-2301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2628-2302 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3272-2302 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2280-2303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4759-2303 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5524-2305 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3848-2306 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4141-2306 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2914-2307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4083-2307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5026-2307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5026-2307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2510-2308 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4864-2309 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3211-2310 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4119-2311 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4511-2311 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3640-2312 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5425-2313 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3356-2314 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3072-2317 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4380-2320 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5384-2321 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3076-2323 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5430-2324 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3188-2327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3240-2327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3408-2328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4607-2328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4694-2328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5562-2328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3408-2327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4607-2327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4243-2329 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5431-2329 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4243-2329 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4569-2330 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3056-2331 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3462-2331 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2850-2332 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2420-2333 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2880-2334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4434-2334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2880-2334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5810-2335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3346-2337 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4198-2337 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4308-2338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5092-2338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2873-2339 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5432-2339 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2563-2341 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2969-2341 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4289-2341 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2563-2341 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4290-2341 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4614-2342 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2563-2341 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4009-2346 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2807-2347 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4340-2347 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3552-2349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5752-2350 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4510-2351 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5187-2352 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4334-2354 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5434-2355 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5435-2356 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2369-2367 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2369-2366 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2369-2365 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2369-2364 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2369-2363 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2369-2362 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2627-2368 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3887-2368 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5417-2368 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3887-2368 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3272-2369 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4125-2369 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4173-2370 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2751-2371 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4009-2371 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3106-2373 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3544-2373 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3705-2373 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5437-2374 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3690-2374 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5336-2375 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3657-2377 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2504-2378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2584-2379 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3657-2379 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4895-2380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3296-2381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4983-2382 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2745-2383 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3632-2383 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2385-2384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5462-2384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2902-2385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3324-2385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5537-2385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2902-2385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5538-2385 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2817-2386 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4918-2387 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2494-2388 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2636-2389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2772-2390 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2772-2390 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3318-2392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3842-2392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5447-2393 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3005-2394 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3670-2394 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3713-2394 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5642-2394 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3670-2394 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4697-2396 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4697-2395 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5448-2397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2461-2398 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2975-2398 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5727-2399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4713-2400 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2405-2401 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4536-2401 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3209-2402 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5798-2404 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3922-2406 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5758-2407 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4831-2408 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5655-2408 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3156-2409 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3156-2410 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5340-2411 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5454-2412 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4209-2414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4209-2414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5445-2415 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2419-2416 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2504-2416 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3362-2416 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3438-2416 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5764-2416 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2504-2416 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2588-2418 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2777-2418 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2777-2417 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5597-2419 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3001-2420 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3074-2420 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4712-2420 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4851-2420 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3002-2421 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3075-2421 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4468-2421 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4902-2421 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5420-2421 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2423-2422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4244-2424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4734-2424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5307-2423 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5453-2424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5481-2423 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5482-2423 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5526-2423 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4244-2424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4734-2424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4244-2424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4484-2425 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5486-2425 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5702-2425 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4385-2426 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4675-2426 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3896-2427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5439-2427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5706-2427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2959-2429 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5452-2428 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3306-2430 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5565-2430 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4910-2432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4910-2431 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3501-2433 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5696-2433 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3785-2434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4018-2434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4354-2434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5227-2434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5751-2434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5456-2436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2587-2437 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2587-2438 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4770-2439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5554-2439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5143-2439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5126-2439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5123-2439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5536-2440 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3497-2441 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3892-2442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3892-2442 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2937-2443 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5440-2445 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3413-2446 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2559-2449 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4369-2449 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2555-2450 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3085-2450 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4153-2450 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4206-2450 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5434-2450 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5670-2450 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4205-2450 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4649-2452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5205-2452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5457-2453 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3331-2455 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3168-2456 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3642-2457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5032-2457 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3390-2459 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3917-2459 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4970-2460 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4232-2461 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4887-2461 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5449-2461 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3729-2462 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4565-2463 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4565-2463 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2899-2464 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4448-2464 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4652-2464 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2827-2465 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3627-2465 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2482-2467 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2482-2466 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4561-2468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4080-2469 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3844-2470 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4859-2470 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4857-2471 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5181-2472 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3734-2473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2815-2475 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4259-2475 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4606-2475 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5108-2476 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5184-2477 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5255-2477 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2721-2479 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3490-2480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4749-2481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5515-2481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2827-2482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3026-2482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2827-2482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3463-2483 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3590-2483 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3773-2483 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4094-2483 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3772-2483 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3771-2483 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4857-2484 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5279-2484 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3584-2486 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4680-2488 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2717-2489 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2711-2492 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3000-2492 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4071-2492 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5159-2492 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5458-2493 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5440-2494 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2783-2494 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2510-2496 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3671-2496 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2773-2497 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2915-2498 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5459-2499 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4189-2500 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4857-2500 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5219-2500 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5221-2500 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4857-2500 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4987-2501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4987-2501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3349-2502 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2774-2503 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2829-2505 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5722-2505 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2828-2506 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4389-2506 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4000-2507 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4000-2507 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3244-2509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3244-2509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4858-2510 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4858-2510 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4854-2511 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2710-2514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4770-2514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5159-2514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5711-2515 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2529-2518 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5460-2518 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3383-2519 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4801-2520 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3928-2521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2552-2522 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5339-2522 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2552-2522 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2923-2523 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2526-2525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2680-2526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3653-2526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4810-2526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5464-2526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2564-2527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4951-2527 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5463-2528 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5750-2529 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5460-2530 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2699-2531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2888-2532 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3151-2532 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3151-2532 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3934-2533 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4202-2534 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3475-2535 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5468-2537 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5497-2536 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2964-2538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2964-2538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5466-2539 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5467-2540 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3676-2541 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4728-2541 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4835-2541 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4728-2541 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5685-2542 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3903-2543 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4729-2543 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4736-2543 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4168-2545 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3181-2546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4785-2547 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4785-2547 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2759-2548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3657-2549 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3691-2549 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3370-2550 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4905-2550 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3834-2551 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4315-2551 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3639-2552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5563-2552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5564-2552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5837-2552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2621-2552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4453-2553 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5471-2555 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5472-2556 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5473-2557 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3932-2558 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3999-2558 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3098-2559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3816-2559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4072-2559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5246-2559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5757-2559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5484-2560 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3096-2561 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4101-2562 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4785-2562 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5703-2563 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5701-2563 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5470-2564 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3994-2565 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4358-2565 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5182-2567 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2844-2568 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3001-2569 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3001-2569 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4330-2570 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5381-2570 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5744-2570 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5784-2570 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5247-2572 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5039-2573 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5838-2573 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5661-2573 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3429-2574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4133-2574 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2821-2575 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2617-2576 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4388-2576 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5103-2576 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4387-2576 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5102-2576 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2731-2578 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5743-2578 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3162-2580 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5475-2581 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2977-2582 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2825-2583 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3003-2583 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5714-2583 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2791-2583 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2825-2583 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3003-2583 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2791-2583 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3657-2584 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3657-2584 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5373-2585 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5623-2585 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5477-2586 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4395-2587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4405-2587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4395-2587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4405-2587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2777-2588 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5392-2589 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2593-2591 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4667-2591 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5478-2592 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3106-2594 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4046-2594 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3106-2594 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5479-2596 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3565-2597 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4440-2597 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2869-2598 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3219-2598 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3341-2598 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4064-2598 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3405-2601 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3402-2603 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3612-2604 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5026-2605 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5448-2605 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4785-2606 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3353-2607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3969-2608 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4672-2608 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3017-2609 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5805-2609 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4857-2612 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5087-2613 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5481-2614 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5482-2614 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2951-2615 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5796-2615 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5797-2615 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2923-2618 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4582-2618 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2824-2619 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2925-2619 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4468-2619 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2824-2619 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2924-2619 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5563-2621 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2630-2622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3552-2622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3883-2622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2903-2623 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5240-2623 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5483-2625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2782-2626 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3132-2626 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4599-2626 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4599-2627 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4125-2628 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4629-2628 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4125-2628 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2943-2629 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4061-2629 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3434-2630 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5223-2631 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5495-2632 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5824-2632 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5525-2633 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2637-2636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5212-2636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5209-2637 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3495-2638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4164-2638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3644-2638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4165-2641 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5536-2641 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5574-2641 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4986-2642 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5811-2642 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3761-2643 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3369-2644 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3482-2644 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4535-2645 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5181-2645 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5777-2646 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4138-2647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4508-2647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5347-2647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4509-2648 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4886-2648 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3532-2649 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2710-2650 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3445-2650 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3979-2651 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3680-2652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2585-2653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3523-2653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4031-2653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5421-2653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2585-2653 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4772-2654 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3484-2659 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5680-2660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5681-2660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3504-2661 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4154-2661 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4875-2661 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3565-2665 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3565-2664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4247-2666 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4882-2666 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4247-2666 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4393-2667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5485-2668 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3875-2668 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5432-2669 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2668-2670 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4350-2673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3008-2674 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5392-2674 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5752-2674 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3008-2674 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3476-2676 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4690-2677 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5487-2678 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5488-2679 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3753-2680 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4775-2682 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3510-2683 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2685-2684 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5489-2684 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3160-2686 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3874-2686 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4908-2686 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2827-2687 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3889-2689 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4727-2689 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4822-2691 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4314-2692 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3649-2693 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3431-2694 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3168-2695 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4049-2695 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4662-2695 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4050-2695 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4893-2696 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5198-2696 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5826-2696 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3339-2697 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2888-2699 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3831-2698 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4609-2699 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4860-2698 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5390-2698 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3934-2700 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3934-2700 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3922-2702 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3923-2703 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5493-2704 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3305-2706 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3536-2706 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3553-2706 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3305-2706 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4127-2707 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5160-2711 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5162-2711 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3022-2712 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4718-2713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4717-2713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4716-2713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5057-2714 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3657-2715 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3657-2715 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3576-2717 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4809-2717 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4809-2717 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4219-2718 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3907-2719 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4436-2720 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3593-2721 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5495-2722 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4139-2723 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4217-2726 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4949-2730 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4949-2729 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3670-2731 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5641-2732 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3637-2735 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3806-2736 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4983-2736 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3114-2737 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4059-2737 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4985-2737 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3113-2737 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4985-2737 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3112-2737 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4621-2738 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3415-2739 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2937-2741 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2938-2742 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4723-2743 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4779-2743 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5100-2743 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4779-2743 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2838-2746 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4196-2746 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4417-2746 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5093-2746 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5728-2746 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4195-2746 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3502-2747 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3929-2747 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5500-2748 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3417-2749 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4797-2749 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5497-2750 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3655-2751 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5496-2753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5501-2754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2945-2755 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3756-2755 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2944-2755 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3756-2755 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4060-2756 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-2756 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4620-2757 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3359-2758 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3359-2758 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5498-2759 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5678-2760 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5377-2760 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2833-2762 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3254-2762 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4275-2762 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4402-2762 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4899-2762 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5809-2762 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4275-2762 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5231-2762 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3009-2763 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4803-2763 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4527-2764 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4527-2764 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5493-2765 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5766-2765 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3895-2767 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5074-2767 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5499-2768 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3801-2769 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5128-2769 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5502-2770 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4000-2771 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2954-2772 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3323-2772 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5433-2773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5443-2773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5444-2773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5590-2773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3323-2772 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3349-2773 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3497-2774 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3477-2776 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4174-2777 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5803-2777 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5413-2780 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4852-2781 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4852-2781 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4599-2782 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4062-2783 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5440-2783 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5461-2783 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5462-2783 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4062-2783 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3393-2784 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5125-2784 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4055-2785 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4949-2786 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4951-2787 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5503-2788 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3374-2790 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3663-2790 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3850-2792 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4190-2793 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4857-2794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3790-2795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3916-2795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5242-2795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3662-2798 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3663-2799 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4919-2800 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5448-2800 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3691-2801 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3504-2802 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4167-2802 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4371-2802 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4876-2803 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4247-2804 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5506-2806 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3300-2807 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4363-2807 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4386-2807 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5030-2807 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5289-2807 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5545-2807 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5547-2807 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5561-2807 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5029-2807 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3594-2808 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2937-2809 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5742-2809 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4713-2811 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5204-2811 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5450-2811 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4338-2812 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4339-2814 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4339-2813 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4306-2816 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4326-2816 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5441-2817 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3704-2818 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3175-2822 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3839-2822 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5313-2822 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5809-2822 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5142-2823 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3800-2825 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3799-2825 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3798-2825 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3797-2825 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5664-2826 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4389-2828 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5507-2830 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5509-2831 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3338-2832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5085-2833 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5257-2835 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5383-2836 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5511-2837 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2946-2838 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4556-2838 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5721-2840 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5512-2841 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4565-2842 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4642-2842 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4565-2842 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4642-2842 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4565-2842 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4565-2842 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5243-2843 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5513-2843 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3095-2845 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3558-2845 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5782-2846 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5516-2848 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5515-2849 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5514-2851 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5514-2852 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5518-2853 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3392-2854 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3749-2856 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5328-2856 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5776-2856 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4134-2857 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4163-2857 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2989-2860 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4842-2858 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4842-2859 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5519-2861 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4678-2862 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4440-2863 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5521-2866 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4925-2867 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3269-2868 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5609-2869 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5523-2870 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5522-2871 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3030-2875 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3068-2876 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3001-2877 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5308-2878 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5524-2878 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3028-2879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5525-2879 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4285-2880 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4577-2881 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4560-2882 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2909-2884 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3478-2885 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4856-2885 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5556-2885 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3205-2885 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3478-2885 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5669-2885 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3478-2885 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3472-2886 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4632-2886 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5079-2886 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3471-2886 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4633-2886 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4952-2886 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3470-2886 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3469-2886 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3319-2887 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5646-2887 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4008-2888 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3174-2889 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5526-2890 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3836-2891 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5026-2891 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5483-2891 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5528-2895 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5527-2895 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5673-2896 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4711-2897 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4124-2898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2902-2901 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5613-2903 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3892-2904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5397-2904 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4849-2906 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2930-2908 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2991-2908 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3602-2908 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4458-2907 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4843-2909 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5395-2907 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2990-2907 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4843-2907 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2913-2911 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3785-2912 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3922-2913 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4245-2913 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5769-2913 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4909-2916 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4935-2916 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3842-2917 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3842-2917 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3078-2918 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4374-2919 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3290-2920 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5530-2921 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3206-2923 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3674-2923 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2978-2926 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3605-2926 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3092-2927 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5771-2927 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3841-2929 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4990-2928 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5600-2929 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3841-2928 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5602-2928 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5533-2931 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5281-2933 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5835-2933 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4840-2934 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3232-2937 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5017-2937 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5073-2937 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3929-2938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4296-2938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4397-2938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3929-2938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3959-2939 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4920-2939 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3697-2940 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3233-2943 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5059-2943 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5435-2943 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4417-2946 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5045-2947 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5665-2947 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4338-2948 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4234-2949 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5535-2951 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5536-2952 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4663-2955 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2960-2956 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2959-2957 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4074-2959 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4149-2959 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5028-2958 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5582-2960 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4074-2958 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4149-2959 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5452-2959 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4970-2961 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5235-2962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4970-2962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5537-2963 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3990-2964 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4901-2964 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5208-2964 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3989-2964 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3033-2966 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5193-2966 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3974-2967 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4249-2967 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5539-2968 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5609-2970 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5632-2970 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3307-2971 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3595-2972 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4348-2972 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5456-2972 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5597-2972 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5634-2973 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3996-2976 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3396-2977 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4088-2977 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4359-2977 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5139-2977 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5839-2977 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4088-2977 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3477-2979 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4047-2981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4152-2981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5245-2981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5732-2981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3900-2982 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3546-2983 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4976-2984 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5658-2984 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4102-2986 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4786-2986 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3280-2989 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3672-2988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4307-2988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5533-2988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5637-2988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5639-2989 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3281-2991 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3382-2991 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4762-2992 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5610-2992 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4762-2992 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3613-2993 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3167-2994 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5161-2994 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5765-2994 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3039-2994 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3167-2994 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4555-2995 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3670-2996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3641-2997 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4591-2997 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3459-2998 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4950-2999 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4950-2999 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5037-3001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5109-3001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-3003 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4904-3003 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3074-3004 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3670-3005 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4771-3006 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4771-3006 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5445-3008 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4921-3010 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5161-3011 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5569-3011 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4783-3012 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3535-3013 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4764-3013 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5543-3015 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5768-3016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5774-3016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3512-3020 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5583-3022 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5018-3023 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5129-3023 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4020-3025 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3589-3026 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3392-3027 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4713-3028 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4453-3031 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3475-3032 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4456-3033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4504-3033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4630-3033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4857-3034 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4857-3035 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4857-3035 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4221-3036 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4834-3036 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3304-3037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4294-3037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4839-3040 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5118-3040 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4806-3041 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4577-3042 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3056-3043 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3261-3045 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3489-3046 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3051-3049 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3930-3049 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3050-3049 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5549-3052 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5188-3058 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5297-3058 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3666-3059 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3970-3059 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4949-3060 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5550-3062 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5551-3061 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3670-3064 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4327-3066 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5315-3066 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5627-3066 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3094-3067 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5648-3068 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4761-3069 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5817-3069 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4791-3069 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5552-3070 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3194-3071 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4765-3072 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5428-3072 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5150-3073 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4652-3076 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5221-3077 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5727-3077 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3701-3078 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5354-3078 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5367-3078 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3400-3079 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4542-3079 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5649-3079 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4542-3079 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3306-3080 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5651-3080 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3502-3081 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5252-3082 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3959-3083 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5134-3084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5619-3084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4067-3085 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4993-3088 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3554-3089 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3337-3091 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4946-3093 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5248-3093 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4060-3096 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4126-3096 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4913-3096 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4127-3096 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3680-3100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3680-3099 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3450-3101 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5369-3101 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5349-3101 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5556-3102 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4912-3103 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5324-3103 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3670-3104 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3670-3104 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3262-3105 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5575-3105 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3544-3106 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3752-3106 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4385-3106 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4752-3106 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5615-3106 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5472-3106 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4850-3108 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5085-3107 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5276-3108 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4956-3107 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5557-3115 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3501-3116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5558-3118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4344-3119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5604-3120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5808-3120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5599-3120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3171-3121 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2923-3122 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3804-3122 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4260-3124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5110-3124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4355-3125 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4971-3127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5561-3129 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4604-3132 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3002-3133 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3157-3134 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3921-3134 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3157-3134 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5351-3135 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5562-3136 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3139-3137 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3894-3138 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4967-3138 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5090-3138 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4966-3138 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4039-3139 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4968-3139 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3977-3140 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5837-3140 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5769-3141 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3463-3142 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3464-3143 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3870-3144 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3881-3145 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4122-3145 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5011-3145 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5040-3145 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4880-3147 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4898-3147 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5235-3146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4898-3146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5060-3150 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3593-3152 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4885-3152 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3251-3153 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3519-3153 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3268-3154 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3558-3156 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3927-3156 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3558-3156 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3926-3156 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3378-3157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4425-3157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5195-3157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5483-3157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5563-3159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4517-3162 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5495-3162 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5565-3163 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5566-3164 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4715-3165 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5335-3165 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3664-3166 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5569-3167 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4662-3168 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4955-3169 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5617-3170 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3259-3171 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4866-3172 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4917-3172 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3744-3173 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3744-3173 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4670-3173 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3389-3176 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4101-3177 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4631-3177 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5571-3178 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5113-3178 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4878-3179 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5572-3180 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5607-3181 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5778-3181 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4281-3183 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5368-3183 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4391-3185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4391-3184 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3507-3186 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4243-3187 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4242-3188 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4302-3189 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4683-3189 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5230-3190 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5345-3190 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4302-3189 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5046-3192 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4570-3191 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5553-3194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3263-3195 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3873-3197 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3874-3198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5491-3199 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4619-3200 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5261-3201 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4209-3202 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4492-3202 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5574-3203 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3262-3204 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5556-3205 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5576-3207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4863-3211 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5570-3212 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3817-3213 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3915-3213 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3916-3213 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4949-3214 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3293-3215 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4221-3215 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3292-3216 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4220-3216 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4758-3217 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5817-3217 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3814-3219 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3623-3221 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5481-3222 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3420-3226 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3420-3225 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3420-3224 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4600-3228 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4601-3227 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5435-3233 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5530-3234 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4173-3235 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4687-3236 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4701-3236 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4257-3237 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5270-3237 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5323-3238 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4627-3239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5021-3239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5579-3240 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5580-3241 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4609-3242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3429-3243 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4313-3243 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5557-3243 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5830-3244 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5745-3244 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4780-3245 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5640-3245 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4136-3246 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4436-3246 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5509-3246 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3643-3248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3643-3247 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3643-3249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3430-3251 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4439-3251 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5187-3251 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4785-3253 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5313-3254 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4665-3255 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3572-3256 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5581-3257 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4551-3259 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3940-3260 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4228-3262 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4230-3263 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4879-3263 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4886-3263 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4229-3263 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4879-3263 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4391-3264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4764-3265 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4969-3266 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5582-3266 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4969-3266 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5104-3267 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5122-3267 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5534-3267 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4467-3269 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3277-3271 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3645-3271 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5606-3271 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3276-3271 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3645-3271 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5605-3271 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3279-3272 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3278-3272 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4030-3280 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4323-3284 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4861-3287 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5584-3288 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3493-3290 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3861-3290 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3929-3291 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5772-3291 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4644-3293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4644-3292 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4267-3294 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3392-3295 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4538-3295 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3392-3295 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4406-3296 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5397-3297 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4199-3299 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5162-3301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5747-3301 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5824-3302 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4294-3304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5372-3304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5576-3304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5741-3304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3683-3305 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4815-3307 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5167-3308 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5730-3308 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5300-3314 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5682-3314 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3905-3315 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4094-3316 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4436-3316 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4094-3316 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3527-3316 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3526-3316 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3842-3317 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3421-3319 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4275-3320 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3696-3321 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3696-3322 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5461-3324 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5566-3324 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4842-3326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4842-3325 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4279-3328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5033-3328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5316-3328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5586-3330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5240-3332 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5027-3334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5027-3333 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4434-3336 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5234-3337 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5344-3338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3516-3339 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5609-3341 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3765-3342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4605-3342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5086-3342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3765-3342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5629-3342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5762-3342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4593-3343 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5591-3347 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5592-3347 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3349-3348 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5590-3349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5589-3350 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5477-3351 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4954-3351 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3925-3352 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3925-3352 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5319-3354 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4449-3357 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3480-3358 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4660-3358 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4660-3358 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4573-3359 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4339-3360 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4339-3360 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4173-3363 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4173-3363 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3366-3365 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3367-3365 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5598-3368 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5115-3369 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5216-3369 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5600-3371 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5601-3372 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3828-3373 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4329-3373 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5718-3373 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3828-3373 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4111-3374 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4398-3375 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5532-3376 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5531-3377 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5083-3379 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3892-3380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3892-3380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5131-3381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4584-3383 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3878-3384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4833-3384 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3915-3389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5532-3389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3916-3389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5531-3389 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3917-3390 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4285-3391 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3534-3392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4325-3392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5294-3392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5507-3392 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4019-3393 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4019-3393 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5605-3395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5476-3396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3398-3397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4123-3399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4035-3400 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5607-3401 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4053-3404 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3904-3408 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4962-3409 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5610-3410 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4448-3411 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3973-3412 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4027-3412 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3973-3412 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4138-3413 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5755-3414 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5271-3415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5546-3415 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4100-3416 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4319-3417 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5405-3419 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3874-3420 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5117-3420 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5116-3420 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5363-3420 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3728-3422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3885-3422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5119-3424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4340-3425 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5386-3425 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4340-3425 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5614-3427 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3517-3430 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4602-3432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5578-3432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3764-3434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4911-3435 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5615-3436 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3440-3437 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4233-3437 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4674-3437 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5764-3438 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5616-3439 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4674-3440 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4674-3441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5133-3442 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5617-3444 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5226-3446 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5227-3446 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5334-3446 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5791-3447 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4914-3448 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4960-3448 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4960-3448 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5618-3449 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3548-3450 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5529-3452 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4005-3453 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5767-3454 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5619-3455 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4771-3456 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5264-3459 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5620-3461 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3507-3462 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3743-3463 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3743-3463 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3475-3466 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3475-3468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3475-3465 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3475-3467 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4871-3474 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4871-3473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5320-3475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5369-3475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5468-3475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5349-3475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5497-3475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5548-3475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3712-3477 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3549-3478 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4219-3478 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4393-3479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4406-3479 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3538-3481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4115-3481 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5540-3483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5621-3485 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4449-3486 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4310-3487 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4399-3487 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5474-3487 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5475-3487 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5622-3488 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4380-3490 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4744-3490 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5096-3490 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4380-3490 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3560-3491 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5045-3491 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5045-3491 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5623-3492 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3861-3493 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3496-1494 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5268-3499 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5627-3500 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4002-3501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4561-3501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5093-3501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5625-3501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4003-3502 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4602-3503 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4781-3504 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4008-3505 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3870-3506 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3973-3507 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4828-3507 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5789-3507 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3973-3507 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3973-3507 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4026-3510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4026-3510 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4097-3511 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4097-3511 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3828-3512 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4544-3515 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5000-3514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5376-3515 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5780-3514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4787-3516 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4040-3521 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5705-3521 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5812-3522 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4416-3523 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5629-3525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5631-3528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4164-3529 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4808-3531 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5060-3531 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5422-3531 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4096-3532 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4874-3532 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4095-3532 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4254-3533 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5820-3534 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4052-3538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4115-3538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5413-3538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5634-3541 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4338-3543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5068-3543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4338-3543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5635-3545 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5008-3546 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4352-3547 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4883-3548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5168-3548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5468-3548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5520-3548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5697-3548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5172-3548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4510-3551 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4881-3552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4881-3552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3871-3553 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3557-3554 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3558-3555 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3558-3556 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4009-3559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4208-3559 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5328-3560 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5122-3561 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4715-3562 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4663-3563 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4002-3564 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4561-3564 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4002-3564 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3974-3565 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4999-3566 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3363-3569 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5622-3569 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4038-3572 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4499-3574 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5636-3573 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3573-1492 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4511-3575 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5707-3575 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3837-3577 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5275-3577 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5333-3577 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5827-3577 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4644-3578 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5637-3581 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5639-3582 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3384-3583 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3878-3583 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5638-3585 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5470-3586 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3423-3587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3979-3587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3502-3588 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5447-3588 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3734-3589 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5446-3592 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5360-3593 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5561-3593 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4297-3595 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5597-3595 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4180-3598 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4179-3598 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5297-3599 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4316-3600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4225-3601 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4183-3603 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4610-3603 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5616-3603 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5643-3604 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3388-3607 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4040-3607 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4070-3607 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4635-3605 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5016-3605 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5385-3607 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5463-3606 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5015-3606 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5173-3607 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4070-3607 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5342-3605 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5176-3607 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5341-3605 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3361-3608 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4041-3609 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4595-3609 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4594-3609 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4595-3608 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4594-3608 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4970-3608 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4502-3611 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5192-3610 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3399-3612 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3399-3612 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3356-3614 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5794-3614 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3356-3614 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4609-3615 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3893-3616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4676-3616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5256-3616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4676-3616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5645-3618 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3623-3620 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3623-3619 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4735-3622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4735-3621 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5318-3623 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5577-3623 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4464-3623 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3457-3623 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3738-3624 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3898-3624 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3997-3624 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4823-3624 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3872-3625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5330-3627 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4093-3627 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5801-3629 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4064-3630 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5511-3633 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5510-3634 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5646-3636 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4795-3638 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5564-3639 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5200-3640 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3923-3641 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4567-3641 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3524-3643 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3647-3643 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3851-3643 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3647-3643 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4164-3644 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4481-3646 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4480-3646 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4172-3648 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4482-3648 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5555-3650 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3652-3651 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3976-3651 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3976-3652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5758-3654 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3668-3655 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3669-3655 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4208-3655 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4010-3656 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4210-3656 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3691-3657 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4428-3657 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5615-3657 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5472-3657 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4174-3658 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4603-3658 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4415-3659 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5189-3659 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5647-3660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4681-3661 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3686-3662 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3884-3664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3996-3666 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4151-3666 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3738-3667 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3972-3667 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3997-3667 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4120-3670 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3303-3671 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3843-3671 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4390-3671 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4552-3671 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4853-3671 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4853-3671 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4842-3673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5649-3675 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3304-3677 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5576-3677 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5651-3678 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5650-3679 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5411-3680 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5652-3680 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5671-3680 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4939-3680 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5654-3681 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4610-3682 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4314-3687 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4602-3687 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5549-3688 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4909-3689 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4173-3692 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5436-3692 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4173-3692 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4222-3693 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4454-3694 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5657-3695 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4235-3696 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5091-3696 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5656-3696 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4542-3702 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4490-3703 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4489-3703 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5202-3704 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4170-3706 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4783-3706 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4305-3707 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5658-3708 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4910-3710 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5659-3711 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4356-3715 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5083-3719 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5094-3719 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5661-3722 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4321-3723 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5660-3725 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5762-3724 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4257-3726 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5321-3727 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3714-3728 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4420-3728 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4532-3728 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4420-3728 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3718-3730 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3717-3730 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4571-3729 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3716-3730 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4788-3733 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3923-3735 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3864-3738 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5394-3739 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5662-3742 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4094-3743 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4094-3743 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4569-3744 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4569-3744 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4802-3745 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5663-3746 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5180-3747 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5427-3749 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4483-3750 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4521-3750 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5282-3751 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5664-3754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3851-3755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3867-3755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4709-3755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5053-3755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4321-3757 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5403-3758 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4796-3762 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4612-3764 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4380-3764 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5496-3765 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5825-3765 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4722-3765 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4594-3766 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4595-3766 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5035-3767 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4745-3778 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4703-3779 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4702-3778 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4719-3786 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5683-3786 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4434-3787 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5587-3787 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4447-3788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5802-3788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4112-3791 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5667-3792 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4814-3794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4816-3794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4813-3794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4070-3796 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4070-3795 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3987-3801 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4274-3801 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4365-3801 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5190-3801 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5506-3801 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3987-3801 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4724-3802 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5502-3802 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4904-3803 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4985-3805 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4072-3806 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3813-3807 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3812-3807 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3811-3807 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4072-3816 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5241-3817 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4110-3818 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5669-3819 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4149-3821 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4149-3820 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3877-3823 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3967-3823 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4322-3822 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3966-3822 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4322-3823 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4323-3824 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5058-3827 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4535-3829 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5272-3830 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4991-3831 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5084-3831 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5459-3832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5504-3832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5130-3834 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5671-3834 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3882-3835 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4736-3838 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4736-3838 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4275-3839 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5673-3840 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5442-3842 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4552-3843 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4341-3847 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5786-3847 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5787-3846 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4682-3848 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4963-3850 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5504-3850 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5675-3853 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5674-3852 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5755-3855 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5676-3856 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4723-3859 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3867-3863 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4500-3865 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4929-3865 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5332-3865 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3923-3866 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4246-3866 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5677-3869 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5678-3869 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4948-3870 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4948-3870 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5650-3871 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4968-3873 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4969-3874 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5364-3873 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4308-3875 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5679-3876 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4505-3882 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4612-3883 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5378-3883 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4245-3886 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5804-3888 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5302-3890 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5617-3892 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5256-3893 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4581-3895 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4385-3896 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5072-3898 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4632-3899 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4656-3899 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4633-3899 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4656-3899 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4435-3902 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5735-3903 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5522-3907 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4092-3908 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5049-3908 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5228-3908 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5709-3908 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4097-3909 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5684-3910 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4749-3911 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4027-3914 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5789-3914 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4827-3916 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4827-3915 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5685-3920 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4500-3922 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5110-3922 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3988-3923 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4286-3923 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5431-3923 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4056-3929 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5262-3929 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5454-3929 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5699-3929 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5731-3936 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5764-3936 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4102-3937 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5687-3941 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5408-3943 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4006-3946 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4006-3947 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5263-3948 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3952-3951 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4454-3951 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5169-3951 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4558-3953 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4950-3954 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4950-3955 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4608-3956 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5167-3956 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5427-3956 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5790-3956 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5691-3957 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4920-3959 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5690-3964 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4902-3968 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4077-3969 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4077-3969 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5317-3971 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5072-3972 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4190-3973 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5097-3973 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4998-3974 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5693-3978 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4916-3980 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5076-3981 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5521-3982 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5692-3983 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4921-3984 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5694-3985 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5344-3986 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5696-3991 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4692-3992 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4357-3993 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5815-3995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4305-3996 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4461-3996 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5496-3998 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4326-4000 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4360-4000 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4714-4001 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5478-4002 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4682-4003 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5237-4005 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5204-4007 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5698-4010 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5699-4012 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5699-4012 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5408-4013 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4097-4014 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4897-4014 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5480-4015 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5567-4015 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4602-4016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4602-4016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5226-4018 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5125-4019 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4452-4022 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5146-4022 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4452-4022 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5145-4022 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4678-4023 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5701-4025 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5089-4028 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5702-4029 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4872-4032 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4895-4033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4094-4034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4542-4035 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5704-4036 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4370-4037 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5785-4037 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5838-4038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4968-4039 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5385-4040 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5705-4040 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4970-4041 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5425-4042 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4713-4051 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5705-4054 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4300-4055 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4539-4055 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5778-4055 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5706-4057 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5059-4061 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4597-4062 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5224-4062 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4221-4066 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4220-4066 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5770-4067 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4391-4070 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4391-4070 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5173-4070 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5176-4070 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4224-4072 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4369-4072 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4674-4078 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4675-4078 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4769-4079 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5708-4082 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5080-4084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5843-4084 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5295-4089 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4613-4090 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4943-4091 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4929-4093 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5330-4093 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5492-4093 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4646-4097 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5795-4097 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4898-4098 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4944-4098 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4722-4099 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5827-4101 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4441-4104 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5713-4105 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4926-4106 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5710-4106 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4109-4108 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4329-4110 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5570-4110 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5005-4112 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5714-4114 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5716-4121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4237-4123 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5418-4125 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4138-4130 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4535-4131 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5167-4133 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5557-4133 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5790-4133 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5805-4132 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4202-4135 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4845-4135 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5153-4136 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5692-4136 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5251-4137 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4844-4138 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4993-4140 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5786-4140 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4994-4141 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5718-4144 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5717-4145 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4467-4147 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4467-4147 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4247-4148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5719-4148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4377-4149 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5720-4152 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5196-4155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4692-4156 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5416-4156 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5721-4158 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5559-4159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5722-4160 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4313-4162 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4373-4162 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5776-4162 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4313-4162 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4373-4162 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5723-4164 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5631-4164 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5382-4166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5425-4166 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5030-4169 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4663-4170 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5174-4173 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5336-4173 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5622-4173 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5803-4174 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4674-4175 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4322-4176 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5726-4176 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4178-4177 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5288-4177 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5727-4181 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5745-4182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5022-4183 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4841-4186 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5148-4186 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4757-4187 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5186-4191 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4956-4193 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4956-4192 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4194-4195 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4572-4199 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4870-4199 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5782-4199 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4872-4201 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-4200 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5551-4200 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4436-4203 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5509-4203 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5692-4203 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5578-4204 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4466-4209 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4492-4209 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5211-4208 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4492-4209 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4491-4208 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4484-4210 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4902-4210 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5698-4210 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5702-4210 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4904-4211 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5381-4212 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5734-4212 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5298-4218 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5362-4217 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4947-4222 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4341-4226 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5730-4227 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5449-4231 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4674-4233 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4890-4234 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5157-4234 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5400-4234 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4317-4238 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4671-4240 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5203-4239 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4239-4262 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5733-4241 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4826-4242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4882-4242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4248-4243 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4734-4244 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4837-4247 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5401-4247 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5649-4248 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4998-4249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5647-4249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4816-4250 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5174-4252 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5731-4252 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5434-4253 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5232-4256 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5232-4255 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5781-4259 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5735-4261 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5018-4263 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5737-4264 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5707-4265 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5685-4268 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5753-4273 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4855-4278 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4855-4277 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4996-4279 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5368-4281 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5586-4281 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4975-4283 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4436-4286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5608-4287 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5739-4288 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4279-4291 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5740-4292 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4312-4293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4563-4293 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5741-4294 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5374-4299 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5528-4299 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5527-4298 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4301-4300 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5383-4302 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5841-4305 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5742-4311 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5530-4315 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5584-4315 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4415-4319 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4616-4322 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4712-4321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5337-4321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5338-4321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5419-4322 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5679-4322 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5726-4322 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5724-4322 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5194-4323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5420-4324 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4902-4323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5365-4324 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5293-4325 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4547-4334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4545-4334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5311-4335 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4765-4336 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5747-4337 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4889-4338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5068-4338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5068-4338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4902-4339 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4902-4339 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4902-4339 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5387-4340 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5393-4341 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5771-4341 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5821-4341 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5748-4344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5144-4344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5370-4346 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5749-4347 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4580-4349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5034-4349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5218-4349 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5409-4351 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5569-4351 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4433-4352 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4794-4353 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5230-4355 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5240-4355 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4420-4356 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4420-4356 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4713-4360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4906-4361 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5189-4361 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5392-4362 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4483-4365 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5753-4366 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5249-4368 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5371-4371 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5586-4372 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5171-4375 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5806-4376 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5756-4381 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5754-4383 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4885-4386 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4853-4390 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4720-4391 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5165-4393 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5114-4394 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5757-4396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4585-4398 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4864-4403 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5760-4407 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5761-4409 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4874-4411 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4874-4410 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5002-4416 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4989-4418 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5761-4418 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5303-4419 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5763-4421 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5762-4422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5360-4424 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4681-4426 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4873-4426 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4681-4426 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4620-4427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4852-4429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4957-4429 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5709-4430 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4668-4433 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4668-4433 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4750-4434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4915-4434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4751-4434 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5657-4436 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5266-4441 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5765-4444 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5088-4447 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5810-4447 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5772-4449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4921-4450 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5766-4451 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4888-4452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5662-4452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5145-4452 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5741-4454 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5823-4455 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4529-4456 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4630-4457 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5138-4456 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5141-4457 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4898-4459 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4672-4463 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4492-4465 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5768-4467 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4770-4469 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4480-4475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4482-4479 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4482-4478 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4482-4477 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4482-4476 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5005-4483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5506-4483 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4799-4485 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5769-4487 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5175-4495 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5247-4495 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5558-4497 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4601-4501 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4801-4505 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5251-4505 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5771-4506 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5772-4507 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4045-4508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4138-4508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5239-4508 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5687-4509 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5479-4513 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5361-4514 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5774-4515 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4845-4518 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4136-4520 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5775-4522 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4322-4523 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4322-4523 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5700-4525 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5375-4526 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5380-4526 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4826-4528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4882-4528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5273-4533 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5733-4535 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5742-4536 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5777-4537 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5507-4538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5508-4538 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5779-4541 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4569-4543 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4569-4543 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5386-4548 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5515-4550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5691-4550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5813-4550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5814-4550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5518-4552 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5601-4564 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4589-4565 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4588-4565 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4922-4568 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4922-4568 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4706-4569 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5812-4569 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4706-4569 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4706-4569 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4706-4569 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4706-4569 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5581-4574 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5627-4575 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4576-4577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4792-4577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5783-4577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5785-4579 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4739-4580 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5138-4581 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5259-4587 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4656-4589 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4656-4588 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5786-4592 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5788-4596 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5789-4598 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4798-4602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5473-4602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5578-4602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5626-4602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5729-4602 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5628-4603 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5051-4605 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5629-4605 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5458-4607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4860-4609 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5314-4609 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5467-4609 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5616-4610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5653-4610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4774-4611 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5654-4611 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5791-4613 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4637-4614 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4971-4620 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5612-4622 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5792-4623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5519-4624 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5101-4625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5242-4625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5216-4627 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5794-4628 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4793-4631 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4661-4638 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4643-4641 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4658-4641 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5121-4641 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4658-4641 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5795-4645 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5501-4647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4785-4650 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4805-4650 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5237-4653 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5321-4655 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4737-4657 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5798-4659 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4894-4668 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4917-4669 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5250-4671 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5134-4673 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5178-4674 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5804-4677 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4845-4680 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5801-4681 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4745-4688 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5806-4693 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5807-4695 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5807-4696 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4745-4704 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5808-4707 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5810-4710 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5137-4713 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5135-4713 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5450-4713 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5343-4719 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5811-4721 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5825-4722 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4796-4724 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4613-4726 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5822-4733 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5512-4736 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5140-4739 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5677-4739 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5765-4742 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4921-4753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5458-4753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4969-4756 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4968-4755 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5203-4758 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5618-4768 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5540-4771 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4801-4773 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5654-4774 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5366-4775 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5660-4775 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5818-4776 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5166-4777 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5816-4778 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5670-4780 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5315-4782 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4805-4784 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5275-4784 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5229-4786 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5817-4790 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5651-4792 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4916-4794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4916-4794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4986-4795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5819-4797 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5626-4798 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5526-4800 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5191-4802 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5770-4802 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5290-4806 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5299-4807 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5070-4822 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5306-4822 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5404-4822 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5490-4822 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5072-4824 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4993-4830 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4993-4830 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5720-4832 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4895-4834 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5801-4838 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5142-4839 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4960-4840 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5788-4840 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4960-4840 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5148-4841 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4884-4845 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4846-4847 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5800-4847 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5829-4847 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4961-4855 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4962-4855 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5505-4857 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5130-4859 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5584-4859 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5822-4862 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4895-4867 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4895-4868 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5244-4869 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5076-4873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5063-4874 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5282-4879 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5714-4880 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5826-4892 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5618-4895 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5302-4896 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5231-4899 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5827-4900 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5163-4901 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5194-4902 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5595-4902 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5365-4902 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5415-4910 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4935-4910 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4936-4912 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5384-4912 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5486-4912 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5756-4912 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5694-4921 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5719-4921 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5779-4921 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4924-4923 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5828-4926 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5663-4938 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5829-4941 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5636-4942 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5092-4947 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5580-4949 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5630-4949 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5701-4949 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4959-4951 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5213-4950 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5470-4951 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5550-4951 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5551-4951 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5675-4951 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5210-4950 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5674-4950 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5503-4950 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5477-4954 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5380-4955 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5276-4956 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5445-4956 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5830-4957 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5831-4958 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5154-4960 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5155-4960 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5459-4963 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5304-4964 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5832-4965 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5831-4966 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5117-4969 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5582-4969 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5116-4969 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5363-4969 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5364-4968 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5156-4972 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5541-4976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4984-4982 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4984-4981 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4985-4980 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5238-4987 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5249-4987 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5821-4993 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5833-4995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5600-4996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5645-4996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5388-4996 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5647-4998 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5773-4998 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5740-5000 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5291-5001 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5623-5002 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5834-5006 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5835-5009 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5836-5009 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5539-5013 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5090-5014 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5670-5020 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5653-5022 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5837-5023 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5252-5026 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5136-5027 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5082-5029 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5236-5031 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5799-5032 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5640-5038 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4983-5043 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5757-5043 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5513-5047 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5064-5056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5840-5067 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5482-5069 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5333-5071 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5842-5071 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5841-5077 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5844-5081 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5763-5086 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5351-5099 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5544-5099 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5744-5107 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5574-5112 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5390-5120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5144-5126 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5596-5127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5748-5158 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5280-5166 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5844-5192 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5222-5200 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5490-5206 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5339-5207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5441-5214 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5706-5215 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5457-5262 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5284-5271 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5233-5289 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5428-5350 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5588-5354 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5713-5370 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5602-5388 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5494-5403 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5738-5411 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5548-5424 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5443-5684 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5644-5467 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5575-5469 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5723-5480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5545-5488 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5244-5500 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5659-5500 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5775-5501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5581-5514 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5813-5517 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5444-5534 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5565-5625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5591-5593 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5603-5601 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5759-5611 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5631-5633 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5806-5643 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5735-5657 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5755-5672 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5830-5746 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5832-5775 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2583-5947 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6056-5947 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6044-5948 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6076-5948 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5952-5949 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5952-5949 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6035-5949 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6112-5949 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6120-5949 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6140-5949 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4408-5950 connects the same voltage levels (90.0, 90.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 140-5951 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6071-5951 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6071-5951 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6037-5952 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6144-5952 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6174-5952 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6174-5952 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6212-5952 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6212-5952 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4126-5953 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6048-5953 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6085-5953 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6091-5953 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3002-5954 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3133-5954 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5984-5956 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2791-5957 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 264-5957 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5846-5957 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5856-5957 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6155-5958 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6211-5958 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6228-5958 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6044-5959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6072-5959 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5980-5960 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6135-5960 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6152-5960 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6159-5960 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6208-5960 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6027-5961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6058-5961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6234-5961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6243-5961 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6059-5962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6064-5962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6076-5962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6101-5962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6183-5962 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2707-5964 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4126-5964 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6145-5963 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5975-5964 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6091-5964 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4787-5965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6155-5965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6180-5965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6041-5966 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6161-5966 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6037-5967 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6043-5967 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6144-5967 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6165-5967 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6115-5968 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6178-5968 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2659-5969 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6077-5970 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6222-5970 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6174-5971 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6223-5971 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5982-5972 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6090-5972 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6093-5972 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6204-5972 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6007-5974 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6007-5973 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6123-5974 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6130-5973 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6090-5975 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3496-5976 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6167-5976 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5982-5977 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6107-5977 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6178-5977 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6178-5977 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6186-5977 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6045-5978 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6241-5978 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6123-5979 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6180-5979 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5986-5980 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5997-5980 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6046-5980 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6135-5980 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6159-5980 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6018-5981 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6102-5981 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6091-5982 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6107-5982 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6186-5982 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5845-5983 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5859-5983 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5858-5983 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6006-5983 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6000-5984 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5999-5984 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6056-5984 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6056-5984 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6012-5985 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6239-5985 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6179-5986 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5852-5987 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6074-5987 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6074-5987 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5997-5988 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6124-5988 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5990-5989 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6236-5989 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5512-6187 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5996-5991 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6105-5991 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6147-5991 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 800-5993 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6062-5992 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6123-5992 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6155-5992 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6155-5992 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6155-5992 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6122-5994 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6154-5994 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6211-5994 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6161-5995 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6180-5995 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6164-5996 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6154-5998 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6228-5998 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6125-6001 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6133-6001 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6168-6001 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6006-6002 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6056-6002 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6041-6003 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6161-6003 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6126-6004 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6126-6004 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6176-6004 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6176-6004 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1756-6005 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5464-6005 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5845-6006 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5857-6006 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6054-6006 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6053-6006 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5992-6007 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5992-6007 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6206-6008 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6225-6008 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6229-6008 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6127-6010 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6127-6009 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6129-6010 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6129-6009 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5850-6011 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6025-6014 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6025-6013 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6084-6014 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6141-6013 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6141-6014 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6240-6014 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5848-6015 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5847-6015 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6060-6016 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6061-6016 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6162-6016 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6081-6017 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6094-6017 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6094-6017 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6132-6017 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6020-6018 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6020-6018 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6103-6018 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5846-6019 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6114-6019 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6114-6019 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6114-6019 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6242-6019 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6069-6020 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6069-6020 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5845-6021 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5846-6022 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4984-6023 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3096-6025 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6066-6024 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6067-6023 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6239-6024 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6238-6023 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6085-6025 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6084-6025 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6045-6026 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6045-6026 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6045-6026 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6103-6026 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6102-6026 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6063-6027 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6075-6027 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6233-6027 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6243-6027 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5854-6028 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5860-6028 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6128-6028 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6207-6028 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4903-6032 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4904-6031 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5848-6030 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5847-6030 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6189-6029 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6210-6032 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6210-6031 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6094-6033 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6094-6033 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6244-6033 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6244-6033 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5853-6034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6224-6034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6059-6035 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6120-6035 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6111-6036 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6143-6036 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6203-6036 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6149-6038 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6200-6038 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6157-6039 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6178-6039 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6046-6040 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6136-6040 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6159-6040 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6184-6040 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1064-6118 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6219-6041 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6219-6041 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6138-6042 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6158-6042 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6212-6043 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6064-6044 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6081-6045 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6081-6045 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6241-6045 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6142-6046 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6156-6046 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6089-6047 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6090-6048 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6115-6048 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6115-6048 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6051-6050 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6051-6049 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6200-6050 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6200-6049 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6117-6051 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6117-6051 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6060-6055 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6136-6055 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6151-6055 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6230-6055 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5851-6056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5857-6056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6205-6056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6063-6057 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6073-6059 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6073-6059 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6120-6059 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6148-6059 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6166-6059 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6202-6059 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6235-6059 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6061-6060 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6172-6060 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6069-6061 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6069-6061 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6190-6061 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6123-6062 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6232-6063 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6243-6063 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6170-6064 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6226-6064 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6111-6065 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6139-6065 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6167-6065 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6088-6066 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6089-6067 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6123-6068 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6180-6068 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6244-6069 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6244-6069 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6074-6070 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6204-6070 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6230-6070 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 141-6072 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6075-6071 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6075-6071 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6076-6072 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6101-6073 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6148-6073 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6166-6073 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6202-6073 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6226-6073 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6151-6074 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6230-6074 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6133-6075 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6133-6075 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6243-6075 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6235-6076 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6222-6077 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6141-6079 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6141-6079 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6141-6078 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6141-6078 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5849-6080 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6132-6081 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6089-6083 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6087-6082 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5860-6085 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6090-6084 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6091-6085 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6090-6084 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5850-6086 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4127-6091 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6097-6087 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6130-6088 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6093-6090 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6204-6090 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6207-6091 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6115-6092 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6124-6092 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6122-6095 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6163-6095 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6211-6095 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6146-6096 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6146-6096 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6164-6096 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6123-6097 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6108-6099 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6114-6098 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6114-6099 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5851-6100 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6162-6102 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6177-6103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6198-6102 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6197-6103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6140-6104 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6166-6104 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6176-6104 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6202-6104 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6147-6105 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6237-6105 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6112-6106 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6165-6106 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6110-6108 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6114-6108 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6244-6109 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6244-6109 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6214-6110 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6124-6113 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6208-6113 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5856-6114 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5859-6114 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5858-6114 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5852-6116 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6210-6116 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6240-6116 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6119-6117 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6149-6119 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6148-6120 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5853-6121 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6182-6121 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6224-6121 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6145-6123 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6133-6125 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6134-6127 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6210-6127 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5854-6128 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6151-6128 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6137-6129 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6172-6129 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6172-6129 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6177-6129 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6175-6131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6185-6131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6185-6133 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6210-6134 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6150-6136 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6159-6136 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6230-6136 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6162-6137 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6173-6138 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6151-6141 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6151-6141 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6184-6142 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6174-6144 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6174-6144 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6212-6144 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6223-6144 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6147-6146 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6216-6147 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6166-6148 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6202-6148 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6212-6148 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5855-6150 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5854-6151 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6172-6151 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6230-6151 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6229-6152 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2234-6153 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1192-6155 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6180-6155 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6211-6155 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5855-6156 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6184-6157 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6222-6158 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5856-6160 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 36-6195 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 35-6194 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6215-6161 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6221-6161 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5849-6162 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6195-6164 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6206-6164 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6208-6164 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6212-6165 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6202-6166 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6168-6167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6203-6167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5853-6171 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6236-6171 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5849-6172 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6183-6176 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5855-6178 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6179-6178 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1191-6180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6221-6180 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6173-6181 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6222-6181 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6224-6182 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6016-6192 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6016-6191 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6241-6199 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5857-6201 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6135-6208 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5848-6209 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5847-6209 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5852-6210 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5851-6213 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6219-6215 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4942-6216 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5859-6218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5858-6217 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1955-6219 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1955-6219 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 800-6220 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 323-6223 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5860-6227 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6243-6231 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6225-6237 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5850-6238 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 35-5889 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 35-5913 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 146-5861 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 146-5914 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 180-5890 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 180-5915 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 380-5916 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 459-5862 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 459-5891 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 617-5892 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 755-5863 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 755-5893 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 916-5864 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 916-5894 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 934-5865 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 935-5917 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 934-5931 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 935-5941 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 998-5866 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 998-5895 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1037-5918 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1072-5919 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1261-5942 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1459-5867 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1531-5932 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1531-5943 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1595-5868 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1595-5896 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1929-5897 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2082-5869 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2179-5920 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2179-5933 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2242-5870 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2460-5898 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2460-5921 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2659-5922 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2707-5923 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2764-5871 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2778-5872 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2779-5899 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2825-5873 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2825-5900 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2886-5874 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2886-5901 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2886-5924 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2886-5934 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2894-5875 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2910-5876 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2910-5902 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2961-5903 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2962-5925 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2962-5935 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3025-5877 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3025-5904 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3173-5878 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3173-5905 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4570-3192 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3609-5879 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3609-5906 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3608-5926 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3608-5936 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3697-5880 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3873-5927 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3930-5881 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3930-5907 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4041-5882 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4070-5883 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4070-5908 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4098-5884 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4126-5928 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4127-5937 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4268-5885 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4284-5944 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4543-5886 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4543-5909 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4656-5929 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4656-5938 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4767-5887 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4854-5910 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4952-5888 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4952-5911 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4952-5930 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4952-5939 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4952-5945 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4970-5912 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4970-5940 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 4970-5946 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6193-6118 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% INFO    : 
% INFO    : === Line Capacity UB Model Notes ===
% INFO    : Updated Thermal Rating: on line 4639-1 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2186
% INFO    : Updated Thermal Rating: on line 5234-1 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 910
% INFO    : Updated Thermal Rating: on line 1676-2 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2441
% INFO    : Updated Thermal Rating: on line 1667-3 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 2296-3 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 695-4 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 3931-4 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 5036-4 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 4405-5 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 2772-6 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1398
% INFO    : Updated Thermal Rating: on line 2773-7 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 884
% INFO    : Updated Thermal Rating: on line 470-9 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 11-10 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24078
% INFO    : Updated Thermal Rating: on line 11-10 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24078
% INFO    : Updated Thermal Rating: on line 30-11 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 2922-11 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 2174-12 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 4009-12 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 4011-12 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60355
% INFO    : Updated Thermal Rating: on line 1220-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 2867-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 4587-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 4945-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 5220-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 2867-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 4587-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 2899-15 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 4116-15 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 4447-15 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 249-16 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 337-16 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 5824-17 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 3719-18 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 5084-19 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 3719-20 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5369
% INFO    : Updated Thermal Rating: on line 1349-21 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 1592-21 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 1837-22 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 5013-22 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 1152-23 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 2696-23 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 3418-23 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 144-24 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 1277-24 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 490-25 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1048
% INFO    : Updated Thermal Rating: on line 2086-25 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 612-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 1860-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2731
% INFO    : Updated Thermal Rating: on line 2595-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 2915-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 3332-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 4624-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 2915-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 2677-28 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 3884-28 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 2880-29 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 3314-29 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 3314-29 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 144-30 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 1548-30 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 4831-30 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 150-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on line 3155-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 3684-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 4733-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1018
% INFO    : Updated Thermal Rating: on line 150-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on line 3721-32 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 4738-33 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3441
% INFO    : Updated Thermal Rating: on line 4848-34 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9629
% INFO    : Updated Thermal Rating: on line 5219-37 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5505-37 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 725-38 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4462
% INFO    : Updated Thermal Rating: on line 1224-39 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 5799-39 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 1224-39 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 2244-40 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4587-40 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 1479-42 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1454
% INFO    : Updated Thermal Rating: on line 2758-42 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3651
% INFO    : Updated Thermal Rating: on line 2717-43 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4689
% INFO    : Updated Thermal Rating: on line 3481-44 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 4314-44 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 5087-45 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38027
% INFO    : Updated Thermal Rating: on line 1080-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 2187-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 3298-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 1080-47 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 5353-48 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 1218-49 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 2338-49 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 470-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 1670-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 3546-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 416
% INFO    : Updated Thermal Rating: on line 4621-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 3546-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 4621-50 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 909
% INFO    : Updated Thermal Rating: on line 166-52 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 846
% INFO    : Updated Thermal Rating: on line 5479-52 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on line 3342-53 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1285
% INFO    : Updated Thermal Rating: on line 2762-54 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 373-55 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53975
% INFO    : Updated Thermal Rating: on line 5088-57 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 142-59 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on line 1646-59 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1124
% INFO    : Updated Thermal Rating: on line 2469-60 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 3518-60 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 2221-61 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 2627-61 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 2041-62 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on line 2943-62 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 996
% INFO    : Updated Thermal Rating: on line 371-63 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 3074-63 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 4599-65 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 4599-65 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 889
% INFO    : Updated Thermal Rating: on line 1541-66 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 2285-66 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on line 3242-66 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 3023-67 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1862
% INFO    : Updated Thermal Rating: on line 2876-68 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 4529-68 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 5141-68 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 4602-69 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 5089-70 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303410
% INFO    : Updated Thermal Rating: on line 2158-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 3138-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 5090-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1625
% INFO    : Updated Thermal Rating: on line 3138-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 4954-75 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on line 2077-75 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1945
% INFO    : Updated Thermal Rating: on line 2337-77 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on line 240-78 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3471
% INFO    : Updated Thermal Rating: on line 4554-78 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90076
% INFO    : Updated Thermal Rating: on line 630-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1176
% INFO    : Updated Thermal Rating: on line 1865-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1899
% INFO    : Updated Thermal Rating: on line 2403-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1510
% INFO    : Updated Thermal Rating: on line 4069-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16079
% INFO    : Updated Thermal Rating: on line 630-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1176
% INFO    : Updated Thermal Rating: on line 4068-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18009
% INFO    : Updated Thermal Rating: on line 675-82 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 798-82 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 2066-82 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 2122-84 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 3794-84 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 5093-85 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 2802-86 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 3504-86 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 3763-87 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on line 4338-87 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 3763-87 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 1611-88 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 1700-88 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 3635-88 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 5549-88 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 2489-89 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 4218-89 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 5094-90 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21404
% INFO    : Updated Thermal Rating: on line 3719-91 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 648-92 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 4048-92 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 5719-92 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 2130-93 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on line 3760-94 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1339
% INFO    : Updated Thermal Rating: on line 5834-94 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 283-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 1169-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 5695-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1943
% INFO    : Updated Thermal Rating: on line 4102-96 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 706
% INFO    : Updated Thermal Rating: on line 2994-97 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 4168-97 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 4437-97 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 2994-97 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 1247-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 3510-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on line 4644-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 2626-99 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 2627-99 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 552-100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 1189-100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 1190-100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 1898-101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 4441-101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 1474-102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5495
% INFO    : Updated Thermal Rating: on line 1957-103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 2480-103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 4273-103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 1957-103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 2201-106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1225
% INFO    : Updated Thermal Rating: on line 2265-106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 676
% INFO    : Updated Thermal Rating: on line 3255-106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 5060-106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 3971-108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 3970-108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 633-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on line 672-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 760-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 5193-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 5197-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 4732-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 481-110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1479
% INFO    : Updated Thermal Rating: on line 714-111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 4434-111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 1163-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1009
% INFO    : Updated Thermal Rating: on line 1650-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 2289-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 5304-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 1164-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 1649-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 2289-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 1648-112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 3514-114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 3986-114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 1239-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 1242-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on line 5399-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5521-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 4954-118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4034
% INFO    : Updated Thermal Rating: on line 996-119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 4549-119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 996-119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 2696-120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 5224-121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 5451-121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 5096-122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1677
% INFO    : Updated Thermal Rating: on line 5096-123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1677
% INFO    : Updated Thermal Rating: on line 5097-124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 1259-125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 1258-125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 4301-126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 5728-126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 179-127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13220
% INFO    : Updated Thermal Rating: on line 2739-129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 4251-129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 5286-129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1311
% INFO    : Updated Thermal Rating: on line 5732-128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 901
% INFO    : Updated Thermal Rating: on line 2739-128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 5285-128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1419
% INFO    : Updated Thermal Rating: on line 783-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29203
% INFO    : Updated Thermal Rating: on line 2188-132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 2727-132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 1703-133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2646
% INFO    : Updated Thermal Rating: on line 1879-136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 4807-136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 626-137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 3041-137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 4519-138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 5175-138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1408
% INFO    : Updated Thermal Rating: on line 3550-139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 4743-139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 185-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 761
% INFO    : Updated Thermal Rating: on line 1646-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 2211-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 2212-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 3883-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 5715-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 3883-142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 1548-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 1555-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16510
% INFO    : Updated Thermal Rating: on line 3685-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 5036-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 915
% INFO    : Updated Thermal Rating: on line 5655-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 1555-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4881
% INFO    : Updated Thermal Rating: on line 2714-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1470
% INFO    : Updated Thermal Rating: on line 3365-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2256
% INFO    : Updated Thermal Rating: on line 4594-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2077
% INFO    : Updated Thermal Rating: on line 2714-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1470
% INFO    : Updated Thermal Rating: on line 3365-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2258
% INFO    : Updated Thermal Rating: on line 4595-146 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2074
% INFO    : Updated Thermal Rating: on line 4971-147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1696
% INFO    : Updated Thermal Rating: on line 480-148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2466
% INFO    : Updated Thermal Rating: on line 4234-149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 1988-150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 942
% INFO    : Updated Thermal Rating: on line 4260-152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 4512-151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 4694-152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 156-151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 3568-153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 5474-153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on line 5716-153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 520
% INFO    : Updated Thermal Rating: on line 5475-153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 5099-155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16165
% INFO    : Updated Thermal Rating: on line 684-157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 4737-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7261
% INFO    : Updated Thermal Rating: on line 5800-157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1058
% INFO    : Updated Thermal Rating: on line 1721-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 2757-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 2832-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 3684-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 4615-162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 4661-162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on line 2216-164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7864
% INFO    : Updated Thermal Rating: on line 2216-163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7864
% INFO    : Updated Thermal Rating: on line 1405-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 1585-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3611-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 3777-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 4171-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 4488-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 5133-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 5183-167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on line 5400-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 3442-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 5844-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 5100-169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 632
% INFO    : Updated Thermal Rating: on line 2563-170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5167
% INFO    : Updated Thermal Rating: on line 5580-170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1501
% INFO    : Updated Thermal Rating: on line 1558-171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1125
% INFO    : Updated Thermal Rating: on line 4613-171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 5791-171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1035
% INFO    : Updated Thermal Rating: on line 1558-171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 5669-172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2348
% INFO    : Updated Thermal Rating: on line 5103-173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8279
% INFO    : Updated Thermal Rating: on line 445-174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 5359-174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1284
% INFO    : Updated Thermal Rating: on line 1937-174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 5143-175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 5158-175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3471
% INFO    : Updated Thermal Rating: on line 4711-176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2959
% INFO    : Updated Thermal Rating: on line 5112-176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3941
% INFO    : Updated Thermal Rating: on line 911-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11544
% INFO    : Updated Thermal Rating: on line 1444-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3780
% INFO    : Updated Thermal Rating: on line 1488-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1634
% INFO    : Updated Thermal Rating: on line 3460-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1551
% INFO    : Updated Thermal Rating: on line 4927-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2172
% INFO    : Updated Thermal Rating: on line 4932-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5543
% INFO    : Updated Thermal Rating: on line 5664-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2118
% INFO    : Updated Thermal Rating: on line 912-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9717
% INFO    : Updated Thermal Rating: on line 1444-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4305
% INFO    : Updated Thermal Rating: on line 1444-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3667
% INFO    : Updated Thermal Rating: on line 4930-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11985
% INFO    : Updated Thermal Rating: on line 4931-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14102
% INFO    : Updated Thermal Rating: on line 989-180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31961
% INFO    : Updated Thermal Rating: on line 2100-180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169660
% INFO    : Updated Thermal Rating: on line 989-180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31961
% INFO    : Updated Thermal Rating: on line 5104-181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 4403-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16580
% INFO    : Updated Thermal Rating: on line 5105-183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 1031-184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3370
% INFO    : Updated Thermal Rating: on line 5378-185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1163
% INFO    : Updated Thermal Rating: on line 5106-186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3901
% INFO    : Updated Thermal Rating: on line 5396-187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1466
% INFO    : Updated Thermal Rating: on line 2893-188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 2241-189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 5594-189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 5107-190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23633
% INFO    : Updated Thermal Rating: on line 2743-191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 4828-191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 317-192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5088-192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 2497-194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 2773-194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 5327-194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3208-195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3453
% INFO    : Updated Thermal Rating: on line 3208-196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3308
% INFO    : Updated Thermal Rating: on line 321-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 573-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53974
% INFO    : Updated Thermal Rating: on line 930-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 321-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 826-198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 1754-198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 5108-199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 392-202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 829-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1051
% INFO    : Updated Thermal Rating: on line 1919-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1030
% INFO    : Updated Thermal Rating: on line 2062-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 2712-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 674
% INFO    : Updated Thermal Rating: on line 2985-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 829-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 973
% INFO    : Updated Thermal Rating: on line 1919-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 968
% INFO    : Updated Thermal Rating: on line 392-206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on line 1683-206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5127-206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 563-207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 563-207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 5577-208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 905
% INFO    : Updated Thermal Rating: on line 5842-208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 3922-209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1574
% INFO    : Updated Thermal Rating: on line 1791-211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 4829-210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 1791-211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 525-214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19602
% INFO    : Updated Thermal Rating: on line 1177-214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on line 1415-214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 1732-214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 1879-214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 4063-214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 4905-214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 1983-216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 5410-216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 1513-217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 1577-217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 2762-218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23039
% INFO    : Updated Thermal Rating: on line 5111-219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 5109-220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on line 255-221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 2038-221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 4392-221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 2307-223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on line 4146-223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 2307-223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 5112-224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24440
% INFO    : Updated Thermal Rating: on line 3825-226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17970
% INFO    : Updated Thermal Rating: on line 3825-225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17970
% INFO    : Updated Thermal Rating: on line 1545-228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 1545-227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 422-229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 3134-229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 4557-229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 422-229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 2483-230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48541
% INFO    : Updated Thermal Rating: on line 520-231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 208
% INFO    : Updated Thermal Rating: on line 1863-232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 772
% INFO    : Updated Thermal Rating: on line 4877-232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 453
% INFO    : Updated Thermal Rating: on line 3662-234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 504-236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2910
% INFO    : Updated Thermal Rating: on line 1011-237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 3937-237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1814
% INFO    : Updated Thermal Rating: on line 2690-238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 5007-238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 2374-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 4602-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 5437-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1618
% INFO    : Updated Thermal Rating: on line 5729-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 360-240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 4553-240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on line 692-241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 4445-241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 5488-241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 605
% INFO    : Updated Thermal Rating: on line 1683-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 5682-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 3148-243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 3349-243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 1922-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 2348-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 5114-245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 282-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2780
% INFO    : Updated Thermal Rating: on line 479-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 751-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2322
% INFO    : Updated Thermal Rating: on line 2444-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 4725-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 722
% INFO    : Updated Thermal Rating: on line 2108-249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 3561-249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 1267-250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 1621-250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 2256-250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on line 2939-251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2626
% INFO    : Updated Thermal Rating: on line 4005-252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 5106-252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1070
% INFO    : Updated Thermal Rating: on line 3510-253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1500
% INFO    : Updated Thermal Rating: on line 3510-253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on line 1113-254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 3815-254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 4634-254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2181
% INFO    : Updated Thermal Rating: on line 559-255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 1681-255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 4161-256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 4550-256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 1109-258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1875
% INFO    : Updated Thermal Rating: on line 763-259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 1455-259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11497
% INFO    : Updated Thermal Rating: on line 5115-261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 5057-264 : Rate A, Rate B, Rate C , 2275.0, 2275.0, 2275.0 -> 1648
% INFO    : Updated Thermal Rating: on line 728-265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7450
% INFO    : Updated Thermal Rating: on line 1900-268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 2673-268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 549-269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 5278-269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 1409-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 1695-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 4442-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2987
% INFO    : Updated Thermal Rating: on line 4832-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1519
% INFO    : Updated Thermal Rating: on line 5245-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 5792-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 4442-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3057
% INFO    : Updated Thermal Rating: on line 1937-274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 1937-274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 740-277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on line 981-277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 1054-277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 741-277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 1053-277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 2980-279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 2461-280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 4945-280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 5075-280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 2461-280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 1258-281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 5712-283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16188
% INFO    : Updated Thermal Rating: on line 448-284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 866
% INFO    : Updated Thermal Rating: on line 2663-284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32529
% INFO    : Updated Thermal Rating: on line 3638-284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on line 5116-286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306461
% INFO    : Updated Thermal Rating: on line 960-287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 2316-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240340
% INFO    : Updated Thermal Rating: on line 2905-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1943
% INFO    : Updated Thermal Rating: on line 4626-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 5426-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240340
% INFO    : Updated Thermal Rating: on line 2789-290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4503
% INFO    : Updated Thermal Rating: on line 2165-291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 2624-291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 3148-291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5195-291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 292-293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3677
% INFO    : Updated Thermal Rating: on line 480-293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 1564-293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 1239-294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1302
% INFO    : Updated Thermal Rating: on line 1299-296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 1750-297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3394
% INFO    : Updated Thermal Rating: on line 4315-298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 2159-299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8155
% INFO    : Updated Thermal Rating: on line 5119-301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 1340-302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on line 1340-302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1200
% INFO    : Updated Thermal Rating: on line 197-303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 4586-303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 5737-303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 197-303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 4586-303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 4826-304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 5401-304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 690-305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 4681-305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 3889-306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 2476-307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4928-307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 1305-308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 4574-308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 829
% INFO    : Updated Thermal Rating: on line 1632-310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2898
% INFO    : Updated Thermal Rating: on line 1632-309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2147
% INFO    : Updated Thermal Rating: on line 5613-311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3363
% INFO    : Updated Thermal Rating: on line 3145-312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24326
% INFO    : Updated Thermal Rating: on line 2635-313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2640
% INFO    : Updated Thermal Rating: on line 5152-313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 5151-313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 1031-315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 5121-315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15203
% INFO    : Updated Thermal Rating: on line 2282-316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 5278-316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5280-316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4334
% INFO    : Updated Thermal Rating: on line 2282-316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 3290-317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 3268-318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5314
% INFO    : Updated Thermal Rating: on line 5122-319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22178
% INFO    : Updated Thermal Rating: on line 1253-320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 1651-320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 830-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1681
% INFO    : Updated Thermal Rating: on line 2304-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 3120-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 3140-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 4563-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 2304-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 3120-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 3140-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 3120-321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 4142-322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11556
% INFO    : Updated Thermal Rating: on line 4143-322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11556
% INFO    : Updated Thermal Rating: on line 2305-324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2963
% INFO    : Updated Thermal Rating: on line 1676-324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2641
% INFO    : Updated Thermal Rating: on line 522-325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 521-325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 1839-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 627
% INFO    : Updated Thermal Rating: on line 2603-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 2918-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 4109-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 5367-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 4109-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 854
% INFO    : Updated Thermal Rating: on line 1789-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 1789-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 2265-329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3207
% INFO    : Updated Thermal Rating: on line 2265-329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4803
% INFO    : Updated Thermal Rating: on line 4389-330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 4648-330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23670
% INFO    : Updated Thermal Rating: on line 4741-330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 1363-332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 3676-332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 1006-333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 1609-333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 2542-333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 4760-333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 5257-334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 1133-335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 2817-336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 4918-336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 871
% INFO    : Updated Thermal Rating: on line 2497-337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 2639-337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 1694-338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 1858-338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 3290-339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 3494-339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 5794-339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 3056-340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on line 3378-341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3231-342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 3880-342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5398-342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 1859-344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 4518-344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 5290-344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 671-345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 1725-345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 1278-346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 5447-346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 4916-347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 444-348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 3375-348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 3766-350 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2031
% INFO    : Updated Thermal Rating: on line 4594-349 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1639
% INFO    : Updated Thermal Rating: on line 3766-349 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2048
% INFO    : Updated Thermal Rating: on line 4595-350 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1638
% INFO    : Updated Thermal Rating: on line 880-353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2688-353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3014
% INFO    : Updated Thermal Rating: on line 5839-353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 5126-354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11206
% INFO    : Updated Thermal Rating: on line 1354-355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 358-356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2802
% INFO    : Updated Thermal Rating: on line 1350-357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 3144-357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 3870-357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 2293-358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 3023-358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5129-358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5527
% INFO    : Updated Thermal Rating: on line 5608-358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1680
% INFO    : Updated Thermal Rating: on line 1683-359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 4015-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 4553-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1216
% INFO    : Updated Thermal Rating: on line 4919-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 5147-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 561
% INFO    : Updated Thermal Rating: on line 2440-361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 490-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on line 5103-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3419
% INFO    : Updated Thermal Rating: on line 5102-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3460
% INFO    : Updated Thermal Rating: on line 4391-364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 4733-365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12708
% INFO    : Updated Thermal Rating: on line 859-369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155924
% INFO    : Updated Thermal Rating: on line 3004-371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 416
% INFO    : Updated Thermal Rating: on line 3074-371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 3544-374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 3657-374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 1169-375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 1774-375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 2575-375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 2093-376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 2097-376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 2097-376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 647-377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 2322-377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 2766-377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 401-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 1252-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 1532-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on line 1903-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 4084-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 4891-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 5010-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 4891-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 5010-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 1931-380 : Rate A, Rate B, Rate C , 2040.0, 2040.0, 2040.0 -> 1087
% INFO    : Updated Thermal Rating: on line 2764-380 : Rate A, Rate B, Rate C , 1487.0, 1487.0, 1487.0 -> 1128
% INFO    : Updated Thermal Rating: on line 2764-380 : Rate A, Rate B, Rate C , 1487.0, 1487.0, 1487.0 -> 1127
% INFO    : Updated Thermal Rating: on line 4284-380 : Rate A, Rate B, Rate C , 2040.0, 2040.0, 2040.0 -> 1979
% INFO    : Updated Thermal Rating: on line 4004-381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 5270-381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on line 2423-382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 3689-382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 5415-382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 937-383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 3791-383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 937-383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 3791-383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 2434-384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 5223-384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5751-384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 2923-385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5768-385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 3024-386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13045
% INFO    : Updated Thermal Rating: on line 1590-387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 2937-387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on line 2705-388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 3531-388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 1400-389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6238
% INFO    : Updated Thermal Rating: on line 1876-389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1061
% INFO    : Updated Thermal Rating: on line 3846-389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 4681-389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 1399-389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6629
% INFO    : Updated Thermal Rating: on line 4590-390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 5720-390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on line 1719-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 1817-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 2323-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 2464-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 3932-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 5598-392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 1907-393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 395-394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12255
% INFO    : Updated Thermal Rating: on line 1786-395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1953
% INFO    : Updated Thermal Rating: on line 4559-395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3645
% INFO    : Updated Thermal Rating: on line 1786-395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1958
% INFO    : Updated Thermal Rating: on line 3863-396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 4080-396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 2392-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3842-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 5186-398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2000
% INFO    : Updated Thermal Rating: on line 849-399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 2236-400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 2783-400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 2299-402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 2807-402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 2767-403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 503
% INFO    : Updated Thermal Rating: on line 5164-403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 2291-404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 3286-404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1859
% INFO    : Updated Thermal Rating: on line 1079-405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on line 1020-406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on line 1861-406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on line 4005-406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 794
% INFO    : Updated Thermal Rating: on line 2355-407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1257
% INFO    : Updated Thermal Rating: on line 2450-407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 2811-408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 3919-409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 487-410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 1058-410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2155
% INFO    : Updated Thermal Rating: on line 1864-411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 3190-411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 1631-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 2041-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 3233-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 4072-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 1141-413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 1141-413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 4185-414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on line 5134-414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60637
% INFO    : Updated Thermal Rating: on line 1242-415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 3664-415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 4438-415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8876
% INFO    : Updated Thermal Rating: on line 857-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 3670-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 4120-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 3733-418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4306-419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 5137-419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 5135-419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on line 5135-420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2632
% INFO    : Updated Thermal Rating: on line 3547-421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8736
% INFO    : Updated Thermal Rating: on line 1478-422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 1478-422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 1562-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 3404-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 4013-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 4525-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 1562-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 4013-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 591
% INFO    : Updated Thermal Rating: on line 4013-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 591
% INFO    : Updated Thermal Rating: on line 5136-426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8185
% INFO    : Updated Thermal Rating: on line 1151-427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 4674-428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on line 3865-429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1739
% INFO    : Updated Thermal Rating: on line 5201-429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4352
% INFO    : Updated Thermal Rating: on line 3865-429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1724
% INFO    : Updated Thermal Rating: on line 1660-429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on line 3290-431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 3200-432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 4000-432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 879-433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6104
% INFO    : Updated Thermal Rating: on line 1445-434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 5466-434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 982-435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 2839-435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 3056-435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 5264-435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 665
% INFO    : Updated Thermal Rating: on line 3056-435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 3979-436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5694-436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 2544-437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1320
% INFO    : Updated Thermal Rating: on line 2977-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 1667-439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 2212-439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 5001-439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 5140-440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25776
% INFO    : Updated Thermal Rating: on line 5138-441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1109
% INFO    : Updated Thermal Rating: on line 2751-442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 4208-442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 1553-443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 1645-445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2031
% INFO    : Updated Thermal Rating: on line 2025-443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 4865-445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 5329-443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1672
% INFO    : Updated Thermal Rating: on line 1645-445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2031
% INFO    : Updated Thermal Rating: on line 2025-444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on line 4865-445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2767
% INFO    : Updated Thermal Rating: on line 3587-447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on line 1229-448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 2900-448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 3975-448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 2900-448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 2756-450 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 899
% INFO    : Updated Thermal Rating: on line 5146-451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 462-452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 2332-452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 2692-452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 3705-452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 2332-452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 3433-452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on line 5147-454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 4058-456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4777
% INFO    : Updated Thermal Rating: on line 4058-455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4695
% INFO    : Updated Thermal Rating: on line 4237-457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6068
% INFO    : Updated Thermal Rating: on line 3167-460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1465
% INFO    : Updated Thermal Rating: on line 4013-461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5473-462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 5148-463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3473
% INFO    : Updated Thermal Rating: on line 2705-465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4634
% INFO    : Updated Thermal Rating: on line 5150-466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11716
% INFO    : Updated Thermal Rating: on line 2178-467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5279
% INFO    : Updated Thermal Rating: on line 3474-467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 606
% INFO    : Updated Thermal Rating: on line 3554-468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 2178-467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5207
% INFO    : Updated Thermal Rating: on line 3473-467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 604
% INFO    : Updated Thermal Rating: on line 3554-468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 2178-467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5279
% INFO    : Updated Thermal Rating: on line 2980-470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 972-471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 3338-471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 3736-471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1264
% INFO    : Updated Thermal Rating: on line 4289-474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 4290-474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 2167-475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 3867-475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 5566-476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 3755-477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 883
% INFO    : Updated Thermal Rating: on line 3755-477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 883
% INFO    : Updated Thermal Rating: on line 4037-478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 642-479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1032
% INFO    : Updated Thermal Rating: on line 1829-479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 3571-479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22978
% INFO    : Updated Thermal Rating: on line 971-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32501
% INFO    : Updated Thermal Rating: on line 1563-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1180
% INFO    : Updated Thermal Rating: on line 2141-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 2161-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2140
% INFO    : Updated Thermal Rating: on line 3149-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2216
% INFO    : Updated Thermal Rating: on line 1564-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 2162-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2140
% INFO    : Updated Thermal Rating: on line 2163-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2196
% INFO    : Updated Thermal Rating: on line 2007-482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 2502-483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 5433-483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2109
% INFO    : Updated Thermal Rating: on line 5589-483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6697
% INFO    : Updated Thermal Rating: on line 5594-483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7777
% INFO    : Updated Thermal Rating: on line 960-484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 641
% INFO    : Updated Thermal Rating: on line 4166-484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 3538-485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 5151-486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1112
% INFO    : Updated Thermal Rating: on line 1025-487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 1058-487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 653-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1016
% INFO    : Updated Thermal Rating: on line 3632-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 2256-489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 2611-489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 2196-490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 3564-492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 5076-492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 2151-498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11206
% INFO    : Updated Thermal Rating: on line 2450-502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 2555-502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5191-502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 3971-503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 3970-503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 736-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 1277-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 1811-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1243
% INFO    : Updated Thermal Rating: on line 5113-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27851
% INFO    : Updated Thermal Rating: on line 5353-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1243
% INFO    : Updated Thermal Rating: on line 2660-506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 4334-506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 5154-507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on line 5155-507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 3974-508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 1559-509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 5220-509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5610-510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 5611-510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 3086-512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34920
% INFO    : Updated Thermal Rating: on line 2571-513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 2961-514 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 2232
% INFO    : Updated Thermal Rating: on line 2962-514 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2175
% INFO    : Updated Thermal Rating: on line 1077-515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on line 2580-515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 1190-516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 5446-517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 880
% INFO    : Updated Thermal Rating: on line 2260-518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 3206-518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 565-519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 4190-520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 4302-520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 1402-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 2883-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 2919-522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 3665-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1260
% INFO    : Updated Thermal Rating: on line 3830-522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 4258-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 5648-522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1557
% INFO    : Updated Thermal Rating: on line 2919-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 1127-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 1916-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 2950-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 3029-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 872
% INFO    : Updated Thermal Rating: on line 3309-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 824
% INFO    : Updated Thermal Rating: on line 4240-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 4685-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 4761-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 5546-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 832
% INFO    : Updated Thermal Rating: on line 5690-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 4684-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on line 3530-527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5617
% INFO    : Updated Thermal Rating: on line 529-528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3553
% INFO    : Updated Thermal Rating: on line 1350-528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 1837-528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 1080-530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3109
% INFO    : Updated Thermal Rating: on line 532-531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113138
% INFO    : Updated Thermal Rating: on line 1392-531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 1392-531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 3872-534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1527
% INFO    : Updated Thermal Rating: on line 3872-533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1549
% INFO    : Updated Thermal Rating: on line 663-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 952
% INFO    : Updated Thermal Rating: on line 1351-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 2872-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39543
% INFO    : Updated Thermal Rating: on line 3452-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 584
% INFO    : Updated Thermal Rating: on line 5672-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 940
% INFO    : Updated Thermal Rating: on line 5673-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2989
% INFO    : Updated Thermal Rating: on line 663-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 966
% INFO    : Updated Thermal Rating: on line 3452-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 5529-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1153
% INFO    : Updated Thermal Rating: on line 646-537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 1316-537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 1352-537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 1189-538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 5376-538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 1130-539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 2094-540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 1340-541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1745
% INFO    : Updated Thermal Rating: on line 2084-544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 2676-544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 2979-544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7234
% INFO    : Updated Thermal Rating: on line 5766-544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1798
% INFO    : Updated Thermal Rating: on line 1679-546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 5159-546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 5568-547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 5589-547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 2591-548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 5123-548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 3064-549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5697
% INFO    : Updated Thermal Rating: on line 3193-550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 1538-551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 2727-551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3562-551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 5188-551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 1538-551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on line 1188-552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 1551-552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 3387-553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 5697-553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 4338-554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 4889-554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 4338-554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 1788-557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20021
% INFO    : Updated Thermal Rating: on line 1133-559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 3066-559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 3635-559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 4367-559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2807
% INFO    : Updated Thermal Rating: on line 5399-560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3126
% INFO    : Updated Thermal Rating: on line 2994-561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 1128-562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 2461-562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 2651-563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 4792-563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 852-565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 2974-565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2826
% INFO    : Updated Thermal Rating: on line 852-565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 1010-566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 4227-566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 2439-567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 5796-567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 4528-568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 2304-569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 5021-569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 585-570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 4209-570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 1068-571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 3317-571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 1898-572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 4861-572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 1180-574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 3882-574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 4850-574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 4899-574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 3107-574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 5693-574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 1571-575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 2038-575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 1820-576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8751
% INFO    : Updated Thermal Rating: on line 654-577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19054
% INFO    : Updated Thermal Rating: on line 5162-578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4152
% INFO    : Updated Thermal Rating: on line 1207-580 : Rate A, Rate B, Rate C , 935.0, 935.0, 935.0 -> 892
% INFO    : Updated Thermal Rating: on line 5027-583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2290
% INFO    : Updated Thermal Rating: on line 3033-584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1948
% INFO    : Updated Thermal Rating: on line 1456-585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 1152-586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 4976-586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 556
% INFO    : Updated Thermal Rating: on line 5268-586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 893
% INFO    : Updated Thermal Rating: on line 2423-587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 2487-587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 5164-588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5331-589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 5683-589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 1520-590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1954
% INFO    : Updated Thermal Rating: on line 1519-590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1954
% INFO    : Updated Thermal Rating: on line 5165-591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11707
% INFO    : Updated Thermal Rating: on line 3200-592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 4000-592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 4000-592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 2636-593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 5781-596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1635
% INFO    : Updated Thermal Rating: on line 3510-597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on line 1513-599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 1847-600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 5721-600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 2679-601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1022
% INFO    : Updated Thermal Rating: on line 5343-601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 737-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 1883-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 2054-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 3845-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7133
% INFO    : Updated Thermal Rating: on line 1883-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 830
% INFO    : Updated Thermal Rating: on line 2372-607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 3936-607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 4318-607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 880-609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 4359-609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 5499-611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153231
% INFO    : Updated Thermal Rating: on line 3332-612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 2183-613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 5366-613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 3082-614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2764-617 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 640
% INFO    : Updated Thermal Rating: on line 5168-619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9349
% INFO    : Updated Thermal Rating: on line 5172-618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 5027-620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3851
% INFO    : Updated Thermal Rating: on line 5027-621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3667
% INFO    : Updated Thermal Rating: on line 1242-622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 4893-623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5031-623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 5236-623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2048
% INFO    : Updated Thermal Rating: on line 5826-623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 2697-624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2032
% INFO    : Updated Thermal Rating: on line 818-625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2405
% INFO    : Updated Thermal Rating: on line 1103-625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on line 2587-625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 5175-628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8880
% INFO    : Updated Thermal Rating: on line 5182-629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 5173-632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 5176-631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99170
% INFO    : Updated Thermal Rating: on line 4223-633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 5174-634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13714
% INFO    : Updated Thermal Rating: on line 1258-635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 4274-635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 2454-636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 2534-636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 5587-636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 2785-637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 4562-637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5696-637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 1106-638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 3973-638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 5150-639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26199
% INFO    : Updated Thermal Rating: on line 996-643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 842
% INFO    : Updated Thermal Rating: on line 1340-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1036
% INFO    : Updated Thermal Rating: on line 1340-645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 1352-646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 4274-647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 1735-648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 4450-648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 1735-648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 4921-648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 5779-648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1696
% INFO    : Updated Thermal Rating: on line 1780-649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1017
% INFO    : Updated Thermal Rating: on line 5179-649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4316
% INFO    : Updated Thermal Rating: on line 3174-650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 3570-650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 5217-650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 5180-651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 5181-652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 1999-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 2745-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 2854-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 4364-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 5152-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 5423-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 1073-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 2184-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 5151-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 2166-655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 3755-655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 4110-656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 1206-657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1090
% INFO    : Updated Thermal Rating: on line 3862-657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 1206-657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 1619-659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4374
% INFO    : Updated Thermal Rating: on line 1429-660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 5238-660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3171
% INFO    : Updated Thermal Rating: on line 5632-661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3297
% INFO    : Updated Thermal Rating: on line 4885-662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 934
% INFO    : Updated Thermal Rating: on line 4460-667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183736
% INFO    : Updated Thermal Rating: on line 4459-666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170060
% INFO    : Updated Thermal Rating: on line 4460-665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158275
% INFO    : Updated Thermal Rating: on line 4459-664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158275
% INFO    : Updated Thermal Rating: on line 1816-668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 2523-668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 2548-668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 2759-668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 2223-668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1698
% INFO    : Updated Thermal Rating: on line 2762-670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 4841-670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 5809-670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 4841-670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 1503-671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 2018-671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 5404-671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 1387-672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 3841-672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 4906-672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 3373-673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 3056-674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 1750-675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 2815-677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on line 5389-677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 4928-679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 807
% INFO    : Updated Thermal Rating: on line 2674-680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 3554-681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1443
% INFO    : Updated Thermal Rating: on line 3554-681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1444
% INFO    : Updated Thermal Rating: on line 3554-681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1541
% INFO    : Updated Thermal Rating: on line 1314-682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5185-682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85273
% INFO    : Updated Thermal Rating: on line 3894-683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 1994-684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 499
% INFO    : Updated Thermal Rating: on line 5406-684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 4198-686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 2341-688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27692
% INFO    : Updated Thermal Rating: on line 2342-689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30077
% INFO    : Updated Thermal Rating: on line 5478-690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 886-692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1255
% INFO    : Updated Thermal Rating: on line 2807-692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 736-695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 4023-695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 5571-695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1266
% INFO    : Updated Thermal Rating: on line 4678-695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 3888-703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 4309-702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 5186-703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 5712-703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 4309-702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 4021-705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 5406-705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 5829-705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 4847-705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 5711-706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on line 2609-711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 2724-711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 2905-710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2138
% INFO    : Updated Thermal Rating: on line 3307-710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 5426-710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 3307-710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 5187-713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13344
% INFO    : Updated Thermal Rating: on line 5222-714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 4436-715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6053
% INFO    : Updated Thermal Rating: on line 957-716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 4997-716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 1181-716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 3030-716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 1924-717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2340
% INFO    : Updated Thermal Rating: on line 716-718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1471
% INFO    : Updated Thermal Rating: on line 3560-719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 5805-719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 5338-720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 988
% INFO    : Updated Thermal Rating: on line 5522-720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 4321-720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 4276-721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3057
% INFO    : Updated Thermal Rating: on line 5188-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1403
% INFO    : Updated Thermal Rating: on line 5624-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5354
% INFO    : Updated Thermal Rating: on line 1387-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 1898-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 5667-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 2840-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 4271-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7550
% INFO    : Updated Thermal Rating: on line 4735-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 4270-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7550
% INFO    : Updated Thermal Rating: on line 4735-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 2175-726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 2446-726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 2716-725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on line 4130-725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 4138-725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 5498-725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 5570-725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 2175-726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 4130-725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 4583-725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1086
% INFO    : Updated Thermal Rating: on line 3342-729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3342-728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 3342-730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 923-731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 640
% INFO    : Updated Thermal Rating: on line 923-731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 601
% INFO    : Updated Thermal Rating: on line 967-732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 5189-733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37051
% INFO    : Updated Thermal Rating: on line 5190-734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 2155-735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3789
% INFO    : Updated Thermal Rating: on line 4822-738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 1557-739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308785
% INFO    : Updated Thermal Rating: on line 2526-742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 3653-742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 462
% INFO    : Updated Thermal Rating: on line 4769-742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 5464-742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 745-744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 5033-744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 462
% INFO    : Updated Thermal Rating: on line 3659-745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 3610-746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2859
% INFO    : Updated Thermal Rating: on line 3422-747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 487-748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19914
% INFO    : Updated Thermal Rating: on line 2005-749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 2036-749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 5044-749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 1215-750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 4084-750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 4946-750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 1472-752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 3434-752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 4681-753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 2739-756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 2950-756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 4379-756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1432
% INFO    : Updated Thermal Rating: on line 5690-756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 3626-757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39366
% INFO    : Updated Thermal Rating: on line 3873-757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22986
% INFO    : Updated Thermal Rating: on line 5193-761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 1841-764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6823
% INFO    : Updated Thermal Rating: on line 1552-765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 3304-765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 3801-766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 4024-766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 340-767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 5111-767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4829
% INFO    : Updated Thermal Rating: on line 661-768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 1297-768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 2214-768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2103
% INFO    : Updated Thermal Rating: on line 2310-768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 3053-768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 4107-768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1768
% INFO    : Updated Thermal Rating: on line 4540-768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 5402-768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2192
% INFO    : Updated Thermal Rating: on line 5614-768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 1297-768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 3053-768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 1752-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2121
% INFO    : Updated Thermal Rating: on line 1872-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6273
% INFO    : Updated Thermal Rating: on line 3709-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6192
% INFO    : Updated Thermal Rating: on line 4842-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 5637-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 1872-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6068
% INFO    : Updated Thermal Rating: on line 5639-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2763
% INFO    : Updated Thermal Rating: on line 2295-774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 918-775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 4822-775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1363
% INFO    : Updated Thermal Rating: on line 899-776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on line 2719-776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 3757-776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 900-776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 948-780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5006
% INFO    : Updated Thermal Rating: on line 948-779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9266
% INFO    : Updated Thermal Rating: on line 948-778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5965
% INFO    : Updated Thermal Rating: on line 5196-781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 1755-782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 2509-782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 5198-785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 1124-789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 3417-788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 3456-789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 4319-788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 4534-789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 4771-788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 5798-789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 5819-789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7106
% INFO    : Updated Thermal Rating: on line 1336-789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 4534-788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 2622-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2728
% INFO    : Updated Thermal Rating: on line 2342-793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 4615-793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 4895-794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on line 4833-795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 4895-795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on line 480-796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 922-796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16094
% INFO    : Updated Thermal Rating: on line 818-797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4138
% INFO    : Updated Thermal Rating: on line 3117-797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7080
% INFO    : Updated Thermal Rating: on line 4395-797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2128
% INFO    : Updated Thermal Rating: on line 1218-798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 1982-799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 3487-799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 4399-799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2555
% INFO    : Updated Thermal Rating: on line 1982-799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 3670-806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6082
% INFO    : Updated Thermal Rating: on line 1760-807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85273
% INFO    : Updated Thermal Rating: on line 3140-807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 1607-810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 4916-810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 845-811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1013
% INFO    : Updated Thermal Rating: on line 5604-811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 986
% INFO    : Updated Thermal Rating: on line 5599-811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 974
% INFO    : Updated Thermal Rating: on line 4926-813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2909
% INFO    : Updated Thermal Rating: on line 4434-814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 4915-814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 5286-816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19262
% INFO    : Updated Thermal Rating: on line 5285-815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 2435-818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 820-819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8292
% INFO    : Updated Thermal Rating: on line 4317-819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 1067-820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 5525-820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 4822-823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1405
% INFO    : Updated Thermal Rating: on line 2127-824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4554
% INFO    : Updated Thermal Rating: on line 4240-825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on line 2005-826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on line 1195-828 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1075
% INFO    : Updated Thermal Rating: on line 2779-828 : Rate A, Rate B, Rate C , 1987.0, 1987.0, 1987.0 -> 1524
% INFO    : Updated Thermal Rating: on line 2712-829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 941
% INFO    : Updated Thermal Rating: on line 3087-831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 4037-831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on line 4671-832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4845
% INFO    : Updated Thermal Rating: on line 5205-833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7650
% INFO    : Updated Thermal Rating: on line 1672-834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 4631-834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 2229-835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 3020-835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 3373-835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3445-836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 3650-836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 591
% INFO    : Updated Thermal Rating: on line 4770-836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1018
% INFO    : Updated Thermal Rating: on line 2951-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 5396-837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5535-837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12012
% INFO    : Updated Thermal Rating: on line 5204-839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 2946-840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 4116-840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 4822-841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 5200-842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27427
% INFO    : Updated Thermal Rating: on line 1877-843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10493
% INFO    : Updated Thermal Rating: on line 1877-843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10493
% INFO    : Updated Thermal Rating: on line 1547-844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 5034-844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 2992-846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1253
% INFO    : Updated Thermal Rating: on line 2992-848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1560
% INFO    : Updated Thermal Rating: on line 2992-847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1648
% INFO    : Updated Thermal Rating: on line 1918-849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3789-849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1023
% INFO    : Updated Thermal Rating: on line 3948-849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 5537-849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 929
% INFO    : Updated Thermal Rating: on line 5258-849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 5538-849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 865
% INFO    : Updated Thermal Rating: on line 2995-850 : Rate A, Rate B, Rate C , 736.0, 736.0, 736.0 -> 462
% INFO    : Updated Thermal Rating: on line 4020-851 : Rate A, Rate B, Rate C , 1932.0, 1932.0, 1932.0 -> 1807
% INFO    : Updated Thermal Rating: on line 4020-851 : Rate A, Rate B, Rate C , 1932.0, 1932.0, 1932.0 -> 1827
% INFO    : Updated Thermal Rating: on line 1816-852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 1816-852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 1137-855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 5680-856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2104
% INFO    : Updated Thermal Rating: on line 2711-857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 3104-857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 5747-857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 2964-858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on line 4901-858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3854
% INFO    : Updated Thermal Rating: on line 2372-861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 3443-861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 3896-861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 4318-861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 5212-865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5209-864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 4209-866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 1154-867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 5382-868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2340
% INFO    : Updated Thermal Rating: on line 1607-869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 2247-869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 4486-869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12351
% INFO    : Updated Thermal Rating: on line 2482-871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1532
% INFO    : Updated Thermal Rating: on line 2482-870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2339
% INFO    : Updated Thermal Rating: on line 4641-872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on line 4643-872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 4590-873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 5250-873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 4590-873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1859
% INFO    : Updated Thermal Rating: on line 2660-874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 4334-874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 2247-876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 2247-875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 3386-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 3724-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4754-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2759
% INFO    : Updated Thermal Rating: on line 5041-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 5660-880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5763-880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 4775-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 2203-883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1095
% INFO    : Updated Thermal Rating: on line 5287-883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1181
% INFO    : Updated Thermal Rating: on line 5439-884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1499
% INFO    : Updated Thermal Rating: on line 5216-885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 3300-886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on line 4672-886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 5547-886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 2179-888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21471
% INFO    : Updated Thermal Rating: on line 2999-887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27618
% INFO    : Updated Thermal Rating: on line 4118-887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42153
% INFO    : Updated Thermal Rating: on line 1307-890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4057
% INFO    : Updated Thermal Rating: on line 2033-891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 5214-891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 599
% INFO    : Updated Thermal Rating: on line 2531-892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5882
% INFO    : Updated Thermal Rating: on line 3373-893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 4144-893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 4775-894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 5071-901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on line 5841-901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11095
% INFO    : Updated Thermal Rating: on line 4713-902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 3931-903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 4156-903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 3373-904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 4144-904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 3567-905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20979
% INFO    : Updated Thermal Rating: on line 5792-906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1019
% INFO    : Updated Thermal Rating: on line 5220-907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2617
% INFO    : Updated Thermal Rating: on line 3640-908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on line 5793-908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 2478-909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 4433-909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 1748-910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 5223-913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 2775-916 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1573
% INFO    : Updated Thermal Rating: on line 4854-916 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1434
% INFO    : Updated Thermal Rating: on line 2775-916 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1578
% INFO    : Updated Thermal Rating: on line 4854-916 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1435
% INFO    : Updated Thermal Rating: on line 5224-917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 4822-918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 1797-919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 5662-919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 4452-919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5160-920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5743-920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 5552-922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 1343-923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 2554-923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 1343-923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 2554-923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 2391-925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4207
% INFO    : Updated Thermal Rating: on line 3831-925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 2699-926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on line 5314-926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 2166-927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1061
% INFO    : Updated Thermal Rating: on line 1786-928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 1786-928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 4112-929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 5808-930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 2805-936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 5665-936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 2111-937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 2544-937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1366
% INFO    : Updated Thermal Rating: on line 3204-937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 3541-937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 5469-937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1012
% INFO    : Updated Thermal Rating: on line 5634-937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 2544-937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1363
% INFO    : Updated Thermal Rating: on line 2552-940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 1528-941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on line 1528-941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1032
% INFO    : Updated Thermal Rating: on line 3331-943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 3908-943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 2455-942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3908-942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3300-944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2856
% INFO    : Updated Thermal Rating: on line 2701-945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3338
% INFO    : Updated Thermal Rating: on line 3314-945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 5492-945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3338
% INFO    : Updated Thermal Rating: on line 2207-946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on line 2805-946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 2590-947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 3425-947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 1040-948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 1098-948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 2354-948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 3065-948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 1513-951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1281
% INFO    : Updated Thermal Rating: on line 1369-952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4421
% INFO    : Updated Thermal Rating: on line 2294-953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 2309-953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 2906-953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 4403-953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 991
% INFO    : Updated Thermal Rating: on line 4630-953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 4864-953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 4403-953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1097
% INFO    : Updated Thermal Rating: on line 1214-954 : Rate A, Rate B, Rate C , 1611.0, 1611.0, 1611.0 -> 1100
% INFO    : Updated Thermal Rating: on line 1238-954 : Rate A, Rate B, Rate C , 1567.0, 1567.0, 1567.0 -> 1311
% INFO    : Updated Thermal Rating: on line 2143-954 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2245
% INFO    : Updated Thermal Rating: on line 2143-954 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2244
% INFO    : Updated Thermal Rating: on line 4899-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21515
% INFO    : Updated Thermal Rating: on line 5231-956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31602
% INFO    : Updated Thermal Rating: on line 2942-957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3706
% INFO    : Updated Thermal Rating: on line 1179-958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 5693-958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16188
% INFO    : Updated Thermal Rating: on line 2941-959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3908-959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 4431-959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 2733-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 3453-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 721
% INFO    : Updated Thermal Rating: on line 3761-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 4005-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 4042-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 5301-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4437
% INFO    : Updated Thermal Rating: on line 2734-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 959
% INFO    : Updated Thermal Rating: on line 3760-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 968-964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1015
% INFO    : Updated Thermal Rating: on line 2942-964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 3308-967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 5776-967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 2256-968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 2597-968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on line 4089-968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 1846-968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 4804-968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 2766-970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 3044-972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41442
% INFO    : Updated Thermal Rating: on line 3338-972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 5232-973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on line 2953-974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 3358-974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 5708-974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 3358-974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 971
% INFO    : Updated Thermal Rating: on line 5352-974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3358-974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 2238-976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on line 2642-976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 2766-976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 587
% INFO    : Updated Thermal Rating: on line 3801-976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4024-976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 4274-976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on line 4721-976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 4274-976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 1110-978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 4516-978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 992
% INFO    : Updated Thermal Rating: on line 5543-978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 5773-978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on line 4998-978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 518
% INFO    : Updated Thermal Rating: on line 2475-979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on line 2815-979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 2164-980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1004
% INFO    : Updated Thermal Rating: on line 3830-980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 1379-982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 2709-982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1152
% INFO    : Updated Thermal Rating: on line 1201-983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8928
% INFO    : Updated Thermal Rating: on line 3194-985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on line 3462-986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 2299-987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1165
% INFO    : Updated Thermal Rating: on line 2290-988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4380
% INFO    : Updated Thermal Rating: on line 3732-988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3280
% INFO    : Updated Thermal Rating: on line 4789-988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3203
% INFO    : Updated Thermal Rating: on line 4788-988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5279
% INFO    : Updated Thermal Rating: on line 3552-991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 3767-991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 1346-992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 2066-992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 5228-993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 1085-994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 2105-994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 1038-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 1078-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 1251-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 5269-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2777
% INFO    : Updated Thermal Rating: on line 4949-999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1475
% INFO    : Updated Thermal Rating: on line 5703-999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 889
% INFO    : Updated Thermal Rating: on line 4630-1000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 2121-1001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on line 2898-1001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 1724-1004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 5345-1004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 5471-1005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1966
% INFO    : Updated Thermal Rating: on line 3920-1006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3362
% INFO    : Updated Thermal Rating: on line 4443-1006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90021
% INFO    : Updated Thermal Rating: on line 5233-1009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13732
% INFO    : Updated Thermal Rating: on line 2207-1010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 2856-1010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 2856-1010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 1248-1011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2182
% INFO    : Updated Thermal Rating: on line 3451-1011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on line 5229-1011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83805
% INFO    : Updated Thermal Rating: on line 5348-1011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2308
% INFO    : Updated Thermal Rating: on line 1248-1011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1574
% INFO    : Updated Thermal Rating: on line 5229-1013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 4783-1014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 1750-1015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 4139-1015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 2270-1016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2545
% INFO    : Updated Thermal Rating: on line 4281-1016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 968-1017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 2620-1017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10350
% INFO    : Updated Thermal Rating: on line 968-1017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 968-1017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 1353-1019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154266
% INFO    : Updated Thermal Rating: on line 1353-1018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151981
% INFO    : Updated Thermal Rating: on line 5382-1020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 5234-1021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1065
% INFO    : Updated Thermal Rating: on line 3337-1023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 3337-1022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 4505-1024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 2152-1025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2424
% INFO    : Updated Thermal Rating: on line 2802-1025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 1477-1027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8700
% INFO    : Updated Thermal Rating: on line 1477-1026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7132
% INFO    : Updated Thermal Rating: on line 1354-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 4641-1030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1023
% INFO    : Updated Thermal Rating: on line 4641-1031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1140
% INFO    : Updated Thermal Rating: on line 4641-1030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1127
% INFO    : Updated Thermal Rating: on line 4890-1032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1105
% INFO    : Updated Thermal Rating: on line 2153-1033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 3045-1033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 4358-1033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 2153-1033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 3046-1033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 4357-1033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 3774-1033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 877
% INFO    : Updated Thermal Rating: on line 3774-1033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 3344-1034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3425
% INFO    : Updated Thermal Rating: on line 5003-1034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5192
% INFO    : Updated Thermal Rating: on line 5004-1034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5314
% INFO    : Updated Thermal Rating: on line 4527-1037 : Rate A, Rate B, Rate C , 1566.0, 1566.0, 1566.0 -> 1490
% INFO    : Updated Thermal Rating: on line 4527-1036 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1720
% INFO    : Updated Thermal Rating: on line 4527-1036 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1735
% INFO    : Updated Thermal Rating: on line 1100-1041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5823
% INFO    : Updated Thermal Rating: on line 2271-1041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 3296-1041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on line 4393-1041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 4406-1041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 5165-1041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 5680-1040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 974
% INFO    : Updated Thermal Rating: on line 1097-1041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5169
% INFO    : Updated Thermal Rating: on line 5681-1040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 979
% INFO    : Updated Thermal Rating: on line 1099-1040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6551
% INFO    : Updated Thermal Rating: on line 2660-1040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 1224-1043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 1224-1043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1001
% INFO    : Updated Thermal Rating: on line 3127-1044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 4971-1044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1828
% INFO    : Updated Thermal Rating: on line 5056-1045 : Rate A, Rate B, Rate C , 1917.0, 1917.0, 1917.0 -> 1451
% INFO    : Updated Thermal Rating: on line 5057-1045 : Rate A, Rate B, Rate C , 1917.0, 1917.0, 1917.0 -> 1451
% INFO    : Updated Thermal Rating: on line 1183-1047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10039
% INFO    : Updated Thermal Rating: on line 3161-1047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10374
% INFO    : Updated Thermal Rating: on line 5236-1048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7488
% INFO    : Updated Thermal Rating: on line 2404-1050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 4416-1050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 3194-1051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on line 4387-1057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1127
% INFO    : Updated Thermal Rating: on line 2207-1058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 2805-1058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 5180-1058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 5371-1058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on line 4987-1060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 1997-1063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on line 2260-1063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 4924-1063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 5357-1063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 5024-1065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5239-1065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 2029-1066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 2658-1066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 5544-1066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179912
% INFO    : Updated Thermal Rating: on line 2399-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 2996-1068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 5707-1069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 2213-1070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 3943-1070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 2243-1073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 2745-1073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 2829-1073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 5592-1073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 5593-1073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 5823-1073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 5303-1077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24008
% INFO    : Updated Thermal Rating: on line 1946-1079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 2337-1079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 2291-1080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 4673-1080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 5543-1080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5710-1080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 1663-1082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2144
% INFO    : Updated Thermal Rating: on line 4974-1083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 4974-1083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 1933-1084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5574
% INFO    : Updated Thermal Rating: on line 5671-1084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6551
% INFO    : Updated Thermal Rating: on line 1932-1084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37051
% INFO    : Updated Thermal Rating: on line 2735-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 2504-1086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 4348-1086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 1201-1087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 4280-1087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4022
% INFO    : Updated Thermal Rating: on line 1467-1089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 1466-1090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4250-1093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5788
% INFO    : Updated Thermal Rating: on line 1761-1094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 2668-1094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 2291-1095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2028
% INFO    : Updated Thermal Rating: on line 2291-1095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 940
% INFO    : Updated Thermal Rating: on line 3515-1096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 3515-1096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3036
% INFO    : Updated Thermal Rating: on line 4546-1098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1872
% INFO    : Updated Thermal Rating: on line 5241-1101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113138
% INFO    : Updated Thermal Rating: on line 5567-1102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5568-1102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 2416-1103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 2587-1103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 2416-1103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 2739-1105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1807
% INFO    : Updated Thermal Rating: on line 2315-1106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 3186-1106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3862
% INFO    : Updated Thermal Rating: on line 5244-1107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29034
% INFO    : Updated Thermal Rating: on line 2443-1109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 4498-1109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 5073-1109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 3286-1110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 3570-1111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 5034-1111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 5217-1111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1503
% INFO    : Updated Thermal Rating: on line 5218-1111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5836-1111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 3570-1111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on line 3592-1111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 3592-1111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 1951-1113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 870
% INFO    : Updated Thermal Rating: on line 2559-1114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on line 1766-1116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 2495-1115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 848
% INFO    : Updated Thermal Rating: on line 4432-1115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2826
% INFO    : Updated Thermal Rating: on line 4510-1116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 2495-1115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 848
% INFO    : Updated Thermal Rating: on line 3540-1117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 5245-1117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2753
% INFO    : Updated Thermal Rating: on line 1496-1118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on line 1913-1118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 2076-1118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 1540-1120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2430
% INFO    : Updated Thermal Rating: on line 4954-1120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 4954-1120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 2559-1121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on line 2559-1122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2715
% INFO    : Updated Thermal Rating: on line 5247-1123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320583
% INFO    : Updated Thermal Rating: on line 1302-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 2314-1125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 4524-1125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3778
% INFO    : Updated Thermal Rating: on line 1379-1126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 3385-1126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 4679-1128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5249-1129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10315
% INFO    : Updated Thermal Rating: on line 1224-1130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 2708-1130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1134
% INFO    : Updated Thermal Rating: on line 5494-1130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 2450-1132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 5640-1132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 3066-1133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 3740-1133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3356
% INFO    : Updated Thermal Rating: on line 5248-1133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7884
% INFO    : Updated Thermal Rating: on line 3093-1133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 1354-1135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 3238-1135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 1354-1135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 2795-1137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 2977-1136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 5101-1137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1642
% INFO    : Updated Thermal Rating: on line 5241-1136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 984
% INFO    : Updated Thermal Rating: on line 5476-1137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 4992-1139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2077
% INFO    : Updated Thermal Rating: on line 5250-1140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 2376-1141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 2835-1141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on line 5215-1141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 5436-1141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 5439-1141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 5257-1141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 5252-1144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 2579-1147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 4340-1147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 1809-1148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 3552-1148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 3610-1149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 3801-1150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1691
% INFO    : Updated Thermal Rating: on line 2131-1151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 3014-1152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1471
% INFO    : Updated Thermal Rating: on line 3458-1152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2805
% INFO    : Updated Thermal Rating: on line 3499-1152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5541-1151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 5620-1151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1715
% INFO    : Updated Thermal Rating: on line 5658-1151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 3355-1154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 4735-1154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 5760-1154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 5251-1155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1543
% INFO    : Updated Thermal Rating: on line 4785-1159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3672
% INFO    : Updated Thermal Rating: on line 4784-1160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3321
% INFO    : Updated Thermal Rating: on line 4785-1161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3234
% INFO    : Updated Thermal Rating: on line 4558-1163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 813
% INFO    : Updated Thermal Rating: on line 5107-1165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 2571-1166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 4974-1167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5585-1167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 2821-1169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 3083-1169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 3630-1169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 4191-1169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2331
% INFO    : Updated Thermal Rating: on line 4215-1169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1574
% INFO    : Updated Thermal Rating: on line 4677-1169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 5612-1169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1239
% INFO    : Updated Thermal Rating: on line 3083-1169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 4214-1169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 5695-1169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1397
% INFO    : Updated Thermal Rating: on line 3356-1175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 3600-1176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 4044-1176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8488
% INFO    : Updated Thermal Rating: on line 5689-1176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 5012-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 1187-1178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43410
% INFO    : Updated Thermal Rating: on line 2643-1180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 5834-1179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 3220-1181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 3906-1184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1646
% INFO    : Updated Thermal Rating: on line 5394-1184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 1957-1186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 4612-1186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 2136-1187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 2155-1187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1337
% INFO    : Updated Thermal Rating: on line 4150-1187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19301
% INFO    : Updated Thermal Rating: on line 4073-1189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 4310-1190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 5740-1189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 4073-1188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116592
% INFO    : Updated Thermal Rating: on line 3658-1194 : Rate A, Rate B, Rate C , 558.0, 558.0, 558.0 -> 297
% INFO    : Updated Thermal Rating: on line 1515-1195 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1002
% INFO    : Updated Thermal Rating: on line 1515-1195 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 996
% INFO    : Updated Thermal Rating: on line 2778-1195 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 633
% INFO    : Updated Thermal Rating: on line 3381-1196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 3995-1196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5573-1196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 4651-1197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 5430-1197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2398
% INFO    : Updated Thermal Rating: on line 5429-1197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2398
% INFO    : Updated Thermal Rating: on line 4169-1200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12326
% INFO    : Updated Thermal Rating: on line 4973-1200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 5082-1199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 5156-1199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 2717-1201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 3949-1201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 3950-1201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 4412-1201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 4413-1201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 3878-1203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 4997-1203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 208
% INFO    : Updated Thermal Rating: on line 1981-1203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 3384-1203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 5260-1205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27851
% INFO    : Updated Thermal Rating: on line 2247-1206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 3862-1206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 4128-1206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 2247-1206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 5717-1206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 4601-1208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2918
% INFO    : Updated Thermal Rating: on line 5019-1209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1097
% INFO    : Updated Thermal Rating: on line 5708-1209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 3701-1212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 665
% INFO    : Updated Thermal Rating: on line 4350-1212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 2653-1213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 2881-1213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 1984-1216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 1805-1217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 2744-1217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10890
% INFO    : Updated Thermal Rating: on line 1346-1218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3850-1218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 3421-1219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5075-1220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 5259-1221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 1242-1223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 5403-1224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 1380-1226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on line 3046-1227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 4431-1227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 3489-1228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10482
% INFO    : Updated Thermal Rating: on line 4430-1228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 1338-1229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 1647-1229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 2422-1229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 2487-1229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 4340-1230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 4445-1230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 1772-1232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 743
% INFO    : Updated Thermal Rating: on line 3038-1232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 1772-1232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 743
% INFO    : Updated Thermal Rating: on line 3597-1234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2368
% INFO    : Updated Thermal Rating: on line 4272-1234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on line 5232-1233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 5738-1233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1480
% INFO    : Updated Thermal Rating: on line 5641-1233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1450
% INFO    : Updated Thermal Rating: on line 3597-1234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on line 5689-1237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19617
% INFO    : Updated Thermal Rating: on line 4075-1235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 5542-1239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 1954-1240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 3305-1240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 555
% INFO    : Updated Thermal Rating: on line 1610-1241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 1850-1241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4966
% INFO    : Updated Thermal Rating: on line 1611-1241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 1849-1241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6273
% INFO    : Updated Thermal Rating: on line 2866-1242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 3815-1242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 5169-1242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 4281-1244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 4320-1244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 4281-1244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 2257-1245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 4560-1248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10119
% INFO    : Updated Thermal Rating: on line 4618-1248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10465
% INFO    : Updated Thermal Rating: on line 5108-1249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 5621-1249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 5269-1250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 1651-1253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1583
% INFO    : Updated Thermal Rating: on line 4198-1255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 5485-1255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1309
% INFO    : Updated Thermal Rating: on line 2332-1256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 5271-1257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32501
% INFO    : Updated Thermal Rating: on line 2250-1259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 4708-1259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 4727-1258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 5539-1258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5767-1259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 4708-1258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 4727-1259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 3803-1261 : Rate A, Rate B, Rate C , 1711.0, 1711.0, 1711.0 -> 1648
% INFO    : Updated Thermal Rating: on line 4898-1261 : Rate A, Rate B, Rate C , 1307.0, 1307.0, 1307.0 -> 1080
% INFO    : Updated Thermal Rating: on line 4084-1262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 1507-1263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 2653-1263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5270-1266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on line 2256-1267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 4208-1268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5211-1268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 5273-1269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1337
% INFO    : Updated Thermal Rating: on line 1542-1272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 3194-1272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 1769-1274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 5274-1275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 3623-1276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 3971-1276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 4785-1279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21546
% INFO    : Updated Thermal Rating: on line 2265-1280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on line 2705-1280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 3913-1281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27378
% INFO    : Updated Thermal Rating: on line 3912-1281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27596
% INFO    : Updated Thermal Rating: on line 1833-1282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23964
% INFO    : Updated Thermal Rating: on line 2042-1283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 3755-1283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 1627-1284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 5170-1284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4968
% INFO    : Updated Thermal Rating: on line 5781-1284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4252
% INFO    : Updated Thermal Rating: on line 5136-1285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1046
% INFO    : Updated Thermal Rating: on line 5802-1286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 2005-1287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5205
% INFO    : Updated Thermal Rating: on line 5207-1289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8292
% INFO    : Updated Thermal Rating: on line 5208-1289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 2300-1290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 3936-1290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 3936-1290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 3442-1296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 2026-1297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 4636-1297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 5833-1298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 1300-1299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 4895-1299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 2112-1302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1618
% INFO    : Updated Thermal Rating: on line 2634-1304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1236
% INFO    : Updated Thermal Rating: on line 5814-1305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 5140-1306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 941
% INFO    : Updated Thermal Rating: on line 5379-1306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 1345-1307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23302
% INFO    : Updated Thermal Rating: on line 1609-1307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 3902-1307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 3340-1308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1835
% INFO    : Updated Thermal Rating: on line 3701-1308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 4836-1308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 5280-1309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38166
% INFO    : Updated Thermal Rating: on line 2920-1310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 3928-1310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 5279-1311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2153
% INFO    : Updated Thermal Rating: on line 2612-1312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 5279-1312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5281-1312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on line 1313-1314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5399
% INFO    : Updated Thermal Rating: on line 1980-1314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 2598-1315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 5621-1315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 2598-1315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 2934-1316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 2130-1318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3887
% INFO    : Updated Thermal Rating: on line 2130-1317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5064
% INFO    : Updated Thermal Rating: on line 3424-1319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 1380-1320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 4401-1320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 5579-1320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 3670-1322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 5642-1322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5504
% INFO    : Updated Thermal Rating: on line 4037-1323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4533
% INFO    : Updated Thermal Rating: on line 3251-1324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 3519-1324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 2094-1325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 5233-1325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1345
% INFO    : Updated Thermal Rating: on line 4420-1326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11223
% INFO    : Updated Thermal Rating: on line 1661-1327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 4263-1327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 5736-1327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 1537-1329 : Rate A, Rate B, Rate C , 2280.0, 2280.0, 2280.0 -> 932
% INFO    : Updated Thermal Rating: on line 3426-1329 : Rate A, Rate B, Rate C , 1559.0, 1559.0, 1559.0 -> 944
% INFO    : Updated Thermal Rating: on line 1537-1329 : Rate A, Rate B, Rate C , 2280.0, 2280.0, 2280.0 -> 932
% INFO    : Updated Thermal Rating: on line 5095-1330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2802
% INFO    : Updated Thermal Rating: on line 5346-1331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 5822-1331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1139
% INFO    : Updated Thermal Rating: on line 2129-1332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 4998-1332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 4102-1333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 5164-1333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2759
% INFO    : Updated Thermal Rating: on line 1840-1338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 1841-1338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 1751-1340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1575
% INFO    : Updated Thermal Rating: on line 5272-1340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 4188-1341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19787
% INFO    : Updated Thermal Rating: on line 3001-1342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on line 2355-1348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21515
% INFO    : Updated Thermal Rating: on line 2355-1347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21515
% INFO    : Updated Thermal Rating: on line 1592-1349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 3870-1350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 1359-1351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 2352-1351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 1385-1352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 1944-1352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 874
% INFO    : Updated Thermal Rating: on line 2616-1352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2427
% INFO    : Updated Thermal Rating: on line 2684-1352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 2685-1352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 2690-1352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 1384-1352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 5128-1354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 4102-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1039
% INFO    : Updated Thermal Rating: on line 4102-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1022
% INFO    : Updated Thermal Rating: on line 4467-1358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 5350-1359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 3825-1361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22551
% INFO    : Updated Thermal Rating: on line 3825-1360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23186
% INFO    : Updated Thermal Rating: on line 2450-1362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17936
% INFO    : Updated Thermal Rating: on line 5760-1363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 1702-1366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1181
% INFO    : Updated Thermal Rating: on line 1708-1365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 1709-1364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1754
% INFO    : Updated Thermal Rating: on line 1793-1367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26552
% INFO    : Updated Thermal Rating: on line 1378-1368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on line 3250-1368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7254
% INFO    : Updated Thermal Rating: on line 5284-1368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4688
% INFO    : Updated Thermal Rating: on line 5286-1368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5285-1368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 5301-1370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 499
% INFO    : Updated Thermal Rating: on line 2072-1369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 3996-1371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7767
% INFO    : Updated Thermal Rating: on line 1770-1373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 2532-1374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 5287-1375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27851
% INFO    : Updated Thermal Rating: on line 2340-1377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 3698-1377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8177
% INFO    : Updated Thermal Rating: on line 3908-1377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 5228-1377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 4442-1380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2154
% INFO    : Updated Thermal Rating: on line 5267-1380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2005
% INFO    : Updated Thermal Rating: on line 1659-1381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 2045-1381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 3268-1381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 3994-1381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 5511-1381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 5750-1381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 2530-1381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 3993-1381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 4940-1381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 5510-1381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 3405-1385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6474
% INFO    : Updated Thermal Rating: on line 2602-1384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 2746-1386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 2653-1388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on line 3042-1388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 3387-1389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5520-1389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on line 2141-1390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 3857-1390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 752
% INFO    : Updated Thermal Rating: on line 5132-1390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 5288-1390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 3186-1391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21515
% INFO    : Updated Thermal Rating: on line 4967-1392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 4966-1392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 5289-1394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1462
% INFO    : Updated Thermal Rating: on line 5246-1395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 2559-1395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 5290-1396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28417
% INFO    : Updated Thermal Rating: on line 2337-1397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 4320-1398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 5585-1398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 5291-1401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1093
% INFO    : Updated Thermal Rating: on line 1946-1402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 3693-1402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3856-1402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 3856-1402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 1296-1405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 1808-1405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2199
% INFO    : Updated Thermal Rating: on line 4328-1405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 2863-1407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5697
% INFO    : Updated Thermal Rating: on line 3166-1407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 5562-1408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7412
% INFO    : Updated Thermal Rating: on line 5793-1409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26199
% INFO    : Updated Thermal Rating: on line 5292-1410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16094
% INFO    : Updated Thermal Rating: on line 2231-1411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 4139-1411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 5787-1411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 4674-1412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 5758-1412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 2476-1413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 2865-1413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 4622-1413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 1817-1414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1097
% INFO    : Updated Thermal Rating: on line 1817-1414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 2601-1416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 3228-1415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 2602-1416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 3227-1416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 3666-1417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3794
% INFO    : Updated Thermal Rating: on line 3666-1417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3140
% INFO    : Updated Thermal Rating: on line 3870-1419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 663
% INFO    : Updated Thermal Rating: on line 3870-1418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 3599-1420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 2002-1421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38266
% INFO    : Updated Thermal Rating: on line 3879-1422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 5295-1422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29272
% INFO    : Updated Thermal Rating: on line 5296-1422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29272
% INFO    : Updated Thermal Rating: on line 5298-1423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12455
% INFO    : Updated Thermal Rating: on line 974-1424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 5019-1424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 5087-1424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 5352-1424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 3995-1425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 5310-1425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 4042-1426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 4514-1426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 1430-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309464
% INFO    : Updated Thermal Rating: on line 1060-1429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 4531-1429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11961
% INFO    : Updated Thermal Rating: on line 5025-1429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 1060-1429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 925-1431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 621
% INFO    : Updated Thermal Rating: on line 1241-1431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 632
% INFO    : Updated Thermal Rating: on line 1610-1431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 1768-1431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2467
% INFO    : Updated Thermal Rating: on line 2531-1431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1224
% INFO    : Updated Thermal Rating: on line 1775-1432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 5300-1433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16094
% INFO    : Updated Thermal Rating: on line 1678-1434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 4217-1435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1496
% INFO    : Updated Thermal Rating: on line 2486-1436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1537
% INFO    : Updated Thermal Rating: on line 2728-1436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 4197-1436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2632
% INFO    : Updated Thermal Rating: on line 4690-1436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 5274-1436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 2486-1436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2073
% INFO    : Updated Thermal Rating: on line 2728-1436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 2486-1436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1356
% INFO    : Updated Thermal Rating: on line 2953-1438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 5788-1438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 1263-1440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 1319-1440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2023
% INFO    : Updated Thermal Rating: on line 3042-1439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 3063-1440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 4577-1440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 4761-1439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 5663-1440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 5783-1439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 1444-1442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2231
% INFO    : Updated Thermal Rating: on line 1444-1442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2924
% INFO    : Updated Thermal Rating: on line 5301-1443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23584
% INFO    : Updated Thermal Rating: on line 3976-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8415
% INFO    : Updated Thermal Rating: on line 968-1447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 4795-1449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 4795-1448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 2677-1450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1280
% INFO    : Updated Thermal Rating: on line 5274-1450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1407
% INFO    : Updated Thermal Rating: on line 3454-1451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 3194-1453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4708
% INFO    : Updated Thermal Rating: on line 4321-1456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 3258-1457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 367
% INFO    : Updated Thermal Rating: on line 4638-1457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 4654-1457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 5007-1457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 5106-1457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3691
% INFO    : Updated Thermal Rating: on line 4637-1457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on line 5237-1457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on line 5079-1459 : Rate A, Rate B, Rate C , 1828.0, 1828.0, 1828.0 -> 1297
% INFO    : Updated Thermal Rating: on line 1616-1460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 2740-1460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 3520-1460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on line 5323-1460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 3262-1460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 4877-1461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 2526-1463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 5012-1464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 5739-1464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 3552-1465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 3552-1465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 1703-1466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 954
% INFO    : Updated Thermal Rating: on line 3554-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2064
% INFO    : Updated Thermal Rating: on line 1703-1466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 3028-1468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 4349-1468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5034-1468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 3028-1468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 5269-1471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 4935-1472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 3623-1473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28743
% INFO    : Updated Thermal Rating: on line 1884-1474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14533
% INFO    : Updated Thermal Rating: on line 2001-1474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20949
% INFO    : Updated Thermal Rating: on line 2693-1474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 2936-1474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21757
% INFO    : Updated Thermal Rating: on line 2935-1474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21757
% INFO    : Updated Thermal Rating: on line 5523-1474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on line 2509-1476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 2509-1476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 2545-1478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 4168-1478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 4269-1478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1572
% INFO    : Updated Thermal Rating: on line 4437-1478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 5104-1478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 5263-1478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 5684-1478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 5258-1478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 3542-1479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2700
% INFO    : Updated Thermal Rating: on line 4573-1479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1639
% INFO    : Updated Thermal Rating: on line 3359-1479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 617
% INFO    : Updated Thermal Rating: on line 4731-1480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3272
% INFO    : Updated Thermal Rating: on line 4731-1480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3532
% INFO    : Updated Thermal Rating: on line 2127-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1044
% INFO    : Updated Thermal Rating: on line 4238-1484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 5305-1484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85273
% INFO    : Updated Thermal Rating: on line 2798-1485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4650
% INFO    : Updated Thermal Rating: on line 1667-1486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 5715-1486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 1711-1487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 3008-1490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3724
% INFO    : Updated Thermal Rating: on line 4956-1490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 2598-1495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 2617-1497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 3992-1497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 2273-1498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 3403-1498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 4053-1498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 4709-1498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 5059-1498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4053-1498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 5306-1501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 4822-1502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 3364-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 5666-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on line 3069-1504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 3034-1505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 3244-1505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 2414-1506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 5089-1506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 4202-1508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 4202-1508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 2105-1509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 3637-1509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 3728-1510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 3885-1510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 4532-1510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3422-1511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 3728-1511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1500
% INFO    : Updated Thermal Rating: on line 3728-1511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1459
% INFO    : Updated Thermal Rating: on line 2353-1513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 2595-1513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4036-1513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1004
% INFO    : Updated Thermal Rating: on line 5519-1513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 5704-1513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 4036-1513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on line 3409-1515 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1517
% INFO    : Updated Thermal Rating: on line 4784-1516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 4785-1516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 1628-1521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 2407-1521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3428-1521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 4117-1521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106
% INFO    : Updated Thermal Rating: on line 5178-1521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 2407-1521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 2320-1523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 4910-1523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 4909-1523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 4420-1524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 5307-1525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 1832-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 1775-1527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 2566-1527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 1544-1528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 1561-1528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 4863-1529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 4928-1528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 5713-1528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 971
% INFO    : Updated Thermal Rating: on line 4105-1528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 5438-1530 : Rate A, Rate B, Rate C , 541.0, 541.0, 541.0 -> 447
% INFO    : Updated Thermal Rating: on line 2463-1531 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2406
% INFO    : Updated Thermal Rating: on line 2940-1531 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1759
% INFO    : Updated Thermal Rating: on line 3617-1531 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1245
% INFO    : Updated Thermal Rating: on line 3697-1531 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1191
% INFO    : Updated Thermal Rating: on line 2463-1531 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2405
% INFO    : Updated Thermal Rating: on line 1845-1532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 5010-1532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 5358-1532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5843-1532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 2923-1533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5832-1533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1981
% INFO    : Updated Thermal Rating: on line 2097-1534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 3073-1534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 3538-1534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 5177-1534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on line 5358-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 4854-1537 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1934
% INFO    : Updated Thermal Rating: on line 1927-1538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1292
% INFO    : Updated Thermal Rating: on line 3599-1538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 3969-1538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 5624-1538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on line 3599-1538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 3520-1542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 2146-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2751
% INFO    : Updated Thermal Rating: on line 2626-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 2146-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2764
% INFO    : Updated Thermal Rating: on line 2626-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 951
% INFO    : Updated Thermal Rating: on line 4173-1545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5731-1545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 4173-1545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5310-1546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 1831-1548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 3237-1550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 4257-1550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 703
% INFO    : Updated Thermal Rating: on line 2738-1551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 3304-1552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 4668-1556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1294
% INFO    : Updated Thermal Rating: on line 1843-1558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109898
% INFO    : Updated Thermal Rating: on line 5491-1558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 1813-1558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6227
% INFO    : Updated Thermal Rating: on line 1844-1558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109898
% INFO    : Updated Thermal Rating: on line 1828-1559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1984
% INFO    : Updated Thermal Rating: on line 3237-1559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 3370-1559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 3237-1559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 3237-1559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 2007-1562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 4368-1565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 4851-1565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 5190-1565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 5260-1566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 4426-1568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 4681-1568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on line 5313-1569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 3066-1571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 4327-1571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 4446-1571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3736
% INFO    : Updated Thermal Rating: on line 5315-1571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on line 3942-1572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 5139-1572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 5688-1572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 2977-1572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 1513-1577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 3328-1579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 5316-1579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4368
% INFO    : Updated Thermal Rating: on line 4223-1582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 4990-1582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 3270-1583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3108
% INFO    : Updated Thermal Rating: on line 3282-1583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3384
% INFO    : Updated Thermal Rating: on line 3992-1583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 5048-1583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3055
% INFO    : Updated Thermal Rating: on line 5583-1583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2792
% INFO    : Updated Thermal Rating: on line 3270-1583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3393
% INFO    : Updated Thermal Rating: on line 3591-1583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5554
% INFO    : Updated Thermal Rating: on line 5048-1583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2366
% INFO    : Updated Thermal Rating: on line 2613-1585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5695-1586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21515
% INFO    : Updated Thermal Rating: on line 5317-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31460
% INFO    : Updated Thermal Rating: on line 4533-1589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 5319-1589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 4748-1590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5335-1590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 1606-1591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 3922-1591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 2350-1593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 4973-1592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 5394-1593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 4362-1593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 4972-1592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 2763-1594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 2938-1594 : Rate A, Rate B, Rate C , 325.0, 325.0, 325.0 -> 276
% INFO    : Updated Thermal Rating: on line 2764-1595 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1482
% INFO    : Updated Thermal Rating: on line 3426-1595 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1546
% INFO    : Updated Thermal Rating: on line 3930-1595 : Rate A, Rate B, Rate C , 1263.0, 1263.0, 1263.0 -> 624
% INFO    : Updated Thermal Rating: on line 4767-1595 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2287
% INFO    : Updated Thermal Rating: on line 4855-1595 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 996
% INFO    : Updated Thermal Rating: on line 4767-1595 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2289
% INFO    : Updated Thermal Rating: on line 2607-1596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 3055-1596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 3419-1596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on line 4869-1596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1913
% INFO    : Updated Thermal Rating: on line 2607-1596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 3054-1596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 5320-1599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31883
% INFO    : Updated Thermal Rating: on line 3041-1601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 4518-1601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 4338-1603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 4338-1603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 2621-1604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 4452-1604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5146-1604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 2089-1605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 2301-1605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 3314-1606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 3314-1606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 4668-1607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 2114-1608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 3505-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 4008-1610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 5558-1610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5761-1610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 3364-1613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 5666-1613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1866
% INFO    : Updated Thermal Rating: on line 1940-1614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 2684-1615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on line 5489-1615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 5094-1617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 5734-1617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 3953-1618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 5430-1619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5429-1619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5635-1620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 2256-1621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 3623-1625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 2003-1626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85214
% INFO    : Updated Thermal Rating: on line 5389-1627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 715
% INFO    : Updated Thermal Rating: on line 3422-1628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 2202-1629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2839
% INFO    : Updated Thermal Rating: on line 5409-1629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6565
% INFO    : Updated Thermal Rating: on line 1851-1630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 5109-1630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 2041-1631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 2524-1632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 3021-1632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 3575-1632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on line 4119-1632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on line 4511-1632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 759
% INFO    : Updated Thermal Rating: on line 2524-1632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1614
% INFO    : Updated Thermal Rating: on line 4119-1632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on line 4511-1632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 4128-1634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 4353-1634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 1802-1635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 4749-1635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 453
% INFO    : Updated Thermal Rating: on line 3127-1636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 5325-1637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85273
% INFO    : Updated Thermal Rating: on line 2538-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 2964-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 4749-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 1719-1640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 3402-1640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4452-1640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 1936-1641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 1936-1641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 5327-1642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3291
% INFO    : Updated Thermal Rating: on line 2856-1644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 5328-1643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23993
% INFO    : Updated Thermal Rating: on line 1873-1645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7204
% INFO    : Updated Thermal Rating: on line 5453-1647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 5329-1651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 5330-1652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 520
% INFO    : Updated Thermal Rating: on line 2638-1653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1607
% INFO    : Updated Thermal Rating: on line 2795-1654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 2121-1656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 3601-1656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 1786-1657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1733
% INFO    : Updated Thermal Rating: on line 1786-1657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1808
% INFO    : Updated Thermal Rating: on line 2420-1658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on line 4851-1658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 5050-1658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3268-1659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5332-1660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12351
% INFO    : Updated Thermal Rating: on line 5018-1661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 1938-1662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41198
% INFO    : Updated Thermal Rating: on line 2000-1663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 3019-1663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28461
% INFO    : Updated Thermal Rating: on line 3710-1663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 3731-1663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 4224-1663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 5042-1663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 5753-1663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 707
% INFO    : Updated Thermal Rating: on line 3018-1663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10795
% INFO    : Updated Thermal Rating: on line 2035-1665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 4722-1665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5333-1666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5595
% INFO    : Updated Thermal Rating: on line 3398-1667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1343
% INFO    : Updated Thermal Rating: on line 4079-1667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1061
% INFO    : Updated Thermal Rating: on line 5001-1667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 3398-1667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1351
% INFO    : Updated Thermal Rating: on line 1863-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 3145-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 3546-1671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 4631-1672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5298-1672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 5493-1672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 5739-1672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 1674-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on line 4513-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 2476-1674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 2507-1675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 4619-1675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 3933-1676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3862
% INFO    : Updated Thermal Rating: on line 5524-1676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 5652-1676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 3041-1678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on line 3649-1680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 4512-1680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 5325-1682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 5598-1683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 5596-1683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 583
% INFO    : Updated Thermal Rating: on line 5338-1685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7473
% INFO    : Updated Thermal Rating: on line 3706-1686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240340
% INFO    : Updated Thermal Rating: on line 5339-1687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28260
% INFO    : Updated Thermal Rating: on line 2450-1688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on line 2450-1688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 2450-1688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on line 4211-1690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318558
% INFO    : Updated Thermal Rating: on line 4211-1689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318567
% INFO    : Updated Thermal Rating: on line 4208-1691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303410
% INFO    : Updated Thermal Rating: on line 4210-1693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310129
% INFO    : Updated Thermal Rating: on line 4210-1692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310185
% INFO    : Updated Thermal Rating: on line 5327-1694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 4523-1696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1287
% INFO    : Updated Thermal Rating: on line 5726-1696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2676
% INFO    : Updated Thermal Rating: on line 5724-1696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2708
% INFO    : Updated Thermal Rating: on line 4344-1697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 2783-1698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on line 2783-1699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 967
% INFO    : Updated Thermal Rating: on line 5293-1699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5294-1699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 5340-1699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7068
% INFO    : Updated Thermal Rating: on line 5451-1699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 1709-1703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3772
% INFO    : Updated Thermal Rating: on line 2725-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4361
% INFO    : Updated Thermal Rating: on line 3209-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1479
% INFO    : Updated Thermal Rating: on line 4065-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13439
% INFO    : Updated Thermal Rating: on line 1708-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3772
% INFO    : Updated Thermal Rating: on line 3209-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1542
% INFO    : Updated Thermal Rating: on line 3925-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 3209-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on line 3209-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 1710-1705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1710-1707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1710-1704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1710-1706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 2229-1711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 2246-1711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 739
% INFO    : Updated Thermal Rating: on line 3123-1711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11088
% INFO    : Updated Thermal Rating: on line 4610-1711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 2246-1711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on line 5342-1714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25032
% INFO    : Updated Thermal Rating: on line 5341-1713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25032
% INFO    : Updated Thermal Rating: on line 2231-1715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9016
% INFO    : Updated Thermal Rating: on line 3859-1716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 4626-1716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 4723-1716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 5100-1716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 5097-1716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 3104-1718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 5344-1723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26199
% INFO    : Updated Thermal Rating: on line 3970-1725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 5317-1725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 2798-1726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4341
% INFO    : Updated Thermal Rating: on line 5346-1727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5788
% INFO    : Updated Thermal Rating: on line 5347-1728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 1987-1729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 4007-1730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 4076-1730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 4159-1729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1520
% INFO    : Updated Thermal Rating: on line 5560-1729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 4076-1729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 3891-1733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 3906-1733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 5350-1733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 1795-1734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on line 5517-1734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 1746-1740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1745-1740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1744-1740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2326-1747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 5816-1748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2646
% INFO    : Updated Thermal Rating: on line 2325-1748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 2855-1748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7488
% INFO    : Updated Thermal Rating: on line 5523-1747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 2927-1750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 3088-1750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 3092-1750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 5572-1750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 1752-4124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 5348-1753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7997
% INFO    : Updated Thermal Rating: on line 2005-1754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 2509-1755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2680-1756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 2306-1757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3869
% INFO    : Updated Thermal Rating: on line 2140-1758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 2328-1758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 3262-1759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 2668-1761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 4091-1761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 5833-1761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 1778-1761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 2668-1761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 4510-1766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 2698-1768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 2315-1771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 3302-1772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 3563-1772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on line 3706-1772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 3858-1771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 3901-1771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 5111-1771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 3706-1772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 3024-1773 : Rate A, Rate B, Rate C , 509.0, 509.0, 509.0 -> 421
% INFO    : Updated Thermal Rating: on line 3057-1773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 566
% INFO    : Updated Thermal Rating: on line 4920-1774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 5183-1774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 2566-1775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 2975-1775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 4925-1775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 5299-1775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 2307-1777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 2491-1777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 4943-1778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 4147-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 3455-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 4926-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 5179-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 5828-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1337
% INFO    : Updated Thermal Rating: on line 5320-1782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11433
% INFO    : Updated Thermal Rating: on line 4644-1783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 5374-1783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 4298-1784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4644-1784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 3269-1785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 4582-1785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320
% INFO    : Updated Thermal Rating: on line 4965-1785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 796
% INFO    : Updated Thermal Rating: on line 3965-1786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4287-1786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 2998-1787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 3402-1789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 4888-1789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 3558-1792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37155
% INFO    : Updated Thermal Rating: on line 5442-1794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2889
% INFO    : Updated Thermal Rating: on line 1794-1795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2981
% INFO    : Updated Thermal Rating: on line 2387-1797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 4400-1798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 4462-1798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 4891-1798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 2751-1801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1879
% INFO    : Updated Thermal Rating: on line 2751-1800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1879
% INFO    : Updated Thermal Rating: on line 3369-1802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 1930-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8785
% INFO    : Updated Thermal Rating: on line 3182-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on line 3924-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 5410-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 5573-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2129
% INFO    : Updated Thermal Rating: on line 5815-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 2159-1804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3579
% INFO    : Updated Thermal Rating: on line 2159-1804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3514
% INFO    : Updated Thermal Rating: on line 2744-1805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 990
% INFO    : Updated Thermal Rating: on line 3354-1805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 5273-1805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 3354-1805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 4533-1805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 208
% INFO    : Updated Thermal Rating: on line 5351-1807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16165
% INFO    : Updated Thermal Rating: on line 3434-1809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 5449-1810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 5635-1810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 4809-1812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 5362-1812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 1816-1814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2468
% INFO    : Updated Thermal Rating: on line 1816-1814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2403
% INFO    : Updated Thermal Rating: on line 5352-1815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 2474-1817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 2558-1817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3999-1817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 3662-1820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 3662-1820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 3007-1821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1306
% INFO    : Updated Thermal Rating: on line 3535-1821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 1956-1823 : Rate A, Rate B, Rate C , 1253.0, 1253.0, 1253.0 -> 1246
% INFO    : Updated Thermal Rating: on line 4064-1824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 3078-1825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 3547-1826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1170
% INFO    : Updated Thermal Rating: on line 4404-1826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 5759-1826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 3547-1826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 4725-1829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 907
% INFO    : Updated Thermal Rating: on line 5799-1830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 952
% INFO    : Updated Thermal Rating: on line 5416-1831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 2015-1832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 2413-1832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 2847-1832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 3628-1832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3938
% INFO    : Updated Thermal Rating: on line 4859-1832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 5308-1832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 2470-1832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 2129-1836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 2597-1836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 2016-1837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 2322-1837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 4878-1837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 1937-1842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 984
% INFO    : Updated Thermal Rating: on line 2875-1846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 4267-1847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 2298-1848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 2495-1848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 2254-1851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 2420-1851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 4321-1851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 2771-1852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 724
% INFO    : Updated Thermal Rating: on line 4000-1852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 4735-1853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 3063-1854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on line 3069-1854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 3028-1855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2313
% INFO    : Updated Thermal Rating: on line 3328-1856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 4017-1856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 4279-1856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 3646-1857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2495
% INFO    : Updated Thermal Rating: on line 4005-1861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1459
% INFO    : Updated Thermal Rating: on line 4502-1862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 546
% INFO    : Updated Thermal Rating: on line 4122-1863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 1724-1864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 2297-1864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 3189-1864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 5132-1866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 5267-1867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2530
% INFO    : Updated Thermal Rating: on line 5579-1867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 921
% INFO    : Updated Thermal Rating: on line 1941-1868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 2554-1868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 1816-1869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 2676-1870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1486
% INFO    : Updated Thermal Rating: on line 5360-1871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 3647-1874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 5361-1875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23584
% INFO    : Updated Thermal Rating: on line 3661-1876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 3847-1876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 4740-1876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on line 5393-1876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 3996-1877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 3996-1877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 3738-1878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206242
% INFO    : Updated Thermal Rating: on line 3053-1880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 3053-1881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 4218-1882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 5364-1886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1897-1895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1897-1894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1897-1893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1897-1892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3867-1896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5053-1896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 3962-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 577
% INFO    : Updated Thermal Rating: on line 4207-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 4250-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 4861-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 5266-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 5466-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 3976-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 5667-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 3976-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 4449-1901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 4922-1901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 4257-1902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1592
% INFO    : Updated Thermal Rating: on line 5084-1903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 4775-1904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 5070-1905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 561
% INFO    : Updated Thermal Rating: on line 2079-1906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 5643-1906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on line 2079-1906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 4281-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5131-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 5310-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 5292-1910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4122
% INFO    : Updated Thermal Rating: on line 5300-1909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84779
% INFO    : Updated Thermal Rating: on line 5717-1911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1393
% INFO    : Updated Thermal Rating: on line 5171-1913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on line 3314-1914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 5292-1914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4688
% INFO    : Updated Thermal Rating: on line 3314-1914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1895
% INFO    : Updated Thermal Rating: on line 5367-1915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3052
% INFO    : Updated Thermal Rating: on line 5119-1916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13714
% INFO    : Updated Thermal Rating: on line 5009-1917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7487
% INFO    : Updated Thermal Rating: on line 3921-1918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 2092-1919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21948
% INFO    : Updated Thermal Rating: on line 3826-1919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5407
% INFO    : Updated Thermal Rating: on line 5424-1920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on line 2319-1921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59375
% INFO    : Updated Thermal Rating: on line 2188-1922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 2348-1922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 2401-1922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 4236-1922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16129
% INFO    : Updated Thermal Rating: on line 4236-1922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16129
% INFO    : Updated Thermal Rating: on line 3416-1924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 3416-1924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 1931-1925 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1998
% INFO    : Updated Thermal Rating: on line 1931-1925 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1997
% INFO    : Updated Thermal Rating: on line 3868-1926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 4110-1926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 4110-1926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 5331-1927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 3930-1929 : Rate A, Rate B, Rate C , 1695.0, 1695.0, 1695.0 -> 789
% INFO    : Updated Thermal Rating: on line 4543-1929 : Rate A, Rate B, Rate C , 2362.0, 2362.0, 2362.0 -> 1552
% INFO    : Updated Thermal Rating: on line 4854-1929 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1543
% INFO    : Updated Thermal Rating: on line 4543-1929 : Rate A, Rate B, Rate C , 2362.0, 2362.0, 2362.0 -> 1597
% INFO    : Updated Thermal Rating: on line 4284-1931 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2461
% INFO    : Updated Thermal Rating: on line 2652-1934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 4093-1935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4433
% INFO    : Updated Thermal Rating: on line 2203-1936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 2922-1936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 3126-1937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 4058-1936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1008
% INFO    : Updated Thermal Rating: on line 5359-1937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 2203-1936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 4058-1936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 3495-1942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on line 2041-1943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2981
% INFO    : Updated Thermal Rating: on line 2690-1944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2745
% INFO    : Updated Thermal Rating: on line 2883-1945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 2906-1945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 5371-1947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83671
% INFO    : Updated Thermal Rating: on line 3304-1948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 5276-1949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2664
% INFO    : Updated Thermal Rating: on line 5716-1950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 2677-1951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 404
% INFO    : Updated Thermal Rating: on line 3265-1952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 3304-1952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 3445-1953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5284
% INFO    : Updated Thermal Rating: on line 4423-1953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on line 4898-1956 : Rate A, Rate B, Rate C , 1750.0, 1750.0, 1750.0 -> 873
% INFO    : Updated Thermal Rating: on line 4898-1956 : Rate A, Rate B, Rate C , 2197.0, 2197.0, 2197.0 -> 873
% INFO    : Updated Thermal Rating: on line 4898-1956 : Rate A, Rate B, Rate C , 1192.0, 1192.0, 1192.0 -> 806
% INFO    : Updated Thermal Rating: on line 3006-1958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 3601-1959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 3510-1960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 1973-1971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1973-1970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1973-1969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1973-1968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1973-1967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1973-1966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3806-1972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4480-1972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3287-1975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4104-1976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 4312-1978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 4749-1978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 4334-1979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 2241-1980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 734
% INFO    : Updated Thermal Rating: on line 3220-1981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 4249-1982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 3924-1983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on line 5182-1984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 5361-1984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 5376-1986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21757
% INFO    : Updated Thermal Rating: on line 3193-1987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 5725-1988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 2298-1989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 2307-1989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 3196-1989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4182-1990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 674
% INFO    : Updated Thermal Rating: on line 4510-1990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 4741-1990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 4182-1990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 765
% INFO    : Updated Thermal Rating: on line 4510-1990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on line 4510-1990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 643
% INFO    : Updated Thermal Rating: on line 5378-1992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 4935-1993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 4066-1995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 4867-1995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 4066-1996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 4868-1996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5357-1997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13395
% INFO    : Updated Thermal Rating: on line 2672-1998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2747
% INFO    : Updated Thermal Rating: on line 5508-1999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 3710-2000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 4640-2003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89765
% INFO    : Updated Thermal Rating: on line 4153-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 5171-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on line 2810-2005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 5044-2005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on line 5205-2005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 4449-2006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 3403-2007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 4302-2008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7529
% INFO    : Updated Thermal Rating: on line 5835-2012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on line 5836-2013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on line 5457-2014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5032
% INFO    : Updated Thermal Rating: on line 3179-2016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 4935-2016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 2702-2019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 4285-2019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 605
% INFO    : Updated Thermal Rating: on line 2541-2020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 4735-2020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 5645-2021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 5387-2022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4107
% INFO    : Updated Thermal Rating: on line 5386-2023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4651
% INFO    : Updated Thermal Rating: on line 5389-2024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1021
% INFO    : Updated Thermal Rating: on line 2086-2025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 2681-2025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1651
% INFO    : Updated Thermal Rating: on line 3375-2025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 2937-2027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 4748-2027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 4875-2028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3711
% INFO    : Updated Thermal Rating: on line 5554-2029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5555-2029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 4117-2030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 5178-2030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 5305-2031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 5559-2031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 5560-2031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 2427-2032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 2054-2033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 2817-2033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3741-2033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 5212-2033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 5214-2033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 5209-2033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 4722-2035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 3861-2036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on line 2440-2039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 2659-2039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 972
% INFO    : Updated Thermal Rating: on line 2216-2042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 2228-2042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 2267-2042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 2834-2042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 870
% INFO    : Updated Thermal Rating: on line 2217-2043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6148
% INFO    : Updated Thermal Rating: on line 5393-2044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3779
% INFO    : Updated Thermal Rating: on line 2977-2046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on line 2977-2046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 4804-2048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 5296-2048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 3509-2050 : Rate A, Rate B, Rate C , 2368.0, 2368.0, 2368.0 -> 2335
% INFO    : Updated Thermal Rating: on line 4767-2050 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1679
% INFO    : Updated Thermal Rating: on line 3508-2050 : Rate A, Rate B, Rate C , 2368.0, 2368.0, 2368.0 -> 2335
% INFO    : Updated Thermal Rating: on line 4767-2050 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1679
% INFO    : Updated Thermal Rating: on line 3612-2053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4237
% INFO    : Updated Thermal Rating: on line 3612-2052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4237
% INFO    : Updated Thermal Rating: on line 3612-2051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4237
% INFO    : Updated Thermal Rating: on line 5390-2061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6969
% INFO    : Updated Thermal Rating: on line 2120-2063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 2728-2063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on line 4690-2063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 4086-2064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 935
% INFO    : Updated Thermal Rating: on line 3832-2066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 3850-2066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 5572-2066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 2798-2069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5731
% INFO    : Updated Thermal Rating: on line 3965-2070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 4394-2070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 4960-2073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on line 5711-2073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 4960-2072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 2272-2076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1391
% INFO    : Updated Thermal Rating: on line 3251-2076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 4954-2077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 791
% INFO    : Updated Thermal Rating: on line 5396-2078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15304
% INFO    : Updated Thermal Rating: on line 3041-2079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 3604-2079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 4043-2079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 4518-2079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 4460-2082 : Rate A, Rate B, Rate C , 1662.0, 1662.0, 1662.0 -> 1168
% INFO    : Updated Thermal Rating: on line 4898-2082 : Rate A, Rate B, Rate C , 1659.0, 1659.0, 1659.0 -> 1605
% INFO    : Updated Thermal Rating: on line 3612-2083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1375
% INFO    : Updated Thermal Rating: on line 3612-2083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1397
% INFO    : Updated Thermal Rating: on line 2726-2084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 2609-2085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2196-2086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 2087-1491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 3132-2089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 2442-2091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 5456-2091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 2479-2094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1378
% INFO    : Updated Thermal Rating: on line 4295-2094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2151
% INFO    : Updated Thermal Rating: on line 4295-2094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2151
% INFO    : Updated Thermal Rating: on line 4373-2095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 4373-2095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 3106-2096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1715
% INFO    : Updated Thermal Rating: on line 2197-2097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 3073-2097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 4691-2097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on line 5177-2097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on line 3073-2097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 4383-2097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 5754-2097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 404
% INFO    : Updated Thermal Rating: on line 2869-2099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 5614-2099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1095
% INFO    : Updated Thermal Rating: on line 2105-2102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1937
% INFO    : Updated Thermal Rating: on line 2105-2101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3363
% INFO    : Updated Thermal Rating: on line 2105-2104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18630
% INFO    : Updated Thermal Rating: on line 2105-2103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18082
% INFO    : Updated Thermal Rating: on line 2611-2105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 3637-2105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 4155-2105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 5105-2105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 5196-2105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 3892-2107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 5397-2107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 2994-2108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 3657-2109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 3691-2109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 5398-2110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 888
% INFO    : Updated Thermal Rating: on line 3262-2111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 3006-2112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 2987-2113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13742
% INFO    : Updated Thermal Rating: on line 2456-2115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 3168-2115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 3170-2116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 3441-2116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 4175-2116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 3403-2117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 3518-2117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 2760-2118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 3345-2118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 3785-2118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 4051-2118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 5379-2118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 3785-2118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 5377-2118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 5372-2120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 2671-2121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 3601-2122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 3946-2121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 4006-2122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 4665-2126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 848
% INFO    : Updated Thermal Rating: on line 4184-2129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5962
% INFO    : Updated Thermal Rating: on line 4185-2129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7065
% INFO    : Updated Thermal Rating: on line 2490-2130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on line 3218-2130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1217
% INFO    : Updated Thermal Rating: on line 5243-2131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1004
% INFO    : Updated Thermal Rating: on line 5346-2131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 5513-2131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 2423-2135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3993
% INFO    : Updated Thermal Rating: on line 2423-2135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3993
% INFO    : Updated Thermal Rating: on line 1905-2136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 2752-2136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41324
% INFO    : Updated Thermal Rating: on line 3188-2140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 3537-2141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 4343-2141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2805
% INFO    : Updated Thermal Rating: on line 5288-2141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 5552-2141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 4342-2141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2872
% INFO    : Updated Thermal Rating: on line 4154-2144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 5730-2144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 5400-2145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19026
% INFO    : Updated Thermal Rating: on line 3535-2147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 5401-2148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 973
% INFO    : Updated Thermal Rating: on line 3647-2149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 3535-2150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 5542-2150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 1990-2151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1682
% INFO    : Updated Thermal Rating: on line 1990-2151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 2155-2154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6326
% INFO    : Updated Thermal Rating: on line 5306-2155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 2062-2159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 3201-2159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 779
% INFO    : Updated Thermal Rating: on line 4747-2159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4374
% INFO    : Updated Thermal Rating: on line 5260-2159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 4746-2159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4930
% INFO    : Updated Thermal Rating: on line 5676-2164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 2773-2165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 4425-2165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 3403-2166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 3518-2167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 3867-2167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 3403-2166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 3518-2167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4641-2170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 4641-2170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 2216-2172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2562
% INFO    : Updated Thermal Rating: on line 2216-2171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2562
% INFO    : Updated Thermal Rating: on line 2675-2173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38967
% INFO    : Updated Thermal Rating: on line 4009-2174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1633
% INFO    : Updated Thermal Rating: on line 2874-2175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 3868-2175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 2181-2178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 2288-2178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13307
% INFO    : Updated Thermal Rating: on line 3090-2178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1673
% INFO    : Updated Thermal Rating: on line 3289-2178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1379
% INFO    : Updated Thermal Rating: on line 3700-2178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6195
% INFO    : Updated Thermal Rating: on line 4799-2178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1656
% INFO    : Updated Thermal Rating: on line 2181-2178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4799-2178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1987
% INFO    : Updated Thermal Rating: on line 4799-2178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2563
% INFO    : Updated Thermal Rating: on line 2319-2179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50437
% INFO    : Updated Thermal Rating: on line 2318-2179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40928
% INFO    : Updated Thermal Rating: on line 5404-2180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 5405-2182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1226
% INFO    : Updated Thermal Rating: on line 3915-2183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 5422-2185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27888
% INFO    : Updated Thermal Rating: on line 5406-2186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9817
% INFO    : Updated Thermal Rating: on line 2796-2189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5585
% INFO    : Updated Thermal Rating: on line 3804-2195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4923-2195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 5754-2197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 2981-2198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 3131-2199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8140
% INFO    : Updated Thermal Rating: on line 3130-2199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8731
% INFO    : Updated Thermal Rating: on line 4013-2200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 3126-2203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1109
% INFO    : Updated Thermal Rating: on line 5410-2204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5413-2205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 2494-2206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 2864-2208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 5168-2208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 5172-2208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 4800-2213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 5415-2213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 2834-2216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2069
% INFO    : Updated Thermal Rating: on line 2219-1493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25273
% INFO    : Updated Thermal Rating: on line 4156-2219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 5416-2219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8499
% INFO    : Updated Thermal Rating: on line 5417-2220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2414
% INFO    : Updated Thermal Rating: on line 5052-2221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on line 2492-2224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 2514-2224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on line 3755-2225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 727
% INFO    : Updated Thermal Rating: on line 3755-2225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 727
% INFO    : Updated Thermal Rating: on line 2985-2226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 3827-2226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5058-2226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 5261-2226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 3755-2228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 2789-2230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on line 3513-2230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 2789-2230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 4006-2231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 3482-2233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 3482-2233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 2851-2233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 4018-2236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 3319-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 887
% INFO    : Updated Thermal Rating: on line 3452-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1388
% INFO    : Updated Thermal Rating: on line 2561-2239 : Rate A, Rate B, Rate C , 1617.0, 1617.0, 1617.0 -> 1286
% INFO    : Updated Thermal Rating: on line 3146-2239 : Rate A, Rate B, Rate C , 1828.0, 1828.0, 1828.0 -> 926
% INFO    : Updated Thermal Rating: on line 3147-2239 : Rate A, Rate B, Rate C , 1828.0, 1828.0, 1828.0 -> 926
% INFO    : Updated Thermal Rating: on line 5325-2241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2636
% INFO    : Updated Thermal Rating: on line 2894-2242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5892
% INFO    : Updated Thermal Rating: on line 2388-2243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 4641-2244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 4763-2244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 5417-2245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130845
% INFO    : Updated Thermal Rating: on line 2478-2247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 3889-2250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1461
% INFO    : Updated Thermal Rating: on line 4824-2252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7026
% INFO    : Updated Thermal Rating: on line 4823-2251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7033
% INFO    : Updated Thermal Rating: on line 5419-2253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3593
% INFO    : Updated Thermal Rating: on line 2265-2255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3315
% INFO    : Updated Thermal Rating: on line 2611-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 5105-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5638-2257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2205
% INFO    : Updated Thermal Rating: on line 4643-2259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 5603-2259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 4408-2259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1653
% INFO    : Updated Thermal Rating: on line 5259-2259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 953
% INFO    : Updated Thermal Rating: on line 4322-2262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 3140-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 2201-2265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 797
% INFO    : Updated Thermal Rating: on line 4481-2267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 5422-2268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27888
% INFO    : Updated Thermal Rating: on line 4013-2269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1548
% INFO    : Updated Thermal Rating: on line 4013-2269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1548
% INFO    : Updated Thermal Rating: on line 3403-2273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 3559-2274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 5679-2277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 4004-2279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 4587-2279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 5423-2281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 894
% INFO    : Updated Thermal Rating: on line 4777-2282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 3793-2282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 2598-2284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 3219-2284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 2819-2285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13714
% INFO    : Updated Thermal Rating: on line 3407-2285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 619
% INFO    : Updated Thermal Rating: on line 4562-2285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 5607-2285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 2820-2286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308785
% INFO    : Updated Thermal Rating: on line 5424-2287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12712
% INFO    : Updated Thermal Rating: on line 3285-2291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 208
% INFO    : Updated Thermal Rating: on line 5736-2293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 5820-2293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4060
% INFO    : Updated Thermal Rating: on line 5197-2294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 3301-2295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 4083-2295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 5291-2296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 2724-2297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 997
% INFO    : Updated Thermal Rating: on line 2336-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on line 3860-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on line 5613-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 2485-2301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 3097-2301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1978
% INFO    : Updated Thermal Rating: on line 3849-2301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1053
% INFO    : Updated Thermal Rating: on line 5052-2301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 5606-2301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 966
% INFO    : Updated Thermal Rating: on line 3849-2301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on line 5605-2301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 963
% INFO    : Updated Thermal Rating: on line 3394-2301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1578
% INFO    : Updated Thermal Rating: on line 2280-2303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 4759-2303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5524-2305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 2914-2307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 4083-2307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5026-2307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 5026-2307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 4864-2309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 3211-2310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1067
% INFO    : Updated Thermal Rating: on line 4119-2311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1907
% INFO    : Updated Thermal Rating: on line 4511-2311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on line 3640-2312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 5425-2313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 3356-2314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on line 3072-2317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4316
% INFO    : Updated Thermal Rating: on line 4380-2320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 3076-2323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 5430-2324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on line 3188-2327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3240-2327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 3408-2328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 4607-2328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 4694-2328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 5562-2328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on line 3408-2327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 4607-2327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 3056-2331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3462-2331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2850-2332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 2420-2333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3176
% INFO    : Updated Thermal Rating: on line 2880-2334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 4434-2334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 2880-2334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 5810-2335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 3346-2337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 4198-2337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4308-2338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 601
% INFO    : Updated Thermal Rating: on line 5092-2338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 916
% INFO    : Updated Thermal Rating: on line 5432-2339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2283
% INFO    : Updated Thermal Rating: on line 2563-2341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 2969-2341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 4289-2341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 709
% INFO    : Updated Thermal Rating: on line 2563-2341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 4290-2341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 4614-2342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 2563-2341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 4009-2346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1684
% INFO    : Updated Thermal Rating: on line 2807-2347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 4340-2347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 3552-2349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 5752-2350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 4510-2351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3252
% INFO    : Updated Thermal Rating: on line 5187-2352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 977
% INFO    : Updated Thermal Rating: on line 4334-2354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 5434-2355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23932
% INFO    : Updated Thermal Rating: on line 5435-2356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 2369-2367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2369-2366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2369-2365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2369-2364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2369-2363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24882
% INFO    : Updated Thermal Rating: on line 2369-2362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2627-2368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 3887-2368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2356
% INFO    : Updated Thermal Rating: on line 5417-2368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3887-2368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 4173-2370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 974
% INFO    : Updated Thermal Rating: on line 2751-2371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 4009-2371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 3106-2373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 3544-2373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 3705-2373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 5437-2374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 3690-2374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5336-2375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 3657-2377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 2504-2378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 2584-2379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2239
% INFO    : Updated Thermal Rating: on line 3657-2379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 4895-2380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 3296-2381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10014
% INFO    : Updated Thermal Rating: on line 4983-2382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 2745-2383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1281
% INFO    : Updated Thermal Rating: on line 3632-2383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 2385-2384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23551
% INFO    : Updated Thermal Rating: on line 5462-2384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 2902-2385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 3324-2385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 5537-2385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 2902-2385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 5538-2385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 2817-2386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 4918-2387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 2494-2388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 2636-2389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 2772-2390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 2772-2390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 3318-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23670
% INFO    : Updated Thermal Rating: on line 3842-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 5447-2393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38032
% INFO    : Updated Thermal Rating: on line 3005-2394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1168
% INFO    : Updated Thermal Rating: on line 3670-2394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 3713-2394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4637
% INFO    : Updated Thermal Rating: on line 5642-2394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1383
% INFO    : Updated Thermal Rating: on line 3670-2394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on line 4697-2396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148594
% INFO    : Updated Thermal Rating: on line 4697-2395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151981
% INFO    : Updated Thermal Rating: on line 5448-2397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 2461-2398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 2975-2398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 5727-2399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 4713-2400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 2405-2401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77773
% INFO    : Updated Thermal Rating: on line 4536-2401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 3209-2402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3391
% INFO    : Updated Thermal Rating: on line 5798-2404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 3922-2406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 5758-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 4831-2408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2105
% INFO    : Updated Thermal Rating: on line 5655-2408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2632
% INFO    : Updated Thermal Rating: on line 3156-2409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185438
% INFO    : Updated Thermal Rating: on line 3156-2410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170405
% INFO    : Updated Thermal Rating: on line 5340-2411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 5454-2412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48031
% INFO    : Updated Thermal Rating: on line 4209-2414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 4209-2414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5445-2415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4620
% INFO    : Updated Thermal Rating: on line 2419-2416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 2504-2416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 3362-2416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2503
% INFO    : Updated Thermal Rating: on line 3438-2416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 5764-2416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 2504-2416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 5597-2419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 3001-2420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 3074-2420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 4712-2420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 4851-2420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 2423-2422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 4244-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 4734-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1192
% INFO    : Updated Thermal Rating: on line 5307-2423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 5453-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 5481-2423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 5482-2423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 5526-2423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 4244-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 4734-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1158
% INFO    : Updated Thermal Rating: on line 4244-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 4385-2426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 4675-2426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 3896-2427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5439-2427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 5706-2427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 3306-2430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 5565-2430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 4910-2432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 4910-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 3501-2433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 5696-2433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 3785-2434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 4018-2434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 4354-2434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 5227-2434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 5751-2434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5456-2436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 2587-2437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 2587-2438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 4770-2439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 5554-2439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 5143-2439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5126-2439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 5123-2439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 796
% INFO    : Updated Thermal Rating: on line 5536-2440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 826
% INFO    : Updated Thermal Rating: on line 3892-2442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 3892-2442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 2937-2443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 5440-2445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56971
% INFO    : Updated Thermal Rating: on line 3413-2446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 2559-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4369-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 2555-2450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 3085-2450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 4153-2450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 4206-2450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2157
% INFO    : Updated Thermal Rating: on line 5434-2450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 5670-2450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 4205-2450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2163
% INFO    : Updated Thermal Rating: on line 4649-2452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 5205-2452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2288
% INFO    : Updated Thermal Rating: on line 3331-2455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 3168-2456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 3642-2457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 5032-2457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 4970-2460 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1476
% INFO    : Updated Thermal Rating: on line 4232-2461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 4887-2461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2035
% INFO    : Updated Thermal Rating: on line 5449-2461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 4565-2463 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2130
% INFO    : Updated Thermal Rating: on line 4565-2463 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2130
% INFO    : Updated Thermal Rating: on line 2899-2464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 4448-2464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 4652-2464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 2827-2465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 3627-2465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 2482-2467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3563
% INFO    : Updated Thermal Rating: on line 2482-2466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2766
% INFO    : Updated Thermal Rating: on line 4561-2468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 4080-2469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 3844-2470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23430
% INFO    : Updated Thermal Rating: on line 4859-2470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 4857-2471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on line 5181-2472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22412
% INFO    : Updated Thermal Rating: on line 3734-2473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1514
% INFO    : Updated Thermal Rating: on line 2815-2475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 4259-2475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 4606-2475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2079
% INFO    : Updated Thermal Rating: on line 5108-2476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 2721-2479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3490-2480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 4749-2481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 5515-2481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 2827-2482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 3026-2482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 2827-2482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 3773-2483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104366
% INFO    : Updated Thermal Rating: on line 3772-2483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87644
% INFO    : Updated Thermal Rating: on line 4857-2484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5279-2484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 3584-2486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3292
% INFO    : Updated Thermal Rating: on line 4680-2488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 2717-2489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 2711-2492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 3000-2492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 4071-2492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 5159-2492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4710
% INFO    : Updated Thermal Rating: on line 5458-2493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1105
% INFO    : Updated Thermal Rating: on line 5440-2494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 2783-2494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 2773-2497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 2915-2498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 5459-2499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114924
% INFO    : Updated Thermal Rating: on line 4189-2500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 4857-2500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 5219-2500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5221-2500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 4857-2500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 4987-2501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 4987-2501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 3349-2502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 2829-2505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8065
% INFO    : Updated Thermal Rating: on line 5722-2505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 2828-2506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1359
% INFO    : Updated Thermal Rating: on line 4389-2506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1543
% INFO    : Updated Thermal Rating: on line 4000-2507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 4000-2507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 3244-2509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 3244-2509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 2710-2514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 4770-2514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 5159-2514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 5711-2515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1856
% INFO    : Updated Thermal Rating: on line 2529-2518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on line 5460-2518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 3383-2519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128418
% INFO    : Updated Thermal Rating: on line 4801-2520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3928-2521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 2552-2522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 5339-2522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 2552-2522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 2923-2523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on line 2526-2525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 2680-2526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 3653-2526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 4810-2526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 5464-2526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 5463-2528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83031
% INFO    : Updated Thermal Rating: on line 5750-2529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320
% INFO    : Updated Thermal Rating: on line 5460-2530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 781
% INFO    : Updated Thermal Rating: on line 2699-2531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 2888-2532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1550
% INFO    : Updated Thermal Rating: on line 3151-2532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 3151-2532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 4202-2534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 3475-2535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1013
% INFO    : Updated Thermal Rating: on line 5468-2537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1893
% INFO    : Updated Thermal Rating: on line 5497-2536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3707
% INFO    : Updated Thermal Rating: on line 2964-2538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 2964-2538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 5466-2539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2082
% INFO    : Updated Thermal Rating: on line 5467-2540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 3676-2541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 4728-2541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 612
% INFO    : Updated Thermal Rating: on line 4835-2541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 4728-2541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 5685-2542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 845
% INFO    : Updated Thermal Rating: on line 3903-2543 : Rate A, Rate B, Rate C , 482.0, 482.0, 482.0 -> 455
% INFO    : Updated Thermal Rating: on line 4168-2545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3181-2546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 4785-2547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on line 4785-2547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on line 2759-2548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 3657-2549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 3691-2549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 3370-2550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 4905-2550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 3834-2551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 4315-2551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 3639-2552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 5563-2552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 5564-2552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 5837-2552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 2621-2552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 5471-2555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5472-2556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on line 5473-2557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 3932-2558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 3999-2558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 3098-2559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 3816-2559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 4072-2559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 5246-2559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 5757-2559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 4101-2562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 584
% INFO    : Updated Thermal Rating: on line 4785-2562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5703-2563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1168
% INFO    : Updated Thermal Rating: on line 5701-2563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1111
% INFO    : Updated Thermal Rating: on line 3994-2565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 4358-2565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1147
% INFO    : Updated Thermal Rating: on line 5182-2567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12942
% INFO    : Updated Thermal Rating: on line 3001-2569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 3001-2569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 4330-2570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 5381-2570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 5744-2570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2532
% INFO    : Updated Thermal Rating: on line 5784-2570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 5247-2572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on line 3429-2574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 4133-2574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 2821-2575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 2617-2576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 566
% INFO    : Updated Thermal Rating: on line 4388-2576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5342
% INFO    : Updated Thermal Rating: on line 5103-2576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 4387-2576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5342
% INFO    : Updated Thermal Rating: on line 5102-2576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 2731-2578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 5743-2578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3162-2580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 5475-2581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5531
% INFO    : Updated Thermal Rating: on line 2977-2582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 3003-2583 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1547
% INFO    : Updated Thermal Rating: on line 2791-2583 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1476
% INFO    : Updated Thermal Rating: on line 3003-2583 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1547
% INFO    : Updated Thermal Rating: on line 2791-2583 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1479
% INFO    : Updated Thermal Rating: on line 3657-2584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 3657-2584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 5373-2585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 5623-2585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33358
% INFO    : Updated Thermal Rating: on line 5477-2586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 4395-2587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 4405-2587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4395-2587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 4405-2587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 5392-2589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5979
% INFO    : Updated Thermal Rating: on line 2593-2591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62462
% INFO    : Updated Thermal Rating: on line 4667-2591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 5478-2592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83282
% INFO    : Updated Thermal Rating: on line 3106-2594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 4046-2594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 3106-2594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 5479-2596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 3565-2597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on line 4440-2597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 2869-2598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 3219-2598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 3341-2598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 4064-2598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 3405-2601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 3402-2603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 3612-2604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 5026-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 5448-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 4785-2606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 3353-2607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1161
% INFO    : Updated Thermal Rating: on line 3969-2608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 4672-2608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 3017-2609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 5805-2609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 4857-2612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5087-2613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 5481-2614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 5482-2614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12845
% INFO    : Updated Thermal Rating: on line 2951-2615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5796-2615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7635
% INFO    : Updated Thermal Rating: on line 5797-2615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 2923-2618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 4582-2618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 5563-2621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1157
% INFO    : Updated Thermal Rating: on line 2630-2622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on line 3552-2622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on line 3883-2622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 2903-2623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 5240-2623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 5483-2625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1516
% INFO    : Updated Thermal Rating: on line 2782-2626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 3132-2626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 4599-2626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 4599-2627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 2943-2629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4061-2629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 3434-2630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5223-2631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5495-2632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3410
% INFO    : Updated Thermal Rating: on line 5824-2632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 5525-2633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8999
% INFO    : Updated Thermal Rating: on line 2637-2636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5212-2636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 5209-2637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 3495-2638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 4164-2638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 3644-2638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 4165-2641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2280
% INFO    : Updated Thermal Rating: on line 5536-2641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 684
% INFO    : Updated Thermal Rating: on line 5574-2641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3399
% INFO    : Updated Thermal Rating: on line 4986-2642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 5811-2642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 3761-2643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 3369-2644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 3482-2644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 4535-2645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2100
% INFO    : Updated Thermal Rating: on line 5181-2645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 4138-2647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4508-2647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 5347-2647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on line 2710-2650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 3445-2650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 3979-2651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 3680-2652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on line 2585-2653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 3523-2653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4031-2653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 5421-2653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on line 2585-2653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 3484-2659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1792
% INFO    : Updated Thermal Rating: on line 5680-2660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 5681-2660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 3504-2661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 4154-2661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1357
% INFO    : Updated Thermal Rating: on line 4875-2661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4350
% INFO    : Updated Thermal Rating: on line 3565-2665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 3565-2664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 4247-2666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 819
% INFO    : Updated Thermal Rating: on line 4882-2666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 4247-2666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 4393-2667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 5485-2668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on line 3875-2668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 2668-2670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 702
% INFO    : Updated Thermal Rating: on line 4350-2673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 3008-2674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1405
% INFO    : Updated Thermal Rating: on line 5392-2674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 5752-2674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 3008-2674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1431
% INFO    : Updated Thermal Rating: on line 3476-2676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 4690-2677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 5488-2679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2745
% INFO    : Updated Thermal Rating: on line 3753-2680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4775-2682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 3510-2683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 2685-2684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 5489-2684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24050
% INFO    : Updated Thermal Rating: on line 2827-2687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5788
% INFO    : Updated Thermal Rating: on line 3889-2689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 4727-2689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on line 4822-2691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 870
% INFO    : Updated Thermal Rating: on line 4314-2692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 3649-2693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 967
% INFO    : Updated Thermal Rating: on line 3168-2695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 4049-2695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22736
% INFO    : Updated Thermal Rating: on line 4662-2695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 4050-2695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17760
% INFO    : Updated Thermal Rating: on line 4893-2696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 486
% INFO    : Updated Thermal Rating: on line 5198-2696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1357
% INFO    : Updated Thermal Rating: on line 5826-2696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on line 2888-2699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 3831-2698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 4609-2699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on line 4860-2698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 5390-2698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 3922-2702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 3923-2703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3468
% INFO    : Updated Thermal Rating: on line 5493-2704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 3536-2706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 5160-2711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on line 5162-2711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 3022-2712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 4718-2713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46632
% INFO    : Updated Thermal Rating: on line 4717-2713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51447
% INFO    : Updated Thermal Rating: on line 4716-2713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51447
% INFO    : Updated Thermal Rating: on line 3657-2715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 3657-2715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 3576-2717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3320
% INFO    : Updated Thermal Rating: on line 4809-2717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 4809-2717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 971
% INFO    : Updated Thermal Rating: on line 3907-2719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 3593-2721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 5495-2722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1725
% INFO    : Updated Thermal Rating: on line 4139-2723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2715
% INFO    : Updated Thermal Rating: on line 4217-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 4949-2730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1465
% INFO    : Updated Thermal Rating: on line 4949-2729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3204
% INFO    : Updated Thermal Rating: on line 3670-2731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 5641-2732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17478
% INFO    : Updated Thermal Rating: on line 3637-2735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 3806-2736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 4983-2736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 3114-2737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3113-2737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3112-2737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4621-2738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1246
% INFO    : Updated Thermal Rating: on line 3415-2739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 2937-2741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8159
% INFO    : Updated Thermal Rating: on line 4723-2743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 4779-2743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 5100-2743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 4779-2743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 2838-2746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 4196-2746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5525
% INFO    : Updated Thermal Rating: on line 4417-2746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 5093-2746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 5728-2746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2177
% INFO    : Updated Thermal Rating: on line 4195-2746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4439
% INFO    : Updated Thermal Rating: on line 3502-2747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 937
% INFO    : Updated Thermal Rating: on line 5500-2748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3615
% INFO    : Updated Thermal Rating: on line 3417-2749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 4797-2749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 5497-2750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27575
% INFO    : Updated Thermal Rating: on line 3655-2751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1684
% INFO    : Updated Thermal Rating: on line 5496-2753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9377
% INFO    : Updated Thermal Rating: on line 5501-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6271
% INFO    : Updated Thermal Rating: on line 4903-2756 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1264
% INFO    : Updated Thermal Rating: on line 4620-2757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 3359-2758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 3359-2758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 5498-2759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 5678-2760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5377-2760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1617
% INFO    : Updated Thermal Rating: on line 2833-2762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 624
% INFO    : Updated Thermal Rating: on line 3254-2762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 917
% INFO    : Updated Thermal Rating: on line 4275-2762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 4402-2762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 4899-2762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 5809-2762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 4275-2762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 5231-2762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 3009-2763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 5493-2765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 5766-2765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 3895-2767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 5074-2767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 3801-2769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 5128-2769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 4000-2771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 2954-2772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 3323-2772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1383
% INFO    : Updated Thermal Rating: on line 5433-2773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5443-2773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 5444-2773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 5590-2773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 3323-2772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 3349-2773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 3477-2776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on line 5413-2780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 4852-2781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 4852-2781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 4599-2782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 4062-2783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 5440-2783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 5461-2783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 5462-2783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 4062-2783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 4055-2785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 4949-2786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 3850-2792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on line 4190-2793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 4857-2794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 3790-2795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11330
% INFO    : Updated Thermal Rating: on line 3916-2795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 5242-2795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 3662-2798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 724
% INFO    : Updated Thermal Rating: on line 4919-2800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 5448-2800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 3691-2801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10480
% INFO    : Updated Thermal Rating: on line 3504-2802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 4167-2802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 4371-2802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1659
% INFO    : Updated Thermal Rating: on line 4247-2804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 5506-2806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12969
% INFO    : Updated Thermal Rating: on line 3300-2807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 4363-2807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10216
% INFO    : Updated Thermal Rating: on line 4386-2807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 5030-2807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 5289-2807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1039
% INFO    : Updated Thermal Rating: on line 5545-2807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 5547-2807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on line 5561-2807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 5029-2807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 2937-2809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5742-2809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 4713-2811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 5204-2811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5450-2811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 4338-2812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1278
% INFO    : Updated Thermal Rating: on line 4306-2816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 4326-2816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 5441-2817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 3704-2818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25728
% INFO    : Updated Thermal Rating: on line 3175-2822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 3839-2822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1415
% INFO    : Updated Thermal Rating: on line 5313-2822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 803
% INFO    : Updated Thermal Rating: on line 5809-2822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 640
% INFO    : Updated Thermal Rating: on line 5664-2826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4389-2828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1620
% INFO    : Updated Thermal Rating: on line 5507-2830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 3338-2832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5085-2833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3170
% INFO    : Updated Thermal Rating: on line 5257-2835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1862
% INFO    : Updated Thermal Rating: on line 5383-2836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5511-2837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114403
% INFO    : Updated Thermal Rating: on line 2946-2838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 4556-2838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 5721-2840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 5243-2843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 5513-2843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5782-2846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 5516-2848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309124
% INFO    : Updated Thermal Rating: on line 5515-2849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27511
% INFO    : Updated Thermal Rating: on line 5514-2851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1734
% INFO    : Updated Thermal Rating: on line 5514-2852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12072
% INFO    : Updated Thermal Rating: on line 3392-2854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 3749-2856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on line 5328-2856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 830
% INFO    : Updated Thermal Rating: on line 5776-2856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 2989-2860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2246
% INFO    : Updated Thermal Rating: on line 4842-2858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2395
% INFO    : Updated Thermal Rating: on line 4842-2859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2672
% INFO    : Updated Thermal Rating: on line 5519-2861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23932
% INFO    : Updated Thermal Rating: on line 4678-2862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38824
% INFO    : Updated Thermal Rating: on line 4440-2863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 5521-2866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5072
% INFO    : Updated Thermal Rating: on line 4925-2867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 3269-2868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1823
% INFO    : Updated Thermal Rating: on line 5609-2869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 5523-2870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1925
% INFO    : Updated Thermal Rating: on line 5522-2871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on line 3030-2875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 3068-2876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 3001-2877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 5308-2878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1275
% INFO    : Updated Thermal Rating: on line 5524-2878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12709
% INFO    : Updated Thermal Rating: on line 3028-2879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 5525-2879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 4285-2880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 4577-2881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 4560-2882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2161
% INFO    : Updated Thermal Rating: on line 4632-2886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2130
% INFO    : Updated Thermal Rating: on line 4633-2886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2147
% INFO    : Updated Thermal Rating: on line 3319-2887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1449
% INFO    : Updated Thermal Rating: on line 5646-2887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2579
% INFO    : Updated Thermal Rating: on line 4008-2888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 3174-2889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 5526-2890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6565
% INFO    : Updated Thermal Rating: on line 3836-2891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5026-2891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 5483-2891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 5528-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7065
% INFO    : Updated Thermal Rating: on line 5527-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7639
% INFO    : Updated Thermal Rating: on line 5673-2896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on line 4711-2897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5259
% INFO    : Updated Thermal Rating: on line 4124-2898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 2902-2901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on line 5613-2903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1565
% INFO    : Updated Thermal Rating: on line 3892-2904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5397-2904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 4849-2906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4458-2907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on line 2913-2911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 3785-2912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3282
% INFO    : Updated Thermal Rating: on line 3922-2913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 4245-2913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 5769-2913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1602
% INFO    : Updated Thermal Rating: on line 4909-2916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4935-2916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 3842-2917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 3842-2917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 3078-2918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 4374-2919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7146
% INFO    : Updated Thermal Rating: on line 3290-2920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 5530-2921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32501
% INFO    : Updated Thermal Rating: on line 3206-2923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 3674-2923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 3092-2927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 5771-2927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3841-2929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 4990-2928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 5600-2929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1171
% INFO    : Updated Thermal Rating: on line 3841-2928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 5602-2928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 5533-2931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18638
% INFO    : Updated Thermal Rating: on line 5281-2933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 5835-2933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 4840-2934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 3232-2937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 5017-2937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2126
% INFO    : Updated Thermal Rating: on line 5073-2937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on line 3959-2939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1675
% INFO    : Updated Thermal Rating: on line 4920-2939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1964
% INFO    : Updated Thermal Rating: on line 3233-2943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 5059-2943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5435-2943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 751
% INFO    : Updated Thermal Rating: on line 4417-2946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 5045-2947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 5665-2947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 4338-2948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4234-2949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 5535-2951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 5536-2952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35735
% INFO    : Updated Thermal Rating: on line 4663-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1271
% INFO    : Updated Thermal Rating: on line 5537-2963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10795
% INFO    : Updated Thermal Rating: on line 3990-2964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 4901-2964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 5208-2964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 3989-2964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 3033-2966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 5193-2966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 3974-2967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 4249-2967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 5539-2968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6352
% INFO    : Updated Thermal Rating: on line 5609-2970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 5632-2970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 3307-2971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 3595-2972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 4348-2972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 5456-2972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 5597-2972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 5634-2973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1095
% INFO    : Updated Thermal Rating: on line 3996-2976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4892
% INFO    : Updated Thermal Rating: on line 3396-2977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 4088-2977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 4359-2977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 5139-2977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 5839-2977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 4088-2977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 3477-2979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 4047-2981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1082
% INFO    : Updated Thermal Rating: on line 4152-2981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 5245-2981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1412
% INFO    : Updated Thermal Rating: on line 5732-2981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 3546-2983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52855
% INFO    : Updated Thermal Rating: on line 4976-2984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 5658-2984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 4102-2986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 503
% INFO    : Updated Thermal Rating: on line 4786-2986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 3280-2989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1032
% INFO    : Updated Thermal Rating: on line 3672-2988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 4307-2988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5196
% INFO    : Updated Thermal Rating: on line 5533-2988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 5637-2988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1391
% INFO    : Updated Thermal Rating: on line 5639-2989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1292
% INFO    : Updated Thermal Rating: on line 4762-2992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 5610-2992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 4762-2992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 3167-2994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 5161-2994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 5765-2994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3039-2994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 3167-2994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 3670-2996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 3459-2998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 5037-3001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 5109-3001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 3074-3004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 3670-3005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 4771-3006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on line 4771-3006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on line 5445-3008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 591
% INFO    : Updated Thermal Rating: on line 4921-3010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 5161-3011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56971
% INFO    : Updated Thermal Rating: on line 5569-3011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 4783-3012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 3535-3013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 4764-3013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 5543-3015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28670
% INFO    : Updated Thermal Rating: on line 5768-3016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9667
% INFO    : Updated Thermal Rating: on line 5774-3016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1648
% INFO    : Updated Thermal Rating: on line 3512-3020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 5583-3022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 5018-3023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 5129-3023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 3589-3026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 3392-3027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4713-3028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on line 3475-3032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 978
% INFO    : Updated Thermal Rating: on line 4456-3033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4504-3033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 4630-3033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 4857-3034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7065
% INFO    : Updated Thermal Rating: on line 4857-3035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 4857-3035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 4221-3036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1597
% INFO    : Updated Thermal Rating: on line 4834-3036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3304-3037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 4294-3037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2337
% INFO    : Updated Thermal Rating: on line 4806-3041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 4577-3042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 613
% INFO    : Updated Thermal Rating: on line 3056-3043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 3261-3045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 3489-3046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 5549-3052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 5188-3058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5297-3058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 3666-3059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1766
% INFO    : Updated Thermal Rating: on line 3970-3059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1183
% INFO    : Updated Thermal Rating: on line 4949-3060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1326
% INFO    : Updated Thermal Rating: on line 3670-3064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 4327-3066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 5315-3066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 5627-3066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 5648-3068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 822
% INFO    : Updated Thermal Rating: on line 4761-3069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 5817-3069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6858
% INFO    : Updated Thermal Rating: on line 4791-3069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2345
% INFO    : Updated Thermal Rating: on line 5552-3070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1047
% INFO    : Updated Thermal Rating: on line 3194-3071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 4765-3072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5428-3072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240340
% INFO    : Updated Thermal Rating: on line 5150-3073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2621
% INFO    : Updated Thermal Rating: on line 4652-3076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 5221-3077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5727-3077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 3701-3078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 5354-3078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 5367-3078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 3306-3080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 5651-3080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 5252-3082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 3959-3083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 5134-3084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 5619-3084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 4067-3085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 4993-3088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 3554-3089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1162
% INFO    : Updated Thermal Rating: on line 3337-3091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 4946-3093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5248-3093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 4913-3096 : Rate A, Rate B, Rate C , 1617.0, 1617.0, 1617.0 -> 1275
% INFO    : Updated Thermal Rating: on line 3680-3100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 3680-3099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 3450-3101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 5369-3101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 5349-3101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 846
% INFO    : Updated Thermal Rating: on line 3670-3104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 3670-3104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 3262-3105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 5575-3105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 3544-3106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 3752-3106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 4385-3106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 4752-3106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 5615-3106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on line 5472-3106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4850-3108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 5085-3107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 5276-3108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 4956-3107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 5557-3115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2570
% INFO    : Updated Thermal Rating: on line 3501-3116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3688
% INFO    : Updated Thermal Rating: on line 5558-3118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 4344-3119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 5604-3120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 5808-3120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 5599-3120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 3171-3121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 2923-3122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3804-3122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 4260-3124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5215
% INFO    : Updated Thermal Rating: on line 5110-3124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 4355-3125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 4971-3127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 5561-3129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4490
% INFO    : Updated Thermal Rating: on line 4604-3132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on line 3157-3134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 882
% INFO    : Updated Thermal Rating: on line 3921-3134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 3157-3134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 5351-3135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1975
% INFO    : Updated Thermal Rating: on line 5562-3136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7254
% INFO    : Updated Thermal Rating: on line 3139-3137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310318
% INFO    : Updated Thermal Rating: on line 3894-3138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 4967-3138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 5090-3138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 4966-3138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 3977-3140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 5837-3140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on line 5769-3141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 3870-3144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 3881-3145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 4122-3145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 208
% INFO    : Updated Thermal Rating: on line 5011-3145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 5040-3145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36728
% INFO    : Updated Thermal Rating: on line 4898-3147 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1005
% INFO    : Updated Thermal Rating: on line 4898-3146 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1006
% INFO    : Updated Thermal Rating: on line 5060-3150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3291
% INFO    : Updated Thermal Rating: on line 3593-3152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 4885-3152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 3251-3153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 3519-3153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10278
% INFO    : Updated Thermal Rating: on line 3268-3154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 486
% INFO    : Updated Thermal Rating: on line 3378-3157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 4425-3157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 5195-3157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 5483-3157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 5563-3159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2328
% INFO    : Updated Thermal Rating: on line 4517-3162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2877
% INFO    : Updated Thermal Rating: on line 5495-3162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 5565-3163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18302
% INFO    : Updated Thermal Rating: on line 5566-3164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23670
% INFO    : Updated Thermal Rating: on line 4715-3165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 5335-3165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 3664-3166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 5569-3167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23551
% INFO    : Updated Thermal Rating: on line 4662-3168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 4955-3169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on line 5617-3170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 3259-3171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 3389-3176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on line 4101-3177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 4631-3177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 5571-3178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5113-3178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 4878-3179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5572-3180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 5607-3181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 5778-3181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on line 4281-3183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 5368-3183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2606
% INFO    : Updated Thermal Rating: on line 4391-3184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37253
% INFO    : Updated Thermal Rating: on line 3507-3186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4242-3188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 4302-3189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 4683-3189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3321
% INFO    : Updated Thermal Rating: on line 5230-3190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 5345-3190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4302-3189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 5553-3194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1740
% INFO    : Updated Thermal Rating: on line 3873-3197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93975
% INFO    : Updated Thermal Rating: on line 3874-3198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102466
% INFO    : Updated Thermal Rating: on line 5491-3199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 4619-3200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 5261-3201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1932
% INFO    : Updated Thermal Rating: on line 4209-3202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2662
% INFO    : Updated Thermal Rating: on line 4492-3202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4328
% INFO    : Updated Thermal Rating: on line 5574-3203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42408
% INFO    : Updated Thermal Rating: on line 3262-3204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 5576-3207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 4863-3211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1295
% INFO    : Updated Thermal Rating: on line 5570-3212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 3817-3213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 3915-3213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 3916-3213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 4949-3214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7828
% INFO    : Updated Thermal Rating: on line 3293-3215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 4221-3215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 3292-3216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 4220-3216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 4758-3217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 5817-3217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 3814-3219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 3623-3221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1285
% INFO    : Updated Thermal Rating: on line 5481-3222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 3420-3226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64823
% INFO    : Updated Thermal Rating: on line 3420-3225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64823
% INFO    : Updated Thermal Rating: on line 3420-3224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52241
% INFO    : Updated Thermal Rating: on line 4600-3228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 4601-3227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 5435-3233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 5530-3234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 4173-3235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 914
% INFO    : Updated Thermal Rating: on line 4257-3237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 5270-3237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 774
% INFO    : Updated Thermal Rating: on line 5323-3238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 4627-3239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 5021-3239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 5579-3240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 5580-3241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7124
% INFO    : Updated Thermal Rating: on line 4609-3242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 3429-3243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 4313-3243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 5557-3243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 5830-3244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 611
% INFO    : Updated Thermal Rating: on line 5745-3244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 4780-3245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1019
% INFO    : Updated Thermal Rating: on line 5640-3245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1246
% INFO    : Updated Thermal Rating: on line 3643-3248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3058
% INFO    : Updated Thermal Rating: on line 3643-3247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3058
% INFO    : Updated Thermal Rating: on line 3643-3249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3099
% INFO    : Updated Thermal Rating: on line 3430-3251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 4439-3251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 5187-3251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 4785-3253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 5313-3254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 4665-3255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on line 5581-3257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1522
% INFO    : Updated Thermal Rating: on line 4551-3259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 3940-3260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107251
% INFO    : Updated Thermal Rating: on line 4228-3262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 864
% INFO    : Updated Thermal Rating: on line 4764-3265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 5104-3267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 5122-3267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 5534-3267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 4467-3269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 3277-3271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2012
% INFO    : Updated Thermal Rating: on line 3645-3271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1065
% INFO    : Updated Thermal Rating: on line 5606-3271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 3276-3271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2012
% INFO    : Updated Thermal Rating: on line 3645-3271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3487
% INFO    : Updated Thermal Rating: on line 5605-3271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 4030-3280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15045
% INFO    : Updated Thermal Rating: on line 4861-3287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5584-3288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1885
% INFO    : Updated Thermal Rating: on line 3493-3290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 577
% INFO    : Updated Thermal Rating: on line 3861-3290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 4644-3293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 4644-3292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 4267-3294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 927
% INFO    : Updated Thermal Rating: on line 3392-3295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 4538-3295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3284
% INFO    : Updated Thermal Rating: on line 3392-3295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 4406-3296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 643
% INFO    : Updated Thermal Rating: on line 5397-3297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 4199-3299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 5162-3301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 5747-3301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 5824-3302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23932
% INFO    : Updated Thermal Rating: on line 4294-3304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 708
% INFO    : Updated Thermal Rating: on line 5372-3304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 5576-3304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 5741-3304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 3683-3305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14024
% INFO    : Updated Thermal Rating: on line 4815-3307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3198
% INFO    : Updated Thermal Rating: on line 5167-3308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 5730-3308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5300-3314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2154
% INFO    : Updated Thermal Rating: on line 5682-3314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 691
% INFO    : Updated Thermal Rating: on line 3905-3315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on line 3527-3316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308192
% INFO    : Updated Thermal Rating: on line 3526-3316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308192
% INFO    : Updated Thermal Rating: on line 3842-3317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1417
% INFO    : Updated Thermal Rating: on line 3421-3319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 516
% INFO    : Updated Thermal Rating: on line 4275-3320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6319
% INFO    : Updated Thermal Rating: on line 5461-3324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 5566-3324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on line 4842-3326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13848
% INFO    : Updated Thermal Rating: on line 4842-3325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7105
% INFO    : Updated Thermal Rating: on line 4279-3328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 5033-3328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5316-3328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 5586-3330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 5240-3332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 5027-3334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3901
% INFO    : Updated Thermal Rating: on line 5027-3333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3901
% INFO    : Updated Thermal Rating: on line 4434-3336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5234-3337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11822
% INFO    : Updated Thermal Rating: on line 5344-3338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 5609-3341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1178
% INFO    : Updated Thermal Rating: on line 3765-3342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 4605-3342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 5086-3342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1257
% INFO    : Updated Thermal Rating: on line 3765-3342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 5629-3342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 5762-3342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 5591-3347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 5592-3347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 3349-3348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on line 5590-3349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 5589-3350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5477-3351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 789
% INFO    : Updated Thermal Rating: on line 4954-3351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 3925-3352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1443
% INFO    : Updated Thermal Rating: on line 3925-3352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1278
% INFO    : Updated Thermal Rating: on line 5319-3354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 3480-3358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4964
% INFO    : Updated Thermal Rating: on line 4660-3358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 4660-3358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 4573-3359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 533
% INFO    : Updated Thermal Rating: on line 4173-3363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 4173-3363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 5598-3368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5115-3369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 5216-3369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 503
% INFO    : Updated Thermal Rating: on line 5600-3371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1519
% INFO    : Updated Thermal Rating: on line 5601-3372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241598
% INFO    : Updated Thermal Rating: on line 3828-3373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 4329-3373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 5718-3373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 3828-3373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 4398-3375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 5532-3376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 815
% INFO    : Updated Thermal Rating: on line 5531-3377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 805
% INFO    : Updated Thermal Rating: on line 5083-3379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 3892-3380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 3892-3380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 5131-3381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 3878-3384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 865
% INFO    : Updated Thermal Rating: on line 4833-3384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 3915-3389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 5532-3389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 3916-3389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 5531-3389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 4285-3391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 3534-3392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 4325-3392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 5294-3392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 5507-3392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 5605-3395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3799
% INFO    : Updated Thermal Rating: on line 5476-3396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 929
% INFO    : Updated Thermal Rating: on line 3398-3397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4524
% INFO    : Updated Thermal Rating: on line 4123-3399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 5607-3401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46388
% INFO    : Updated Thermal Rating: on line 4053-3404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 3904-3408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 5610-3410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2846
% INFO    : Updated Thermal Rating: on line 4448-3411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1072
% INFO    : Updated Thermal Rating: on line 3973-3412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 979
% INFO    : Updated Thermal Rating: on line 4027-3412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 3973-3412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 979
% INFO    : Updated Thermal Rating: on line 4138-3413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 5755-3414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 5271-3415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 5546-3415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 4100-3416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 4319-3417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 5405-3419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 3728-3422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 3885-3422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 5119-3424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 4340-3425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 5386-3425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 4340-3425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 5614-3427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 3517-3430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 4602-3432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 5578-3432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 3764-3434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 4911-3435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 5615-3436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 3440-3437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 4233-3437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on line 4674-3437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 5764-3438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5616-3439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13444
% INFO    : Updated Thermal Rating: on line 4674-3440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 4674-3441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5133-3442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1334
% INFO    : Updated Thermal Rating: on line 5617-3444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on line 5226-3446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5227-3446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5334-3446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 5791-3447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 4914-3448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2162
% INFO    : Updated Thermal Rating: on line 4960-3448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1531
% INFO    : Updated Thermal Rating: on line 4960-3448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1541
% INFO    : Updated Thermal Rating: on line 5618-3449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 634
% INFO    : Updated Thermal Rating: on line 3548-3450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 5529-3452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1834
% INFO    : Updated Thermal Rating: on line 4005-3453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1378
% INFO    : Updated Thermal Rating: on line 5767-3454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 5619-3455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 4771-3456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 5264-3459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 5620-3461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10014
% INFO    : Updated Thermal Rating: on line 3507-3462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 3475-3466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6987
% INFO    : Updated Thermal Rating: on line 3475-3468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10050
% INFO    : Updated Thermal Rating: on line 3475-3465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10699
% INFO    : Updated Thermal Rating: on line 3475-3467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13403
% INFO    : Updated Thermal Rating: on line 4871-3474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3633
% INFO    : Updated Thermal Rating: on line 4871-3473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3633
% INFO    : Updated Thermal Rating: on line 5320-3475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 5369-3475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 5468-3475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2203
% INFO    : Updated Thermal Rating: on line 5349-3475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 5497-3475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1384
% INFO    : Updated Thermal Rating: on line 5548-3475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1318
% INFO    : Updated Thermal Rating: on line 3712-3477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 4393-3479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 4406-3479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 3538-3481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 4115-3481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 5540-3483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2546
% INFO    : Updated Thermal Rating: on line 5621-3485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 4310-3487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 4399-3487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5474-3487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5475-3487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 5622-3488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 4380-3490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 4744-3490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5096-3490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1605
% INFO    : Updated Thermal Rating: on line 4380-3490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 3560-3491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5045-3491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 5045-3491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 5623-3492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 3861-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 5268-3499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28417
% INFO    : Updated Thermal Rating: on line 5627-3500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2143
% INFO    : Updated Thermal Rating: on line 4002-3501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 4561-3501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 5093-3501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 5625-3501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3446
% INFO    : Updated Thermal Rating: on line 4602-3503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 936
% INFO    : Updated Thermal Rating: on line 4781-3504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 4008-3505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on line 3870-3506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 3973-3507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 4828-3507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 5789-3507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 3973-3507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 3973-3507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 4026-3510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 4026-3510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 3828-3512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 743
% INFO    : Updated Thermal Rating: on line 4544-3515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 5000-3514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 602
% INFO    : Updated Thermal Rating: on line 5376-3515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 5780-3514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 761
% INFO    : Updated Thermal Rating: on line 4416-3523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 5629-3525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7266
% INFO    : Updated Thermal Rating: on line 5631-3528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21242
% INFO    : Updated Thermal Rating: on line 4164-3529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2259
% INFO    : Updated Thermal Rating: on line 4808-3531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4085
% INFO    : Updated Thermal Rating: on line 5060-3531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 5422-3531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6818
% INFO    : Updated Thermal Rating: on line 5820-3534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 4052-3538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 4115-3538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 5413-3538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5634-3541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 4338-3543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 5068-3543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1049
% INFO    : Updated Thermal Rating: on line 4338-3543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on line 5635-3545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20555
% INFO    : Updated Thermal Rating: on line 5008-3546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23178
% INFO    : Updated Thermal Rating: on line 4352-3547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 4883-3548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5168-3548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 5468-3548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 5520-3548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 5697-3548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 5172-3548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on line 4510-3551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1867
% INFO    : Updated Thermal Rating: on line 4881-3552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 4881-3552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 3557-3554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 4009-3559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 4208-3559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 5328-3560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 5122-3561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 4715-3562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 4663-3563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 4002-3564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 4561-3564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 4002-3564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 208
% INFO    : Updated Thermal Rating: on line 3974-3565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 3363-3569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 5622-3569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 4511-3575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 5707-3575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 3837-3577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5982
% INFO    : Updated Thermal Rating: on line 5275-3577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 5333-3577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 5827-3577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 4644-3578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5637-3581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52417
% INFO    : Updated Thermal Rating: on line 5639-3582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 3384-3583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1249
% INFO    : Updated Thermal Rating: on line 3878-3583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1864
% INFO    : Updated Thermal Rating: on line 5638-3585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151236
% INFO    : Updated Thermal Rating: on line 5470-3586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20343
% INFO    : Updated Thermal Rating: on line 3423-3587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5006
% INFO    : Updated Thermal Rating: on line 3979-3587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 3502-3588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 5447-3588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6284
% INFO    : Updated Thermal Rating: on line 3734-3589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 5446-3592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 5360-3593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on line 5561-3593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 994
% INFO    : Updated Thermal Rating: on line 4297-3595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 872
% INFO    : Updated Thermal Rating: on line 5597-3595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 5297-3599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1641
% INFO    : Updated Thermal Rating: on line 4225-3601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 4183-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 4610-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5616-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1476
% INFO    : Updated Thermal Rating: on line 5643-3604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 3388-3607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on line 4502-3611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 5192-3610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3129
% INFO    : Updated Thermal Rating: on line 3399-3612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 3399-3612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on line 3356-3614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 5794-3614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 3356-3614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 4609-3615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 5645-3618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6375
% INFO    : Updated Thermal Rating: on line 3623-3620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15535
% INFO    : Updated Thermal Rating: on line 3623-3619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15535
% INFO    : Updated Thermal Rating: on line 4735-3622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 4735-3621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on line 5318-3623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2951
% INFO    : Updated Thermal Rating: on line 5577-3623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2460
% INFO    : Updated Thermal Rating: on line 4464-3623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42115
% INFO    : Updated Thermal Rating: on line 3457-3623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12856
% INFO    : Updated Thermal Rating: on line 3872-3625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 5330-3627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 4093-3627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 5801-3629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1778
% INFO    : Updated Thermal Rating: on line 4064-3630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5511-3633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1789
% INFO    : Updated Thermal Rating: on line 5510-3634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1815
% INFO    : Updated Thermal Rating: on line 5646-3636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23932
% INFO    : Updated Thermal Rating: on line 4795-3638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 5564-3639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 5200-3640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2428
% INFO    : Updated Thermal Rating: on line 3524-3643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2305
% INFO    : Updated Thermal Rating: on line 3647-3643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 3851-3643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2710
% INFO    : Updated Thermal Rating: on line 3647-3643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 4164-3644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 4481-3646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 4480-3646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 5555-3650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on line 3652-3651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5241
% INFO    : Updated Thermal Rating: on line 3976-3651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2045
% INFO    : Updated Thermal Rating: on line 3976-3652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7695
% INFO    : Updated Thermal Rating: on line 5758-3654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 621
% INFO    : Updated Thermal Rating: on line 3668-3655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1413
% INFO    : Updated Thermal Rating: on line 3669-3655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 4208-3655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 3691-3657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 4428-3657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58788
% INFO    : Updated Thermal Rating: on line 5615-3657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 5472-3657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 4415-3659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1278
% INFO    : Updated Thermal Rating: on line 5189-3659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 5647-3660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2723
% INFO    : Updated Thermal Rating: on line 4681-3661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 3686-3662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 3884-3664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 3996-3666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 4151-3666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13072
% INFO    : Updated Thermal Rating: on line 4120-3670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 4552-3671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 4842-3673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 724
% INFO    : Updated Thermal Rating: on line 3304-3677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 5576-3677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 5651-3678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3062
% INFO    : Updated Thermal Rating: on line 5411-3680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 762
% INFO    : Updated Thermal Rating: on line 5652-3680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5671-3680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 4939-3680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 973
% INFO    : Updated Thermal Rating: on line 4610-3682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 4314-3687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 4602-3687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 5549-3688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 4909-3689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 4173-3692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 5436-3692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2893
% INFO    : Updated Thermal Rating: on line 4173-3692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 4222-3693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 4454-3694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 5657-3695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5986
% INFO    : Updated Thermal Rating: on line 4490-3703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5613
% INFO    : Updated Thermal Rating: on line 4489-3703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1925
% INFO    : Updated Thermal Rating: on line 4170-3706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 4783-3706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 4305-3707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109898
% INFO    : Updated Thermal Rating: on line 5658-3708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 4910-3710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 5659-3711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22757
% INFO    : Updated Thermal Rating: on line 4356-3715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 5083-3719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1736
% INFO    : Updated Thermal Rating: on line 5094-3719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5661-3722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47367
% INFO    : Updated Thermal Rating: on line 4321-3723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 5660-3725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on line 5762-3724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 4257-3726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 3714-3728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10480
% INFO    : Updated Thermal Rating: on line 4420-3728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 4532-3728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 4420-3728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 3718-3730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138682
% INFO    : Updated Thermal Rating: on line 3717-3730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138682
% INFO    : Updated Thermal Rating: on line 3716-3730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123245
% INFO    : Updated Thermal Rating: on line 4788-3733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9077
% INFO    : Updated Thermal Rating: on line 3864-3738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29661
% INFO    : Updated Thermal Rating: on line 5394-3739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on line 5662-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 824
% INFO    : Updated Thermal Rating: on line 4802-3745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5663-3746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 5180-3747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 653
% INFO    : Updated Thermal Rating: on line 5427-3749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1308
% INFO    : Updated Thermal Rating: on line 4483-3750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 4521-3750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on line 5664-3754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10170
% INFO    : Updated Thermal Rating: on line 3851-3755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 3867-3755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 4709-3755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 5053-3755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 4321-3757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 5403-3758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 4612-3764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 4380-3764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on line 5496-3765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 5825-3765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 4722-3765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 5035-3767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 4719-3786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 890
% INFO    : Updated Thermal Rating: on line 5683-3786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 4434-3787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 864
% INFO    : Updated Thermal Rating: on line 5587-3787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2081
% INFO    : Updated Thermal Rating: on line 4447-3788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 5802-3788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on line 4112-3791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 5667-3792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 4814-3794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 4816-3794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1851
% INFO    : Updated Thermal Rating: on line 4813-3794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 4070-3796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40590
% INFO    : Updated Thermal Rating: on line 4070-3795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42124
% INFO    : Updated Thermal Rating: on line 3987-3801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3801
% INFO    : Updated Thermal Rating: on line 4274-3801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 4365-3801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on line 5190-3801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5506-3801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 3987-3801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3774
% INFO    : Updated Thermal Rating: on line 4904-3803 : Rate A, Rate B, Rate C , 1708.0, 1708.0, 1708.0 -> 1115
% INFO    : Updated Thermal Rating: on line 4072-3806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 3813-3807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3812-3807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 3811-3807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4072-3816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 5241-3817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1495
% INFO    : Updated Thermal Rating: on line 4110-3818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 4149-3820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20973
% INFO    : Updated Thermal Rating: on line 3877-3823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 3967-3823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 773
% INFO    : Updated Thermal Rating: on line 4322-3822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on line 3966-3822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on line 4322-3823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 5058-3827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 4535-3829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 5272-3830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2711
% INFO    : Updated Thermal Rating: on line 4991-3831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 5084-3831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 5459-3832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 5504-3832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 5130-3834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 5671-3834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 3882-3835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 4275-3839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2168
% INFO    : Updated Thermal Rating: on line 5673-3840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1253
% INFO    : Updated Thermal Rating: on line 5442-3842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 4341-3847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 5786-3847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 5787-3846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 4963-3850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 5504-3850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on line 5675-3853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53230
% INFO    : Updated Thermal Rating: on line 5674-3852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67907
% INFO    : Updated Thermal Rating: on line 5755-3855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5676-3856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3817
% INFO    : Updated Thermal Rating: on line 4723-3859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 3867-3863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 4500-3865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 4929-3865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 5332-3865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 5677-3869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5678-3869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 4948-3870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 4948-3870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 4308-3875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 5679-3876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11206
% INFO    : Updated Thermal Rating: on line 4505-3882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 4612-3883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 5378-3883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 4245-3886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32501
% INFO    : Updated Thermal Rating: on line 5804-3888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 5617-3892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 4581-3895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 4385-3896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 4656-3899 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1811
% INFO    : Updated Thermal Rating: on line 4656-3899 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1825
% INFO    : Updated Thermal Rating: on line 4435-3902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on line 5522-3907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 4092-3908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 5049-3908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5228-3908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 5709-3908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 5684-3910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 4749-3911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 906
% INFO    : Updated Thermal Rating: on line 4027-3914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 5789-3914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 4827-3916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 4827-3915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 5685-3920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 4500-3922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 634
% INFO    : Updated Thermal Rating: on line 5110-3922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1971
% INFO    : Updated Thermal Rating: on line 3988-3923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7269
% INFO    : Updated Thermal Rating: on line 5731-3936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 5764-3936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 4102-3937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 5408-3943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 4006-3946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 4006-3947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4542
% INFO    : Updated Thermal Rating: on line 5263-3948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on line 3952-3951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on line 4454-3951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 5169-3951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1164
% INFO    : Updated Thermal Rating: on line 4558-3953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 4608-3956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23861
% INFO    : Updated Thermal Rating: on line 5167-3956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on line 5427-3956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 5790-3956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24089
% INFO    : Updated Thermal Rating: on line 5691-3957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 4920-3959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 969
% INFO    : Updated Thermal Rating: on line 5690-3964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 4077-3969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 4077-3969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 5317-3971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 4190-3973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 5097-3973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 4998-3974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 5693-3978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3660
% INFO    : Updated Thermal Rating: on line 4916-3980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5076-3981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 5521-3982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 4921-3984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 5694-3985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 811
% INFO    : Updated Thermal Rating: on line 5344-3986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5696-3991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2220
% INFO    : Updated Thermal Rating: on line 4692-3992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 4357-3993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 5815-3995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4305-3996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 4461-3996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3258
% INFO    : Updated Thermal Rating: on line 5496-3998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 952
% INFO    : Updated Thermal Rating: on line 4326-4000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 4360-4000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 5478-4002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 5237-4005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 5204-4007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5408-4013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 5480-4015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16838
% INFO    : Updated Thermal Rating: on line 5567-4015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 4602-4016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 4602-4016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 5226-4018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 4452-4022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 5146-4022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22412
% INFO    : Updated Thermal Rating: on line 4452-4022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 5145-4022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22412
% INFO    : Updated Thermal Rating: on line 4678-4023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 5701-4025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24434
% INFO    : Updated Thermal Rating: on line 5089-4028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 899
% INFO    : Updated Thermal Rating: on line 4895-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 5704-4036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23993
% INFO    : Updated Thermal Rating: on line 4370-4037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3027
% INFO    : Updated Thermal Rating: on line 5785-4037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37370
% INFO    : Updated Thermal Rating: on line 5425-4042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1772
% INFO    : Updated Thermal Rating: on line 4713-4051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 5705-4054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56492
% INFO    : Updated Thermal Rating: on line 4300-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 4539-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2760
% INFO    : Updated Thermal Rating: on line 5778-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2714
% INFO    : Updated Thermal Rating: on line 5706-4057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 5059-4061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 4597-4062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 5224-4062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 4221-4066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 4220-4066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 5770-4067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 4224-4072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 4369-4072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 4674-4078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 4675-4078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 4769-4079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 5708-4082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8357
% INFO    : Updated Thermal Rating: on line 5080-4084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 5843-4084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116592
% INFO    : Updated Thermal Rating: on line 5295-4089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 4613-4090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 4943-4091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 4929-4093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 5330-4093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 5492-4093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 4898-4098 : Rate A, Rate B, Rate C , 1659.0, 1659.0, 1659.0 -> 1386
% INFO    : Updated Thermal Rating: on line 4722-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5827-4101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 4441-4104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 5713-4105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 815
% INFO    : Updated Thermal Rating: on line 4926-4106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 5710-4106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 920
% INFO    : Updated Thermal Rating: on line 4109-4108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28461
% INFO    : Updated Thermal Rating: on line 4329-4110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 5570-4110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 5005-4112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 5716-4121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 4237-4123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 4138-4130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 4535-4131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 5167-4133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 5557-4133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 5790-4133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 5805-4132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4237
% INFO    : Updated Thermal Rating: on line 4202-4135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 4845-4135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 5251-4137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8030
% INFO    : Updated Thermal Rating: on line 4844-4138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 533
% INFO    : Updated Thermal Rating: on line 4993-4140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 5786-4140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 605
% INFO    : Updated Thermal Rating: on line 5718-4144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13354
% INFO    : Updated Thermal Rating: on line 5717-4145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 793
% INFO    : Updated Thermal Rating: on line 4467-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 4467-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 4247-4148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 5719-4148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 4377-4149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16924
% INFO    : Updated Thermal Rating: on line 5720-4152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 880
% INFO    : Updated Thermal Rating: on line 5196-4155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2379
% INFO    : Updated Thermal Rating: on line 4692-4156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 518
% INFO    : Updated Thermal Rating: on line 5416-4156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 5721-4158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5531
% INFO    : Updated Thermal Rating: on line 5559-4159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 5722-4160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47067
% INFO    : Updated Thermal Rating: on line 4313-4162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 4373-4162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 5776-4162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1166
% INFO    : Updated Thermal Rating: on line 4313-4162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1125
% INFO    : Updated Thermal Rating: on line 4373-4162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 5723-4164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1105
% INFO    : Updated Thermal Rating: on line 5631-4164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2029
% INFO    : Updated Thermal Rating: on line 5382-4166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16527
% INFO    : Updated Thermal Rating: on line 5425-4166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1802
% INFO    : Updated Thermal Rating: on line 5030-4169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 4663-4170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on line 5174-4173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 5336-4173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 5622-4173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 4674-4175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on line 4322-4176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 967
% INFO    : Updated Thermal Rating: on line 5726-4176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11909
% INFO    : Updated Thermal Rating: on line 4178-4177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2059
% INFO    : Updated Thermal Rating: on line 5288-4177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 5727-4181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 5745-4182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 5022-4183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 4841-4186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 5148-4186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 4757-4187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22038
% INFO    : Updated Thermal Rating: on line 5186-4191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 4956-4193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on line 4956-4192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on line 4194-4195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3795
% INFO    : Updated Thermal Rating: on line 4572-4199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1421
% INFO    : Updated Thermal Rating: on line 4870-4199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 5782-4199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 5578-4204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on line 4466-4209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4678
% INFO    : Updated Thermal Rating: on line 4492-4209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2928
% INFO    : Updated Thermal Rating: on line 5211-4208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on line 4492-4209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2795
% INFO    : Updated Thermal Rating: on line 4491-4208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2932
% INFO    : Updated Thermal Rating: on line 5381-4212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 5734-4212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 5298-4218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 5362-4217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 4947-4222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 624
% INFO    : Updated Thermal Rating: on line 4341-4226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 5730-4227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 691
% INFO    : Updated Thermal Rating: on line 5449-4231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194699
% INFO    : Updated Thermal Rating: on line 4674-4233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1753
% INFO    : Updated Thermal Rating: on line 4890-4234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 5157-4234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 5400-4234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 4317-4238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 4671-4240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 5203-4239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1184
% INFO    : Updated Thermal Rating: on line 4239-4262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on line 5733-4241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 4826-4242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 4882-4242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 4734-4244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2353
% INFO    : Updated Thermal Rating: on line 4837-4247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 5401-4247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 4998-4249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 5647-4249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 4816-4250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 5174-4252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 5731-4252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 5434-4253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1183
% INFO    : Updated Thermal Rating: on line 5232-4256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 5232-4255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 5781-4259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3793
% INFO    : Updated Thermal Rating: on line 5735-4261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17958
% INFO    : Updated Thermal Rating: on line 5018-4263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 5737-4264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5707-4265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5882
% INFO    : Updated Thermal Rating: on line 5685-4268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 5753-4273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 4996-4279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 5368-4281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1485
% INFO    : Updated Thermal Rating: on line 5586-4281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 5608-4287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 5739-4288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1241
% INFO    : Updated Thermal Rating: on line 4279-4291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4118
% INFO    : Updated Thermal Rating: on line 5740-4292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9521
% INFO    : Updated Thermal Rating: on line 4312-4293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 4563-4293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 5741-4294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1432
% INFO    : Updated Thermal Rating: on line 5374-4299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1423
% INFO    : Updated Thermal Rating: on line 5528-4299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 5527-4298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4301-4300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 706
% INFO    : Updated Thermal Rating: on line 5383-4302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9387
% INFO    : Updated Thermal Rating: on line 5841-4305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 5742-4311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 5530-4315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 5584-4315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 4415-4319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 478
% INFO    : Updated Thermal Rating: on line 4616-4322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 4712-4321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 5337-4321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 5338-4321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 753
% INFO    : Updated Thermal Rating: on line 5419-4322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 5679-4322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 5726-4322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1059
% INFO    : Updated Thermal Rating: on line 5724-4322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 5293-4325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 4547-4334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 4545-4334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1431
% INFO    : Updated Thermal Rating: on line 4765-4336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 5747-4337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1047
% INFO    : Updated Thermal Rating: on line 4889-4338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 5068-4338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on line 5068-4338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on line 5387-4340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 587
% INFO    : Updated Thermal Rating: on line 5393-4341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 5771-4341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5821-4341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 5748-4344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6566
% INFO    : Updated Thermal Rating: on line 5144-4344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 5370-4346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13344
% INFO    : Updated Thermal Rating: on line 4580-4349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 5034-4349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 5218-4349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 5409-4351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 5569-4351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 4433-4352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 4794-4353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 5230-4355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 5240-4355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 4420-4356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 4420-4356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on line 4713-4360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 4906-4361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 5189-4361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on line 5392-4362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 4483-4365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 5753-4366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10315
% INFO    : Updated Thermal Rating: on line 5249-4368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 5371-4371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 5586-4372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 5171-4375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 5806-4376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 5754-4383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 4885-4386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 5165-4393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 5114-4394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 5757-4396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23137
% INFO    : Updated Thermal Rating: on line 4585-4398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30291
% INFO    : Updated Thermal Rating: on line 4864-4403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1962
% INFO    : Updated Thermal Rating: on line 5760-4407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17466
% INFO    : Updated Thermal Rating: on line 5761-4409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65055
% INFO    : Updated Thermal Rating: on line 5002-4416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 4989-4418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 5761-4418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5303-4419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1536
% INFO    : Updated Thermal Rating: on line 5763-4421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1019
% INFO    : Updated Thermal Rating: on line 5762-4422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3780
% INFO    : Updated Thermal Rating: on line 5360-4424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 4681-4426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 587
% INFO    : Updated Thermal Rating: on line 4873-4426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 4681-4426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 4620-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 4852-4429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 4957-4429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 5709-4430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2743
% INFO    : Updated Thermal Rating: on line 4668-4433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 4668-4433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 4750-4434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on line 4915-4434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 4751-4434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on line 5266-4441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1140
% INFO    : Updated Thermal Rating: on line 5765-4444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 5088-4447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 5810-4447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 4921-4450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 759
% INFO    : Updated Thermal Rating: on line 5766-4451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2162
% INFO    : Updated Thermal Rating: on line 4888-4452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 5662-4452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 5145-4452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 5741-4454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 5823-4455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13494
% INFO    : Updated Thermal Rating: on line 4529-4456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1141
% INFO    : Updated Thermal Rating: on line 4630-4457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 5138-4456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 5141-4457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 4898-4459 : Rate A, Rate B, Rate C , 1711.0, 1711.0, 1711.0 -> 811
% INFO    : Updated Thermal Rating: on line 4672-4463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 705
% INFO    : Updated Thermal Rating: on line 4492-4465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8432
% INFO    : Updated Thermal Rating: on line 5768-4467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4770-4469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on line 4480-4475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2012
% INFO    : Updated Thermal Rating: on line 4482-4479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4482-4478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4482-4477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4482-4476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 5005-4483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on line 5506-4483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 4799-4485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2033
% INFO    : Updated Thermal Rating: on line 5769-4487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23415
% INFO    : Updated Thermal Rating: on line 5175-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1313
% INFO    : Updated Thermal Rating: on line 5247-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 5558-4497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 4601-4501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 4801-4505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 5251-4505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 5771-4506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 4045-4508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 4138-4508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 5239-4508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 926
% INFO    : Updated Thermal Rating: on line 5479-4513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5361-4514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 5774-4515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2280
% INFO    : Updated Thermal Rating: on line 4845-4518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 5775-4522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3667
% INFO    : Updated Thermal Rating: on line 4322-4523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 4322-4523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 647
% INFO    : Updated Thermal Rating: on line 5700-4525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 4826-4528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 4882-4528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 5273-4533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 907
% INFO    : Updated Thermal Rating: on line 5733-4535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14657
% INFO    : Updated Thermal Rating: on line 5742-4536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 5507-4538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16578
% INFO    : Updated Thermal Rating: on line 5508-4538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15848
% INFO    : Updated Thermal Rating: on line 5779-4541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1162
% INFO    : Updated Thermal Rating: on line 4569-4543 : Rate A, Rate B, Rate C , 2961.0, 2961.0, 2961.0 -> 1589
% INFO    : Updated Thermal Rating: on line 4569-4543 : Rate A, Rate B, Rate C , 2961.0, 2961.0, 2961.0 -> 1589
% INFO    : Updated Thermal Rating: on line 5386-4548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14447
% INFO    : Updated Thermal Rating: on line 5515-4550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 5691-4550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1386
% INFO    : Updated Thermal Rating: on line 5813-4550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 5814-4550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 917
% INFO    : Updated Thermal Rating: on line 5812-4569 : Rate A, Rate B, Rate C , 2450.0, 2450.0, 2450.0 -> 1390
% INFO    : Updated Thermal Rating: on line 5581-4574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3126
% INFO    : Updated Thermal Rating: on line 5627-4575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 4576-4577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on line 4792-4577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on line 5783-4577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 5785-4579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 4739-4580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 5138-4581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5259-4587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 4656-4589 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2158
% INFO    : Updated Thermal Rating: on line 4656-4588 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2153
% INFO    : Updated Thermal Rating: on line 5786-4592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13183
% INFO    : Updated Thermal Rating: on line 5788-4596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 5789-4598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3538
% INFO    : Updated Thermal Rating: on line 4798-4602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 5473-4602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 5578-4602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 5626-4602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1639
% INFO    : Updated Thermal Rating: on line 5729-4602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 5051-4605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4291
% INFO    : Updated Thermal Rating: on line 5629-4605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11313
% INFO    : Updated Thermal Rating: on line 5458-4607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 4860-4609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 5314-4609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 5467-4609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 5616-4610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 5653-4610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1573
% INFO    : Updated Thermal Rating: on line 5791-4613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 4637-4614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 4971-4620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 5612-4622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 5792-4623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 5519-4624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 5101-4625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 5242-4625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1393
% INFO    : Updated Thermal Rating: on line 5216-4627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 5794-4628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11206
% INFO    : Updated Thermal Rating: on line 4793-4631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 4661-4638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 853
% INFO    : Updated Thermal Rating: on line 4643-4641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 4658-4641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1350
% INFO    : Updated Thermal Rating: on line 5121-4641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 4658-4641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1334
% INFO    : Updated Thermal Rating: on line 5501-4647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13395
% INFO    : Updated Thermal Rating: on line 4785-4650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 4805-4650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5237-4653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 4737-4657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1837
% INFO    : Updated Thermal Rating: on line 5798-4659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 4894-4668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 5250-4671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 5134-4673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 5178-4674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 5804-4677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2828
% INFO    : Updated Thermal Rating: on line 4845-4680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 5801-4681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53761
% INFO    : Updated Thermal Rating: on line 5806-4693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on line 5808-4707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 5810-4710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11206
% INFO    : Updated Thermal Rating: on line 5137-4713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 5135-4713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 5450-4713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5343-4719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1011
% INFO    : Updated Thermal Rating: on line 5811-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3126
% INFO    : Updated Thermal Rating: on line 5825-4722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2122
% INFO    : Updated Thermal Rating: on line 4613-4726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246667
% INFO    : Updated Thermal Rating: on line 5822-4733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3957
% INFO    : Updated Thermal Rating: on line 5140-4739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 5677-4739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 5765-4742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7065
% INFO    : Updated Thermal Rating: on line 4921-4753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 5458-4753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 5203-4758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 5618-4768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 875
% INFO    : Updated Thermal Rating: on line 5540-4771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1106
% INFO    : Updated Thermal Rating: on line 4801-4773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 985
% INFO    : Updated Thermal Rating: on line 5366-4775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 5660-4775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 5166-4777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5816-4778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 5670-4780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 5315-4782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 4805-4784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 5275-4784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8426
% INFO    : Updated Thermal Rating: on line 5229-4786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 5817-4790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2647
% INFO    : Updated Thermal Rating: on line 5651-4792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 4916-4794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 4916-4794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 4986-4795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59
% INFO    : Updated Thermal Rating: on line 5819-4797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 5626-4798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on line 5526-4800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 5191-4802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5807
% INFO    : Updated Thermal Rating: on line 5770-4802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 5290-4806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5299-4807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 5070-4822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 5306-4822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on line 5404-4822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 5490-4822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1168
% INFO    : Updated Thermal Rating: on line 4993-4830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2535
% INFO    : Updated Thermal Rating: on line 4993-4830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3804
% INFO    : Updated Thermal Rating: on line 5720-4832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 4895-4834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 5801-4838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 4960-4840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 5788-4840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 4960-4840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 5148-4841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 612
% INFO    : Updated Thermal Rating: on line 4884-4845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 4846-4847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10572
% INFO    : Updated Thermal Rating: on line 5800-4847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 5829-4847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 5505-4857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 5130-4859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 5584-4859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 5822-4862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23430
% INFO    : Updated Thermal Rating: on line 4895-4867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 4895-4868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 5244-4869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1263
% INFO    : Updated Thermal Rating: on line 5076-4873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 5826-4892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5618-4895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 5231-4899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23932
% INFO    : Updated Thermal Rating: on line 5827-4900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3033
% INFO    : Updated Thermal Rating: on line 5163-4901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 5415-4910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 4935-4910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 5694-4921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on line 5719-4921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 5779-4921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 4924-4923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 5828-4926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116592
% INFO    : Updated Thermal Rating: on line 5663-4938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 5829-4941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9817
% INFO    : Updated Thermal Rating: on line 5092-4947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on line 5580-4949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 826
% INFO    : Updated Thermal Rating: on line 5630-4949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on line 5701-4949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 5477-4954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 5276-4956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 556
% INFO    : Updated Thermal Rating: on line 5445-4956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 5830-4957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 5831-4958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2174
% INFO    : Updated Thermal Rating: on line 5154-4960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1435
% INFO    : Updated Thermal Rating: on line 5155-4960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 5459-4963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 5304-4964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 5832-4965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12855
% INFO    : Updated Thermal Rating: on line 5831-4966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 5156-4972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 5541-4976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 793
% INFO    : Updated Thermal Rating: on line 4984-4982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4984-4981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 4985-4980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 5238-4987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 5249-4987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 5821-4993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2438
% INFO    : Updated Thermal Rating: on line 5833-4995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 5600-4996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 5645-4996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1562
% INFO    : Updated Thermal Rating: on line 5388-4996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1449
% INFO    : Updated Thermal Rating: on line 5647-4998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 5773-4998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 865
% INFO    : Updated Thermal Rating: on line 5740-5000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 5291-5001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 5623-5002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 5834-5006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1478
% INFO    : Updated Thermal Rating: on line 5835-5009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3024
% INFO    : Updated Thermal Rating: on line 5836-5009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2864
% INFO    : Updated Thermal Rating: on line 5539-5013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 5090-5014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 5670-5020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9602
% INFO    : Updated Thermal Rating: on line 5653-5022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 5837-5023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 5252-5026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 5136-5027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8991
% INFO    : Updated Thermal Rating: on line 5082-5029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 5236-5031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 5799-5032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 5640-5038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13450
% INFO    : Updated Thermal Rating: on line 4983-5043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 894
% INFO    : Updated Thermal Rating: on line 5757-5043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 5513-5047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 5064-5056 : Rate A, Rate B, Rate C , 2275.0, 2275.0, 2275.0 -> 2203
% INFO    : Updated Thermal Rating: on line 5482-5069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 5333-5071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 5842-5071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 591
% INFO    : Updated Thermal Rating: on line 5841-5077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 478
% INFO    : Updated Thermal Rating: on line 5844-5081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24046
% INFO    : Updated Thermal Rating: on line 5763-5086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 5351-5099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 5544-5099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 5744-5107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 5574-5112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3790
% INFO    : Updated Thermal Rating: on line 5390-5120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1156
% INFO    : Updated Thermal Rating: on line 5144-5126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 5596-5127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5965
% INFO    : Updated Thermal Rating: on line 5748-5158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 5280-5166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 5844-5192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on line 5222-5200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 554
% INFO    : Updated Thermal Rating: on line 5490-5206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3584
% INFO    : Updated Thermal Rating: on line 5339-5207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 5441-5214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 5706-5215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11707
% INFO    : Updated Thermal Rating: on line 5284-5271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37051
% INFO    : Updated Thermal Rating: on line 5233-5289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 5428-5350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 5588-5354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on line 5713-5370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 875
% INFO    : Updated Thermal Rating: on line 5602-5388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1273
% INFO    : Updated Thermal Rating: on line 5494-5403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2284
% INFO    : Updated Thermal Rating: on line 5738-5411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 5548-5424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3270
% INFO    : Updated Thermal Rating: on line 5443-5684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on line 5644-5467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1451
% INFO    : Updated Thermal Rating: on line 5575-5469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2052
% INFO    : Updated Thermal Rating: on line 5723-5480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 5545-5488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 5244-5500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 5659-5500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1321
% INFO    : Updated Thermal Rating: on line 5775-5501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6303
% INFO    : Updated Thermal Rating: on line 5581-5514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 5813-5517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 5444-5534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 926
% INFO    : Updated Thermal Rating: on line 5565-5625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 5591-5593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 5603-5601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245373
% INFO    : Updated Thermal Rating: on line 5759-5611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5631-5633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9287
% INFO    : Updated Thermal Rating: on line 5806-5643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 5755-5672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on line 5830-5746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 5832-5775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6303
% INFO    : Updated Thermal Rating: on line 6044-5948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7982
% INFO    : Updated Thermal Rating: on line 6076-5948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3115
% INFO    : Updated Thermal Rating: on line 5952-5949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2274
% INFO    : Updated Thermal Rating: on line 5952-5949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2274
% INFO    : Updated Thermal Rating: on line 6112-5949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2843
% INFO    : Updated Thermal Rating: on line 6120-5949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2276
% INFO    : Updated Thermal Rating: on line 6140-5949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2213
% INFO    : Updated Thermal Rating: on line 4408-5950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10754
% INFO    : Updated Thermal Rating: on line 6071-5951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4531
% INFO    : Updated Thermal Rating: on line 6071-5951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4569
% INFO    : Updated Thermal Rating: on line 6212-5952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4405
% INFO    : Updated Thermal Rating: on line 6212-5952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4405
% INFO    : Updated Thermal Rating: on line 6048-5953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3541
% INFO    : Updated Thermal Rating: on line 6085-5953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6894
% INFO    : Updated Thermal Rating: on line 6091-5953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6513
% INFO    : Updated Thermal Rating: on line 5984-5956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1587
% INFO    : Updated Thermal Rating: on line 6155-5958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 6211-5958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1525
% INFO    : Updated Thermal Rating: on line 6228-5958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12439
% INFO    : Updated Thermal Rating: on line 6159-5960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2067
% INFO    : Updated Thermal Rating: on line 6027-5961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 6058-5961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 6234-5961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 6243-5961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 6059-5962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 6101-5962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2933
% INFO    : Updated Thermal Rating: on line 6145-5963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3141
% INFO    : Updated Thermal Rating: on line 5975-5964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2839
% INFO    : Updated Thermal Rating: on line 6155-5965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3084
% INFO    : Updated Thermal Rating: on line 6041-5966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1009
% INFO    : Updated Thermal Rating: on line 6161-5966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9134
% INFO    : Updated Thermal Rating: on line 6144-5967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6619
% INFO    : Updated Thermal Rating: on line 6165-5967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5050
% INFO    : Updated Thermal Rating: on line 6178-5968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1634
% INFO    : Updated Thermal Rating: on line 2659-5969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 977
% INFO    : Updated Thermal Rating: on line 6222-5970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on line 6223-5971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4495
% INFO    : Updated Thermal Rating: on line 6090-5972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10163
% INFO    : Updated Thermal Rating: on line 6204-5972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15043
% INFO    : Updated Thermal Rating: on line 6007-5974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 6007-5973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 6123-5974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1230
% INFO    : Updated Thermal Rating: on line 6130-5973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1064
% INFO    : Updated Thermal Rating: on line 5982-5977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 6186-5977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5512
% INFO    : Updated Thermal Rating: on line 6123-5979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1172
% INFO    : Updated Thermal Rating: on line 6180-5979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on line 5986-5980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6412
% INFO    : Updated Thermal Rating: on line 6018-5981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4239
% INFO    : Updated Thermal Rating: on line 6102-5981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3048
% INFO    : Updated Thermal Rating: on line 6107-5982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1623
% INFO    : Updated Thermal Rating: on line 6186-5982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on line 5845-5983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10739
% INFO    : Updated Thermal Rating: on line 5859-5983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9685
% INFO    : Updated Thermal Rating: on line 5858-5983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9522
% INFO    : Updated Thermal Rating: on line 6006-5983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3201
% INFO    : Updated Thermal Rating: on line 6000-5984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76420
% INFO    : Updated Thermal Rating: on line 5999-5984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76420
% INFO    : Updated Thermal Rating: on line 6056-5984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3417
% INFO    : Updated Thermal Rating: on line 6056-5984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3571
% INFO    : Updated Thermal Rating: on line 6239-5985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 5852-5987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on line 6074-5987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on line 6074-5987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on line 5990-5989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 5996-5991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3733
% INFO    : Updated Thermal Rating: on line 6105-5991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3493
% INFO    : Updated Thermal Rating: on line 800-5993 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1033
% INFO    : Updated Thermal Rating: on line 6062-5992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1140
% INFO    : Updated Thermal Rating: on line 6123-5992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 6155-5992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13437
% INFO    : Updated Thermal Rating: on line 6155-5992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10336
% INFO    : Updated Thermal Rating: on line 6155-5992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10336
% INFO    : Updated Thermal Rating: on line 6122-5994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4661
% INFO    : Updated Thermal Rating: on line 6154-5994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4902
% INFO    : Updated Thermal Rating: on line 6211-5994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1460
% INFO    : Updated Thermal Rating: on line 6161-5995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on line 6180-5995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3569
% INFO    : Updated Thermal Rating: on line 6154-5998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5656
% INFO    : Updated Thermal Rating: on line 6228-5998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4356
% INFO    : Updated Thermal Rating: on line 6133-6001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4032
% INFO    : Updated Thermal Rating: on line 6168-6001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1383
% INFO    : Updated Thermal Rating: on line 6041-6003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3568
% INFO    : Updated Thermal Rating: on line 6161-6003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1333
% INFO    : Updated Thermal Rating: on line 6126-6004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2974
% INFO    : Updated Thermal Rating: on line 6126-6004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2981
% INFO    : Updated Thermal Rating: on line 6176-6004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21158
% INFO    : Updated Thermal Rating: on line 6176-6004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21158
% INFO    : Updated Thermal Rating: on line 1756-6005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 5464-6005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 5992-6007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1598
% INFO    : Updated Thermal Rating: on line 5992-6007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1598
% INFO    : Updated Thermal Rating: on line 6206-6008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2833
% INFO    : Updated Thermal Rating: on line 6240-6014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6060
% INFO    : Updated Thermal Rating: on line 5848-6015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9771
% INFO    : Updated Thermal Rating: on line 5847-6015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9748
% INFO    : Updated Thermal Rating: on line 6060-6016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 6061-6016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 6162-6016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 6081-6017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3080
% INFO    : Updated Thermal Rating: on line 6094-6017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3518
% INFO    : Updated Thermal Rating: on line 6094-6017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3518
% INFO    : Updated Thermal Rating: on line 6103-6018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1781
% INFO    : Updated Thermal Rating: on line 5845-6021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12590
% INFO    : Updated Thermal Rating: on line 5846-6022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12649
% INFO    : Updated Thermal Rating: on line 6066-6024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 6067-6023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 6239-6024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1551
% INFO    : Updated Thermal Rating: on line 6238-6023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on line 6084-6025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2357
% INFO    : Updated Thermal Rating: on line 6103-6026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3645
% INFO    : Updated Thermal Rating: on line 6102-6026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3645
% INFO    : Updated Thermal Rating: on line 6063-6027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 6075-6027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2624
% INFO    : Updated Thermal Rating: on line 6233-6027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 956
% INFO    : Updated Thermal Rating: on line 5848-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9186
% INFO    : Updated Thermal Rating: on line 5847-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9482
% INFO    : Updated Thermal Rating: on line 6210-6031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8417
% INFO    : Updated Thermal Rating: on line 6094-6033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8447
% INFO    : Updated Thermal Rating: on line 6094-6033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8447
% INFO    : Updated Thermal Rating: on line 5853-6034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4327
% INFO    : Updated Thermal Rating: on line 6224-6034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1315
% INFO    : Updated Thermal Rating: on line 6120-6035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9496
% INFO    : Updated Thermal Rating: on line 6111-6036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 6143-6036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 6203-6036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50827
% INFO    : Updated Thermal Rating: on line 6149-6038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12717
% INFO    : Updated Thermal Rating: on line 6200-6038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7215
% INFO    : Updated Thermal Rating: on line 6046-6040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4573
% INFO    : Updated Thermal Rating: on line 6136-6040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 6159-6040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1767
% INFO    : Updated Thermal Rating: on line 6184-6040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2456
% INFO    : Updated Thermal Rating: on line 6219-6041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5222
% INFO    : Updated Thermal Rating: on line 6219-6041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5222
% INFO    : Updated Thermal Rating: on line 6241-6045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2681
% INFO    : Updated Thermal Rating: on line 6142-6046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5467
% INFO    : Updated Thermal Rating: on line 6089-6047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2347
% INFO    : Updated Thermal Rating: on line 6051-6050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 6051-6049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 6200-6050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1674
% INFO    : Updated Thermal Rating: on line 6200-6049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1674
% INFO    : Updated Thermal Rating: on line 6117-6051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1664
% INFO    : Updated Thermal Rating: on line 6117-6051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1664
% INFO    : Updated Thermal Rating: on line 6060-6055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 6136-6055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 6151-6055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 6230-6055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 6063-6057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 6073-6059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3035
% INFO    : Updated Thermal Rating: on line 6073-6059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8841
% INFO    : Updated Thermal Rating: on line 6120-6059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 873
% INFO    : Updated Thermal Rating: on line 6148-6059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2052
% INFO    : Updated Thermal Rating: on line 6166-6059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3773
% INFO    : Updated Thermal Rating: on line 6202-6059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 6061-6060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 6172-6060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 6190-6061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29308
% INFO    : Updated Thermal Rating: on line 6123-6062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 6232-6063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 6243-6063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 6111-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 6139-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1469
% INFO    : Updated Thermal Rating: on line 6088-6066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2790
% INFO    : Updated Thermal Rating: on line 6089-6067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2813
% INFO    : Updated Thermal Rating: on line 6123-6068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1926
% INFO    : Updated Thermal Rating: on line 6180-6068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 6244-6069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3003
% INFO    : Updated Thermal Rating: on line 6244-6069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3003
% INFO    : Updated Thermal Rating: on line 6074-6070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1279
% INFO    : Updated Thermal Rating: on line 6230-6070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2050
% INFO    : Updated Thermal Rating: on line 6075-6071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1413
% INFO    : Updated Thermal Rating: on line 6075-6071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1349
% INFO    : Updated Thermal Rating: on line 6101-6073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4385
% INFO    : Updated Thermal Rating: on line 6148-6073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 6166-6073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on line 6202-6073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1408
% INFO    : Updated Thermal Rating: on line 6151-6074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14302
% INFO    : Updated Thermal Rating: on line 6133-6075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on line 6133-6075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 899
% INFO    : Updated Thermal Rating: on line 6243-6075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8735
% INFO    : Updated Thermal Rating: on line 6222-6077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on line 6141-6079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344932
% INFO    : Updated Thermal Rating: on line 6141-6079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344932
% INFO    : Updated Thermal Rating: on line 5849-6080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222473
% INFO    : Updated Thermal Rating: on line 6132-6081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2451
% INFO    : Updated Thermal Rating: on line 6089-6083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5936
% INFO    : Updated Thermal Rating: on line 6087-6082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5070
% INFO    : Updated Thermal Rating: on line 5860-6085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2799
% INFO    : Updated Thermal Rating: on line 6090-6084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22600
% INFO    : Updated Thermal Rating: on line 6090-6084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22600
% INFO    : Updated Thermal Rating: on line 5850-6086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252116
% INFO    : Updated Thermal Rating: on line 6097-6087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 807
% INFO    : Updated Thermal Rating: on line 6130-6088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1454
% INFO    : Updated Thermal Rating: on line 6204-6090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6883
% INFO    : Updated Thermal Rating: on line 6207-6091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2353
% INFO    : Updated Thermal Rating: on line 6122-6095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 650
% INFO    : Updated Thermal Rating: on line 6211-6095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 6146-6096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6857
% INFO    : Updated Thermal Rating: on line 6146-6096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6857
% INFO    : Updated Thermal Rating: on line 6123-6097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 935
% INFO    : Updated Thermal Rating: on line 6114-6098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7176
% INFO    : Updated Thermal Rating: on line 6114-6099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7176
% INFO    : Updated Thermal Rating: on line 6140-6104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1703
% INFO    : Updated Thermal Rating: on line 6166-6104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6476
% INFO    : Updated Thermal Rating: on line 6176-6104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2200
% INFO    : Updated Thermal Rating: on line 6202-6104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on line 6147-6105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2832
% INFO    : Updated Thermal Rating: on line 6237-6105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2522
% INFO    : Updated Thermal Rating: on line 6114-6108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4297
% INFO    : Updated Thermal Rating: on line 6208-6113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6641
% INFO    : Updated Thermal Rating: on line 5852-6116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345173
% INFO    : Updated Thermal Rating: on line 6210-6116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9695
% INFO    : Updated Thermal Rating: on line 6119-6117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3213
% INFO    : Updated Thermal Rating: on line 6149-6119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2708
% INFO    : Updated Thermal Rating: on line 6148-6120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22626
% INFO    : Updated Thermal Rating: on line 5853-6121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17394
% INFO    : Updated Thermal Rating: on line 6182-6121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1355
% INFO    : Updated Thermal Rating: on line 6224-6121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1693
% INFO    : Updated Thermal Rating: on line 6145-6123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2638
% INFO    : Updated Thermal Rating: on line 6134-6127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4262
% INFO    : Updated Thermal Rating: on line 6210-6127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2064
% INFO    : Updated Thermal Rating: on line 6172-6129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4379
% INFO    : Updated Thermal Rating: on line 6172-6129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4379
% INFO    : Updated Thermal Rating: on line 6175-6131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 6185-6131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5970
% INFO    : Updated Thermal Rating: on line 6185-6133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on line 6210-6134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4013
% INFO    : Updated Thermal Rating: on line 6159-6136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 6151-6141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2696
% INFO    : Updated Thermal Rating: on line 6151-6141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2698
% INFO    : Updated Thermal Rating: on line 6184-6142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5431
% INFO    : Updated Thermal Rating: on line 6174-6144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3809
% INFO    : Updated Thermal Rating: on line 6174-6144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3817
% INFO    : Updated Thermal Rating: on line 6166-6148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3007
% INFO    : Updated Thermal Rating: on line 6202-6148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3983
% INFO    : Updated Thermal Rating: on line 6212-6148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 6172-6151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 6230-6151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 6229-6152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19968
% INFO    : Updated Thermal Rating: on line 2234-6153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1752
% INFO    : Updated Thermal Rating: on line 6211-6155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 761
% INFO    : Updated Thermal Rating: on line 5856-6160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69049
% INFO    : Updated Thermal Rating: on line 36-6195 : Rate A, Rate B, Rate C , 1559.0, 1559.0, 1559.0 -> 873
% INFO    : Updated Thermal Rating: on line 35-6194 : Rate A, Rate B, Rate C , 1559.0, 1559.0, 1559.0 -> 956
% INFO    : Updated Thermal Rating: on line 6215-6161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4262
% INFO    : Updated Thermal Rating: on line 6195-6164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245589
% INFO    : Updated Thermal Rating: on line 6206-6164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8451
% INFO    : Updated Thermal Rating: on line 6202-6166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43571
% INFO    : Updated Thermal Rating: on line 6168-6167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 624
% INFO    : Updated Thermal Rating: on line 6203-6167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on line 5853-6171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 922
% INFO    : Updated Thermal Rating: on line 5855-6178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3404
% INFO    : Updated Thermal Rating: on line 6221-6180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3347
% INFO    : Updated Thermal Rating: on line 6224-6182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 743
% INFO    : Updated Thermal Rating: on line 5848-6209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3368
% INFO    : Updated Thermal Rating: on line 5847-6209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3374
% INFO    : Updated Thermal Rating: on line 5852-6210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9679
% INFO    : Updated Thermal Rating: on line 6219-6215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1035
% INFO    : Updated Thermal Rating: on line 5859-6218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7175
% INFO    : Updated Thermal Rating: on line 5858-6217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6972
% INFO    : Updated Thermal Rating: on line 323-6223 : Rate A, Rate B, Rate C , 1624.0, 1624.0, 1624.0 -> 1498
% INFO    : Updated Thermal Rating: on line 5860-6227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12963
% INFO    : Updated Thermal Rating: on line 6243-6231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on transformer 26-27 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 26-27 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 26-27 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 31-33 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 31-34 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 32-33 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 35-5889 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1111
% INFO    : Updated Thermal Rating: on line 35-5913 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1111
% INFO    : Updated Thermal Rating: on transformer 50-51 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 50-51 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 50-51 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 103-104 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 103-104 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 109-110 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 109-110 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 112-113 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 112-113 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 112-113 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 128-130 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 129-130 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 137-138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 139-140 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 142-143 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 142-143 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 144-145 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 285
% INFO    : Updated Thermal Rating: on transformer 144-146 : Rate A, Rate B, Rate C , 712.0, 712.0, 712.0 -> 201
% INFO    : Updated Thermal Rating: on transformer 144-146 : Rate A, Rate B, Rate C , 712.0, 712.0, 712.0 -> 201
% INFO    : Updated Thermal Rating: on line 146-5861 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1094
% INFO    : Updated Thermal Rating: on line 146-5914 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1070
% INFO    : Updated Thermal Rating: on transformer 156-152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on transformer 153-154 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 324
% INFO    : Updated Thermal Rating: on transformer 157-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 165-168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 166-168 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 166-168 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 166-168 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 167-168 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 171-172 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 171-172 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 273
% INFO    : Updated Thermal Rating: on line 180-5890 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 303
% INFO    : Updated Thermal Rating: on line 180-5915 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 203-204 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 346
% INFO    : Updated Thermal Rating: on transformer 203-204 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 346
% INFO    : Updated Thermal Rating: on transformer 214-215 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 214-215 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 214-215 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 221-222 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 199
% INFO    : Updated Thermal Rating: on transformer 233-234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 246-247 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 256-257 : Rate A, Rate B, Rate C , 459.0, 459.0, 459.0 -> 292
% INFO    : Updated Thermal Rating: on transformer 259-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 259-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 272-273 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 272-273 : Rate A, Rate B, Rate C , 447.0, 447.0, 447.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 277-278 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 277-278 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 313-314 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 313-314 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 321-323 : Rate A, Rate B, Rate C , 1020.0, 1020.0, 1020.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 321-323 : Rate A, Rate B, Rate C , 1627.0, 1627.0, 1627.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 321-323 : Rate A, Rate B, Rate C , 1016.0, 1016.0, 1016.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 326-327 : Rate A, Rate B, Rate C , 433.0, 433.0, 433.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 326-327 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 330-331 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 330-331 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 342-343 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 360-361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 360-361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 360-361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 360-362 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 378-379 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 378-379 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 422-423 : Rate A, Rate B, Rate C , 721.0, 721.0, 721.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 422-423 : Rate A, Rate B, Rate C , 721.0, 721.0, 721.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 424-425 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 424-425 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 424-425 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 445-446 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 443-446 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 444-446 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 448-449 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 448-449 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 452-453 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 452-453 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 457-458 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 266
% INFO    : Updated Thermal Rating: on line 459-5862 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1169
% INFO    : Updated Thermal Rating: on line 459-5891 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1087
% INFO    : Updated Thermal Rating: on transformer 464-465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on transformer 478-479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 480-481 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 480-481 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 480-481 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 504-505 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 504-505 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 512-513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on transformer 521-523 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 522-523 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 526-527 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 526-527 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 526-527 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 535-536 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 535-536 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 267
% INFO    : Updated Thermal Rating: on transformer 535-536 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 544-545 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 550-551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 563-564 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 602-603 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 602-603 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 607-608 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 607-608 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 610-611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 627-628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 653-654 : Rate A, Rate B, Rate C , 721.0, 721.0, 721.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 653-654 : Rate A, Rate B, Rate C , 718.0, 718.0, 718.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 668-669 : Rate A, Rate B, Rate C , 337.0, 337.0, 337.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 677-678 : Rate A, Rate B, Rate C , 530.0, 530.0, 530.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 695-696 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 695-696 : Rate A, Rate B, Rate C , 300.0, 300.0, 300.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 697-700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 698-700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 699-701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 702-704 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 702-704 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 709-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 708-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 707-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 711-712 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 710-712 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 710-712 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 725-727 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 726-727 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 725-727 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 742-743 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 742-743 : Rate A, Rate B, Rate C , 445.0, 445.0, 445.0 -> 252
% INFO    : Updated Thermal Rating: on line 755-5863 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1169
% INFO    : Updated Thermal Rating: on line 755-5893 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1087
% INFO    : Updated Thermal Rating: on transformer 762-763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 768-769 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 768-769 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 768-769 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 770-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 771-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 772-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 776-777 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 787-788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 786-789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 788-790 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 789-790 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 799-800 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 803-805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 802-805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 801-804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 849-850 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 849-850 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 849-850 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 852-853 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 852-853 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 853-854 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 566
% INFO    : Updated Thermal Rating: on transformer 879-881 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 880-881 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 879-881 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 889-890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 923-924 : Rate A, Rate B, Rate C , 1629.0, 1629.0, 1629.0 -> 320
% INFO    : Updated Thermal Rating: on transformer 923-924 : Rate A, Rate B, Rate C , 1629.0, 1629.0, 1629.0 -> 320
% INFO    : Updated Thermal Rating: on line 935-5917 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 894
% INFO    : Updated Thermal Rating: on line 934-5931 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 974
% INFO    : Updated Thermal Rating: on line 935-5941 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 987
% INFO    : Updated Thermal Rating: on transformer 937-938 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 937-938 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 937-938 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 948-949 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 948-949 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 953-954 : Rate A, Rate B, Rate C , 1627.0, 1627.0, 1627.0 -> 320
% INFO    : Updated Thermal Rating: on transformer 953-954 : Rate A, Rate B, Rate C , 1627.0, 1627.0, 1627.0 -> 318
% INFO    : Updated Thermal Rating: on transformer 960-961 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 335
% INFO    : Updated Thermal Rating: on transformer 960-961 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 330
% INFO    : Updated Thermal Rating: on transformer 960-961 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 332
% INFO    : Updated Thermal Rating: on transformer 961-963 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1177
% INFO    : Updated Thermal Rating: on transformer 965-966 : Rate A, Rate B, Rate C , 639.0, 639.0, 639.0 -> 137
% INFO    : Updated Thermal Rating: on transformer 965-966 : Rate A, Rate B, Rate C , 639.0, 639.0, 639.0 -> 137
% INFO    : Updated Thermal Rating: on transformer 965-966 : Rate A, Rate B, Rate C , 639.0, 639.0, 639.0 -> 137
% INFO    : Updated Thermal Rating: on transformer 968-969 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 968-969 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 974-975 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 974-975 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 976-977 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 220
% INFO    : Updated Thermal Rating: on transformer 988-990 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 291
% INFO    : Updated Thermal Rating: on transformer 988-990 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 996-997 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 995-5866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on transformer 996-998 : Rate A, Rate B, Rate C , 1627.0, 1627.0, 1627.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 996-998 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 1011-1012 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 1011-1012 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1026-1028 : Rate A, Rate B, Rate C , 445.0, 445.0, 445.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 1033-1034 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 1033-1034 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1034-1035 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1168
% INFO    : Updated Thermal Rating: on transformer 1034-1035 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1165
% INFO    : Updated Thermal Rating: on line 1037-5918 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 959
% INFO    : Updated Thermal Rating: on transformer 1041-1042 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1041-1042 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1040-1042 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 1058-1059 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1058-1059 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 1058-1059 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1058-1059 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1063-1064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 1063-1064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on transformer 1063-1064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 1071-1072 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1162
% INFO    : Updated Thermal Rating: on transformer 1071-1072 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1159
% INFO    : Updated Thermal Rating: on line 1072-5919 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 985
% INFO    : Updated Thermal Rating: on transformer 1073-1074 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 1073-1074 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 1087-1088 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 1108-1109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 1111-1112 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1111-1112 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1130-1131 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 1130-1131 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1136-1138 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 1137-1138 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 1141-1142 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 1141-1142 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 233
% INFO    : Updated Thermal Rating: on transformer 1145-1146 : Rate A, Rate B, Rate C , 1038.0, 1038.0, 1038.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 1152-1153 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1152-1153 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 1151-1153 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 190
% INFO    : Updated Thermal Rating: on transformer 1159-1162 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 311
% INFO    : Updated Thermal Rating: on transformer 1160-1162 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 1161-1162 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 1169-1170 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 331
% INFO    : Updated Thermal Rating: on transformer 1169-1170 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 1169-1170 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 334
% INFO    : Updated Thermal Rating: on transformer 1169-1170 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 1190-1191 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1189-1191 : Rate A, Rate B, Rate C , 466.0, 466.0, 466.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 1190-1192 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1194-1195 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1165
% INFO    : Updated Thermal Rating: on transformer 1194-1195 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1153
% INFO    : Updated Thermal Rating: on transformer 1197-1198 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 1197-1198 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1203-1204 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1203-1204 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1206-1207 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 1206-1207 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1206-1207 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1224-1225 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 1232-1231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6589
% INFO    : Updated Thermal Rating: on transformer 1234-1236 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 1233-1236 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 241
% INFO    : Updated Thermal Rating: on transformer 1234-1237 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1239-1240 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 1242-1243 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 1242-1243 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 1242-1243 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 1244-1245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on transformer 1244-1245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on transformer 1246-1247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 1253-1254 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1253-1254 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 1258-1260 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 1259-1260 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1258-1260 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1303-1305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 1304-1305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 1320-1321 : Rate A, Rate B, Rate C , 438.0, 438.0, 438.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1320-1321 : Rate A, Rate B, Rate C , 316.0, 316.0, 316.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 1327-1328 : Rate A, Rate B, Rate C , 310.0, 310.0, 310.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1327-1328 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1330-1331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 1338-1339 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1340-1341 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1340-1341 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 283
% INFO    : Updated Thermal Rating: on transformer 1344-1345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1352-1353 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 338
% INFO    : Updated Thermal Rating: on transformer 1352-1353 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 332
% INFO    : Updated Thermal Rating: on transformer 1352-1353 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 330
% INFO    : Updated Thermal Rating: on transformer 1354-1355 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 182
% INFO    : Updated Thermal Rating: on transformer 1354-1355 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 183
% INFO    : Updated Thermal Rating: on transformer 1354-1355 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 182
% INFO    : Updated Thermal Rating: on transformer 1375-1376 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 1381-1382 : Rate A, Rate B, Rate C , 729.0, 729.0, 729.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1381-1382 : Rate A, Rate B, Rate C , 721.0, 721.0, 721.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 1381-1382 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1402-1403 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1404-1406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 1405-1406 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1405-1406 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1429-1430 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 1429-1430 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 1436-1437 : Rate A, Rate B, Rate C , 740.0, 740.0, 740.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1436-1437 : Rate A, Rate B, Rate C , 740.0, 740.0, 740.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1440-1441 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 1439-1441 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1451-1452 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 210
% INFO    : Updated Thermal Rating: on transformer 1454-1455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 1457-1458 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1457-1458 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 248
% INFO    : Updated Thermal Rating: on line 1459-5867 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1041
% INFO    : Updated Thermal Rating: on transformer 1460-1461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on transformer 1460-1462 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 280
% INFO    : Updated Thermal Rating: on transformer 1460-1462 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 279
% INFO    : Updated Thermal Rating: on transformer 1468-1469 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 1474-1475 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 1474-1475 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 1480-1482 : Rate A, Rate B, Rate C , 545.0, 545.0, 545.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 1498-1499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1513-1514 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 343
% INFO    : Updated Thermal Rating: on transformer 1513-1514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 1513-1514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 1514-1515 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1153
% INFO    : Updated Thermal Rating: on transformer 1514-1515 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1145
% INFO    : Updated Thermal Rating: on transformer 1518-1520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on transformer 1517-1520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 1521-1522 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1521-1522 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1528-1530 : Rate A, Rate B, Rate C , 315.0, 315.0, 315.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1529-1530 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 1528-1530 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 1528-1531 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 316
% INFO    : Updated Thermal Rating: on line 1531-5932 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1016
% INFO    : Updated Thermal Rating: on line 1531-5943 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1039
% INFO    : Updated Thermal Rating: on transformer 1538-1539 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 305
% INFO    : Updated Thermal Rating: on transformer 1538-1539 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 305
% INFO    : Updated Thermal Rating: on transformer 1559-1560 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 1559-1560 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1559-1560 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 283
% INFO    : Updated Thermal Rating: on transformer 1583-1584 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 1583-1584 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1592-1594 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 267
% INFO    : Updated Thermal Rating: on transformer 1593-1594 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 275
% INFO    : Updated Thermal Rating: on line 1595-5868 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 999
% INFO    : Updated Thermal Rating: on transformer 1596-1597 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 1596-1597 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1596-1598 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 1608-1609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 1608-1609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on transformer 1611-1612 : Rate A, Rate B, Rate C , 428.0, 428.0, 428.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1610-1612 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1610-1612 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 1614-1615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 1632-1633 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1632-1633 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1632-1633 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1663-1664 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 1663-1664 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 1667-1668 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 1667-1668 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1676-1677 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1676-1677 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 1683-1684 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 1683-1684 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 1702-1705 : Rate A, Rate B, Rate C , 482.0, 482.0, 482.0 -> 279
% INFO    : Updated Thermal Rating: on transformer 1703-1707 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 1703-1704 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1702-1706 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 287
% INFO    : Updated Thermal Rating: on transformer 1711-1712 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 1711-1712 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 283
% INFO    : Updated Thermal Rating: on transformer 1716-1717 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1716-1717 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 1722-1723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 1729-1731 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 1729-1731 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1743-1746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 1742-1745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 1741-1744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 1747-1749 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1748-1749 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 1770-1773 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 1771-1773 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 1772-1773 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 1772-1773 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1772-1773 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 1775-1776 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 311
% INFO    : Updated Thermal Rating: on transformer 1775-1776 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 311
% INFO    : Updated Thermal Rating: on transformer 1775-1776 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 296
% INFO    : Updated Thermal Rating: on transformer 1780-1781 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1780-1781 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1786-1787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 1786-1788 : Rate A, Rate B, Rate C , 310.0, 310.0, 310.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 1786-1788 : Rate A, Rate B, Rate C , 442.0, 442.0, 442.0 -> 291
% INFO    : Updated Thermal Rating: on transformer 1786-1788 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 1787-1788 : Rate A, Rate B, Rate C , 301.0, 301.0, 301.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 1789-1790 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 1789-1790 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1798-1799 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1805-1806 : Rate A, Rate B, Rate C , 557.0, 557.0, 557.0 -> 212
% INFO    : Updated Thermal Rating: on transformer 1805-1806 : Rate A, Rate B, Rate C , 579.0, 579.0, 579.0 -> 208
% INFO    : Updated Thermal Rating: on transformer 1817-1818 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1817-1818 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1821-1822 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1826-1827 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1826-1827 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1832-1833 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1832-1833 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 1837-1838 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 1837-1838 : Rate A, Rate B, Rate C , 448.0, 448.0, 448.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 1877-1878 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1891-1895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1890-1894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1889-1893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1888-1892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1898-1899 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 1898-1899 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1900-1901 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1907-1908 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1907-1908 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1922-1923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 1922-1923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on transformer 1924-1925 : Rate A, Rate B, Rate C , 717.0, 717.0, 717.0 -> 203
% INFO    : Updated Thermal Rating: on line 1929-5897 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1158
% INFO    : Updated Thermal Rating: on transformer 1930-1931 : Rate A, Rate B, Rate C , 1011.0, 1011.0, 1011.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 1936-1938 : Rate A, Rate B, Rate C , 315.0, 315.0, 315.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 1936-1939 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 323
% INFO    : Updated Thermal Rating: on transformer 1937-1939 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 319
% INFO    : Updated Thermal Rating: on transformer 1965-1971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 1964-1969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 1963-1968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 1962-1967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 1961-1966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 1974-1977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on transformer 1983-1984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 1983-1985 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 1984-1985 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 1984-1985 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 1990-1991 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1990-1991 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1990-1991 : Rate A, Rate B, Rate C , 758.0, 758.0, 758.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 2005-2006 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 2005-2006 : Rate A, Rate B, Rate C , 337.0, 337.0, 337.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 2033-2034 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2033-2034 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 2042-2043 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 279
% INFO    : Updated Thermal Rating: on transformer 2041-2043 : Rate A, Rate B, Rate C , 445.0, 445.0, 445.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2049-2050 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1174
% INFO    : Updated Thermal Rating: on transformer 2049-2050 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1174
% INFO    : Updated Thermal Rating: on transformer 2049-2050 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 2066-2068 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 200
% INFO    : Updated Thermal Rating: on transformer 2066-2067 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 202
% INFO    : Updated Thermal Rating: on transformer 2070-2071 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 2070-2071 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2079-2080 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 238
% INFO    : Updated Thermal Rating: on transformer 2079-2080 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 238
% INFO    : Updated Thermal Rating: on line 2082-5869 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1099
% INFO    : Updated Thermal Rating: on transformer 2086-2088 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 2086-2088 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 2089-2090 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2089-2090 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2097-2098 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 2097-2098 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 2097-2098 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 2105-2106 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2105-2106 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2105-2106 : Rate A, Rate B, Rate C , 445.0, 445.0, 445.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 2118-2119 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 2118-2119 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2122-2125 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2121-2124 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 2121-2123 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 2126-2128 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2127-2128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on transformer 2127-2128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on transformer 2130-2131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 2130-2131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 2130-2132 : Rate A, Rate B, Rate C , 560.0, 560.0, 560.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 2130-2132 : Rate A, Rate B, Rate C , 604.0, 604.0, 604.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 2136-2137 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 2136-2137 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2141-2142 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 2141-2142 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 2155-2156 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 334
% INFO    : Updated Thermal Rating: on transformer 2159-2160 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 282
% INFO    : Updated Thermal Rating: on transformer 2166-2169 : Rate A, Rate B, Rate C , 701.0, 701.0, 701.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 2166-2168 : Rate A, Rate B, Rate C , 701.0, 701.0, 701.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 2178-2179 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 267
% INFO    : Updated Thermal Rating: on line 2179-5920 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 278
% INFO    : Updated Thermal Rating: on line 2179-5933 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 348
% INFO    : Updated Thermal Rating: on transformer 2190-2191 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1157
% INFO    : Updated Thermal Rating: on transformer 2190-2191 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1160
% INFO    : Updated Thermal Rating: on transformer 2216-2217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 2221-2222 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 2226-2227 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 284
% INFO    : Updated Thermal Rating: on transformer 2226-2227 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 284
% INFO    : Updated Thermal Rating: on transformer 2229-2230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 2234-2235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 2234-2235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 2240-5870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on transformer 2241-5870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29046
% INFO    : Updated Thermal Rating: on line 2242-5870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 2247-2248 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 2247-2248 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 2256-2257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 2256-2258 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 210
% INFO    : Updated Thermal Rating: on transformer 2256-2258 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 2257-2258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on transformer 2261-2263 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2265-2266 : Rate A, Rate B, Rate C , 316.0, 316.0, 316.0 -> 282
% INFO    : Updated Thermal Rating: on transformer 2265-2266 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 282
% INFO    : Updated Thermal Rating: on transformer 2265-2266 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 2282-2283 : Rate A, Rate B, Rate C , 1018.0, 1018.0, 1018.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 2285-2286 : Rate A, Rate B, Rate C , 428.0, 428.0, 428.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 2285-2286 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2291-2292 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2291-2292 : Rate A, Rate B, Rate C , 474.0, 474.0, 474.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 2301-2302 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 2301-2302 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2307-2308 : Rate A, Rate B, Rate C , 437.0, 437.0, 437.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 2307-2308 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 2307-2308 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2320-2321 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 2327-2329 : Rate A, Rate B, Rate C , 438.0, 438.0, 438.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2328-2329 : Rate A, Rate B, Rate C , 447.0, 447.0, 447.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 2328-2329 : Rate A, Rate B, Rate C , 438.0, 438.0, 438.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 2337-2339 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 2337-2339 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 2338-2339 : Rate A, Rate B, Rate C , 337.0, 337.0, 337.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 2361-2367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 2360-2365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 2359-2364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 2358-2363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 2357-2362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 2368-2369 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 2368-2369 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2416-2418 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 234
% INFO    : Updated Thermal Rating: on transformer 2416-2417 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 2420-2421 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 183
% INFO    : Updated Thermal Rating: on transformer 2424-2425 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2424-2425 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 2423-2425 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 2423-2425 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2439-2440 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 2439-2441 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 284
% INFO    : Updated Thermal Rating: on transformer 2439-2441 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 2440-2441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 2450-2451 : Rate A, Rate B, Rate C , 1243.0, 1243.0, 1243.0 -> 301
% INFO    : Updated Thermal Rating: on transformer 2450-2451 : Rate A, Rate B, Rate C , 1243.0, 1243.0, 1243.0 -> 315
% INFO    : Updated Thermal Rating: on line 2460-5898 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1099
% INFO    : Updated Thermal Rating: on line 2460-5921 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1089
% INFO    : Updated Thermal Rating: on transformer 2461-2462 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 2461-2462 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 2461-2463 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 2461-2463 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 2475-2477 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 335
% INFO    : Updated Thermal Rating: on transformer 2476-2477 : Rate A, Rate B, Rate C , 530.0, 530.0, 530.0 -> 331
% INFO    : Updated Thermal Rating: on transformer 2475-2477 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 332
% INFO    : Updated Thermal Rating: on transformer 2482-2483 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2482-2483 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 2495-2496 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 2495-2496 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2502-2503 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 2507-2508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 2507-2508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 2509-2510 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2509-2510 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2516-2517 : Rate A, Rate B, Rate C , 437.0, 437.0, 437.0 -> 301
% INFO    : Updated Thermal Rating: on transformer 2532-2533 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2541-2542 : Rate A, Rate B, Rate C , 278.0, 278.0, 278.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 2541-2543 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 2541-2543 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 2542-2543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on transformer 2552-2553 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 2552-2553 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 2559-2560 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2559-2560 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2559-2560 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 2563-2564 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 308
% INFO    : Updated Thermal Rating: on transformer 2563-2564 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 308
% INFO    : Updated Thermal Rating: on transformer 2570-2571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 2570-2573 : Rate A, Rate B, Rate C , 453.0, 453.0, 453.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2571-2573 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 2571-2573 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 2572-2573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on transformer 2576-2577 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 348
% INFO    : Updated Thermal Rating: on transformer 2576-2577 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 341
% INFO    : Updated Thermal Rating: on transformer 2587-2588 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 2587-2588 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2587-2588 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2587-2588 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 2598-2600 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 2598-2599 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 2618-2619 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 280
% INFO    : Updated Thermal Rating: on transformer 2626-2628 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 2627-2628 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2626-2628 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 2647-2648 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 2653-2654 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 2653-2654 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 2656-2658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7637
% INFO    : Updated Thermal Rating: on transformer 2655-5922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on transformer 2657-2659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on transformer 2658-5922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12244
% INFO    : Updated Thermal Rating: on line 2659-5922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on transformer 2660-2661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 2662-2663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 2668-2669 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2668-2669 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 2668-2669 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2677-2678 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2696-2697 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 2696-2697 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2698-2700 : Rate A, Rate B, Rate C , 445.0, 445.0, 445.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2698-2700 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 2699-2700 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 2717-2718 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 2717-2718 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2746-2747 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2746-2747 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 180
% INFO    : Updated Thermal Rating: on transformer 2762-2763 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 331
% INFO    : Updated Thermal Rating: on transformer 2761-5871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on transformer 2762-2764 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 307
% INFO    : Updated Thermal Rating: on transformer 2762-2764 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 314
% INFO    : Updated Thermal Rating: on transformer 2767-2768 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 2769-2770 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 2773-2774 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 292
% INFO    : Updated Thermal Rating: on transformer 2773-2774 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 287
% INFO    : Updated Thermal Rating: on transformer 2772-2775 : Rate A, Rate B, Rate C , 1628.0, 1628.0, 1628.0 -> 314
% INFO    : Updated Thermal Rating: on transformer 2772-2775 : Rate A, Rate B, Rate C , 1628.0, 1628.0, 1628.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 2774-2775 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 885
% INFO    : Updated Thermal Rating: on line 2778-5872 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 883
% INFO    : Updated Thermal Rating: on line 2779-5899 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 982
% INFO    : Updated Thermal Rating: on transformer 2783-2784 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2783-2784 : Rate A, Rate B, Rate C , 721.0, 721.0, 721.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 2789-2791 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 320
% INFO    : Updated Thermal Rating: on transformer 2796-2799 : Rate A, Rate B, Rate C , 604.0, 604.0, 604.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 2797-2799 : Rate A, Rate B, Rate C , 342.0, 342.0, 342.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2798-2799 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 2802-2803 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2802-2803 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2807-2808 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 2807-2808 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 267
% INFO    : Updated Thermal Rating: on transformer 2840-2841 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 2856-2857 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 306
% INFO    : Updated Thermal Rating: on transformer 2856-2857 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 309
% INFO    : Updated Thermal Rating: on line 2886-5874 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 894
% INFO    : Updated Thermal Rating: on line 2886-5924 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1068
% INFO    : Updated Thermal Rating: on line 2886-5934 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 891
% INFO    : Updated Thermal Rating: on transformer 2892-5875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on transformer 2893-5875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2625
% INFO    : Updated Thermal Rating: on line 2894-5875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 2906-2907 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on line 2910-5876 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1166
% INFO    : Updated Thermal Rating: on line 2910-5902 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1178
% INFO    : Updated Thermal Rating: on transformer 2923-2925 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2923-2924 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 267
% INFO    : Updated Thermal Rating: on transformer 2929-2930 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2928-2930 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 240
% INFO    : Updated Thermal Rating: on transformer 2928-2930 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2937-2938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on transformer 2937-2938 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 2939-2940 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 318
% INFO    : Updated Thermal Rating: on transformer 2943-2945 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 2943-2944 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 2951-2952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on transformer 2959-2961 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1159
% INFO    : Updated Thermal Rating: on line 2961-5903 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 891
% INFO    : Updated Thermal Rating: on line 2962-5925 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 989
% INFO    : Updated Thermal Rating: on line 2962-5935 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 981
% INFO    : Updated Thermal Rating: on transformer 2964-2965 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2964-2965 : Rate A, Rate B, Rate C , 469.0, 469.0, 469.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 2977-2978 : Rate A, Rate B, Rate C , 796.0, 796.0, 796.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2977-2978 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 2987-2988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 2988-2991 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2989-2991 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 2992-2993 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 2992-2993 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 2992-2993 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 2994-2995 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 2994-2995 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2994-2995 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 3001-3002 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 3001-3002 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 3008-3009 : Rate A, Rate B, Rate C , 363.0, 363.0, 363.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 3008-3009 : Rate A, Rate B, Rate C , 363.0, 363.0, 363.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 3023-3024 : Rate A, Rate B, Rate C , 307.0, 307.0, 307.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 3023-3024 : Rate A, Rate B, Rate C , 307.0, 307.0, 307.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 3056-3057 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 3056-3057 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3066-3067 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 3066-3067 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 3074-3075 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3074-3075 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3078-3079 : Rate A, Rate B, Rate C , 432.0, 432.0, 432.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 3078-3079 : Rate A, Rate B, Rate C , 432.0, 432.0, 432.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3078-3079 : Rate A, Rate B, Rate C , 432.0, 432.0, 432.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 3080-3081 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 3093-3094 : Rate A, Rate B, Rate C , 378.0, 378.0, 378.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3093-3094 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 3111-3114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3110-3113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3109-3112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3120-3121 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3120-3121 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3127-3128 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 3127-3128 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 3138-3139 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 3138-3139 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 3145-3146 : Rate A, Rate B, Rate C , 712.0, 712.0, 712.0 -> 200
% INFO    : Updated Thermal Rating: on transformer 3145-3147 : Rate A, Rate B, Rate C , 712.0, 712.0, 712.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 3145-3147 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 281
% INFO    : Updated Thermal Rating: on transformer 3157-3158 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3157-3158 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 3168-3169 : Rate A, Rate B, Rate C , 471.0, 471.0, 471.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 3168-3169 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 243
% INFO    : Updated Thermal Rating: on line 3173-5878 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1178
% INFO    : Updated Thermal Rating: on line 3173-5905 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1097
% INFO    : Updated Thermal Rating: on transformer 3190-3192 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3190-3192 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 280
% INFO    : Updated Thermal Rating: on transformer 3190-3192 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 3194-3195 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3194-3195 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3208-3210 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3251-3252 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 308
% INFO    : Updated Thermal Rating: on transformer 3251-3252 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 309
% INFO    : Updated Thermal Rating: on transformer 3262-3263 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3262-3263 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 3262-3263 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 3271-3272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on transformer 3271-3272 : Rate A, Rate B, Rate C , 437.0, 437.0, 437.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 3275-3277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 3274-3276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 3273-3279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3283-3284 : Rate A, Rate B, Rate C , 420.0, 420.0, 420.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 3290-3291 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3304-3305 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 3304-3305 : Rate A, Rate B, Rate C , 470.0, 470.0, 470.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3304-3305 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 3314-3316 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3314-3316 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3315-3316 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3328-3329 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 3328-3329 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 3327-3329 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 3337-3338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 3337-3338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 3338-3339 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 3338-3339 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 3342-3343 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 3342-3343 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 3356-3357 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 3356-3357 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 3359-3360 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 296
% INFO    : Updated Thermal Rating: on transformer 3359-3360 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 296
% INFO    : Updated Thermal Rating: on transformer 3359-3360 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 267
% INFO    : Updated Thermal Rating: on transformer 3364-3365 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 322
% INFO    : Updated Thermal Rating: on transformer 3364-3365 : Rate A, Rate B, Rate C , 1140.0, 1140.0, 1140.0 -> 322
% INFO    : Updated Thermal Rating: on transformer 3373-3374 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 3373-3374 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 3373-3374 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 3389-3390 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3389-3390 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3392-3393 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3392-3393 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3392-3393 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 3425-3426 : Rate A, Rate B, Rate C , 710.0, 710.0, 710.0 -> 204
% INFO    : Updated Thermal Rating: on transformer 3425-3426 : Rate A, Rate B, Rate C , 710.0, 710.0, 710.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 3434-3435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 3434-3435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 3475-3478 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 3475-3478 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 3476-3478 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 3495-3497 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3498-3499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 3501-3502 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 3507-3509 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 3507-3508 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 3510-3511 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 3510-3511 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 3510-3511 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 3512-3513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3514-3516 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3515-3516 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3515-3516 : Rate A, Rate B, Rate C , 758.0, 758.0, 758.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 3531-3532 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 3531-3532 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 3535-3536 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 3538-3539 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 3538-3539 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 3538-3539 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 280
% INFO    : Updated Thermal Rating: on transformer 3548-3549 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3548-3549 : Rate A, Rate B, Rate C , 481.0, 481.0, 481.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3552-3553 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 3552-3553 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 3552-3553 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 182
% INFO    : Updated Thermal Rating: on transformer 3554-3555 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 3554-3556 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 3557-3558 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 3565-3566 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 185
% INFO    : Updated Thermal Rating: on transformer 3565-3566 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 190
% INFO    : Updated Thermal Rating: on transformer 3571-3572 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3579-3581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 3580-3582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 3587-3588 : Rate A, Rate B, Rate C , 313.0, 313.0, 313.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 3589-3590 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 3593-3594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 3595-3596 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 238
% INFO    : Updated Thermal Rating: on transformer 3601-3602 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3607-3608 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1171
% INFO    : Updated Thermal Rating: on line 3609-5879 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 974
% INFO    : Updated Thermal Rating: on line 3609-5906 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1046
% INFO    : Updated Thermal Rating: on line 3608-5926 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 985
% INFO    : Updated Thermal Rating: on line 3608-5936 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1003
% INFO    : Updated Thermal Rating: on transformer 3612-3613 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3612-3613 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3612-3613 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3616-3617 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 3623-3624 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 3623-3624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 3623-3624 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3640-3641 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 3640-3641 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 3647-3648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3646-3648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3655-3656 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 3657-3658 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3657-3658 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3657-3658 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 3657-3658 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 3662-3663 : Rate A, Rate B, Rate C , 316.0, 316.0, 316.0 -> 284
% INFO    : Updated Thermal Rating: on transformer 3662-3663 : Rate A, Rate B, Rate C , 326.0, 326.0, 326.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 3666-3667 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 283
% INFO    : Updated Thermal Rating: on transformer 3666-3667 : Rate A, Rate B, Rate C , 274.0, 274.0, 274.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 3666-3667 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 3670-3671 : Rate A, Rate B, Rate C , 722.0, 722.0, 722.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 3670-3671 : Rate A, Rate B, Rate C , 722.0, 722.0, 722.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 3670-3671 : Rate A, Rate B, Rate C , 722.0, 722.0, 722.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 3696-3697 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1153
% INFO    : Updated Thermal Rating: on line 3697-5880 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1031
% INFO    : Updated Thermal Rating: on transformer 3701-3702 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3703-3704 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3703-3704 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 3719-3720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 3719-3721 : Rate A, Rate B, Rate C , 290.0, 290.0, 290.0 -> 117
% INFO    : Updated Thermal Rating: on transformer 3720-3722 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 3726-3727 : Rate A, Rate B, Rate C , 530.0, 530.0, 530.0 -> 340
% INFO    : Updated Thermal Rating: on transformer 3728-3730 : Rate A, Rate B, Rate C , 439.0, 439.0, 439.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3728-3730 : Rate A, Rate B, Rate C , 439.0, 439.0, 439.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3728-3730 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3728-3730 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 3734-3735 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 3737-3738 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 3737-3738 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 3750-3751 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 3750-3751 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 3755-3756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 3755-3756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 3755-3756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 3765-3766 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 314
% INFO    : Updated Thermal Rating: on transformer 3765-3766 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 317
% INFO    : Updated Thermal Rating: on transformer 3769-3773 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3770-3772 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3769-3773 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3768-3771 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3782-3784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 3781-3784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 3780-3783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 3801-3802 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 3801-3802 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 3802-3803 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1134
% INFO    : Updated Thermal Rating: on transformer 3810-3813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3809-3812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3808-3811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3822-3824 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 3823-3824 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 3832-3833 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 3842-3843 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 3842-3843 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 3846-3848 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 3847-3848 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 3865-3866 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 3865-3866 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 3870-3871 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 3870-3871 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 3870-3871 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 3872-3873 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 258
% INFO    : Updated Thermal Rating: on line 3873-5927 : Rate A, Rate B, Rate C , 482.0, 482.0, 482.0 -> 317
% INFO    : Updated Thermal Rating: on transformer 3880-3881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3889-3890 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 3892-3893 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 3892-3893 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 3897-3899 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1180
% INFO    : Updated Thermal Rating: on transformer 3908-3909 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 3908-3909 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3908-3909 : Rate A, Rate B, Rate C , 378.0, 378.0, 378.0 -> 238
% INFO    : Updated Thermal Rating: on transformer 3915-3917 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 3916-3917 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 3919-3920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 3922-3923 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3922-3923 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 3928-3929 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 3961-3962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 3960-3963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 3970-3972 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 3971-3972 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 3996-3997 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 3996-3997 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 4000-4001 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 4000-4001 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 4002-4003 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 4009-4010 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 215
% INFO    : Updated Thermal Rating: on transformer 4009-4010 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 211
% INFO    : Updated Thermal Rating: on transformer 4018-4019 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 4018-4019 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 4028-4029 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 182
% INFO    : Updated Thermal Rating: on transformer 4037-4038 : Rate A, Rate B, Rate C , 453.0, 453.0, 453.0 -> 197
% INFO    : Updated Thermal Rating: on line 4041-5882 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1039
% INFO    : Updated Thermal Rating: on transformer 4055-4056 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 4069-5883 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 4068-5908 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 4080-4081 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 4080-4081 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4084-4085 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4086-4087 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 4093-4094 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4093-4094 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on line 4098-5884 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1158
% INFO    : Updated Thermal Rating: on transformer 4102-4103 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 4102-4103 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 190
% INFO    : Updated Thermal Rating: on transformer 4110-4111 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 4110-4111 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 4112-4113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on transformer 4113-4114 : Rate A, Rate B, Rate C , 712.0, 712.0, 712.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 4132-4134 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 4133-4134 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4133-4134 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 4133-4134 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 4135-4136 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 4135-4136 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 4140-4141 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4139-4141 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 4139-4141 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 4156-4157 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 4156-4157 : Rate A, Rate B, Rate C , 327.0, 327.0, 327.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 4162-4163 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 309
% INFO    : Updated Thermal Rating: on transformer 4164-4165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10522
% INFO    : Updated Thermal Rating: on transformer 4173-4174 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 4173-4174 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 4199-4201 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 4199-4201 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 4202-4203 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 4202-4203 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 233
% INFO    : Updated Thermal Rating: on transformer 4208-4210 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 4209-4210 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 4209-4210 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 280
% INFO    : Updated Thermal Rating: on transformer 4208-4210 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 4216-4213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4218-4219 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 4217-4219 : Rate A, Rate B, Rate C , 293.0, 293.0, 293.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 4234-4235 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 307
% INFO    : Updated Thermal Rating: on transformer 4240-4262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on transformer 4242-4243 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 4242-4243 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4245-4246 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4247-4248 : Rate A, Rate B, Rate C , 726.0, 726.0, 726.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4247-4248 : Rate A, Rate B, Rate C , 726.0, 726.0, 726.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4266-5885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 4267-5885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 4268-5885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3573
% INFO    : Updated Thermal Rating: on transformer 4282-4283 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 138
% INFO    : Updated Thermal Rating: on transformer 4281-4283 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 139
% INFO    : Updated Thermal Rating: on transformer 4281-4283 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 143
% INFO    : Updated Thermal Rating: on transformer 4281-4283 : Rate A, Rate B, Rate C , 304.0, 304.0, 304.0 -> 131
% INFO    : Updated Thermal Rating: on transformer 4285-4286 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 4295-4296 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 234
% INFO    : Updated Thermal Rating: on transformer 4302-4303 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 4302-4304 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 4315-4316 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 4321-4324 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 283
% INFO    : Updated Thermal Rating: on transformer 4322-4324 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 4322-4323 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 4321-4323 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 4333-4335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4332-4335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4331-4335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4334-4335 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 4334-4335 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4338-4339 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 4338-4339 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 283
% INFO    : Updated Thermal Rating: on transformer 4338-4339 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 278
% INFO    : Updated Thermal Rating: on transformer 4347-4345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40897
% INFO    : Updated Thermal Rating: on transformer 4380-4381 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 4380-4381 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4382-4384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4389-4390 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 4389-4390 : Rate A, Rate B, Rate C , 432.0, 432.0, 432.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 1493-4398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 4412-4414 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 4413-4414 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4434-4436 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4434-4436 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4435-4436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 4447-4449 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 4452-4453 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 285
% INFO    : Updated Thermal Rating: on transformer 4452-4453 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 4452-4453 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 4457-4458 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 4457-4458 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 4456-4458 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 4467-4468 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 4467-4468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 4470-4475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 4474-4479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 4473-4478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 4472-4477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 4471-4476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on transformer 4493-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on transformer 4494-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 4496-4497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 4503-4504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 4508-4509 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 4508-4509 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 211
% INFO    : Updated Thermal Rating: on transformer 4518-4520 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4519-4520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 4530-4531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 4535-4536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on transformer 4535-4536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on transformer 4535-4537 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 258
% INFO    : Updated Thermal Rating: on line 4543-5886 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1099
% INFO    : Updated Thermal Rating: on line 4543-5909 : Rate A, Rate B, Rate C , 1174.0, 1174.0, 1174.0 -> 1166
% INFO    : Updated Thermal Rating: on transformer 4550-4551 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 238
% INFO    : Updated Thermal Rating: on transformer 4550-4552 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 4551-4552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 4564-4565 : Rate A, Rate B, Rate C , 1217.0, 1217.0, 1217.0 -> 293
% INFO    : Updated Thermal Rating: on transformer 4568-4569 : Rate A, Rate B, Rate C , 1266.0, 1266.0, 1266.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 4568-4569 : Rate A, Rate B, Rate C , 1266.0, 1266.0, 1266.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 4587-4589 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 312
% INFO    : Updated Thermal Rating: on transformer 4587-4588 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 311
% INFO    : Updated Thermal Rating: on transformer 4590-4591 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4590-4591 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4593-4594 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1159
% INFO    : Updated Thermal Rating: on transformer 4593-4595 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1065
% INFO    : Updated Thermal Rating: on transformer 4602-4603 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 4602-4603 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 199
% INFO    : Updated Thermal Rating: on transformer 4602-4603 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 223
% INFO    : Updated Thermal Rating: on transformer 4610-4611 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 4610-4611 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 4631-4633 : Rate A, Rate B, Rate C , 1140.0, 1140.0, 1140.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 4631-4632 : Rate A, Rate B, Rate C , 1140.0, 1140.0, 1140.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 4641-4642 : Rate A, Rate B, Rate C , 711.0, 711.0, 711.0 -> 204
% INFO    : Updated Thermal Rating: on transformer 4641-4642 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 317
% INFO    : Updated Thermal Rating: on transformer 4641-4642 : Rate A, Rate B, Rate C , 711.0, 711.0, 711.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 4644-4646 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 4644-4645 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 248
% INFO    : Updated Thermal Rating: on line 4656-5929 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 976
% INFO    : Updated Thermal Rating: on line 4656-5938 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 983
% INFO    : Updated Thermal Rating: on transformer 4666-4667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7637
% INFO    : Updated Thermal Rating: on transformer 4668-4669 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4668-4669 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 4668-4669 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4669-4670 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 993
% INFO    : Updated Thermal Rating: on transformer 4669-4670 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 991
% INFO    : Updated Thermal Rating: on transformer 4674-4676 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 4674-4676 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 4674-4676 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 4674-4676 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 4681-4682 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 4681-4682 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 4703-4706 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 4702-4706 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 4699-4706 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 4698-4706 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 4713-4714 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4713-4714 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4735-4736 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 4735-4736 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4735-4736 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4737-4738 : Rate A, Rate B, Rate C , 374.0, 374.0, 374.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 4737-4738 : Rate A, Rate B, Rate C , 374.0, 374.0, 374.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 4759-4760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on transformer 4765-4766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 4771-4772 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 4771-4772 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 4775-4776 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 4795-4796 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4795-4796 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 4801-4803 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 306
% INFO    : Updated Thermal Rating: on transformer 4801-4803 : Rate A, Rate B, Rate C , 508.0, 508.0, 508.0 -> 307
% INFO    : Updated Thermal Rating: on transformer 4812-4814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 4811-4813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 4817-4821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on transformer 4820-4821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 367
% INFO    : Updated Thermal Rating: on transformer 4818-4821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 367
% INFO    : Updated Thermal Rating: on transformer 4819-4821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on transformer 4822-4824 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 4822-4823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 4822-4823 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 265
% INFO    : Updated Thermal Rating: on transformer 4822-4823 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 4824-4825 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1176
% INFO    : Updated Thermal Rating: on transformer 4823-4825 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1167
% INFO    : Updated Thermal Rating: on transformer 4823-4825 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1149
% INFO    : Updated Thermal Rating: on transformer 4842-4843 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 279
% INFO    : Updated Thermal Rating: on transformer 4842-4843 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 4847-4848 : Rate A, Rate B, Rate C , 453.0, 453.0, 453.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 4852-4853 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 4852-4853 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 178
% INFO    : Updated Thermal Rating: on line 4854-5910 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1175
% INFO    : Updated Thermal Rating: on transformer 4857-4858 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 4857-4858 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 4857-4858 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4875-4876 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 4875-4876 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 4895-4897 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 4895-4896 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 4910-4912 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 4909-4912 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 4910-4912 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 4911-4912 : Rate A, Rate B, Rate C , 358.0, 358.0, 358.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 4916-4917 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 4916-4917 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 4921-4922 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 4921-4922 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4921-4922 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 4935-4936 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 4949-4951 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 4949-4951 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 255
% INFO    : Updated Thermal Rating: on line 4952-5888 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1046
% INFO    : Updated Thermal Rating: on line 4952-5911 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1041
% INFO    : Updated Thermal Rating: on line 4952-5930 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 983
% INFO    : Updated Thermal Rating: on line 4952-5939 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 983
% INFO    : Updated Thermal Rating: on line 4952-5945 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 886
% INFO    : Updated Thermal Rating: on transformer 4953-4955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40922
% INFO    : Updated Thermal Rating: on transformer 4954-4955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on transformer 4954-4955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 4954-4955 : Rate A, Rate B, Rate C , 302.0, 302.0, 302.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 4960-4962 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 4960-4961 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 311
% INFO    : Updated Thermal Rating: on transformer 4966-4968 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 4967-4968 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 4968-4970 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1159
% INFO    : Updated Thermal Rating: on line 4970-5912 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 885
% INFO    : Updated Thermal Rating: on line 4970-5940 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1041
% INFO    : Updated Thermal Rating: on transformer 4974-4975 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 4974-4975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 4979-4982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 4978-4981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 4977-4980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 4983-4985 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 4987-4988 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 4991-4992 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 4993-4994 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 4998-4999 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 4998-4999 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 5027-5028 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 5045-5046 : Rate A, Rate B, Rate C , 511.0, 511.0, 511.0 -> 342
% INFO    : Updated Thermal Rating: on transformer 5071-5072 : Rate A, Rate B, Rate C , 303.0, 303.0, 303.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 5078-5079 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1145
% INFO    : Updated Thermal Rating: on transformer 5955-5956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 674
% INFO    : Updated Thermal Rating: on transformer 5954-5956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 691
% INFO    : Updated Thermal Rating: on transformer 5961-5962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1192
% INFO    : Updated Thermal Rating: on transformer 5963-5964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1364
% INFO    : Updated Thermal Rating: on transformer 5973-5975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1348
% INFO    : Updated Thermal Rating: on transformer 5974-5975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1348
% INFO    : Updated Thermal Rating: on transformer 6188-5993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11039
% INFO    : Updated Thermal Rating: on transformer 5992-6188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6986
% INFO    : Updated Thermal Rating: on transformer 6011-6013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1892
% INFO    : Updated Thermal Rating: on transformer 6012-6014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1968
% INFO    : Updated Thermal Rating: on transformer 6024-6025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1892
% INFO    : Updated Thermal Rating: on transformer 6029-6031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1151
% INFO    : Updated Thermal Rating: on transformer 6047-6048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2596
% INFO    : Updated Thermal Rating: on transformer 6051-6054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 6052-6053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 6057-6059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on transformer 6058-6059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on transformer 6063-6064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1125
% INFO    : Updated Thermal Rating: on transformer 6063-6064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1287
% INFO    : Updated Thermal Rating: on transformer 6071-6072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1145
% INFO    : Updated Thermal Rating: on transformer 6075-6076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 6075-6076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1316
% INFO    : Updated Thermal Rating: on transformer 6083-6085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2279
% INFO    : Updated Thermal Rating: on transformer 6088-6090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1842
% INFO    : Updated Thermal Rating: on transformer 6095-6096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on transformer 6111-6112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on transformer 6125-6126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1837
% INFO    : Updated Thermal Rating: on transformer 6139-6140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 765
% INFO    : Updated Thermal Rating: on transformer 6139-6140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 6143-6144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1509
% INFO    : Updated Thermal Rating: on transformer 6163-6164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1689
% INFO    : Updated Thermal Rating: on transformer 6169-6170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on transformer 6173-6174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1344
% INFO    : Updated Thermal Rating: on transformer 6173-6174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1355
% INFO    : Updated Thermal Rating: on transformer 6173-6174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1359
% INFO    : Updated Thermal Rating: on transformer 6175-6176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 6200-6201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 803
% INFO    : Updated Thermal Rating: on transformer 6196-6210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55237
% INFO    : Updated Thermal Rating: on transformer 6196-6209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2200
% INFO    : Updated Thermal Rating: on transformer 6222-6223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on transformer 6222-6223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on transformer 6222-6223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1850
% INFO    : Updated Thermal Rating: on transformer 6234-6235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 6232-6235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 6233-6235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 6231-6235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 6236-6237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1471
% INFO    : Updated Thermal Rating: on transformer 6236-6237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on transformer 115-6245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on transformer 116-6246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on transformer 200-6247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 200-6248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 200-6249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 230-6250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on transformer 230-6251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on transformer 247-6252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on transformer 271-6253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 271-6254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 270-6255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 270-6256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 366-6257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 366-6258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 367-6259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 367-6260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 368-6261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 368-6262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 500-6268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 499-6269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 501-6270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 779
% INFO    : Updated Thermal Rating: on transformer 501-6272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on transformer 527-6273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 527-6274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 527-6275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 527-6276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 527-6277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 2790-6278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 616-6279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on transformer 616-6280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 616-6281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 623-6282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 624-6283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 624-6284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on transformer 694-6291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 694-6292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 694-6293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 693-6294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 693-6295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 693-6296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 715-6297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 1002-6301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 1042-6302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on transformer 1049-6303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 634
% INFO    : Updated Thermal Rating: on transformer 73-6312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on transformer 72-6313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on transformer 2100-6314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on transformer 1171-6315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1759
% INFO    : Updated Thermal Rating: on transformer 1174-6319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1588
% INFO    : Updated Thermal Rating: on transformer 1176-6320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on transformer 1176-6321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 1441-6322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1441-6323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1441-6324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1441-6325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1441-6326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1441-6327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 1335-6332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1335-6333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1361-6334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on transformer 1360-6335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on transformer 1602-6341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on transformer 1866-6344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on transformer 1954-6345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1955-6346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1955-6347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 1955-6348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on transformer 1954-6349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on transformer 2014-6352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 2014-6353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 2047-6355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 2047-6356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 2128-6363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on transformer 2193-6366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on transformer 2194-6367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1616
% INFO    : Updated Thermal Rating: on transformer 2215-6369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on transformer 2215-6370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on transformer 2235-6371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on transformer 2235-6372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on transformer 2393-6373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 2393-6374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 2453-6375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 2654-6376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 2654-6377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 2654-6378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 2654-6379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 2610-6380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on transformer 2646-6381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on transformer 2646-6382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on transformer 2697-6383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 2697-6384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on transformer 2697-6385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2697-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 2703-6387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 2703-6388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 2703-6389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 2720-6390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2742-6391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 2742-6392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 2742-6393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 2742-6394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 2814-6395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 2853-6397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 2853-6398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 4397-6399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on transformer 3031-6401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 3031-6402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 3048-6403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on transformer 3047-6404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on transformer 3051-6405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on transformer 3051-6406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on transformer 3050-6407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on transformer 3050-6408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on transformer 3081-6409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on transformer 3081-6410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on transformer 3142-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on transformer 3143-6415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1000
% INFO    : Updated Thermal Rating: on transformer 3246-6417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 3246-6418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 3256-6419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on transformer 3339-6424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on transformer 3472-6427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1594
% INFO    : Updated Thermal Rating: on transformer 3471-6428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1594
% INFO    : Updated Thermal Rating: on transformer 3469-6430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on transformer 3486-6431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 3486-6432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 3486-6433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 3497-6434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on transformer 3588-6437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on transformer 3588-6438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on transformer 3600-6439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 3680-6440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 3680-6441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 3695-6443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on transformer 3718-6444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 3717-6445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 3716-6446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 3721-6447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 3721-6448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 3721-6449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 3721-6450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 3799-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on transformer 3983-6452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on transformer 3988-6453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 3988-6454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 4012-6455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 4012-6456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 4012-6457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 4012-6458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 4038-6459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on transformer 4038-6460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on transformer 4044-6461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 4044-6462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 4136-6463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on transformer 4246-6470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on transformer 4246-6471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on transformer 4254-6472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4254-6473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4256-6474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on transformer 4255-6475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on transformer 4261-6476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on transformer 4286-6479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 4286-6480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 4286-6481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 4499-6482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on transformer 4520-6483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 4520-6484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 4756-6489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on transformer 4756-6490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on transformer 4755-6491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on transformer 4787-6492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 4787-6493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 4787-6494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 4934-6495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 4933-6496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 4942-6497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on transformer 4999-6498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on transformer 4999-6499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 1	: V=0.979893048, theta=-10.3768261 -> V=0.9444445, theta=0.0
% INFO    : Bus 2	: V=1.03715026, theta=-10.3554691 -> V=0.999999, theta=0.0
% INFO    : Bus 3	: V=1.02433173, theta=-12.8534061 -> V=1.0158755, theta=0.0
% INFO    : Bus 4	: V=1.03921351, theta=-24.1153288 -> V=1.0111115, theta=0.0
% INFO    : Bus 5	: V=1.01936346, theta=-52.5501319 -> V=1.0079355, theta=0.0
% INFO    : Bus 6	: V=1.02004802, theta=-21.2483732 -> V=1.0000025, theta=0.0
% INFO    : Bus 7	: V=1.04792706, theta=-23.3284608 -> V=1.0000025, theta=0.0
% INFO    : Bus 8	: V=1.04830196, theta=-17.3700741 -> V=0.9888895, theta=0.0
% INFO    : Bus 9	: V=1.04575179, theta=-17.7128995 -> V=0.999999, theta=0.0
% INFO    : Bus 10	: V=1.03364016, theta=-22.9721855 -> V=1.000001, theta=0.0
% INFO    : Bus 11	: V=1.03363994, theta=-22.972183 -> V=1.000001, theta=0.0
% INFO    : Bus 12	: V=1.01664069, theta=1.01323791 -> V=1.0158755, theta=0.0
% INFO    : Bus 13	: V=1.05890193, theta=-3.64645757 -> V=1.07788, theta=0.0
% INFO    : Bus 14	: V=1.0671468, theta=-31.2262094 -> V=1.027779, theta=0.0
% INFO    : Bus 15	: V=1.03133856, theta=-23.3422562 -> V=1.0000025, theta=0.0
% INFO    : Bus 16	: V=1.03134679, theta=-29.0313207 -> V=1.0000025, theta=0.0
% INFO    : Bus 17	: V=1.04794596, theta=-31.3481823 -> V=1.022224, theta=0.0
% INFO    : Bus 18	: V=0.936377787, theta=-5.06544702 -> V=0.9444445, theta=0.0
% INFO    : Bus 19	: V=1.03087171, theta=-20.3196785 -> V=0.999999, theta=0.0
% INFO    : Bus 20	: V=0.937158468, theta=-5.10023226 -> V=0.9444445, theta=0.0
% INFO    : Bus 21	: V=1.03894873, theta=-19.7127085 -> V=1.022224, theta=0.0
% INFO    : Bus 22	: V=1.02417072, theta=-13.0166794 -> V=1.0158755, theta=0.0
% INFO    : Bus 23	: V=1.01426878, theta=-10.2175532 -> V=0.999999, theta=0.0
% INFO    : Bus 24	: V=1.04175688, theta=-22.5362878 -> V=1.033333, theta=0.0
% INFO    : Bus 25	: V=1.07638926, theta=-18.9285736 -> V=1.022222, theta=0.0
% INFO    : Bus 26	: V=1.0352752, theta=-25.1015831 -> V=1.022224, theta=0.0
% INFO    : Bus 27	: V=1.06660839, theta=-20.5147974 -> V=1.04444, theta=0.0
% INFO    : Bus 28	: V=1.03351276, theta=-20.2158954 -> V=1.0158755, theta=0.0
% INFO    : Bus 29	: V=0.993975162, theta=-23.136013 -> V=1.015872, theta=0.0
% INFO    : Bus 30	: V=1.03314256, theta=-23.1778346 -> V=1.0111115, theta=0.0
% INFO    : Bus 31	: V=1.03625024, theta=-8.99316829 -> V=0.999999, theta=0.0
% INFO    : Bus 32	: V=1.04470302, theta=-3.80682716 -> V=1.003335, theta=0.0
% INFO    : Bus 33	: V=1.05413664, theta=-6.21339632 -> V=1.0111115, theta=0.0
% INFO    : Bus 34	: V=1.04983156, theta=-5.54355372 -> V=1.0111115, theta=0.0
% INFO    : Bus 35	: V=1.07133358, theta=-4.99227828 -> V=1.072365, theta=0.0
% INFO    : Bus 36	: V=1.07322038, theta=-3.90267037 -> V=1.072365, theta=0.0
% INFO    : Bus 37	: V=1.01508935, theta=-25.6290612 -> V=1.0000025, theta=0.0
% INFO    : Bus 38	: V=1.03528191, theta=-20.7803563 -> V=1.015874, theta=0.0
% INFO    : Bus 39	: V=1.0138152, theta=-38.8457623 -> V=1.027779, theta=0.0
% INFO    : Bus 40	: V=1.05527447, theta=-29.4760069 -> V=1.027779, theta=0.0
% INFO    : Bus 41	: V=1.07410025, theta=-25.8455379 -> V=1.04798, theta=0.0
% INFO    : Bus 42	: V=1.12162006, theta=4.48114191 -> V=1.0403605, theta=0.0
% INFO    : Bus 43	: V=1.04783898, theta=-26.6714372 -> V=1.027779, theta=0.0
% INFO    : Bus 44	: V=1.02768593, theta=-49.8132016 -> V=1.0079355, theta=0.0
% INFO    : Bus 45	: V=1.02336375, theta=-33.4018313 -> V=1.022224, theta=0.0
% INFO    : Bus 46	: V=1.03292446, theta=-15.1098515 -> V=0.999999, theta=0.0
% INFO    : Bus 47	: V=1.027, theta=-12.083344 -> V=0.999999, theta=0.0
% INFO    : Bus 48	: V=1.03526823, theta=-23.9652248 -> V=1.000001, theta=0.0
% INFO    : Bus 49	: V=1.03702466, theta=-15.8386251 -> V=0.999999, theta=0.0
% INFO    : Bus 50	: V=1.07071557, theta=-13.4433142 -> V=1.005544, theta=0.0
% INFO    : Bus 51	: V=1.05549555, theta=-8.72688394 -> V=1.0111115, theta=0.0
% INFO    : Bus 52	: V=1.03612192, theta=-34.8372976 -> V=1.022224, theta=0.0
% INFO    : Bus 53	: V=1.00766185, theta=-27.119197 -> V=1.0000005, theta=0.0
% INFO    : Bus 54	: V=1.03886174, theta=-17.8087968 -> V=1.022224, theta=0.0
% INFO    : Bus 55	: V=1.07439337, theta=-28.5325781 -> V=1.047175, theta=0.0
% INFO    : Bus 56	: V=1.06403386, theta=-24.7163715 -> V=1.046665, theta=0.0
% INFO    : Bus 57	: V=1.061, theta=-19.0743248 -> V=1.0000025, theta=0.0
% INFO    : Bus 58	: V=1.07422414, theta=-28.5476197 -> V=1.047095, theta=0.0
% INFO    : Bus 59	: V=1.04830263, theta=-11.1695545 -> V=1.0158755, theta=0.0
% INFO    : Bus 60	: V=1.03839799, theta=-5.55113533 -> V=1.0158755, theta=0.0
% INFO    : Bus 61	: V=1.04122846, theta=-7.53885721 -> V=1.0158755, theta=0.0
% INFO    : Bus 62	: V=1.02509397, theta=-5.66246789 -> V=1.0158755, theta=0.0
% INFO    : Bus 63	: V=1.01103702, theta=0.0424383585 -> V=1.0158755, theta=0.0
% INFO    : Bus 64	: V=1.06588036, theta=-16.5426802 -> V=0.9888895, theta=0.0
% INFO    : Bus 65	: V=1.05154171, theta=-8.12705692 -> V=1.0158755, theta=0.0
% INFO    : Bus 66	: V=1.0416174, theta=-24.3594319 -> V=0.999999, theta=0.0
% INFO    : Bus 67	: V=1.04174355, theta=-20.4532918 -> V=1.0000025, theta=0.0
% INFO    : Bus 68	: V=1.02271664, theta=-15.0424467 -> V=0.999999, theta=0.0
% INFO    : Bus 69	: V=1.0446944, theta=-53.9257484 -> V=1.0079355, theta=0.0
% INFO    : Bus 70	: V=1.0211168, theta=1.75224351 -> V=1.0158755, theta=0.0
% INFO    : Bus 71	: V=1.02187174, theta=-27.6353903 -> V=1.0000005, theta=0.0
% INFO    : Bus 72	: V=1.07905772, theta=-20.4454849 -> V=1.04668, theta=0.0
% INFO    : Bus 73	: V=1.07905853, theta=-20.4447201 -> V=1.04668, theta=0.0
% INFO    : Bus 74	: V=1.06637837, theta=-16.3923304 -> V=0.9888895, theta=0.0
% INFO    : Bus 75	: V=1.04842048, theta=-21.1820269 -> V=1.022224, theta=0.0
% INFO    : Bus 76	: V=1.07517032, theta=3.47900906 -> V=1.0377785, theta=0.0
% INFO    : Bus 77	: V=1.02800455, theta=-16.3349876 -> V=0.999999, theta=0.0
% INFO    : Bus 78	: V=1.03831897, theta=-26.3244184 -> V=1.0000025, theta=0.0
% INFO    : Bus 79	: V=1.01089841, theta=-26.183276 -> V=1.0000005, theta=0.0
% INFO    : Bus 80	: V=1.04923048, theta=-25.848135 -> V=1.046665, theta=0.0
% INFO    : Bus 81	: V=1.04924992, theta=-25.8480644 -> V=1.046665, theta=0.0
% INFO    : Bus 82	: V=1.0384376, theta=-16.7259604 -> V=0.999999, theta=0.0
% INFO    : Bus 83	: V=1.05946458, theta=-26.2942368 -> V=1.046665, theta=0.0
% INFO    : Bus 84	: V=1.02536595, theta=-12.5330646 -> V=0.999999, theta=0.0
% INFO    : Bus 85	: V=1.04847454, theta=-16.0537832 -> V=1.001094, theta=0.0
% INFO    : Bus 86	: V=1.03240006, theta=-42.3544522 -> V=1.022224, theta=0.0
% INFO    : Bus 87	: V=1.02476015, theta=0.189234452 -> V=1.0158755, theta=0.0
% INFO    : Bus 88	: V=1.03992315, theta=-18.4990468 -> V=0.999999, theta=0.0
% INFO    : Bus 89	: V=1.04374964, theta=-29.2142493 -> V=1.027779, theta=0.0
% INFO    : Bus 90	: V=0.941141294, theta=-5.76927592 -> V=0.9444445, theta=0.0
% INFO    : Bus 91	: V=0.936377787, theta=-5.06544702 -> V=0.9444445, theta=0.0
% INFO    : Bus 92	: V=1.01482002, theta=-18.9752952 -> V=1.015872, theta=0.0
% INFO    : Bus 93	: V=0.953435375, theta=-7.72442804 -> V=0.9444445, theta=0.0
% INFO    : Bus 94	: V=1.04421444, theta=-24.0559689 -> V=1.022224, theta=0.0
% INFO    : Bus 95	: V=1.03697618, theta=-34.730461 -> V=1.022224, theta=0.0
% INFO    : Bus 96	: V=1.05121477, theta=-8.32668915 -> V=0.999999, theta=0.0
% INFO    : Bus 97	: V=1.03680942, theta=-23.8967173 -> V=1.0000025, theta=0.0
% INFO    : Bus 98	: V=1.03306301, theta=-19.305384 -> V=1.0158755, theta=0.0
% INFO    : Bus 99	: V=1.04753422, theta=-7.21416459 -> V=1.0158755, theta=0.0
% INFO    : Bus 100	: V=1.02153611, theta=-14.1138264 -> V=0.999999, theta=0.0
% INFO    : Bus 101	: V=1.01462219, theta=-13.3414563 -> V=0.999999, theta=0.0
% INFO    : Bus 102	: V=1.03, theta=-14.7394089 -> V=1.0158755, theta=0.0
% INFO    : Bus 103	: V=1.04168196, theta=-5.9124754 -> V=1.0158755, theta=0.0
% INFO    : Bus 104	: V=1.07376319, theta=-3.24103261 -> V=1.0377785, theta=0.0
% INFO    : Bus 105	: V=1.0476859, theta=-15.0454002 -> V=0.9888895, theta=0.0
% INFO    : Bus 106	: V=1.05807326, theta=-19.8747997 -> V=1.022222, theta=0.0
% INFO    : Bus 107	: V=1.04740374, theta=-28.4302924 -> V=1.046665, theta=0.0
% INFO    : Bus 108	: V=1.05194743, theta=-24.8950195 -> V=1.027779, theta=0.0
% INFO    : Bus 109	: V=1.04888746, theta=-12.4858197 -> V=1.002439, theta=0.0
% INFO    : Bus 110	: V=1.03317493, theta=-8.83146225 -> V=1.0111115, theta=0.0
% INFO    : Bus 111	: V=1.00285431, theta=-21.3961828 -> V=1.015872, theta=0.0
% INFO    : Bus 112	: V=1.02277458, theta=-27.3291888 -> V=1.0000005, theta=0.0
% INFO    : Bus 113	: V=1.05428214, theta=-23.8486593 -> V=1.046665, theta=0.0
% INFO    : Bus 114	: V=1.04699471, theta=-11.7135619 -> V=0.999999, theta=0.0
% INFO    : Bus 115	: V=1.05891111, theta=-3.64654095 -> V=1.078945, theta=0.0
% INFO    : Bus 116	: V=1.05891111, theta=-3.64654095 -> V=1.078945, theta=0.0
% INFO    : Bus 117	: V=1.02390906, theta=-18.3028877 -> V=1.0158755, theta=0.0
% INFO    : Bus 118	: V=1.0508012, theta=-20.8600636 -> V=1.022224, theta=0.0
% INFO    : Bus 119	: V=1.01921766, theta=-10.1804408 -> V=0.999999, theta=0.0
% INFO    : Bus 120	: V=1.01796489, theta=-9.15733727 -> V=0.999999, theta=0.0
% INFO    : Bus 121	: V=1.02368034, theta=-25.6646161 -> V=1.0000025, theta=0.0
% INFO    : Bus 122	: V=1.038, theta=-6.82675392 -> V=1.0158755, theta=0.0
% INFO    : Bus 123	: V=1.0359314, theta=-6.95350482 -> V=1.0158755, theta=0.0
% INFO    : Bus 124	: V=1.04547533, theta=-27.3968828 -> V=1.022224, theta=0.0
% INFO    : Bus 125	: V=1.03277618, theta=-13.6066251 -> V=1.0158755, theta=0.0
% INFO    : Bus 126	: V=1.05036369, theta=-16.0236274 -> V=0.999999, theta=0.0
% INFO    : Bus 127	: V=1.01431466, theta=-30.0051866 -> V=1.0000005, theta=0.0
% INFO    : Bus 128	: V=1.02103073, theta=-11.2979252 -> V=1.015872, theta=0.0
% INFO    : Bus 129	: V=1.01953551, theta=-9.55719239 -> V=1.015872, theta=0.0
% INFO    : Bus 130	: V=1.04904375, theta=-8.72555958 -> V=1.046665, theta=0.0
% INFO    : Bus 131	: V=1.04723325, theta=-16.2594936 -> V=1.046665, theta=0.0
% INFO    : Bus 132	: V=1.068, theta=-17.1797687 -> V=1.000001, theta=0.0
% INFO    : Bus 133	: V=0.985771946, theta=-29.7504791 -> V=1.0000005, theta=0.0
% INFO    : Bus 134	: V=1.03201673, theta=-26.5791626 -> V=1.046665, theta=0.0
% INFO    : Bus 135	: V=1.07521745, theta=-28.3621828 -> V=1.04758, theta=0.0
% INFO    : Bus 136	: V=1.04368464, theta=-37.7238495 -> V=1.027779, theta=0.0
% INFO    : Bus 137	: V=1.032, theta=-12.8887764 -> V=1.015872, theta=0.0
% INFO    : Bus 138	: V=1.05024707, theta=-11.0755553 -> V=1.0233335, theta=0.0
% INFO    : Bus 139	: V=1.03445563, theta=-16.9390403 -> V=1.0000025, theta=0.0
% INFO    : Bus 140	: V=1.05987232, theta=-13.2255136 -> V=1.044445, theta=0.0
% INFO    : Bus 141	: V=1.06803927, theta=-9.79432415 -> V=1.078945, theta=0.0
% INFO    : Bus 142	: V=1.05173173, theta=-10.7314443 -> V=1.0158755, theta=0.0
% INFO    : Bus 143	: V=1.069667, theta=-6.32556381 -> V=1.0377785, theta=0.0
% INFO    : Bus 144	: V=1.04615994, theta=-20.7164905 -> V=1.033333, theta=0.0
% INFO    : Bus 145	: V=1.06730872, theta=-16.2828642 -> V=1.0288895, theta=0.0
% INFO    : Bus 146	: V=1.07893565, theta=-13.2565255 -> V=1.05263, theta=0.0
% INFO    : Bus 147	: V=1.0460682, theta=-14.7875757 -> V=0.999999, theta=0.0
% INFO    : Bus 148	: V=1.04459985, theta=-12.1022181 -> V=0.999999, theta=0.0
% INFO    : Bus 149	: V=1.04278468, theta=-33.9950246 -> V=1.022224, theta=0.0
% INFO    : Bus 150	: V=1.0345059, theta=-9.49190197 -> V=0.999999, theta=0.0
% INFO    : Bus 151	: V=0.984485029, theta=-24.2430812 -> V=1.015872, theta=0.0
% INFO    : Bus 152	: V=0.984373819, theta=-22.988736 -> V=1.015872, theta=0.0
% INFO    : Bus 153	: V=1.04181198, theta=-10.7366802 -> V=0.999999, theta=0.0
% INFO    : Bus 154	: V=1.06419161, theta=-7.4594666 -> V=1.0111115, theta=0.0
% INFO    : Bus 155	: V=1.04606359, theta=-21.140902 -> V=1.0000025, theta=0.0
% INFO    : Bus 156	: V=0.984438426, theta=-24.2481413 -> V=1.015872, theta=0.0
% INFO    : Bus 157	: V=0.93033985, theta=-9.08222663 -> V=0.9444445, theta=0.0
% INFO    : Bus 158	: V=0.963, theta=-8.51156895 -> V=0.9444445, theta=0.0
% INFO    : Bus 159	: V=1.03333219, theta=-11.9335484 -> V=0.999999, theta=0.0
% INFO    : Bus 160	: V=1.05587049, theta=-13.5394301 -> V=0.9888895, theta=0.0
% INFO    : Bus 161	: V=1.05565475, theta=-13.5407201 -> V=0.9888895, theta=0.0
% INFO    : Bus 162	: V=1.02219857, theta=-24.9428349 -> V=1.022224, theta=0.0
% INFO    : Bus 163	: V=1.02286077, theta=-6.44251223 -> V=1.0158755, theta=0.0
% INFO    : Bus 164	: V=1.02286077, theta=-6.44251223 -> V=1.0158755, theta=0.0
% INFO    : Bus 165	: V=1.07403518, theta=-29.5511273 -> V=0.975, theta=0.0
% INFO    : Bus 166	: V=1.04275466, theta=-33.6436872 -> V=1.022224, theta=0.0
% INFO    : Bus 167	: V=1.04027647, theta=-34.1112677 -> V=1.022224, theta=0.0
% INFO    : Bus 168	: V=1.07409653, theta=-29.5462001 -> V=1.04444, theta=0.0
% INFO    : Bus 169	: V=1.03640065, theta=-29.6709628 -> V=1.022224, theta=0.0
% INFO    : Bus 170	: V=1.04459062, theta=-29.4504458 -> V=1.027779, theta=0.0
% INFO    : Bus 171	: V=1.05951006, theta=-32.3605127 -> V=1.028494, theta=0.0
% INFO    : Bus 172	: V=1.06881147, theta=-28.1963472 -> V=1.046665, theta=0.0
% INFO    : Bus 173	: V=1.07000053, theta=-17.9396571 -> V=1.0111115, theta=0.0
% INFO    : Bus 174	: V=1.07058638, theta=-20.6359947 -> V=1.033333, theta=0.0
% INFO    : Bus 175	: V=1.02623844, theta=-20.4004716 -> V=1.0000025, theta=0.0
% INFO    : Bus 176	: V=1.09807384, theta=-18.170938 -> V=1.0, theta=0.0
% INFO    : Bus 177	: V=1.06740858, theta=-26.5950591 -> V=1.046665, theta=0.0
% INFO    : Bus 178	: V=1.0674088, theta=-26.5950603 -> V=1.046665, theta=0.0
% INFO    : Bus 179	: V=1.01447721, theta=-29.9954878 -> V=1.0000005, theta=0.0
% INFO    : Bus 180	: V=1.0674073, theta=-26.5950521 -> V=1.046665, theta=0.0
% INFO    : Bus 181	: V=1.04276469, theta=-25.7016665 -> V=1.0000025, theta=0.0
% INFO    : Bus 182	: V=1.04407781, theta=-9.36641029 -> V=0.999999, theta=0.0
% INFO    : Bus 183	: V=1.03668717, theta=-19.3274022 -> V=1.0158755, theta=0.0
% INFO    : Bus 184	: V=1.06425697, theta=-26.0579053 -> V=1.027779, theta=0.0
% INFO    : Bus 185	: V=1.04327826, theta=-11.5442269 -> V=1.0158755, theta=0.0
% INFO    : Bus 186	: V=1.0290045, theta=-23.510342 -> V=1.022224, theta=0.0
% INFO    : Bus 187	: V=1.05051182, theta=-20.9900302 -> V=1.0000025, theta=0.0
% INFO    : Bus 188	: V=1.09615659, theta=-19.2244145 -> V=1.0113725, theta=0.0
% INFO    : Bus 189	: V=1.03429537, theta=-24.0858699 -> V=1.0000025, theta=0.0
% INFO    : Bus 190	: V=0.949967688, theta=-6.96346435 -> V=0.9444445, theta=0.0
% INFO    : Bus 191	: V=1.03808607, theta=-29.727828 -> V=1.022224, theta=0.0
% INFO    : Bus 192	: V=1.06203927, theta=-19.6835663 -> V=1.0000025, theta=0.0
% INFO    : Bus 193	: V=1.05393537, theta=-24.3564537 -> V=1.046665, theta=0.0
% INFO    : Bus 194	: V=1.059, theta=-24.4585786 -> V=1.0000025, theta=0.0
% INFO    : Bus 195	: V=1.05832148, theta=-26.6696164 -> V=1.0139155, theta=0.0
% INFO    : Bus 196	: V=1.05832293, theta=-26.669659 -> V=1.0139205, theta=0.0
% INFO    : Bus 197	: V=1.02026619, theta=-31.8670207 -> V=1.0000025, theta=0.0
% INFO    : Bus 198	: V=1.03635018, theta=-21.1800518 -> V=1.0000025, theta=0.0
% INFO    : Bus 199	: V=1.02199189, theta=-40.0182133 -> V=1.022224, theta=0.0
% INFO    : Bus 200	: V=1.08301901, theta=-22.2931995 -> V=1.044445, theta=0.0
% INFO    : Bus 201	: V=1.04436274, theta=-15.3884841 -> V=0.9888895, theta=0.0
% INFO    : Bus 202	: V=0.989677072, theta=-27.5531691 -> V=1.015872, theta=0.0
% INFO    : Bus 203	: V=1.06042657, theta=-15.4696966 -> V=1.022222, theta=0.0
% INFO    : Bus 204	: V=1.06978953, theta=-11.9481334 -> V=1.0288895, theta=0.0
% INFO    : Bus 205	: V=1.08582544, theta=-8.30246238 -> V=1.05263, theta=0.0
% INFO    : Bus 206	: V=1.0064033, theta=-25.330007 -> V=1.015872, theta=0.0
% INFO    : Bus 207	: V=1.00209559, theta=-12.3918785 -> V=1.015872, theta=0.0
% INFO    : Bus 208	: V=1.03674342, theta=-25.0757239 -> V=1.027779, theta=0.0
% INFO    : Bus 209	: V=1.01697821, theta=-18.8885891 -> V=1.015872, theta=0.0
% INFO    : Bus 210	: V=0.999946854, theta=-15.2601409 -> V=1.015872, theta=0.0
% INFO    : Bus 211	: V=0.999986373, theta=-15.1085438 -> V=1.015872, theta=0.0
% INFO    : Bus 212	: V=1.04467142, theta=-15.0563987 -> V=1.046665, theta=0.0
% INFO    : Bus 213	: V=1.04460481, theta=-15.0394889 -> V=1.046665, theta=0.0
% INFO    : Bus 214	: V=1.05351711, theta=-33.7855068 -> V=1.027779, theta=0.0
% INFO    : Bus 215	: V=1.06315026, theta=-30.0412438 -> V=1.046665, theta=0.0
% INFO    : Bus 216	: V=0.999755148, theta=-16.3924177 -> V=1.0079355, theta=0.0
% INFO    : Bus 217	: V=1.0263754, theta=-29.8450461 -> V=1.022224, theta=0.0
% INFO    : Bus 218	: V=1.03926694, theta=-17.8311307 -> V=1.022224, theta=0.0
% INFO    : Bus 219	: V=1.05982359, theta=-28.4275653 -> V=1.022949, theta=0.0
% INFO    : Bus 220	: V=1.02397085, theta=-4.26812719e-05 -> V=1.0158755, theta=0.0
% INFO    : Bus 221	: V=1.03812722, theta=-17.2048211 -> V=0.999999, theta=0.0
% INFO    : Bus 222	: V=1.09095418, theta=-14.4482663 -> V=1.0138265, theta=0.0
% INFO    : Bus 223	: V=1.03147633, theta=-25.8507581 -> V=1.0000025, theta=0.0
% INFO    : Bus 224	: V=1.09802378, theta=-18.1699659 -> V=1.0, theta=0.0
% INFO    : Bus 225	: V=1.05186845, theta=-14.6708662 -> V=1.046665, theta=0.0
% INFO    : Bus 226	: V=1.05124549, theta=-14.6645159 -> V=1.046665, theta=0.0
% INFO    : Bus 227	: V=1.02145523, theta=-55.9527092 -> V=1.0079355, theta=0.0
% INFO    : Bus 228	: V=1.01759019, theta=-56.4837789 -> V=1.0079355, theta=0.0
% INFO    : Bus 229	: V=1.04812521, theta=-21.0580923 -> V=1.0000025, theta=0.0
% INFO    : Bus 230	: V=1.05158389, theta=-14.8173736 -> V=1.033334, theta=0.0
% INFO    : Bus 231	: V=1.03927735, theta=-29.0275127 -> V=1.022224, theta=0.0
% INFO    : Bus 232	: V=1.0328614, theta=-13.1069653 -> V=1.0111115, theta=0.0
% INFO    : Bus 233	: V=1.05368207, theta=-14.6274321 -> V=0.975, theta=0.0
% INFO    : Bus 234	: V=1.05368207, theta=-14.6274321 -> V=1.0111115, theta=0.0
% INFO    : Bus 235	: V=1.06832851, theta=-11.2997131 -> V=0.9888895, theta=0.0
% INFO    : Bus 236	: V=1.04936733, theta=-22.4626728 -> V=1.000001, theta=0.0
% INFO    : Bus 237	: V=1.04651527, theta=-10.3679679 -> V=0.999999, theta=0.0
% INFO    : Bus 238	: V=1.03907617, theta=-27.9516924 -> V=1.022224, theta=0.0
% INFO    : Bus 239	: V=1.023565, theta=-58.1329313 -> V=1.0079355, theta=0.0
% INFO    : Bus 240	: V=1.03846197, theta=-26.3221394 -> V=1.0000025, theta=0.0
% INFO    : Bus 241	: V=1.02315926, theta=-24.2358188 -> V=1.000001, theta=0.0
% INFO    : Bus 242	: V=0.994240215, theta=-24.9807834 -> V=1.015872, theta=0.0
% INFO    : Bus 243	: V=1.02057469, theta=-28.5162824 -> V=1.0000025, theta=0.0
% INFO    : Bus 244	: V=1.05012014, theta=-18.0566541 -> V=1.000001, theta=0.0
% INFO    : Bus 245	: V=1.02318028, theta=-27.1710983 -> V=1.0000025, theta=0.0
% INFO    : Bus 246	: V=1.01843728, theta=-4.66723789 -> V=0.999999, theta=0.0
% INFO    : Bus 247	: V=1.0501661, theta=-3.23372076 -> V=1.0111115, theta=0.0
% INFO    : Bus 248	: V=1.06279228, theta=-24.9782102 -> V=1.046665, theta=0.0
% INFO    : Bus 249	: V=1.02988452, theta=-28.5044202 -> V=1.0000025, theta=0.0
% INFO    : Bus 250	: V=1.02156277, theta=-22.6839426 -> V=1.0158755, theta=0.0
% INFO    : Bus 251	: V=1.03502349, theta=-33.2461662 -> V=1.022224, theta=0.0
% INFO    : Bus 252	: V=1.02940017, theta=-24.0093891 -> V=1.022224, theta=0.0
% INFO    : Bus 253	: V=1.03449873, theta=-19.6993029 -> V=1.0158755, theta=0.0
% INFO    : Bus 254	: V=1.03093749, theta=-19.8605396 -> V=1.0158755, theta=0.0
% INFO    : Bus 255	: V=1.02472731, theta=-19.2277379 -> V=0.999999, theta=0.0
% INFO    : Bus 256	: V=1.047, theta=-21.7878311 -> V=1.0000025, theta=0.0
% INFO    : Bus 257	: V=1.08035266, theta=-22.4758983 -> V=1.044445, theta=0.0
% INFO    : Bus 258	: V=1.079, theta=-13.1346298 -> V=1.000731, theta=0.0
% INFO    : Bus 259	: V=1.05321277, theta=-17.7521403 -> V=1.0158755, theta=0.0
% INFO    : Bus 260	: V=1.06852019, theta=-15.5448788 -> V=1.0377785, theta=0.0
% INFO    : Bus 261	: V=1.03809865, theta=-27.8744741 -> V=1.0000025, theta=0.0
% INFO    : Bus 262	: V=1.06224211, theta=-12.5344257 -> V=0.9888895, theta=0.0
% INFO    : Bus 263	: V=1.04941575, theta=-14.3131771 -> V=0.9888895, theta=0.0
% INFO    : Bus 264	: V=1.06202964, theta=-8.66137669 -> V=1.05921, theta=0.0
% INFO    : Bus 265	: V=1.00037744, theta=-28.103089 -> V=1.0000005, theta=0.0
% INFO    : Bus 266	: V=1.06452562, theta=-24.6567267 -> V=1.046665, theta=0.0
% INFO    : Bus 267	: V=1.04841331, theta=-26.0512823 -> V=1.046665, theta=0.0
% INFO    : Bus 268	: V=1.00327689, theta=-18.443712 -> V=1.0000025, theta=0.0
% INFO    : Bus 269	: V=1.00878337, theta=-29.9385244 -> V=1.0000025, theta=0.0
% INFO    : Bus 270	: V=1.04268375, theta=-10.3423781 -> V=1.033334, theta=0.0
% INFO    : Bus 271	: V=1.04283617, theta=-10.3419534 -> V=1.033334, theta=0.0
% INFO    : Bus 272	: V=1.02404231, theta=-15.719636 -> V=1.015872, theta=0.0
% INFO    : Bus 273	: V=1.03982599, theta=-11.1736796 -> V=1.046665, theta=0.0
% INFO    : Bus 274	: V=1.07140481, theta=-20.5497908 -> V=1.022222, theta=0.0
% INFO    : Bus 275	: V=1.07708732, theta=-25.1951478 -> V=1.04444, theta=0.0
% INFO    : Bus 276	: V=1.08644504, theta=-19.4710161 -> V=1.07237, theta=0.0
% INFO    : Bus 277	: V=1.0457138, theta=-27.9914799 -> V=1.022224, theta=0.0
% INFO    : Bus 278	: V=1.07684777, theta=-25.2518836 -> V=1.04444, theta=0.0
% INFO    : Bus 279	: V=1.0215041, theta=-21.3062036 -> V=0.999999, theta=0.0
% INFO    : Bus 280	: V=1.05012132, theta=-33.9683196 -> V=1.027779, theta=0.0
% INFO    : Bus 281	: V=1.01994474, theta=-15.2348522 -> V=1.0158755, theta=0.0
% INFO    : Bus 282	: V=1.01843778, theta=-4.66724943 -> V=0.999999, theta=0.0
% INFO    : Bus 283	: V=1.03614937, theta=-34.976062 -> V=1.022224, theta=0.0
% INFO    : Bus 284	: V=1.01758712, theta=1.25883592 -> V=1.0158755, theta=0.0
% INFO    : Bus 285	: V=1.06500363, theta=-24.5370537 -> V=1.046665, theta=0.0
% INFO    : Bus 286	: V=1.06479408, theta=-24.5510322 -> V=1.046665, theta=0.0
% INFO    : Bus 287	: V=1.0415265, theta=-24.7054363 -> V=1.022224, theta=0.0
% INFO    : Bus 288	: V=1.03994247, theta=-30.5221379 -> V=1.022224, theta=0.0
% INFO    : Bus 289	: V=1.07741013, theta=-0.0466451995 -> V=0.9893695, theta=0.0
% INFO    : Bus 290	: V=1.07037581, theta=-13.2536995 -> V=1.033333, theta=0.0
% INFO    : Bus 291	: V=1.02437552, theta=-26.2000589 -> V=1.0000025, theta=0.0
% INFO    : Bus 292	: V=1.03860199, theta=-13.2430311 -> V=0.999999, theta=0.0
% INFO    : Bus 293	: V=1.03862018, theta=-13.2435793 -> V=0.999999, theta=0.0
% INFO    : Bus 294	: V=1.03295864, theta=-12.5941044 -> V=1.0158755, theta=0.0
% INFO    : Bus 295	: V=1.05390338, theta=-16.1529174 -> V=0.9888895, theta=0.0
% INFO    : Bus 296	: V=1.0189003, theta=-18.3275408 -> V=1.0158755, theta=0.0
% INFO    : Bus 297	: V=1.01367016, theta=-19.2703759 -> V=0.999999, theta=0.0
% INFO    : Bus 298	: V=1.00645208, theta=-9.47888871 -> V=0.999999, theta=0.0
% INFO    : Bus 299	: V=1.06418712, theta=-13.3819438 -> V=1.033333, theta=0.0
% INFO    : Bus 300	: V=1.06809893, theta=-10.7061656 -> V=0.9888895, theta=0.0
% INFO    : Bus 301	: V=0.998578911, theta=-12.5862354 -> V=1.015872, theta=0.0
% INFO    : Bus 302	: V=1.02862271, theta=-11.8841659 -> V=0.999999, theta=0.0
% INFO    : Bus 303	: V=0.991381333, theta=-34.6929608 -> V=1.0000025, theta=0.0
% INFO    : Bus 304	: V=1.00633647, theta=-23.8275008 -> V=1.015872, theta=0.0
% INFO    : Bus 305	: V=1.053, theta=-15.7404958 -> V=1.003694, theta=0.0
% INFO    : Bus 306	: V=1.01766812, theta=-15.6122686 -> V=1.0158755, theta=0.0
% INFO    : Bus 307	: V=1.0136652, theta=-40.7014829 -> V=1.022224, theta=0.0
% INFO    : Bus 308	: V=1.03987591, theta=-25.996149 -> V=1.0000025, theta=0.0
% INFO    : Bus 309	: V=1.03283091, theta=-28.3991366 -> V=1.015872, theta=0.0
% INFO    : Bus 310	: V=1.03309434, theta=-28.4242862 -> V=1.015872, theta=0.0
% INFO    : Bus 311	: V=1.01432129, theta=-30.9131851 -> V=1.022224, theta=0.0
% INFO    : Bus 312	: V=1.02079372, theta=-10.6367867 -> V=1.000001, theta=0.0
% INFO    : Bus 313	: V=1.04229698, theta=-22.315202 -> V=1.0000025, theta=0.0
% INFO    : Bus 314	: V=1.06964043, theta=-18.4868332 -> V=1.044445, theta=0.0
% INFO    : Bus 315	: V=1.06341208, theta=-26.2432348 -> V=1.027779, theta=0.0
% INFO    : Bus 316	: V=1.02464361, theta=-26.5397301 -> V=1.0000025, theta=0.0
% INFO    : Bus 317	: V=1.06376485, theta=-20.2565602 -> V=1.0000025, theta=0.0
% INFO    : Bus 318	: V=1.02107033, theta=-27.7823351 -> V=1.0000005, theta=0.0
% INFO    : Bus 319	: V=1.03536964, theta=-27.420133 -> V=1.0000025, theta=0.0
% INFO    : Bus 320	: V=1.06015465, theta=-18.3314305 -> V=1.022222, theta=0.0
% INFO    : Bus 321	: V=1.05199905, theta=-24.6933583 -> V=1.0000025, theta=0.0
% INFO    : Bus 322	: V=1.03020475, theta=-14.8027685 -> V=1.044445, theta=0.0
% INFO    : Bus 323	: V=1.06835466, theta=-14.6436251 -> V=1.078945, theta=0.0
% INFO    : Bus 324	: V=1.03544013, theta=-10.6322933 -> V=0.999999, theta=0.0
% INFO    : Bus 325	: V=1.03522259, theta=-13.6000384 -> V=0.999999, theta=0.0
% INFO    : Bus 326	: V=1.05170362, theta=-20.1978282 -> V=1.0000025, theta=0.0
% INFO    : Bus 327	: V=1.05511306, theta=-17.0988411 -> V=1.044445, theta=0.0
% INFO    : Bus 328	: V=1.03149734, theta=-22.216583 -> V=1.0000025, theta=0.0
% INFO    : Bus 329	: V=1.06464218, theta=-19.1800323 -> V=1.022222, theta=0.0
% INFO    : Bus 330	: V=1.04987845, theta=-24.8133793 -> V=1.0000025, theta=0.0
% INFO    : Bus 331	: V=1.07080751, theta=-20.5131015 -> V=1.044445, theta=0.0
% INFO    : Bus 332	: V=1.03194429, theta=-32.0957418 -> V=1.015872, theta=0.0
% INFO    : Bus 333	: V=1.0473898, theta=-25.0793666 -> V=1.0233335, theta=0.0
% INFO    : Bus 334	: V=1.04947456, theta=-53.1480479 -> V=1.0079355, theta=0.0
% INFO    : Bus 335	: V=1.03396225, theta=-17.2394691 -> V=0.999999, theta=0.0
% INFO    : Bus 336	: V=1.026, theta=-21.9492976 -> V=1.0000025, theta=0.0
% INFO    : Bus 337	: V=1.04516174, theta=-27.8669538 -> V=1.0000025, theta=0.0
% INFO    : Bus 338	: V=1.06787506, theta=-22.9279908 -> V=1.0000025, theta=0.0
% INFO    : Bus 339	: V=1.04196715, theta=-24.7120245 -> V=1.0000025, theta=0.0
% INFO    : Bus 340	: V=1.05538345, theta=-27.7279399 -> V=1.022224, theta=0.0
% INFO    : Bus 341	: V=1.06004478, theta=-25.3354013 -> V=1.0000025, theta=0.0
% INFO    : Bus 342	: V=1.02535201, theta=-13.4869862 -> V=1.0158755, theta=0.0
% INFO    : Bus 343	: V=1.03200458, theta=-10.5153385 -> V=1.0377785, theta=0.0
% INFO    : Bus 344	: V=1.00896899, theta=-15.5281506 -> V=1.015872, theta=0.0
% INFO    : Bus 345	: V=1.03264588, theta=-25.6612657 -> V=1.027779, theta=0.0
% INFO    : Bus 346	: V=1.06153386, theta=-6.80602171 -> V=1.046665, theta=0.0
% INFO    : Bus 347	: V=1.038852, theta=-28.4678801 -> V=1.015872, theta=0.0
% INFO    : Bus 348	: V=1.06021012, theta=-22.198311 -> V=1.022222, theta=0.0
% INFO    : Bus 349	: V=1.09514547, theta=-11.6578802 -> V=1.07453, theta=0.0
% INFO    : Bus 350	: V=1.09513358, theta=-11.6699471 -> V=1.07455, theta=0.0
% INFO    : Bus 351	: V=1.07260669, theta=-17.1720353 -> V=1.044445, theta=0.0
% INFO    : Bus 352	: V=1.06440835, theta=-26.1866263 -> V=1.046665, theta=0.0
% INFO    : Bus 353	: V=1.02795822, theta=-29.1916739 -> V=1.0000005, theta=0.0
% INFO    : Bus 354	: V=1.02851959, theta=-20.0572474 -> V=1.0000025, theta=0.0
% INFO    : Bus 355	: V=1.04958114, theta=-10.0003256 -> V=1.0000025, theta=0.0
% INFO    : Bus 356	: V=1.02270616, theta=-22.5029165 -> V=1.0000025, theta=0.0
% INFO    : Bus 357	: V=1.01639978, theta=-13.4986638 -> V=1.0158755, theta=0.0
% INFO    : Bus 358	: V=1.02313934, theta=-22.4742091 -> V=1.0000025, theta=0.0
% INFO    : Bus 359	: V=1.01652722, theta=-23.6352908 -> V=1.015872, theta=0.0
% INFO    : Bus 360	: V=1.0443874, theta=-25.5025528 -> V=1.0000025, theta=0.0
% INFO    : Bus 361	: V=1.0747314, theta=-21.7909412 -> V=1.0, theta=0.0
% INFO    : Bus 362	: V=1.07363604, theta=-20.3622282 -> V=1.044445, theta=0.0
% INFO    : Bus 363	: V=1.07103299, theta=-17.9438971 -> V=1.0111115, theta=0.0
% INFO    : Bus 364	: V=1.049, theta=-25.8976207 -> V=1.046665, theta=0.0
% INFO    : Bus 365	: V=1.03404434, theta=-9.18536912 -> V=0.999999, theta=0.0
% INFO    : Bus 366	: V=1.04844498, theta=-5.50274758 -> V=1.0111115, theta=0.0
% INFO    : Bus 367	: V=1.07318411, theta=-3.85227208 -> V=1.072365, theta=0.0
% INFO    : Bus 368	: V=1.07068964, theta=-4.92607275 -> V=1.072365, theta=0.0
% INFO    : Bus 369	: V=1.07474128, theta=-28.5067468 -> V=1.04735, theta=0.0
% INFO    : Bus 370	: V=1.03067239, theta=-26.7952947 -> V=1.046665, theta=0.0
% INFO    : Bus 371	: V=1.01070798, theta=-0.00389582555 -> V=1.0158755, theta=0.0
% INFO    : Bus 372	: V=1.04599644, theta=-1.99258893 -> V=1.0377785, theta=0.0
% INFO    : Bus 373	: V=1.07455655, theta=-28.5213035 -> V=1.04726, theta=0.0
% INFO    : Bus 374	: V=1.00331834, theta=-55.3853538 -> V=1.0079355, theta=0.0
% INFO    : Bus 375	: V=1.02627869, theta=-35.7363139 -> V=1.022224, theta=0.0
% INFO    : Bus 376	: V=1.02501453, theta=-42.0957258 -> V=1.0079355, theta=0.0
% INFO    : Bus 377	: V=1.02318901, theta=-10.7194737 -> V=1.0158755, theta=0.0
% INFO    : Bus 378	: V=1.04732465, theta=-15.8319582 -> V=0.999999, theta=0.0
% INFO    : Bus 379	: V=1.05365153, theta=-11.4139226 -> V=1.0111115, theta=0.0
% INFO    : Bus 380	: V=1.07558614, theta=-8.61716569 -> V=1.072365, theta=0.0
% INFO    : Bus 381	: V=1.0338767, theta=-32.3564593 -> V=1.027779, theta=0.0
% INFO    : Bus 382	: V=1.02727684, theta=-5.35257436 -> V=1.0158755, theta=0.0
% INFO    : Bus 383	: V=1.03946811, theta=-15.0955468 -> V=1.0000025, theta=0.0
% INFO    : Bus 384	: V=1.00832137, theta=-28.4967318 -> V=1.0000025, theta=0.0
% INFO    : Bus 385	: V=1.02142853, theta=-4.35666921 -> V=1.0000025, theta=0.0
% INFO    : Bus 386	: V=1.07748509, theta=-16.8722625 -> V=1.044445, theta=0.0
% INFO    : Bus 387	: V=1.06366944, theta=-15.8441075 -> V=1.000001, theta=0.0
% INFO    : Bus 388	: V=1.05441067, theta=-20.55177 -> V=1.022222, theta=0.0
% INFO    : Bus 389	: V=1.04414764, theta=-15.0271914 -> V=0.999999, theta=0.0
% INFO    : Bus 390	: V=1.0234174, theta=-15.7602472 -> V=1.015872, theta=0.0
% INFO    : Bus 391	: V=1.04334366, theta=-22.411263 -> V=1.0000025, theta=0.0
% INFO    : Bus 392	: V=1.00237267, theta=-25.9789616 -> V=1.015872, theta=0.0
% INFO    : Bus 393	: V=1.0360919, theta=-15.392956 -> V=1.0158755, theta=0.0
% INFO    : Bus 394	: V=1.03672915, theta=-22.1795209 -> V=1.0000025, theta=0.0
% INFO    : Bus 395	: V=1.03683125, theta=-22.173342 -> V=1.0000025, theta=0.0
% INFO    : Bus 396	: V=1.04478084, theta=-4.64251974 -> V=1.0158755, theta=0.0
% INFO    : Bus 397	: V=1.04103864, theta=-27.3033919 -> V=1.0000025, theta=0.0
% INFO    : Bus 398	: V=1.03692158, theta=-34.8848315 -> V=1.022224, theta=0.0
% INFO    : Bus 399	: V=1.06212103, theta=-20.120538 -> V=1.0000025, theta=0.0
% INFO    : Bus 400	: V=1.03908861, theta=-23.5540108 -> V=1.0000025, theta=0.0
% INFO    : Bus 401	: V=1.04400563, theta=-16.3249423 -> V=0.999999, theta=0.0
% INFO    : Bus 402	: V=1.03158916, theta=-26.4596942 -> V=1.000001, theta=0.0
% INFO    : Bus 403	: V=1.04449307, theta=-11.2006196 -> V=0.999999, theta=0.0
% INFO    : Bus 404	: V=1.04392378, theta=-13.42175 -> V=1.000114, theta=0.0
% INFO    : Bus 405	: V=1.0261238, theta=-15.9245124 -> V=0.999999, theta=0.0
% INFO    : Bus 406	: V=1.02659562, theta=-25.9634059 -> V=1.022224, theta=0.0
% INFO    : Bus 407	: V=1.04594346, theta=-30.3081515 -> V=1.022224, theta=0.0
% INFO    : Bus 408	: V=1.05996133, theta=-29.9738109 -> V=1.0000025, theta=0.0
% INFO    : Bus 409	: V=1.03010219, theta=-24.9872831 -> V=1.015872, theta=0.0
% INFO    : Bus 410	: V=1.03901446, theta=-38.1022814 -> V=1.022224, theta=0.0
% INFO    : Bus 411	: V=1.03569581, theta=-30.1693725 -> V=1.022224, theta=0.0
% INFO    : Bus 412	: V=1.01718355, theta=-7.48203749 -> V=1.0158755, theta=0.0
% INFO    : Bus 413	: V=1.03811598, theta=-53.4618027 -> V=1.0079355, theta=0.0
% INFO    : Bus 414	: V=1.01311025, theta=-16.9776643 -> V=0.999999, theta=0.0
% INFO    : Bus 415	: V=1.02995292, theta=-20.5589323 -> V=1.0158755, theta=0.0
% INFO    : Bus 416	: V=1.07022776, theta=-27.3595312 -> V=1.046835, theta=0.0
% INFO    : Bus 417	: V=1.04224416, theta=-30.3076822 -> V=1.0000025, theta=0.0
% INFO    : Bus 418	: V=1.01297644, theta=-27.5769913 -> V=1.0000005, theta=0.0
% INFO    : Bus 419	: V=1.05465853, theta=-29.1633716 -> V=1.0000025, theta=0.0
% INFO    : Bus 420	: V=1.05771546, theta=-28.7528785 -> V=1.0000025, theta=0.0
% INFO    : Bus 421	: V=1.01514686, theta=-33.8288257 -> V=1.015872, theta=0.0
% INFO    : Bus 422	: V=1.04901883, theta=-20.671992 -> V=1.0000025, theta=0.0
% INFO    : Bus 423	: V=1.07617869, theta=-17.7762043 -> V=1.044555, theta=0.0
% INFO    : Bus 424	: V=1.03781475, theta=-2.27241252 -> V=1.0158755, theta=0.0
% INFO    : Bus 425	: V=1.06679883, theta=1.13368684 -> V=1.0377785, theta=0.0
% INFO    : Bus 426	: V=1.02020862, theta=-28.2957025 -> V=1.0000005, theta=0.0
% INFO    : Bus 427	: V=1.02769925, theta=-9.65549765 -> V=0.999999, theta=0.0
% INFO    : Bus 428	: V=1.03069569, theta=-45.7840777 -> V=1.0079355, theta=0.0
% INFO    : Bus 429	: V=1.02546967, theta=-18.5986382 -> V=1.015872, theta=0.0
% INFO    : Bus 430	: V=1.07410479, theta=-25.840946 -> V=1.04798, theta=0.0
% INFO    : Bus 431	: V=1.0605157, theta=-22.0216793 -> V=1.0000025, theta=0.0
% INFO    : Bus 432	: V=1.03898047, theta=-36.6024796 -> V=1.0000025, theta=0.0
% INFO    : Bus 433	: V=1.05003832, theta=-28.2858901 -> V=1.0094155, theta=0.0
% INFO    : Bus 434	: V=1.02161889, theta=-13.4132911 -> V=0.999999, theta=0.0
% INFO    : Bus 435	: V=1.0438349, theta=-26.8718198 -> V=1.000001, theta=0.0
% INFO    : Bus 436	: V=1.01125019, theta=-15.4489767 -> V=1.015872, theta=0.0
% INFO    : Bus 437	: V=1.05586134, theta=-14.888318 -> V=1.000001, theta=0.0
% INFO    : Bus 438	: V=1.01694856, theta=-28.4978758 -> V=1.0000005, theta=0.0
% INFO    : Bus 439	: V=1.0395141, theta=-11.3194532 -> V=1.0158755, theta=0.0
% INFO    : Bus 440	: V=1.03183084, theta=-27.7839461 -> V=1.0000025, theta=0.0
% INFO    : Bus 441	: V=1.03020754, theta=-12.9874142 -> V=0.999999, theta=0.0
% INFO    : Bus 442	: V=1.0261642, theta=2.31979275 -> V=1.0158755, theta=0.0
% INFO    : Bus 443	: V=1.07237522, theta=-20.0519684 -> V=1.033333, theta=0.0
% INFO    : Bus 444	: V=1.07638735, theta=-20.8350436 -> V=1.033333, theta=0.0
% INFO    : Bus 445	: V=1.0834199, theta=-21.314253 -> V=1.033333, theta=0.0
% INFO    : Bus 446	: V=1.03550331, theta=-16.1633568 -> V=1.006667, theta=0.0
% INFO    : Bus 447	: V=0.999, theta=-9.60542531 -> V=1.015872, theta=0.0
% INFO    : Bus 448	: V=1.02128195, theta=1.50617133 -> V=1.0158755, theta=0.0
% INFO    : Bus 449	: V=1.08632783, theta=4.85807051 -> V=1.0408035, theta=0.0
% INFO    : Bus 450	: V=1.08999518, theta=6.00924378 -> V=1.072365, theta=0.0
% INFO    : Bus 451	: V=1.01142531, theta=-23.7617685 -> V=1.0000025, theta=0.0
% INFO    : Bus 452	: V=1.05371245, theta=-48.6758107 -> V=1.0079355, theta=0.0
% INFO    : Bus 453	: V=1.06688598, theta=-43.8164547 -> V=1.04444, theta=0.0
% INFO    : Bus 454	: V=1.03883298, theta=-26.4185645 -> V=1.0000025, theta=0.0
% INFO    : Bus 455	: V=1.05799409, theta=-19.8407392 -> V=1.022222, theta=0.0
% INFO    : Bus 456	: V=1.05736228, theta=-19.8934593 -> V=1.022222, theta=0.0
% INFO    : Bus 457	: V=0.975621027, theta=-29.3211685 -> V=1.015872, theta=0.0
% INFO    : Bus 458	: V=1.04928537, theta=-27.173243 -> V=1.046665, theta=0.0
% INFO    : Bus 459	: V=1.04154238, theta=-24.333068 -> V=1.06579, theta=0.0
% INFO    : Bus 460	: V=1.01625739, theta=-23.2106527 -> V=1.0000025, theta=0.0
% INFO    : Bus 461	: V=1.02569313, theta=-3.93671481 -> V=1.0158755, theta=0.0
% INFO    : Bus 462	: V=1.03538941, theta=-53.5578541 -> V=1.0079355, theta=0.0
% INFO    : Bus 463	: V=1.02756343, theta=-21.1722053 -> V=1.022224, theta=0.0
% INFO    : Bus 464	: V=1.168, theta=-18.8469774 -> V=0.984405, theta=0.0
% INFO    : Bus 465	: V=1.05539681, theta=-20.5262072 -> V=1.033333, theta=0.0
% INFO    : Bus 466	: V=1.03572208, theta=-38.6827227 -> V=1.0079355, theta=0.0
% INFO    : Bus 467	: V=1.00050594, theta=-29.2954586 -> V=1.0000005, theta=0.0
% INFO    : Bus 468	: V=1.02730692, theta=-33.4720105 -> V=1.0000005, theta=0.0
% INFO    : Bus 469	: V=1.05396444, theta=-11.4194658 -> V=1.0111115, theta=0.0
% INFO    : Bus 470	: V=1.05350061, theta=-16.6053732 -> V=0.999999, theta=0.0
% INFO    : Bus 471	: V=1.03922725, theta=-10.8317151 -> V=0.999999, theta=0.0
% INFO    : Bus 472	: V=1.08659733, theta=-9.0908108 -> V=1.052629, theta=0.0
% INFO    : Bus 473	: V=1.08658279, theta=-9.09014642 -> V=1.052629, theta=0.0
% INFO    : Bus 474	: V=1.02670476, theta=-31.7653796 -> V=1.027779, theta=0.0
% INFO    : Bus 475	: V=1.02932189, theta=-6.12978192 -> V=1.0158755, theta=0.0
% INFO    : Bus 476	: V=1.01413579, theta=-28.5940104 -> V=1.0000025, theta=0.0
% INFO    : Bus 477	: V=1.01604854, theta=-6.43957473 -> V=1.0158755, theta=0.0
% INFO    : Bus 478	: V=1.00366136, theta=-5.0931459 -> V=0.9498095, theta=0.0
% INFO    : Bus 479	: V=1.02213106, theta=-4.58471121 -> V=0.999999, theta=0.0
% INFO    : Bus 480	: V=1.0449563, theta=-12.0644294 -> V=0.999999, theta=0.0
% INFO    : Bus 481	: V=1.04147204, theta=-8.56958279 -> V=1.0111115, theta=0.0
% INFO    : Bus 482	: V=1.00762679, theta=-8.55509573 -> V=1.0158755, theta=0.0
% INFO    : Bus 483	: V=1.03955761, theta=-26.4134792 -> V=1.0000025, theta=0.0
% INFO    : Bus 484	: V=1.03698071, theta=-25.6979911 -> V=1.022224, theta=0.0
% INFO    : Bus 485	: V=1.00852384, theta=-47.2934114 -> V=1.0079355, theta=0.0
% INFO    : Bus 486	: V=1.04339857, theta=-23.2234793 -> V=1.0000025, theta=0.0
% INFO    : Bus 487	: V=1.03411356, theta=-38.7913833 -> V=1.022224, theta=0.0
% INFO    : Bus 488	: V=1.04963686, theta=-23.798981 -> V=1.0000025, theta=0.0
% INFO    : Bus 489	: V=1.01702239, theta=-20.8333915 -> V=1.0158755, theta=0.0
% INFO    : Bus 490	: V=1.07327102, theta=-18.5336888 -> V=1.0112665, theta=0.0
% INFO    : Bus 491	: V=1.05750776, theta=-9.60497422 -> V=1.033334, theta=0.0
% INFO    : Bus 492	: V=1.0324429, theta=-18.6614908 -> V=0.999999, theta=0.0
% INFO    : Bus 493	: V=1.09609542, theta=-8.9964026 -> V=1.050675, theta=0.0
% INFO    : Bus 494	: V=1.09043035, theta=-9.01017245 -> V=1.078945, theta=0.0
% INFO    : Bus 495	: V=1.09036342, theta=-9.00101214 -> V=1.078945, theta=0.0
% INFO    : Bus 496	: V=1.0904128, theta=-8.99831167 -> V=1.078945, theta=0.0
% INFO    : Bus 497	: V=1.09039062, theta=-8.99506989 -> V=1.078945, theta=0.0
% INFO    : Bus 498	: V=1.03268491, theta=-25.7349695 -> V=1.0000025, theta=0.0
% INFO    : Bus 499	: V=1.08683606, theta=4.94877074 -> V=1.0410385, theta=0.0
% INFO    : Bus 500	: V=1.08706218, theta=4.97715351 -> V=1.0411535, theta=0.0
% INFO    : Bus 501	: V=1.09031539, theta=6.10446209 -> V=1.072365, theta=0.0
% INFO    : Bus 502	: V=1.04575249, theta=-31.860651 -> V=1.022224, theta=0.0
% INFO    : Bus 503	: V=1.04997286, theta=-25.4247641 -> V=1.027779, theta=0.0
% INFO    : Bus 504	: V=1.05039015, theta=-22.3385156 -> V=1.016666, theta=0.0
% INFO    : Bus 505	: V=1.05867916, theta=-18.3967315 -> V=1.0288895, theta=0.0
% INFO    : Bus 506	: V=1.02947153, theta=-42.2003813 -> V=1.0079355, theta=0.0
% INFO    : Bus 507	: V=1.01425665, theta=-24.4553914 -> V=1.022224, theta=0.0
% INFO    : Bus 508	: V=1.02491407, theta=-15.6241899 -> V=0.999999, theta=0.0
% INFO    : Bus 509	: V=1.05661714, theta=-31.7736567 -> V=1.027779, theta=0.0
% INFO    : Bus 510	: V=1.01104382, theta=-34.0893381 -> V=1.015872, theta=0.0
% INFO    : Bus 511	: V=1.04741084, theta=-28.3752154 -> V=1.046665, theta=0.0
% INFO    : Bus 512	: V=0.933654094, theta=-6.47116096 -> V=0.9444445, theta=0.0
% INFO    : Bus 513	: V=0.999943338, theta=-6.47116096 -> V=0.999999, theta=0.0
% INFO    : Bus 514	: V=1.06766145, theta=-11.0608623 -> V=1.072365, theta=0.0
% INFO    : Bus 515	: V=1.02851503, theta=-33.7466738 -> V=1.022224, theta=0.0
% INFO    : Bus 516	: V=1.00016254, theta=-13.7854134 -> V=0.999999, theta=0.0
% INFO    : Bus 517	: V=1.02390213, theta=-27.7962165 -> V=1.0000025, theta=0.0
% INFO    : Bus 518	: V=1.04297128, theta=-4.5748888 -> V=0.9722445, theta=0.0
% INFO    : Bus 519	: V=1.00605149, theta=-20.7711922 -> V=1.015874, theta=0.0
% INFO    : Bus 520	: V=1.04039924, theta=-28.4832764 -> V=1.022224, theta=0.0
% INFO    : Bus 521	: V=1.04202218, theta=-13.4599476 -> V=0.999999, theta=0.0
% INFO    : Bus 522	: V=1.04063201, theta=-13.1635972 -> V=0.999999, theta=0.0
% INFO    : Bus 523	: V=1.0546662, theta=-8.48001357 -> V=1.0111115, theta=0.0
% INFO    : Bus 524	: V=1.06675884, theta=-3.42515057 -> V=1.072365, theta=0.0
% INFO    : Bus 525	: V=1.05339942, theta=-33.7905669 -> V=1.027779, theta=0.0
% INFO    : Bus 526	: V=1.01777983, theta=-9.95918376 -> V=1.015872, theta=0.0
% INFO    : Bus 527	: V=1.05784173, theta=-5.50774126 -> V=1.046665, theta=0.0
% INFO    : Bus 528	: V=1.03354417, theta=-11.3168987 -> V=1.0158755, theta=0.0
% INFO    : Bus 529	: V=1.03326259, theta=-11.3339438 -> V=1.0158755, theta=0.0
% INFO    : Bus 530	: V=1.044, theta=-13.7376946 -> V=0.999999, theta=0.0
% INFO    : Bus 531	: V=1.00735285, theta=-28.1513212 -> V=1.0000005, theta=0.0
% INFO    : Bus 532	: V=1.00732188, theta=-28.1556296 -> V=1.0000005, theta=0.0
% INFO    : Bus 533	: V=0.99908333, theta=-26.7898578 -> V=1.0000005, theta=0.0
% INFO    : Bus 534	: V=1.00004648, theta=-26.8168686 -> V=1.0000005, theta=0.0
% INFO    : Bus 535	: V=1.056222, theta=-22.6857264 -> V=1.022224, theta=0.0
% INFO    : Bus 536	: V=1.0639494, theta=-17.9917266 -> V=1.04444, theta=0.0
% INFO    : Bus 537	: V=1.0337163, theta=-29.77464 -> V=1.022224, theta=0.0
% INFO    : Bus 538	: V=1.03765798, theta=-12.4602888 -> V=0.999999, theta=0.0
% INFO    : Bus 539	: V=1.01836466, theta=-37.3122633 -> V=1.022224, theta=0.0
% INFO    : Bus 540	: V=1.07269574, theta=-19.2700809 -> V=1.000001, theta=0.0
% INFO    : Bus 541	: V=1.02917942, theta=-11.7721193 -> V=0.999999, theta=0.0
% INFO    : Bus 542	: V=1.05483969, theta=-9.22251142 -> V=1.0111115, theta=0.0
% INFO    : Bus 543	: V=1.05481586, theta=-9.2259049 -> V=1.0111115, theta=0.0
% INFO    : Bus 544	: V=1.04337642, theta=-30.4638955 -> V=1.027779, theta=0.0
% INFO    : Bus 545	: V=1.06999659, theta=-27.3474731 -> V=1.04672, theta=0.0
% INFO    : Bus 546	: V=1.051, theta=-28.1185754 -> V=1.0000025, theta=0.0
% INFO    : Bus 547	: V=1.03433327, theta=-27.081047 -> V=1.0000025, theta=0.0
% INFO    : Bus 548	: V=1.0479142, theta=-18.5406696 -> V=1.0000025, theta=0.0
% INFO    : Bus 549	: V=1.01741934, theta=-31.3623166 -> V=1.0000025, theta=0.0
% INFO    : Bus 550	: V=1.05437663, theta=-20.2186081 -> V=1.0000025, theta=0.0
% INFO    : Bus 551	: V=1.04213054, theta=-20.6333583 -> V=1.000001, theta=0.0
% INFO    : Bus 552	: V=1.02272811, theta=-14.8743542 -> V=0.999999, theta=0.0
% INFO    : Bus 553	: V=1.0104235, theta=-33.8786474 -> V=1.0000005, theta=0.0
% INFO    : Bus 554	: V=1.03557286, theta=0.925069514 -> V=1.0158755, theta=0.0
% INFO    : Bus 555	: V=1.0919974, theta=-13.0962417 -> V=1.046375, theta=0.0
% INFO    : Bus 556	: V=1.0919994, theta=-13.0962636 -> V=1.046375, theta=0.0
% INFO    : Bus 557	: V=1.0710779, theta=-18.3368871 -> V=1.044445, theta=0.0
% INFO    : Bus 558	: V=1.07045984, theta=-23.1609938 -> V=1.046665, theta=0.0
% INFO    : Bus 559	: V=1.02598502, theta=-19.0336408 -> V=0.999999, theta=0.0
% INFO    : Bus 560	: V=1.01526095, theta=-19.285561 -> V=1.0158755, theta=0.0
% INFO    : Bus 561	: V=1.02554079, theta=-23.1669716 -> V=1.0000025, theta=0.0
% INFO    : Bus 562	: V=1.03186207, theta=-36.4724454 -> V=1.027779, theta=0.0
% INFO    : Bus 563	: V=1.00557149, theta=-12.0419432 -> V=1.015872, theta=0.0
% INFO    : Bus 564	: V=1.04899245, theta=-7.54124991 -> V=1.046665, theta=0.0
% INFO    : Bus 565	: V=1.03678599, theta=-17.3385305 -> V=1.0000025, theta=0.0
% INFO    : Bus 566	: V=1.0353551, theta=-44.1563161 -> V=1.022224, theta=0.0
% INFO    : Bus 567	: V=1.03512698, theta=-20.3885441 -> V=1.0000025, theta=0.0
% INFO    : Bus 568	: V=1.00818895, theta=-22.2503493 -> V=1.015872, theta=0.0
% INFO    : Bus 569	: V=1.04406889, theta=-26.3490734 -> V=1.0000025, theta=0.0
% INFO    : Bus 570	: V=1.0003895, theta=-2.24255957 -> V=1.0158755, theta=0.0
% INFO    : Bus 571	: V=1.02650719, theta=-30.0350875 -> V=1.0000025, theta=0.0
% INFO    : Bus 572	: V=1.01374319, theta=-14.3938413 -> V=0.999999, theta=0.0
% INFO    : Bus 573	: V=1.02026619, theta=-31.8670207 -> V=1.0000025, theta=0.0
% INFO    : Bus 574	: V=1.03868942, theta=-21.9165158 -> V=1.022224, theta=0.0
% INFO    : Bus 575	: V=1.03135637, theta=-19.4873416 -> V=0.999999, theta=0.0
% INFO    : Bus 576	: V=1.05288659, theta=-15.2119882 -> V=1.0111115, theta=0.0
% INFO    : Bus 577	: V=1.06606702, theta=-18.9037007 -> V=1.044445, theta=0.0
% INFO    : Bus 578	: V=1.03771388, theta=-28.766316 -> V=1.0000025, theta=0.0
% INFO    : Bus 579	: V=1.05207441, theta=-17.9147703 -> V=1.046665, theta=0.0
% INFO    : Bus 580	: V=1.05196721, theta=-17.9248913 -> V=1.046665, theta=0.0
% INFO    : Bus 581	: V=1.05238932, theta=-12.7025406 -> V=1.046665, theta=0.0
% INFO    : Bus 582	: V=1.04944473, theta=-9.52851802 -> V=1.06579, theta=0.0
% INFO    : Bus 583	: V=1.021, theta=-28.2808645 -> V=1.0000005, theta=0.0
% INFO    : Bus 584	: V=1.03834748, theta=-12.9240629 -> V=0.999999, theta=0.0
% INFO    : Bus 585	: V=0.994166962, theta=-3.36267662 -> V=1.0158755, theta=0.0
% INFO    : Bus 586	: V=1.02001957, theta=-10.6092696 -> V=0.999999, theta=0.0
% INFO    : Bus 587	: V=1.01772522, theta=-3.67431348 -> V=1.0158755, theta=0.0
% INFO    : Bus 588	: V=1.04510666, theta=-9.69250989 -> V=0.999999, theta=0.0
% INFO    : Bus 589	: V=1.02980262, theta=-22.5162338 -> V=1.000001, theta=0.0
% INFO    : Bus 590	: V=1.06866096, theta=-10.5782161 -> V=0.9888895, theta=0.0
% INFO    : Bus 591	: V=1.02429255, theta=-43.776346 -> V=1.0079355, theta=0.0
% INFO    : Bus 592	: V=1.04965062, theta=-35.0863133 -> V=1.0000025, theta=0.0
% INFO    : Bus 593	: V=1.01212962, theta=-21.2977351 -> V=1.0000025, theta=0.0
% INFO    : Bus 594	: V=1.09607819, theta=-8.99640073 -> V=1.05067, theta=0.0
% INFO    : Bus 595	: V=1.09025683, theta=-9.0726064 -> V=1.078945, theta=0.0
% INFO    : Bus 596	: V=1.02916633, theta=-39.8590454 -> V=1.022224, theta=0.0
% INFO    : Bus 597	: V=1.03570234, theta=-19.7339931 -> V=1.0158755, theta=0.0
% INFO    : Bus 598	: V=1.06625271, theta=-16.2621104 -> V=1.0377785, theta=0.0
% INFO    : Bus 599	: V=1.03163741, theta=-29.2494467 -> V=1.022224, theta=0.0
% INFO    : Bus 600	: V=1.02277991, theta=-28.0123065 -> V=1.015872, theta=0.0
% INFO    : Bus 601	: V=1.02441075, theta=-24.1568395 -> V=1.000001, theta=0.0
% INFO    : Bus 602	: V=1.03907384, theta=-21.7048778 -> V=1.0000025, theta=0.0
% INFO    : Bus 603	: V=1.06929715, theta=-20.2278576 -> V=1.044445, theta=0.0
% INFO    : Bus 604	: V=1.07069979, theta=-46.2571562 -> V=1.04444, theta=0.0
% INFO    : Bus 605	: V=1.07069979, theta=-46.2571562 -> V=1.04444, theta=0.0
% INFO    : Bus 606	: V=1.0707073, theta=-46.2573531 -> V=1.04444, theta=0.0
% INFO    : Bus 607	: V=1.04544168, theta=-49.8479293 -> V=1.0079355, theta=0.0
% INFO    : Bus 608	: V=1.07069873, theta=-46.2571285 -> V=1.04444, theta=0.0
% INFO    : Bus 609	: V=1.02405116, theta=-28.3288068 -> V=1.0000005, theta=0.0
% INFO    : Bus 610	: V=1.028, theta=-7.02539493 -> V=0.975, theta=0.0
% INFO    : Bus 611	: V=1.03113362, theta=-8.70114838 -> V=1.0111115, theta=0.0
% INFO    : Bus 612	: V=1.02203446, theta=-28.2907138 -> V=1.022224, theta=0.0
% INFO    : Bus 613	: V=1.01839611, theta=-28.6013203 -> V=1.0000005, theta=0.0
% INFO    : Bus 614	: V=1.01048802, theta=-33.1027029 -> V=1.0000025, theta=0.0
% INFO    : Bus 615	: V=1.04653804, theta=-14.7690429 -> V=1.0377785, theta=0.0
% INFO    : Bus 616	: V=1.0877911, theta=-13.3457824 -> V=1.044445, theta=0.0
% INFO    : Bus 617	: V=1.10190769, theta=-10.258592 -> V=1.07944, theta=0.0
% INFO    : Bus 618	: V=1.02330448, theta=-32.6360987 -> V=1.0000005, theta=0.0
% INFO    : Bus 619	: V=1.02175772, theta=-32.6917327 -> V=1.0000005, theta=0.0
% INFO    : Bus 620	: V=1.02005275, theta=-28.2933392 -> V=1.0000005, theta=0.0
% INFO    : Bus 621	: V=1.0200642, theta=-28.2952219 -> V=1.0000005, theta=0.0
% INFO    : Bus 622	: V=1.04486235, theta=-18.2448673 -> V=1.0158755, theta=0.0
% INFO    : Bus 623	: V=1.00230069, theta=-9.76784592 -> V=0.999999, theta=0.0
% INFO    : Bus 624	: V=1.039, theta=-5.30802798 -> V=1.0111115, theta=0.0
% INFO    : Bus 625	: V=1.02278011, theta=-52.1481571 -> V=1.0079355, theta=0.0
% INFO    : Bus 626	: V=1.02742728, theta=-13.4744823 -> V=1.015872, theta=0.0
% INFO    : Bus 627	: V=0.986968757, theta=-12.1108719 -> V=1.015872, theta=0.0
% INFO    : Bus 628	: V=1.04988278, theta=-11.0315022 -> V=1.0233335, theta=0.0
% INFO    : Bus 629	: V=1.05830355, theta=-19.4840062 -> V=1.024714, theta=0.0
% INFO    : Bus 630	: V=1.00803531, theta=-26.3746902 -> V=1.0000005, theta=0.0
% INFO    : Bus 631	: V=1.04972771, theta=-25.6816085 -> V=1.046665, theta=0.0
% INFO    : Bus 632	: V=1.04998021, theta=-25.5939071 -> V=1.046665, theta=0.0
% INFO    : Bus 633	: V=1.04081404, theta=-13.2751708 -> V=0.999999, theta=0.0
% INFO    : Bus 634	: V=1.02728314, theta=-54.8217115 -> V=1.0079355, theta=0.0
% INFO    : Bus 635	: V=0.996266506, theta=-14.3760979 -> V=1.0158755, theta=0.0
% INFO    : Bus 636	: V=1.003, theta=-19.361683 -> V=1.015872, theta=0.0
% INFO    : Bus 637	: V=1.03065558, theta=-19.9056708 -> V=0.999999, theta=0.0
% INFO    : Bus 638	: V=1.05276096, theta=-25.5382008 -> V=1.022224, theta=0.0
% INFO    : Bus 639	: V=1.03570106, theta=-38.6848368 -> V=1.0079355, theta=0.0
% INFO    : Bus 640	: V=1.06859018, theta=-10.6661768 -> V=0.9888895, theta=0.0
% INFO    : Bus 641	: V=1.104, theta=-8.91556648 -> V=1.079965, theta=0.0
% INFO    : Bus 642	: V=1.02216053, theta=-4.58519624 -> V=0.999999, theta=0.0
% INFO    : Bus 643	: V=1.02117016, theta=-9.1157779 -> V=0.999999, theta=0.0
% INFO    : Bus 644	: V=1.02709888, theta=-11.9908091 -> V=0.999999, theta=0.0
% INFO    : Bus 645	: V=1.02464382, theta=-12.1392908 -> V=0.999999, theta=0.0
% INFO    : Bus 646	: V=1.03845393, theta=-29.7114476 -> V=1.022224, theta=0.0
% INFO    : Bus 647	: V=1.01353855, theta=-11.3045092 -> V=1.0158755, theta=0.0
% INFO    : Bus 648	: V=1.02668364, theta=-16.5803572 -> V=1.015872, theta=0.0
% INFO    : Bus 649	: V=1.03960377, theta=-14.8319284 -> V=0.999999, theta=0.0
% INFO    : Bus 650	: V=1.04461828, theta=-26.3155506 -> V=1.0000025, theta=0.0
% INFO    : Bus 651	: V=1.03253929, theta=-39.1846723 -> V=1.022224, theta=0.0
% INFO    : Bus 652	: V=1.06155353, theta=-17.4445036 -> V=1.0000025, theta=0.0
% INFO    : Bus 653	: V=1.05185914, theta=-23.4963119 -> V=1.0000025, theta=0.0
% INFO    : Bus 654	: V=1.06627832, theta=-18.8738226 -> V=1.044445, theta=0.0
% INFO    : Bus 655	: V=1.04144214, theta=-6.07021987 -> V=1.0158755, theta=0.0
% INFO    : Bus 656	: V=1.0289992, theta=-21.9674078 -> V=1.0000025, theta=0.0
% INFO    : Bus 657	: V=1.03495191, theta=-26.2758679 -> V=1.015872, theta=0.0
% INFO    : Bus 658	: V=1.06531329, theta=-0.601299331 -> V=1.0377785, theta=0.0
% INFO    : Bus 659	: V=0.99991503, theta=-31.5074753 -> V=1.0000005, theta=0.0
% INFO    : Bus 660	: V=1.02853956, theta=3.00733713 -> V=1.0158755, theta=0.0
% INFO    : Bus 661	: V=1.0237563, theta=-43.4942443 -> V=1.022224, theta=0.0
% INFO    : Bus 662	: V=1.0694371, theta=-20.5579711 -> V=1.000001, theta=0.0
% INFO    : Bus 663	: V=1.05552634, theta=-22.9291484 -> V=1.022224, theta=0.0
% INFO    : Bus 664	: V=1.07726868, theta=-1.4099227 -> V=1.072365, theta=0.0
% INFO    : Bus 665	: V=1.0764839, theta=-1.47386943 -> V=1.072365, theta=0.0
% INFO    : Bus 666	: V=1.07728397, theta=-1.41029596 -> V=1.072365, theta=0.0
% INFO    : Bus 667	: V=1.07647158, theta=-1.48446831 -> V=1.072365, theta=0.0
% INFO    : Bus 668	: V=1.03916992, theta=-16.1027815 -> V=1.000001, theta=0.0
% INFO    : Bus 669	: V=1.06826568, theta=-12.1066478 -> V=1.006667, theta=0.0
% INFO    : Bus 670	: V=1.03266363, theta=-19.6518482 -> V=1.022224, theta=0.0
% INFO    : Bus 671	: V=1.03396333, theta=-23.2819067 -> V=1.027779, theta=0.0
% INFO    : Bus 672	: V=1.02257995, theta=-14.1469528 -> V=0.999999, theta=0.0
% INFO    : Bus 673	: V=1.0423805, theta=-18.9740368 -> V=1.000001, theta=0.0
% INFO    : Bus 674	: V=1.06119163, theta=-25.4178275 -> V=1.023279, theta=0.0
% INFO    : Bus 675	: V=1.01966252, theta=-18.7216491 -> V=0.999999, theta=0.0
% INFO    : Bus 676	: V=1.07349356, theta=-6.39966882 -> V=1.0377785, theta=0.0
% INFO    : Bus 677	: V=1.05103882, theta=-38.4997284 -> V=1.024594, theta=0.0
% INFO    : Bus 678	: V=1.06220635, theta=-34.5821928 -> V=1.04444, theta=0.0
% INFO    : Bus 679	: V=1.00853751, theta=-40.9531167 -> V=1.022224, theta=0.0
% INFO    : Bus 680	: V=1.05862474, theta=-21.7347922 -> V=1.022374, theta=0.0
% INFO    : Bus 681	: V=1.02487978, theta=-33.4963351 -> V=1.0000005, theta=0.0
% INFO    : Bus 682	: V=1.04113273, theta=-21.4995597 -> V=1.0000025, theta=0.0
% INFO    : Bus 683	: V=0.995375762, theta=-32.4238551 -> V=1.0000005, theta=0.0
% INFO    : Bus 684	: V=0.966, theta=-8.17233854 -> V=0.9444445, theta=0.0
% INFO    : Bus 685	: V=1.07944913, theta=-5.54404223 -> V=1.07237, theta=0.0
% INFO    : Bus 686	: V=1.00447543, theta=-18.4607284 -> V=0.999999, theta=0.0
% INFO    : Bus 687	: V=1.07946473, theta=-5.56172333 -> V=1.07237, theta=0.0
% INFO    : Bus 688	: V=1.03516682, theta=-30.65414 -> V=1.027779, theta=0.0
% INFO    : Bus 689	: V=1.02059623, theta=-24.8649363 -> V=1.027779, theta=0.0
% INFO    : Bus 690	: V=1.04561879, theta=-16.7294407 -> V=0.999999, theta=0.0
% INFO    : Bus 691	: V=1.04648173, theta=-26.3426248 -> V=1.046665, theta=0.0
% INFO    : Bus 692	: V=1.02795421, theta=-23.8793138 -> V=1.000001, theta=0.0
% INFO    : Bus 693	: V=1.04719812, theta=-11.090998 -> V=1.033334, theta=0.0
% INFO    : Bus 694	: V=1.04725688, theta=-11.0901898 -> V=1.033334, theta=0.0
% INFO    : Bus 695	: V=1.04900365, theta=-23.5423448 -> V=1.022222, theta=0.0
% INFO    : Bus 696	: V=1.05363607, theta=-19.3484288 -> V=1.0288895, theta=0.0
% INFO    : Bus 697	: V=1.012, theta=-2.40655153 -> V=0.975, theta=0.0
% INFO    : Bus 698	: V=1.012, theta=-2.36242754 -> V=0.975, theta=0.0
% INFO    : Bus 699	: V=1.014, theta=-2.69451486 -> V=0.975, theta=0.0
% INFO    : Bus 700	: V=1.02441001, theta=-4.73963553 -> V=1.0111115, theta=0.0
% INFO    : Bus 701	: V=1.02538469, theta=-5.09125915 -> V=1.0111115, theta=0.0
% INFO    : Bus 702	: V=1.03287008, theta=-33.8308072 -> V=1.022224, theta=0.0
% INFO    : Bus 703	: V=1.03618514, theta=-35.0621316 -> V=1.022224, theta=0.0
% INFO    : Bus 704	: V=1.06086612, theta=-31.2592992 -> V=1.04444, theta=0.0
% INFO    : Bus 705	: V=0.96, theta=-8.16094486 -> V=0.9444445, theta=0.0
% INFO    : Bus 706	: V=1.00405403, theta=-25.5810409 -> V=1.022224, theta=0.0
% INFO    : Bus 707	: V=1.07167119, theta=-27.1829476 -> V=0.975, theta=0.0
% INFO    : Bus 708	: V=1.0716441, theta=-27.184915 -> V=0.975, theta=0.0
% INFO    : Bus 709	: V=1.07165674, theta=-27.1866619 -> V=0.975, theta=0.0
% INFO    : Bus 710	: V=1.04236652, theta=-30.1991576 -> V=1.022224, theta=0.0
% INFO    : Bus 711	: V=1.06170517, theta=-32.2319724 -> V=1.023839, theta=0.0
% INFO    : Bus 712	: V=1.07168279, theta=-27.1750533 -> V=1.04444, theta=0.0
% INFO    : Bus 713	: V=1.04074143, theta=-24.7798954 -> V=1.022224, theta=0.0
% INFO    : Bus 714	: V=1.01263228, theta=-19.4911614 -> V=1.015872, theta=0.0
% INFO    : Bus 715	: V=1.05072194, theta=-13.640797 -> V=1.033334, theta=0.0
% INFO    : Bus 716	: V=0.995056454, theta=-24.730015 -> V=1.0158755, theta=0.0
% INFO    : Bus 717	: V=1.04338183, theta=-19.3716383 -> V=1.022224, theta=0.0
% INFO    : Bus 718	: V=0.99464747, theta=-25.0427003 -> V=1.0158755, theta=0.0
% INFO    : Bus 719	: V=1.04670727, theta=-39.800119 -> V=1.022224, theta=0.0
% INFO    : Bus 720	: V=1.01143544, theta=-1.59483029 -> V=1.0158755, theta=0.0
% INFO    : Bus 721	: V=1.0746007, theta=-18.0697321 -> V=1.04464, theta=0.0
% INFO    : Bus 722	: V=1.0383217, theta=-21.0374978 -> V=1.000001, theta=0.0
% INFO    : Bus 723	: V=1.0136481, theta=-14.4701872 -> V=0.999999, theta=0.0
% INFO    : Bus 724	: V=0.995695394, theta=-30.8250303 -> V=1.015872, theta=0.0
% INFO    : Bus 725	: V=1.03566623, theta=-20.7563835 -> V=1.015874, theta=0.0
% INFO    : Bus 726	: V=1.06006851, theta=-21.6198081 -> V=1.015874, theta=0.0
% INFO    : Bus 727	: V=1.04766386, theta=-17.3255956 -> V=1.0200005, theta=0.0
% INFO    : Bus 728	: V=1.00037305, theta=-28.1029516 -> V=1.0000005, theta=0.0
% INFO    : Bus 729	: V=1.0014035, theta=-27.6937019 -> V=1.0000005, theta=0.0
% INFO    : Bus 730	: V=0.999320318, theta=-27.7360024 -> V=1.0000005, theta=0.0
% INFO    : Bus 731	: V=1.00752768, theta=-21.795325 -> V=1.0000005, theta=0.0
% INFO    : Bus 732	: V=1.0370334, theta=-46.8883744 -> V=1.022224, theta=0.0
% INFO    : Bus 733	: V=1.007, theta=-11.8648689 -> V=0.999999, theta=0.0
% INFO    : Bus 734	: V=1.00494247, theta=-7.15848931 -> V=1.0158755, theta=0.0
% INFO    : Bus 735	: V=1.06475162, theta=-22.6186072 -> V=1.027779, theta=0.0
% INFO    : Bus 736	: V=1.04743866, theta=-23.8342723 -> V=1.000001, theta=0.0
% INFO    : Bus 737	: V=1.03908264, theta=-21.7051428 -> V=1.0000025, theta=0.0
% INFO    : Bus 738	: V=1.06726901, theta=-23.5642591 -> V=1.027909, theta=0.0
% INFO    : Bus 739	: V=1.064273, theta=-24.5436469 -> V=1.046665, theta=0.0
% INFO    : Bus 740	: V=1.04459348, theta=-28.1440351 -> V=1.022224, theta=0.0
% INFO    : Bus 741	: V=1.04553143, theta=-28.1785958 -> V=1.022224, theta=0.0
% INFO    : Bus 742	: V=1.04199425, theta=-9.39057631 -> V=1.0158755, theta=0.0
% INFO    : Bus 743	: V=1.07372637, theta=-6.59032505 -> V=1.0377785, theta=0.0
% INFO    : Bus 744	: V=1.01584087, theta=-11.7123508 -> V=0.999999, theta=0.0
% INFO    : Bus 745	: V=1.015, theta=-11.2621817 -> V=0.999999, theta=0.0
% INFO    : Bus 746	: V=1.023, theta=-36.9549787 -> V=1.022224, theta=0.0
% INFO    : Bus 747	: V=1.01859686, theta=-46.8628068 -> V=1.0079355, theta=0.0
% INFO    : Bus 748	: V=1.03404893, theta=-38.7932677 -> V=1.022224, theta=0.0
% INFO    : Bus 749	: V=1.05042036, theta=-20.9377242 -> V=1.0000025, theta=0.0
% INFO    : Bus 750	: V=1.02540559, theta=-19.3978246 -> V=0.999999, theta=0.0
% INFO    : Bus 751	: V=1.01843842, theta=-4.66727282 -> V=0.999999, theta=0.0
% INFO    : Bus 752	: V=1.02800857, theta=-10.3547856 -> V=1.0158755, theta=0.0
% INFO    : Bus 753	: V=1.05250477, theta=-15.8506838 -> V=1.002939, theta=0.0
% INFO    : Bus 754	: V=1.04343803, theta=-26.3013717 -> V=1.046665, theta=0.0
% INFO    : Bus 755	: V=1.04239416, theta=-24.9368006 -> V=1.06579, theta=0.0
% INFO    : Bus 756	: V=1.00143157, theta=-12.4058266 -> V=1.015872, theta=0.0
% INFO    : Bus 757	: V=1.06446748, theta=-24.8305658 -> V=1.046665, theta=0.0
% INFO    : Bus 758	: V=1.05938841, theta=-16.1863942 -> V=0.9888895, theta=0.0
% INFO    : Bus 759	: V=1.0593883, theta=-16.1863937 -> V=0.9888895, theta=0.0
% INFO    : Bus 760	: V=1.045, theta=-11.6186986 -> V=1.000709, theta=0.0
% INFO    : Bus 761	: V=1.043, theta=-12.6180446 -> V=0.999999, theta=0.0
% INFO    : Bus 762	: V=0.579715903, theta=-17.7558487 -> V=0.825, theta=0.0
% INFO    : Bus 763	: V=1.05333754, theta=-17.7558487 -> V=1.0158755, theta=0.0
% INFO    : Bus 764	: V=1.024262, theta=-0.866909827 -> V=1.0158755, theta=0.0
% INFO    : Bus 765	: V=1.04046312, theta=-16.788196 -> V=1.0158755, theta=0.0
% INFO    : Bus 766	: V=1.02475412, theta=-9.12199979 -> V=1.0158755, theta=0.0
% INFO    : Bus 767	: V=1.05942579, theta=-28.1923794 -> V=1.022744, theta=0.0
% INFO    : Bus 768	: V=1.04361362, theta=-41.8667519 -> V=1.022224, theta=0.0
% INFO    : Bus 769	: V=1.07498207, theta=-36.2640595 -> V=1.04444, theta=0.0
% INFO    : Bus 770	: V=1.04210851, theta=-10.8299268 -> V=0.975, theta=0.0
% INFO    : Bus 771	: V=1.04210851, theta=-10.8299268 -> V=0.975, theta=0.0
% INFO    : Bus 772	: V=1.04210851, theta=-10.8299268 -> V=0.975, theta=0.0
% INFO    : Bus 773	: V=1.04106744, theta=-10.8299268 -> V=0.999999, theta=0.0
% INFO    : Bus 774	: V=1.02320842, theta=-29.7635734 -> V=1.0000025, theta=0.0
% INFO    : Bus 775	: V=1.0703518, theta=-23.3010878 -> V=1.029449, theta=0.0
% INFO    : Bus 776	: V=1.02624552, theta=-0.830350609 -> V=1.0158755, theta=0.0
% INFO    : Bus 777	: V=1.07478591, theta=3.71728087 -> V=1.0377785, theta=0.0
% INFO    : Bus 778	: V=1.037947, theta=-41.5419787 -> V=1.0079355, theta=0.0
% INFO    : Bus 779	: V=1.03768939, theta=-41.5569865 -> V=1.0079355, theta=0.0
% INFO    : Bus 780	: V=1.03807819, theta=-41.5248321 -> V=1.0079355, theta=0.0
% INFO    : Bus 781	: V=1.02597732, theta=-19.7796764 -> V=1.0158755, theta=0.0
% INFO    : Bus 782	: V=1.02380836, theta=-25.6304869 -> V=1.0000025, theta=0.0
% INFO    : Bus 783	: V=1.04716208, theta=-16.2749074 -> V=1.046665, theta=0.0
% INFO    : Bus 784	: V=1.04571323, theta=-16.8602961 -> V=1.046665, theta=0.0
% INFO    : Bus 785	: V=1.01966857, theta=-8.66884114 -> V=0.999999, theta=0.0
% INFO    : Bus 786	: V=1.02193372, theta=-10.9323771 -> V=0.975, theta=0.0
% INFO    : Bus 787	: V=1.02664938, theta=-10.011527 -> V=0.975, theta=0.0
% INFO    : Bus 788	: V=1.02562376, theta=-10.011527 -> V=0.999999, theta=0.0
% INFO    : Bus 789	: V=1.02091281, theta=-10.9323771 -> V=0.999999, theta=0.0
% INFO    : Bus 790	: V=1.02695826, theta=-6.0777605 -> V=1.0111115, theta=0.0
% INFO    : Bus 791	: V=1.08100805, theta=0.806414519 -> V=1.072365, theta=0.0
% INFO    : Bus 792	: V=1.02223811, theta=-13.3644319 -> V=1.0158755, theta=0.0
% INFO    : Bus 793	: V=1.01907616, theta=-25.14153 -> V=1.022224, theta=0.0
% INFO    : Bus 794	: V=1.02845048, theta=-16.6093661 -> V=1.0158755, theta=0.0
% INFO    : Bus 795	: V=1.02535478, theta=-17.3434373 -> V=1.0158755, theta=0.0
% INFO    : Bus 796	: V=1.04021838, theta=-12.7331722 -> V=0.999999, theta=0.0
% INFO    : Bus 797	: V=1.02172417, theta=-52.0872638 -> V=1.0079355, theta=0.0
% INFO    : Bus 798	: V=1.03686309, theta=-16.7142333 -> V=0.999999, theta=0.0
% INFO    : Bus 799	: V=1.02162053, theta=-12.515766 -> V=0.999999, theta=0.0
% INFO    : Bus 800	: V=1.06327013, theta=-5.23927128 -> V=1.072365, theta=0.0
% INFO    : Bus 801	: V=1.014, theta=-3.27279424 -> V=0.975, theta=0.0
% INFO    : Bus 802	: V=1.017, theta=-3.47531335 -> V=0.975, theta=0.0
% INFO    : Bus 803	: V=1.016, theta=-3.51564665 -> V=0.975, theta=0.0
% INFO    : Bus 804	: V=1.02576578, theta=-5.40270121 -> V=1.0111115, theta=0.0
% INFO    : Bus 805	: V=1.02633303, theta=-5.65993514 -> V=1.0111115, theta=0.0
% INFO    : Bus 806	: V=1.06231867, theta=-28.7745357 -> V=1.0000025, theta=0.0
% INFO    : Bus 807	: V=1.02332486, theta=-24.7256869 -> V=1.0000025, theta=0.0
% INFO    : Bus 808	: V=1.05195873, theta=-14.0424056 -> V=1.046665, theta=0.0
% INFO    : Bus 809	: V=1.0525282, theta=-13.9824312 -> V=1.046665, theta=0.0
% INFO    : Bus 810	: V=1.03252759, theta=-29.3578316 -> V=1.015872, theta=0.0
% INFO    : Bus 811	: V=1.01655344, theta=-29.795439 -> V=1.0000025, theta=0.0
% INFO    : Bus 812	: V=1.04829181, theta=-15.180271 -> V=1.046665, theta=0.0
% INFO    : Bus 813	: V=1.04229883, theta=-14.6561253 -> V=0.999999, theta=0.0
% INFO    : Bus 814	: V=1.00355274, theta=-18.0263598 -> V=1.015872, theta=0.0
% INFO    : Bus 815	: V=1.019, theta=-11.1483039 -> V=1.015872, theta=0.0
% INFO    : Bus 816	: V=1.019, theta=-8.88388246 -> V=1.015872, theta=0.0
% INFO    : Bus 817	: V=1.07066444, theta=-25.8422655 -> V=1.046665, theta=0.0
% INFO    : Bus 818	: V=1.02206924, theta=-52.1203983 -> V=1.0079355, theta=0.0
% INFO    : Bus 819	: V=1.03718851, theta=-28.846137 -> V=1.0000025, theta=0.0
% INFO    : Bus 820	: V=1.0369027, theta=-28.8762919 -> V=1.0000025, theta=0.0
% INFO    : Bus 821	: V=1.04584671, theta=-16.7872501 -> V=1.046665, theta=0.0
% INFO    : Bus 822	: V=1.04649455, theta=-16.7573035 -> V=1.046665, theta=0.0
% INFO    : Bus 823	: V=1.07225048, theta=-22.7438148 -> V=1.030394, theta=0.0
% INFO    : Bus 824	: V=1.06863294, theta=-12.2911095 -> V=1.0266685, theta=0.0
% INFO    : Bus 825	: V=1.00002309, theta=-14.4960829 -> V=1.015872, theta=0.0
% INFO    : Bus 826	: V=1.04490303, theta=-20.2031418 -> V=1.0000025, theta=0.0
% INFO    : Bus 827	: V=1.07283495, theta=-44.5083294 -> V=1.04444, theta=0.0
% INFO    : Bus 828	: V=1.07365643, theta=-40.2883383 -> V=1.07237, theta=0.0
% INFO    : Bus 829	: V=1.05778691, theta=-15.9746991 -> V=1.022222, theta=0.0
% INFO    : Bus 830	: V=1.053, theta=-24.6532669 -> V=1.0000025, theta=0.0
% INFO    : Bus 831	: V=0.979468296, theta=-5.00240982 -> V=0.9444445, theta=0.0
% INFO    : Bus 832	: V=1.01045477, theta=-14.8488557 -> V=1.015872, theta=0.0
% INFO    : Bus 833	: V=1.07824626, theta=-16.4486838 -> V=1.0000025, theta=0.0
% INFO    : Bus 834	: V=1.04818523, theta=-28.1406101 -> V=1.027779, theta=0.0
% INFO    : Bus 835	: V=1.05284803, theta=-19.6904921 -> V=1.015874, theta=0.0
% INFO    : Bus 836	: V=1.033, theta=-23.5002681 -> V=1.0000025, theta=0.0
% INFO    : Bus 837	: V=1.05040342, theta=-20.9873672 -> V=1.0000025, theta=0.0
% INFO    : Bus 838	: V=1.05030406, theta=-20.9846803 -> V=1.0000025, theta=0.0
% INFO    : Bus 839	: V=1.04533659, theta=-28.4922923 -> V=1.0000025, theta=0.0
% INFO    : Bus 840	: V=1.02799885, theta=-22.4961308 -> V=1.0000025, theta=0.0
% INFO    : Bus 841	: V=1.06769, theta=-23.4213116 -> V=1.028119, theta=0.0
% INFO    : Bus 842	: V=1.03148186, theta=-16.1569955 -> V=1.015872, theta=0.0
% INFO    : Bus 843	: V=1.04294356, theta=-23.1606404 -> V=1.027779, theta=0.0
% INFO    : Bus 844	: V=1.02444346, theta=-29.0682124 -> V=1.0000025, theta=0.0
% INFO    : Bus 845	: V=1.01300873, theta=-30.2699904 -> V=1.0000025, theta=0.0
% INFO    : Bus 846	: V=1.01275995, theta=-32.5062412 -> V=1.015872, theta=0.0
% INFO    : Bus 847	: V=1.01375472, theta=-32.571794 -> V=1.015872, theta=0.0
% INFO    : Bus 848	: V=1.01465412, theta=-32.4733324 -> V=1.015872, theta=0.0
% INFO    : Bus 849	: V=1.06222699, theta=-20.1170227 -> V=1.0000025, theta=0.0
% INFO    : Bus 850	: V=1.0782382, theta=-16.5072003 -> V=1.04585, theta=0.0
% INFO    : Bus 851	: V=1.07733158, theta=-13.4349107 -> V=1.078945, theta=0.0
% INFO    : Bus 852	: V=1.04811518, theta=-14.8736388 -> V=1.015874, theta=0.0
% INFO    : Bus 853	: V=1.06228395, theta=-11.3886464 -> V=1.0000005, theta=0.0
% INFO    : Bus 854	: V=1.06747627, theta=-2.57984279 -> V=1.05263, theta=0.0
% INFO    : Bus 855	: V=1.01218507, theta=-25.953545 -> V=1.0000005, theta=0.0
% INFO    : Bus 856	: V=1.02791841, theta=-42.3594043 -> V=1.0079355, theta=0.0
% INFO    : Bus 857	: V=1.0414546, theta=-29.6265235 -> V=1.0000025, theta=0.0
% INFO    : Bus 858	: V=1.05384582, theta=-22.522128 -> V=1.0000025, theta=0.0
% INFO    : Bus 859	: V=1.07471508, theta=-28.5102273 -> V=1.047335, theta=0.0
% INFO    : Bus 860	: V=1.03074904, theta=-26.7892828 -> V=1.046665, theta=0.0
% INFO    : Bus 861	: V=1.03870511, theta=-54.857821 -> V=1.0079355, theta=0.0
% INFO    : Bus 862	: V=1.06824541, theta=-15.7709325 -> V=1.0377785, theta=0.0
% INFO    : Bus 863	: V=1.06814099, theta=-15.8083055 -> V=1.0377785, theta=0.0
% INFO    : Bus 864	: V=1.016, theta=-21.6377546 -> V=1.0000025, theta=0.0
% INFO    : Bus 865	: V=1.018, theta=-21.9914971 -> V=1.0000025, theta=0.0
% INFO    : Bus 866	: V=1.0355125, theta=2.59424619 -> V=1.0158755, theta=0.0
% INFO    : Bus 867	: V=1.01016035, theta=-30.6052592 -> V=1.015872, theta=0.0
% INFO    : Bus 868	: V=1.03304729, theta=-26.4608042 -> V=1.022224, theta=0.0
% INFO    : Bus 869	: V=1.00300337, theta=-31.8293389 -> V=1.015872, theta=0.0
% INFO    : Bus 870	: V=1.01496913, theta=-20.0612318 -> V=1.015872, theta=0.0
% INFO    : Bus 871	: V=1.01319286, theta=-20.1586322 -> V=1.015872, theta=0.0
% INFO    : Bus 872	: V=1.06552925, theta=-26.4703578 -> V=1.027779, theta=0.0
% INFO    : Bus 873	: V=1.03589072, theta=-15.0153461 -> V=1.015872, theta=0.0
% INFO    : Bus 874	: V=1.0281269, theta=-42.6428595 -> V=1.0079355, theta=0.0
% INFO    : Bus 875	: V=1.02438908, theta=-28.0635733 -> V=1.015872, theta=0.0
% INFO    : Bus 876	: V=1.02326033, theta=-28.0737004 -> V=1.015872, theta=0.0
% INFO    : Bus 877	: V=1.071547, theta=-25.1696811 -> V=1.04682, theta=0.0
% INFO    : Bus 878	: V=1.07121099, theta=-25.188258 -> V=1.046665, theta=0.0
% INFO    : Bus 879	: V=1.05026028, theta=-28.2819197 -> V=1.0095305, theta=0.0
% INFO    : Bus 880	: V=1.03295425, theta=-28.205915 -> V=1.0000855, theta=0.0
% INFO    : Bus 881	: V=1.03946947, theta=-24.294715 -> V=1.046665, theta=0.0
% INFO    : Bus 882	: V=1.04793182, theta=-23.0372167 -> V=1.046665, theta=0.0
% INFO    : Bus 883	: V=1.0535883, theta=-20.2865659 -> V=1.0111115, theta=0.0
% INFO    : Bus 884	: V=1.04476769, theta=-54.1580922 -> V=1.0079355, theta=0.0
% INFO    : Bus 885	: V=1.0419035, theta=-27.3561502 -> V=1.0000025, theta=0.0
% INFO    : Bus 886	: V=1.03083468, theta=-23.5922404 -> V=1.000001, theta=0.0
% INFO    : Bus 887	: V=1.06799525, theta=-26.5084502 -> V=1.046665, theta=0.0
% INFO    : Bus 888	: V=1.06861735, theta=-26.4602917 -> V=1.046665, theta=0.0
% INFO    : Bus 889	: V=0.994002484, theta=-22.3539133 -> V=0.975, theta=0.0
% INFO    : Bus 890	: V=1.05775357, theta=-21.5502044 -> V=1.0233335, theta=0.0
% INFO    : Bus 891	: V=1.00774682, theta=-23.1418823 -> V=1.0000025, theta=0.0
% INFO    : Bus 892	: V=1.0486459, theta=-20.3545253 -> V=0.999999, theta=0.0
% INFO    : Bus 893	: V=1.03624325, theta=-20.8749856 -> V=1.015874, theta=0.0
% INFO    : Bus 894	: V=1.01536864, theta=-29.017468 -> V=1.0000005, theta=0.0
% INFO    : Bus 895	: V=1.09598598, theta=11.3537077 -> V=1.072365, theta=0.0
% INFO    : Bus 896	: V=1.09148971, theta=8.24420609 -> V=1.072365, theta=0.0
% INFO    : Bus 897	: V=1.09727285, theta=12.767022 -> V=1.072455, theta=0.0
% INFO    : Bus 898	: V=1.09711791, theta=12.7862062 -> V=1.072365, theta=0.0
% INFO    : Bus 899	: V=1.02625573, theta=-0.830545488 -> V=1.0158755, theta=0.0
% INFO    : Bus 900	: V=1.02443206, theta=-0.916092188 -> V=1.0158755, theta=0.0
% INFO    : Bus 901	: V=1.05010459, theta=-25.7067336 -> V=1.027779, theta=0.0
% INFO    : Bus 902	: V=1.05134791, theta=-30.2196437 -> V=1.0000025, theta=0.0
% INFO    : Bus 903	: V=1.05162984, theta=-23.0566798 -> V=1.022222, theta=0.0
% INFO    : Bus 904	: V=1.03676255, theta=-20.7009928 -> V=1.015874, theta=0.0
% INFO    : Bus 905	: V=1.04853441, theta=-25.9381277 -> V=1.046665, theta=0.0
% INFO    : Bus 906	: V=1.02326472, theta=-15.8161858 -> V=1.015872, theta=0.0
% INFO    : Bus 907	: V=1.05932182, theta=-31.8583758 -> V=1.027779, theta=0.0
% INFO    : Bus 908	: V=1.02649849, theta=-16.4501871 -> V=1.015872, theta=0.0
% INFO    : Bus 909	: V=0.988833277, theta=-35.8046343 -> V=1.015872, theta=0.0
% INFO    : Bus 910	: V=1.01969331, theta=-15.7532275 -> V=1.015872, theta=0.0
% INFO    : Bus 911	: V=1.01444957, theta=-29.9958525 -> V=1.0000005, theta=0.0
% INFO    : Bus 912	: V=1.01437582, theta=-30.006857 -> V=1.0000005, theta=0.0
% INFO    : Bus 913	: V=1.00527934, theta=-28.985487 -> V=1.0000025, theta=0.0
% INFO    : Bus 914	: V=1.07809645, theta=-18.4615374 -> V=1.044445, theta=0.0
% INFO    : Bus 915	: V=1.07869568, theta=-18.6543878 -> V=1.044445, theta=0.0
% INFO    : Bus 916	: V=1.08712118, theta=-16.9442499 -> V=1.078945, theta=0.0
% INFO    : Bus 917	: V=1.02641582, theta=-25.6457343 -> V=1.0000025, theta=0.0
% INFO    : Bus 918	: V=1.06813161, theta=-23.6813117 -> V=1.028334, theta=0.0
% INFO    : Bus 919	: V=1.0205443, theta=-23.0726491 -> V=1.0000025, theta=0.0
% INFO    : Bus 920	: V=1.0434229, theta=-28.9366015 -> V=1.0000025, theta=0.0
% INFO    : Bus 921	: V=1.02730515, theta=-6.08160762 -> V=1.0111115, theta=0.0
% INFO    : Bus 922	: V=1.04032888, theta=-12.7002789 -> V=0.999999, theta=0.0
% INFO    : Bus 923	: V=1.01296929, theta=-21.1720846 -> V=1.0000005, theta=0.0
% INFO    : Bus 924	: V=1.06002373, theta=-17.0496078 -> V=1.073685, theta=0.0
% INFO    : Bus 925	: V=1.04415216, theta=-20.4955224 -> V=0.999999, theta=0.0
% INFO    : Bus 926	: V=1.04231291, theta=-23.1351493 -> V=0.999999, theta=0.0
% INFO    : Bus 927	: V=1.07453453, theta=-5.32329931 -> V=1.0162105, theta=0.0
% INFO    : Bus 928	: V=1.03161875, theta=-22.8777136 -> V=1.0000025, theta=0.0
% INFO    : Bus 929	: V=1.05660958, theta=-10.9109935 -> V=1.0000025, theta=0.0
% INFO    : Bus 930	: V=1.02512237, theta=-32.2945912 -> V=1.0000025, theta=0.0
% INFO    : Bus 931	: V=1.05624688, theta=-26.245702 -> V=1.046665, theta=0.0
% INFO    : Bus 932	: V=1.07295352, theta=-26.08315 -> V=1.046665, theta=0.0
% INFO    : Bus 933	: V=1.07408335, theta=-26.2447498 -> V=1.046935, theta=0.0
% INFO    : Bus 934	: V=1.0673252, theta=-20.8221498 -> V=1.073685, theta=0.0
% INFO    : Bus 935	: V=1.06740786, theta=-20.8035444 -> V=1.073685, theta=0.0
% INFO    : Bus 936	: V=1.04296599, theta=-39.1540752 -> V=1.022224, theta=0.0
% INFO    : Bus 937	: V=1.05823421, theta=-14.5279147 -> V=1.000001, theta=0.0
% INFO    : Bus 938	: V=1.03419615, theta=-11.1460018 -> V=1.0088895, theta=0.0
% INFO    : Bus 939	: V=1.06327979, theta=-5.24718038 -> V=1.072365, theta=0.0
% INFO    : Bus 940	: V=1.00098101, theta=-21.7231092 -> V=1.0000025, theta=0.0
% INFO    : Bus 941	: V=1.04236836, theta=-36.7680458 -> V=1.022224, theta=0.0
% INFO    : Bus 942	: V=1.03728716, theta=-24.6762252 -> V=1.0158755, theta=0.0
% INFO    : Bus 943	: V=1.0329338, theta=-25.5492346 -> V=1.0158755, theta=0.0
% INFO    : Bus 944	: V=1.03693765, theta=-22.9859467 -> V=1.000001, theta=0.0
% INFO    : Bus 945	: V=1.00921063, theta=-22.2701915 -> V=1.015872, theta=0.0
% INFO    : Bus 946	: V=1.03688165, theta=-40.7979533 -> V=1.022224, theta=0.0
% INFO    : Bus 947	: V=1.04224953, theta=-18.9677813 -> V=1.022224, theta=0.0
% INFO    : Bus 948	: V=1.0380779, theta=-41.5248263 -> V=1.0079355, theta=0.0
% INFO    : Bus 949	: V=1.06759818, theta=-36.3132169 -> V=1.04444, theta=0.0
% INFO    : Bus 950	: V=1.03686292, theta=-6.20733437 -> V=1.0111115, theta=0.0
% INFO    : Bus 951	: V=1.0385603, theta=-28.4650104 -> V=1.022224, theta=0.0
% INFO    : Bus 952	: V=1.00656094, theta=-26.0192337 -> V=1.022224, theta=0.0
% INFO    : Bus 953	: V=1.04797419, theta=-8.76550324 -> V=1.001874, theta=0.0
% INFO    : Bus 954	: V=1.07373851, theta=-1.96358924 -> V=1.072365, theta=0.0
% INFO    : Bus 955	: V=1.03841945, theta=-20.0854948 -> V=1.022224, theta=0.0
% INFO    : Bus 956	: V=1.03835417, theta=-20.0617854 -> V=1.022224, theta=0.0
% INFO    : Bus 957	: V=0.992774419, theta=-24.602651 -> V=1.0158755, theta=0.0
% INFO    : Bus 958	: V=1.04053826, theta=-22.7486193 -> V=1.022224, theta=0.0
% INFO    : Bus 959	: V=1.00722417, theta=-28.069464 -> V=1.0158755, theta=0.0
% INFO    : Bus 960	: V=1.04668578, theta=-23.7332137 -> V=1.022224, theta=0.0
% INFO    : Bus 961	: V=1.070515, theta=-18.5391784 -> V=1.04444, theta=0.0
% INFO    : Bus 962	: V=1.07980566, theta=-15.3507016 -> V=1.07237, theta=0.0
% INFO    : Bus 963	: V=1.07982445, theta=-15.3474474 -> V=1.07237, theta=0.0
% INFO    : Bus 964	: V=1.01673345, theta=-21.6676293 -> V=1.0158755, theta=0.0
% INFO    : Bus 965	: V=1.062, theta=-2.71350446 -> V=0.975, theta=0.0
% INFO    : Bus 966	: V=1.08481833, theta=-2.4070026 -> V=1.0377785, theta=0.0
% INFO    : Bus 967	: V=1.03929554, theta=-46.0854164 -> V=1.022224, theta=0.0
% INFO    : Bus 968	: V=1.02028485, theta=-21.2686835 -> V=1.0158755, theta=0.0
% INFO    : Bus 969	: V=1.04675854, theta=-13.7235356 -> V=1.0377785, theta=0.0
% INFO    : Bus 970	: V=1.02469415, theta=-9.89773051 -> V=1.0158755, theta=0.0
% INFO    : Bus 971	: V=1.04495786, theta=-12.0648022 -> V=0.999999, theta=0.0
% INFO    : Bus 972	: V=1.03278833, theta=-12.1812867 -> V=0.999999, theta=0.0
% INFO    : Bus 973	: V=1.026, theta=-7.4564743 -> V=0.999999, theta=0.0
% INFO    : Bus 974	: V=1.0394263, theta=-29.916525 -> V=1.022224, theta=0.0
% INFO    : Bus 975	: V=1.08072373, theta=-22.408943 -> V=1.07237, theta=0.0
% INFO    : Bus 976	: V=1.02556215, theta=-9.29284001 -> V=1.0158755, theta=0.0
% INFO    : Bus 977	: V=1.05568334, theta=-5.32645372 -> V=1.0377785, theta=0.0
% INFO    : Bus 978	: V=1.05209996, theta=-12.6056726 -> V=1.004339, theta=0.0
% INFO    : Bus 979	: V=1.03607905, theta=-39.6017757 -> V=1.022224, theta=0.0
% INFO    : Bus 980	: V=1.02971245, theta=-13.7324001 -> V=0.999999, theta=0.0
% INFO    : Bus 981	: V=1.02894623, theta=-29.9489687 -> V=1.022224, theta=0.0
% INFO    : Bus 982	: V=1.04304955, theta=-27.6349687 -> V=1.022224, theta=0.0
% INFO    : Bus 983	: V=1.05279135, theta=-25.3031011 -> V=1.027779, theta=0.0
% INFO    : Bus 984	: V=1.07411057, theta=-21.4487294 -> V=1.046665, theta=0.0
% INFO    : Bus 985	: V=1.01906177, theta=-17.3580538 -> V=0.984126, theta=0.0
% INFO    : Bus 986	: V=1.05021109, theta=-25.8161263 -> V=1.022224, theta=0.0
% INFO    : Bus 987	: V=1.02937304, theta=-28.90177 -> V=1.022224, theta=0.0
% INFO    : Bus 988	: V=1.01360231, theta=-27.5310325 -> V=1.0000005, theta=0.0
% INFO    : Bus 989	: V=1.06722518, theta=-26.6277305 -> V=1.046665, theta=0.0
% INFO    : Bus 990	: V=1.06723801, theta=-26.6875077 -> V=1.046665, theta=0.0
% INFO    : Bus 991	: V=1.03804847, theta=-13.3985969 -> V=1.0158755, theta=0.0
% INFO    : Bus 992	: V=1.04964427, theta=-14.9672317 -> V=1.001149, theta=0.0
% INFO    : Bus 993	: V=1.02102275, theta=-26.4931055 -> V=1.0158755, theta=0.0
% INFO    : Bus 994	: V=1.01528771, theta=-21.11189 -> V=1.0158755, theta=0.0
% INFO    : Bus 995	: V=0.97275004, theta=-7.0790365 -> V=0.975, theta=0.0
% INFO    : Bus 996	: V=1.02372515, theta=-8.86671456 -> V=0.999999, theta=0.0
% INFO    : Bus 997	: V=1.05322563, theta=-6.40575784 -> V=1.0111115, theta=0.0
% INFO    : Bus 998	: V=1.07268136, theta=-2.75666682 -> V=1.072365, theta=0.0
% INFO    : Bus 999	: V=1.04759152, theta=-29.3583044 -> V=1.027779, theta=0.0
% INFO    : Bus 1000	: V=1.03718361, theta=-11.8717855 -> V=0.999999, theta=0.0
% INFO    : Bus 1001	: V=1.04031617, theta=-11.2339639 -> V=0.999999, theta=0.0
% INFO    : Bus 1002	: V=1.08815021, theta=-12.8619137 -> V=1.044445, theta=0.0
% INFO    : Bus 1003	: V=1.07971043, theta=-14.4461485 -> V=1.044445, theta=0.0
% INFO    : Bus 1004	: V=1.02412801, theta=-31.3660559 -> V=1.022224, theta=0.0
% INFO    : Bus 1005	: V=1.03958437, theta=-33.2780723 -> V=1.022224, theta=0.0
% INFO    : Bus 1006	: V=1.05187578, theta=-25.2054802 -> V=1.0233335, theta=0.0
% INFO    : Bus 1007	: V=1.07217114, theta=-25.5801233 -> V=1.046985, theta=0.0
% INFO    : Bus 1008	: V=1.05732988, theta=-25.1418427 -> V=1.046665, theta=0.0
% INFO    : Bus 1009	: V=1.062, theta=-20.6966814 -> V=1.000001, theta=0.0
% INFO    : Bus 1010	: V=1.04834596, theta=-42.6285424 -> V=1.022224, theta=0.0
% INFO    : Bus 1011	: V=1.06174863, theta=-10.1338143 -> V=1.003274, theta=0.0
% INFO    : Bus 1012	: V=1.05528535, theta=-7.36759685 -> V=1.0111115, theta=0.0
% INFO    : Bus 1013	: V=1.065, theta=-10.147663 -> V=1.004549, theta=0.0
% INFO    : Bus 1014	: V=1.04847019, theta=-31.2722726 -> V=1.022224, theta=0.0
% INFO    : Bus 1015	: V=1.01810958, theta=-18.0581913 -> V=0.999999, theta=0.0
% INFO    : Bus 1016	: V=1.0224328, theta=-16.027188 -> V=1.0158755, theta=0.0
% INFO    : Bus 1017	: V=1.01188282, theta=-21.9337104 -> V=1.0158755, theta=0.0
% INFO    : Bus 1018	: V=1.05408857, theta=-22.4774302 -> V=1.04444, theta=0.0
% INFO    : Bus 1019	: V=1.05409233, theta=-22.4764124 -> V=1.04444, theta=0.0
% INFO    : Bus 1020	: V=1.02694031, theta=-26.7263563 -> V=1.022224, theta=0.0
% INFO    : Bus 1021	: V=0.979762176, theta=-10.3538381 -> V=0.9444445, theta=0.0
% INFO    : Bus 1022	: V=0.979752121, theta=-10.3520696 -> V=0.9444445, theta=0.0
% INFO    : Bus 1023	: V=0.979752121, theta=-10.3520696 -> V=0.9444445, theta=0.0
% INFO    : Bus 1024	: V=1.01820873, theta=-22.2592892 -> V=1.022224, theta=0.0
% INFO    : Bus 1025	: V=1.03717903, theta=-40.3339356 -> V=1.022224, theta=0.0
% INFO    : Bus 1026	: V=1.08052015, theta=-23.9545581 -> V=1.0243505, theta=0.0
% INFO    : Bus 1027	: V=1.08057005, theta=-23.9551696 -> V=1.0243755, theta=0.0
% INFO    : Bus 1028	: V=1.05403601, theta=-23.952339 -> V=1.046665, theta=0.0
% INFO    : Bus 1029	: V=1.04939464, theta=-9.82524195 -> V=1.000001, theta=0.0
% INFO    : Bus 1030	: V=1.06518002, theta=-25.9474921 -> V=1.027779, theta=0.0
% INFO    : Bus 1031	: V=1.06447134, theta=-26.0434642 -> V=1.027779, theta=0.0
% INFO    : Bus 1032	: V=1.05666552, theta=-34.8954632 -> V=1.022224, theta=0.0
% INFO    : Bus 1033	: V=1.01785009, theta=-24.4270829 -> V=1.0000005, theta=0.0
% INFO    : Bus 1034	: V=1.04955024, theta=-19.0547535 -> V=1.046665, theta=0.0
% INFO    : Bus 1035	: V=1.06038684, theta=-16.5689604 -> V=1.073685, theta=0.0
% INFO    : Bus 1036	: V=1.07410634, theta=-12.7235578 -> V=1.073685, theta=0.0
% INFO    : Bus 1037	: V=1.06063134, theta=-16.3932645 -> V=1.073685, theta=0.0
% INFO    : Bus 1038	: V=1.01982409, theta=-9.74272987 -> V=0.999999, theta=0.0
% INFO    : Bus 1039	: V=1.06050848, theta=-16.4811058 -> V=1.073685, theta=0.0
% INFO    : Bus 1040	: V=1.03273365, theta=-42.0224787 -> V=1.0079355, theta=0.0
% INFO    : Bus 1041	: V=1.03599922, theta=-41.9922339 -> V=1.0079355, theta=0.0
% INFO    : Bus 1042	: V=1.06636648, theta=-36.5468642 -> V=1.04444, theta=0.0
% INFO    : Bus 1043	: V=1.01488272, theta=-37.9469578 -> V=1.027779, theta=0.0
% INFO    : Bus 1044	: V=1.04959709, theta=-14.1464369 -> V=0.999999, theta=0.0
% INFO    : Bus 1045	: V=1.07227256, theta=-12.3379092 -> V=1.05263, theta=0.0
% INFO    : Bus 1046	: V=1.06550226, theta=-26.8401577 -> V=1.046665, theta=0.0
% INFO    : Bus 1047	: V=1.07415051, theta=-25.7648119 -> V=1.048, theta=0.0
% INFO    : Bus 1048	: V=1.00170018, theta=-9.87290966 -> V=0.999999, theta=0.0
% INFO    : Bus 1049	: V=1.07184297, theta=-3.55563888 -> V=1.072365, theta=0.0
% INFO    : Bus 1050	: V=0.994065953, theta=-14.6205646 -> V=1.015872, theta=0.0
% INFO    : Bus 1051	: V=1.02353646, theta=-16.946178 -> V=1.000001, theta=0.0
% INFO    : Bus 1052	: V=1.08651461, theta=-19.4258024 -> V=1.07237, theta=0.0
% INFO    : Bus 1053	: V=1.04062641, theta=-28.676436 -> V=1.022224, theta=0.0
% INFO    : Bus 1054	: V=1.04275586, theta=-28.3775645 -> V=1.022224, theta=0.0
% INFO    : Bus 1055	: V=1.08655242, theta=-19.425406 -> V=1.07237, theta=0.0
% INFO    : Bus 1056	: V=1.08655233, theta=-19.4253043 -> V=1.07237, theta=0.0
% INFO    : Bus 1057	: V=1.072, theta=-17.5814299 -> V=1.022222, theta=0.0
% INFO    : Bus 1058	: V=1.04195034, theta=-37.7162649 -> V=1.022224, theta=0.0
% INFO    : Bus 1059	: V=1.05970471, theta=-33.469936 -> V=1.04444, theta=0.0
% INFO    : Bus 1060	: V=1.02010438, theta=2.75232865 -> V=1.0158755, theta=0.0
% INFO    : Bus 1061	: V=1.1038338, theta=7.52762843 -> V=1.05843, theta=0.0
% INFO    : Bus 1062	: V=1.09177225, theta=7.33112735 -> V=1.05263, theta=0.0
% INFO    : Bus 1063	: V=1.06016214, theta=-2.70377081 -> V=1.0000025, theta=0.0
% INFO    : Bus 1064	: V=1.07630676, theta=-0.0685947191 -> V=0.9888895, theta=0.0
% INFO    : Bus 1065	: V=1.04060147, theta=-24.4818872 -> V=0.9736045, theta=0.0
% INFO    : Bus 1066	: V=1.046, theta=-21.1392071 -> V=1.0000025, theta=0.0
% INFO    : Bus 1067	: V=1.02726595, theta=-29.0175953 -> V=1.0000025, theta=0.0
% INFO    : Bus 1068	: V=1.02772534, theta=-30.2440992 -> V=1.0000025, theta=0.0
% INFO    : Bus 1069	: V=1.01226873, theta=-30.5905955 -> V=1.015872, theta=0.0
% INFO    : Bus 1070	: V=1.01784685, theta=-6.12970177 -> V=1.0158755, theta=0.0
% INFO    : Bus 1071	: V=1.05733812, theta=-23.2101616 -> V=1.046665, theta=0.0
% INFO    : Bus 1072	: V=1.06270102, theta=-18.2809846 -> V=1.073685, theta=0.0
% INFO    : Bus 1073	: V=1.05325884, theta=-21.884738 -> V=1.0000025, theta=0.0
% INFO    : Bus 1074	: V=1.0849323, theta=-18.5696975 -> V=1.045465, theta=0.0
% INFO    : Bus 1075	: V=1.07404211, theta=-7.34212755 -> V=1.07237, theta=0.0
% INFO    : Bus 1076	: V=1.07395572, theta=-7.36795836 -> V=1.07237, theta=0.0
% INFO    : Bus 1077	: V=1.02286396, theta=-34.4317897 -> V=1.022224, theta=0.0
% INFO    : Bus 1078	: V=1.0209612, theta=-9.75656738 -> V=0.999999, theta=0.0
% INFO    : Bus 1079	: V=1.02880158, theta=-15.8257688 -> V=0.999999, theta=0.0
% INFO    : Bus 1080	: V=1.04369057, theta=-13.7610723 -> V=0.999999, theta=0.0
% INFO    : Bus 1081	: V=1.05019989, theta=-9.60578483 -> V=1.0111115, theta=0.0
% INFO    : Bus 1082	: V=1.03285489, theta=-6.08961995 -> V=1.0158755, theta=0.0
% INFO    : Bus 1083	: V=1.03293916, theta=-18.0429903 -> V=1.0158755, theta=0.0
% INFO    : Bus 1084	: V=1.02752761, theta=-8.60510595 -> V=0.999999, theta=0.0
% INFO    : Bus 1085	: V=1.00859108, theta=-22.2386195 -> V=1.0158755, theta=0.0
% INFO    : Bus 1086	: V=1.01757409, theta=-54.5928859 -> V=1.0079355, theta=0.0
% INFO    : Bus 1087	: V=1.05431535, theta=-24.5434509 -> V=1.027779, theta=0.0
% INFO    : Bus 1088	: V=1.07364983, theta=-21.6645488 -> V=1.046665, theta=0.0
% INFO    : Bus 1089	: V=1.02568609, theta=-33.6429201 -> V=1.0000005, theta=0.0
% INFO    : Bus 1090	: V=0.982151079, theta=-30.3009372 -> V=1.0000005, theta=0.0
% INFO    : Bus 1091	: V=1.04644467, theta=-15.1600626 -> V=0.9888895, theta=0.0
% INFO    : Bus 1092	: V=1.04614735, theta=-15.1737558 -> V=0.9888895, theta=0.0
% INFO    : Bus 1093	: V=1.01515535, theta=-13.7985184 -> V=0.999999, theta=0.0
% INFO    : Bus 1094	: V=1.01741452, theta=-18.2484155 -> V=1.0158755, theta=0.0
% INFO    : Bus 1095	: V=1.05587978, theta=-13.1046441 -> V=1.005409, theta=0.0
% INFO    : Bus 1096	: V=1.05942621, theta=-9.89094043 -> V=0.999999, theta=0.0
% INFO    : Bus 1097	: V=1.03564328, theta=-42.0448813 -> V=1.0079355, theta=0.0
% INFO    : Bus 1098	: V=1.0280571, theta=-43.0078666 -> V=1.0079355, theta=0.0
% INFO    : Bus 1099	: V=1.03216206, theta=-42.0689274 -> V=1.0079355, theta=0.0
% INFO    : Bus 1100	: V=1.03556333, theta=-42.0358959 -> V=1.0079355, theta=0.0
% INFO    : Bus 1101	: V=1.02452504, theta=-25.779364 -> V=1.0000005, theta=0.0
% INFO    : Bus 1102	: V=1.02964376, theta=-27.692427 -> V=1.0000025, theta=0.0
% INFO    : Bus 1103	: V=1.02660264, theta=-51.5464787 -> V=1.0079355, theta=0.0
% INFO    : Bus 1104	: V=1.06902943, theta=-3.71613162 -> V=1.072365, theta=0.0
% INFO    : Bus 1105	: V=1.01064211, theta=-11.5272794 -> V=1.015872, theta=0.0
% INFO    : Bus 1106	: V=1.05052934, theta=-26.5673393 -> V=1.022224, theta=0.0
% INFO    : Bus 1107	: V=1.04886234, theta=-32.2887163 -> V=1.0108055, theta=0.0
% INFO    : Bus 1108	: V=1.077, theta=-11.5722167 -> V=0.975, theta=0.0
% INFO    : Bus 1109	: V=1.07751089, theta=-13.320457 -> V=1.000001, theta=0.0
% INFO    : Bus 1110	: V=1.047, theta=-12.443666 -> V=1.002384, theta=0.0
% INFO    : Bus 1111	: V=1.05498843, theta=-24.495271 -> V=1.0000025, theta=0.0
% INFO    : Bus 1112	: V=1.05535556, theta=-18.1861305 -> V=1.044445, theta=0.0
% INFO    : Bus 1113	: V=1.03480769, theta=-20.0315902 -> V=1.0158755, theta=0.0
% INFO    : Bus 1114	: V=1.03712985, theta=-6.67645307 -> V=1.0158755, theta=0.0
% INFO    : Bus 1115	: V=1.04188369, theta=-26.4027398 -> V=1.0000025, theta=0.0
% INFO    : Bus 1116	: V=1.02769223, theta=-27.0983045 -> V=1.0000025, theta=0.0
% INFO    : Bus 1117	: V=1.02553683, theta=-14.7767641 -> V=1.015872, theta=0.0
% INFO    : Bus 1118	: V=1.02519729, theta=-28.5800945 -> V=1.022224, theta=0.0
% INFO    : Bus 1119	: V=1.06723813, theta=-26.6827392 -> V=1.046665, theta=0.0
% INFO    : Bus 1120	: V=1.04377514, theta=-21.5355636 -> V=1.022224, theta=0.0
% INFO    : Bus 1121	: V=1.0391159, theta=-6.90240409 -> V=1.0158755, theta=0.0
% INFO    : Bus 1122	: V=1.04169304, theta=-6.61400771 -> V=1.0158755, theta=0.0
% INFO    : Bus 1123	: V=1.05207587, theta=-9.77585446 -> V=1.003335, theta=0.0
% INFO    : Bus 1124	: V=1.01885188, theta=-11.6835673 -> V=0.999999, theta=0.0
% INFO    : Bus 1125	: V=1.03953414, theta=-25.5623225 -> V=1.0000025, theta=0.0
% INFO    : Bus 1126	: V=1.04254892, theta=-28.1931775 -> V=1.022224, theta=0.0
% INFO    : Bus 1127	: V=1.01765323, theta=-9.95585782 -> V=1.015872, theta=0.0
% INFO    : Bus 1128	: V=1.01189868, theta=-39.3972996 -> V=1.022224, theta=0.0
% INFO    : Bus 1129	: V=1.01769707, theta=0.751033641 -> V=1.0158755, theta=0.0
% INFO    : Bus 1130	: V=1.03203712, theta=-36.0048473 -> V=1.022224, theta=0.0
% INFO    : Bus 1131	: V=1.06260699, theta=-32.2187842 -> V=1.04444, theta=0.0
% INFO    : Bus 1132	: V=1.03185024, theta=-31.9103101 -> V=1.022224, theta=0.0
% INFO    : Bus 1133	: V=1.03404026, theta=-17.2286654 -> V=0.999999, theta=0.0
% INFO    : Bus 1134	: V=1.05492946, theta=-14.033009 -> V=1.0377785, theta=0.0
% INFO    : Bus 1135	: V=1.0242783, theta=-12.8614377 -> V=1.0000025, theta=0.0
% INFO    : Bus 1136	: V=1.02559652, theta=-25.5363539 -> V=1.0000005, theta=0.0
% INFO    : Bus 1137	: V=1.02144194, theta=-25.5360386 -> V=1.0000005, theta=0.0
% INFO    : Bus 1138	: V=1.04161216, theta=-22.4071378 -> V=1.046665, theta=0.0
% INFO    : Bus 1139	: V=1.03367414, theta=-15.1560141 -> V=1.0111115, theta=0.0
% INFO    : Bus 1140	: V=1.01865545, theta=-15.5874356 -> V=1.015872, theta=0.0
% INFO    : Bus 1141	: V=1.04760283, theta=-52.1436052 -> V=1.0079355, theta=0.0
% INFO    : Bus 1142	: V=1.06780775, theta=-47.520392 -> V=1.04444, theta=0.0
% INFO    : Bus 1143	: V=1.04691643, theta=-16.572393 -> V=1.046665, theta=0.0
% INFO    : Bus 1144	: V=1.02279373, theta=-32.5469981 -> V=1.0000025, theta=0.0
% INFO    : Bus 1145	: V=1.04526382, theta=-16.4965182 -> V=0.975, theta=0.0
% INFO    : Bus 1146	: V=1.0515241, theta=-7.95597174 -> V=1.0111115, theta=0.0
% INFO    : Bus 1147	: V=1.03814142, theta=-21.3202342 -> V=1.022224, theta=0.0
% INFO    : Bus 1148	: V=1.03330439, theta=-12.7121339 -> V=1.0158755, theta=0.0
% INFO    : Bus 1149	: V=1.01678652, theta=-37.903875 -> V=1.022224, theta=0.0
% INFO    : Bus 1150	: V=1.02169673, theta=-8.06797669 -> V=1.0158755, theta=0.0
% INFO    : Bus 1151	: V=1.02774368, theta=-9.65781445 -> V=0.999999, theta=0.0
% INFO    : Bus 1152	: V=1.0240372, theta=-9.5260447 -> V=0.999999, theta=0.0
% INFO    : Bus 1153	: V=1.04558338, theta=-6.26445718 -> V=1.0111115, theta=0.0
% INFO    : Bus 1154	: V=1.00989041, theta=-30.5996528 -> V=1.015872, theta=0.0
% INFO    : Bus 1155	: V=1.01151147, theta=-23.3422078 -> V=1.022224, theta=0.0
% INFO    : Bus 1156	: V=1.06827037, theta=-26.4747506 -> V=1.046665, theta=0.0
% INFO    : Bus 1157	: V=1.05340747, theta=-24.0045511 -> V=1.046665, theta=0.0
% INFO    : Bus 1158	: V=1.05345322, theta=-23.9812114 -> V=1.046665, theta=0.0
% INFO    : Bus 1159	: V=1.05799832, theta=-28.2547066 -> V=1.027779, theta=0.0
% INFO    : Bus 1160	: V=1.05859277, theta=-27.3260554 -> V=1.027779, theta=0.0
% INFO    : Bus 1161	: V=1.05852936, theta=-28.2151554 -> V=1.027779, theta=0.0
% INFO    : Bus 1162	: V=1.07429716, theta=-23.8920921 -> V=1.046665, theta=0.0
% INFO    : Bus 1163	: V=1.0233097, theta=-28.2935803 -> V=1.0000005, theta=0.0
% INFO    : Bus 1164	: V=1.02101015, theta=-27.3496758 -> V=1.0000005, theta=0.0
% INFO    : Bus 1165	: V=0.949967688, theta=-6.96346435 -> V=0.9444445, theta=0.0
% INFO    : Bus 1166	: V=1.00599602, theta=-7.01107944 -> V=0.999999, theta=0.0
% INFO    : Bus 1167	: V=1.03274495, theta=-19.4122065 -> V=1.0158755, theta=0.0
% INFO    : Bus 1168	: V=1.04670579, theta=-15.1659872 -> V=0.9888895, theta=0.0
% INFO    : Bus 1169	: V=1.04265666, theta=-34.0904057 -> V=1.022224, theta=0.0
% INFO    : Bus 1170	: V=1.06762748, theta=-29.8355049 -> V=1.04444, theta=0.0
% INFO    : Bus 1171	: V=1.07785317, theta=-34.4129718 -> V=1.04444, theta=0.0
% INFO    : Bus 1172	: V=1.07864187, theta=-34.2322395 -> V=1.04444, theta=0.0
% INFO    : Bus 1173	: V=1.07841779, theta=-34.2301907 -> V=1.04444, theta=0.0
% INFO    : Bus 1174	: V=1.07899958, theta=-31.8595546 -> V=1.07237, theta=0.0
% INFO    : Bus 1175	: V=1.05258989, theta=-24.6137204 -> V=1.0000025, theta=0.0
% INFO    : Bus 1176	: V=1.05620534, theta=-6.00000825 -> V=1.0111115, theta=0.0
% INFO    : Bus 1177	: V=1.03436414, theta=-34.6023517 -> V=1.027779, theta=0.0
% INFO    : Bus 1178	: V=1.0572902, theta=-22.5878311 -> V=1.027779, theta=0.0
% INFO    : Bus 1179	: V=1.04229456, theta=-23.3201897 -> V=1.022224, theta=0.0
% INFO    : Bus 1180	: V=1.03889224, theta=-23.4558053 -> V=1.022224, theta=0.0
% INFO    : Bus 1181	: V=0.998642691, theta=-24.0325224 -> V=1.0158755, theta=0.0
% INFO    : Bus 1182	: V=1.06680161, theta=-26.6737949 -> V=1.046665, theta=0.0
% INFO    : Bus 1183	: V=1.07390047, theta=-25.8485695 -> V=1.04788, theta=0.0
% INFO    : Bus 1184	: V=1.0513767, theta=-19.3111829 -> V=1.022224, theta=0.0
% INFO    : Bus 1185	: V=1.07519823, theta=-28.3008339 -> V=1.04757, theta=0.0
% INFO    : Bus 1186	: V=1.01308287, theta=-10.3422232 -> V=1.0158755, theta=0.0
% INFO    : Bus 1187	: V=1.05729045, theta=-22.5878387 -> V=1.027779, theta=0.0
% INFO    : Bus 1188	: V=1.03439077, theta=-13.6937426 -> V=0.999999, theta=0.0
% INFO    : Bus 1189	: V=1.03874991, theta=-12.0667325 -> V=0.999999, theta=0.0
% INFO    : Bus 1190	: V=1.0263287, theta=-11.1948342 -> V=0.999999, theta=0.0
% INFO    : Bus 1191	: V=1.06711671, theta=-7.46718396 -> V=1.0111115, theta=0.0
% INFO    : Bus 1192	: V=1.06544266, theta=-6.92667814 -> V=1.0111115, theta=0.0
% INFO    : Bus 1193	: V=1.07283294, theta=-6.09399275 -> V=1.072365, theta=0.0
% INFO    : Bus 1194	: V=1.07785822, theta=-34.4130777 -> V=1.04444, theta=0.0
% INFO    : Bus 1195	: V=1.07900836, theta=-31.8596803 -> V=1.07237, theta=0.0
% INFO    : Bus 1196	: V=1.00704901, theta=-14.4314915 -> V=1.0158755, theta=0.0
% INFO    : Bus 1197	: V=1.02363618, theta=-29.3848717 -> V=1.0000005, theta=0.0
% INFO    : Bus 1198	: V=1.05938435, theta=-25.0604666 -> V=1.046665, theta=0.0
% INFO    : Bus 1199	: V=1.04853377, theta=-19.9493503 -> V=1.000001, theta=0.0
% INFO    : Bus 1200	: V=1.03930097, theta=-21.2866804 -> V=1.000001, theta=0.0
% INFO    : Bus 1201	: V=1.05279, theta=-25.3030756 -> V=1.027779, theta=0.0
% INFO    : Bus 1202	: V=1.05840913, theta=-25.1207542 -> V=1.046665, theta=0.0
% INFO    : Bus 1203	: V=1.02117807, theta=-19.1081704 -> V=1.0158755, theta=0.0
% INFO    : Bus 1204	: V=1.05632407, theta=-15.1250895 -> V=1.0377785, theta=0.0
% INFO    : Bus 1205	: V=1.06384878, theta=-13.4712287 -> V=1.033333, theta=0.0
% INFO    : Bus 1206	: V=1.03757944, theta=-25.8451631 -> V=1.015872, theta=0.0
% INFO    : Bus 1207	: V=1.04336134, theta=-21.9330773 -> V=1.046665, theta=0.0
% INFO    : Bus 1208	: V=1.02224458, theta=-29.4049377 -> V=1.022224, theta=0.0
% INFO    : Bus 1209	: V=1.02390119, theta=-32.364074 -> V=1.022224, theta=0.0
% INFO    : Bus 1210	: V=1.095, theta=-11.5827226 -> V=1.047405, theta=0.0
% INFO    : Bus 1211	: V=1.08, theta=-16.783785 -> V=1.044445, theta=0.0
% INFO    : Bus 1212	: V=1.02441331, theta=-20.811763 -> V=1.0000025, theta=0.0
% INFO    : Bus 1213	: V=1.01659707, theta=-10.7753647 -> V=1.015872, theta=0.0
% INFO    : Bus 1214	: V=1.08370321, theta=3.05697421 -> V=1.078945, theta=0.0
% INFO    : Bus 1215	: V=1.02072684, theta=-20.3245424 -> V=0.999999, theta=0.0
% INFO    : Bus 1216	: V=1.06371929, theta=-18.892564 -> V=1.027404, theta=0.0
% INFO    : Bus 1217	: V=1.02774696, theta=-30.8671613 -> V=1.0000005, theta=0.0
% INFO    : Bus 1218	: V=1.03824189, theta=-16.3101217 -> V=0.999999, theta=0.0
% INFO    : Bus 1219	: V=1.05065657, theta=-24.1016124 -> V=1.022224, theta=0.0
% INFO    : Bus 1220	: V=1.04459294, theta=-34.6731478 -> V=1.027779, theta=0.0
% INFO    : Bus 1221	: V=1.05050089, theta=-32.384935 -> V=1.027779, theta=0.0
% INFO    : Bus 1222	: V=1.02892863, theta=-6.92469832 -> V=1.0111115, theta=0.0
% INFO    : Bus 1223	: V=1.03784245, theta=-18.985505 -> V=1.0158755, theta=0.0
% INFO    : Bus 1224	: V=1.01656986, theta=-37.7198469 -> V=1.022224, theta=0.0
% INFO    : Bus 1225	: V=1.06171352, theta=-32.9053895 -> V=1.04444, theta=0.0
% INFO    : Bus 1226	: V=1.0199808, theta=-16.353703 -> V=1.015872, theta=0.0
% INFO    : Bus 1227	: V=1.01121815, theta=-26.7153491 -> V=1.0158755, theta=0.0
% INFO    : Bus 1228	: V=1.0115118, theta=-26.3602527 -> V=1.0158755, theta=0.0
% INFO    : Bus 1229	: V=1.01813781, theta=-2.33654469 -> V=1.0158755, theta=0.0
% INFO    : Bus 1230	: V=1.03459565, theta=-21.4020444 -> V=1.000001, theta=0.0
% INFO    : Bus 1231	: V=1.0612416, theta=-29.6290217 -> V=0.975, theta=0.0
% INFO    : Bus 1232	: V=1.0612416, theta=-29.6290217 -> V=1.023604, theta=0.0
% INFO    : Bus 1233	: V=1.02604192, theta=-7.54764721 -> V=0.999999, theta=0.0
% INFO    : Bus 1234	: V=1.020383, theta=-6.50149033 -> V=0.999999, theta=0.0
% INFO    : Bus 1235	: V=1.05459224, theta=-7.57869368 -> V=1.0111115, theta=0.0
% INFO    : Bus 1236	: V=1.05634893, theta=-6.70454023 -> V=1.0111115, theta=0.0
% INFO    : Bus 1237	: V=1.05663218, theta=-6.76691807 -> V=1.0111115, theta=0.0
% INFO    : Bus 1238	: V=1.0683968, theta=-2.54677187 -> V=1.072365, theta=0.0
% INFO    : Bus 1239	: V=1.03277249, theta=-12.588462 -> V=1.0158755, theta=0.0
% INFO    : Bus 1240	: V=1.0616204, theta=-7.73420627 -> V=1.0377785, theta=0.0
% INFO    : Bus 1241	: V=1.04012361, theta=-20.3487732 -> V=0.999999, theta=0.0
% INFO    : Bus 1242	: V=1.0440847, theta=-18.2287528 -> V=1.0158755, theta=0.0
% INFO    : Bus 1243	: V=1.04725049, theta=-15.0579064 -> V=1.0377785, theta=0.0
% INFO    : Bus 1244	: V=1.0241687, theta=-18.5998159 -> V=1.0158755, theta=0.0
% INFO    : Bus 1245	: V=0.993275057, theta=-17.6869733 -> V=1.0, theta=0.0
% INFO    : Bus 1246	: V=0.583554543, theta=-19.4147251 -> V=0.825, theta=0.0
% INFO    : Bus 1247	: V=1.033077, theta=-19.3056707 -> V=1.0158755, theta=0.0
% INFO    : Bus 1248	: V=1.06079126, theta=-10.3815881 -> V=1.002789, theta=0.0
% INFO    : Bus 1249	: V=1.02093322, theta=-40.397987 -> V=1.022224, theta=0.0
% INFO    : Bus 1250	: V=1.01569001, theta=-10.194459 -> V=0.999999, theta=0.0
% INFO    : Bus 1251	: V=1.00255902, theta=-11.6049272 -> V=0.999999, theta=0.0
% INFO    : Bus 1252	: V=1.04716522, theta=-15.8271937 -> V=0.999999, theta=0.0
% INFO    : Bus 1253	: V=1.06606121, theta=-17.402048 -> V=1.016666, theta=0.0
% INFO    : Bus 1254	: V=1.05415933, theta=-13.9640324 -> V=1.0111115, theta=0.0
% INFO    : Bus 1255	: V=1.02821232, theta=-16.3994338 -> V=1.0158755, theta=0.0
% INFO    : Bus 1256	: V=1.03597521, theta=-51.2610128 -> V=1.0079355, theta=0.0
% INFO    : Bus 1257	: V=1.00521762, theta=-11.7586303 -> V=1.015872, theta=0.0
% INFO    : Bus 1258	: V=1.03585139, theta=-12.6817186 -> V=1.0158755, theta=0.0
% INFO    : Bus 1259	: V=1.03361069, theta=-13.0188075 -> V=1.0158755, theta=0.0
% INFO    : Bus 1260	: V=1.04307897, theta=-9.36648514 -> V=1.0377785, theta=0.0
% INFO    : Bus 1261	: V=1.07267295, theta=-8.67901239 -> V=1.072365, theta=0.0
% INFO    : Bus 1262	: V=1.03712545, theta=-18.7770167 -> V=0.999999, theta=0.0
% INFO    : Bus 1263	: V=1.00064918, theta=-14.1262538 -> V=1.015872, theta=0.0
% INFO    : Bus 1264	: V=1.06570651, theta=-26.8290221 -> V=1.046665, theta=0.0
% INFO    : Bus 1265	: V=1.07455541, theta=-25.8293668 -> V=1.048205, theta=0.0
% INFO    : Bus 1266	: V=1.03886047, theta=-31.6334222 -> V=1.027779, theta=0.0
% INFO    : Bus 1267	: V=1.01792777, theta=-21.7160875 -> V=1.0158755, theta=0.0
% INFO    : Bus 1268	: V=1.03010819, theta=3.00983129 -> V=1.0158755, theta=0.0
% INFO    : Bus 1269	: V=1.02185247, theta=-32.2563555 -> V=1.0000005, theta=0.0
% INFO    : Bus 1270	: V=1.07597773, theta=-2.90385746 -> V=1.072365, theta=0.0
% INFO    : Bus 1271	: V=1.07640049, theta=-2.86317167 -> V=1.072365, theta=0.0
% INFO    : Bus 1272	: V=1.02278501, theta=-16.9964023 -> V=1.0000025, theta=0.0
% INFO    : Bus 1273	: V=1.0470917, theta=-26.2851121 -> V=1.046665, theta=0.0
% INFO    : Bus 1274	: V=1.06392151, theta=-24.8918467 -> V=1.046665, theta=0.0
% INFO    : Bus 1275	: V=1.03918099, theta=-19.8215686 -> V=1.0158755, theta=0.0
% INFO    : Bus 1276	: V=1.03886262, theta=-25.5827326 -> V=1.027779, theta=0.0
% INFO    : Bus 1277	: V=1.0439873, theta=-22.7471002 -> V=1.033333, theta=0.0
% INFO    : Bus 1278	: V=1.05837792, theta=-5.59405654 -> V=1.046665, theta=0.0
% INFO    : Bus 1279	: V=1.05767417, theta=-28.6318843 -> V=1.027779, theta=0.0
% INFO    : Bus 1280	: V=1.06066252, theta=-19.8106058 -> V=1.0111115, theta=0.0
% INFO    : Bus 1281	: V=1.05308922, theta=-14.6637534 -> V=0.9888895, theta=0.0
% INFO    : Bus 1282	: V=1.05043657, theta=-7.71106168 -> V=1.0111115, theta=0.0
% INFO    : Bus 1283	: V=1.01884565, theta=-6.29283388 -> V=1.0158755, theta=0.0
% INFO    : Bus 1284	: V=1.0289965, theta=-39.7889937 -> V=1.022224, theta=0.0
% INFO    : Bus 1285	: V=1.02025772, theta=-28.2972087 -> V=1.0000005, theta=0.0
% INFO    : Bus 1286	: V=1.065, theta=-20.0124601 -> V=1.0000025, theta=0.0
% INFO    : Bus 1287	: V=1.05556815, theta=-18.633605 -> V=1.0000025, theta=0.0
% INFO    : Bus 1288	: V=1.08345263, theta=-15.3480707 -> V=1.044445, theta=0.0
% INFO    : Bus 1289	: V=1.03311791, theta=-23.6251708 -> V=1.0000025, theta=0.0
% INFO    : Bus 1290	: V=1.0189321, theta=-55.9292828 -> V=1.0079355, theta=0.0
% INFO    : Bus 1291	: V=1.0409215, theta=-6.19692011 -> V=1.046665, theta=0.0
% INFO    : Bus 1292	: V=1.08444254, theta=3.27982527 -> V=1.078945, theta=0.0
% INFO    : Bus 1293	: V=1.0844928, theta=3.29491435 -> V=1.078945, theta=0.0
% INFO    : Bus 1294	: V=1.08451804, theta=3.3008115 -> V=1.078945, theta=0.0
% INFO    : Bus 1295	: V=1.0843061, theta=3.28026712 -> V=1.078945, theta=0.0
% INFO    : Bus 1296	: V=1.03659927, theta=-34.5849085 -> V=1.022224, theta=0.0
% INFO    : Bus 1297	: V=1.03352206, theta=-43.3290764 -> V=1.022224, theta=0.0
% INFO    : Bus 1298	: V=1.00004191, theta=-20.9457529 -> V=0.999999, theta=0.0
% INFO    : Bus 1299	: V=1.01986232, theta=-17.9393658 -> V=1.0158755, theta=0.0
% INFO    : Bus 1300	: V=1.01981795, theta=-17.9518612 -> V=1.0158755, theta=0.0
% INFO    : Bus 1301	: V=1.06679494, theta=-7.34825837 -> V=1.0111115, theta=0.0
% INFO    : Bus 1302	: V=1.01734219, theta=-12.498137 -> V=0.999999, theta=0.0
% INFO    : Bus 1303	: V=1.0422278, theta=-25.6271654 -> V=0.975, theta=0.0
% INFO    : Bus 1304	: V=1.06311619, theta=-27.2538695 -> V=0.975, theta=0.0
% INFO    : Bus 1305	: V=1.0422278, theta=-25.6271654 -> V=1.0000025, theta=0.0
% INFO    : Bus 1306	: V=1.03324537, theta=-27.7308688 -> V=1.0000025, theta=0.0
% INFO    : Bus 1307	: V=1.05785255, theta=-21.5252803 -> V=1.0233335, theta=0.0
% INFO    : Bus 1308	: V=1.02067699, theta=-21.1316549 -> V=1.0000025, theta=0.0
% INFO    : Bus 1309	: V=1.02433211, theta=-26.5707136 -> V=1.0000025, theta=0.0
% INFO    : Bus 1310	: V=1.05763196, theta=-19.0650259 -> V=1.0000025, theta=0.0
% INFO    : Bus 1311	: V=1.01037847, theta=-25.5200645 -> V=1.0000025, theta=0.0
% INFO    : Bus 1312	: V=1.01023332, theta=-25.5466744 -> V=1.0000025, theta=0.0
% INFO    : Bus 1313	: V=1.04109852, theta=-21.4985665 -> V=1.0000025, theta=0.0
% INFO    : Bus 1314	: V=1.04109852, theta=-21.4985665 -> V=1.0000025, theta=0.0
% INFO    : Bus 1315	: V=1.03937417, theta=-38.5567797 -> V=1.022224, theta=0.0
% INFO    : Bus 1316	: V=1.02284655, theta=-30.9201105 -> V=1.022224, theta=0.0
% INFO    : Bus 1317	: V=0.952986718, theta=-7.6911964 -> V=0.9444445, theta=0.0
% INFO    : Bus 1318	: V=0.95305881, theta=-7.68588672 -> V=0.9444445, theta=0.0
% INFO    : Bus 1319	: V=1.0137213, theta=-11.7126807 -> V=1.015872, theta=0.0
% INFO    : Bus 1320	: V=1.03216053, theta=-15.1569033 -> V=1.015872, theta=0.0
% INFO    : Bus 1321	: V=1.03981639, theta=-11.9222673 -> V=1.046665, theta=0.0
% INFO    : Bus 1322	: V=1.05769458, theta=-29.6190456 -> V=1.0000025, theta=0.0
% INFO    : Bus 1323	: V=0.978674388, theta=-4.94957903 -> V=0.9444445, theta=0.0
% INFO    : Bus 1324	: V=1.03383616, theta=-26.0094294 -> V=1.022224, theta=0.0
% INFO    : Bus 1325	: V=1.064, theta=-20.5055876 -> V=1.000001, theta=0.0
% INFO    : Bus 1326	: V=1.03831657, theta=-44.3929717 -> V=1.0079355, theta=0.0
% INFO    : Bus 1327	: V=1.03762722, theta=-20.7845352 -> V=1.0000025, theta=0.0
% INFO    : Bus 1328	: V=1.07897273, theta=-16.4681966 -> V=1.044445, theta=0.0
% INFO    : Bus 1329	: V=1.08760801, theta=-10.9797916 -> V=1.078945, theta=0.0
% INFO    : Bus 1330	: V=0.978174389, theta=-9.78543705 -> V=0.9444445, theta=0.0
% INFO    : Bus 1331	: V=1.03196457, theta=-9.3951366 -> V=0.999999, theta=0.0
% INFO    : Bus 1332	: V=1.01051161, theta=-17.777911 -> V=1.0158755, theta=0.0
% INFO    : Bus 1333	: V=1.04585714, theta=-9.52785027 -> V=0.999999, theta=0.0
% INFO    : Bus 1334	: V=1.0392907, theta=-10.5874252 -> V=0.9888895, theta=0.0
% INFO    : Bus 1335	: V=1.05756257, theta=-9.44197037 -> V=1.046665, theta=0.0
% INFO    : Bus 1336	: V=1.02088502, theta=-10.9315251 -> V=0.999999, theta=0.0
% INFO    : Bus 1337	: V=1.0523096, theta=-12.7667603 -> V=1.0377785, theta=0.0
% INFO    : Bus 1338	: V=1.02490809, theta=-0.795061386 -> V=1.0158755, theta=0.0
% INFO    : Bus 1339	: V=1.08314795, theta=4.42946497 -> V=1.0391935, theta=0.0
% INFO    : Bus 1340	: V=1.02910451, theta=-11.7698409 -> V=0.999999, theta=0.0
% INFO    : Bus 1341	: V=1.05496227, theta=-9.19962054 -> V=1.0111115, theta=0.0
% INFO    : Bus 1342	: V=1.03793699, theta=1.13359512 -> V=1.0158755, theta=0.0
% INFO    : Bus 1343	: V=1.01009115, theta=-22.006377 -> V=1.0000005, theta=0.0
% INFO    : Bus 1344	: V=1.0, theta=-21.5358814 -> V=0.975, theta=0.0
% INFO    : Bus 1345	: V=1.05789007, theta=-21.525934 -> V=1.0233335, theta=0.0
% INFO    : Bus 1346	: V=1.04115588, theta=-16.2085113 -> V=0.999999, theta=0.0
% INFO    : Bus 1347	: V=1.04430608, theta=-30.5753091 -> V=1.022224, theta=0.0
% INFO    : Bus 1348	: V=1.04424139, theta=-30.5792117 -> V=1.022224, theta=0.0
% INFO    : Bus 1349	: V=1.03304452, theta=-20.2630117 -> V=1.022224, theta=0.0
% INFO    : Bus 1350	: V=1.02566876, theta=-12.7217213 -> V=1.0158755, theta=0.0
% INFO    : Bus 1351	: V=1.0505145, theta=-23.3409927 -> V=1.022224, theta=0.0
% INFO    : Bus 1352	: V=1.05176272, theta=-26.9309797 -> V=1.022224, theta=0.0
% INFO    : Bus 1353	: V=1.0541039, theta=-22.4744955 -> V=1.04444, theta=0.0
% INFO    : Bus 1354	: V=1.04891751, theta=-9.77357668 -> V=1.0000025, theta=0.0
% INFO    : Bus 1355	: V=1.04509288, theta=-8.04710209 -> V=0.9977785, theta=0.0
% INFO    : Bus 1356	: V=1.053, theta=-7.96541971 -> V=0.999999, theta=0.0
% INFO    : Bus 1357	: V=1.051, theta=-7.92639185 -> V=0.999999, theta=0.0
% INFO    : Bus 1358	: V=1.04519876, theta=-2.70187949 -> V=1.000001, theta=0.0
% INFO    : Bus 1359	: V=1.0404369, theta=-23.5279208 -> V=1.022224, theta=0.0
% INFO    : Bus 1360	: V=1.05225614, theta=-14.6142368 -> V=1.033334, theta=0.0
% INFO    : Bus 1361	: V=1.05227454, theta=-14.6142127 -> V=1.033334, theta=0.0
% INFO    : Bus 1362	: V=1.04850509, theta=-29.7991183 -> V=1.022224, theta=0.0
% INFO    : Bus 1363	: V=1.038, theta=-31.7120843 -> V=1.015872, theta=0.0
% INFO    : Bus 1364	: V=0.98375551, theta=-30.0074825 -> V=1.0000005, theta=0.0
% INFO    : Bus 1365	: V=0.98956679, theta=-30.3148454 -> V=1.0000005, theta=0.0
% INFO    : Bus 1366	: V=0.987161154, theta=-30.5298886 -> V=1.0000005, theta=0.0
% INFO    : Bus 1367	: V=1.07348492, theta=-28.6118887 -> V=1.046725, theta=0.0
% INFO    : Bus 1368	: V=1.00520632, theta=-11.7506252 -> V=1.015872, theta=0.0
% INFO    : Bus 1369	: V=1.00684138, theta=-25.9708534 -> V=1.022224, theta=0.0
% INFO    : Bus 1370	: V=1.04682141, theta=-23.7361626 -> V=1.022224, theta=0.0
% INFO    : Bus 1371	: V=1.04756851, theta=-23.3064501 -> V=1.027779, theta=0.0
% INFO    : Bus 1372	: V=1.04849867, theta=-26.0434407 -> V=1.046665, theta=0.0
% INFO    : Bus 1373	: V=1.01770854, theta=-26.7344647 -> V=1.0079355, theta=0.0
% INFO    : Bus 1374	: V=1.03136784, theta=-21.4911954 -> V=0.999999, theta=0.0
% INFO    : Bus 1375	: V=1.0550081, theta=-19.2450403 -> V=1.016666, theta=0.0
% INFO    : Bus 1376	: V=1.04471679, theta=-15.3751343 -> V=1.004445, theta=0.0
% INFO    : Bus 1377	: V=1.02465312, theta=-26.1123284 -> V=1.0158755, theta=0.0
% INFO    : Bus 1378	: V=1.00540212, theta=-11.7567223 -> V=1.015872, theta=0.0
% INFO    : Bus 1379	: V=1.04237988, theta=-28.1895163 -> V=1.022224, theta=0.0
% INFO    : Bus 1380	: V=1.02004592, theta=-16.3548735 -> V=1.015872, theta=0.0
% INFO    : Bus 1381	: V=1.03969127, theta=-25.0881547 -> V=1.0047205, theta=0.0
% INFO    : Bus 1382	: V=1.04200596, theta=-20.0001053 -> V=1.046665, theta=0.0
% INFO    : Bus 1383	: V=1.05430089, theta=-24.3641461 -> V=1.046665, theta=0.0
% INFO    : Bus 1384	: V=1.04457707, theta=-27.6647522 -> V=1.022224, theta=0.0
% INFO    : Bus 1385	: V=1.03876659, theta=-28.3038641 -> V=1.022224, theta=0.0
% INFO    : Bus 1386	: V=1.0373296, theta=-16.4813964 -> V=0.999999, theta=0.0
% INFO    : Bus 1387	: V=1.00228153, theta=-15.6885087 -> V=0.999999, theta=0.0
% INFO    : Bus 1388	: V=1.01455612, theta=-11.053366 -> V=1.015872, theta=0.0
% INFO    : Bus 1389	: V=1.00970534, theta=-33.802296 -> V=1.0000005, theta=0.0
% INFO    : Bus 1390	: V=1.03944708, theta=-10.6770099 -> V=0.999999, theta=0.0
% INFO    : Bus 1391	: V=1.05027605, theta=-26.4587419 -> V=1.022224, theta=0.0
% INFO    : Bus 1392	: V=1.01019073, theta=-27.9804112 -> V=1.0000005, theta=0.0
% INFO    : Bus 1393	: V=1.06164455, theta=-23.8008271 -> V=1.046665, theta=0.0
% INFO    : Bus 1394	: V=1.05769668, theta=-21.1168881 -> V=1.000001, theta=0.0
% INFO    : Bus 1395	: V=1.03538879, theta=-7.12175479 -> V=1.0158755, theta=0.0
% INFO    : Bus 1396	: V=1.0131913, theta=-14.9350043 -> V=1.015872, theta=0.0
% INFO    : Bus 1397	: V=1.00899071, theta=-18.8243428 -> V=0.999999, theta=0.0
% INFO    : Bus 1398	: V=1.02622304, theta=-20.9195133 -> V=1.0158755, theta=0.0
% INFO    : Bus 1399	: V=1.0441396, theta=-15.0269505 -> V=0.999999, theta=0.0
% INFO    : Bus 1400	: V=1.04414413, theta=-15.0271008 -> V=0.999999, theta=0.0
% INFO    : Bus 1401	: V=1.02920968, theta=-12.6562861 -> V=1.0158755, theta=0.0
% INFO    : Bus 1402	: V=1.03835624, theta=-13.8643104 -> V=0.999999, theta=0.0
% INFO    : Bus 1403	: V=1.05412787, theta=-8.82284754 -> V=1.0111115, theta=0.0
% INFO    : Bus 1404	: V=1.07152123, theta=-30.2080011 -> V=0.975, theta=0.0
% INFO    : Bus 1405	: V=1.0456193, theta=-33.5711883 -> V=1.022224, theta=0.0
% INFO    : Bus 1406	: V=1.07157163, theta=-30.1893155 -> V=1.04444, theta=0.0
% INFO    : Bus 1407	: V=1.00554425, theta=-22.4979498 -> V=1.0158755, theta=0.0
% INFO    : Bus 1408	: V=1.0274902, theta=-16.7077482 -> V=1.015872, theta=0.0
% INFO    : Bus 1409	: V=1.02521708, theta=-16.0604645 -> V=1.015872, theta=0.0
% INFO    : Bus 1410	: V=1.01095806, theta=-22.5620139 -> V=1.015872, theta=0.0
% INFO    : Bus 1411	: V=1.04304022, theta=-13.9657583 -> V=0.999999, theta=0.0
% INFO    : Bus 1412	: V=1.02042695, theta=-46.3408663 -> V=1.0079355, theta=0.0
% INFO    : Bus 1413	: V=0.999430006, theta=-40.5141239 -> V=1.022224, theta=0.0
% INFO    : Bus 1414	: V=1.05966791, theta=-18.7266338 -> V=1.0000025, theta=0.0
% INFO    : Bus 1415	: V=0.995122504, theta=-39.8727325 -> V=1.022224, theta=0.0
% INFO    : Bus 1416	: V=1.02944117, theta=-28.9746935 -> V=1.022224, theta=0.0
% INFO    : Bus 1417	: V=1.05388125, theta=-23.7978686 -> V=1.027779, theta=0.0
% INFO    : Bus 1418	: V=1.01216079, theta=-13.2050721 -> V=1.0158755, theta=0.0
% INFO    : Bus 1419	: V=1.02052577, theta=-12.7089366 -> V=1.0158755, theta=0.0
% INFO    : Bus 1420	: V=1.04, theta=-19.4885032 -> V=1.000001, theta=0.0
% INFO    : Bus 1421	: V=1.07414487, theta=-25.9130615 -> V=1.048005, theta=0.0
% INFO    : Bus 1422	: V=0.987900299, theta=-25.1139105 -> V=1.0158755, theta=0.0
% INFO    : Bus 1423	: V=1.04841029, theta=-29.3424881 -> V=1.027779, theta=0.0
% INFO    : Bus 1424	: V=1.02467102, theta=-32.5578949 -> V=1.022224, theta=0.0
% INFO    : Bus 1425	: V=1.02669259, theta=-15.6091477 -> V=1.0158755, theta=0.0
% INFO    : Bus 1426	: V=1.03173873, theta=-25.7620962 -> V=1.022224, theta=0.0
% INFO    : Bus 1427	: V=1.0788136, theta=5.48239961 -> V=1.0377785, theta=0.0
% INFO    : Bus 1428	: V=1.04399399, theta=-27.5192781 -> V=1.046665, theta=0.0
% INFO    : Bus 1429	: V=1.02783717, theta=3.48124365 -> V=1.0158755, theta=0.0
% INFO    : Bus 1430	: V=1.07876732, theta=5.46311772 -> V=1.0377785, theta=0.0
% INFO    : Bus 1431	: V=1.04746103, theta=-20.1781432 -> V=0.999999, theta=0.0
% INFO    : Bus 1432	: V=1.06784385, theta=-37.4854859 -> V=1.029599, theta=0.0
% INFO    : Bus 1433	: V=1.01213641, theta=-22.4285764 -> V=1.015872, theta=0.0
% INFO    : Bus 1434	: V=1.01208806, theta=-14.4130441 -> V=1.015872, theta=0.0
% INFO    : Bus 1435	: V=1.05045028, theta=-29.3414074 -> V=1.027779, theta=0.0
% INFO    : Bus 1436	: V=1.04544188, theta=-19.8239067 -> V=1.0158755, theta=0.0
% INFO    : Bus 1437	: V=1.05734151, theta=-14.7626286 -> V=1.0377785, theta=0.0
% INFO    : Bus 1438	: V=1.02166866, theta=-29.9974936 -> V=1.022224, theta=0.0
% INFO    : Bus 1439	: V=1.01691284, theta=-11.0885142 -> V=1.015872, theta=0.0
% INFO    : Bus 1440	: V=1.01505629, theta=-11.614534 -> V=1.015872, theta=0.0
% INFO    : Bus 1441	: V=1.05078213, theta=-5.91007361 -> V=1.046665, theta=0.0
% INFO    : Bus 1442	: V=1.0130974, theta=-30.087029 -> V=1.0000005, theta=0.0
% INFO    : Bus 1443	: V=1.04675154, theta=-23.7346547 -> V=1.022224, theta=0.0
% INFO    : Bus 1444	: V=1.01340062, theta=-30.0716459 -> V=1.0000005, theta=0.0
% INFO    : Bus 1445	: V=1.01914138, theta=-13.2650591 -> V=0.999999, theta=0.0
% INFO    : Bus 1446	: V=1.05113109, theta=-6.99877819 -> V=1.0111115, theta=0.0
% INFO    : Bus 1447	: V=1.01871251, theta=-21.6707451 -> V=1.0158755, theta=0.0
% INFO    : Bus 1448	: V=1.02638898, theta=2.040817 -> V=1.0158755, theta=0.0
% INFO    : Bus 1449	: V=1.02638898, theta=2.040817 -> V=1.0158755, theta=0.0
% INFO    : Bus 1450	: V=1.03787146, theta=-19.7933868 -> V=1.0158755, theta=0.0
% INFO    : Bus 1451	: V=1.02917846, theta=-14.3888107 -> V=1.0158755, theta=0.0
% INFO    : Bus 1452	: V=1.05790266, theta=-12.0958585 -> V=1.0377785, theta=0.0
% INFO    : Bus 1453	: V=1.02220778, theta=-16.9576493 -> V=1.0000025, theta=0.0
% INFO    : Bus 1454	: V=0.58977506, theta=-17.8252007 -> V=0.825, theta=0.0
% INFO    : Bus 1455	: V=1.05326407, theta=-17.7531311 -> V=1.0158755, theta=0.0
% INFO    : Bus 1456	: V=0.998297957, theta=-3.13815595 -> V=1.0158755, theta=0.0
% INFO    : Bus 1457	: V=1.029148, theta=-23.366184 -> V=1.022224, theta=0.0
% INFO    : Bus 1458	: V=1.06773954, theta=-19.2681746 -> V=1.04444, theta=0.0
% INFO    : Bus 1459	: V=1.07522849, theta=-15.1892785 -> V=1.07237, theta=0.0
% INFO    : Bus 1460	: V=1.04399148, theta=-15.5139776 -> V=1.000001, theta=0.0
% INFO    : Bus 1461	: V=1.03767827, theta=-14.7937938 -> V=1.016666, theta=0.0
% INFO    : Bus 1462	: V=1.02193501, theta=-12.9557021 -> V=0.9977785, theta=0.0
% INFO    : Bus 1463	: V=1.03236618, theta=-10.6862591 -> V=1.0158755, theta=0.0
% INFO    : Bus 1464	: V=1.02672044, theta=-33.5004604 -> V=1.027779, theta=0.0
% INFO    : Bus 1465	: V=1.03772031, theta=-12.7974222 -> V=1.0158755, theta=0.0
% INFO    : Bus 1466	: V=0.982169513, theta=-30.2919742 -> V=1.0000005, theta=0.0
% INFO    : Bus 1467	: V=1.02568893, theta=-33.642936 -> V=1.0000005, theta=0.0
% INFO    : Bus 1468	: V=1.04771777, theta=-25.9943543 -> V=1.0000025, theta=0.0
% INFO    : Bus 1469	: V=1.06015127, theta=-21.8044759 -> V=1.044445, theta=0.0
% INFO    : Bus 1470	: V=1.07530852, theta=-21.2143965 -> V=1.046665, theta=0.0
% INFO    : Bus 1471	: V=1.01045207, theta=-10.6551521 -> V=0.999999, theta=0.0
% INFO    : Bus 1472	: V=1.02328917, theta=-9.11777534 -> V=1.0158755, theta=0.0
% INFO    : Bus 1473	: V=1.03329084, theta=-24.6025565 -> V=1.027779, theta=0.0
% INFO    : Bus 1474	: V=1.03052522, theta=-14.8006329 -> V=1.015872, theta=0.0
% INFO    : Bus 1475	: V=1.05252465, theta=-13.9826056 -> V=1.046665, theta=0.0
% INFO    : Bus 1476	: V=1.04573663, theta=-25.084455 -> V=1.0000025, theta=0.0
% INFO    : Bus 1477	: V=1.08055995, theta=-23.9550548 -> V=1.0243705, theta=0.0
% INFO    : Bus 1478	: V=1.04437553, theta=-24.3384198 -> V=1.0000025, theta=0.0
% INFO    : Bus 1479	: V=1.12166494, theta=4.48013618 -> V=1.0403055, theta=0.0
% INFO    : Bus 1480	: V=1.01465949, theta=-15.8595007 -> V=1.0000015, theta=0.0
% INFO    : Bus 1481	: V=1.06897049, theta=-12.2914178 -> V=1.0266685, theta=0.0
% INFO    : Bus 1482	: V=1.04680032, theta=-15.1042288 -> V=0.9888895, theta=0.0
% INFO    : Bus 1483	: V=1.05412018, theta=-7.41984845 -> V=1.0111115, theta=0.0
% INFO    : Bus 1484	: V=1.05591831, theta=-24.9323266 -> V=1.0000025, theta=0.0
% INFO    : Bus 1485	: V=1.06597052, theta=-14.6353638 -> V=1.016666, theta=0.0
% INFO    : Bus 1486	: V=1.03605405, theta=-11.7101245 -> V=1.0158755, theta=0.0
% INFO    : Bus 1487	: V=1.0525587, theta=-18.0246781 -> V=1.0000025, theta=0.0
% INFO    : Bus 1488	: V=1.0134258, theta=-30.1592652 -> V=1.0000005, theta=0.0
% INFO    : Bus 1489	: V=1.07667921, theta=-9.34555041 -> V=0.9897095, theta=0.0
% INFO    : Bus 1490	: V=1.06248487, theta=-20.5994157 -> V=1.024204, theta=0.0
% INFO    : Bus 1491	: V=1.04914061, theta=-15.3266 -> V=0.9888895, theta=0.0
% INFO    : Bus 1492	: V=1.06468503, theta=-11.2747847 -> V=1.072365, theta=0.0
% INFO    : Bus 1493	: V=1.05532757, theta=-23.1985812 -> V=1.000001, theta=0.0
% INFO    : Bus 1494	: V=1.04254612, theta=-4.21292853 -> V=0.975, theta=0.0
% INFO    : Bus 1495	: V=1.04121906, theta=-38.1770596 -> V=1.022224, theta=0.0
% INFO    : Bus 1496	: V=1.02177085, theta=-28.7755396 -> V=1.022224, theta=0.0
% INFO    : Bus 1497	: V=1.04701486, theta=-20.9298813 -> V=1.0111115, theta=0.0
% INFO    : Bus 1498	: V=1.04315752, theta=-6.37177501 -> V=1.0158755, theta=0.0
% INFO    : Bus 1499	: V=1.0570626, theta=-1.31800682 -> V=1.0377785, theta=0.0
% INFO    : Bus 1500	: V=1.01730548, theta=4.64743145 -> V=1.013331, theta=0.0
% INFO    : Bus 1501	: V=1.06519437, theta=-22.6046413 -> V=1.027779, theta=0.0
% INFO    : Bus 1502	: V=1.06971932, theta=-23.0322044 -> V=1.029129, theta=0.0
% INFO    : Bus 1503	: V=1.03326715, theta=-18.5681644 -> V=1.027779, theta=0.0
% INFO    : Bus 1504	: V=0.975093539, theta=-19.0987107 -> V=1.015872, theta=0.0
% INFO    : Bus 1505	: V=1.03655257, theta=-24.0859444 -> V=1.0000025, theta=0.0
% INFO    : Bus 1506	: V=1.01769824, theta=0.792175112 -> V=1.0158755, theta=0.0
% INFO    : Bus 1507	: V=0.981406288, theta=-16.0812115 -> V=1.015872, theta=0.0
% INFO    : Bus 1508	: V=1.02631262, theta=-15.6704275 -> V=1.015872, theta=0.0
% INFO    : Bus 1509	: V=1.03569758, theta=-20.126483 -> V=1.0158755, theta=0.0
% INFO    : Bus 1510	: V=1.02536834, theta=-46.33577 -> V=1.0079355, theta=0.0
% INFO    : Bus 1511	: V=1.03958125, theta=-43.3537489 -> V=1.0079355, theta=0.0
% INFO    : Bus 1512	: V=1.07296739, theta=-45.8508099 -> V=1.04444, theta=0.0
% INFO    : Bus 1513	: V=1.0384589, theta=-28.4759858 -> V=1.022224, theta=0.0
% INFO    : Bus 1514	: V=1.07363299, theta=-25.6732702 -> V=1.04444, theta=0.0
% INFO    : Bus 1515	: V=1.08137191, theta=-21.0534081 -> V=1.07237, theta=0.0
% INFO    : Bus 1516	: V=1.05019773, theta=-29.2454606 -> V=1.027779, theta=0.0
% INFO    : Bus 1517	: V=1.123, theta=-2.38181396 -> V=0.975, theta=0.0
% INFO    : Bus 1518	: V=0.97, theta=-0.695325778 -> V=0.975, theta=0.0
% INFO    : Bus 1519	: V=1.0687567, theta=-10.5785133 -> V=1.0222245, theta=0.0
% INFO    : Bus 1520	: V=1.08041782, theta=-7.31874677 -> V=1.0222245, theta=0.0
% INFO    : Bus 1521	: V=1.01328801, theta=-44.8341691 -> V=1.0079355, theta=0.0
% INFO    : Bus 1522	: V=1.06447239, theta=-41.6189096 -> V=1.04444, theta=0.0
% INFO    : Bus 1523	: V=1.03638822, theta=-6.27805498 -> V=1.0158755, theta=0.0
% INFO    : Bus 1524	: V=1.01798757, theta=-46.7510398 -> V=1.0079355, theta=0.0
% INFO    : Bus 1525	: V=1.02595409, theta=-2.84061157 -> V=1.0158755, theta=0.0
% INFO    : Bus 1526	: V=1.02909088, theta=-12.2198746 -> V=0.999999, theta=0.0
% INFO    : Bus 1527	: V=1.06500098, theta=-37.0858152 -> V=1.028159, theta=0.0
% INFO    : Bus 1528	: V=1.04526318, theta=-36.445556 -> V=1.022224, theta=0.0
% INFO    : Bus 1529	: V=1.04045939, theta=-39.4498604 -> V=1.022224, theta=0.0
% INFO    : Bus 1530	: V=1.08268822, theta=-34.6270541 -> V=1.047485, theta=0.0
% INFO    : Bus 1531	: V=1.08174536, theta=-30.0945214 -> V=1.07237, theta=0.0
% INFO    : Bus 1532	: V=1.0279334, theta=-18.9080649 -> V=0.999999, theta=0.0
% INFO    : Bus 1533	: V=1.04733681, theta=-4.46969211 -> V=1.000001, theta=0.0
% INFO    : Bus 1534	: V=1.03471285, theta=-39.1252297 -> V=1.0079355, theta=0.0
% INFO    : Bus 1535	: V=1.02538411, theta=-19.5783569 -> V=0.999999, theta=0.0
% INFO    : Bus 1536	: V=1.07384363, theta=-14.9836435 -> V=1.044445, theta=0.0
% INFO    : Bus 1537	: V=1.08864367, theta=-8.91542645 -> V=1.078945, theta=0.0
% INFO    : Bus 1538	: V=1.04574094, theta=-20.2593946 -> V=1.000001, theta=0.0
% INFO    : Bus 1539	: V=1.06634259, theta=-16.5395724 -> V=1.044445, theta=0.0
% INFO    : Bus 1540	: V=1.04345581, theta=-21.563396 -> V=1.022224, theta=0.0
% INFO    : Bus 1541	: V=1.04169565, theta=-25.9421891 -> V=0.999999, theta=0.0
% INFO    : Bus 1542	: V=1.02360704, theta=-17.0623105 -> V=1.0000025, theta=0.0
% INFO    : Bus 1543	: V=1.05128703, theta=-7.01867361 -> V=1.0158755, theta=0.0
% INFO    : Bus 1544	: V=1.03656979, theta=-37.2028117 -> V=1.022224, theta=0.0
% INFO    : Bus 1545	: V=1.02138027, theta=-55.4069328 -> V=1.0079355, theta=0.0
% INFO    : Bus 1546	: V=1.01680094, theta=-19.2799851 -> V=1.0158755, theta=0.0
% INFO    : Bus 1547	: V=1.02117881, theta=-29.751776 -> V=1.0000025, theta=0.0
% INFO    : Bus 1548	: V=1.04001362, theta=-23.6718141 -> V=1.022222, theta=0.0
% INFO    : Bus 1549	: V=1.06313134, theta=-37.0484161 -> V=1.04444, theta=0.0
% INFO    : Bus 1550	: V=1.04073209, theta=-30.8322943 -> V=1.027779, theta=0.0
% INFO    : Bus 1551	: V=1.02920995, theta=-16.0976467 -> V=0.999999, theta=0.0
% INFO    : Bus 1552	: V=1.04225519, theta=-16.3787618 -> V=1.0158755, theta=0.0
% INFO    : Bus 1553	: V=1.06601393, theta=-20.915329 -> V=1.022222, theta=0.0
% INFO    : Bus 1554	: V=1.04431362, theta=-15.4240607 -> V=0.9888895, theta=0.0
% INFO    : Bus 1555	: V=1.046, theta=-20.7327198 -> V=1.033333, theta=0.0
% INFO    : Bus 1556	: V=1.01964671, theta=-30.4745679 -> V=1.015872, theta=0.0
% INFO    : Bus 1557	: V=1.06425569, theta=-24.5439242 -> V=1.046665, theta=0.0
% INFO    : Bus 1558	: V=1.05687126, theta=-32.8765588 -> V=1.027779, theta=0.0
% INFO    : Bus 1559	: V=1.06284314, theta=-29.5393371 -> V=1.027779, theta=0.0
% INFO    : Bus 1560	: V=1.0711796, theta=-25.6751624 -> V=1.046665, theta=0.0
% INFO    : Bus 1561	: V=1.03684379, theta=-37.7120968 -> V=1.022224, theta=0.0
% INFO    : Bus 1562	: V=1.02717063, theta=-4.04665801 -> V=1.0158755, theta=0.0
% INFO    : Bus 1563	: V=1.04175463, theta=-12.3668478 -> V=0.999999, theta=0.0
% INFO    : Bus 1564	: V=1.04250728, theta=-12.6092496 -> V=0.999999, theta=0.0
% INFO    : Bus 1565	: V=0.978412349, theta=-6.11277708 -> V=1.0158755, theta=0.0
% INFO    : Bus 1566	: V=1.0638565, theta=-13.4714031 -> V=1.005558, theta=0.0
% INFO    : Bus 1567	: V=1.0632333, theta=-11.3117798 -> V=0.9888895, theta=0.0
% INFO    : Bus 1568	: V=1.05075667, theta=-16.0767219 -> V=1.002104, theta=0.0
% INFO    : Bus 1569	: V=1.03253847, theta=-19.4839822 -> V=1.022224, theta=0.0
% INFO    : Bus 1570	: V=1.04600834, theta=-15.2101779 -> V=1.046665, theta=0.0
% INFO    : Bus 1571	: V=1.03672411, theta=-18.8373422 -> V=0.999999, theta=0.0
% INFO    : Bus 1572	: V=1.01186123, theta=-29.4527361 -> V=1.0000005, theta=0.0
% INFO    : Bus 1573	: V=1.08189114, theta=-9.45005257 -> V=1.07237, theta=0.0
% INFO    : Bus 1574	: V=1.08186365, theta=-9.44994325 -> V=1.07237, theta=0.0
% INFO    : Bus 1575	: V=1.08189006, theta=-9.44870981 -> V=1.07237, theta=0.0
% INFO    : Bus 1576	: V=1.08186017, theta=-9.44572678 -> V=1.07237, theta=0.0
% INFO    : Bus 1577	: V=1.03048128, theta=-29.3411618 -> V=1.022224, theta=0.0
% INFO    : Bus 1578	: V=1.04282243, theta=-26.8060412 -> V=1.046665, theta=0.0
% INFO    : Bus 1579	: V=1.02125617, theta=-11.4341618 -> V=0.999999, theta=0.0
% INFO    : Bus 1580	: V=1.05281328, theta=-6.99513466 -> V=1.0111115, theta=0.0
% INFO    : Bus 1581	: V=1.07090229, theta=-1.43591106 -> V=1.072365, theta=0.0
% INFO    : Bus 1582	: V=1.03170428, theta=-13.7534033 -> V=0.999999, theta=0.0
% INFO    : Bus 1583	: V=1.06156519, theta=-18.888649 -> V=1.016666, theta=0.0
% INFO    : Bus 1584	: V=1.06032224, theta=-14.1033418 -> V=1.0288895, theta=0.0
% INFO    : Bus 1585	: V=1.03197651, theta=-34.6156527 -> V=1.022224, theta=0.0
% INFO    : Bus 1586	: V=1.03913045, theta=-34.513887 -> V=1.022224, theta=0.0
% INFO    : Bus 1587	: V=1.04411799, theta=-26.0056027 -> V=1.027779, theta=0.0
% INFO    : Bus 1588	: V=1.01447783, theta=4.80224468 -> V=1.013331, theta=0.0
% INFO    : Bus 1589	: V=1.00300392, theta=-34.4044547 -> V=1.0000005, theta=0.0
% INFO    : Bus 1590	: V=1.05722486, theta=-17.616801 -> V=1.000001, theta=0.0
% INFO    : Bus 1591	: V=0.994214676, theta=-24.0343651 -> V=1.015872, theta=0.0
% INFO    : Bus 1592	: V=1.04379005, theta=-18.872996 -> V=1.022224, theta=0.0
% INFO    : Bus 1593	: V=1.057, theta=-17.4605929 -> V=1.022224, theta=0.0
% INFO    : Bus 1594	: V=1.08563489, theta=-14.718995 -> V=1.047835, theta=0.0
% INFO    : Bus 1595	: V=1.08629952, theta=-10.4775739 -> V=1.07237, theta=0.0
% INFO    : Bus 1596	: V=1.0518541, theta=-32.0408801 -> V=1.0122655, theta=0.0
% INFO    : Bus 1597	: V=1.05807467, theta=-27.7585026 -> V=1.046665, theta=0.0
% INFO    : Bus 1598	: V=1.05516076, theta=-28.0624747 -> V=1.046665, theta=0.0
% INFO    : Bus 1599	: V=1.05, theta=-30.0947027 -> V=1.0028855, theta=0.0
% INFO    : Bus 1600	: V=1.07360063, theta=-25.0308106 -> V=1.046665, theta=0.0
% INFO    : Bus 1601	: V=1.01407926, theta=-14.4686194 -> V=1.015872, theta=0.0
% INFO    : Bus 1602	: V=1.08675154, theta=-13.6919548 -> V=1.044445, theta=0.0
% INFO    : Bus 1603	: V=1.03547444, theta=0.926636839 -> V=1.0158755, theta=0.0
% INFO    : Bus 1604	: V=1.00894175, theta=-23.9226416 -> V=1.0000025, theta=0.0
% INFO    : Bus 1605	: V=1.03292056, theta=-6.29735441 -> V=1.0158755, theta=0.0
% INFO    : Bus 1606	: V=1.00013927, theta=-23.7324217 -> V=1.015872, theta=0.0
% INFO    : Bus 1607	: V=1.01457795, theta=-31.2677308 -> V=1.015872, theta=0.0
% INFO    : Bus 1608	: V=0.979155657, theta=-23.7496041 -> V=1.015872, theta=0.0
% INFO    : Bus 1609	: V=1.05417867, theta=-23.2868235 -> V=1.0233335, theta=0.0
% INFO    : Bus 1610	: V=1.0452892, theta=-19.6518353 -> V=0.999999, theta=0.0
% INFO    : Bus 1611	: V=1.04112886, theta=-19.7333629 -> V=0.999999, theta=0.0
% INFO    : Bus 1612	: V=1.03231614, theta=-15.6964172 -> V=1.0111115, theta=0.0
% INFO    : Bus 1613	: V=1.0361919, theta=-16.1345523 -> V=1.027779, theta=0.0
% INFO    : Bus 1614	: V=1.04095191, theta=-29.4648115 -> V=1.0079355, theta=0.0
% INFO    : Bus 1615	: V=1.0406535, theta=-29.4642191 -> V=1.022224, theta=0.0
% INFO    : Bus 1616	: V=1.03246247, theta=-17.9940712 -> V=1.0000025, theta=0.0
% INFO    : Bus 1617	: V=0.941535613, theta=-5.93846542 -> V=0.9444445, theta=0.0
% INFO    : Bus 1618	: V=0.966701026, theta=-35.5327266 -> V=1.0000005, theta=0.0
% INFO    : Bus 1619	: V=1.00021216, theta=-31.4861057 -> V=1.0000005, theta=0.0
% INFO    : Bus 1620	: V=1.03253346, theta=-39.2523725 -> V=1.022224, theta=0.0
% INFO    : Bus 1621	: V=1.02156213, theta=-22.4487467 -> V=1.0158755, theta=0.0
% INFO    : Bus 1622	: V=1.06176942, theta=-12.6015241 -> V=0.9888895, theta=0.0
% INFO    : Bus 1623	: V=1.06149539, theta=-12.6338731 -> V=0.9888895, theta=0.0
% INFO    : Bus 1624	: V=1.056, theta=-5.82815927 -> V=1.0377785, theta=0.0
% INFO    : Bus 1625	: V=1.03270569, theta=-24.6515376 -> V=1.027779, theta=0.0
% INFO    : Bus 1626	: V=1.06462891, theta=-26.932772 -> V=1.046665, theta=0.0
% INFO    : Bus 1627	: V=1.03517957, theta=-39.6995036 -> V=1.022224, theta=0.0
% INFO    : Bus 1628	: V=1.0176883, theta=-46.0606662 -> V=1.0079355, theta=0.0
% INFO    : Bus 1629	: V=0.989289579, theta=-25.9661363 -> V=1.0000025, theta=0.0
% INFO    : Bus 1630	: V=1.01877217, theta=-0.727596081 -> V=1.0158755, theta=0.0
% INFO    : Bus 1631	: V=1.01579857, theta=-7.24014613 -> V=1.0158755, theta=0.0
% INFO    : Bus 1632	: V=1.03353913, theta=-28.3616248 -> V=1.015872, theta=0.0
% INFO    : Bus 1633	: V=1.04017746, theta=-21.735835 -> V=1.046665, theta=0.0
% INFO    : Bus 1634	: V=0.984707014, theta=-34.2903107 -> V=1.015872, theta=0.0
% INFO    : Bus 1635	: V=1.04529322, theta=-26.7417023 -> V=1.0000025, theta=0.0
% INFO    : Bus 1636	: V=1.05145119, theta=-13.4812326 -> V=1.001104, theta=0.0
% INFO    : Bus 1637	: V=1.04114745, theta=-21.5124305 -> V=1.0000025, theta=0.0
% INFO    : Bus 1638	: V=1.04899703, theta=-25.0351832 -> V=1.0000025, theta=0.0
% INFO    : Bus 1639	: V=1.064, theta=-20.3069305 -> V=1.04444, theta=0.0
% INFO    : Bus 1640	: V=1.029098, theta=-22.957816 -> V=1.0000025, theta=0.0
% INFO    : Bus 1641	: V=1.05763867, theta=-19.7962301 -> V=1.033333, theta=0.0
% INFO    : Bus 1642	: V=1.0676705, theta=-22.912464 -> V=1.0000025, theta=0.0
% INFO    : Bus 1643	: V=1.05470925, theta=-41.6944823 -> V=1.022224, theta=0.0
% INFO    : Bus 1644	: V=1.06006275, theta=-42.0752269 -> V=1.022224, theta=0.0
% INFO    : Bus 1645	: V=1.08231571, theta=-21.4994244 -> V=1.033333, theta=0.0
% INFO    : Bus 1646	: V=1.04766253, theta=-11.2471657 -> V=1.0158755, theta=0.0
% INFO    : Bus 1647	: V=1.01249064, theta=-3.34747804 -> V=1.0158755, theta=0.0
% INFO    : Bus 1648	: V=1.01960178, theta=-27.6279448 -> V=1.0000005, theta=0.0
% INFO    : Bus 1649	: V=1.01959123, theta=-27.5854591 -> V=1.0000005, theta=0.0
% INFO    : Bus 1650	: V=1.01850735, theta=-27.6501517 -> V=1.0000005, theta=0.0
% INFO    : Bus 1651	: V=1.06280727, theta=-18.2339711 -> V=1.022222, theta=0.0
% INFO    : Bus 1652	: V=1.00960021, theta=-22.1664185 -> V=1.015872, theta=0.0
% INFO    : Bus 1653	: V=1.05200266, theta=-17.8127401 -> V=1.0000025, theta=0.0
% INFO    : Bus 1654	: V=1.02304377, theta=-26.4371998 -> V=1.0000005, theta=0.0
% INFO    : Bus 1655	: V=1.0607767, theta=-12.7658236 -> V=0.9888895, theta=0.0
% INFO    : Bus 1656	: V=1.03384982, theta=-11.9716347 -> V=0.999999, theta=0.0
% INFO    : Bus 1657	: V=1.03490847, theta=-22.2219832 -> V=1.0000025, theta=0.0
% INFO    : Bus 1658	: V=0.994457914, theta=-4.21618243 -> V=1.0158755, theta=0.0
% INFO    : Bus 1659	: V=1.02432439, theta=-27.4371815 -> V=1.0000005, theta=0.0
% INFO    : Bus 1660	: V=1.02664382, theta=-18.4775821 -> V=1.015872, theta=0.0
% INFO    : Bus 1661	: V=1.02161695, theta=-22.9811073 -> V=1.0000025, theta=0.0
% INFO    : Bus 1662	: V=1.04757783, theta=-15.177797 -> V=0.9888895, theta=0.0
% INFO    : Bus 1663	: V=1.0332048, theta=-6.08039322 -> V=1.0158755, theta=0.0
% INFO    : Bus 1664	: V=1.07082058, theta=-3.47300629 -> V=1.0377785, theta=0.0
% INFO    : Bus 1665	: V=0.997735316, theta=-30.0728342 -> V=1.0000005, theta=0.0
% INFO    : Bus 1666	: V=1.04764209, theta=-27.1972913 -> V=1.027779, theta=0.0
% INFO    : Bus 1667	: V=1.0429388, theta=-10.5845064 -> V=1.0158755, theta=0.0
% INFO    : Bus 1668	: V=1.07153318, theta=-6.41318756 -> V=1.0377785, theta=0.0
% INFO    : Bus 1669	: V=1.03234124, theta=-12.2638791 -> V=1.0111115, theta=0.0
% INFO    : Bus 1670	: V=1.05815226, theta=-14.5316224 -> V=0.999999, theta=0.0
% INFO    : Bus 1671	: V=1.05690349, theta=-15.3010475 -> V=0.999999, theta=0.0
% INFO    : Bus 1672	: V=1.04651318, theta=-29.8304104 -> V=1.027779, theta=0.0
% INFO    : Bus 1673	: V=1.02296942, theta=-40.2965011 -> V=1.022224, theta=0.0
% INFO    : Bus 1674	: V=1.02280149, theta=-40.5511792 -> V=1.022224, theta=0.0
% INFO    : Bus 1675	: V=1.04027859, theta=-37.5823701 -> V=1.0000025, theta=0.0
% INFO    : Bus 1676	: V=1.03710898, theta=-10.354223 -> V=0.999999, theta=0.0
% INFO    : Bus 1677	: V=1.0545895, theta=-7.04020216 -> V=1.0111115, theta=0.0
% INFO    : Bus 1678	: V=1.018, theta=-13.9722844 -> V=1.015872, theta=0.0
% INFO    : Bus 1679	: V=1.05107007, theta=-28.1204378 -> V=1.0000025, theta=0.0
% INFO    : Bus 1680	: V=1.01836312, theta=-18.9105783 -> V=1.015872, theta=0.0
% INFO    : Bus 1681	: V=1.02486531, theta=-19.7593547 -> V=0.999999, theta=0.0
% INFO    : Bus 1682	: V=1.04114745, theta=-21.5124305 -> V=1.0000025, theta=0.0
% INFO    : Bus 1683	: V=1.02704253, theta=-22.4855368 -> V=1.015872, theta=0.0
% INFO    : Bus 1684	: V=1.04607316, theta=-16.7124084 -> V=1.046665, theta=0.0
% INFO    : Bus 1685	: V=1.01575301, theta=-1.12585407 -> V=1.0158755, theta=0.0
% INFO    : Bus 1686	: V=1.05549776, theta=-30.3023476 -> V=1.022224, theta=0.0
% INFO    : Bus 1687	: V=1.018, theta=-23.1015484 -> V=1.0000025, theta=0.0
% INFO    : Bus 1688	: V=1.04734085, theta=-29.9485652 -> V=1.022224, theta=0.0
% INFO    : Bus 1689	: V=1.09810019, theta=10.9035626 -> V=1.072765, theta=0.0
% INFO    : Bus 1690	: V=1.09808371, theta=10.9013727 -> V=1.072755, theta=0.0
% INFO    : Bus 1691	: V=1.03253817, theta=3.25799725 -> V=1.0158755, theta=0.0
% INFO    : Bus 1692	: V=1.08391956, theta=6.34103041 -> V=1.0390435, theta=0.0
% INFO    : Bus 1693	: V=1.08378833, theta=6.33027101 -> V=1.0389785, theta=0.0
% INFO    : Bus 1694	: V=1.06769307, theta=-22.9236836 -> V=1.0000025, theta=0.0
% INFO    : Bus 1695	: V=1.02401546, theta=-15.7190366 -> V=1.015872, theta=0.0
% INFO    : Bus 1696	: V=1.02077865, theta=1.81170939 -> V=1.0158755, theta=0.0
% INFO    : Bus 1697	: V=1.02321131, theta=-20.586505 -> V=1.0000025, theta=0.0
% INFO    : Bus 1698	: V=1.045707, theta=-23.6496144 -> V=1.0000025, theta=0.0
% INFO    : Bus 1699	: V=1.04113791, theta=-24.3697103 -> V=1.0000025, theta=0.0
% INFO    : Bus 1700	: V=1.044, theta=-17.8799607 -> V=0.999999, theta=0.0
% INFO    : Bus 1701	: V=1.06659124, theta=-26.6936646 -> V=1.046665, theta=0.0
% INFO    : Bus 1702	: V=0.989772865, theta=-30.1480896 -> V=1.0000005, theta=0.0
% INFO    : Bus 1703	: V=0.985851861, theta=-29.7348278 -> V=1.0000005, theta=0.0
% INFO    : Bus 1704	: V=1.03222397, theta=-26.5598844 -> V=1.046665, theta=0.0
% INFO    : Bus 1705	: V=1.03221946, theta=-26.5612974 -> V=1.046665, theta=0.0
% INFO    : Bus 1706	: V=1.0322584, theta=-26.5617826 -> V=1.046665, theta=0.0
% INFO    : Bus 1707	: V=1.03222185, theta=-26.560381 -> V=1.046665, theta=0.0
% INFO    : Bus 1708	: V=0.989958368, theta=-30.1974266 -> V=1.0000005, theta=0.0
% INFO    : Bus 1709	: V=0.985596057, theta=-29.8298468 -> V=1.0000005, theta=0.0
% INFO    : Bus 1710	: V=1.03224793, theta=-26.5549846 -> V=1.046665, theta=0.0
% INFO    : Bus 1711	: V=1.07259535, theta=-16.4330065 -> V=1.015874, theta=0.0
% INFO    : Bus 1712	: V=1.05824529, theta=-12.8842348 -> V=1.015556, theta=0.0
% INFO    : Bus 1713	: V=1.03526575, theta=-25.9273421 -> V=1.046665, theta=0.0
% INFO    : Bus 1714	: V=1.03504057, theta=-25.9443396 -> V=1.046665, theta=0.0
% INFO    : Bus 1715	: V=1.03600366, theta=-14.1655515 -> V=0.999999, theta=0.0
% INFO    : Bus 1716	: V=1.04098688, theta=-28.2848275 -> V=1.022224, theta=0.0
% INFO    : Bus 1717	: V=1.0729706, theta=-25.2748394 -> V=1.04444, theta=0.0
% INFO    : Bus 1718	: V=1.05040506, theta=-30.1186871 -> V=1.0000025, theta=0.0
% INFO    : Bus 1719	: V=1.03876541, theta=-22.5833012 -> V=1.0000025, theta=0.0
% INFO    : Bus 1720	: V=1.04755534, theta=-15.0093256 -> V=1.046665, theta=0.0
% INFO    : Bus 1721	: V=1.02112031, theta=-13.5292357 -> V=0.999999, theta=0.0
% INFO    : Bus 1722	: V=1.04232545, theta=-10.6140147 -> V=0.975, theta=0.0
% INFO    : Bus 1723	: V=1.04128416, theta=-10.6140147 -> V=0.999999, theta=0.0
% INFO    : Bus 1724	: V=1.02674574, theta=-31.6166131 -> V=1.022224, theta=0.0
% INFO    : Bus 1725	: V=1.03967534, theta=-26.3712133 -> V=1.027779, theta=0.0
% INFO    : Bus 1726	: V=1.06597074, theta=-14.6624255 -> V=1.0111115, theta=0.0
% INFO    : Bus 1727	: V=1.02888069, theta=-9.7255296 -> V=0.999999, theta=0.0
% INFO    : Bus 1728	: V=1.04581483, theta=-21.6677637 -> V=1.0000025, theta=0.0
% INFO    : Bus 1729	: V=1.07105417, theta=-19.9650375 -> V=1.0000025, theta=0.0
% INFO    : Bus 1730	: V=1.06922554, theta=-23.5226837 -> V=1.0000025, theta=0.0
% INFO    : Bus 1731	: V=1.06929687, theta=-16.5484945 -> V=1.044445, theta=0.0
% INFO    : Bus 1732	: V=1.05167625, theta=-34.2738466 -> V=1.027779, theta=0.0
% INFO    : Bus 1733	: V=1.03626217, theta=-21.8962398 -> V=1.022224, theta=0.0
% INFO    : Bus 1734	: V=1.054, theta=-25.2380518 -> V=1.0000025, theta=0.0
% INFO    : Bus 1735	: V=1.02648033, theta=-16.8696646 -> V=1.015872, theta=0.0
% INFO    : Bus 1736	: V=1.08641531, theta=-2.13526195 -> V=1.0377785, theta=0.0
% INFO    : Bus 1737	: V=1.08641211, theta=-2.13521681 -> V=1.0377785, theta=0.0
% INFO    : Bus 1738	: V=1.10494489, theta=2.64389982 -> V=1.072365, theta=0.0
% INFO    : Bus 1739	: V=1.10506627, theta=2.64523561 -> V=1.072365, theta=0.0
% INFO    : Bus 1740	: V=1.08644338, theta=-2.13565532 -> V=1.0377785, theta=0.0
% INFO    : Bus 1741	: V=1.113, theta=3.65185209 -> V=0.975, theta=0.0
% INFO    : Bus 1742	: V=1.112, theta=4.24596715 -> V=0.975, theta=0.0
% INFO    : Bus 1743	: V=1.113, theta=3.49862916 -> V=0.975, theta=0.0
% INFO    : Bus 1744	: V=1.08650794, theta=-2.11513155 -> V=1.0377785, theta=0.0
% INFO    : Bus 1745	: V=1.08649946, theta=-2.11306999 -> V=1.0377785, theta=0.0
% INFO    : Bus 1746	: V=1.08650918, theta=-2.11566986 -> V=1.0377785, theta=0.0
% INFO    : Bus 1747	: V=1.0320215, theta=-15.45072 -> V=1.015872, theta=0.0
% INFO    : Bus 1748	: V=1.02005541, theta=-15.6994239 -> V=1.015872, theta=0.0
% INFO    : Bus 1749	: V=1.05214053, theta=-14.609657 -> V=1.046665, theta=0.0
% INFO    : Bus 1750	: V=1.01362253, theta=-19.2640446 -> V=0.999999, theta=0.0
% INFO    : Bus 1751	: V=1.02883605, theta=-11.7847966 -> V=0.999999, theta=0.0
% INFO    : Bus 1752	: V=1.03980742, theta=-11.0483887 -> V=0.999999, theta=0.0
% INFO    : Bus 1753	: V=1.06168231, theta=-10.1449542 -> V=1.003239, theta=0.0
% INFO    : Bus 1754	: V=1.03516457, theta=-21.0274754 -> V=1.0000025, theta=0.0
% INFO    : Bus 1755	: V=1.03024241, theta=-24.9219378 -> V=1.0000025, theta=0.0
% INFO    : Bus 1756	: V=0.996957539, theta=-13.9978088 -> V=1.0158755, theta=0.0
% INFO    : Bus 1757	: V=1.04304967, theta=-9.69004594 -> V=1.0111115, theta=0.0
% INFO    : Bus 1758	: V=1.02126287, theta=-17.7759301 -> V=1.015872, theta=0.0
% INFO    : Bus 1759	: V=1.02360676, theta=-18.2637116 -> V=1.0000025, theta=0.0
% INFO    : Bus 1760	: V=1.02332486, theta=-24.7256869 -> V=1.0000025, theta=0.0
% INFO    : Bus 1761	: V=1.01810327, theta=-17.6821207 -> V=1.0158755, theta=0.0
% INFO    : Bus 1762	: V=1.09214283, theta=-18.6287259 -> V=1.073685, theta=0.0
% INFO    : Bus 1763	: V=1.09461225, theta=-16.1561552 -> V=1.073685, theta=0.0
% INFO    : Bus 1764	: V=1.09314731, theta=-15.9200417 -> V=1.073685, theta=0.0
% INFO    : Bus 1765	: V=1.09206154, theta=-18.6284666 -> V=1.073685, theta=0.0
% INFO    : Bus 1766	: V=1.02912569, theta=-26.8345112 -> V=1.0000025, theta=0.0
% INFO    : Bus 1767	: V=1.05626151, theta=-13.4599659 -> V=0.9888895, theta=0.0
% INFO    : Bus 1768	: V=1.05068494, theta=-19.7789588 -> V=1.000069, theta=0.0
% INFO    : Bus 1769	: V=1.06395344, theta=-24.8873835 -> V=1.046665, theta=0.0
% INFO    : Bus 1770	: V=1.03107755, theta=-25.916873 -> V=1.0079355, theta=0.0
% INFO    : Bus 1771	: V=1.07145939, theta=-27.4107669 -> V=1.028844, theta=0.0
% INFO    : Bus 1772	: V=1.06471004, theta=-29.081857 -> V=1.025339, theta=0.0
% INFO    : Bus 1773	: V=1.07270925, theta=-24.6781147 -> V=1.04444, theta=0.0
% INFO    : Bus 1774	: V=1.02616131, theta=-35.3048154 -> V=1.022224, theta=0.0
% INFO    : Bus 1775	: V=1.0797197, theta=-35.865578 -> V=1.035499, theta=0.0
% INFO    : Bus 1776	: V=1.07120285, theta=-32.4447375 -> V=1.046665, theta=0.0
% INFO    : Bus 1777	: V=0.992879645, theta=-29.450645 -> V=1.0000025, theta=0.0
% INFO    : Bus 1778	: V=1.01725382, theta=-17.7112487 -> V=1.0158755, theta=0.0
% INFO    : Bus 1779	: V=1.04389459, theta=-3.02763203 -> V=0.984126, theta=0.0
% INFO    : Bus 1780	: V=1.04405076, theta=-14.3632385 -> V=0.999999, theta=0.0
% INFO    : Bus 1781	: V=1.04670162, theta=-10.4172383 -> V=1.0111115, theta=0.0
% INFO    : Bus 1782	: V=1.04960622, theta=-30.1218388 -> V=1.0027255, theta=0.0
% INFO    : Bus 1783	: V=1.01488172, theta=-19.7072335 -> V=1.0158755, theta=0.0
% INFO    : Bus 1784	: V=1.01485186, theta=-19.7215668 -> V=1.0158755, theta=0.0
% INFO    : Bus 1785	: V=1.04610336, theta=-4.73062847 -> V=1.0000025, theta=0.0
% INFO    : Bus 1786	: V=1.03688136, theta=-22.0192419 -> V=1.0000025, theta=0.0
% INFO    : Bus 1787	: V=1.05228851, theta=-21.6490734 -> V=1.000001, theta=0.0
% INFO    : Bus 1788	: V=1.07130224, theta=-18.2916125 -> V=1.044445, theta=0.0
% INFO    : Bus 1789	: V=1.04081307, theta=-21.1414946 -> V=1.0000025, theta=0.0
% INFO    : Bus 1790	: V=1.05956938, theta=-18.1393014 -> V=1.044445, theta=0.0
% INFO    : Bus 1791	: V=1.00001565, theta=-15.108847 -> V=1.015872, theta=0.0
% INFO    : Bus 1792	: V=1.07404487, theta=-28.5649604 -> V=1.047005, theta=0.0
% INFO    : Bus 1793	: V=1.07387785, theta=-28.5854766 -> V=1.04692, theta=0.0
% INFO    : Bus 1794	: V=1.05267022, theta=-25.5093318 -> V=1.0000025, theta=0.0
% INFO    : Bus 1795	: V=1.0529349, theta=-25.4611054 -> V=1.0000025, theta=0.0
% INFO    : Bus 1796	: V=1.04843106, theta=-25.9660219 -> V=1.046665, theta=0.0
% INFO    : Bus 1797	: V=1.02261098, theta=-22.7523193 -> V=1.0000025, theta=0.0
% INFO    : Bus 1798	: V=1.03690451, theta=-16.7396029 -> V=0.999999, theta=0.0
% INFO    : Bus 1799	: V=1.05140852, theta=-12.2056614 -> V=1.0111115, theta=0.0
% INFO    : Bus 1800	: V=1.02776418, theta=2.23153391 -> V=1.0158755, theta=0.0
% INFO    : Bus 1801	: V=1.0262489, theta=2.1319292 -> V=1.0158755, theta=0.0
% INFO    : Bus 1802	: V=1.03727351, theta=-27.4497351 -> V=1.0000025, theta=0.0
% INFO    : Bus 1803	: V=1.01738174, theta=-11.4158045 -> V=1.0079355, theta=0.0
% INFO    : Bus 1804	: V=1.06398721, theta=-13.3891409 -> V=1.033333, theta=0.0
% INFO    : Bus 1805	: V=1.03102257, theta=-30.525214 -> V=1.0000655, theta=0.0
% INFO    : Bus 1806	: V=1.06275391, theta=-25.3091025 -> V=1.046665, theta=0.0
% INFO    : Bus 1807	: V=1.04607144, theta=-21.1411226 -> V=1.0000025, theta=0.0
% INFO    : Bus 1808	: V=1.04400717, theta=-33.7656364 -> V=1.022224, theta=0.0
% INFO    : Bus 1809	: V=1.03272613, theta=-11.6512429 -> V=1.0158755, theta=0.0
% INFO    : Bus 1810	: V=1.03422808, theta=-38.944964 -> V=1.022224, theta=0.0
% INFO    : Bus 1811	: V=1.05012904, theta=-22.3794709 -> V=1.005558, theta=0.0
% INFO    : Bus 1812	: V=1.04533962, theta=-28.5637313 -> V=1.027779, theta=0.0
% INFO    : Bus 1813	: V=1.05684962, theta=-32.8787645 -> V=1.027779, theta=0.0
% INFO    : Bus 1814	: V=1.03263965, theta=-17.220492 -> V=1.000001, theta=0.0
% INFO    : Bus 1815	: V=1.02621696, theta=-32.3094398 -> V=1.022224, theta=0.0
% INFO    : Bus 1816	: V=1.03291299, theta=-17.189672 -> V=1.0000025, theta=0.0
% INFO    : Bus 1817	: V=1.06191152, theta=-18.4806672 -> V=1.0000025, theta=0.0
% INFO    : Bus 1818	: V=1.06658833, theta=-14.9560186 -> V=1.044445, theta=0.0
% INFO    : Bus 1819	: V=1.06823845, theta=-10.6972099 -> V=0.9888895, theta=0.0
% INFO    : Bus 1820	: V=1.05297202, theta=-15.1999459 -> V=1.0111115, theta=0.0
% INFO    : Bus 1821	: V=1.03960706, theta=-8.97198371 -> V=1.0158755, theta=0.0
% INFO    : Bus 1822	: V=1.05876807, theta=-6.85949294 -> V=1.0377785, theta=0.0
% INFO    : Bus 1823	: V=1.08999311, theta=-4.34861602 -> V=1.072365, theta=0.0
% INFO    : Bus 1824	: V=1.01491819, theta=-39.585342 -> V=1.022224, theta=0.0
% INFO    : Bus 1825	: V=1.02781202, theta=-21.5634957 -> V=1.0000025, theta=0.0
% INFO    : Bus 1826	: V=1.01914996, theta=-33.4506765 -> V=1.015872, theta=0.0
% INFO    : Bus 1827	: V=1.02887927, theta=-26.720137 -> V=1.046665, theta=0.0
% INFO    : Bus 1828	: V=1.06226106, theta=-29.5777753 -> V=1.027779, theta=0.0
% INFO    : Bus 1829	: V=1.02095, theta=-4.64314469 -> V=0.999999, theta=0.0
% INFO    : Bus 1830	: V=1.00159531, theta=-41.0517216 -> V=1.022224, theta=0.0
% INFO    : Bus 1831	: V=1.04538054, theta=-23.8296891 -> V=1.0111115, theta=0.0
% INFO    : Bus 1832	: V=1.03665148, theta=-10.0743243 -> V=0.999999, theta=0.0
% INFO    : Bus 1833	: V=1.05085531, theta=-7.68595714 -> V=1.0111115, theta=0.0
% INFO    : Bus 1834	: V=1.07456989, theta=-27.9380921 -> V=1.047245, theta=0.0
% INFO    : Bus 1835	: V=1.07497219, theta=-27.8981042 -> V=1.04744, theta=0.0
% INFO    : Bus 1836	: V=1.00485926, theta=-19.8361886 -> V=1.0158755, theta=0.0
% INFO    : Bus 1837	: V=1.04459648, theta=-9.59741244 -> V=1.0158755, theta=0.0
% INFO    : Bus 1838	: V=1.04954125, theta=-7.20529016 -> V=1.0377785, theta=0.0
% INFO    : Bus 1839	: V=1.05214593, theta=-20.1536887 -> V=1.0000025, theta=0.0
% INFO    : Bus 1840	: V=1.0248439, theta=-0.805208859 -> V=1.0158755, theta=0.0
% INFO    : Bus 1841	: V=1.02457831, theta=-0.829421861 -> V=1.0158755, theta=0.0
% INFO    : Bus 1842	: V=1.0755759, theta=-19.8033057 -> V=1.022222, theta=0.0
% INFO    : Bus 1843	: V=1.05687139, theta=-32.8765623 -> V=1.027779, theta=0.0
% INFO    : Bus 1844	: V=1.05687134, theta=-32.8765609 -> V=1.027779, theta=0.0
% INFO    : Bus 1845	: V=1.02481745, theta=-19.0286264 -> V=0.999999, theta=0.0
% INFO    : Bus 1846	: V=1.0118252, theta=-22.3911782 -> V=1.0158755, theta=0.0
% INFO    : Bus 1847	: V=1.04313091, theta=-27.2319939 -> V=1.016667, theta=0.0
% INFO    : Bus 1848	: V=1.03480751, theta=-27.880244 -> V=1.0000025, theta=0.0
% INFO    : Bus 1849	: V=1.03962752, theta=-20.3981313 -> V=0.999999, theta=0.0
% INFO    : Bus 1850	: V=1.03922597, theta=-20.4115644 -> V=0.999999, theta=0.0
% INFO    : Bus 1851	: V=1.01622109, theta=-1.10266048 -> V=1.0158755, theta=0.0
% INFO    : Bus 1852	: V=1.04582319, theta=-32.8154447 -> V=1.0000025, theta=0.0
% INFO    : Bus 1853	: V=0.996221353, theta=-31.9701897 -> V=1.015872, theta=0.0
% INFO    : Bus 1854	: V=0.986600849, theta=-15.5193151 -> V=1.015872, theta=0.0
% INFO    : Bus 1855	: V=1.04680617, theta=-26.9032102 -> V=1.0000025, theta=0.0
% INFO    : Bus 1856	: V=1.02251234, theta=-11.3882944 -> V=0.999999, theta=0.0
% INFO    : Bus 1857	: V=1.01987783, theta=-6.78830666 -> V=1.0158755, theta=0.0
% INFO    : Bus 1858	: V=1.06794857, theta=-22.9301457 -> V=1.0000025, theta=0.0
% INFO    : Bus 1859	: V=1.00252222, theta=-16.1209381 -> V=1.015872, theta=0.0
% INFO    : Bus 1860	: V=1.03481383, theta=-25.1798272 -> V=1.022224, theta=0.0
% INFO    : Bus 1861	: V=1.02753677, theta=-25.5761748 -> V=1.022224, theta=0.0
% INFO    : Bus 1862	: V=1.00170237, theta=-38.7937685 -> V=1.022224, theta=0.0
% INFO    : Bus 1863	: V=1.03266887, theta=-12.5891811 -> V=1.0111115, theta=0.0
% INFO    : Bus 1864	: V=1.03608451, theta=-31.1648506 -> V=1.022224, theta=0.0
% INFO    : Bus 1865	: V=1.014, theta=-25.9013459 -> V=1.0000005, theta=0.0
% INFO    : Bus 1866	: V=1.04072108, theta=-8.19726966 -> V=0.999999, theta=0.0
% INFO    : Bus 1867	: V=1.01773429, theta=-16.9211463 -> V=1.015872, theta=0.0
% INFO    : Bus 1868	: V=0.976783301, theta=-25.8654031 -> V=1.0000005, theta=0.0
% INFO    : Bus 1869	: V=1.02586715, theta=-18.4969018 -> V=1.0000025, theta=0.0
% INFO    : Bus 1870	: V=1.04363481, theta=-30.2575096 -> V=1.027779, theta=0.0
% INFO    : Bus 1871	: V=1.07611159, theta=-18.3297068 -> V=1.000001, theta=0.0
% INFO    : Bus 1872	: V=1.0402668, theta=-10.8846227 -> V=0.999999, theta=0.0
% INFO    : Bus 1873	: V=1.082129, theta=-21.51648 -> V=1.033333, theta=0.0
% INFO    : Bus 1874	: V=1.04644206, theta=-4.92814842 -> V=1.0158755, theta=0.0
% INFO    : Bus 1875	: V=1.04486272, theta=-22.3848188 -> V=1.022224, theta=0.0
% INFO    : Bus 1876	: V=1.04266988, theta=-15.2096274 -> V=0.999999, theta=0.0
% INFO    : Bus 1877	: V=1.04322773, theta=-23.1441295 -> V=1.027779, theta=0.0
% INFO    : Bus 1878	: V=1.07901434, theta=-20.4723177 -> V=1.046675, theta=0.0
% INFO    : Bus 1879	: V=1.04675255, theta=-35.9856587 -> V=1.027779, theta=0.0
% INFO    : Bus 1880	: V=1.03191826, theta=-43.6158235 -> V=1.022224, theta=0.0
% INFO    : Bus 1881	: V=1.03155304, theta=-43.6691003 -> V=1.022224, theta=0.0
% INFO    : Bus 1882	: V=1.04738254, theta=-29.4505845 -> V=1.027779, theta=0.0
% INFO    : Bus 1883	: V=1.03657313, theta=-22.000933 -> V=1.0000025, theta=0.0
% INFO    : Bus 1884	: V=1.03052423, theta=-14.8006027 -> V=1.015872, theta=0.0
% INFO    : Bus 1885	: V=1.06583636, theta=-24.098866 -> V=1.046665, theta=0.0
% INFO    : Bus 1886	: V=1.06349132, theta=-23.9621471 -> V=1.046665, theta=0.0
% INFO    : Bus 1887	: V=1.06287367, theta=-24.957676 -> V=1.046665, theta=0.0
% INFO    : Bus 1888	: V=1.042, theta=-0.123347782 -> V=0.975, theta=0.0
% INFO    : Bus 1889	: V=1.039, theta=-0.30162197 -> V=0.975, theta=0.0
% INFO    : Bus 1890	: V=1.045, theta=0.0488933734 -> V=0.975, theta=0.0
% INFO    : Bus 1891	: V=1.046, theta=-0.0186203624 -> V=0.975, theta=0.0
% INFO    : Bus 1892	: V=1.04436913, theta=-2.17670371 -> V=1.0377785, theta=0.0
% INFO    : Bus 1893	: V=1.04435483, theta=-2.177611 -> V=1.0377785, theta=0.0
% INFO    : Bus 1894	: V=1.0443834, theta=-2.17582137 -> V=1.0377785, theta=0.0
% INFO    : Bus 1895	: V=1.04438859, theta=-2.17614555 -> V=1.0377785, theta=0.0
% INFO    : Bus 1896	: V=1.02495822, theta=-6.18712755 -> V=1.0158755, theta=0.0
% INFO    : Bus 1897	: V=1.04438365, theta=-2.18690073 -> V=1.0377785, theta=0.0
% INFO    : Bus 1898	: V=1.02497822, theta=-12.4824207 -> V=0.999999, theta=0.0
% INFO    : Bus 1899	: V=1.03318881, theta=-7.13711324 -> V=1.0111115, theta=0.0
% INFO    : Bus 1900	: V=1.0180891, theta=-16.941265 -> V=1.0000025, theta=0.0
% INFO    : Bus 1901	: V=1.06244601, theta=-14.0305703 -> V=1.044445, theta=0.0
% INFO    : Bus 1902	: V=1.04129667, theta=-30.4536833 -> V=1.027779, theta=0.0
% INFO    : Bus 1903	: V=1.03485916, theta=-18.9842234 -> V=0.999999, theta=0.0
% INFO    : Bus 1904	: V=1.02751863, theta=-27.6343552 -> V=1.0000005, theta=0.0
% INFO    : Bus 1905	: V=1.05287795, theta=-23.1064838 -> V=1.027779, theta=0.0
% INFO    : Bus 1906	: V=1.02854358, theta=-12.3091991 -> V=1.015872, theta=0.0
% INFO    : Bus 1907	: V=1.0389166, theta=-15.1151796 -> V=1.0158755, theta=0.0
% INFO    : Bus 1908	: V=1.07197324, theta=-12.4978711 -> V=1.0377785, theta=0.0
% INFO    : Bus 1909	: V=1.01213481, theta=-22.4285504 -> V=1.0158755, theta=0.0
% INFO    : Bus 1910	: V=1.01097963, theta=-22.5623633 -> V=1.0158755, theta=0.0
% INFO    : Bus 1911	: V=1.03255373, theta=-26.4612845 -> V=1.015872, theta=0.0
% INFO    : Bus 1912	: V=1.0420589, theta=-22.2329648 -> V=1.046665, theta=0.0
% INFO    : Bus 1913	: V=1.02468646, theta=-29.8484605 -> V=1.022224, theta=0.0
% INFO    : Bus 1914	: V=1.01088737, theta=-22.5608457 -> V=1.015872, theta=0.0
% INFO    : Bus 1915	: V=1.03291568, theta=-20.9106292 -> V=1.0000025, theta=0.0
% INFO    : Bus 1916	: V=0.99894248, theta=-12.5339203 -> V=1.015872, theta=0.0
% INFO    : Bus 1917	: V=1.03417859, theta=-23.5701833 -> V=1.0000025, theta=0.0
% INFO    : Bus 1918	: V=1.06080728, theta=-22.0404136 -> V=1.0000025, theta=0.0
% INFO    : Bus 1919	: V=1.05781989, theta=-15.6587591 -> V=1.022222, theta=0.0
% INFO    : Bus 1920	: V=1.02512515, theta=-31.2894881 -> V=1.0000005, theta=0.0
% INFO    : Bus 1921	: V=1.0684238, theta=-26.457241 -> V=1.046665, theta=0.0
% INFO    : Bus 1922	: V=1.06391011, theta=-16.2324808 -> V=1.000001, theta=0.0
% INFO    : Bus 1923	: V=1.08552907, theta=-13.9904371 -> V=1.044445, theta=0.0
% INFO    : Bus 1924	: V=1.04382523, theta=-19.1761348 -> V=1.022224, theta=0.0
% INFO    : Bus 1925	: V=1.07317737, theta=-12.9086908 -> V=1.07237, theta=0.0
% INFO    : Bus 1926	: V=1.03248791, theta=-22.1981774 -> V=1.0000025, theta=0.0
% INFO    : Bus 1927	: V=1.04308377, theta=-20.6291951 -> V=1.000001, theta=0.0
% INFO    : Bus 1928	: V=1.07627817, theta=-16.7826549 -> V=1.044445, theta=0.0
% INFO    : Bus 1929	: V=1.07693873, theta=-13.9046686 -> V=1.078945, theta=0.0
% INFO    : Bus 1930	: V=1.017514, theta=-11.2008545 -> V=1.0079355, theta=0.0
% INFO    : Bus 1931	: V=1.07943995, theta=-5.627602 -> V=1.07237, theta=0.0
% INFO    : Bus 1932	: V=1.02752761, theta=-8.60510595 -> V=0.999999, theta=0.0
% INFO    : Bus 1933	: V=1.02752761, theta=-8.60510595 -> V=0.999999, theta=0.0
% INFO    : Bus 1934	: V=1.03118956, theta=-8.45018464 -> V=0.999999, theta=0.0
% INFO    : Bus 1935	: V=1.01650251, theta=-21.3129367 -> V=1.015872, theta=0.0
% INFO    : Bus 1936	: V=1.06105042, theta=-19.5308054 -> V=1.016666, theta=0.0
% INFO    : Bus 1937	: V=1.07579799, theta=-19.7871172 -> V=1.016666, theta=0.0
% INFO    : Bus 1938	: V=1.04760174, theta=-15.1733636 -> V=1.015556, theta=0.0
% INFO    : Bus 1939	: V=1.06591905, theta=-11.833756 -> V=1.05263, theta=0.0
% INFO    : Bus 1940	: V=1.04098626, theta=-29.4657015 -> V=1.0035905, theta=0.0
% INFO    : Bus 1941	: V=0.976739772, theta=-25.8644682 -> V=1.0000005, theta=0.0
% INFO    : Bus 1942	: V=1.04427558, theta=-17.0826749 -> V=1.0000025, theta=0.0
% INFO    : Bus 1943	: V=1.0246025, theta=-5.34481935 -> V=1.0158755, theta=0.0
% INFO    : Bus 1944	: V=1.0484205, theta=-27.567185 -> V=1.022224, theta=0.0
% INFO    : Bus 1945	: V=1.03796294, theta=-12.8666457 -> V=0.999999, theta=0.0
% INFO    : Bus 1946	: V=1.03287657, theta=-15.6125499 -> V=0.999999, theta=0.0
% INFO    : Bus 1947	: V=1.0434289, theta=-39.1781284 -> V=1.022224, theta=0.0
% INFO    : Bus 1948	: V=1.04100085, theta=-16.5185355 -> V=1.0158755, theta=0.0
% INFO    : Bus 1949	: V=1.05170154, theta=-21.3656684 -> V=1.022224, theta=0.0
% INFO    : Bus 1950	: V=1.03972916, theta=-10.7112438 -> V=0.999999, theta=0.0
% INFO    : Bus 1951	: V=1.03546035, theta=-20.0540513 -> V=1.0158755, theta=0.0
% INFO    : Bus 1952	: V=1.04438348, theta=-15.6912093 -> V=1.0158755, theta=0.0
% INFO    : Bus 1953	: V=1.0361904, theta=-24.399983 -> V=1.0000025, theta=0.0
% INFO    : Bus 1954	: V=1.0661919, theta=-7.02661535 -> V=1.0111115, theta=0.0
% INFO    : Bus 1955	: V=1.06493878, theta=-7.34320197 -> V=1.0111115, theta=0.0
% INFO    : Bus 1956	: V=1.07525288, theta=-5.49166113 -> V=1.072365, theta=0.0
% INFO    : Bus 1957	: V=1.03377097, theta=-7.47740787 -> V=1.0158755, theta=0.0
% INFO    : Bus 1958	: V=1.02346377, theta=-12.0262319 -> V=0.999999, theta=0.0
% INFO    : Bus 1959	: V=1.03339703, theta=-11.9261438 -> V=0.999999, theta=0.0
% INFO    : Bus 1960	: V=1.01581268, theta=-24.0525042 -> V=1.0158755, theta=0.0
% INFO    : Bus 1961	: V=1.058, theta=0.923664965 -> V=0.975, theta=0.0
% INFO    : Bus 1962	: V=1.061, theta=0.860577415 -> V=0.975, theta=0.0
% INFO    : Bus 1963	: V=1.058, theta=0.923664965 -> V=0.975, theta=0.0
% INFO    : Bus 1964	: V=1.061, theta=0.88838172 -> V=0.975, theta=0.0
% INFO    : Bus 1965	: V=1.062, theta=0.885921069 -> V=0.975, theta=0.0
% INFO    : Bus 1966	: V=1.06035108, theta=-0.167136156 -> V=1.0377785, theta=0.0
% INFO    : Bus 1967	: V=1.06038206, theta=-0.167724609 -> V=1.0377785, theta=0.0
% INFO    : Bus 1968	: V=1.06035108, theta=-0.167136156 -> V=1.0377785, theta=0.0
% INFO    : Bus 1969	: V=1.06038188, theta=-0.167440956 -> V=1.0377785, theta=0.0
% INFO    : Bus 1970	: V=1.0603803, theta=-0.178330756 -> V=1.0377785, theta=0.0
% INFO    : Bus 1971	: V=1.0603921, theta=-0.167448037 -> V=1.0377785, theta=0.0
% INFO    : Bus 1972	: V=1.00475547, theta=-8.25729514 -> V=1.0158755, theta=0.0
% INFO    : Bus 1973	: V=1.06037968, theta=-0.178330699 -> V=1.0377785, theta=0.0
% INFO    : Bus 1974	: V=1.016, theta=-1.77362716 -> V=0.975, theta=0.0
% INFO    : Bus 1975	: V=1.009, theta=-9.59785191 -> V=0.999999, theta=0.0
% INFO    : Bus 1976	: V=1.014, theta=-10.8627667 -> V=0.999999, theta=0.0
% INFO    : Bus 1977	: V=1.02709548, theta=-5.77874965 -> V=1.0111115, theta=0.0
% INFO    : Bus 1978	: V=1.04735325, theta=-26.4272759 -> V=1.0000025, theta=0.0
% INFO    : Bus 1979	: V=1.01447537, theta=-44.3720251 -> V=1.0079355, theta=0.0
% INFO    : Bus 1980	: V=1.041, theta=-21.4958464 -> V=1.0000025, theta=0.0
% INFO    : Bus 1981	: V=1.01610461, theta=-20.035482 -> V=1.0158755, theta=0.0
% INFO    : Bus 1982	: V=1.01667365, theta=-13.8124806 -> V=0.999999, theta=0.0
% INFO    : Bus 1983	: V=0.999427308, theta=-15.5874212 -> V=1.0079355, theta=0.0
% INFO    : Bus 1984	: V=1.06360271, theta=-18.6547673 -> V=1.027354, theta=0.0
% INFO    : Bus 1985	: V=1.06458445, theta=-14.3656426 -> V=1.04444, theta=0.0
% INFO    : Bus 1986	: V=1.05292962, theta=-10.6237739 -> V=0.999999, theta=0.0
% INFO    : Bus 1987	: V=1.06433261, theta=-20.0701656 -> V=1.0000025, theta=0.0
% INFO    : Bus 1988	: V=1.03497872, theta=-9.49817881 -> V=0.999999, theta=0.0
% INFO    : Bus 1989	: V=1.02547594, theta=-29.2366574 -> V=1.0000025, theta=0.0
% INFO    : Bus 1990	: V=1.03368191, theta=-25.5128185 -> V=1.0000025, theta=0.0
% INFO    : Bus 1991	: V=1.0630737, theta=-20.1385808 -> V=1.044445, theta=0.0
% INFO    : Bus 1992	: V=1.0376291, theta=-12.1501121 -> V=1.0158755, theta=0.0
% INFO    : Bus 1993	: V=1.01824723, theta=-7.98356494 -> V=1.0158755, theta=0.0
% INFO    : Bus 1994	: V=0.96600458, theta=-8.17246586 -> V=0.9444445, theta=0.0
% INFO    : Bus 1995	: V=1.02227124, theta=-17.9535407 -> V=1.0158755, theta=0.0
% INFO    : Bus 1996	: V=1.02144943, theta=-18.0058949 -> V=1.0158755, theta=0.0
% INFO    : Bus 1997	: V=1.05763143, theta=-2.97507546 -> V=1.0000025, theta=0.0
% INFO    : Bus 1998	: V=1.05059448, theta=-7.47638364 -> V=1.0111115, theta=0.0
% INFO    : Bus 1999	: V=1.03626763, theta=-25.2234602 -> V=1.0000025, theta=0.0
% INFO    : Bus 2000	: V=1.02567851, theta=-6.9088153 -> V=1.0158755, theta=0.0
% INFO    : Bus 2001	: V=1.031, theta=-14.7757878 -> V=1.0158755, theta=0.0
% INFO    : Bus 2002	: V=1.07432619, theta=-25.8999439 -> V=1.048095, theta=0.0
% INFO    : Bus 2003	: V=1.06474108, theta=-26.9235006 -> V=1.046665, theta=0.0
% INFO    : Bus 2004	: V=1.02891605, theta=-30.2789002 -> V=1.022224, theta=0.0
% INFO    : Bus 2005	: V=1.05556784, theta=-18.6336028 -> V=1.0000025, theta=0.0
% INFO    : Bus 2006	: V=1.08345232, theta=-15.3480667 -> V=1.044445, theta=0.0
% INFO    : Bus 2007	: V=1.0165048, theta=-7.4724832 -> V=1.0158755, theta=0.0
% INFO    : Bus 2008	: V=1.04733617, theta=-26.5384921 -> V=1.022224, theta=0.0
% INFO    : Bus 2009	: V=1.06866032, theta=-2.38631097 -> V=1.0377785, theta=0.0
% INFO    : Bus 2010	: V=1.08895915, theta=-8.7248699 -> V=1.078945, theta=0.0
% INFO    : Bus 2011	: V=1.08887634, theta=-8.73985217 -> V=1.078945, theta=0.0
% INFO    : Bus 2012	: V=1.033, theta=-23.3267041 -> V=1.0000025, theta=0.0
% INFO    : Bus 2013	: V=1.037, theta=-23.0603372 -> V=1.0000025, theta=0.0
% INFO    : Bus 2014	: V=1.09520266, theta=-11.5284516 -> V=1.04724, theta=0.0
% INFO    : Bus 2015	: V=1.03427205, theta=-10.4014687 -> V=0.999999, theta=0.0
% INFO    : Bus 2016	: V=1.03179161, theta=-9.87817676 -> V=1.0158755, theta=0.0
% INFO    : Bus 2017	: V=1.0518262, theta=-24.8631663 -> V=1.046665, theta=0.0
% INFO    : Bus 2018	: V=1.02998285, theta=-24.2435029 -> V=1.027779, theta=0.0
% INFO    : Bus 2019	: V=0.999464317, theta=-20.0706592 -> V=1.015872, theta=0.0
% INFO    : Bus 2020	: V=1.01479948, theta=-30.912319 -> V=1.015872, theta=0.0
% INFO    : Bus 2021	: V=1.03171854, theta=-12.0557027 -> V=0.999999, theta=0.0
% INFO    : Bus 2022	: V=1.055, theta=-18.5148622 -> V=1.000001, theta=0.0
% INFO    : Bus 2023	: V=1.05004788, theta=-18.1477289 -> V=1.000001, theta=0.0
% INFO    : Bus 2024	: V=1.04022316, theta=-39.3873648 -> V=1.022224, theta=0.0
% INFO    : Bus 2025	: V=1.07013036, theta=-20.939547 -> V=1.022222, theta=0.0
% INFO    : Bus 2026	: V=1.02266555, theta=-45.0125632 -> V=1.022224, theta=0.0
% INFO    : Bus 2027	: V=1.05767234, theta=-16.4355045 -> V=1.000001, theta=0.0
% INFO    : Bus 2028	: V=1.04119774, theta=-41.1499079 -> V=1.022224, theta=0.0
% INFO    : Bus 2029	: V=1.03406122, theta=-22.1520873 -> V=1.0000025, theta=0.0
% INFO    : Bus 2030	: V=1.00979748, theta=-47.4187165 -> V=1.0079355, theta=0.0
% INFO    : Bus 2031	: V=1.06437285, theta=-22.7721692 -> V=1.0000025, theta=0.0
% INFO    : Bus 2032	: V=1.0492813, theta=-56.2738172 -> V=1.0079355, theta=0.0
% INFO    : Bus 2033	: V=1.01265618, theta=-22.0487975 -> V=1.0000025, theta=0.0
% INFO    : Bus 2034	: V=1.07443039, theta=-19.5070469 -> V=1.044445, theta=0.0
% INFO    : Bus 2035	: V=1.00142235, theta=-31.5183399 -> V=1.0000005, theta=0.0
% INFO    : Bus 2036	: V=1.05004695, theta=-21.9138776 -> V=1.0000025, theta=0.0
% INFO    : Bus 2037	: V=1.03915899, theta=-24.6386223 -> V=1.046665, theta=0.0
% INFO    : Bus 2038	: V=1.02932076, theta=-19.0638084 -> V=0.999999, theta=0.0
% INFO    : Bus 2039	: V=1.09385611, theta=-18.9844587 -> V=1.0, theta=0.0
% INFO    : Bus 2040	: V=1.05295707, theta=-13.6637262 -> V=1.033334, theta=0.0
% INFO    : Bus 2041	: V=1.02485162, theta=-5.30188754 -> V=1.0158755, theta=0.0
% INFO    : Bus 2042	: V=1.02316328, theta=-6.07731822 -> V=1.0158755, theta=0.0
% INFO    : Bus 2043	: V=1.05665224, theta=-1.28525912 -> V=1.0377785, theta=0.0
% INFO    : Bus 2044	: V=1.03, theta=-15.9961709 -> V=0.999999, theta=0.0
% INFO    : Bus 2045	: V=1.02080226, theta=-26.8768029 -> V=1.0000005, theta=0.0
% INFO    : Bus 2046	: V=1.01958997, theta=-28.0879417 -> V=1.0000005, theta=0.0
% INFO    : Bus 2047	: V=1.08024542, theta=-11.4434708 -> V=1.044445, theta=0.0
% INFO    : Bus 2048	: V=0.991287752, theta=-24.6582057 -> V=1.0158755, theta=0.0
% INFO    : Bus 2049	: V=1.07537051, theta=-20.8871803 -> V=1.04444, theta=0.0
% INFO    : Bus 2050	: V=1.07579602, theta=-14.8007418 -> V=1.07237, theta=0.0
% INFO    : Bus 2051	: V=1.01458043, theta=-31.4163598 -> V=1.015872, theta=0.0
% INFO    : Bus 2052	: V=1.0147595, theta=-31.4066774 -> V=1.015872, theta=0.0
% INFO    : Bus 2053	: V=1.01484152, theta=-31.4037297 -> V=1.015872, theta=0.0
% INFO    : Bus 2054	: V=1.02635041, theta=-22.7948635 -> V=1.0000025, theta=0.0
% INFO    : Bus 2055	: V=1.0911673, theta=-5.48262138 -> V=1.05263, theta=0.0
% INFO    : Bus 2056	: V=1.08952702, theta=-5.73662033 -> V=1.05263, theta=0.0
% INFO    : Bus 2057	: V=1.08931054, theta=-5.72946569 -> V=1.05263, theta=0.0
% INFO    : Bus 2058	: V=1.09074232, theta=-5.48255063 -> V=1.05263, theta=0.0
% INFO    : Bus 2059	: V=1.08921107, theta=-5.72042789 -> V=1.05263, theta=0.0
% INFO    : Bus 2060	: V=1.09124132, theta=-5.55367965 -> V=1.05263, theta=0.0
% INFO    : Bus 2061	: V=1.06431392, theta=-18.5351665 -> V=1.006954, theta=0.0
% INFO    : Bus 2062	: V=1.05728964, theta=-15.2240552 -> V=1.022222, theta=0.0
% INFO    : Bus 2063	: V=1.01792537, theta=-21.3196259 -> V=1.0158755, theta=0.0
% INFO    : Bus 2064	: V=0.982006757, theta=-24.309818 -> V=1.0000005, theta=0.0
% INFO    : Bus 2065	: V=1.04982183, theta=-7.24378806 -> V=1.0111115, theta=0.0
% INFO    : Bus 2066	: V=1.05964494, theta=-13.1478428 -> V=1.006059, theta=0.0
% INFO    : Bus 2067	: V=1.07263281, theta=-5.69075589 -> V=1.072365, theta=0.0
% INFO    : Bus 2068	: V=1.07259925, theta=-5.7838412 -> V=1.072365, theta=0.0
% INFO    : Bus 2069	: V=1.06586272, theta=-14.6498032 -> V=1.022222, theta=0.0
% INFO    : Bus 2070	: V=1.05472573, theta=-21.6614357 -> V=1.0000025, theta=0.0
% INFO    : Bus 2071	: V=1.0657426, theta=-18.5978258 -> V=1.044445, theta=0.0
% INFO    : Bus 2072	: V=1.00999872, theta=-25.0287019 -> V=1.022224, theta=0.0
% INFO    : Bus 2073	: V=1.01405463, theta=-24.3947542 -> V=1.022224, theta=0.0
% INFO    : Bus 2074	: V=1.05263888, theta=-24.1906174 -> V=1.046665, theta=0.0
% INFO    : Bus 2075	: V=1.05253868, theta=-24.299033 -> V=1.046665, theta=0.0
% INFO    : Bus 2076	: V=1.03376817, theta=-26.2797883 -> V=1.022224, theta=0.0
% INFO    : Bus 2077	: V=1.0491655, theta=-21.1003858 -> V=1.022224, theta=0.0
% INFO    : Bus 2078	: V=1.05050983, theta=-20.9899811 -> V=1.0000025, theta=0.0
% INFO    : Bus 2079	: V=1.03031926, theta=-12.1358266 -> V=1.015872, theta=0.0
% INFO    : Bus 2080	: V=1.05660353, theta=-9.27574263 -> V=1.046665, theta=0.0
% INFO    : Bus 2081	: V=1.05247605, theta=-12.714254 -> V=1.0377785, theta=0.0
% INFO    : Bus 2082	: V=1.06269007, theta=-9.23337259 -> V=1.072365, theta=0.0
% INFO    : Bus 2083	: V=1.01242697, theta=-31.6111756 -> V=1.015872, theta=0.0
% INFO    : Bus 2084	: V=1.04197572, theta=-30.6340847 -> V=1.027779, theta=0.0
% INFO    : Bus 2085	: V=1.0330212, theta=-39.7851554 -> V=1.022224, theta=0.0
% INFO    : Bus 2086	: V=1.08266611, theta=-18.4094385 -> V=1.033333, theta=0.0
% INFO    : Bus 2087	: V=1.04918454, theta=-15.3059579 -> V=1.0000005, theta=0.0
% INFO    : Bus 2088	: V=1.04879735, theta=-14.2178535 -> V=1.0000005, theta=0.0
% INFO    : Bus 2089	: V=1.03514219, theta=-5.04491169 -> V=1.0158755, theta=0.0
% INFO    : Bus 2090	: V=1.07165417, theta=-2.20638067 -> V=1.0377785, theta=0.0
% INFO    : Bus 2091	: V=1.01737357, theta=-52.8920801 -> V=1.0079355, theta=0.0
% INFO    : Bus 2092	: V=1.058, theta=-15.6403219 -> V=1.022222, theta=0.0
% INFO    : Bus 2093	: V=1.0156316, theta=-43.8513886 -> V=1.0079355, theta=0.0
% INFO    : Bus 2094	: V=1.07459259, theta=-18.8485948 -> V=1.000001, theta=0.0
% INFO    : Bus 2095	: V=1.03538727, theta=-46.676606 -> V=1.022224, theta=0.0
% INFO    : Bus 2096	: V=1.029, theta=-57.8960368 -> V=1.0079355, theta=0.0
% INFO    : Bus 2097	: V=1.03871437, theta=-38.2240176 -> V=1.0079355, theta=0.0
% INFO    : Bus 2098	: V=1.08047413, theta=-34.3506557 -> V=1.04444, theta=0.0
% INFO    : Bus 2099	: V=1.02150541, theta=-44.6699342 -> V=1.022224, theta=0.0
% INFO    : Bus 2100	: V=1.06743986, theta=-26.5842048 -> V=1.046665, theta=0.0
% INFO    : Bus 2101	: V=1.04436573, theta=-18.2662085 -> V=1.0158755, theta=0.0
% INFO    : Bus 2102	: V=1.04410571, theta=-18.2076609 -> V=1.0158755, theta=0.0
% INFO    : Bus 2103	: V=1.04415807, theta=-18.1987686 -> V=1.0158755, theta=0.0
% INFO    : Bus 2104	: V=1.0442255, theta=-18.1973635 -> V=1.0158755, theta=0.0
% INFO    : Bus 2105	: V=1.04420694, theta=-18.1910397 -> V=1.0158755, theta=0.0
% INFO    : Bus 2106	: V=1.04645241, theta=-15.1788001 -> V=1.0377785, theta=0.0
% INFO    : Bus 2107	: V=1.02965376, theta=-51.3454544 -> V=1.0079355, theta=0.0
% INFO    : Bus 2108	: V=1.02775097, theta=-26.2753734 -> V=1.0000025, theta=0.0
% INFO    : Bus 2109	: V=1.00515831, theta=-53.2508617 -> V=1.0079355, theta=0.0
% INFO    : Bus 2110	: V=1.01328662, theta=-14.282036 -> V=1.0158755, theta=0.0
% INFO    : Bus 2111	: V=1.04300335, theta=-16.4170331 -> V=1.0000025, theta=0.0
% INFO    : Bus 2112	: V=1.01852536, theta=-12.3929803 -> V=0.999999, theta=0.0
% INFO    : Bus 2113	: V=1.04977036, theta=-10.1483753 -> V=0.975, theta=0.0
% INFO    : Bus 2114	: V=0.978599237, theta=-24.061121 -> V=1.015872, theta=0.0
% INFO    : Bus 2115	: V=1.03213311, theta=-24.7150268 -> V=1.0000005, theta=0.0
% INFO    : Bus 2116	: V=1.02045646, theta=-51.635564 -> V=1.0079355, theta=0.0
% INFO    : Bus 2117	: V=1.02361305, theta=-7.42812327 -> V=1.0158755, theta=0.0
% INFO    : Bus 2118	: V=1.05950388, theta=-24.5586654 -> V=1.0000025, theta=0.0
% INFO    : Bus 2119	: V=1.05540428, theta=-19.856943 -> V=1.044445, theta=0.0
% INFO    : Bus 2120	: V=1.02470986, theta=-19.4225133 -> V=1.0158755, theta=0.0
% INFO    : Bus 2121	: V=1.04332501, theta=-10.8433907 -> V=0.999999, theta=0.0
% INFO    : Bus 2122	: V=1.03986822, theta=-11.9884833 -> V=0.999999, theta=0.0
% INFO    : Bus 2123	: V=1.05052909, theta=-7.48960753 -> V=1.0111115, theta=0.0
% INFO    : Bus 2124	: V=1.05057764, theta=-7.48769729 -> V=1.0111115, theta=0.0
% INFO    : Bus 2125	: V=1.05053106, theta=-7.4896234 -> V=1.0111115, theta=0.0
% INFO    : Bus 2126	: V=1.07538053, theta=-17.6698653 -> V=1.022222, theta=0.0
% INFO    : Bus 2127	: V=1.0688211, theta=-12.2890927 -> V=1.0266685, theta=0.0
% INFO    : Bus 2128	: V=1.06423628, theta=-12.219432 -> V=1.022223, theta=0.0
% INFO    : Bus 2129	: V=1.00599707, theta=-18.4374259 -> V=1.0158755, theta=0.0
% INFO    : Bus 2130	: V=0.953116538, theta=-7.68606776 -> V=0.9444445, theta=0.0
% INFO    : Bus 2131	: V=1.02614166, theta=-9.99780407 -> V=0.999999, theta=0.0
% INFO    : Bus 2132	: V=1.04622416, theta=-6.09440689 -> V=1.0111115, theta=0.0
% INFO    : Bus 2133	: V=1.06396644, theta=-11.2144162 -> V=0.9888895, theta=0.0
% INFO    : Bus 2134	: V=1.07599976, theta=-9.37496757 -> V=0.9893745, theta=0.0
% INFO    : Bus 2135	: V=1.02661513, theta=-2.74606648 -> V=1.0158755, theta=0.0
% INFO    : Bus 2136	: V=1.04482692, theta=-22.3298932 -> V=1.027779, theta=0.0
% INFO    : Bus 2137	: V=1.07549363, theta=-21.1839532 -> V=1.046665, theta=0.0
% INFO    : Bus 2138	: V=1.06824258, theta=-19.2330823 -> V=1.04444, theta=0.0
% INFO    : Bus 2139	: V=1.05261382, theta=-19.7497139 -> V=1.04444, theta=0.0
% INFO    : Bus 2140	: V=1.00856383, theta=-19.9326524 -> V=1.015872, theta=0.0
% INFO    : Bus 2141	: V=1.046566, theta=-10.5489784 -> V=0.999999, theta=0.0
% INFO    : Bus 2142	: V=1.05374129, theta=-7.21516454 -> V=1.0111115, theta=0.0
% INFO    : Bus 2143	: V=1.07293887, theta=-3.76822817 -> V=1.072365, theta=0.0
% INFO    : Bus 2144	: V=1.0370091, theta=-43.8128702 -> V=1.022224, theta=0.0
% INFO    : Bus 2145	: V=1.04331353, theta=-33.9318696 -> V=1.022224, theta=0.0
% INFO    : Bus 2146	: V=1.05069909, theta=-7.08208588 -> V=1.0158755, theta=0.0
% INFO    : Bus 2147	: V=1.0104002, theta=-15.6805761 -> V=1.0158755, theta=0.0
% INFO    : Bus 2148	: V=1.0142656, theta=-23.1083685 -> V=1.0000025, theta=0.0
% INFO    : Bus 2149	: V=1.04644026, theta=-4.92810745 -> V=1.0158755, theta=0.0
% INFO    : Bus 2150	: V=1.03456879, theta=-12.5754544 -> V=1.0158755, theta=0.0
% INFO    : Bus 2151	: V=1.0327166, theta=-25.7309613 -> V=1.0000025, theta=0.0
% INFO    : Bus 2152	: V=1.03615864, theta=-40.408151 -> V=1.022224, theta=0.0
% INFO    : Bus 2153	: V=1.01297292, theta=-25.134616 -> V=1.0000005, theta=0.0
% INFO    : Bus 2154	: V=1.066, theta=-22.5801732 -> V=1.027779, theta=0.0
% INFO    : Bus 2155	: V=1.06502279, theta=-22.5851977 -> V=1.027779, theta=0.0
% INFO    : Bus 2156	: V=1.08127199, theta=-19.2105121 -> V=1.04858, theta=0.0
% INFO    : Bus 2157	: V=1.08119303, theta=-34.0761005 -> V=1.04444, theta=0.0
% INFO    : Bus 2158	: V=1.022, theta=-27.5805928 -> V=1.0000005, theta=0.0
% INFO    : Bus 2159	: V=1.06418868, theta=-13.3819655 -> V=1.033333, theta=0.0
% INFO    : Bus 2160	: V=1.0682943, theta=-10.6863339 -> V=1.0288895, theta=0.0
% INFO    : Bus 2161	: V=1.04479711, theta=-12.0968013 -> V=0.999999, theta=0.0
% INFO    : Bus 2162	: V=1.04460374, theta=-12.1237869 -> V=0.999999, theta=0.0
% INFO    : Bus 2163	: V=1.04459623, theta=-12.1656477 -> V=0.999999, theta=0.0
% INFO    : Bus 2164	: V=1.03148431, theta=-13.8141705 -> V=0.999999, theta=0.0
% INFO    : Bus 2165	: V=1.02909948, theta=-25.1555214 -> V=1.0000025, theta=0.0
% INFO    : Bus 2166	: V=1.07453018, theta=-5.32321442 -> V=1.0162055, theta=0.0
% INFO    : Bus 2167	: V=1.0299567, theta=-6.2286713 -> V=1.0158755, theta=0.0
% INFO    : Bus 2168	: V=1.04394803, theta=-2.13268216 -> V=1.0377785, theta=0.0
% INFO    : Bus 2169	: V=1.04359105, theta=-2.12795826 -> V=1.0377785, theta=0.0
% INFO    : Bus 2170	: V=1.05650972, theta=-27.2148046 -> V=1.027779, theta=0.0
% INFO    : Bus 2171	: V=1.02288188, theta=-6.44317075 -> V=1.0158755, theta=0.0
% INFO    : Bus 2172	: V=1.02288188, theta=-6.44317075 -> V=1.0158755, theta=0.0
% INFO    : Bus 2173	: V=1.06327454, theta=-24.9571402 -> V=1.046665, theta=0.0
% INFO    : Bus 2174	: V=1.01957079, theta=1.24547043 -> V=1.0158755, theta=0.0
% INFO    : Bus 2175	: V=1.05050674, theta=-23.1693419 -> V=1.0000025, theta=0.0
% INFO    : Bus 2176	: V=1.05206352, theta=-14.7356596 -> V=0.9888895, theta=0.0
% INFO    : Bus 2177	: V=1.05216762, theta=-14.730133 -> V=0.9888895, theta=0.0
% INFO    : Bus 2178	: V=1.00096065, theta=-29.2222737 -> V=1.0000005, theta=0.0
% INFO    : Bus 2179	: V=1.06881554, theta=-26.4198302 -> V=1.046665, theta=0.0
% INFO    : Bus 2180	: V=1.05134488, theta=-24.3549113 -> V=1.027779, theta=0.0
% INFO    : Bus 2181	: V=1.00096204, theta=-29.2222817 -> V=1.0000005, theta=0.0
% INFO    : Bus 2182	: V=1.03377832, theta=-32.6213823 -> V=1.0035055, theta=0.0
% INFO    : Bus 2183	: V=1.02207606, theta=-27.4861178 -> V=0.9682545, theta=0.0
% INFO    : Bus 2184	: V=1.03530654, theta=-25.9052156 -> V=1.0000025, theta=0.0
% INFO    : Bus 2185	: V=1.06566897, theta=-18.1154621 -> V=1.022222, theta=0.0
% INFO    : Bus 2186	: V=0.965, theta=-8.09912076 -> V=0.9444445, theta=0.0
% INFO    : Bus 2187	: V=1.02731104, theta=-15.9671581 -> V=0.999999, theta=0.0
% INFO    : Bus 2188	: V=1.068, theta=-16.9297703 -> V=1.000001, theta=0.0
% INFO    : Bus 2189	: V=0.989709149, theta=-12.0053265 -> V=1.0000015, theta=0.0
% INFO    : Bus 2190	: V=1.07917791, theta=-20.0608499 -> V=1.046875, theta=0.0
% INFO    : Bus 2191	: V=1.0833292, theta=-18.3106948 -> V=1.073685, theta=0.0
% INFO    : Bus 2192	: V=1.07920091, theta=-20.0389406 -> V=1.04688, theta=0.0
% INFO    : Bus 2193	: V=1.07915964, theta=-20.0604862 -> V=1.04687, theta=0.0
% INFO    : Bus 2194	: V=1.08332689, theta=-18.3109341 -> V=1.073685, theta=0.0
% INFO    : Bus 2195	: V=1.04892291, theta=-4.77775405 -> V=0.984126, theta=0.0
% INFO    : Bus 2196	: V=1.07540195, theta=-19.6098283 -> V=1.022222, theta=0.0
% INFO    : Bus 2197	: V=1.02981318, theta=-40.1386425 -> V=1.0079355, theta=0.0
% INFO    : Bus 2198	: V=1.02406089, theta=-14.3435553 -> V=1.015872, theta=0.0
% INFO    : Bus 2199	: V=1.05408959, theta=-14.3836918 -> V=0.9888895, theta=0.0
% INFO    : Bus 2200	: V=1.02435197, theta=-3.51723797 -> V=1.0158755, theta=0.0
% INFO    : Bus 2201	: V=1.05962746, theta=-19.7453945 -> V=1.022222, theta=0.0
% INFO    : Bus 2202	: V=0.989234323, theta=-25.9722501 -> V=1.0000025, theta=0.0
% INFO    : Bus 2203	: V=1.05727761, theta=-20.6023472 -> V=1.022222, theta=0.0
% INFO    : Bus 2204	: V=1.0092795, theta=-15.5495883 -> V=1.0079355, theta=0.0
% INFO    : Bus 2205	: V=1.02374951, theta=-44.2051781 -> V=1.0079355, theta=0.0
% INFO    : Bus 2206	: V=1.02922499, theta=-26.7908962 -> V=1.0000025, theta=0.0
% INFO    : Bus 2207	: V=1.03719084, theta=-41.2066861 -> V=1.022224, theta=0.0
% INFO    : Bus 2208	: V=1.00550063, theta=-33.3432905 -> V=1.0000005, theta=0.0
% INFO    : Bus 2209	: V=1.07330908, theta=-27.3841237 -> V=1.046665, theta=0.0
% INFO    : Bus 2210	: V=1.07206177, theta=-27.4698352 -> V=1.046665, theta=0.0
% INFO    : Bus 2211	: V=1.05254182, theta=-10.7967934 -> V=1.0158755, theta=0.0
% INFO    : Bus 2212	: V=1.0438231, theta=-11.2824709 -> V=1.0158755, theta=0.0
% INFO    : Bus 2213	: V=1.01163496, theta=-6.60143331 -> V=1.0158755, theta=0.0
% INFO    : Bus 2214	: V=1.04247302, theta=-42.0624994 -> V=1.022224, theta=0.0
% INFO    : Bus 2215	: V=1.04183892, theta=-5.35098432 -> V=1.0111115, theta=0.0
% INFO    : Bus 2216	: V=1.02285843, theta=-6.44245313 -> V=1.0158755, theta=0.0
% INFO    : Bus 2217	: V=1.05579004, theta=-1.49446651 -> V=1.0377785, theta=0.0
% INFO    : Bus 2218	: V=1.06231105, theta=-17.0857566 -> V=1.073685, theta=0.0
% INFO    : Bus 2219	: V=1.05538415, theta=-23.1920639 -> V=1.022222, theta=0.0
% INFO    : Bus 2220	: V=1.01171452, theta=-6.5984965 -> V=1.0158755, theta=0.0
% INFO    : Bus 2221	: V=1.05056788, theta=-6.874209 -> V=1.0158755, theta=0.0
% INFO    : Bus 2222	: V=1.07876487, theta=-4.19871142 -> V=1.0377785, theta=0.0
% INFO    : Bus 2223	: V=1.03794691, theta=-16.300367 -> V=1.0000025, theta=0.0
% INFO    : Bus 2224	: V=1.03747826, theta=-26.8328296 -> V=1.0000025, theta=0.0
% INFO    : Bus 2225	: V=1.01689912, theta=-6.45706501 -> V=1.0158755, theta=0.0
% INFO    : Bus 2226	: V=1.05740776, theta=-15.1603434 -> V=1.033333, theta=0.0
% INFO    : Bus 2227	: V=1.06229608, theta=-12.4520373 -> V=1.0288895, theta=0.0
% INFO    : Bus 2228	: V=1.01855601, theta=-6.59088422 -> V=1.0158755, theta=0.0
% INFO    : Bus 2229	: V=1.06464008, theta=-16.7279241 -> V=1.015874, theta=0.0
% INFO    : Bus 2230	: V=1.0638672, theta=-14.6360723 -> V=1.033333, theta=0.0
% INFO    : Bus 2231	: V=1.03597448, theta=-14.1648788 -> V=0.999999, theta=0.0
% INFO    : Bus 2232	: V=1.06306167, theta=-12.4407784 -> V=0.9888895, theta=0.0
% INFO    : Bus 2233	: V=1.03558524, theta=-27.1151755 -> V=1.0000025, theta=0.0
% INFO    : Bus 2234	: V=0.869242829, theta=-23.0153511 -> V=0.83, theta=0.0
% INFO    : Bus 2235	: V=1.08654137, theta=-23.0149719 -> V=1.044445, theta=0.0
% INFO    : Bus 2236	: V=1.04697718, theta=-22.0184146 -> V=1.0000025, theta=0.0
% INFO    : Bus 2237	: V=1.05398837, theta=-23.3923542 -> V=1.022224, theta=0.0
% INFO    : Bus 2238	: V=1.01557879, theta=-8.29745497 -> V=1.0158755, theta=0.0
% INFO    : Bus 2239	: V=1.08723784, theta=1.96030797 -> V=1.072365, theta=0.0
% INFO    : Bus 2240	: V=1.077, theta=-21.4478071 -> V=0.975, theta=0.0
% INFO    : Bus 2241	: V=1.04088184, theta=-21.5392039 -> V=1.0000025, theta=0.0
% INFO    : Bus 2242	: V=1.07065119, theta=-19.5665246 -> V=1.044445, theta=0.0
% INFO    : Bus 2243	: V=1.05454163, theta=-23.1110344 -> V=1.0000025, theta=0.0
% INFO    : Bus 2244	: V=1.05450206, theta=-28.1723361 -> V=1.027779, theta=0.0
% INFO    : Bus 2245	: V=1.01350404, theta=-6.41377894 -> V=1.0158755, theta=0.0
% INFO    : Bus 2246	: V=1.07035404, theta=-16.6189337 -> V=1.015874, theta=0.0
% INFO    : Bus 2247	: V=1.02799128, theta=-27.6546609 -> V=1.015872, theta=0.0
% INFO    : Bus 2248	: V=1.03973506, theta=-22.5870889 -> V=1.046665, theta=0.0
% INFO    : Bus 2249	: V=1.05574154, theta=-25.9871193 -> V=1.046665, theta=0.0
% INFO    : Bus 2250	: V=1.02268033, theta=-13.9647458 -> V=1.0158755, theta=0.0
% INFO    : Bus 2251	: V=1.08102518, theta=-19.0570763 -> V=1.048545, theta=0.0
% INFO    : Bus 2252	: V=1.08043382, theta=-19.4236201 -> V=1.04828, theta=0.0
% INFO    : Bus 2253	: V=1.0256718, theta=1.91685704 -> V=1.0158755, theta=0.0
% INFO    : Bus 2254	: V=1.01680213, theta=-1.27168253 -> V=1.0158755, theta=0.0
% INFO    : Bus 2255	: V=1.06480241, theta=-19.0941095 -> V=1.033333, theta=0.0
% INFO    : Bus 2256	: V=1.0314735, theta=-19.3679752 -> V=1.0158755, theta=0.0
% INFO    : Bus 2257	: V=1.00999774, theta=-17.1969393 -> V=1.0, theta=0.0
% INFO    : Bus 2258	: V=1.04833839, theta=-14.6478899 -> V=1.0377785, theta=0.0
% INFO    : Bus 2259	: V=1.05598321, theta=-30.2234393 -> V=1.027779, theta=0.0
% INFO    : Bus 2260	: V=1.04613452, theta=-4.31368806 -> V=0.984126, theta=0.0
% INFO    : Bus 2261	: V=1.11487072, theta=3.81327725 -> V=1.0379605, theta=0.0
% INFO    : Bus 2262	: V=1.02192358, theta=2.01241566 -> V=1.0158755, theta=0.0
% INFO    : Bus 2263	: V=1.07584965, theta=3.81327725 -> V=1.0377785, theta=0.0
% INFO    : Bus 2264	: V=1.0045169, theta=-28.5330211 -> V=1.0000025, theta=0.0
% INFO    : Bus 2265	: V=1.06559927, theta=-19.0380461 -> V=1.016666, theta=0.0
% INFO    : Bus 2266	: V=1.05261055, theta=-14.665957 -> V=1.006667, theta=0.0
% INFO    : Bus 2267	: V=1.0176338, theta=-6.9811855 -> V=1.0158755, theta=0.0
% INFO    : Bus 2268	: V=1.06566897, theta=-18.1154621 -> V=1.022222, theta=0.0
% INFO    : Bus 2269	: V=1.03322474, theta=-3.016422 -> V=1.0158755, theta=0.0
% INFO    : Bus 2270	: V=1.02243396, theta=-16.0272097 -> V=1.0158755, theta=0.0
% INFO    : Bus 2271	: V=1.0357736, theta=-42.0420296 -> V=1.0079355, theta=0.0
% INFO    : Bus 2272	: V=1.03363962, theta=-26.3389493 -> V=1.022224, theta=0.0
% INFO    : Bus 2273	: V=1.03023892, theta=-7.37587504 -> V=1.0158755, theta=0.0
% INFO    : Bus 2274	: V=1.02092079, theta=0.188780402 -> V=1.0158755, theta=0.0
% INFO    : Bus 2275	: V=1.01760519, theta=4.48587918 -> V=1.013331, theta=0.0
% INFO    : Bus 2276	: V=1.0142139, theta=4.26899436 -> V=1.013331, theta=0.0
% INFO    : Bus 2277	: V=1.02280781, theta=1.99136513 -> V=1.0158755, theta=0.0
% INFO    : Bus 2278	: V=1.04849486, theta=-14.2511418 -> V=0.9888895, theta=0.0
% INFO    : Bus 2279	: V=1.0543112, theta=-30.8138877 -> V=1.027779, theta=0.0
% INFO    : Bus 2280	: V=1.02107489, theta=-27.0676731 -> V=1.015872, theta=0.0
% INFO    : Bus 2281	: V=1.05185914, theta=-23.4963119 -> V=1.0000025, theta=0.0
% INFO    : Bus 2282	: V=1.034522, theta=-24.9143041 -> V=1.0000025, theta=0.0
% INFO    : Bus 2283	: V=1.07836267, theta=-14.8161064 -> V=1.078945, theta=0.0
% INFO    : Bus 2284	: V=1.04575375, theta=-38.1527967 -> V=1.022224, theta=0.0
% INFO    : Bus 2285	: V=1.04522182, theta=-17.5005734 -> V=0.999999, theta=0.0
% INFO    : Bus 2286	: V=1.04013226, theta=-14.6462617 -> V=1.0111115, theta=0.0
% INFO    : Bus 2287	: V=1.02511817, theta=-31.2893697 -> V=1.0000005, theta=0.0
% INFO    : Bus 2288	: V=1.00096297, theta=-29.2223235 -> V=1.0000005, theta=0.0
% INFO    : Bus 2289	: V=1.00378726, theta=-29.0772953 -> V=1.0000005, theta=0.0
% INFO    : Bus 2290	: V=1.014, theta=-27.5549382 -> V=1.0000005, theta=0.0
% INFO    : Bus 2291	: V=1.05725888, theta=-12.916066 -> V=1.006094, theta=0.0
% INFO    : Bus 2292	: V=1.05096236, theta=-9.32149555 -> V=1.0111115, theta=0.0
% INFO    : Bus 2293	: V=1.01664999, theta=-24.1544843 -> V=1.0000025, theta=0.0
% INFO    : Bus 2294	: V=1.04326609, theta=-10.1683775 -> V=0.999999, theta=0.0
% INFO    : Bus 2295	: V=1.02665448, theta=-28.5347554 -> V=1.0000025, theta=0.0
% INFO    : Bus 2296	: V=1.02714315, theta=-12.9571774 -> V=1.0158755, theta=0.0
% INFO    : Bus 2297	: V=1.04281285, theta=-32.7321687 -> V=1.022224, theta=0.0
% INFO    : Bus 2298	: V=1.03919187, theta=-29.3336186 -> V=1.0000025, theta=0.0
% INFO    : Bus 2299	: V=1.02925097, theta=-28.9137956 -> V=1.022224, theta=0.0
% INFO    : Bus 2300	: V=1.01598536, theta=-56.2627876 -> V=1.0079355, theta=0.0
% INFO    : Bus 2301	: V=1.03245124, theta=-6.21989774 -> V=1.0158755, theta=0.0
% INFO    : Bus 2302	: V=1.08163272, theta=-3.38655295 -> V=1.0377785, theta=0.0
% INFO    : Bus 2303	: V=1.02233967, theta=-26.7517392 -> V=1.015872, theta=0.0
% INFO    : Bus 2304	: V=1.04638928, theta=-26.0296414 -> V=1.0000025, theta=0.0
% INFO    : Bus 2305	: V=1.03484257, theta=-10.7478092 -> V=0.999999, theta=0.0
% INFO    : Bus 2306	: V=1.04346544, theta=-9.62904301 -> V=1.0111115, theta=0.0
% INFO    : Bus 2307	: V=1.03518927, theta=-25.3303958 -> V=1.0000025, theta=0.0
% INFO    : Bus 2308	: V=1.06732444, theta=-21.4794717 -> V=1.044445, theta=0.0
% INFO    : Bus 2309	: V=1.03080744, theta=-10.677725 -> V=0.999999, theta=0.0
% INFO    : Bus 2310	: V=1.0324875, theta=-41.7674292 -> V=1.022224, theta=0.0
% INFO    : Bus 2311	: V=1.02540748, theta=-29.1949804 -> V=1.015872, theta=0.0
% INFO    : Bus 2312	: V=1.02726583, theta=-16.2041431 -> V=1.015872, theta=0.0
% INFO    : Bus 2313	: V=1.03327772, theta=-26.6439438 -> V=1.022224, theta=0.0
% INFO    : Bus 2314	: V=1.03953414, theta=-25.5623225 -> V=1.0000025, theta=0.0
% INFO    : Bus 2315	: V=1.05788981, theta=-27.3700296 -> V=1.022224, theta=0.0
% INFO    : Bus 2316	: V=1.03994225, theta=-30.5222683 -> V=1.022224, theta=0.0
% INFO    : Bus 2317	: V=1.0327334, theta=-21.1300265 -> V=1.022224, theta=0.0
% INFO    : Bus 2318	: V=1.06856888, theta=-26.435568 -> V=1.046665, theta=0.0
% INFO    : Bus 2319	: V=1.06858473, theta=-26.4459123 -> V=1.046665, theta=0.0
% INFO    : Bus 2320	: V=1.04193199, theta=-5.68820675 -> V=1.0158755, theta=0.0
% INFO    : Bus 2321	: V=1.06842329, theta=-2.44743775 -> V=1.0377785, theta=0.0
% INFO    : Bus 2322	: V=1.03333769, theta=-10.4339492 -> V=1.0158755, theta=0.0
% INFO    : Bus 2323	: V=1.04120217, theta=-23.1933264 -> V=1.0000025, theta=0.0
% INFO    : Bus 2324	: V=1.01717182, theta=-30.3102202 -> V=1.0000005, theta=0.0
% INFO    : Bus 2325	: V=1.0199979, theta=-15.7701155 -> V=1.015872, theta=0.0
% INFO    : Bus 2326	: V=1.0310988, theta=-15.4766555 -> V=1.015872, theta=0.0
% INFO    : Bus 2327	: V=1.03277972, theta=-17.1442377 -> V=1.015872, theta=0.0
% INFO    : Bus 2328	: V=1.03022287, theta=-16.433803 -> V=1.015872, theta=0.0
% INFO    : Bus 2329	: V=1.04645203, theta=-11.2684032 -> V=1.046665, theta=0.0
% INFO    : Bus 2330	: V=1.05749123, theta=-3.91902883 -> V=1.077185, theta=0.0
% INFO    : Bus 2331	: V=1.05369835, theta=-26.2105598 -> V=1.022224, theta=0.0
% INFO    : Bus 2332	: V=1.0410721, theta=-50.1957638 -> V=1.0079355, theta=0.0
% INFO    : Bus 2333	: V=1.02131472, theta=-0.480548303 -> V=1.0158755, theta=0.0
% INFO    : Bus 2334	: V=0.988, theta=-18.2204905 -> V=1.015872, theta=0.0
% INFO    : Bus 2335	: V=1.05521461, theta=-18.2879613 -> V=1.0000025, theta=0.0
% INFO    : Bus 2336	: V=1.02928086, theta=-28.9146275 -> V=1.022224, theta=0.0
% INFO    : Bus 2337	: V=1.03307757, theta=-15.5416225 -> V=0.999999, theta=0.0
% INFO    : Bus 2338	: V=1.03807943, theta=-14.2982992 -> V=0.999999, theta=0.0
% INFO    : Bus 2339	: V=1.04491767, theta=-10.5853613 -> V=1.0111115, theta=0.0
% INFO    : Bus 2340	: V=1.01495719, theta=-27.9765468 -> V=1.0158755, theta=0.0
% INFO    : Bus 2341	: V=1.03520164, theta=-30.6527241 -> V=1.027779, theta=0.0
% INFO    : Bus 2342	: V=1.02061565, theta=-24.8641412 -> V=1.027779, theta=0.0
% INFO    : Bus 2343	: V=1.06841708, theta=-20.2653436 -> V=1.04444, theta=0.0
% INFO    : Bus 2344	: V=1.07893105, theta=-18.9602886 -> V=1.07237, theta=0.0
% INFO    : Bus 2345	: V=1.07905351, theta=-18.936754 -> V=1.07237, theta=0.0
% INFO    : Bus 2346	: V=1.02165064, theta=1.37411333 -> V=1.0158755, theta=0.0
% INFO    : Bus 2347	: V=1.05399732, theta=-21.429858 -> V=1.000001, theta=0.0
% INFO    : Bus 2348	: V=1.05568146, theta=-17.4137796 -> V=1.000001, theta=0.0
% INFO    : Bus 2349	: V=1.03425762, theta=-13.8728435 -> V=1.0158755, theta=0.0
% INFO    : Bus 2350	: V=1.05901343, theta=-19.0868242 -> V=1.022224, theta=0.0
% INFO    : Bus 2351	: V=1.02793856, theta=-26.8648577 -> V=1.0000025, theta=0.0
% INFO    : Bus 2352	: V=1.03931066, theta=-24.6076614 -> V=1.022224, theta=0.0
% INFO    : Bus 2353	: V=1.01239195, theta=-31.1267623 -> V=1.022224, theta=0.0
% INFO    : Bus 2354	: V=1.02560026, theta=-43.2433548 -> V=1.0079355, theta=0.0
% INFO    : Bus 2355	: V=1.04430741, theta=-30.5753456 -> V=1.022224, theta=0.0
% INFO    : Bus 2356	: V=1.02533388, theta=-5.93188272 -> V=1.0158755, theta=0.0
% INFO    : Bus 2357	: V=1.101, theta=-0.886845437 -> V=0.975, theta=0.0
% INFO    : Bus 2358	: V=1.101, theta=-0.930984682 -> V=0.975, theta=0.0
% INFO    : Bus 2359	: V=1.084, theta=-1.60690459 -> V=0.975, theta=0.0
% INFO    : Bus 2360	: V=1.102, theta=-1.1589136 -> V=0.975, theta=0.0
% INFO    : Bus 2361	: V=1.104, theta=-1.38647877 -> V=0.975, theta=0.0
% INFO    : Bus 2362	: V=1.08686061, theta=-2.83188994 -> V=1.0377785, theta=0.0
% INFO    : Bus 2363	: V=1.08686492, theta=-2.83156076 -> V=1.0377785, theta=0.0
% INFO    : Bus 2364	: V=1.08675706, theta=-2.83674188 -> V=1.0377785, theta=0.0
% INFO    : Bus 2365	: V=1.08686864, theta=-2.83361877 -> V=1.0377785, theta=0.0
% INFO    : Bus 2366	: V=1.08677916, theta=-2.84454694 -> V=1.0377785, theta=0.0
% INFO    : Bus 2367	: V=1.0868826, theta=-2.83505015 -> V=1.0377785, theta=0.0
% INFO    : Bus 2368	: V=1.02754334, theta=-5.15457658 -> V=1.0158755, theta=0.0
% INFO    : Bus 2369	: V=1.08677916, theta=-2.84454694 -> V=1.0377785, theta=0.0
% INFO    : Bus 2370	: V=1.03372424, theta=-53.3485999 -> V=1.0079355, theta=0.0
% INFO    : Bus 2371	: V=1.01973053, theta=1.41043315 -> V=1.0158755, theta=0.0
% INFO    : Bus 2372	: V=1.03882647, theta=-52.8232848 -> V=1.0079355, theta=0.0
% INFO    : Bus 2373	: V=1.01464, theta=-57.4840996 -> V=1.0079355, theta=0.0
% INFO    : Bus 2374	: V=1.0117476, theta=-60.0852803 -> V=1.0079355, theta=0.0
% INFO    : Bus 2375	: V=1.03285618, theta=-53.3635255 -> V=1.0079355, theta=0.0
% INFO    : Bus 2376	: V=1.04776458, theta=-52.9417171 -> V=1.0079355, theta=0.0
% INFO    : Bus 2377	: V=1.01364817, theta=-52.3298671 -> V=1.0079355, theta=0.0
% INFO    : Bus 2378	: V=1.02266065, theta=-53.6242791 -> V=1.0079355, theta=0.0
% INFO    : Bus 2379	: V=1.00869967, theta=-51.7508402 -> V=1.0079355, theta=0.0
% INFO    : Bus 2380	: V=1.01025358, theta=-18.8993067 -> V=1.0158755, theta=0.0
% INFO    : Bus 2381	: V=0.982390152, theta=-47.8957144 -> V=1.0079355, theta=0.0
% INFO    : Bus 2382	: V=1.01930744, theta=-5.88915746 -> V=1.0158755, theta=0.0
% INFO    : Bus 2383	: V=1.04619425, theta=-24.4678372 -> V=1.0000025, theta=0.0
% INFO    : Bus 2384	: V=1.04196209, theta=-24.2035761 -> V=1.0000025, theta=0.0
% INFO    : Bus 2385	: V=1.04193814, theta=-24.205047 -> V=1.0000025, theta=0.0
% INFO    : Bus 2386	: V=1.01202928, theta=-23.1100825 -> V=1.0000025, theta=0.0
% INFO    : Bus 2387	: V=1.02984796, theta=-22.322803 -> V=1.0000025, theta=0.0
% INFO    : Bus 2388	: V=1.04293358, theta=-26.0967728 -> V=1.0000025, theta=0.0
% INFO    : Bus 2389	: V=1.0145769, theta=-22.8938546 -> V=1.0000025, theta=0.0
% INFO    : Bus 2390	: V=1.01712775, theta=-21.4450779 -> V=1.0000025, theta=0.0
% INFO    : Bus 2391	: V=1.04400761, theta=-20.5161889 -> V=0.999999, theta=0.0
% INFO    : Bus 2392	: V=1.04134336, theta=-26.7854097 -> V=1.0000025, theta=0.0
% INFO    : Bus 2393	: V=1.0636505, theta=-7.57770485 -> V=1.046665, theta=0.0
% INFO    : Bus 2394	: V=1.05767819, theta=-29.5310493 -> V=1.0000025, theta=0.0
% INFO    : Bus 2395	: V=1.05847155, theta=-5.10543009 -> V=1.046665, theta=0.0
% INFO    : Bus 2396	: V=1.05847523, theta=-5.10502166 -> V=1.046665, theta=0.0
% INFO    : Bus 2397	: V=1.01056784, theta=-31.489366 -> V=1.0000025, theta=0.0
% INFO    : Bus 2398	: V=1.05450194, theta=-34.7779 -> V=1.027779, theta=0.0
% INFO    : Bus 2399	: V=1.02374503, theta=-29.0676498 -> V=1.0000025, theta=0.0
% INFO    : Bus 2400	: V=1.06127836, theta=-27.7085011 -> V=1.0000025, theta=0.0
% INFO    : Bus 2401	: V=1.06097823, theta=-15.5882613 -> V=1.000001, theta=0.0
% INFO    : Bus 2402	: V=0.989329958, theta=-30.2505646 -> V=1.0000005, theta=0.0
% INFO    : Bus 2403	: V=1.00972765, theta=-26.3002901 -> V=1.0000005, theta=0.0
% INFO    : Bus 2404	: V=0.9935223, theta=-14.3734102 -> V=0.999999, theta=0.0
% INFO    : Bus 2405	: V=1.061, theta=-15.5868139 -> V=1.000001, theta=0.0
% INFO    : Bus 2406	: V=0.993253844, theta=-21.2819495 -> V=1.015872, theta=0.0
% INFO    : Bus 2407	: V=1.01118134, theta=-45.7321415 -> V=1.0079355, theta=0.0
% INFO    : Bus 2408	: V=1.03779979, theta=-22.1456133 -> V=1.016666, theta=0.0
% INFO    : Bus 2409	: V=1.0747994, theta=-28.4233184 -> V=1.047375, theta=0.0
% INFO    : Bus 2410	: V=1.07480709, theta=-28.422938 -> V=1.04738, theta=0.0
% INFO    : Bus 2411	: V=1.0411041, theta=-24.3772048 -> V=1.0000025, theta=0.0
% INFO    : Bus 2412	: V=1.08296837, theta=-11.5684387 -> V=1.044445, theta=0.0
% INFO    : Bus 2413	: V=1.04001786, theta=-9.76288166 -> V=0.999999, theta=0.0
% INFO    : Bus 2414	: V=1.02173224, theta=1.13617358 -> V=1.0158755, theta=0.0
% INFO    : Bus 2415	: V=1.06009409, theta=-20.75705 -> V=1.023439, theta=0.0
% INFO    : Bus 2416	: V=1.03774902, theta=-51.3751693 -> V=1.0079355, theta=0.0
% INFO    : Bus 2417	: V=1.07212164, theta=-45.9184477 -> V=1.04444, theta=0.0
% INFO    : Bus 2418	: V=1.07281948, theta=-46.0467374 -> V=1.04444, theta=0.0
% INFO    : Bus 2419	: V=1.02497411, theta=-53.4422547 -> V=1.0079355, theta=0.0
% INFO    : Bus 2420	: V=1.02139817, theta=-0.471126329 -> V=1.0158755, theta=0.0
% INFO    : Bus 2421	: V=1.07481803, theta=3.44576372 -> V=1.0377785, theta=0.0
% INFO    : Bus 2422	: V=1.0226238, theta=-3.05207853 -> V=1.0158755, theta=0.0
% INFO    : Bus 2423	: V=1.02672375, theta=-2.73522245 -> V=1.0158755, theta=0.0
% INFO    : Bus 2424	: V=1.02670409, theta=-2.22716531 -> V=1.0158755, theta=0.0
% INFO    : Bus 2425	: V=1.06637557, theta=1.96231169 -> V=1.0377785, theta=0.0
% INFO    : Bus 2426	: V=1.02183898, theta=-54.466926 -> V=1.0079355, theta=0.0
% INFO    : Bus 2427	: V=1.04636028, theta=-55.6761289 -> V=1.0079355, theta=0.0
% INFO    : Bus 2428	: V=1.0625379, theta=-24.737116 -> V=1.046665, theta=0.0
% INFO    : Bus 2429	: V=1.06222572, theta=-24.8245221 -> V=1.046665, theta=0.0
% INFO    : Bus 2430	: V=1.03504952, theta=-14.3962363 -> V=0.999999, theta=0.0
% INFO    : Bus 2431	: V=1.04190845, theta=-4.52670048 -> V=1.0158755, theta=0.0
% INFO    : Bus 2432	: V=1.04197858, theta=-4.52842941 -> V=1.0158755, theta=0.0
% INFO    : Bus 2433	: V=1.03907686, theta=-18.8121223 -> V=0.999999, theta=0.0
% INFO    : Bus 2434	: V=1.02065687, theta=-27.3853115 -> V=1.0000025, theta=0.0
% INFO    : Bus 2435	: V=1.02205606, theta=-52.1215491 -> V=1.0079355, theta=0.0
% INFO    : Bus 2436	: V=1.01541594, theta=-54.0589833 -> V=1.0079355, theta=0.0
% INFO    : Bus 2437	: V=1.01500616, theta=-51.6723696 -> V=1.0079355, theta=0.0
% INFO    : Bus 2438	: V=1.01932266, theta=-51.8293373 -> V=1.0079355, theta=0.0
% INFO    : Bus 2439	: V=1.02965452, theta=-19.9734241 -> V=1.0000025, theta=0.0
% INFO    : Bus 2440	: V=1.09101435, theta=-19.7389003 -> V=1.0, theta=0.0
% INFO    : Bus 2441	: V=1.07609088, theta=-18.6373053 -> V=1.044445, theta=0.0
% INFO    : Bus 2442	: V=1.03756423, theta=-49.6922696 -> V=1.0079355, theta=0.0
% INFO    : Bus 2443	: V=1.07283289, theta=-13.9134773 -> V=1.000001, theta=0.0
% INFO    : Bus 2444	: V=1.00776363, theta=-5.76262196 -> V=0.999999, theta=0.0
% INFO    : Bus 2445	: V=1.03473314, theta=-25.7365477 -> V=1.0000025, theta=0.0
% INFO    : Bus 2446	: V=1.04290794, theta=-24.7385302 -> V=1.0000025, theta=0.0
% INFO    : Bus 2447	: V=1.06813923, theta=-26.4884588 -> V=1.046665, theta=0.0
% INFO    : Bus 2448	: V=1.08306423, theta=-22.2937137 -> V=1.044445, theta=0.0
% INFO    : Bus 2449	: V=1.02274163, theta=-8.28385397 -> V=1.0158755, theta=0.0
% INFO    : Bus 2450	: V=1.04852041, theta=-29.7985722 -> V=1.022224, theta=0.0
% INFO    : Bus 2451	: V=1.08185373, theta=-21.7279543 -> V=1.07237, theta=0.0
% INFO    : Bus 2452	: V=1.07826094, theta=-16.4490822 -> V=1.0000025, theta=0.0
% INFO    : Bus 2453	: V=1.09516783, theta=-11.5276985 -> V=1.047355, theta=0.0
% INFO    : Bus 2454	: V=1.00300425, theta=-19.3617718 -> V=1.015872, theta=0.0
% INFO    : Bus 2455	: V=1.03231509, theta=-25.6780752 -> V=1.0158755, theta=0.0
% INFO    : Bus 2456	: V=1.03224838, theta=-24.6848828 -> V=1.0000005, theta=0.0
% INFO    : Bus 2457	: V=1.00108584, theta=-44.530258 -> V=1.022224, theta=0.0
% INFO    : Bus 2458	: V=1.0536469, theta=-18.3164288 -> V=0.9888895, theta=0.0
% INFO    : Bus 2459	: V=1.05080623, theta=-17.1619924 -> V=0.9888895, theta=0.0
% INFO    : Bus 2460	: V=1.06245395, theta=-15.7918643 -> V=1.05263, theta=0.0
% INFO    : Bus 2461	: V=1.05560991, theta=-33.1223086 -> V=1.027779, theta=0.0
% INFO    : Bus 2462	: V=1.07064065, theta=-33.2629434 -> V=1.046665, theta=0.0
% INFO    : Bus 2463	: V=1.0829599, theta=-26.5119923 -> V=1.073685, theta=0.0
% INFO    : Bus 2464	: V=1.03388001, theta=-25.308481 -> V=1.0000025, theta=0.0
% INFO    : Bus 2465	: V=0.997258237, theta=-23.5409832 -> V=1.015872, theta=0.0
% INFO    : Bus 2466	: V=1.01629403, theta=-20.0439886 -> V=1.015872, theta=0.0
% INFO    : Bus 2467	: V=1.0165345, theta=-20.044397 -> V=1.015872, theta=0.0
% INFO    : Bus 2468	: V=1.03955108, theta=-18.2100942 -> V=0.999999, theta=0.0
% INFO    : Bus 2469	: V=1.04680983, theta=-4.63384086 -> V=1.0158755, theta=0.0
% INFO    : Bus 2470	: V=1.02884772, theta=-9.75006608 -> V=0.999999, theta=0.0
% INFO    : Bus 2471	: V=1.01975404, theta=-26.1690347 -> V=1.0000025, theta=0.0
% INFO    : Bus 2472	: V=1.06155353, theta=-17.4445036 -> V=1.0000025, theta=0.0
% INFO    : Bus 2473	: V=1.00761822, theta=-18.7028904 -> V=1.015872, theta=0.0
% INFO    : Bus 2474	: V=1.0638155, theta=-18.6002339 -> V=1.0000025, theta=0.0
% INFO    : Bus 2475	: V=1.04290361, theta=-38.4612414 -> V=1.022224, theta=0.0
% INFO    : Bus 2476	: V=1.02829064, theta=-39.1512474 -> V=1.022224, theta=0.0
% INFO    : Bus 2477	: V=1.06328349, theta=-35.2089147 -> V=1.04444, theta=0.0
% INFO    : Bus 2478	: V=0.998283618, theta=-33.3788563 -> V=1.015872, theta=0.0
% INFO    : Bus 2479	: V=1.07449973, theta=-18.9661855 -> V=1.000001, theta=0.0
% INFO    : Bus 2480	: V=1.03360333, theta=-7.2757169 -> V=1.0158755, theta=0.0
% INFO    : Bus 2481	: V=1.04354663, theta=-27.0086214 -> V=1.0000025, theta=0.0
% INFO    : Bus 2482	: V=1.01693845, theta=-19.9939739 -> V=1.015872, theta=0.0
% INFO    : Bus 2483	: V=1.051348, theta=-14.8353294 -> V=1.046665, theta=0.0
% INFO    : Bus 2484	: V=1.01566931, theta=-24.7963925 -> V=1.0000025, theta=0.0
% INFO    : Bus 2485	: V=1.02983507, theta=-6.50371732 -> V=1.0158755, theta=0.0
% INFO    : Bus 2486	: V=1.04424176, theta=-20.0270864 -> V=1.0158755, theta=0.0
% INFO    : Bus 2487	: V=1.01503116, theta=-3.46366708 -> V=1.0158755, theta=0.0
% INFO    : Bus 2488	: V=1.02323517, theta=-15.3513497 -> V=1.015872, theta=0.0
% INFO    : Bus 2489	: V=1.04402919, theta=-28.293411 -> V=1.027779, theta=0.0
% INFO    : Bus 2490	: V=0.952473624, theta=-7.72092111 -> V=0.9444445, theta=0.0
% INFO    : Bus 2491	: V=0.989600214, theta=-29.8562683 -> V=1.0000025, theta=0.0
% INFO    : Bus 2492	: V=1.04414179, theta=-27.9781289 -> V=1.0000025, theta=0.0
% INFO    : Bus 2493	: V=1.01374493, theta=-18.3705595 -> V=1.015872, theta=0.0
% INFO    : Bus 2494	: V=1.03493527, theta=-26.1889222 -> V=1.0000025, theta=0.0
% INFO    : Bus 2495	: V=1.0437593, theta=-25.8631527 -> V=1.0000025, theta=0.0
% INFO    : Bus 2496	: V=1.06555191, theta=-21.0749231 -> V=1.044445, theta=0.0
% INFO    : Bus 2497	: V=1.04279564, theta=-26.1036012 -> V=1.0000025, theta=0.0
% INFO    : Bus 2498	: V=1.03613612, theta=-26.0935097 -> V=1.022224, theta=0.0
% INFO    : Bus 2499	: V=1.04113258, theta=-14.6440679 -> V=0.999999, theta=0.0
% INFO    : Bus 2500	: V=1.01557086, theta=-27.0896153 -> V=1.0000025, theta=0.0
% INFO    : Bus 2501	: V=1.03118635, theta=2.21625952 -> V=1.0158755, theta=0.0
% INFO    : Bus 2502	: V=1.04595594, theta=-25.9199935 -> V=1.0000025, theta=0.0
% INFO    : Bus 2503	: V=1.06180059, theta=-19.7878618 -> V=1.044445, theta=0.0
% INFO    : Bus 2504	: V=1.02540016, theta=-53.2174513 -> V=1.0079355, theta=0.0
% INFO    : Bus 2505	: V=1.05284892, theta=-22.4051271 -> V=1.0000025, theta=0.0
% INFO    : Bus 2506	: V=1.03758103, theta=-25.3487642 -> V=1.0000025, theta=0.0
% INFO    : Bus 2507	: V=1.04549807, theta=-33.1868893 -> V=1.0000025, theta=0.0
% INFO    : Bus 2508	: V=1.05751763, theta=-33.1868893 -> V=1.000001, theta=0.0
% INFO    : Bus 2509	: V=1.05256323, theta=-23.5998303 -> V=1.0000025, theta=0.0
% INFO    : Bus 2510	: V=1.07017189, theta=-18.6331129 -> V=1.044445, theta=0.0
% INFO    : Bus 2511	: V=1.07748632, theta=-13.8190273 -> V=1.078945, theta=0.0
% INFO    : Bus 2512	: V=1.04413136, theta=-15.4363996 -> V=0.9888895, theta=0.0
% INFO    : Bus 2513	: V=1.04415497, theta=-15.4381238 -> V=0.9888895, theta=0.0
% INFO    : Bus 2514	: V=1.03646644, theta=-26.072775 -> V=1.0000025, theta=0.0
% INFO    : Bus 2515	: V=1.00714451, theta=-25.1895256 -> V=1.022224, theta=0.0
% INFO    : Bus 2516	: V=1.145, theta=-14.5722092 -> V=1.053858, theta=0.0
% INFO    : Bus 2517	: V=1.05414103, theta=-14.0140559 -> V=0.9888895, theta=0.0
% INFO    : Bus 2518	: V=1.01703587, theta=-28.0252435 -> V=1.0000005, theta=0.0
% INFO    : Bus 2519	: V=1.0747515, theta=-28.4942008 -> V=1.047355, theta=0.0
% INFO    : Bus 2520	: V=1.02288402, theta=-20.1000249 -> V=1.022224, theta=0.0
% INFO    : Bus 2521	: V=1.05784129, theta=-14.907647 -> V=1.0000025, theta=0.0
% INFO    : Bus 2522	: V=1.01000019, theta=-22.9601211 -> V=1.0000025, theta=0.0
% INFO    : Bus 2523	: V=1.02549977, theta=-12.333055 -> V=1.0000025, theta=0.0
% INFO    : Bus 2524	: V=1.0319404, theta=-28.5386207 -> V=1.015872, theta=0.0
% INFO    : Bus 2525	: V=1.034, theta=-10.5906518 -> V=1.0158755, theta=0.0
% INFO    : Bus 2526	: V=1.03235575, theta=-10.6859428 -> V=1.0158755, theta=0.0
% INFO    : Bus 2527	: V=1.05648176, theta=-24.261167 -> V=1.046665, theta=0.0
% INFO    : Bus 2528	: V=1.05649781, theta=-25.9414099 -> V=1.046665, theta=0.0
% INFO    : Bus 2529	: V=1.02091661, theta=-27.508434 -> V=1.0000005, theta=0.0
% INFO    : Bus 2530	: V=1.022731, theta=-27.5814897 -> V=1.0000005, theta=0.0
% INFO    : Bus 2531	: V=1.04868059, theta=-20.3414089 -> V=0.999999, theta=0.0
% INFO    : Bus 2532	: V=1.04269604, theta=-19.9385889 -> V=0.999999, theta=0.0
% INFO    : Bus 2533	: V=1.04196622, theta=-13.8847048 -> V=1.0111115, theta=0.0
% INFO    : Bus 2534	: V=1.01182474, theta=-18.0604915 -> V=1.015872, theta=0.0
% INFO    : Bus 2535	: V=1.02155037, theta=-31.5879008 -> V=1.0000005, theta=0.0
% INFO    : Bus 2536	: V=1.0235463, theta=-31.5458018 -> V=1.0000005, theta=0.0
% INFO    : Bus 2537	: V=1.02455428, theta=-31.5699678 -> V=1.0000005, theta=0.0
% INFO    : Bus 2538	: V=1.045626, theta=-24.481626 -> V=1.0000025, theta=0.0
% INFO    : Bus 2539	: V=1.0234283, theta=-12.9972516 -> V=0.999999, theta=0.0
% INFO    : Bus 2540	: V=1.0453357, theta=-23.9320994 -> V=0.999999, theta=0.0
% INFO    : Bus 2541	: V=1.03254703, theta=-29.7428493 -> V=1.015872, theta=0.0
% INFO    : Bus 2542	: V=1.02832723, theta=-26.1542279 -> V=1.0233335, theta=0.0
% INFO    : Bus 2543	: V=1.04307049, theta=-26.7221581 -> V=1.046665, theta=0.0
% INFO    : Bus 2544	: V=1.05562307, theta=-14.8563502 -> V=1.0000025, theta=0.0
% INFO    : Bus 2545	: V=1.03820325, theta=-26.8238244 -> V=1.0000025, theta=0.0
% INFO    : Bus 2546	: V=1.06470189, theta=-17.0542621 -> V=1.005459, theta=0.0
% INFO    : Bus 2547	: V=1.05323558, theta=-29.2394643 -> V=1.027779, theta=0.0
% INFO    : Bus 2548	: V=1.03792225, theta=-18.1114913 -> V=1.0000025, theta=0.0
% INFO    : Bus 2549	: V=1.00465206, theta=-53.3431803 -> V=1.0079355, theta=0.0
% INFO    : Bus 2550	: V=1.04200895, theta=-34.0733127 -> V=1.027779, theta=0.0
% INFO    : Bus 2551	: V=1.025, theta=-8.60323331 -> V=0.999999, theta=0.0
% INFO    : Bus 2552	: V=1.00270052, theta=-21.3713805 -> V=1.0000025, theta=0.0
% INFO    : Bus 2553	: V=1.0725633, theta=-17.7998331 -> V=1.044445, theta=0.0
% INFO    : Bus 2554	: V=1.00658419, theta=-22.8477449 -> V=1.0000005, theta=0.0
% INFO    : Bus 2555	: V=1.04155439, theta=-32.497007 -> V=1.022224, theta=0.0
% INFO    : Bus 2556	: V=1.02698393, theta=-55.5623294 -> V=1.0079355, theta=0.0
% INFO    : Bus 2557	: V=1.03996002, theta=-53.6861448 -> V=1.0079355, theta=0.0
% INFO    : Bus 2558	: V=1.0527156, theta=-20.1588921 -> V=1.0000025, theta=0.0
% INFO    : Bus 2559	: V=1.04222417, theta=-6.45486359 -> V=1.0158755, theta=0.0
% INFO    : Bus 2560	: V=1.07973215, theta=-1.92593929 -> V=1.0377785, theta=0.0
% INFO    : Bus 2561	: V=1.0956764, theta=1.59266887 -> V=1.072365, theta=0.0
% INFO    : Bus 2562	: V=1.03999344, theta=-29.8634562 -> V=1.027779, theta=0.0
% INFO    : Bus 2563	: V=1.04551732, theta=-29.2850726 -> V=1.027779, theta=0.0
% INFO    : Bus 2564	: V=1.05680048, theta=-23.7911072 -> V=1.046665, theta=0.0
% INFO    : Bus 2565	: V=1.01148752, theta=-25.857807 -> V=1.0000005, theta=0.0
% INFO    : Bus 2566	: V=1.06418759, theta=-37.2707825 -> V=1.027779, theta=0.0
% INFO    : Bus 2567	: V=1.0582427, theta=-19.4827964 -> V=1.024684, theta=0.0
% INFO    : Bus 2568	: V=1.06832362, theta=-26.5448966 -> V=1.046665, theta=0.0
% INFO    : Bus 2569	: V=1.03278657, theta=0.817974439 -> V=1.0158755, theta=0.0
% INFO    : Bus 2570	: V=0.952332186, theta=-6.51368294 -> V=0.9444445, theta=0.0
% INFO    : Bus 2571	: V=0.999702382, theta=-6.46728827 -> V=0.999999, theta=0.0
% INFO    : Bus 2572	: V=1.04908553, theta=-8.91298986 -> V=1.003335, theta=0.0
% INFO    : Bus 2573	: V=1.04187909, theta=-5.35945251 -> V=1.0111115, theta=0.0
% INFO    : Bus 2574	: V=1.04838151, theta=-45.3942608 -> V=1.022224, theta=0.0
% INFO    : Bus 2575	: V=1.0194424, theta=-36.3490765 -> V=1.022224, theta=0.0
% INFO    : Bus 2576	: V=1.0719365, theta=-17.4953816 -> V=1.016666, theta=0.0
% INFO    : Bus 2577	: V=1.05998702, theta=-12.9439294 -> V=1.0288895, theta=0.0
% INFO    : Bus 2578	: V=1.05145283, theta=-28.8860426 -> V=1.0000025, theta=0.0
% INFO    : Bus 2579	: V=1.02594384, theta=-23.3593998 -> V=1.022224, theta=0.0
% INFO    : Bus 2580	: V=1.03514253, theta=-32.9440374 -> V=1.022224, theta=0.0
% INFO    : Bus 2581	: V=1.03513498, theta=-11.3431389 -> V=0.999999, theta=0.0
% INFO    : Bus 2582	: V=1.01652981, theta=-27.9891575 -> V=1.0000005, theta=0.0
% INFO    : Bus 2583	: V=1.08154132, theta=2.58520976 -> V=1.05263, theta=0.0
% INFO    : Bus 2584	: V=1.00951371, theta=-51.6467353 -> V=1.0079355, theta=0.0
% INFO    : Bus 2585	: V=1.0138193, theta=-11.7476217 -> V=0.975, theta=0.0
% INFO    : Bus 2586	: V=1.04550884, theta=-21.8070596 -> V=1.022224, theta=0.0
% INFO    : Bus 2587	: V=1.02623538, theta=-50.499241 -> V=1.0079355, theta=0.0
% INFO    : Bus 2588	: V=1.07329992, theta=-47.1901398 -> V=1.04444, theta=0.0
% INFO    : Bus 2589	: V=1.05666052, theta=-20.1571791 -> V=1.022224, theta=0.0
% INFO    : Bus 2590	: V=1.03837583, theta=-19.4724805 -> V=1.022224, theta=0.0
% INFO    : Bus 2591	: V=1.05787664, theta=-17.7597702 -> V=1.0000025, theta=0.0
% INFO    : Bus 2592	: V=1.05073338, theta=-16.7455032 -> V=1.001599, theta=0.0
% INFO    : Bus 2593	: V=1.05788125, theta=-17.7591451 -> V=1.0000025, theta=0.0
% INFO    : Bus 2594	: V=1.03014752, theta=-60.2880417 -> V=1.0079355, theta=0.0
% INFO    : Bus 2595	: V=1.03346292, theta=-27.6094073 -> V=1.022224, theta=0.0
% INFO    : Bus 2596	: V=1.02748706, theta=-36.6564065 -> V=1.022224, theta=0.0
% INFO    : Bus 2597	: V=1.00415838, theta=-20.8117223 -> V=1.0158755, theta=0.0
% INFO    : Bus 2598	: V=1.04933027, theta=-37.5989402 -> V=1.022224, theta=0.0
% INFO    : Bus 2599	: V=1.08019492, theta=-31.262657 -> V=1.07237, theta=0.0
% INFO    : Bus 2600	: V=1.08037355, theta=-31.2603544 -> V=1.07237, theta=0.0
% INFO    : Bus 2601	: V=1.02957355, theta=-29.1421207 -> V=1.022224, theta=0.0
% INFO    : Bus 2602	: V=1.03600175, theta=-28.4178056 -> V=1.022224, theta=0.0
% INFO    : Bus 2603	: V=1.0457672, theta=-21.4914741 -> V=1.0000025, theta=0.0
% INFO    : Bus 2604	: V=1.00583099, theta=-32.6312806 -> V=1.015872, theta=0.0
% INFO    : Bus 2605	: V=1.02248226, theta=-30.2216582 -> V=1.0000025, theta=0.0
% INFO    : Bus 2606	: V=1.05201088, theta=-29.9752323 -> V=1.027779, theta=0.0
% INFO    : Bus 2607	: V=1.02480282, theta=-34.899739 -> V=1.0000005, theta=0.0
% INFO    : Bus 2608	: V=1.02482427, theta=-23.0391145 -> V=1.000001, theta=0.0
% INFO    : Bus 2609	: V=1.0340935, theta=-38.9655383 -> V=1.022224, theta=0.0
% INFO    : Bus 2610	: V=1.04780286, theta=-14.8645098 -> V=1.0377785, theta=0.0
% INFO    : Bus 2611	: V=1.02687404, theta=-20.3913475 -> V=1.0158755, theta=0.0
% INFO    : Bus 2612	: V=1.00395957, theta=-26.4041767 -> V=1.0000025, theta=0.0
% INFO    : Bus 2613	: V=1.0233737, theta=-34.0038909 -> V=1.022224, theta=0.0
% INFO    : Bus 2614	: V=1.02086694, theta=-3.27720946 -> V=1.0158755, theta=0.0
% INFO    : Bus 2615	: V=1.0411038, theta=-20.8416678 -> V=1.0000025, theta=0.0
% INFO    : Bus 2616	: V=1.05184709, theta=-27.0150615 -> V=1.022224, theta=0.0
% INFO    : Bus 2617	: V=1.05877838, theta=-19.0258003 -> V=1.0111115, theta=0.0
% INFO    : Bus 2618	: V=1.0562875, theta=-3.20126339 -> V=1.000001, theta=0.0
% INFO    : Bus 2619	: V=1.07738989, theta=-0.00982130388 -> V=1.0293595, theta=0.0
% INFO    : Bus 2620	: V=1.012, theta=-21.9261685 -> V=1.0158755, theta=0.0
% INFO    : Bus 2621	: V=0.996782673, theta=-22.7829015 -> V=1.0000025, theta=0.0
% INFO    : Bus 2622	: V=1.02305909, theta=-13.3268964 -> V=1.0158755, theta=0.0
% INFO    : Bus 2623	: V=1.01401563, theta=-30.9759216 -> V=1.022224, theta=0.0
% INFO    : Bus 2624	: V=1.02419843, theta=-26.1946476 -> V=1.0000025, theta=0.0
% INFO    : Bus 2625	: V=1.042746, theta=-25.9311697 -> V=1.0000025, theta=0.0
% INFO    : Bus 2626	: V=1.054313, theta=-6.66164852 -> V=1.0158755, theta=0.0
% INFO    : Bus 2627	: V=1.05127162, theta=-6.7033214 -> V=1.0158755, theta=0.0
% INFO    : Bus 2628	: V=1.08118337, theta=-3.53149835 -> V=1.0377785, theta=0.0
% INFO    : Bus 2629	: V=1.02838723, theta=-5.94614016 -> V=1.0158755, theta=0.0
% INFO    : Bus 2630	: V=1.02934017, theta=-12.8415501 -> V=1.0158755, theta=0.0
% INFO    : Bus 2631	: V=1.00527934, theta=-28.985487 -> V=1.0000025, theta=0.0
% INFO    : Bus 2632	: V=1.04382877, theta=-31.8679328 -> V=1.022224, theta=0.0
% INFO    : Bus 2633	: V=1.04345962, theta=-28.3678416 -> V=1.0000025, theta=0.0
% INFO    : Bus 2634	: V=1.06325706, theta=-27.289351 -> V=0.975, theta=0.0
% INFO    : Bus 2635	: V=1.03967347, theta=-22.5904013 -> V=1.0000025, theta=0.0
% INFO    : Bus 2636	: V=1.01212962, theta=-21.2977351 -> V=1.0000025, theta=0.0
% INFO    : Bus 2637	: V=1.012, theta=-21.2742297 -> V=1.0000025, theta=0.0
% INFO    : Bus 2638	: V=1.052, theta=-17.8126664 -> V=1.0000025, theta=0.0
% INFO    : Bus 2639	: V=1.08441398, theta=-26.3946448 -> V=1.0074025, theta=0.0
% INFO    : Bus 2640	: V=1.09577645, theta=-18.3877063 -> V=0.975, theta=0.0
% INFO    : Bus 2641	: V=1.09571346, theta=-18.3881919 -> V=1.0, theta=0.0
% INFO    : Bus 2642	: V=1.02193113, theta=-8.44119166 -> V=1.0158755, theta=0.0
% INFO    : Bus 2643	: V=1.03918109, theta=-23.7594752 -> V=1.022224, theta=0.0
% INFO    : Bus 2644	: V=1.03818913, theta=-27.885287 -> V=1.0000025, theta=0.0
% INFO    : Bus 2645	: V=1.064, theta=-17.2035867 -> V=1.0000025, theta=0.0
% INFO    : Bus 2646	: V=1.07802935, theta=-14.6399405 -> V=1.044445, theta=0.0
% INFO    : Bus 2647	: V=1.05575953, theta=-20.3995598 -> V=1.015874, theta=0.0
% INFO    : Bus 2648	: V=1.03782541, theta=-17.2443466 -> V=0.9888895, theta=0.0
% INFO    : Bus 2649	: V=1.05031262, theta=-15.368854 -> V=0.9888895, theta=0.0
% INFO    : Bus 2650	: V=1.03547655, theta=-24.7841387 -> V=1.0000025, theta=0.0
% INFO    : Bus 2651	: V=0.998279133, theta=-13.1858819 -> V=1.015872, theta=0.0
% INFO    : Bus 2652	: V=1.031, theta=-8.44616259 -> V=0.999999, theta=0.0
% INFO    : Bus 2653	: V=1.021, theta=-10.2078594 -> V=1.015872, theta=0.0
% INFO    : Bus 2654	: V=1.04088609, theta=-6.19730099 -> V=1.046665, theta=0.0
% INFO    : Bus 2655	: V=1.09719937, theta=-20.0989295 -> V=0.975, theta=0.0
% INFO    : Bus 2656	: V=1.058, theta=-20.1120878 -> V=0.975, theta=0.0
% INFO    : Bus 2657	: V=1.095, theta=-18.5826906 -> V=0.975, theta=0.0
% INFO    : Bus 2658	: V=1.058, theta=-20.1120878 -> V=1.0000025, theta=0.0
% INFO    : Bus 2659	: V=1.09472396, theta=-18.6285471 -> V=1.0, theta=0.0
% INFO    : Bus 2660	: V=1.02576386, theta=-42.6409142 -> V=1.0079355, theta=0.0
% INFO    : Bus 2661	: V=1.041822, theta=-41.4061594 -> V=1.022224, theta=0.0
% INFO    : Bus 2662	: V=0.560040593, theta=1.25882746 -> V=0.825, theta=0.0
% INFO    : Bus 2663	: V=1.01758772, theta=1.25882746 -> V=1.0158755, theta=0.0
% INFO    : Bus 2664	: V=1.03622867, theta=-16.1243187 -> V=1.0158755, theta=0.0
% INFO    : Bus 2665	: V=1.03622867, theta=-16.1243187 -> V=1.0158755, theta=0.0
% INFO    : Bus 2666	: V=1.02569225, theta=-21.6149219 -> V=1.0000025, theta=0.0
% INFO    : Bus 2667	: V=1.00586778, theta=-45.9466775 -> V=1.0079355, theta=0.0
% INFO    : Bus 2668	: V=1.03339523, theta=-15.8773843 -> V=1.0158755, theta=0.0
% INFO    : Bus 2669	: V=1.04602832, theta=-12.3234713 -> V=1.0377785, theta=0.0
% INFO    : Bus 2670	: V=1.02445126, theta=-16.7715092 -> V=1.0158755, theta=0.0
% INFO    : Bus 2671	: V=1.04168957, theta=-11.0512585 -> V=0.999999, theta=0.0
% INFO    : Bus 2672	: V=1.04853569, theta=-7.60590177 -> V=1.0111115, theta=0.0
% INFO    : Bus 2673	: V=1.0122872, theta=-19.6880447 -> V=1.0000025, theta=0.0
% INFO    : Bus 2674	: V=1.06109409, theta=-20.6234919 -> V=1.023339, theta=0.0
% INFO    : Bus 2675	: V=1.06353978, theta=-24.9393559 -> V=1.046665, theta=0.0
% INFO    : Bus 2676	: V=1.04367532, theta=-30.2526058 -> V=1.027779, theta=0.0
% INFO    : Bus 2677	: V=1.03809849, theta=-19.4332874 -> V=1.0158755, theta=0.0
% INFO    : Bus 2678	: V=1.05424388, theta=-15.1281592 -> V=1.0377785, theta=0.0
% INFO    : Bus 2679	: V=1.02439659, theta=-24.2644229 -> V=1.000001, theta=0.0
% INFO    : Bus 2680	: V=1.01947763, theta=-12.3903757 -> V=1.0158755, theta=0.0
% INFO    : Bus 2681	: V=1.06909226, theta=-21.1051603 -> V=1.033333, theta=0.0
% INFO    : Bus 2682	: V=1.02387195, theta=-28.376188 -> V=1.0000005, theta=0.0
% INFO    : Bus 2683	: V=1.02982646, theta=-20.6948863 -> V=1.0158755, theta=0.0
% INFO    : Bus 2684	: V=1.04252948, theta=-29.0887728 -> V=1.022224, theta=0.0
% INFO    : Bus 2685	: V=1.04842519, theta=-27.7944901 -> V=1.022224, theta=0.0
% INFO    : Bus 2686	: V=1.06328852, theta=-24.9119891 -> V=1.046665, theta=0.0
% INFO    : Bus 2687	: V=1.00636238, theta=-22.0642886 -> V=1.015872, theta=0.0
% INFO    : Bus 2688	: V=1.028, theta=-29.1722125 -> V=1.0000005, theta=0.0
% INFO    : Bus 2689	: V=1.02782134, theta=-13.7774391 -> V=1.0158755, theta=0.0
% INFO    : Bus 2690	: V=1.04758055, theta=-27.6225145 -> V=1.022224, theta=0.0
% INFO    : Bus 2691	: V=1.07071504, theta=-22.9312417 -> V=1.029619, theta=0.0
% INFO    : Bus 2692	: V=1.03851573, theta=-50.6147959 -> V=1.0079355, theta=0.0
% INFO    : Bus 2693	: V=1.02357558, theta=-16.9498688 -> V=1.015872, theta=0.0
% INFO    : Bus 2694	: V=1.054733, theta=-24.1380122 -> V=1.046665, theta=0.0
% INFO    : Bus 2695	: V=1.02214327, theta=-27.5755055 -> V=1.0000005, theta=0.0
% INFO    : Bus 2696	: V=1.01993342, theta=-8.66050316 -> V=0.999999, theta=0.0
% INFO    : Bus 2697	: V=1.04273687, theta=-5.50154885 -> V=1.0111115, theta=0.0
% INFO    : Bus 2698	: V=1.06512904, theta=-18.1864304 -> V=1.007364, theta=0.0
% INFO    : Bus 2699	: V=1.05878332, theta=-19.5237751 -> V=1.004159, theta=0.0
% INFO    : Bus 2700	: V=1.04253225, theta=-13.3844012 -> V=1.0111115, theta=0.0
% INFO    : Bus 2701	: V=1.00894877, theta=-22.2965685 -> V=1.015872, theta=0.0
% INFO    : Bus 2702	: V=1.00505139, theta=-20.4618849 -> V=1.015872, theta=0.0
% INFO    : Bus 2703	: V=1.04584998, theta=-13.0371917 -> V=1.033334, theta=0.0
% INFO    : Bus 2704	: V=1.03311744, theta=-32.5374035 -> V=1.027779, theta=0.0
% INFO    : Bus 2705	: V=1.05507038, theta=-20.5510726 -> V=1.0111115, theta=0.0
% INFO    : Bus 2706	: V=1.07809485, theta=-6.31534527 -> V=1.0377785, theta=0.0
% INFO    : Bus 2707	: V=1.08966162, theta=-2.71721087 -> V=1.072365, theta=0.0
% INFO    : Bus 2708	: V=1.02810993, theta=-36.402993 -> V=1.022224, theta=0.0
% INFO    : Bus 2709	: V=1.04306159, theta=-27.6352977 -> V=1.022224, theta=0.0
% INFO    : Bus 2710	: V=1.03565476, theta=-25.648056 -> V=1.0000025, theta=0.0
% INFO    : Bus 2711	: V=1.03905989, theta=-28.8676565 -> V=1.0000025, theta=0.0
% INFO    : Bus 2712	: V=1.0575111, theta=-16.2049045 -> V=1.016666, theta=0.0
% INFO    : Bus 2713	: V=1.07168452, theta=-11.9460094 -> V=0.9888895, theta=0.0
% INFO    : Bus 2714	: V=1.0868863, theta=-9.06999975 -> V=1.05263, theta=0.0
% INFO    : Bus 2715	: V=1.01699138, theta=-50.9620401 -> V=1.0079355, theta=0.0
% INFO    : Bus 2716	: V=1.00803471, theta=-26.0179473 -> V=1.0000025, theta=0.0
% INFO    : Bus 2717	: V=1.048035, theta=-26.662518 -> V=1.027779, theta=0.0
% INFO    : Bus 2718	: V=1.06848347, theta=-23.2980425 -> V=1.046665, theta=0.0
% INFO    : Bus 2719	: V=1.015478, theta=-1.9805735 -> V=1.0158755, theta=0.0
% INFO    : Bus 2720	: V=1.05134376, theta=-13.5602805 -> V=1.033334, theta=0.0
% INFO    : Bus 2721	: V=1.07730304, theta=-18.7819952 -> V=1.000001, theta=0.0
% INFO    : Bus 2722	: V=1.04199457, theta=-32.1103425 -> V=1.022224, theta=0.0
% INFO    : Bus 2723	: V=1.0541193, theta=-12.5546905 -> V=1.004924, theta=0.0
% INFO    : Bus 2724	: V=1.04359884, theta=-33.0098214 -> V=1.022224, theta=0.0
% INFO    : Bus 2725	: V=0.989436241, theta=-30.1663553 -> V=1.0000005, theta=0.0
% INFO    : Bus 2726	: V=1.04665738, theta=-30.2297081 -> V=1.027779, theta=0.0
% INFO    : Bus 2727	: V=1.062, theta=-17.9956371 -> V=1.000001, theta=0.0
% INFO    : Bus 2728	: V=1.03533215, theta=-20.9651338 -> V=1.0158755, theta=0.0
% INFO    : Bus 2729	: V=1.05395172, theta=-28.9104095 -> V=1.027779, theta=0.0
% INFO    : Bus 2730	: V=1.05158979, theta=-28.9129492 -> V=1.027779, theta=0.0
% INFO    : Bus 2731	: V=1.05740724, theta=-28.8430828 -> V=1.0000025, theta=0.0
% INFO    : Bus 2732	: V=1.02590912, theta=-7.55818474 -> V=0.999999, theta=0.0
% INFO    : Bus 2733	: V=1.04583073, theta=-23.9560601 -> V=1.022224, theta=0.0
% INFO    : Bus 2734	: V=1.04480914, theta=-24.024564 -> V=1.022224, theta=0.0
% INFO    : Bus 2735	: V=1.01116981, theta=-22.0676087 -> V=1.0158755, theta=0.0
% INFO    : Bus 2736	: V=1.00358211, theta=-8.06590915 -> V=1.0158755, theta=0.0
% INFO    : Bus 2737	: V=1.06594576, theta=-0.649726403 -> V=1.0377785, theta=0.0
% INFO    : Bus 2738	: V=1.05920547, theta=-14.334276 -> V=0.999999, theta=0.0
% INFO    : Bus 2739	: V=1.0109527, theta=-11.505544 -> V=1.015872, theta=0.0
% INFO    : Bus 2740	: V=1.03960852, theta=-15.6537877 -> V=1.000001, theta=0.0
% INFO    : Bus 2741	: V=1.06856176, theta=-14.3374907 -> V=1.000001, theta=0.0
% INFO    : Bus 2742	: V=1.09200543, theta=-13.0719788 -> V=1.046365, theta=0.0
% INFO    : Bus 2743	: V=1.03605134, theta=-30.2824475 -> V=1.022224, theta=0.0
% INFO    : Bus 2744	: V=1.02800879, theta=-30.8376674 -> V=1.0000005, theta=0.0
% INFO    : Bus 2745	: V=1.0461321, theta=-24.4912933 -> V=1.0000025, theta=0.0
% INFO    : Bus 2746	: V=1.04526583, theta=-15.7477348 -> V=0.999999, theta=0.0
% INFO    : Bus 2747	: V=1.074293, theta=-12.493437 -> V=1.0111115, theta=0.0
% INFO    : Bus 2748	: V=1.05045105, theta=-32.3098864 -> V=1.0116305, theta=0.0
% INFO    : Bus 2749	: V=1.00868552, theta=-11.9843929 -> V=0.999999, theta=0.0
% INFO    : Bus 2750	: V=1.02354593, theta=-31.5457946 -> V=1.0000005, theta=0.0
% INFO    : Bus 2751	: V=1.02777789, theta=2.27544907 -> V=1.0158755, theta=0.0
% INFO    : Bus 2752	: V=1.04481871, theta=-22.3309593 -> V=1.027779, theta=0.0
% INFO    : Bus 2753	: V=1.00759241, theta=-25.3276965 -> V=1.0000005, theta=0.0
% INFO    : Bus 2754	: V=1.04672806, theta=-4.57467394 -> V=1.0000025, theta=0.0
% INFO    : Bus 2755	: V=1.06283882, theta=-0.469026329 -> V=1.0377785, theta=0.0
% INFO    : Bus 2756	: V=1.07675432, theta=2.23924126 -> V=1.072365, theta=0.0
% INFO    : Bus 2757	: V=1.03171454, theta=-12.8457577 -> V=0.999999, theta=0.0
% INFO    : Bus 2758	: V=1.12150734, theta=4.48253401 -> V=1.0403355, theta=0.0
% INFO    : Bus 2759	: V=1.03412838, theta=-19.2801218 -> V=1.0000025, theta=0.0
% INFO    : Bus 2760	: V=1.05257458, theta=-25.3997985 -> V=1.0000025, theta=0.0
% INFO    : Bus 2761	: V=0.942142466, theta=-15.3367311 -> V=0.975, theta=0.0
% INFO    : Bus 2762	: V=1.03927691, theta=-17.8317238 -> V=1.022224, theta=0.0
% INFO    : Bus 2763	: V=1.06926393, theta=-15.0465682 -> V=1.04444, theta=0.0
% INFO    : Bus 2764	: V=1.08693263, theta=-10.5768723 -> V=1.07237, theta=0.0
% INFO    : Bus 2765	: V=1.03994578, theta=-31.3265752 -> V=1.027779, theta=0.0
% INFO    : Bus 2766	: V=1.02473397, theta=-9.89855657 -> V=1.0158755, theta=0.0
% INFO    : Bus 2767	: V=1.05053626, theta=-11.2010354 -> V=1.001694, theta=0.0
% INFO    : Bus 2768	: V=1.03097665, theta=-8.71796071 -> V=1.0111115, theta=0.0
% INFO    : Bus 2769	: V=1.03016727, theta=-9.49316887 -> V=1.0158755, theta=0.0
% INFO    : Bus 2770	: V=1.05366474, theta=-6.7101023 -> V=1.0377785, theta=0.0
% INFO    : Bus 2771	: V=1.04607508, theta=-32.8415375 -> V=1.0000025, theta=0.0
% INFO    : Bus 2772	: V=1.02146645, theta=-21.1093394 -> V=1.0000025, theta=0.0
% INFO    : Bus 2773	: V=1.04818175, theta=-23.3107436 -> V=1.0000025, theta=0.0
% INFO    : Bus 2774	: V=1.06918314, theta=-19.096939 -> V=1.044445, theta=0.0
% INFO    : Bus 2775	: V=1.08492531, theta=-17.9101051 -> V=1.078945, theta=0.0
% INFO    : Bus 2776	: V=1.05465776, theta=-29.9640772 -> V=1.027779, theta=0.0
% INFO    : Bus 2777	: V=1.07308201, theta=-45.7922974 -> V=1.04444, theta=0.0
% INFO    : Bus 2778	: V=1.07524137, theta=-40.8811465 -> V=1.07237, theta=0.0
% INFO    : Bus 2779	: V=1.07338602, theta=-42.6827695 -> V=1.07237, theta=0.0
% INFO    : Bus 2780	: V=1.01953959, theta=-44.8737232 -> V=1.0079355, theta=0.0
% INFO    : Bus 2781	: V=1.06260279, theta=-23.6768143 -> V=1.0000025, theta=0.0
% INFO    : Bus 2782	: V=1.04815038, theta=-7.90913676 -> V=1.0158755, theta=0.0
% INFO    : Bus 2783	: V=1.046407, theta=-23.5186868 -> V=1.0000025, theta=0.0
% INFO    : Bus 2784	: V=1.06674476, theta=-18.4752224 -> V=1.044445, theta=0.0
% INFO    : Bus 2785	: V=1.04420135, theta=-18.2156509 -> V=0.999999, theta=0.0
% INFO    : Bus 2786	: V=1.05417406, theta=-28.8878182 -> V=1.027779, theta=0.0
% INFO    : Bus 2787	: V=1.05804838, theta=-24.6718693 -> V=1.046665, theta=0.0
% INFO    : Bus 2788	: V=1.0719293, theta=-25.5819895 -> V=1.04687, theta=0.0
% INFO    : Bus 2789	: V=1.07061059, theta=-13.2452653 -> V=1.016666, theta=0.0
% INFO    : Bus 2790	: V=1.06602903, theta=-11.9167378 -> V=1.022223, theta=0.0
% INFO    : Bus 2791	: V=1.06263787, theta=-6.43992536 -> V=1.05263, theta=0.0
% INFO    : Bus 2792	: V=1.04116911, theta=-14.9857209 -> V=0.999999, theta=0.0
% INFO    : Bus 2793	: V=1.03869696, theta=-28.5295121 -> V=1.022224, theta=0.0
% INFO    : Bus 2794	: V=1.0036875, theta=-26.3852332 -> V=1.0000025, theta=0.0
% INFO    : Bus 2795	: V=1.03064384, theta=-25.4535903 -> V=1.0003855, theta=0.0
% INFO    : Bus 2796	: V=0.989770036, theta=-11.9923295 -> V=1.0000015, theta=0.0
% INFO    : Bus 2797	: V=0.990876143, theta=-11.8695031 -> V=1.0000015, theta=0.0
% INFO    : Bus 2798	: V=1.06638357, theta=-14.6114547 -> V=1.022222, theta=0.0
% INFO    : Bus 2799	: V=1.06457257, theta=-11.7356998 -> V=0.9888895, theta=0.0
% INFO    : Bus 2800	: V=1.02600356, theta=-29.821741 -> V=1.0000025, theta=0.0
% INFO    : Bus 2801	: V=1.00670212, theta=-53.2491639 -> V=1.0079355, theta=0.0
% INFO    : Bus 2802	: V=1.05228931, theta=-39.5888245 -> V=1.022224, theta=0.0
% INFO    : Bus 2803	: V=1.06488615, theta=-35.6141686 -> V=1.04444, theta=0.0
% INFO    : Bus 2804	: V=1.01899818, theta=-22.6180343 -> V=1.0000025, theta=0.0
% INFO    : Bus 2805	: V=1.03797681, theta=-39.6661249 -> V=1.022224, theta=0.0
% INFO    : Bus 2806	: V=1.02186338, theta=-9.10675977 -> V=0.984126, theta=0.0
% INFO    : Bus 2807	: V=1.05479253, theta=-21.4189268 -> V=1.000001, theta=0.0
% INFO    : Bus 2808	: V=1.063063, theta=-17.0504886 -> V=1.044445, theta=0.0
% INFO    : Bus 2809	: V=1.05911515, theta=-14.8390019 -> V=1.000001, theta=0.0
% INFO    : Bus 2810	: V=1.04966521, theta=-19.4391261 -> V=1.0000025, theta=0.0
% INFO    : Bus 2811	: V=1.06226735, theta=-28.1467385 -> V=1.0000025, theta=0.0
% INFO    : Bus 2812	: V=1.03547157, theta=0.926663814 -> V=1.0158755, theta=0.0
% INFO    : Bus 2813	: V=1.08015116, theta=4.98526222 -> V=1.0377785, theta=0.0
% INFO    : Bus 2814	: V=1.08007064, theta=4.97275248 -> V=1.0377785, theta=0.0
% INFO    : Bus 2815	: V=1.04077306, theta=-39.3952078 -> V=1.022224, theta=0.0
% INFO    : Bus 2816	: V=1.02566933, theta=-33.9225582 -> V=1.0000025, theta=0.0
% INFO    : Bus 2817	: V=1.01430916, theta=-22.83018 -> V=1.0000025, theta=0.0
% INFO    : Bus 2818	: V=1.04625466, theta=-16.7486163 -> V=1.046665, theta=0.0
% INFO    : Bus 2819	: V=1.04522182, theta=-17.5005734 -> V=0.999999, theta=0.0
% INFO    : Bus 2820	: V=1.04012265, theta=-14.6470737 -> V=1.0111115, theta=0.0
% INFO    : Bus 2821	: V=1.0252724, theta=-35.8336359 -> V=1.022224, theta=0.0
% INFO    : Bus 2822	: V=1.02861012, theta=-19.5991078 -> V=1.022224, theta=0.0
% INFO    : Bus 2823	: V=1.03879791, theta=-15.9102664 -> V=0.9888895, theta=0.0
% INFO    : Bus 2824	: V=1.08037768, theta=0.670706724 -> V=0.9909245, theta=0.0
% INFO    : Bus 2825	: V=1.08185229, theta=2.46022569 -> V=1.05263, theta=0.0
% INFO    : Bus 2826	: V=1.015, theta=-30.0284913 -> V=1.0000005, theta=0.0
% INFO    : Bus 2827	: V=1.00693736, theta=-22.0271537 -> V=1.015872, theta=0.0
% INFO    : Bus 2828	: V=1.03803463, theta=-25.3285171 -> V=1.0000025, theta=0.0
% INFO    : Bus 2829	: V=1.05287928, theta=-22.3910818 -> V=1.0000025, theta=0.0
% INFO    : Bus 2830	: V=1.04143806, theta=-24.8249447 -> V=1.0000025, theta=0.0
% INFO    : Bus 2831	: V=1.05302877, theta=-12.2573699 -> V=1.033334, theta=0.0
% INFO    : Bus 2832	: V=1.02445896, theta=-12.7623441 -> V=0.999999, theta=0.0
% INFO    : Bus 2833	: V=1.04214098, theta=-18.9390151 -> V=1.022224, theta=0.0
% INFO    : Bus 2834	: V=1.02335197, theta=-6.50923693 -> V=1.0158755, theta=0.0
% INFO    : Bus 2835	: V=1.04826294, theta=-52.5679673 -> V=1.0079355, theta=0.0
% INFO    : Bus 2836	: V=1.01051652, theta=-30.9511753 -> V=1.022224, theta=0.0
% INFO    : Bus 2837	: V=1.03599319, theta=-25.4618066 -> V=1.0028855, theta=0.0
% INFO    : Bus 2838	: V=1.03366722, theta=-21.1421013 -> V=0.999999, theta=0.0
% INFO    : Bus 2839	: V=1.0360466, theta=-27.7661877 -> V=1.000001, theta=0.0
% INFO    : Bus 2840	: V=0.997138371, theta=-28.7114386 -> V=1.015872, theta=0.0
% INFO    : Bus 2841	: V=1.01955288, theta=-23.3544483 -> V=1.046665, theta=0.0
% INFO    : Bus 2842	: V=1.09152565, theta=-18.6225495 -> V=1.073685, theta=0.0
% INFO    : Bus 2843	: V=1.01309477, theta=-12.0465982 -> V=0.999999, theta=0.0
% INFO    : Bus 2844	: V=1.06853455, theta=-26.49124 -> V=1.046665, theta=0.0
% INFO    : Bus 2845	: V=1.07369817, theta=-28.6370963 -> V=1.046835, theta=0.0
% INFO    : Bus 2846	: V=1.00555679, theta=-30.7195773 -> V=1.0000005, theta=0.0
% INFO    : Bus 2847	: V=1.03640094, theta=-10.0705896 -> V=0.999999, theta=0.0
% INFO    : Bus 2848	: V=1.0534147, theta=-7.40831975 -> V=1.0111115, theta=0.0
% INFO    : Bus 2849	: V=1.04732047, theta=-24.6438842 -> V=1.0000025, theta=0.0
% INFO    : Bus 2850	: V=1.03814047, theta=-52.1726041 -> V=1.0079355, theta=0.0
% INFO    : Bus 2851	: V=1.03614719, theta=-26.861264 -> V=1.0000025, theta=0.0
% INFO    : Bus 2852	: V=1.03632758, theta=-26.7843753 -> V=1.0000025, theta=0.0
% INFO    : Bus 2853	: V=1.08572157, theta=-22.9364562 -> V=1.044445, theta=0.0
% INFO    : Bus 2854	: V=1.04737906, theta=-24.4689422 -> V=1.0000025, theta=0.0
% INFO    : Bus 2855	: V=1.02005817, theta=-15.7016867 -> V=1.015872, theta=0.0
% INFO    : Bus 2856	: V=1.06006259, theta=-41.911467 -> V=1.022224, theta=0.0
% INFO    : Bus 2857	: V=1.06840579, theta=-38.7824088 -> V=1.04444, theta=0.0
% INFO    : Bus 2858	: V=1.05161788, theta=-10.504217 -> V=1.004094, theta=0.0
% INFO    : Bus 2859	: V=1.05022071, theta=-10.5123458 -> V=1.003404, theta=0.0
% INFO    : Bus 2860	: V=1.04346663, theta=-10.5306384 -> V=1.000394, theta=0.0
% INFO    : Bus 2861	: V=1.02923739, theta=-28.4582948 -> V=1.022224, theta=0.0
% INFO    : Bus 2862	: V=1.04310408, theta=-24.9732224 -> V=1.000001, theta=0.0
% INFO    : Bus 2863	: V=1.00541596, theta=-22.4593032 -> V=1.0158755, theta=0.0
% INFO    : Bus 2864	: V=1.00601243, theta=-33.0421248 -> V=1.0000005, theta=0.0
% INFO    : Bus 2865	: V=0.991209533, theta=-41.3721313 -> V=1.022224, theta=0.0
% INFO    : Bus 2866	: V=1.02629254, theta=-18.6843627 -> V=1.0158755, theta=0.0
% INFO    : Bus 2867	: V=1.06297287, theta=-32.2948814 -> V=1.027779, theta=0.0
% INFO    : Bus 2868	: V=1.03834042, theta=-4.47778658 -> V=1.0000025, theta=0.0
% INFO    : Bus 2869	: V=1.02227844, theta=-42.6831599 -> V=1.022224, theta=0.0
% INFO    : Bus 2870	: V=1.02971862, theta=-15.1028155 -> V=1.015872, theta=0.0
% INFO    : Bus 2871	: V=1.00468667, theta=-2.49031578 -> V=1.0158755, theta=0.0
% INFO    : Bus 2872	: V=1.05620696, theta=-22.6894625 -> V=1.022224, theta=0.0
% INFO    : Bus 2873	: V=1.04945, theta=-9.51701698 -> V=1.0111115, theta=0.0
% INFO    : Bus 2874	: V=1.05052367, theta=-23.1710449 -> V=1.0000025, theta=0.0
% INFO    : Bus 2875	: V=0.997174909, theta=-24.4297714 -> V=1.0158755, theta=0.0
% INFO    : Bus 2876	: V=1.02085485, theta=-15.6305842 -> V=0.999999, theta=0.0
% INFO    : Bus 2877	: V=1.03202924, theta=0.840328857 -> V=1.0158755, theta=0.0
% INFO    : Bus 2878	: V=1.03469522, theta=-10.8127254 -> V=0.999999, theta=0.0
% INFO    : Bus 2879	: V=1.04749627, theta=-28.1862197 -> V=1.0000025, theta=0.0
% INFO    : Bus 2880	: V=0.98986813, theta=-20.0291637 -> V=1.015872, theta=0.0
% INFO    : Bus 2881	: V=1.01514415, theta=-10.9767249 -> V=1.015872, theta=0.0
% INFO    : Bus 2882	: V=1.06079623, theta=-10.3848812 -> V=1.002794, theta=0.0
% INFO    : Bus 2883	: V=1.03642941, theta=-13.4936669 -> V=0.999999, theta=0.0
% INFO    : Bus 2884	: V=1.05518686, theta=-7.95920139 -> V=1.0111115, theta=0.0
% INFO    : Bus 2885	: V=1.06292565, theta=-25.9254015 -> V=1.046665, theta=0.0
% INFO    : Bus 2886	: V=1.07160381, theta=-20.9740315 -> V=1.073685, theta=0.0
% INFO    : Bus 2887	: V=1.05121775, theta=-23.9783382 -> V=1.022224, theta=0.0
% INFO    : Bus 2888	: V=1.04023225, theta=-20.4444524 -> V=0.999999, theta=0.0
% INFO    : Bus 2889	: V=1.03703006, theta=-27.9309469 -> V=1.0000025, theta=0.0
% INFO    : Bus 2890	: V=1.01730628, theta=-4.17781183 -> V=1.0158755, theta=0.0
% INFO    : Bus 2891	: V=1.053639, theta=-28.9644512 -> V=1.0000025, theta=0.0
% INFO    : Bus 2892	: V=1.071, theta=-19.048722 -> V=0.975, theta=0.0
% INFO    : Bus 2893	: V=1.09612532, theta=-19.2239352 -> V=1.0113575, theta=0.0
% INFO    : Bus 2894	: V=1.07072625, theta=-19.5539629 -> V=1.044445, theta=0.0
% INFO    : Bus 2895	: V=0.994827939, theta=-22.2511539 -> V=1.0158755, theta=0.0
% INFO    : Bus 2896	: V=1.05427945, theta=-22.9007986 -> V=1.022224, theta=0.0
% INFO    : Bus 2897	: V=1.09811788, theta=-18.1715941 -> V=1.0, theta=0.0
% INFO    : Bus 2898	: V=1.02968528, theta=-12.6191767 -> V=0.999999, theta=0.0
% INFO    : Bus 2899	: V=1.02694525, theta=-25.329329 -> V=1.0000025, theta=0.0
% INFO    : Bus 2900	: V=1.01959283, theta=1.22440136 -> V=1.0158755, theta=0.0
% INFO    : Bus 2901	: V=1.03270391, theta=-26.8470243 -> V=1.0000025, theta=0.0
% INFO    : Bus 2902	: V=1.03509294, theta=-26.5873922 -> V=1.0000025, theta=0.0
% INFO    : Bus 2903	: V=1.01307006, theta=-31.0806071 -> V=1.022224, theta=0.0
% INFO    : Bus 2904	: V=1.03133852, theta=-51.2714273 -> V=1.0079355, theta=0.0
% INFO    : Bus 2905	: V=1.0403361, theta=-30.4597949 -> V=1.022224, theta=0.0
% INFO    : Bus 2906	: V=1.03886086, theta=-11.3277098 -> V=0.999999, theta=0.0
% INFO    : Bus 2907	: V=1.0535773, theta=-7.11037655 -> V=1.0111115, theta=0.0
% INFO    : Bus 2908	: V=1.05072085, theta=-7.12767649 -> V=1.0111115, theta=0.0
% INFO    : Bus 2909	: V=1.05711837, theta=-7.02008752 -> V=1.0111115, theta=0.0
% INFO    : Bus 2910	: V=1.06909951, theta=-2.813099 -> V=1.072365, theta=0.0
% INFO    : Bus 2911	: V=1.02719916, theta=-19.26793 -> V=1.015872, theta=0.0
% INFO    : Bus 2912	: V=1.03978133, theta=-26.0458839 -> V=1.0000025, theta=0.0
% INFO    : Bus 2913	: V=1.02720644, theta=-19.267791 -> V=1.015872, theta=0.0
% INFO    : Bus 2914	: V=1.0267397, theta=-26.9491481 -> V=1.0000025, theta=0.0
% INFO    : Bus 2915	: V=1.03372182, theta=-25.866035 -> V=1.022224, theta=0.0
% INFO    : Bus 2916	: V=1.02607759, theta=-6.98045839 -> V=1.0158755, theta=0.0
% INFO    : Bus 2917	: V=1.04126161, theta=-26.9799619 -> V=1.0000025, theta=0.0
% INFO    : Bus 2918	: V=1.04629788, theta=-19.6689801 -> V=1.0000025, theta=0.0
% INFO    : Bus 2919	: V=1.03810126, theta=-14.0015975 -> V=0.999999, theta=0.0
% INFO    : Bus 2920	: V=1.05940661, theta=-19.9850378 -> V=1.0000025, theta=0.0
% INFO    : Bus 2921	: V=1.010344, theta=-8.938026 -> V=0.999999, theta=0.0
% INFO    : Bus 2922	: V=1.04356422, theta=-21.1673195 -> V=1.000001, theta=0.0
% INFO    : Bus 2923	: V=1.05121157, theta=-3.6991874 -> V=1.0000025, theta=0.0
% INFO    : Bus 2924	: V=1.07696862, theta=-0.149862998 -> V=0.9891595, theta=0.0
% INFO    : Bus 2925	: V=1.07693445, theta=-0.11694117 -> V=0.9891395, theta=0.0
% INFO    : Bus 2926	: V=1.03762383, theta=-25.0324234 -> V=1.046665, theta=0.0
% INFO    : Bus 2927	: V=1.00026284, theta=-21.1356486 -> V=0.999999, theta=0.0
% INFO    : Bus 2928	: V=1.04063779, theta=-11.3508794 -> V=0.999999, theta=0.0
% INFO    : Bus 2929	: V=1.03944866, theta=-11.6919173 -> V=0.999999, theta=0.0
% INFO    : Bus 2930	: V=1.05017686, theta=-8.06617813 -> V=1.0111115, theta=0.0
% INFO    : Bus 2931	: V=1.04694979, theta=-10.3304402 -> V=1.001569, theta=0.0
% INFO    : Bus 2932	: V=1.05840623, theta=-25.1226968 -> V=1.046665, theta=0.0
% INFO    : Bus 2933	: V=1.01811128, theta=-24.8396244 -> V=1.0000025, theta=0.0
% INFO    : Bus 2934	: V=1.01524209, theta=-30.0794478 -> V=1.022224, theta=0.0
% INFO    : Bus 2935	: V=1.03038826, theta=-14.8078396 -> V=1.015872, theta=0.0
% INFO    : Bus 2936	: V=1.03038826, theta=-14.8078396 -> V=1.015872, theta=0.0
% INFO    : Bus 2937	: V=1.06858897, theta=-14.3384556 -> V=1.000001, theta=0.0
% INFO    : Bus 2938	: V=1.09190956, theta=-13.0952189 -> V=1.04633, theta=0.0
% INFO    : Bus 2939	: V=1.03558767, theta=-33.1853275 -> V=1.022224, theta=0.0
% INFO    : Bus 2940	: V=1.0829459, theta=-27.4796709 -> V=1.07237, theta=0.0
% INFO    : Bus 2941	: V=0.99984254, theta=-29.1937013 -> V=1.0158755, theta=0.0
% INFO    : Bus 2942	: V=0.992666591, theta=-24.5993548 -> V=1.0158755, theta=0.0
% INFO    : Bus 2943	: V=1.02518754, theta=-5.84622241 -> V=1.0158755, theta=0.0
% INFO    : Bus 2944	: V=1.05954601, theta=-0.899957116 -> V=1.0377785, theta=0.0
% INFO    : Bus 2945	: V=1.05853969, theta=-0.886573622 -> V=1.0377785, theta=0.0
% INFO    : Bus 2946	: V=1.03169247, theta=-21.2869884 -> V=0.999999, theta=0.0
% INFO    : Bus 2947	: V=1.05484012, theta=-37.9889887 -> V=1.022224, theta=0.0
% INFO    : Bus 2948	: V=0.996671951, theta=-2.29039556 -> V=1.0158755, theta=0.0
% INFO    : Bus 2949	: V=1.04541982, theta=-34.3309668 -> V=1.022224, theta=0.0
% INFO    : Bus 2950	: V=1.0070348, theta=-11.4313944 -> V=1.015872, theta=0.0
% INFO    : Bus 2951	: V=1.05028566, theta=-20.9841319 -> V=1.0000025, theta=0.0
% INFO    : Bus 2952	: V=1.0921331, theta=-19.2282196 -> V=1.0, theta=0.0
% INFO    : Bus 2953	: V=1.0323425, theta=-30.3003448 -> V=1.022224, theta=0.0
% INFO    : Bus 2954	: V=1.01337114, theta=-21.5865103 -> V=1.0000025, theta=0.0
% INFO    : Bus 2955	: V=1.05682732, theta=-30.340247 -> V=1.022224, theta=0.0
% INFO    : Bus 2956	: V=1.06813502, theta=-22.7025592 -> V=1.046665, theta=0.0
% INFO    : Bus 2957	: V=1.06369951, theta=-24.5741921 -> V=1.046665, theta=0.0
% INFO    : Bus 2958	: V=1.06669885, theta=-25.8661962 -> V=1.046665, theta=0.0
% INFO    : Bus 2959	: V=1.06371432, theta=-24.5713456 -> V=1.046665, theta=0.0
% INFO    : Bus 2960	: V=1.06813417, theta=-22.7009044 -> V=1.046665, theta=0.0
% INFO    : Bus 2961	: V=1.06079586, theta=-17.6417084 -> V=1.073685, theta=0.0
% INFO    : Bus 2962	: V=1.05908998, theta=-18.3505205 -> V=1.073685, theta=0.0
% INFO    : Bus 2963	: V=1.05834191, theta=-20.7459112 -> V=1.0000025, theta=0.0
% INFO    : Bus 2964	: V=1.05651149, theta=-22.0872558 -> V=1.0000025, theta=0.0
% INFO    : Bus 2965	: V=1.07469975, theta=-17.4975881 -> V=1.044445, theta=0.0
% INFO    : Bus 2966	: V=1.0334488, theta=-13.7744981 -> V=0.999999, theta=0.0
% INFO    : Bus 2967	: V=1.01008107, theta=-16.4374307 -> V=0.999999, theta=0.0
% INFO    : Bus 2968	: V=1.03119297, theta=-12.9637242 -> V=1.0158755, theta=0.0
% INFO    : Bus 2969	: V=1.02809587, theta=-31.492993 -> V=1.027779, theta=0.0
% INFO    : Bus 2970	: V=1.02032349, theta=-43.3850382 -> V=1.022224, theta=0.0
% INFO    : Bus 2971	: V=1.04201799, theta=-31.5056448 -> V=1.022224, theta=0.0
% INFO    : Bus 2972	: V=1.02260174, theta=-53.3929209 -> V=1.0079355, theta=0.0
% INFO    : Bus 2973	: V=1.05624946, theta=-14.8445156 -> V=1.0000025, theta=0.0
% INFO    : Bus 2974	: V=1.03686388, theta=-17.3585257 -> V=1.0000025, theta=0.0
% INFO    : Bus 2975	: V=1.05727621, theta=-36.1522985 -> V=1.027779, theta=0.0
% INFO    : Bus 2976	: V=1.04693199, theta=-23.3451586 -> V=1.027779, theta=0.0
% INFO    : Bus 2977	: V=1.02121869, theta=-27.8088622 -> V=1.0000005, theta=0.0
% INFO    : Bus 2978	: V=1.03997703, theta=-23.6996988 -> V=1.046665, theta=0.0
% INFO    : Bus 2979	: V=1.04354202, theta=-30.5130382 -> V=1.027779, theta=0.0
% INFO    : Bus 2980	: V=1.02372266, theta=-20.8356184 -> V=0.999999, theta=0.0
% INFO    : Bus 2981	: V=1.02452191, theta=-14.3203489 -> V=1.015872, theta=0.0
% INFO    : Bus 2982	: V=1.04255318, theta=-10.3713511 -> V=1.046665, theta=0.0
% INFO    : Bus 2983	: V=1.06424259, theta=-14.5208977 -> V=1.002289, theta=0.0
% INFO    : Bus 2984	: V=1.01951986, theta=-11.031985 -> V=0.999999, theta=0.0
% INFO    : Bus 2985	: V=1.05641227, theta=-15.6962873 -> V=1.022222, theta=0.0
% INFO    : Bus 2986	: V=1.051, theta=-8.66975579 -> V=0.999999, theta=0.0
% INFO    : Bus 2987	: V=1.04977036, theta=-10.1483753 -> V=0.975, theta=0.0
% INFO    : Bus 2988	: V=1.04872164, theta=-10.1483753 -> V=1.002444, theta=0.0
% INFO    : Bus 2989	: V=1.04421261, theta=-10.396416 -> V=1.000764, theta=0.0
% INFO    : Bus 2990	: V=1.05369975, theta=-7.11105627 -> V=1.0111115, theta=0.0
% INFO    : Bus 2991	: V=1.04810009, theta=-7.92068464 -> V=1.0111115, theta=0.0
% INFO    : Bus 2992	: V=1.01547757, theta=-32.320547 -> V=1.015872, theta=0.0
% INFO    : Bus 2993	: V=1.04749959, theta=-28.3233573 -> V=1.046665, theta=0.0
% INFO    : Bus 2994	: V=1.03411848, theta=-21.3356231 -> V=1.0000025, theta=0.0
% INFO    : Bus 2995	: V=1.0596647, theta=-13.9302662 -> V=1.044445, theta=0.0
% INFO    : Bus 2996	: V=1.03055511, theta=-30.6747373 -> V=1.0000025, theta=0.0
% INFO    : Bus 2997	: V=1.04172021, theta=-11.4199435 -> V=1.046665, theta=0.0
% INFO    : Bus 2998	: V=1.0408544, theta=-24.0799753 -> V=1.000001, theta=0.0
% INFO    : Bus 2999	: V=1.06874121, theta=-26.4189833 -> V=1.046665, theta=0.0
% INFO    : Bus 3000	: V=1.044103, theta=-27.9773485 -> V=1.0000025, theta=0.0
% INFO    : Bus 3001	: V=1.03560332, theta=1.21564129 -> V=1.0158755, theta=0.0
% INFO    : Bus 3002	: V=1.07417823, theta=4.12762768 -> V=1.0377785, theta=0.0
% INFO    : Bus 3003	: V=1.08525462, theta=6.19695886 -> V=1.072365, theta=0.0
% INFO    : Bus 3004	: V=1.00736922, theta=-0.267338974 -> V=1.0158755, theta=0.0
% INFO    : Bus 3005	: V=1.05719216, theta=-29.6919306 -> V=1.0000025, theta=0.0
% INFO    : Bus 3006	: V=1.02346377, theta=-12.0262319 -> V=0.999999, theta=0.0
% INFO    : Bus 3007	: V=1.0397712, theta=-8.98396116 -> V=1.0158755, theta=0.0
% INFO    : Bus 3008	: V=1.06375966, theta=-20.45854 -> V=1.024759, theta=0.0
% INFO    : Bus 3009	: V=1.06744718, theta=-16.4590157 -> V=1.04444, theta=0.0
% INFO    : Bus 3010	: V=1.01908074, theta=-17.3377041 -> V=1.015872, theta=0.0
% INFO    : Bus 3011	: V=1.03029233, theta=-21.7212437 -> V=1.0000025, theta=0.0
% INFO    : Bus 3012	: V=1.05255268, theta=-30.7220107 -> V=1.022224, theta=0.0
% INFO    : Bus 3013	: V=1.02657391, theta=-14.2933189 -> V=1.0158755, theta=0.0
% INFO    : Bus 3014	: V=1.02312861, theta=-9.68641825 -> V=0.999999, theta=0.0
% INFO    : Bus 3015	: V=1.048, theta=-12.8665072 -> V=1.002359, theta=0.0
% INFO    : Bus 3016	: V=1.0232924, theta=-4.04779418 -> V=1.0000025, theta=0.0
% INFO    : Bus 3017	: V=1.03273442, theta=-39.5968799 -> V=1.022224, theta=0.0
% INFO    : Bus 3018	: V=1.03326411, theta=-6.08372841 -> V=1.0158755, theta=0.0
% INFO    : Bus 3019	: V=1.03320414, theta=-6.08037307 -> V=1.0158755, theta=0.0
% INFO    : Bus 3020	: V=1.04096095, theta=-20.5809436 -> V=1.0000025, theta=0.0
% INFO    : Bus 3021	: V=1.03357266, theta=-28.3626402 -> V=1.015872, theta=0.0
% INFO    : Bus 3022	: V=1.05517429, theta=-18.9129181 -> V=1.022222, theta=0.0
% INFO    : Bus 3023	: V=1.04181218, theta=-20.4455353 -> V=1.0000025, theta=0.0
% INFO    : Bus 3024	: V=1.07786422, theta=-16.8254368 -> V=1.044445, theta=0.0
% INFO    : Bus 3025	: V=1.08495457, theta=-11.5965978 -> V=1.078945, theta=0.0
% INFO    : Bus 3026	: V=1.01048274, theta=-19.7858914 -> V=1.015872, theta=0.0
% INFO    : Bus 3027	: V=1.02064316, theta=-26.6450397 -> V=1.0000025, theta=0.0
% INFO    : Bus 3028	: V=1.04658774, theta=-26.8996231 -> V=1.0000025, theta=0.0
% INFO    : Bus 3029	: V=1.01599538, theta=-10.5017645 -> V=1.015872, theta=0.0
% INFO    : Bus 3030	: V=0.992832717, theta=-25.0319061 -> V=1.0158755, theta=0.0
% INFO    : Bus 3031	: V=1.08051449, theta=-16.9615017 -> V=1.044445, theta=0.0
% INFO    : Bus 3032	: V=1.02565196, theta=-31.171054 -> V=1.0000005, theta=0.0
% INFO    : Bus 3033	: V=1.03822007, theta=-12.8866712 -> V=0.999999, theta=0.0
% INFO    : Bus 3034	: V=1.0262249, theta=-23.4530726 -> V=1.0000025, theta=0.0
% INFO    : Bus 3035	: V=1.02154846, theta=-24.068542 -> V=1.0000025, theta=0.0
% INFO    : Bus 3036	: V=1.01037367, theta=-20.1311183 -> V=1.0158755, theta=0.0
% INFO    : Bus 3037	: V=1.04763802, theta=-15.700353 -> V=1.0158755, theta=0.0
% INFO    : Bus 3038	: V=1.05817907, theta=-30.4321015 -> V=1.022224, theta=0.0
% INFO    : Bus 3039	: V=1.02325616, theta=-23.2801361 -> V=1.0000025, theta=0.0
% INFO    : Bus 3040	: V=1.04484039, theta=-15.6947838 -> V=0.9888895, theta=0.0
% INFO    : Bus 3041	: V=1.01784741, theta=-14.0589679 -> V=1.015872, theta=0.0
% INFO    : Bus 3042	: V=1.00558275, theta=-12.220116 -> V=1.015872, theta=0.0
% INFO    : Bus 3043	: V=1.06153218, theta=-25.6006055 -> V=1.023434, theta=0.0
% INFO    : Bus 3044	: V=1.0327884, theta=-12.1812886 -> V=0.999999, theta=0.0
% INFO    : Bus 3045	: V=0.997324625, theta=-26.0752443 -> V=1.0000005, theta=0.0
% INFO    : Bus 3046	: V=1.01338674, theta=-25.526678 -> V=1.0000005, theta=0.0
% INFO    : Bus 3047	: V=1.04957552, theta=-19.054996 -> V=1.046665, theta=0.0
% INFO    : Bus 3048	: V=1.04957573, theta=-19.0549983 -> V=1.046665, theta=0.0
% INFO    : Bus 3049	: V=1.10478675, theta=-8.39423919 -> V=1.08024, theta=0.0
% INFO    : Bus 3050	: V=1.10485245, theta=-8.37444405 -> V=1.08027, theta=0.0
% INFO    : Bus 3051	: V=1.10485216, theta=-8.37468595 -> V=1.08027, theta=0.0
% INFO    : Bus 3052	: V=1.03999335, theta=-18.4952222 -> V=0.999999, theta=0.0
% INFO    : Bus 3053	: V=1.03432978, theta=-43.1211134 -> V=1.022224, theta=0.0
% INFO    : Bus 3054	: V=1.03860815, theta=-32.8557331 -> V=1.0057055, theta=0.0
% INFO    : Bus 3055	: V=1.03816631, theta=-33.9262486 -> V=1.0055255, theta=0.0
% INFO    : Bus 3056	: V=1.06283833, theta=-25.1608899 -> V=1.024094, theta=0.0
% INFO    : Bus 3057	: V=1.0723164, theta=-20.9378647 -> V=1.04444, theta=0.0
% INFO    : Bus 3058	: V=1.03917333, theta=-20.7192126 -> V=1.000001, theta=0.0
% INFO    : Bus 3059	: V=1.05501694, theta=-24.0772824 -> V=1.027779, theta=0.0
% INFO    : Bus 3060	: V=1.05165562, theta=-29.1860859 -> V=1.027779, theta=0.0
% INFO    : Bus 3061	: V=1.05978773, theta=-24.5707429 -> V=1.046665, theta=0.0
% INFO    : Bus 3062	: V=1.05872494, theta=-24.533815 -> V=1.046665, theta=0.0
% INFO    : Bus 3063	: V=0.994115916, theta=-14.3411218 -> V=1.015872, theta=0.0
% INFO    : Bus 3064	: V=1.01846668, theta=-31.2941477 -> V=1.0000025, theta=0.0
% INFO    : Bus 3065	: V=1.0351685, theta=-42.2033265 -> V=1.0079355, theta=0.0
% INFO    : Bus 3066	: V=1.04424546, theta=-17.7445403 -> V=0.999999, theta=0.0
% INFO    : Bus 3067	: V=1.05729952, theta=-14.459252 -> V=1.0111115, theta=0.0
% INFO    : Bus 3068	: V=1.03581994, theta=-13.8401053 -> V=0.999999, theta=0.0
% INFO    : Bus 3069	: V=0.97626175, theta=-17.1259381 -> V=1.015872, theta=0.0
% INFO    : Bus 3070	: V=1.04505997, theta=-11.2075626 -> V=0.999999, theta=0.0
% INFO    : Bus 3071	: V=1.00270802, theta=-19.5816486 -> V=0.984126, theta=0.0
% INFO    : Bus 3072	: V=1.0331715, theta=-21.0641271 -> V=1.022224, theta=0.0
% INFO    : Bus 3073	: V=1.03587244, theta=-38.6599718 -> V=1.0079355, theta=0.0
% INFO    : Bus 3074	: V=1.0157376, theta=0.583856982 -> V=1.0158755, theta=0.0
% INFO    : Bus 3075	: V=1.07319556, theta=3.19497082 -> V=1.0377785, theta=0.0
% INFO    : Bus 3076	: V=1.03765164, theta=-24.1562625 -> V=1.0000025, theta=0.0
% INFO    : Bus 3077	: V=1.01961321, theta=-28.184324 -> V=1.0000025, theta=0.0
% INFO    : Bus 3078	: V=1.04207815, theta=-19.2663792 -> V=1.0000025, theta=0.0
% INFO    : Bus 3079	: V=1.0602744, theta=-15.6346573 -> V=1.044445, theta=0.0
% INFO    : Bus 3080	: V=1.02667769, theta=-10.7417783 -> V=0.999999, theta=0.0
% INFO    : Bus 3081	: V=1.05031654, theta=-8.24497199 -> V=1.0111115, theta=0.0
% INFO    : Bus 3082	: V=1.0155359, theta=-32.5149144 -> V=1.0000025, theta=0.0
% INFO    : Bus 3083	: V=1.03900953, theta=-34.4046635 -> V=1.022224, theta=0.0
% INFO    : Bus 3084	: V=1.00856679, theta=-17.5672379 -> V=0.999999, theta=0.0
% INFO    : Bus 3085	: V=1.03514779, theta=-32.836784 -> V=1.022224, theta=0.0
% INFO    : Bus 3086	: V=0.933654094, theta=-6.47116096 -> V=0.9444445, theta=0.0
% INFO    : Bus 3087	: V=0.980741273, theta=-5.08164235 -> V=0.9444445, theta=0.0
% INFO    : Bus 3088	: V=1.02065333, theta=-17.6892155 -> V=0.999999, theta=0.0
% INFO    : Bus 3089	: V=1.02808507, theta=-33.3767403 -> V=1.0000005, theta=0.0
% INFO    : Bus 3090	: V=1.00013852, theta=-29.3007472 -> V=1.0000005, theta=0.0
% INFO    : Bus 3091	: V=0.98, theta=-10.1446521 -> V=0.9444445, theta=0.0
% INFO    : Bus 3092	: V=0.998039241, theta=-21.180196 -> V=0.999999, theta=0.0
% INFO    : Bus 3093	: V=1.03620267, theta=-16.4587184 -> V=0.999999, theta=0.0
% INFO    : Bus 3094	: V=1.05633796, theta=-13.8109819 -> V=1.0111115, theta=0.0
% INFO    : Bus 3095	: V=1.07341284, theta=-28.6860274 -> V=1.046695, theta=0.0
% INFO    : Bus 3096	: V=1.10477731, theta=2.59354189 -> V=1.072365, theta=0.0
% INFO    : Bus 3097	: V=1.03081001, theta=-6.44234926 -> V=1.0158755, theta=0.0
% INFO    : Bus 3098	: V=1.02620169, theta=-7.6804152 -> V=1.0158755, theta=0.0
% INFO    : Bus 3099	: V=1.02200182, theta=-9.51751866 -> V=0.999999, theta=0.0
% INFO    : Bus 3100	: V=1.02510659, theta=-9.2142824 -> V=0.999999, theta=0.0
% INFO    : Bus 3101	: V=1.0196575, theta=-33.3910779 -> V=1.0000005, theta=0.0
% INFO    : Bus 3102	: V=1.05908198, theta=-26.6850241 -> V=1.046665, theta=0.0
% INFO    : Bus 3103	: V=1.06153872, theta=-4.77355074 -> V=1.0377785, theta=0.0
% INFO    : Bus 3104	: V=1.04961925, theta=-30.1029291 -> V=1.0000025, theta=0.0
% INFO    : Bus 3105	: V=1.04396203, theta=-15.7921034 -> V=1.0000025, theta=0.0
% INFO    : Bus 3106	: V=1.02748801, theta=-57.9006996 -> V=1.0079355, theta=0.0
% INFO    : Bus 3107	: V=1.04415937, theta=-20.4087243 -> V=1.022224, theta=0.0
% INFO    : Bus 3108	: V=1.04732127, theta=-21.5965621 -> V=1.022224, theta=0.0
% INFO    : Bus 3109	: V=1.066, theta=5.34732574 -> V=0.975, theta=0.0
% INFO    : Bus 3110	: V=1.097, theta=4.33185237 -> V=0.975, theta=0.0
% INFO    : Bus 3111	: V=1.081, theta=4.78889166 -> V=0.975, theta=0.0
% INFO    : Bus 3112	: V=1.06591499, theta=-0.629893868 -> V=1.0377785, theta=0.0
% INFO    : Bus 3113	: V=1.06602514, theta=-0.632585976 -> V=1.0377785, theta=0.0
% INFO    : Bus 3114	: V=1.0659689, theta=-0.63139534 -> V=1.0377785, theta=0.0
% INFO    : Bus 3115	: V=1.04360676, theta=-45.452172 -> V=1.022224, theta=0.0
% INFO    : Bus 3116	: V=1.04500309, theta=-15.7732312 -> V=0.999999, theta=0.0
% INFO    : Bus 3117	: V=1.02155739, theta=-52.1013422 -> V=1.0079355, theta=0.0
% INFO    : Bus 3118	: V=1.02459197, theta=-22.7270851 -> V=0.999999, theta=0.0
% INFO    : Bus 3119	: V=1.02396484, theta=-20.6031217 -> V=1.0000025, theta=0.0
% INFO    : Bus 3120	: V=1.04637106, theta=-27.1412149 -> V=1.0000025, theta=0.0
% INFO    : Bus 3121	: V=0.964067205, theta=-25.7661643 -> V=1.0, theta=0.0
% INFO    : Bus 3122	: V=1.03597341, theta=-5.78819791 -> V=0.984126, theta=0.0
% INFO    : Bus 3123	: V=1.07250389, theta=-16.4363953 -> V=1.0046025, theta=0.0
% INFO    : Bus 3124	: V=0.986461839, theta=-23.1695626 -> V=1.015872, theta=0.0
% INFO    : Bus 3125	: V=1.02085328, theta=-31.250101 -> V=1.022224, theta=0.0
% INFO    : Bus 3126	: V=1.06171299, theta=-20.6805211 -> V=1.022222, theta=0.0
% INFO    : Bus 3127	: V=1.05361999, theta=-12.8946937 -> V=1.002179, theta=0.0
% INFO    : Bus 3128	: V=1.07148628, theta=-5.9126233 -> V=1.072365, theta=0.0
% INFO    : Bus 3129	: V=1.073, theta=-18.6068612 -> V=1.000001, theta=0.0
% INFO    : Bus 3130	: V=1.05337452, theta=-14.4827614 -> V=0.9888895, theta=0.0
% INFO    : Bus 3131	: V=1.0540301, theta=-14.4710279 -> V=0.9888895, theta=0.0
% INFO    : Bus 3132	: V=1.0410545, theta=-6.22811284 -> V=1.0158755, theta=0.0
% INFO    : Bus 3133	: V=1.0677873, theta=3.8194557 -> V=1.0377785, theta=0.0
% INFO    : Bus 3134	: V=1.02894345, theta=-22.7137128 -> V=1.0000025, theta=0.0
% INFO    : Bus 3135	: V=1.04607215, theta=-21.1411437 -> V=1.0000025, theta=0.0
% INFO    : Bus 3136	: V=1.02773063, theta=-16.6825975 -> V=1.015872, theta=0.0
% INFO    : Bus 3137	: V=1.06139277, theta=-23.9402783 -> V=1.046665, theta=0.0
% INFO    : Bus 3138	: V=1.0285307, theta=-27.1880512 -> V=1.0000005, theta=0.0
% INFO    : Bus 3139	: V=1.0614005, theta=-23.9399435 -> V=1.046665, theta=0.0
% INFO    : Bus 3140	: V=1.0210897, theta=-26.316094 -> V=1.0000025, theta=0.0
% INFO    : Bus 3141	: V=1.02541266, theta=-19.4165473 -> V=1.015872, theta=0.0
% INFO    : Bus 3142	: V=1.05248865, theta=-14.6015462 -> V=1.033334, theta=0.0
% INFO    : Bus 3143	: V=1.00613437, theta=-14.620116 -> V=1.05336, theta=0.0
% INFO    : Bus 3144	: V=1.01300177, theta=-13.6576045 -> V=1.0158755, theta=0.0
% INFO    : Bus 3145	: V=1.02076815, theta=-10.6454771 -> V=1.0277795, theta=0.0
% INFO    : Bus 3146	: V=1.07068754, theta=-9.90129681 -> V=1.072365, theta=0.0
% INFO    : Bus 3147	: V=1.07041437, theta=-10.2582788 -> V=1.072365, theta=0.0
% INFO    : Bus 3148	: V=1.02138301, theta=-27.4758642 -> V=1.0000025, theta=0.0
% INFO    : Bus 3149	: V=1.04388611, theta=-12.2632562 -> V=0.999999, theta=0.0
% INFO    : Bus 3150	: V=1.06, theta=-19.0568602 -> V=1.0111115, theta=0.0
% INFO    : Bus 3151	: V=1.0372149, theta=-20.6337842 -> V=0.999999, theta=0.0
% INFO    : Bus 3152	: V=1.076, theta=-19.0598927 -> V=1.000001, theta=0.0
% INFO    : Bus 3153	: V=1.03316721, theta=-26.0443085 -> V=1.022224, theta=0.0
% INFO    : Bus 3154	: V=1.0152403, theta=-28.4241426 -> V=1.0000005, theta=0.0
% INFO    : Bus 3155	: V=1.03625176, theta=-8.99325741 -> V=0.999999, theta=0.0
% INFO    : Bus 3156	: V=1.07482708, theta=-28.4228079 -> V=1.04739, theta=0.0
% INFO    : Bus 3157	: V=1.0272321, theta=-22.1581985 -> V=1.0000025, theta=0.0
% INFO    : Bus 3158	: V=1.08062239, theta=-17.6382739 -> V=1.04711, theta=0.0
% INFO    : Bus 3159	: V=0.998550394, theta=-22.3114433 -> V=1.0000025, theta=0.0
% INFO    : Bus 3160	: V=1.06290962, theta=-24.9670291 -> V=1.046665, theta=0.0
% INFO    : Bus 3161	: V=1.07419533, theta=-25.8405226 -> V=1.048025, theta=0.0
% INFO    : Bus 3162	: V=1.03928876, theta=-32.4417666 -> V=1.022224, theta=0.0
% INFO    : Bus 3163	: V=1.03588751, theta=-14.5004493 -> V=0.999999, theta=0.0
% INFO    : Bus 3164	: V=1.01413579, theta=-28.5940104 -> V=1.0000025, theta=0.0
% INFO    : Bus 3165	: V=1.03999326, theta=-20.6139085 -> V=1.000001, theta=0.0
% INFO    : Bus 3166	: V=1.01701527, theta=-21.9850776 -> V=1.0158755, theta=0.0
% INFO    : Bus 3167	: V=1.01806633, theta=-22.9738712 -> V=1.0000025, theta=0.0
% INFO    : Bus 3168	: V=1.03937395, theta=-24.0139171 -> V=1.0035005, theta=0.0
% INFO    : Bus 3169	: V=1.04266896, theta=-19.4323045 -> V=1.046665, theta=0.0
% INFO    : Bus 3170	: V=1.02714067, theta=-51.274525 -> V=1.0079355, theta=0.0
% INFO    : Bus 3171	: V=1.01614371, theta=-24.4772245 -> V=1.0, theta=0.0
% INFO    : Bus 3172	: V=1.04594398, theta=-21.373654 -> V=1.046665, theta=0.0
% INFO    : Bus 3173	: V=1.03918214, theta=-18.3307634 -> V=1.06579, theta=0.0
% INFO    : Bus 3174	: V=1.03806775, theta=-27.592286 -> V=1.0000025, theta=0.0
% INFO    : Bus 3175	: V=1.00017175, theta=-22.288908 -> V=1.022224, theta=0.0
% INFO    : Bus 3176	: V=1.0656574, theta=-20.677884 -> V=0.993746, theta=0.0
% INFO    : Bus 3177	: V=1.04750338, theta=-27.7643699 -> V=1.027779, theta=0.0
% INFO    : Bus 3178	: V=1.04046737, theta=-24.8902232 -> V=1.000001, theta=0.0
% INFO    : Bus 3179	: V=1.01868746, theta=-11.4418336 -> V=1.0158755, theta=0.0
% INFO    : Bus 3180	: V=1.02900425, theta=-17.0078029 -> V=0.999999, theta=0.0
% INFO    : Bus 3181	: V=1.06724651, theta=-16.5301639 -> V=1.006729, theta=0.0
% INFO    : Bus 3182	: V=1.01778483, theta=-11.4222507 -> V=1.0079355, theta=0.0
% INFO    : Bus 3183	: V=1.02715246, theta=-15.832238 -> V=1.0158755, theta=0.0
% INFO    : Bus 3184	: V=1.04892796, theta=-25.9130883 -> V=1.046665, theta=0.0
% INFO    : Bus 3185	: V=1.04889952, theta=-25.9162271 -> V=1.046665, theta=0.0
% INFO    : Bus 3186	: V=1.05033561, theta=-26.4555556 -> V=1.022224, theta=0.0
% INFO    : Bus 3187	: V=1.04349033, theta=-13.1851601 -> V=1.046665, theta=0.0
% INFO    : Bus 3188	: V=1.01804056, theta=-19.5290689 -> V=1.015872, theta=0.0
% INFO    : Bus 3189	: V=1.03883391, theta=-27.8323837 -> V=1.022224, theta=0.0
% INFO    : Bus 3190	: V=1.03800796, theta=-28.5787569 -> V=1.022224, theta=0.0
% INFO    : Bus 3191	: V=1.06793877, theta=-24.3354888 -> V=1.04444, theta=0.0
% INFO    : Bus 3192	: V=1.06952699, theta=-26.035379 -> V=1.04444, theta=0.0
% INFO    : Bus 3193	: V=1.05995942, theta=-20.1375342 -> V=1.0000025, theta=0.0
% INFO    : Bus 3194	: V=1.0226936, theta=-16.9277355 -> V=0.984126, theta=0.0
% INFO    : Bus 3195	: V=1.0210264, theta=-13.760095 -> V=0.995556, theta=0.0
% INFO    : Bus 3196	: V=1.01990016, theta=-30.3242965 -> V=1.0000025, theta=0.0
% INFO    : Bus 3197	: V=1.06478764, theta=-24.7681227 -> V=1.046665, theta=0.0
% INFO    : Bus 3198	: V=1.0637176, theta=-24.8235542 -> V=1.046665, theta=0.0
% INFO    : Bus 3199	: V=1.05128835, theta=-33.7330944 -> V=1.027779, theta=0.0
% INFO    : Bus 3200	: V=1.04854305, theta=-37.133916 -> V=1.0000025, theta=0.0
% INFO    : Bus 3201	: V=1.06139644, theta=-14.1340827 -> V=1.022222, theta=0.0
% INFO    : Bus 3202	: V=1.03553135, theta=2.52319827 -> V=1.0158755, theta=0.0
% INFO    : Bus 3203	: V=1.098, theta=-18.1712103 -> V=1.0, theta=0.0
% INFO    : Bus 3204	: V=1.05434175, theta=-15.5176038 -> V=1.0000025, theta=0.0
% INFO    : Bus 3205	: V=1.05814649, theta=-26.7185372 -> V=1.046665, theta=0.0
% INFO    : Bus 3206	: V=1.04521319, theta=-4.39751844 -> V=0.9733695, theta=0.0
% INFO    : Bus 3207	: V=1.05067985, theta=-15.2675861 -> V=1.0158755, theta=0.0
% INFO    : Bus 3208	: V=1.05829834, theta=-26.6689317 -> V=1.0139055, theta=0.0
% INFO    : Bus 3209	: V=0.989605083, theta=-30.1949275 -> V=1.0000005, theta=0.0
% INFO    : Bus 3210	: V=1.03144607, theta=-26.6667971 -> V=1.046665, theta=0.0
% INFO    : Bus 3211	: V=1.03023084, theta=-41.5483284 -> V=1.022224, theta=0.0
% INFO    : Bus 3212	: V=1.04057274, theta=-23.153345 -> V=1.0000025, theta=0.0
% INFO    : Bus 3213	: V=1.03493621, theta=-25.4964663 -> V=1.0023505, theta=0.0
% INFO    : Bus 3214	: V=1.05407236, theta=-28.8997538 -> V=1.027779, theta=0.0
% INFO    : Bus 3215	: V=1.01763561, theta=-19.3481094 -> V=1.0158755, theta=0.0
% INFO    : Bus 3216	: V=1.023429, theta=-18.4559762 -> V=1.0158755, theta=0.0
% INFO    : Bus 3217	: V=0.96817912, theta=-20.2399518 -> V=1.015872, theta=0.0
% INFO    : Bus 3218	: V=0.952925392, theta=-7.71355277 -> V=0.9444445, theta=0.0
% INFO    : Bus 3219	: V=1.04310437, theta=-39.2735945 -> V=1.022224, theta=0.0
% INFO    : Bus 3220	: V=1.00174173, theta=-23.3382258 -> V=1.0158755, theta=0.0
% INFO    : Bus 3221	: V=1.03180959, theta=-24.6217417 -> V=1.027779, theta=0.0
% INFO    : Bus 3222	: V=1.0220906, theta=-3.24270017 -> V=1.0158755, theta=0.0
% INFO    : Bus 3223	: V=1.08816297, theta=1.93109456 -> V=1.072365, theta=0.0
% INFO    : Bus 3224	: V=1.06469777, theta=-24.6182567 -> V=1.046665, theta=0.0
% INFO    : Bus 3225	: V=1.06474455, theta=-24.615065 -> V=1.046665, theta=0.0
% INFO    : Bus 3226	: V=1.06474636, theta=-24.6138807 -> V=1.046665, theta=0.0
% INFO    : Bus 3227	: V=1.02687614, theta=-29.1471655 -> V=1.022224, theta=0.0
% INFO    : Bus 3228	: V=0.986567555, theta=-41.023565 -> V=1.022224, theta=0.0
% INFO    : Bus 3229	: V=1.06767856, theta=-10.9612526 -> V=1.072365, theta=0.0
% INFO    : Bus 3230	: V=1.06766346, theta=-11.0610323 -> V=1.072365, theta=0.0
% INFO    : Bus 3231	: V=1.00842339, theta=-15.1643877 -> V=1.0158755, theta=0.0
% INFO    : Bus 3232	: V=1.07, theta=-14.1602328 -> V=1.000001, theta=0.0
% INFO    : Bus 3233	: V=1.0225436, theta=-6.42959697 -> V=1.0158755, theta=0.0
% INFO    : Bus 3234	: V=1.01036602, theta=-8.93858691 -> V=0.999999, theta=0.0
% INFO    : Bus 3235	: V=1.03175161, theta=-53.4132833 -> V=1.0079355, theta=0.0
% INFO    : Bus 3236	: V=1.01458689, theta=4.49343022 -> V=1.013331, theta=0.0
% INFO    : Bus 3237	: V=1.04743819, theta=-30.530123 -> V=1.027779, theta=0.0
% INFO    : Bus 3238	: V=1.01860465, theta=-15.9922482 -> V=1.0000025, theta=0.0
% INFO    : Bus 3239	: V=1.041, theta=-27.2891515 -> V=1.0000025, theta=0.0
% INFO    : Bus 3240	: V=1.01918542, theta=-18.0101872 -> V=1.015872, theta=0.0
% INFO    : Bus 3241	: V=1.04797877, theta=-29.2769585 -> V=1.027779, theta=0.0
% INFO    : Bus 3242	: V=1.0414794, theta=-24.4784348 -> V=0.999999, theta=0.0
% INFO    : Bus 3243	: V=1.0361321, theta=-46.7075716 -> V=1.022224, theta=0.0
% INFO    : Bus 3244	: V=1.04681032, theta=-24.673479 -> V=1.0000025, theta=0.0
% INFO    : Bus 3245	: V=1.03378235, theta=-31.7305919 -> V=1.022224, theta=0.0
% INFO    : Bus 3246	: V=1.05329292, theta=-12.2826975 -> V=1.046665, theta=0.0
% INFO    : Bus 3247	: V=1.03593862, theta=-5.44747665 -> V=1.0158755, theta=0.0
% INFO    : Bus 3248	: V=1.03593862, theta=-5.44747665 -> V=1.0158755, theta=0.0
% INFO    : Bus 3249	: V=1.03593879, theta=-5.44755913 -> V=1.0158755, theta=0.0
% INFO    : Bus 3250	: V=1.00520651, theta=-11.7506295 -> V=1.015872, theta=0.0
% INFO    : Bus 3251	: V=1.03843998, theta=-25.3145657 -> V=1.022224, theta=0.0
% INFO    : Bus 3252	: V=1.06646315, theta=-20.7989562 -> V=1.04444, theta=0.0
% INFO    : Bus 3253	: V=1.04889575, theta=-30.175373 -> V=1.027779, theta=0.0
% INFO    : Bus 3254	: V=1.03390471, theta=-18.7446472 -> V=1.022224, theta=0.0
% INFO    : Bus 3255	: V=1.04914504, theta=-20.8580209 -> V=1.0111115, theta=0.0
% INFO    : Bus 3256	: V=1.04965505, theta=-3.44338614 -> V=1.0111115, theta=0.0
% INFO    : Bus 3257	: V=1.03850789, theta=-26.2722061 -> V=1.0000025, theta=0.0
% INFO    : Bus 3258	: V=1.0370475, theta=-23.6193083 -> V=1.022224, theta=0.0
% INFO    : Bus 3259	: V=1.055, theta=-23.5355623 -> V=1.0, theta=0.0
% INFO    : Bus 3260	: V=1.07375995, theta=-25.8230557 -> V=1.047805, theta=0.0
% INFO    : Bus 3261	: V=0.942062798, theta=-31.1468364 -> V=0.993232, theta=0.0
% INFO    : Bus 3262	: V=1.05283492, theta=-15.0950244 -> V=1.0000025, theta=0.0
% INFO    : Bus 3263	: V=1.03190479, theta=-12.556155 -> V=1.002223, theta=0.0
% INFO    : Bus 3264	: V=1.04847578, theta=-25.9610895 -> V=1.046665, theta=0.0
% INFO    : Bus 3265	: V=1.02883083, theta=-17.0607814 -> V=1.0158755, theta=0.0
% INFO    : Bus 3266	: V=1.06844437, theta=-23.751507 -> V=1.046665, theta=0.0
% INFO    : Bus 3267	: V=1.03808354, theta=-27.0056771 -> V=1.0000025, theta=0.0
% INFO    : Bus 3268	: V=1.02159018, theta=-27.7533729 -> V=1.0000005, theta=0.0
% INFO    : Bus 3269	: V=1.03833884, theta=-4.47774645 -> V=1.0000025, theta=0.0
% INFO    : Bus 3270	: V=1.06095173, theta=-19.0371835 -> V=1.033333, theta=0.0
% INFO    : Bus 3271	: V=1.04032938, theta=-4.13088971 -> V=1.0158755, theta=0.0
% INFO    : Bus 3272	: V=1.08436684, theta=-2.89414451 -> V=1.0377785, theta=0.0
% INFO    : Bus 3273	: V=1.122, theta=2.24432445 -> V=0.975, theta=0.0
% INFO    : Bus 3274	: V=1.075, theta=0.40403091 -> V=0.975, theta=0.0
% INFO    : Bus 3275	: V=1.052, theta=0.336459294 -> V=0.975, theta=0.0
% INFO    : Bus 3276	: V=1.04174766, theta=-3.86707138 -> V=1.0158755, theta=0.0
% INFO    : Bus 3277	: V=1.04049328, theta=-3.88000789 -> V=1.0158755, theta=0.0
% INFO    : Bus 3278	: V=1.08436684, theta=-2.89414451 -> V=1.0377785, theta=0.0
% INFO    : Bus 3279	: V=1.08446629, theta=-2.87634408 -> V=1.0377785, theta=0.0
% INFO    : Bus 3280	: V=1.04404344, theta=-10.4284514 -> V=1.000694, theta=0.0
% INFO    : Bus 3281	: V=1.04811418, theta=-7.92567881 -> V=1.0111115, theta=0.0
% INFO    : Bus 3282	: V=1.06174582, theta=-18.8924993 -> V=1.033333, theta=0.0
% INFO    : Bus 3283	: V=1.08204318, theta=3.68521111 -> V=1.0213855, theta=0.0
% INFO    : Bus 3284	: V=1.07555115, theta=3.68521111 -> V=1.0377785, theta=0.0
% INFO    : Bus 3285	: V=1.04290278, theta=-14.7041775 -> V=0.999999, theta=0.0
% INFO    : Bus 3286	: V=1.04362385, theta=-13.3110178 -> V=1.000064, theta=0.0
% INFO    : Bus 3287	: V=1.01118325, theta=-11.6856457 -> V=0.999999, theta=0.0
% INFO    : Bus 3288	: V=1.02183452, theta=-9.41077829 -> V=0.999999, theta=0.0
% INFO    : Bus 3289	: V=1.00013762, theta=-29.24127 -> V=1.0000005, theta=0.0
% INFO    : Bus 3290	: V=1.06621225, theta=-21.0433256 -> V=1.0000025, theta=0.0
% INFO    : Bus 3291	: V=1.080843, theta=-15.2571378 -> V=1.044445, theta=0.0
% INFO    : Bus 3292	: V=1.02563655, theta=-18.3765487 -> V=1.0158755, theta=0.0
% INFO    : Bus 3293	: V=1.02251551, theta=-18.8681255 -> V=1.0158755, theta=0.0
% INFO    : Bus 3294	: V=1.054, theta=-26.7992968 -> V=1.021232, theta=0.0
% INFO    : Bus 3295	: V=1.0424736, theta=-24.7892879 -> V=1.0000025, theta=0.0
% INFO    : Bus 3296	: V=0.982480544, theta=-47.8929754 -> V=1.0079355, theta=0.0
% INFO    : Bus 3297	: V=1.01731521, theta=-53.0851191 -> V=1.0079355, theta=0.0
% INFO    : Bus 3298	: V=1.03049138, theta=-15.1914526 -> V=0.999999, theta=0.0
% INFO    : Bus 3299	: V=1.00954151, theta=-30.296672 -> V=1.0000005, theta=0.0
% INFO    : Bus 3300	: V=1.03722895, theta=-22.9740544 -> V=1.000001, theta=0.0
% INFO    : Bus 3301	: V=1.035, theta=-28.4792005 -> V=1.0000025, theta=0.0
% INFO    : Bus 3302	: V=1.05038233, theta=-30.9708913 -> V=1.022224, theta=0.0
% INFO    : Bus 3303	: V=1.06718229, theta=-21.6415735 -> V=1.044445, theta=0.0
% INFO    : Bus 3304	: V=1.05223534, theta=-15.0917335 -> V=1.0158755, theta=0.0
% INFO    : Bus 3305	: V=1.05793425, theta=-8.96794417 -> V=1.0377785, theta=0.0
% INFO    : Bus 3306	: V=1.03197856, theta=-12.3801858 -> V=0.999999, theta=0.0
% INFO    : Bus 3307	: V=1.04257455, theta=-30.7393367 -> V=1.022224, theta=0.0
% INFO    : Bus 3308	: V=1.04619314, theta=-44.6471333 -> V=1.022224, theta=0.0
% INFO    : Bus 3309	: V=1.01778645, theta=-9.95935699 -> V=1.015872, theta=0.0
% INFO    : Bus 3310	: V=1.10957688, theta=-7.68041357 -> V=1.081285, theta=0.0
% INFO    : Bus 3311	: V=1.10729328, theta=-7.63241297 -> V=1.08007, theta=0.0
% INFO    : Bus 3312	: V=1.11223063, theta=-7.71396292 -> V=1.082685, theta=0.0
% INFO    : Bus 3313	: V=1.10977495, theta=-7.72026254 -> V=1.081535, theta=0.0
% INFO    : Bus 3314	: V=1.01275837, theta=-22.2934515 -> V=1.015872, theta=0.0
% INFO    : Bus 3315	: V=0.998181259, theta=-18.6198732 -> V=1.015872, theta=0.0
% INFO    : Bus 3316	: V=1.04833004, theta=-15.1809454 -> V=1.046665, theta=0.0
% INFO    : Bus 3317	: V=1.04229973, theta=-26.5739191 -> V=1.0000025, theta=0.0
% INFO    : Bus 3318	: V=1.04131431, theta=-26.7892445 -> V=1.0000025, theta=0.0
% INFO    : Bus 3319	: V=1.05184375, theta=-23.8050839 -> V=1.022224, theta=0.0
% INFO    : Bus 3320	: V=1.03173162, theta=-19.0132305 -> V=1.022224, theta=0.0
% INFO    : Bus 3321	: V=1.07634554, theta=-29.2820468 -> V=1.04444, theta=0.0
% INFO    : Bus 3322	: V=1.07635452, theta=-29.2821531 -> V=1.04444, theta=0.0
% INFO    : Bus 3323	: V=1.02038936, theta=-21.207631 -> V=1.0000025, theta=0.0
% INFO    : Bus 3324	: V=1.02252081, theta=-27.4292909 -> V=1.0000025, theta=0.0
% INFO    : Bus 3325	: V=1.05147953, theta=-10.4301453 -> V=1.004024, theta=0.0
% INFO    : Bus 3326	: V=1.05216971, theta=-10.3845442 -> V=1.004364, theta=0.0
% INFO    : Bus 3327	: V=1.04034547, theta=-11.1179067 -> V=0.999999, theta=0.0
% INFO    : Bus 3328	: V=1.02359791, theta=-11.0327035 -> V=0.999999, theta=0.0
% INFO    : Bus 3329	: V=1.05153589, theta=-7.99394816 -> V=1.0111115, theta=0.0
% INFO    : Bus 3330	: V=1.02208914, theta=-16.6217394 -> V=1.0158755, theta=0.0
% INFO    : Bus 3331	: V=1.02903206, theta=-26.3862222 -> V=1.0158755, theta=0.0
% INFO    : Bus 3332	: V=1.01457067, theta=-28.8466149 -> V=1.022224, theta=0.0
% INFO    : Bus 3333	: V=1.0192088, theta=-28.3225848 -> V=1.0000005, theta=0.0
% INFO    : Bus 3334	: V=1.02017083, theta=-28.2829162 -> V=1.0000005, theta=0.0
% INFO    : Bus 3335	: V=1.03051066, theta=-26.8048906 -> V=1.046665, theta=0.0
% INFO    : Bus 3336	: V=1.00332732, theta=-17.37611 -> V=1.015872, theta=0.0
% INFO    : Bus 3337	: V=0.979752121, theta=-10.3520696 -> V=0.9444445, theta=0.0
% INFO    : Bus 3338	: V=1.04082083, theta=-10.3907027 -> V=0.999999, theta=0.0
% INFO    : Bus 3339	: V=1.05106225, theta=-6.8481672 -> V=1.0111115, theta=0.0
% INFO    : Bus 3340	: V=1.01964746, theta=-21.1983061 -> V=1.0000025, theta=0.0
% INFO    : Bus 3341	: V=1.02369514, theta=-42.2952597 -> V=1.022224, theta=0.0
% INFO    : Bus 3342	: V=1.00740579, theta=-27.1143449 -> V=1.0000005, theta=0.0
% INFO    : Bus 3343	: V=1.0433058, theta=-23.6085408 -> V=1.046665, theta=0.0
% INFO    : Bus 3344	: V=1.04501237, theta=-19.519597 -> V=1.046665, theta=0.0
% INFO    : Bus 3345	: V=1.05886795, theta=-24.6707499 -> V=1.0000025, theta=0.0
% INFO    : Bus 3346	: V=1.0275434, theta=-16.48856 -> V=0.999999, theta=0.0
% INFO    : Bus 3347	: V=1.04662726, theta=-22.5121535 -> V=1.0000025, theta=0.0
% INFO    : Bus 3348	: V=1.02881212, theta=-27.3138291 -> V=1.0000025, theta=0.0
% INFO    : Bus 3349	: V=1.03203145, theta=-26.9197021 -> V=1.0000025, theta=0.0
% INFO    : Bus 3350	: V=1.03933948, theta=-26.4532591 -> V=1.0000025, theta=0.0
% INFO    : Bus 3351	: V=1.04694877, theta=-21.5414757 -> V=1.022224, theta=0.0
% INFO    : Bus 3352	: V=0.982818412, theta=-31.0657901 -> V=1.0000005, theta=0.0
% INFO    : Bus 3353	: V=1.01997467, theta=-35.2401985 -> V=1.0000005, theta=0.0
% INFO    : Bus 3354	: V=1.02066745, theta=-32.1602781 -> V=1.0000005, theta=0.0
% INFO    : Bus 3355	: V=1.00891885, theta=-30.7603072 -> V=1.015872, theta=0.0
% INFO    : Bus 3356	: V=1.05492683, theta=-23.8725793 -> V=1.0000025, theta=0.0
% INFO    : Bus 3357	: V=1.06849821, theta=-20.0818564 -> V=1.044445, theta=0.0
% INFO    : Bus 3358	: V=1.03393261, theta=-31.0457404 -> V=1.022224, theta=0.0
% INFO    : Bus 3359	: V=1.12108041, theta=4.48934813 -> V=1.0402055, theta=0.0
% INFO    : Bus 3360	: V=1.07915549, theta=4.49219718 -> V=1.0377785, theta=0.0
% INFO    : Bus 3361	: V=1.06012159, theta=-17.3015403 -> V=1.073685, theta=0.0
% INFO    : Bus 3362	: V=1.03747792, theta=-51.4164899 -> V=1.0079355, theta=0.0
% INFO    : Bus 3363	: V=1.02267254, theta=-54.514066 -> V=1.0079355, theta=0.0
% INFO    : Bus 3364	: V=1.04170186, theta=-13.9080719 -> V=1.027779, theta=0.0
% INFO    : Bus 3365	: V=1.10246209, theta=-9.24928165 -> V=1.07835, theta=0.0
% INFO    : Bus 3366	: V=1.10329495, theta=-9.04069771 -> V=1.078745, theta=0.0
% INFO    : Bus 3367	: V=1.10332299, theta=-9.05386798 -> V=1.07876, theta=0.0
% INFO    : Bus 3368	: V=1.01592772, theta=-23.8033486 -> V=1.015872, theta=0.0
% INFO    : Bus 3369	: V=1.03809865, theta=-27.8744741 -> V=1.0000025, theta=0.0
% INFO    : Bus 3370	: V=1.0413069, theta=-33.0262656 -> V=1.027779, theta=0.0
% INFO    : Bus 3371	: V=1.03515626, theta=-11.9754302 -> V=0.999999, theta=0.0
% INFO    : Bus 3372	: V=1.06490166, theta=-26.4081321 -> V=1.027779, theta=0.0
% INFO    : Bus 3373	: V=1.0474435, theta=-19.0159331 -> V=1.000001, theta=0.0
% INFO    : Bus 3374	: V=1.06233287, theta=-15.1554769 -> V=0.9888895, theta=0.0
% INFO    : Bus 3375	: V=1.05817184, theta=-22.4577448 -> V=1.0111115, theta=0.0
% INFO    : Bus 3376	: V=1.06774153, theta=-21.1879069 -> V=1.0027125, theta=0.0
% INFO    : Bus 3377	: V=1.06134143, theta=-21.4562983 -> V=1.0000025, theta=0.0
% INFO    : Bus 3378	: V=1.04609333, theta=-24.2686174 -> V=1.0000025, theta=0.0
% INFO    : Bus 3379	: V=0.93923925, theta=-5.16009308 -> V=0.9444445, theta=0.0
% INFO    : Bus 3380	: V=1.03504558, theta=-49.9099313 -> V=1.0079355, theta=0.0
% INFO    : Bus 3381	: V=1.01105165, theta=-15.451111 -> V=1.0158755, theta=0.0
% INFO    : Bus 3382	: V=1.04800294, theta=-7.95283438 -> V=1.0111115, theta=0.0
% INFO    : Bus 3383	: V=1.07481723, theta=-28.4884665 -> V=1.047385, theta=0.0
% INFO    : Bus 3384	: V=1.01700794, theta=-19.5745257 -> V=1.0158755, theta=0.0
% INFO    : Bus 3385	: V=1.04255495, theta=-28.1933434 -> V=1.022224, theta=0.0
% INFO    : Bus 3386	: V=0.993348403, theta=-32.4772999 -> V=1.0000005, theta=0.0
% INFO    : Bus 3387	: V=1.00521073, theta=-34.2219739 -> V=1.0000005, theta=0.0
% INFO    : Bus 3388	: V=1.05054823, theta=-25.19872 -> V=1.046665, theta=0.0
% INFO    : Bus 3389	: V=1.06787286, theta=-20.4393339 -> V=1.000001, theta=0.0
% INFO    : Bus 3390	: V=1.04758346, theta=-17.4549945 -> V=1.024445, theta=0.0
% INFO    : Bus 3391	: V=0.982137398, theta=-22.1737126 -> V=1.015872, theta=0.0
% INFO    : Bus 3392	: V=1.05235965, theta=-23.4148875 -> V=1.0000025, theta=0.0
% INFO    : Bus 3393	: V=1.06684478, theta=-18.3921562 -> V=1.044445, theta=0.0
% INFO    : Bus 3394	: V=1.02782954, theta=-6.52030714 -> V=1.0158755, theta=0.0
% INFO    : Bus 3395	: V=1.03333184, theta=-5.74094393 -> V=1.0158755, theta=0.0
% INFO    : Bus 3396	: V=1.01115375, theta=-27.9929457 -> V=1.0000005, theta=0.0
% INFO    : Bus 3397	: V=1.04300034, theta=-10.5845505 -> V=1.0158755, theta=0.0
% INFO    : Bus 3398	: V=1.043, theta=-10.5845461 -> V=1.0158755, theta=0.0
% INFO    : Bus 3399	: V=1.00953066, theta=-31.582036 -> V=1.015872, theta=0.0
% INFO    : Bus 3400	: V=1.05945564, theta=-15.9059152 -> V=1.044445, theta=0.0
% INFO    : Bus 3401	: V=1.061, theta=-16.2285807 -> V=1.004029, theta=0.0
% INFO    : Bus 3402	: V=1.03201779, theta=-22.837151 -> V=1.0000025, theta=0.0
% INFO    : Bus 3403	: V=1.02030301, theta=-7.98569614 -> V=1.0158755, theta=0.0
% INFO    : Bus 3404	: V=1.02600577, theta=-5.45315349 -> V=1.0158755, theta=0.0
% INFO    : Bus 3405	: V=1.03811828, theta=-28.375114 -> V=1.022224, theta=0.0
% INFO    : Bus 3406	: V=1.04893547, theta=-8.74289674 -> V=1.033334, theta=0.0
% INFO    : Bus 3407	: V=1.04457304, theta=-17.5667432 -> V=0.999999, theta=0.0
% INFO    : Bus 3408	: V=1.02330608, theta=-18.1164688 -> V=1.015872, theta=0.0
% INFO    : Bus 3409	: V=1.08340234, theta=-17.3440841 -> V=1.07237, theta=0.0
% INFO    : Bus 3410	: V=1.01157547, theta=-34.1121259 -> V=1.015872, theta=0.0
% INFO    : Bus 3411	: V=1.043, theta=-25.2372437 -> V=1.0000025, theta=0.0
% INFO    : Bus 3412	: V=1.05275972, theta=-25.1056816 -> V=1.022224, theta=0.0
% INFO    : Bus 3413	: V=1.03870508, theta=-24.0156476 -> V=1.0000025, theta=0.0
% INFO    : Bus 3414	: V=1.049686, theta=-23.6866492 -> V=1.022224, theta=0.0
% INFO    : Bus 3415	: V=1.00529487, theta=-11.8134479 -> V=1.015872, theta=0.0
% INFO    : Bus 3416	: V=1.04364695, theta=-20.265696 -> V=1.022224, theta=0.0
% INFO    : Bus 3417	: V=1.013, theta=-11.3561508 -> V=0.999999, theta=0.0
% INFO    : Bus 3418	: V=1.01203143, theta=-10.5667833 -> V=0.999999, theta=0.0
% INFO    : Bus 3419	: V=1.04700006, theta=-32.1971072 -> V=1.0099205, theta=0.0
% INFO    : Bus 3420	: V=1.06488045, theta=-24.6050645 -> V=1.046665, theta=0.0
% INFO    : Bus 3421	: V=1.05154176, theta=-23.9139746 -> V=1.022224, theta=0.0
% INFO    : Bus 3422	: V=1.02574973, theta=-45.9785217 -> V=1.0079355, theta=0.0
% INFO    : Bus 3423	: V=0.99862824, theta=-9.82347274 -> V=1.015872, theta=0.0
% INFO    : Bus 3424	: V=0.998503533, theta=-12.5942266 -> V=1.015872, theta=0.0
% INFO    : Bus 3425	: V=1.05231061, theta=-17.7988298 -> V=1.000001, theta=0.0
% INFO    : Bus 3426	: V=1.0917268, theta=-11.6892197 -> V=1.078945, theta=0.0
% INFO    : Bus 3427	: V=1.02268595, theta=-44.7667256 -> V=1.022224, theta=0.0
% INFO    : Bus 3428	: V=1.00279043, theta=-47.3536408 -> V=1.0079355, theta=0.0
% INFO    : Bus 3429	: V=1.03608112, theta=-46.7859076 -> V=1.022224, theta=0.0
% INFO    : Bus 3430	: V=1.04495052, theta=-26.0535045 -> V=1.022224, theta=0.0
% INFO    : Bus 3431	: V=1.05416085, theta=-24.3657296 -> V=1.046665, theta=0.0
% INFO    : Bus 3432	: V=1.04605372, theta=-53.2862504 -> V=1.0079355, theta=0.0
% INFO    : Bus 3433	: V=1.05183891, theta=-49.1129718 -> V=1.0079355, theta=0.0
% INFO    : Bus 3434	: V=1.04231932, theta=-10.5013087 -> V=1.0158755, theta=0.0
% INFO    : Bus 3435	: V=1.00820068, theta=-6.77700337 -> V=0.95, theta=0.0
% INFO    : Bus 3436	: V=1.01484313, theta=-52.2091931 -> V=1.0079355, theta=0.0
% INFO    : Bus 3437	: V=1.02756594, theta=-46.0916886 -> V=1.0079355, theta=0.0
% INFO    : Bus 3438	: V=1.03275479, theta=-52.5296851 -> V=1.0079355, theta=0.0
% INFO    : Bus 3439	: V=1.04065702, theta=-17.6518124 -> V=0.984126, theta=0.0
% INFO    : Bus 3440	: V=1.01386652, theta=-47.9820186 -> V=1.0079355, theta=0.0
% INFO    : Bus 3441	: V=1.02214873, theta=-48.3540236 -> V=1.0079355, theta=0.0
% INFO    : Bus 3442	: V=1.0367647, theta=-34.5201822 -> V=1.022224, theta=0.0
% INFO    : Bus 3443	: V=1.0413918, theta=-55.8213277 -> V=1.0079355, theta=0.0
% INFO    : Bus 3444	: V=1.02888981, theta=-50.8693513 -> V=1.0079355, theta=0.0
% INFO    : Bus 3445	: V=1.036008, theta=-24.3957874 -> V=1.0000025, theta=0.0
% INFO    : Bus 3446	: V=1.0242423, theta=-26.2897261 -> V=1.0000025, theta=0.0
% INFO    : Bus 3447	: V=1.05793403, theta=-33.0069723 -> V=1.027804, theta=0.0
% INFO    : Bus 3448	: V=1.01803909, theta=-24.0976528 -> V=1.022224, theta=0.0
% INFO    : Bus 3449	: V=1.03323843, theta=-16.2371092 -> V=1.0158755, theta=0.0
% INFO    : Bus 3450	: V=1.02334988, theta=-35.2208596 -> V=1.0000005, theta=0.0
% INFO    : Bus 3451	: V=1.05962135, theta=-10.6312457 -> V=1.002214, theta=0.0
% INFO    : Bus 3452	: V=1.05519595, theta=-23.1267033 -> V=1.022224, theta=0.0
% INFO    : Bus 3453	: V=1.03557302, theta=-24.6850449 -> V=1.022224, theta=0.0
% INFO    : Bus 3454	: V=1.00892028, theta=-15.8062339 -> V=1.0158755, theta=0.0
% INFO    : Bus 3455	: V=1.03276677, theta=-15.3459822 -> V=0.999999, theta=0.0
% INFO    : Bus 3456	: V=1.01770374, theta=-12.2101294 -> V=0.999999, theta=0.0
% INFO    : Bus 3457	: V=1.03286368, theta=-24.6136863 -> V=1.027779, theta=0.0
% INFO    : Bus 3458	: V=1.02184742, theta=-9.6723046 -> V=0.999999, theta=0.0
% INFO    : Bus 3459	: V=1.02987645, theta=-26.6592443 -> V=1.000001, theta=0.0
% INFO    : Bus 3460	: V=1.01390691, theta=-30.0332533 -> V=1.0000005, theta=0.0
% INFO    : Bus 3461	: V=1.028, theta=-9.57758642 -> V=0.999999, theta=0.0
% INFO    : Bus 3462	: V=1.05380074, theta=-25.331206 -> V=1.022224, theta=0.0
% INFO    : Bus 3463	: V=1.05228952, theta=-14.6200169 -> V=1.046665, theta=0.0
% INFO    : Bus 3464	: V=1.00613356, theta=-14.6201113 -> V=1.05336, theta=0.0
% INFO    : Bus 3465	: V=1.02589004, theta=-31.1571663 -> V=1.0000005, theta=0.0
% INFO    : Bus 3466	: V=1.02587001, theta=-31.1594522 -> V=1.0000005, theta=0.0
% INFO    : Bus 3467	: V=1.02589135, theta=-31.1570722 -> V=1.0000005, theta=0.0
% INFO    : Bus 3468	: V=1.02581015, theta=-31.1653848 -> V=1.0000005, theta=0.0
% INFO    : Bus 3469	: V=1.07161809, theta=-20.9741038 -> V=1.073685, theta=0.0
% INFO    : Bus 3470	: V=1.07450834, theta=-20.7411966 -> V=1.073685, theta=0.0
% INFO    : Bus 3471	: V=1.07161732, theta=-20.9741038 -> V=1.073685, theta=0.0
% INFO    : Bus 3472	: V=1.07161732, theta=-20.9741038 -> V=1.073685, theta=0.0
% INFO    : Bus 3473	: V=1.0012455, theta=-29.3185973 -> V=1.0000005, theta=0.0
% INFO    : Bus 3474	: V=1.00124452, theta=-29.3185689 -> V=1.0000005, theta=0.0
% INFO    : Bus 3475	: V=1.0258889, theta=-31.1564669 -> V=1.0000005, theta=0.0
% INFO    : Bus 3476	: V=1.04968479, theta=-29.1538857 -> V=1.027779, theta=0.0
% INFO    : Bus 3477	: V=1.05944197, theta=-29.8963814 -> V=1.027784, theta=0.0
% INFO    : Bus 3478	: V=1.06039708, theta=-26.2477769 -> V=1.046665, theta=0.0
% INFO    : Bus 3479	: V=0.973691945, theta=-49.1979472 -> V=1.0079355, theta=0.0
% INFO    : Bus 3480	: V=1.0324752, theta=-31.2138154 -> V=1.022224, theta=0.0
% INFO    : Bus 3481	: V=1.03227428, theta=-47.4326268 -> V=1.0079355, theta=0.0
% INFO    : Bus 3482	: V=1.03611219, theta=-27.3901661 -> V=1.0000025, theta=0.0
% INFO    : Bus 3483	: V=1.02987943, theta=-11.1194372 -> V=0.999999, theta=0.0
% INFO    : Bus 3484	: V=1.095, theta=-18.3757941 -> V=1.0, theta=0.0
% INFO    : Bus 3485	: V=1.02950246, theta=-39.6054729 -> V=1.022224, theta=0.0
% INFO    : Bus 3486	: V=1.08094731, theta=-16.793414 -> V=1.044445, theta=0.0
% INFO    : Bus 3487	: V=1.02579205, theta=-12.2165732 -> V=0.999999, theta=0.0
% INFO    : Bus 3488	: V=1.01644769, theta=-56.4277516 -> V=1.0079355, theta=0.0
% INFO    : Bus 3489	: V=1.01125889, theta=-26.3820334 -> V=1.0158755, theta=0.0
% INFO    : Bus 3490	: V=1.0380012, theta=-6.83249963 -> V=1.0158755, theta=0.0
% INFO    : Bus 3491	: V=1.05993085, theta=-38.0524656 -> V=1.022689, theta=0.0
% INFO    : Bus 3492	: V=1.01374403, theta=-11.7661486 -> V=1.015872, theta=0.0
% INFO    : Bus 3493	: V=1.06172387, theta=-21.8407521 -> V=1.0000025, theta=0.0
% INFO    : Bus 3494	: V=1.04083736, theta=-25.4200995 -> V=1.0000025, theta=0.0
% INFO    : Bus 3495	: V=1.04427558, theta=-17.0826749 -> V=1.0000025, theta=0.0
% INFO    : Bus 3496	: V=1.04250379, theta=-4.20363615 -> V=1.044445, theta=0.0
% INFO    : Bus 3497	: V=1.048, theta=-16.4073711 -> V=1.044445, theta=0.0
% INFO    : Bus 3498	: V=1.02232182, theta=-10.3183297 -> V=0.975, theta=0.0
% INFO    : Bus 3499	: V=1.02130052, theta=-10.3183297 -> V=0.999999, theta=0.0
% INFO    : Bus 3500	: V=1.04892841, theta=-17.0523472 -> V=0.999999, theta=0.0
% INFO    : Bus 3501	: V=1.04500309, theta=-15.7732312 -> V=0.999999, theta=0.0
% INFO    : Bus 3502	: V=1.05800791, theta=-11.4884682 -> V=1.0111115, theta=0.0
% INFO    : Bus 3503	: V=1.05186942, theta=-52.1456539 -> V=1.0079355, theta=0.0
% INFO    : Bus 3504	: V=1.0347986, theta=-42.189757 -> V=1.022224, theta=0.0
% INFO    : Bus 3505	: V=1.02455298, theta=-21.791681 -> V=0.999999, theta=0.0
% INFO    : Bus 3506	: V=1.03560974, theta=-11.8978701 -> V=1.0158755, theta=0.0
% INFO    : Bus 3507	: V=1.0581655, theta=-22.7282739 -> V=1.022224, theta=0.0
% INFO    : Bus 3508	: V=1.08199665, theta=-12.0847357 -> V=1.07237, theta=0.0
% INFO    : Bus 3509	: V=1.0826035, theta=-12.0814203 -> V=1.07237, theta=0.0
% INFO    : Bus 3510	: V=1.03611259, theta=-19.4201522 -> V=1.0158755, theta=0.0
% INFO    : Bus 3511	: V=1.06650034, theta=-16.1918714 -> V=1.0377785, theta=0.0
% INFO    : Bus 3512	: V=1.04755616, theta=-19.3907209 -> V=1.0000025, theta=0.0
% INFO    : Bus 3513	: V=1.05584548, theta=-16.1984153 -> V=1.0111115, theta=0.0
% INFO    : Bus 3514	: V=1.058, theta=-10.6344842 -> V=0.999999, theta=0.0
% INFO    : Bus 3515	: V=1.06067712, theta=-9.74610085 -> V=0.999999, theta=0.0
% INFO    : Bus 3516	: V=1.05986434, theta=-6.62698533 -> V=1.0111115, theta=0.0
% INFO    : Bus 3517	: V=1.04564806, theta=-26.7702328 -> V=1.022224, theta=0.0
% INFO    : Bus 3518	: V=1.03112608, theta=-6.37902187 -> V=1.0158755, theta=0.0
% INFO    : Bus 3519	: V=1.03328799, theta=-26.0389368 -> V=1.022224, theta=0.0
% INFO    : Bus 3520	: V=1.03087009, theta=-16.5237864 -> V=1.0000025, theta=0.0
% INFO    : Bus 3521	: V=1.04994581, theta=-25.5254137 -> V=1.046665, theta=0.0
% INFO    : Bus 3522	: V=1.05034324, theta=-9.10482322 -> V=1.06579, theta=0.0
% INFO    : Bus 3523	: V=0.999517772, theta=-13.2637853 -> V=1.015872, theta=0.0
% INFO    : Bus 3524	: V=1.03595465, theta=-5.44803856 -> V=1.0158755, theta=0.0
% INFO    : Bus 3525	: V=1.00121744, theta=-27.8767609 -> V=1.0000005, theta=0.0
% INFO    : Bus 3526	: V=1.04859782, theta=-15.1542119 -> V=1.033334, theta=0.0
% INFO    : Bus 3527	: V=1.04841481, theta=-15.1705399 -> V=1.033334, theta=0.0
% INFO    : Bus 3528	: V=1.05363234, theta=-18.4675356 -> V=1.0000025, theta=0.0
% INFO    : Bus 3529	: V=1.05356603, theta=-18.4751951 -> V=1.0000025, theta=0.0
% INFO    : Bus 3530	: V=1.05771466, theta=-5.52318282 -> V=1.046665, theta=0.0
% INFO    : Bus 3531	: V=1.06525865, theta=-18.1949362 -> V=1.0111115, theta=0.0
% INFO    : Bus 3532	: V=1.05029277, theta=-15.3686957 -> V=1.0088895, theta=0.0
% INFO    : Bus 3533	: V=1.05598698, theta=-5.96266992 -> V=1.0111115, theta=0.0
% INFO    : Bus 3534	: V=1.03500876, theta=-24.6260161 -> V=1.0000025, theta=0.0
% INFO    : Bus 3535	: V=1.03474313, theta=-12.568979 -> V=1.0158755, theta=0.0
% INFO    : Bus 3536	: V=1.06116326, theta=-8.05751287 -> V=1.0377785, theta=0.0
% INFO    : Bus 3537	: V=1.048, theta=-10.4716462 -> V=0.999999, theta=0.0
% INFO    : Bus 3538	: V=1.05528116, theta=-40.9701607 -> V=1.0079355, theta=0.0
% INFO    : Bus 3539	: V=1.06756292, theta=-36.6802478 -> V=1.04444, theta=0.0
% INFO    : Bus 3540	: V=1.0255349, theta=-14.7771702 -> V=1.015872, theta=0.0
% INFO    : Bus 3541	: V=1.05565246, theta=-15.0016498 -> V=1.0000025, theta=0.0
% INFO    : Bus 3542	: V=1.12170309, theta=4.47931333 -> V=1.0402155, theta=0.0
% INFO    : Bus 3543	: V=1.03548701, theta=0.926397849 -> V=1.0158755, theta=0.0
% INFO    : Bus 3544	: V=1.01161953, theta=-57.8373324 -> V=1.0079355, theta=0.0
% INFO    : Bus 3545	: V=1.03247028, theta=-39.2510737 -> V=1.022224, theta=0.0
% INFO    : Bus 3546	: V=1.06429931, theta=-14.5179629 -> V=1.002319, theta=0.0
% INFO    : Bus 3547	: V=1.01514486, theta=-33.8287694 -> V=1.015872, theta=0.0
% INFO    : Bus 3548	: V=1.02722864, theta=-31.9522071 -> V=1.0000005, theta=0.0
% INFO    : Bus 3549	: V=1.05540138, theta=-26.6157238 -> V=1.046665, theta=0.0
% INFO    : Bus 3550	: V=0.990773095, theta=-21.6775609 -> V=1.0000025, theta=0.0
% INFO    : Bus 3551	: V=1.0305654, theta=-26.6310614 -> V=1.0000025, theta=0.0
% INFO    : Bus 3552	: V=1.03945382, theta=-12.4582113 -> V=1.0158755, theta=0.0
% INFO    : Bus 3553	: V=1.06741913, theta=-10.1894382 -> V=1.0377785, theta=0.0
% INFO    : Bus 3554	: V=1.02871102, theta=-33.2252542 -> V=1.0000005, theta=0.0
% INFO    : Bus 3555	: V=1.07405701, theta=-28.5553022 -> V=1.04701, theta=0.0
% INFO    : Bus 3556	: V=1.07405828, theta=-28.5553147 -> V=1.04701, theta=0.0
% INFO    : Bus 3557	: V=1.02891356, theta=-33.126946 -> V=1.0000005, theta=0.0
% INFO    : Bus 3558	: V=1.07410436, theta=-28.54785 -> V=1.047035, theta=0.0
% INFO    : Bus 3559	: V=1.01496813, theta=0.916256235 -> V=1.0158755, theta=0.0
% INFO    : Bus 3560	: V=1.04910545, theta=-40.4279131 -> V=1.022224, theta=0.0
% INFO    : Bus 3561	: V=1.0336611, theta=-27.812389 -> V=1.0000025, theta=0.0
% INFO    : Bus 3562	: V=1.03958715, theta=-20.8488487 -> V=1.000001, theta=0.0
% INFO    : Bus 3563	: V=1.06132485, theta=-29.5722626 -> V=1.023634, theta=0.0
% INFO    : Bus 3564	: V=1.03924392, theta=-18.0617711 -> V=0.999999, theta=0.0
% INFO    : Bus 3565	: V=1.03622854, theta=-16.1243179 -> V=1.0158755, theta=0.0
% INFO    : Bus 3566	: V=1.04730216, theta=-12.9622933 -> V=1.0377785, theta=0.0
% INFO    : Bus 3567	: V=1.04798301, theta=-25.9781481 -> V=1.046665, theta=0.0
% INFO    : Bus 3568	: V=1.04176109, theta=-10.7356582 -> V=0.999999, theta=0.0
% INFO    : Bus 3569	: V=1.00488852, theta=-57.5498396 -> V=1.0079355, theta=0.0
% INFO    : Bus 3570	: V=1.05036379, theta=-25.2013041 -> V=1.0000025, theta=0.0
% INFO    : Bus 3571	: V=1.0223416, theta=-4.57455809 -> V=0.999999, theta=0.0
% INFO    : Bus 3572	: V=1.04963707, theta=-3.44577521 -> V=1.0111115, theta=0.0
% INFO    : Bus 3573	: V=1.06473425, theta=-11.2537172 -> V=1.072365, theta=0.0
% INFO    : Bus 3574	: V=1.06448634, theta=-1.39616684 -> V=1.072365, theta=0.0
% INFO    : Bus 3575	: V=1.02136087, theta=-29.8262985 -> V=1.015872, theta=0.0
% INFO    : Bus 3576	: V=1.04765886, theta=-26.702342 -> V=1.027779, theta=0.0
% INFO    : Bus 3577	: V=1.04468974, theta=-28.4346239 -> V=1.027779, theta=0.0
% INFO    : Bus 3578	: V=1.02787193, theta=-18.2870582 -> V=1.0158755, theta=0.0
% INFO    : Bus 3579	: V=1.038, theta=-8.51914402 -> V=0.975, theta=0.0
% INFO    : Bus 3580	: V=1.027, theta=-6.7871832 -> V=0.975, theta=0.0
% INFO    : Bus 3581	: V=1.04389856, theta=-10.4990435 -> V=1.000099, theta=0.0
% INFO    : Bus 3582	: V=1.04186142, theta=-10.5667724 -> V=0.999999, theta=0.0
% INFO    : Bus 3583	: V=1.01549069, theta=-19.8311864 -> V=1.0158755, theta=0.0
% INFO    : Bus 3584	: V=1.04333538, theta=-20.1218143 -> V=1.0158755, theta=0.0
% INFO    : Bus 3585	: V=1.00876853, theta=-17.2305901 -> V=1.0, theta=0.0
% INFO    : Bus 3586	: V=1.05785398, theta=-24.0392238 -> V=1.046665, theta=0.0
% INFO    : Bus 3587	: V=0.997921523, theta=-9.8159318 -> V=1.015872, theta=0.0
% INFO    : Bus 3588	: V=1.06373505, theta=-7.76053318 -> V=1.046665, theta=0.0
% INFO    : Bus 3589	: V=1.01081643, theta=-19.2142057 -> V=1.015872, theta=0.0
% INFO    : Bus 3590	: V=1.05061312, theta=-15.008652 -> V=1.046665, theta=0.0
% INFO    : Bus 3591	: V=1.06138214, theta=-18.9037656 -> V=1.016666, theta=0.0
% INFO    : Bus 3592	: V=1.04554215, theta=-25.7039546 -> V=1.0000025, theta=0.0
% INFO    : Bus 3593	: V=1.077, theta=-18.088939 -> V=1.000001, theta=0.0
% INFO    : Bus 3594	: V=1.07126693, theta=-16.1256187 -> V=1.044445, theta=0.0
% INFO    : Bus 3595	: V=1.02973539, theta=-51.8628008 -> V=1.0079355, theta=0.0
% INFO    : Bus 3596	: V=1.06865066, theta=-46.9126867 -> V=1.04444, theta=0.0
% INFO    : Bus 3597	: V=1.021, theta=-6.40132542 -> V=0.999999, theta=0.0
% INFO    : Bus 3598	: V=1.07765875, theta=0.751272721 -> V=1.072365, theta=0.0
% INFO    : Bus 3599	: V=1.04027012, theta=-20.0098395 -> V=1.000001, theta=0.0
% INFO    : Bus 3600	: V=1.05629385, theta=-6.43850306 -> V=1.0111115, theta=0.0
% INFO    : Bus 3601	: V=1.03404776, theta=-11.8298643 -> V=0.999999, theta=0.0
% INFO    : Bus 3602	: V=1.04141945, theta=-7.43808803 -> V=1.0111115, theta=0.0
% INFO    : Bus 3603	: V=1.03894237, theta=-17.9790843 -> V=1.0000025, theta=0.0
% INFO    : Bus 3604	: V=1.02471374, theta=-12.9761768 -> V=1.015872, theta=0.0
% INFO    : Bus 3605	: V=1.03909318, theta=-25.0275383 -> V=1.046665, theta=0.0
% INFO    : Bus 3606	: V=1.05817002, theta=-24.3767008 -> V=1.046665, theta=0.0
% INFO    : Bus 3607	: V=1.05208291, theta=-24.8372404 -> V=1.046665, theta=0.0
% INFO    : Bus 3608	: V=1.06095341, theta=-18.9840753 -> V=1.073685, theta=0.0
% INFO    : Bus 3609	: V=1.06053387, theta=-19.4381849 -> V=1.073685, theta=0.0
% INFO    : Bus 3610	: V=1.0232352, theta=-36.9000142 -> V=1.022224, theta=0.0
% INFO    : Bus 3611	: V=1.02398623, theta=-36.2499005 -> V=1.022224, theta=0.0
% INFO    : Bus 3612	: V=1.01512255, theta=-31.3449113 -> V=1.015872, theta=0.0
% INFO    : Bus 3613	: V=1.04783403, theta=-28.1875283 -> V=1.046665, theta=0.0
% INFO    : Bus 3614	: V=1.04796596, theta=-24.699933 -> V=1.0000025, theta=0.0
% INFO    : Bus 3615	: V=1.03527371, theta=-23.9033855 -> V=0.999999, theta=0.0
% INFO    : Bus 3616	: V=1.07050513, theta=-41.8958824 -> V=1.04444, theta=0.0
% INFO    : Bus 3617	: V=1.07022419, theta=-35.7621504 -> V=1.07237, theta=0.0
% INFO    : Bus 3618	: V=1.03171746, theta=-12.0556789 -> V=0.999999, theta=0.0
% INFO    : Bus 3619	: V=1.03332128, theta=-24.6037127 -> V=1.027779, theta=0.0
% INFO    : Bus 3620	: V=1.03331376, theta=-24.6022912 -> V=1.027779, theta=0.0
% INFO    : Bus 3621	: V=1.00522439, theta=-30.5218181 -> V=1.015872, theta=0.0
% INFO    : Bus 3622	: V=1.00463909, theta=-30.5305719 -> V=1.015872, theta=0.0
% INFO    : Bus 3623	: V=1.03332487, theta=-24.6002405 -> V=1.027779, theta=0.0
% INFO    : Bus 3624	: V=1.07360186, theta=-21.146443 -> V=1.046665, theta=0.0
% INFO    : Bus 3625	: V=1.00044375, theta=-26.7922813 -> V=1.0000005, theta=0.0
% INFO    : Bus 3626	: V=1.0644775, theta=-24.8308606 -> V=1.046665, theta=0.0
% INFO    : Bus 3627	: V=1.00229572, theta=-23.1294962 -> V=1.015872, theta=0.0
% INFO    : Bus 3628	: V=1.03661885, theta=-10.0778944 -> V=0.999999, theta=0.0
% INFO    : Bus 3629	: V=1.06041736, theta=-15.0436565 -> V=1.006809, theta=0.0
% INFO    : Bus 3630	: V=1.02650394, theta=-36.4840544 -> V=1.022224, theta=0.0
% INFO    : Bus 3631	: V=1.05293719, theta=-14.7181618 -> V=0.9888895, theta=0.0
% INFO    : Bus 3632	: V=1.04599773, theta=-24.3560555 -> V=1.0000025, theta=0.0
% INFO    : Bus 3633	: V=1.04042441, theta=-25.7123981 -> V=1.0050805, theta=0.0
% INFO    : Bus 3634	: V=1.02611515, theta=-26.2137492 -> V=1.0000005, theta=0.0
% INFO    : Bus 3635	: V=1.0297128, theta=-19.0925957 -> V=0.999999, theta=0.0
% INFO    : Bus 3636	: V=1.05088448, theta=-24.0814645 -> V=1.022224, theta=0.0
% INFO    : Bus 3637	: V=1.02976681, theta=-20.3932313 -> V=1.0158755, theta=0.0
% INFO    : Bus 3638	: V=1.01662181, theta=1.28907369 -> V=1.0158755, theta=0.0
% INFO    : Bus 3639	: V=0.998765911, theta=-21.6746879 -> V=1.0000025, theta=0.0
% INFO    : Bus 3640	: V=1.03241795, theta=-15.893313 -> V=1.015872, theta=0.0
% INFO    : Bus 3641	: V=1.04413939, theta=-11.8517408 -> V=1.046665, theta=0.0
% INFO    : Bus 3642	: V=1.00160124, theta=-45.0504968 -> V=1.022224, theta=0.0
% INFO    : Bus 3643	: V=1.03592406, theta=-5.44711413 -> V=1.0158755, theta=0.0
% INFO    : Bus 3644	: V=1.053, theta=-18.1088303 -> V=1.0000025, theta=0.0
% INFO    : Bus 3645	: V=1.03983711, theta=-4.1893744 -> V=1.0158755, theta=0.0
% INFO    : Bus 3646	: V=1.01978713, theta=-6.78743062 -> V=1.0158755, theta=0.0
% INFO    : Bus 3647	: V=1.04643447, theta=-4.92793419 -> V=1.0158755, theta=0.0
% INFO    : Bus 3648	: V=1.05157945, theta=-1.33255344 -> V=1.0377785, theta=0.0
% INFO    : Bus 3649	: V=1.0210711, theta=-17.7079072 -> V=1.015872, theta=0.0
% INFO    : Bus 3650	: V=1.03338847, theta=-22.8170883 -> V=1.0000025, theta=0.0
% INFO    : Bus 3651	: V=1.01874627, theta=-13.3064825 -> V=0.999999, theta=0.0
% INFO    : Bus 3652	: V=1.01837237, theta=-13.286557 -> V=0.999999, theta=0.0
% INFO    : Bus 3653	: V=1.03422267, theta=-10.309959 -> V=1.0158755, theta=0.0
% INFO    : Bus 3654	: V=1.01568003, theta=-46.0503653 -> V=1.0079355, theta=0.0
% INFO    : Bus 3655	: V=1.03168306, theta=2.63275832 -> V=1.0158755, theta=0.0
% INFO    : Bus 3656	: V=1.07682153, theta=5.36702595 -> V=1.0377785, theta=0.0
% INFO    : Bus 3657	: V=1.02185661, theta=-50.1768479 -> V=1.0079355, theta=0.0
% INFO    : Bus 3658	: V=1.07217573, theta=-44.8642913 -> V=1.04444, theta=0.0
% INFO    : Bus 3659	: V=1.013, theta=-11.1233094 -> V=0.999999, theta=0.0
% INFO    : Bus 3660	: V=1.03204957, theta=-14.1030909 -> V=0.999999, theta=0.0
% INFO    : Bus 3661	: V=1.04566033, theta=-15.509387 -> V=0.999999, theta=0.0
% INFO    : Bus 3662	: V=1.05761506, theta=-14.3171746 -> V=1.016666, theta=0.0
% INFO    : Bus 3663	: V=1.06855452, theta=-11.2644678 -> V=1.006667, theta=0.0
% INFO    : Bus 3664	: V=1.02340947, theta=-21.6972626 -> V=1.0158755, theta=0.0
% INFO    : Bus 3665	: V=1.03982371, theta=-13.7606876 -> V=0.999999, theta=0.0
% INFO    : Bus 3666	: V=1.05537519, theta=-23.6493135 -> V=1.027779, theta=0.0
% INFO    : Bus 3667	: V=1.07857959, theta=-20.3379949 -> V=1.046665, theta=0.0
% INFO    : Bus 3668	: V=1.02996881, theta=2.47499128 -> V=1.0158755, theta=0.0
% INFO    : Bus 3669	: V=1.03085569, theta=2.57906243 -> V=1.0158755, theta=0.0
% INFO    : Bus 3670	: V=1.06264969, theta=-28.7524659 -> V=1.0000025, theta=0.0
% INFO    : Bus 3671	: V=1.06723632, theta=-21.6209931 -> V=1.044445, theta=0.0
% INFO    : Bus 3672	: V=1.04668452, theta=-10.4894236 -> V=1.001439, theta=0.0
% INFO    : Bus 3673	: V=1.05215724, theta=-10.6247305 -> V=1.004364, theta=0.0
% INFO    : Bus 3674	: V=1.04742032, theta=-4.41125908 -> V=1.0000025, theta=0.0
% INFO    : Bus 3675	: V=1.05599911, theta=-15.6676879 -> V=1.044445, theta=0.0
% INFO    : Bus 3676	: V=1.02560684, theta=-31.9599995 -> V=1.015872, theta=0.0
% INFO    : Bus 3677	: V=1.04694136, theta=-15.6918599 -> V=1.0158755, theta=0.0
% INFO    : Bus 3678	: V=1.0210326, theta=-11.14549 -> V=0.999999, theta=0.0
% INFO    : Bus 3679	: V=1.05418521, theta=-10.5298059 -> V=1.0377785, theta=0.0
% INFO    : Bus 3680	: V=1.02933839, theta=-8.62084949 -> V=0.999999, theta=0.0
% INFO    : Bus 3681	: V=1.06112822, theta=-13.0548276 -> V=0.9888895, theta=0.0
% INFO    : Bus 3682	: V=1.04354042, theta=-17.3973791 -> V=1.0000025, theta=0.0
% INFO    : Bus 3683	: V=1.05813183, theta=-8.97571996 -> V=1.0377785, theta=0.0
% INFO    : Bus 3684	: V=1.035, theta=-10.8867064 -> V=0.999999, theta=0.0
% INFO    : Bus 3685	: V=1.03469754, theta=-22.6862346 -> V=1.022222, theta=0.0
% INFO    : Bus 3686	: V=1.04847397, theta=-15.5543341 -> V=1.0111115, theta=0.0
% INFO    : Bus 3687	: V=1.03831719, theta=-52.6854078 -> V=1.0079355, theta=0.0
% INFO    : Bus 3688	: V=1.04000723, theta=-18.4957961 -> V=0.999999, theta=0.0
% INFO    : Bus 3689	: V=1.02350737, theta=-6.07455212 -> V=1.0158755, theta=0.0
% INFO    : Bus 3690	: V=1.00505983, theta=-61.2804543 -> V=1.0079355, theta=0.0
% INFO    : Bus 3691	: V=1.00686757, theta=-53.2378457 -> V=1.0079355, theta=0.0
% INFO    : Bus 3692	: V=1.03307742, theta=-53.6356954 -> V=1.0079355, theta=0.0
% INFO    : Bus 3693	: V=1.03564732, theta=-14.6936423 -> V=0.999999, theta=0.0
% INFO    : Bus 3694	: V=1.02066373, theta=-18.6728689 -> V=1.0158755, theta=0.0
% INFO    : Bus 3695	: V=1.05023291, theta=-15.5201437 -> V=1.033334, theta=0.0
% INFO    : Bus 3696	: V=1.07543663, theta=-29.2920483 -> V=1.04444, theta=0.0
% INFO    : Bus 3697	: V=1.08063534, theta=-25.7244386 -> V=1.07237, theta=0.0
% INFO    : Bus 3698	: V=1.02448047, theta=-26.1209655 -> V=1.0158755, theta=0.0
% INFO    : Bus 3699	: V=1.06532105, theta=-11.3295806 -> V=0.9888895, theta=0.0
% INFO    : Bus 3700	: V=1.00075116, theta=-29.2317002 -> V=1.0000005, theta=0.0
% INFO    : Bus 3701	: V=1.02926188, theta=-20.2761941 -> V=1.0000025, theta=0.0
% INFO    : Bus 3702	: V=1.0643764, theta=-15.1162751 -> V=1.044445, theta=0.0
% INFO    : Bus 3703	: V=0.973890597, theta=-19.3470346 -> V=1.015872, theta=0.0
% INFO    : Bus 3704	: V=1.04672116, theta=-16.6959599 -> V=1.046665, theta=0.0
% INFO    : Bus 3705	: V=1.03510153, theta=-51.6960464 -> V=1.0079355, theta=0.0
% INFO    : Bus 3706	: V=1.05549786, theta=-30.3022843 -> V=1.022224, theta=0.0
% INFO    : Bus 3707	: V=1.055, theta=-24.290292 -> V=1.027779, theta=0.0
% INFO    : Bus 3708	: V=1.02516198, theta=-10.0883322 -> V=0.999999, theta=0.0
% INFO    : Bus 3709	: V=1.042, theta=-10.7437534 -> V=0.999999, theta=0.0
% INFO    : Bus 3710	: V=1.02826789, theta=-6.59949072 -> V=1.0158755, theta=0.0
% INFO    : Bus 3711	: V=1.05054283, theta=-32.310752 -> V=1.0116855, theta=0.0
% INFO    : Bus 3712	: V=1.01170573, theta=-35.560607 -> V=1.027779, theta=0.0
% INFO    : Bus 3713	: V=1.05770225, theta=-29.531761 -> V=1.0000025, theta=0.0
% INFO    : Bus 3714	: V=1.04206229, theta=-43.0586199 -> V=1.0079355, theta=0.0
% INFO    : Bus 3715	: V=1.03699357, theta=-45.0960288 -> V=1.0079355, theta=0.0
% INFO    : Bus 3716	: V=1.05738624, theta=-38.9046487 -> V=1.04444, theta=0.0
% INFO    : Bus 3717	: V=1.05738564, theta=-38.9046326 -> V=1.04444, theta=0.0
% INFO    : Bus 3718	: V=1.05738522, theta=-38.9046213 -> V=1.04444, theta=0.0
% INFO    : Bus 3719	: V=0.936377787, theta=-5.06544702 -> V=0.9444445, theta=0.0
% INFO    : Bus 3720	: V=1.0022565, theta=-5.60849678 -> V=0.999999, theta=0.0
% INFO    : Bus 3721	: V=1.05039521, theta=-3.13780959 -> V=1.003335, theta=0.0
% INFO    : Bus 3722	: V=1.05156644, theta=-5.90192968 -> V=1.0111115, theta=0.0
% INFO    : Bus 3723	: V=1.01816103, theta=-1.00793466 -> V=1.0158755, theta=0.0
% INFO    : Bus 3724	: V=1.00537566, theta=-29.686103 -> V=1.0000005, theta=0.0
% INFO    : Bus 3725	: V=1.02186903, theta=-28.9865578 -> V=1.0000005, theta=0.0
% INFO    : Bus 3726	: V=1.03747128, theta=-29.2812258 -> V=1.027779, theta=0.0
% INFO    : Bus 3727	: V=1.07161025, theta=-25.7633496 -> V=1.046665, theta=0.0
% INFO    : Bus 3728	: V=1.04211021, theta=-43.0591064 -> V=1.0079355, theta=0.0
% INFO    : Bus 3729	: V=1.05155547, theta=-43.4163109 -> V=1.04444, theta=0.0
% INFO    : Bus 3730	: V=1.05738373, theta=-38.904581 -> V=1.04444, theta=0.0
% INFO    : Bus 3731	: V=1.02928099, theta=-6.20374149 -> V=1.0158755, theta=0.0
% INFO    : Bus 3732	: V=1.01318886, theta=-27.5626965 -> V=1.0000005, theta=0.0
% INFO    : Bus 3733	: V=1.01307585, theta=-27.5647641 -> V=1.0000005, theta=0.0
% INFO    : Bus 3734	: V=1.00760786, theta=-18.7025699 -> V=1.015872, theta=0.0
% INFO    : Bus 3735	: V=1.0490563, theta=-13.983725 -> V=1.046665, theta=0.0
% INFO    : Bus 3736	: V=1.03922938, theta=-10.8317793 -> V=0.999999, theta=0.0
% INFO    : Bus 3737	: V=1.05046108, theta=-22.7065907 -> V=1.027779, theta=0.0
% INFO    : Bus 3738	: V=1.07898913, theta=-20.4681427 -> V=1.046665, theta=0.0
% INFO    : Bus 3739	: V=1.05583333, theta=-17.9520836 -> V=1.022224, theta=0.0
% INFO    : Bus 3740	: V=1.034, theta=-17.2273652 -> V=0.999999, theta=0.0
% INFO    : Bus 3741	: V=0.999239999, theta=-23.3106883 -> V=1.0000025, theta=0.0
% INFO    : Bus 3742	: V=1.02228217, theta=-22.8998898 -> V=1.0000025, theta=0.0
% INFO    : Bus 3743	: V=1.04826723, theta=-15.1791858 -> V=1.046665, theta=0.0
% INFO    : Bus 3744	: V=1.04330377, theta=-12.962874 -> V=1.06579, theta=0.0
% INFO    : Bus 3745	: V=1.04973036, theta=-33.8946931 -> V=1.022224, theta=0.0
% INFO    : Bus 3746	: V=1.01513845, theta=-11.6164995 -> V=1.015872, theta=0.0
% INFO    : Bus 3747	: V=1.03255656, theta=-39.185037 -> V=1.022224, theta=0.0
% INFO    : Bus 3748	: V=1.06270904, theta=-35.0981218 -> V=1.04444, theta=0.0
% INFO    : Bus 3749	: V=1.05852352, theta=-42.6930376 -> V=1.022224, theta=0.0
% INFO    : Bus 3750	: V=1.03511336, theta=-11.4444364 -> V=0.984126, theta=0.0
% INFO    : Bus 3751	: V=1.04067739, theta=-9.54797141 -> V=0.9888895, theta=0.0
% INFO    : Bus 3752	: V=1.02699731, theta=-58.2814849 -> V=1.0079355, theta=0.0
% INFO    : Bus 3753	: V=1.023, theta=-12.1948763 -> V=1.0158755, theta=0.0
% INFO    : Bus 3754	: V=1.01460098, theta=-30.0473342 -> V=1.0000005, theta=0.0
% INFO    : Bus 3755	: V=1.01604173, theta=-6.43948234 -> V=1.0158755, theta=0.0
% INFO    : Bus 3756	: V=1.05402196, theta=-1.48078938 -> V=1.0377785, theta=0.0
% INFO    : Bus 3757	: V=1.01949737, theta=-1.01430947 -> V=1.0158755, theta=0.0
% INFO    : Bus 3758	: V=1.00543785, theta=-39.2324789 -> V=1.027779, theta=0.0
% INFO    : Bus 3759	: V=1.05247614, theta=-13.9956042 -> V=1.046665, theta=0.0
% INFO    : Bus 3760	: V=1.04486054, theta=-23.991658 -> V=1.022224, theta=0.0
% INFO    : Bus 3761	: V=1.04369971, theta=-23.7530833 -> V=1.022224, theta=0.0
% INFO    : Bus 3762	: V=1.08364265, theta=4.00549837 -> V=1.0398285, theta=0.0
% INFO    : Bus 3763	: V=1.02266808, theta=0.0948414238 -> V=1.0158755, theta=0.0
% INFO    : Bus 3764	: V=1.0357958, theta=-8.58161803 -> V=1.0158755, theta=0.0
% INFO    : Bus 3765	: V=1.01760172, theta=-23.1464064 -> V=1.0000005, theta=0.0
% INFO    : Bus 3766	: V=1.07426546, theta=-16.6213427 -> V=1.073685, theta=0.0
% INFO    : Bus 3767	: V=1.03896959, theta=-13.4135678 -> V=1.0158755, theta=0.0
% INFO    : Bus 3768	: V=1.00366104, theta=-15.6983198 -> V=1.015872, theta=0.0
% INFO    : Bus 3769	: V=0.986093137, theta=-16.9074655 -> V=1.015872, theta=0.0
% INFO    : Bus 3770	: V=1.01532572, theta=-17.1648309 -> V=1.015872, theta=0.0
% INFO    : Bus 3771	: V=1.05134016, theta=-14.8359568 -> V=1.046665, theta=0.0
% INFO    : Bus 3772	: V=1.05134102, theta=-14.8420922 -> V=1.046665, theta=0.0
% INFO    : Bus 3773	: V=1.05119465, theta=-14.8426002 -> V=1.046665, theta=0.0
% INFO    : Bus 3774	: V=1.01669216, theta=-24.4797516 -> V=1.0000005, theta=0.0
% INFO    : Bus 3775	: V=1.04954119, theta=-19.0540634 -> V=1.046665, theta=0.0
% INFO    : Bus 3776	: V=1.07413726, theta=-12.7215155 -> V=1.073685, theta=0.0
% INFO    : Bus 3777	: V=1.03635741, theta=-34.0594378 -> V=1.022224, theta=0.0
% INFO    : Bus 3778	: V=1.01610293, theta=4.29881102 -> V=1.046665, theta=0.0
% INFO    : Bus 3779	: V=1.0141548, theta=4.55963575 -> V=1.046665, theta=0.0
% INFO    : Bus 3780	: V=1.07461963, theta=-36.3133524 -> V=0.975, theta=0.0
% INFO    : Bus 3781	: V=1.07445723, theta=-36.3930577 -> V=0.975, theta=0.0
% INFO    : Bus 3782	: V=1.07445723, theta=-36.3930577 -> V=0.975, theta=0.0
% INFO    : Bus 3783	: V=1.07466827, theta=-36.3045167 -> V=1.04444, theta=0.0
% INFO    : Bus 3784	: V=1.07445723, theta=-36.3930577 -> V=1.04444, theta=0.0
% INFO    : Bus 3785	: V=1.03976103, theta=-26.0452729 -> V=1.0000025, theta=0.0
% INFO    : Bus 3786	: V=1.02598994, theta=-23.521008 -> V=1.000001, theta=0.0
% INFO    : Bus 3787	: V=1.00438288, theta=-18.1254684 -> V=1.015872, theta=0.0
% INFO    : Bus 3788	: V=1.06097327, theta=-20.0297098 -> V=1.0000025, theta=0.0
% INFO    : Bus 3789	: V=1.06143977, theta=-20.2384812 -> V=1.0000025, theta=0.0
% INFO    : Bus 3790	: V=1.03063594, theta=-25.4772976 -> V=1.0003805, theta=0.0
% INFO    : Bus 3791	: V=1.04482688, theta=-13.4934221 -> V=1.0000025, theta=0.0
% INFO    : Bus 3792	: V=1.02257781, theta=-13.3951563 -> V=0.999999, theta=0.0
% INFO    : Bus 3793	: V=1.02496388, theta=-26.6007236 -> V=1.0000025, theta=0.0
% INFO    : Bus 3794	: V=1.02250124, theta=-12.6339681 -> V=0.999999, theta=0.0
% INFO    : Bus 3795	: V=1.04924947, theta=-25.8456968 -> V=1.046665, theta=0.0
% INFO    : Bus 3796	: V=1.04916062, theta=-25.8552836 -> V=1.046665, theta=0.0
% INFO    : Bus 3797	: V=1.08185585, theta=2.46020043 -> V=1.05263, theta=0.0
% INFO    : Bus 3798	: V=1.08185576, theta=2.46020043 -> V=1.05263, theta=0.0
% INFO    : Bus 3799	: V=1.08233134, theta=2.4869535 -> V=1.05263, theta=0.0
% INFO    : Bus 3800	: V=1.08185576, theta=2.46020043 -> V=1.05263, theta=0.0
% INFO    : Bus 3801	: V=1.02256911, theta=-7.96888219 -> V=1.0158755, theta=0.0
% INFO    : Bus 3802	: V=1.05924051, theta=-4.99220266 -> V=1.0377785, theta=0.0
% INFO    : Bus 3803	: V=1.06451073, theta=-2.70055212 -> V=1.072365, theta=0.0
% INFO    : Bus 3804	: V=1.04125882, theta=-5.63920612 -> V=0.984126, theta=0.0
% INFO    : Bus 3805	: V=1.06507659, theta=-1.34967328 -> V=1.0377785, theta=0.0
% INFO    : Bus 3806	: V=1.0022813, theta=-8.93288506 -> V=1.0158755, theta=0.0
% INFO    : Bus 3807	: V=1.06313386, theta=-0.116375533 -> V=1.0377785, theta=0.0
% INFO    : Bus 3808	: V=1.049, theta=6.31945936 -> V=0.975, theta=0.0
% INFO    : Bus 3809	: V=1.062, theta=5.4693137 -> V=0.975, theta=0.0
% INFO    : Bus 3810	: V=1.069, theta=5.33179261 -> V=0.975, theta=0.0
% INFO    : Bus 3811	: V=1.06305279, theta=-0.0954633658 -> V=1.0377785, theta=0.0
% INFO    : Bus 3812	: V=1.06310261, theta=-0.0979241388 -> V=1.0377785, theta=0.0
% INFO    : Bus 3813	: V=1.06312674, theta=-0.0982187522 -> V=1.0377785, theta=0.0
% INFO    : Bus 3814	: V=1.0367569, theta=-40.2360735 -> V=1.022224, theta=0.0
% INFO    : Bus 3815	: V=1.04065815, theta=-18.6520752 -> V=1.0158755, theta=0.0
% INFO    : Bus 3816	: V=1.02124572, theta=-8.48402265 -> V=1.0158755, theta=0.0
% INFO    : Bus 3817	: V=1.02577917, theta=-25.7327066 -> V=1.0000005, theta=0.0
% INFO    : Bus 3818	: V=1.03390818, theta=-21.6383932 -> V=1.0000025, theta=0.0
% INFO    : Bus 3819	: V=1.06582065, theta=-27.6058332 -> V=1.046665, theta=0.0
% INFO    : Bus 3820	: V=1.06396674, theta=-24.7779983 -> V=1.046665, theta=0.0
% INFO    : Bus 3821	: V=1.06379274, theta=-24.79049 -> V=1.046665, theta=0.0
% INFO    : Bus 3822	: V=1.01874826, theta=1.95857387 -> V=1.0158755, theta=0.0
% INFO    : Bus 3823	: V=1.01997567, theta=2.34852466 -> V=1.0158755, theta=0.0
% INFO    : Bus 3824	: V=1.0755677, theta=3.57294402 -> V=1.0377785, theta=0.0
% INFO    : Bus 3825	: V=1.05212932, theta=-14.613412 -> V=1.046665, theta=0.0
% INFO    : Bus 3826	: V=1.0571383, theta=-15.7174756 -> V=1.033333, theta=0.0
% INFO    : Bus 3827	: V=1.05422136, theta=-16.8449399 -> V=1.033333, theta=0.0
% INFO    : Bus 3828	: V=1.04479978, theta=-19.776074 -> V=1.0000025, theta=0.0
% INFO    : Bus 3829	: V=1.04992079, theta=-19.1819932 -> V=1.0000025, theta=0.0
% INFO    : Bus 3830	: V=1.03028104, theta=-13.4207358 -> V=0.999999, theta=0.0
% INFO    : Bus 3831	: V=1.04487612, theta=-20.0138544 -> V=0.999999, theta=0.0
% INFO    : Bus 3832	: V=1.04608955, theta=-14.4787378 -> V=0.999999, theta=0.0
% INFO    : Bus 3833	: V=1.05304069, theta=-12.7780698 -> V=1.0111115, theta=0.0
% INFO    : Bus 3834	: V=1.027, theta=-8.60901821 -> V=0.999999, theta=0.0
% INFO    : Bus 3835	: V=1.0230282, theta=-24.0500812 -> V=1.022224, theta=0.0
% INFO    : Bus 3836	: V=1.04921249, theta=-29.6265562 -> V=1.0000025, theta=0.0
% INFO    : Bus 3837	: V=1.04463526, theta=-28.442091 -> V=1.027779, theta=0.0
% INFO    : Bus 3838	: V=1.03856103, theta=-26.3697633 -> V=1.046665, theta=0.0
% INFO    : Bus 3839	: V=1.03059724, theta=-19.2438061 -> V=1.022224, theta=0.0
% INFO    : Bus 3840	: V=1.05427675, theta=-22.9006356 -> V=1.022224, theta=0.0
% INFO    : Bus 3841	: V=1.03555172, theta=-12.3514468 -> V=0.999999, theta=0.0
% INFO    : Bus 3842	: V=1.0439128, theta=-26.2968479 -> V=1.0000025, theta=0.0
% INFO    : Bus 3843	: V=1.07176796, theta=-22.9172197 -> V=1.044445, theta=0.0
% INFO    : Bus 3844	: V=1.02883677, theta=-9.75066581 -> V=0.999999, theta=0.0
% INFO    : Bus 3845	: V=1.039, theta=-21.6947696 -> V=1.0000025, theta=0.0
% INFO    : Bus 3846	: V=1.04508078, theta=-13.2386335 -> V=1.000139, theta=0.0
% INFO    : Bus 3847	: V=1.04858234, theta=-13.6109635 -> V=1.001819, theta=0.0
% INFO    : Bus 3848	: V=1.04451481, theta=-9.61832633 -> V=1.0111115, theta=0.0
% INFO    : Bus 3849	: V=1.03183415, theta=-6.28287506 -> V=1.0158755, theta=0.0
% INFO    : Bus 3850	: V=1.04401151, theta=-14.8337263 -> V=0.999999, theta=0.0
% INFO    : Bus 3851	: V=1.03044542, theta=-5.73106161 -> V=1.0158755, theta=0.0
% INFO    : Bus 3852	: V=1.07213929, theta=-25.5737655 -> V=1.04697, theta=0.0
% INFO    : Bus 3853	: V=1.05753868, theta=-25.1154054 -> V=1.046665, theta=0.0
% INFO    : Bus 3854	: V=1.05117923, theta=-14.7323356 -> V=1.046665, theta=0.0
% INFO    : Bus 3855	: V=1.04984744, theta=-23.6912675 -> V=1.022224, theta=0.0
% INFO    : Bus 3856	: V=1.03705174, theta=-14.0502794 -> V=0.999999, theta=0.0
% INFO    : Bus 3857	: V=1.03494849, theta=-10.8913495 -> V=0.999999, theta=0.0
% INFO    : Bus 3858	: V=1.06462032, theta=-28.8363483 -> V=1.025904, theta=0.0
% INFO    : Bus 3859	: V=1.0374545, theta=-29.132847 -> V=1.022224, theta=0.0
% INFO    : Bus 3860	: V=1.032, theta=-28.896825 -> V=1.022224, theta=0.0
% INFO    : Bus 3861	: V=1.0604765, theta=-22.0709402 -> V=1.0000025, theta=0.0
% INFO    : Bus 3862	: V=1.03515677, theta=-26.3178858 -> V=1.015872, theta=0.0
% INFO    : Bus 3863	: V=1.03850276, theta=-5.15275561 -> V=1.0158755, theta=0.0
% INFO    : Bus 3864	: V=1.07896796, theta=-20.4695046 -> V=1.046665, theta=0.0
% INFO    : Bus 3865	: V=1.02750517, theta=-18.3884992 -> V=1.015872, theta=0.0
% INFO    : Bus 3866	: V=1.0450085, theta=-15.0095283 -> V=1.046665, theta=0.0
% INFO    : Bus 3867	: V=1.02870776, theta=-6.04904617 -> V=1.0158755, theta=0.0
% INFO    : Bus 3868	: V=1.03318558, theta=-24.2160334 -> V=1.0000025, theta=0.0
% INFO    : Bus 3869	: V=1.02729375, theta=-27.6563808 -> V=1.0000025, theta=0.0
% INFO    : Bus 3870	: V=1.02152218, theta=-12.4835684 -> V=1.0158755, theta=0.0
% INFO    : Bus 3871	: V=1.05828091, theta=-10.9758118 -> V=1.0377785, theta=0.0
% INFO    : Bus 3872	: V=1.00208921, theta=-26.5762496 -> V=1.0000005, theta=0.0
% INFO    : Bus 3873	: V=1.06482591, theta=-24.765796 -> V=1.046665, theta=0.0
% INFO    : Bus 3874	: V=1.06373247, theta=-24.8239926 -> V=1.046665, theta=0.0
% INFO    : Bus 3875	: V=1.03457199, theta=-15.3496847 -> V=1.0158755, theta=0.0
% INFO    : Bus 3876	: V=1.0227816, theta=1.99193969 -> V=1.0158755, theta=0.0
% INFO    : Bus 3877	: V=1.01946545, theta=2.35580034 -> V=1.0158755, theta=0.0
% INFO    : Bus 3878	: V=1.01581997, theta=-19.8372049 -> V=1.0158755, theta=0.0
% INFO    : Bus 3879	: V=0.968114318, theta=-27.267043 -> V=1.0158755, theta=0.0
% INFO    : Bus 3880	: V=1.02349343, theta=-12.6558525 -> V=1.0158755, theta=0.0
% INFO    : Bus 3881	: V=1.02121599, theta=-12.139998 -> V=1.0277795, theta=0.0
% INFO    : Bus 3882	: V=1.02230236, theta=-23.3519242 -> V=1.022224, theta=0.0
% INFO    : Bus 3883	: V=1.0342724, theta=-12.0642651 -> V=1.0158755, theta=0.0
% INFO    : Bus 3884	: V=1.02789942, theta=-21.0973145 -> V=1.0158755, theta=0.0
% INFO    : Bus 3885	: V=1.01905675, theta=-47.4121804 -> V=1.0079355, theta=0.0
% INFO    : Bus 3886	: V=1.04012833, theta=-17.7139958 -> V=1.015872, theta=0.0
% INFO    : Bus 3887	: V=1.02602126, theta=-5.31916774 -> V=1.0158755, theta=0.0
% INFO    : Bus 3888	: V=1.03443405, theta=-35.3569696 -> V=1.022224, theta=0.0
% INFO    : Bus 3889	: V=1.026426, theta=-13.6667458 -> V=1.0158755, theta=0.0
% INFO    : Bus 3890	: V=1.04683351, theta=-10.6747191 -> V=1.0377785, theta=0.0
% INFO    : Bus 3891	: V=1.03602529, theta=-21.9494113 -> V=1.022224, theta=0.0
% INFO    : Bus 3892	: V=1.0405368, theta=-49.10266 -> V=1.0079355, theta=0.0
% INFO    : Bus 3893	: V=1.06617852, theta=-44.3124692 -> V=1.04444, theta=0.0
% INFO    : Bus 3894	: V=1.00504766, theta=-30.9001487 -> V=1.0000005, theta=0.0
% INFO    : Bus 3895	: V=1.04135587, theta=-12.2189448 -> V=0.999999, theta=0.0
% INFO    : Bus 3896	: V=1.0370142, theta=-56.0583717 -> V=1.0079355, theta=0.0
% INFO    : Bus 3897	: V=1.08336555, theta=-20.1972294 -> V=1.049975, theta=0.0
% INFO    : Bus 3898	: V=1.07450598, theta=-21.5017655 -> V=1.046665, theta=0.0
% INFO    : Bus 3899	: V=1.08485835, theta=-17.5408332 -> V=1.073685, theta=0.0
% INFO    : Bus 3900	: V=1.04192182, theta=-10.4022899 -> V=1.046665, theta=0.0
% INFO    : Bus 3901	: V=1.07107555, theta=-27.698655 -> V=1.028654, theta=0.0
% INFO    : Bus 3902	: V=1.05846509, theta=-19.4213383 -> V=1.0233335, theta=0.0
% INFO    : Bus 3903	: V=1.04833587, theta=-16.7928258 -> V=1.046665, theta=0.0
% INFO    : Bus 3904	: V=1.02252497, theta=-18.8862253 -> V=1.015872, theta=0.0
% INFO    : Bus 3905	: V=0.991053519, theta=-19.8791351 -> V=1.015872, theta=0.0
% INFO    : Bus 3906	: V=1.0507369, theta=-19.5827041 -> V=1.022224, theta=0.0
% INFO    : Bus 3907	: V=1.00561804, theta=-2.50393426 -> V=1.0158755, theta=0.0
% INFO    : Bus 3908	: V=1.04216957, theta=-23.724668 -> V=1.0158755, theta=0.0
% INFO    : Bus 3909	: V=1.04741778, theta=-19.1812347 -> V=1.0377785, theta=0.0
% INFO    : Bus 3910	: V=1.03861342, theta=-25.2345874 -> V=1.0000025, theta=0.0
% INFO    : Bus 3911	: V=1.04733238, theta=-26.4809418 -> V=1.0000025, theta=0.0
% INFO    : Bus 3912	: V=1.05292037, theta=-14.6870085 -> V=0.9888895, theta=0.0
% INFO    : Bus 3913	: V=1.05292223, theta=-14.6820741 -> V=0.9888895, theta=0.0
% INFO    : Bus 3914	: V=1.0398102, theta=-26.5925852 -> V=1.022224, theta=0.0
% INFO    : Bus 3915	: V=1.0669584, theta=-22.5209613 -> V=1.015874, theta=0.0
% INFO    : Bus 3916	: V=1.05524508, theta=-22.1353971 -> V=1.015874, theta=0.0
% INFO    : Bus 3917	: V=1.04606953, theta=-17.6278614 -> V=1.026667, theta=0.0
% INFO    : Bus 3918	: V=1.06792956, theta=-10.7096902 -> V=0.9888895, theta=0.0
% INFO    : Bus 3919	: V=1.03004509, theta=-24.9855521 -> V=1.015872, theta=0.0
% INFO    : Bus 3920	: V=1.05027321, theta=-25.2960911 -> V=1.0233335, theta=0.0
% INFO    : Bus 3921	: V=1.05788658, theta=-23.4767178 -> V=1.0000025, theta=0.0
% INFO    : Bus 3922	: V=1.01725435, theta=-18.8862451 -> V=1.015872, theta=0.0
% INFO    : Bus 3923	: V=1.04381597, theta=-13.2957908 -> V=1.046665, theta=0.0
% INFO    : Bus 3924	: V=1.01044035, theta=-14.3699919 -> V=1.0079355, theta=0.0
% INFO    : Bus 3925	: V=0.985753957, theta=-30.8193881 -> V=1.0000005, theta=0.0
% INFO    : Bus 3926	: V=1.07475911, theta=-28.455348 -> V=1.047355, theta=0.0
% INFO    : Bus 3927	: V=1.07461222, theta=-28.4697052 -> V=1.047285, theta=0.0
% INFO    : Bus 3928	: V=1.0573961, theta=-14.9002124 -> V=1.0000025, theta=0.0
% INFO    : Bus 3929	: V=1.09317443, theta=-12.0559055 -> V=1.047575, theta=0.0
% INFO    : Bus 3930	: V=1.1038255, theta=-8.99303311 -> V=1.07987, theta=0.0
% INFO    : Bus 3931	: V=1.04095722, theta=-24.4239305 -> V=1.000001, theta=0.0
% INFO    : Bus 3932	: V=1.0473406, theta=-21.3628232 -> V=1.0000025, theta=0.0
% INFO    : Bus 3933	: V=1.03707694, theta=-10.3535561 -> V=0.999999, theta=0.0
% INFO    : Bus 3934	: V=1.04522483, theta=-13.0969609 -> V=1.0111115, theta=0.0
% INFO    : Bus 3935	: V=1.06732474, theta=-10.0096814 -> V=1.072365, theta=0.0
% INFO    : Bus 3936	: V=1.02462923, theta=-54.188449 -> V=1.0079355, theta=0.0
% INFO    : Bus 3937	: V=1.04716093, theta=-10.0907604 -> V=0.999999, theta=0.0
% INFO    : Bus 3938	: V=1.06228138, theta=-12.4562408 -> V=0.9888895, theta=0.0
% INFO    : Bus 3939	: V=1.06420643, theta=-26.9566377 -> V=1.046665, theta=0.0
% INFO    : Bus 3940	: V=1.07378419, theta=-25.8213452 -> V=1.04782, theta=0.0
% INFO    : Bus 3941	: V=1.04070268, theta=-17.7072482 -> V=0.9888895, theta=0.0
% INFO    : Bus 3942	: V=1.01211378, theta=-30.0877914 -> V=1.0000005, theta=0.0
% INFO    : Bus 3943	: V=1.02000643, theta=-4.97666482 -> V=1.0158755, theta=0.0
% INFO    : Bus 3944	: V=1.07445941, theta=-25.8411833 -> V=1.04816, theta=0.0
% INFO    : Bus 3945	: V=1.07409316, theta=-25.8460792 -> V=1.047975, theta=0.0
% INFO    : Bus 3946	: V=1.03382519, theta=-13.4390784 -> V=0.999999, theta=0.0
% INFO    : Bus 3947	: V=1.0334522, theta=-14.0164269 -> V=0.999999, theta=0.0
% INFO    : Bus 3948	: V=1.05244441, theta=-22.1767194 -> V=1.0000025, theta=0.0
% INFO    : Bus 3949	: V=1.05008697, theta=-25.6494276 -> V=1.027779, theta=0.0
% INFO    : Bus 3950	: V=1.04380078, theta=-26.0567435 -> V=1.027779, theta=0.0
% INFO    : Bus 3951	: V=1.03785756, theta=-18.3315155 -> V=1.0158755, theta=0.0
% INFO    : Bus 3952	: V=1.03808754, theta=-18.3255658 -> V=1.0158755, theta=0.0
% INFO    : Bus 3953	: V=0.999899626, theta=-31.8107251 -> V=1.0000005, theta=0.0
% INFO    : Bus 3954	: V=1.06965969, theta=-26.1383786 -> V=1.046665, theta=0.0
% INFO    : Bus 3955	: V=1.06999766, theta=-26.2204701 -> V=1.046665, theta=0.0
% INFO    : Bus 3956	: V=1.06089084, theta=-42.9918006 -> V=1.022694, theta=0.0
% INFO    : Bus 3957	: V=1.0486447, theta=-23.9600041 -> V=1.0000025, theta=0.0
% INFO    : Bus 3958	: V=1.05511259, theta=-6.8261485 -> V=1.0111115, theta=0.0
% INFO    : Bus 3959	: V=1.03514879, theta=-33.6118321 -> V=1.022224, theta=0.0
% INFO    : Bus 3960	: V=1.032, theta=-4.29413117 -> V=0.975, theta=0.0
% INFO    : Bus 3961	: V=1.021, theta=-7.67760787 -> V=0.975, theta=0.0
% INFO    : Bus 3962	: V=1.02508695, theta=-10.5937911 -> V=0.999999, theta=0.0
% INFO    : Bus 3963	: V=1.03337459, theta=-6.99822966 -> V=1.0111115, theta=0.0
% INFO    : Bus 3964	: V=1.00152014, theta=-12.459028 -> V=1.015872, theta=0.0
% INFO    : Bus 3965	: V=1.04065851, theta=-22.7341943 -> V=1.0000025, theta=0.0
% INFO    : Bus 3966	: V=1.0108677, theta=1.21551002 -> V=1.0158755, theta=0.0
% INFO    : Bus 3967	: V=1.01962287, theta=2.17055833 -> V=1.0158755, theta=0.0
% INFO    : Bus 3968	: V=1.07467308, theta=4.41127454 -> V=1.0377785, theta=0.0
% INFO    : Bus 3969	: V=1.03193377, theta=-21.659652 -> V=1.000001, theta=0.0
% INFO    : Bus 3970	: V=1.05450812, theta=-24.2994886 -> V=1.027779, theta=0.0
% INFO    : Bus 3971	: V=1.04964563, theta=-24.9334345 -> V=1.027779, theta=0.0
% INFO    : Bus 3972	: V=1.07675887, theta=-20.7322913 -> V=1.046665, theta=0.0
% INFO    : Bus 3973	: V=1.0546484, theta=-24.7090916 -> V=1.022224, theta=0.0
% INFO    : Bus 3974	: V=1.02488299, theta=-15.6232407 -> V=0.999999, theta=0.0
% INFO    : Bus 3975	: V=1.01917567, theta=1.42483643 -> V=1.0158755, theta=0.0
% INFO    : Bus 3976	: V=1.01905512, theta=-13.2615069 -> V=0.999999, theta=0.0
% INFO    : Bus 3977	: V=1.0158762, theta=-27.0262249 -> V=1.0000025, theta=0.0
% INFO    : Bus 3978	: V=1.04045585, theta=-22.7275026 -> V=1.022224, theta=0.0
% INFO    : Bus 3979	: V=1.005, theta=-12.7578552 -> V=1.015872, theta=0.0
% INFO    : Bus 3980	: V=1.01568022, theta=-31.364706 -> V=1.015872, theta=0.0
% INFO    : Bus 3981	: V=1.02504451, theta=-19.2795526 -> V=0.999999, theta=0.0
% INFO    : Bus 3982	: V=1.0212468, theta=-19.3605973 -> V=1.0158755, theta=0.0
% INFO    : Bus 3983	: V=1.05434135, theta=-11.5228044 -> V=1.033334, theta=0.0
% INFO    : Bus 3984	: V=1.03392123, theta=-15.1586117 -> V=1.015872, theta=0.0
% INFO    : Bus 3985	: V=1.03097678, theta=-15.1232534 -> V=1.015872, theta=0.0
% INFO    : Bus 3986	: V=1.04291573, theta=-11.9525087 -> V=0.999999, theta=0.0
% INFO    : Bus 3987	: V=1.02249472, theta=-7.97663523 -> V=1.0158755, theta=0.0
% INFO    : Bus 3988	: V=1.04435803, theta=-13.1851228 -> V=1.033334, theta=0.0
% INFO    : Bus 3989	: V=1.06136768, theta=-22.0883892 -> V=1.0000025, theta=0.0
% INFO    : Bus 3990	: V=1.06210035, theta=-22.0222155 -> V=1.0000025, theta=0.0
% INFO    : Bus 3991	: V=1.03445858, theta=-19.4085278 -> V=0.999999, theta=0.0
% INFO    : Bus 3992	: V=1.05149347, theta=-20.8276376 -> V=1.022222, theta=0.0
% INFO    : Bus 3993	: V=1.00415639, theta=-26.7819782 -> V=1.0000005, theta=0.0
% INFO    : Bus 3994	: V=1.01906794, theta=-25.6425131 -> V=1.0000005, theta=0.0
% INFO    : Bus 3995	: V=1.010703, theta=-14.8880579 -> V=1.0079355, theta=0.0
% INFO    : Bus 3996	: V=1.04769665, theta=-23.291812 -> V=1.027779, theta=0.0
% INFO    : Bus 3997	: V=1.07611295, theta=-20.9453013 -> V=1.046665, theta=0.0
% INFO    : Bus 3998	: V=1.00762026, theta=-25.3280867 -> V=1.0000005, theta=0.0
% INFO    : Bus 3999	: V=1.05640112, theta=-19.3817919 -> V=1.0000025, theta=0.0
% INFO    : Bus 4000	: V=1.05632915, theta=-31.7818337 -> V=1.0000025, theta=0.0
% INFO    : Bus 4001	: V=1.05368481, theta=-25.945318 -> V=1.044445, theta=0.0
% INFO    : Bus 4002	: V=1.05558605, theta=-16.4353552 -> V=1.003774, theta=0.0
% INFO    : Bus 4003	: V=1.05038329, theta=-11.6559549 -> V=1.0111115, theta=0.0
% INFO    : Bus 4004	: V=1.04113425, theta=-31.9797397 -> V=1.027779, theta=0.0
% INFO    : Bus 4005	: V=1.03120401, theta=-24.9400338 -> V=1.022224, theta=0.0
% INFO    : Bus 4006	: V=1.03345191, theta=-14.016418 -> V=0.999999, theta=0.0
% INFO    : Bus 4007	: V=1.03155831, theta=-27.6991662 -> V=1.0000025, theta=0.0
% INFO    : Bus 4008	: V=1.02659864, theta=-21.8000889 -> V=0.999999, theta=0.0
% INFO    : Bus 4009	: V=1.02269585, theta=1.44759491 -> V=1.0158755, theta=0.0
% INFO    : Bus 4010	: V=1.07108597, theta=4.25466805 -> V=1.0377785, theta=0.0
% INFO    : Bus 4011	: V=1.01657812, theta=1.01039135 -> V=1.0158755, theta=0.0
% INFO    : Bus 4012	: V=1.09274262, theta=-11.9143481 -> V=1.04728, theta=0.0
% INFO    : Bus 4013	: V=1.03340541, theta=-2.99785719 -> V=1.0158755, theta=0.0
% INFO    : Bus 4014	: V=1.06804289, theta=-15.2897106 -> V=1.0377785, theta=0.0
% INFO    : Bus 4015	: V=1.03959862, theta=-25.1459901 -> V=1.0000025, theta=0.0
% INFO    : Bus 4016	: V=1.04191382, theta=-53.3847786 -> V=1.0079355, theta=0.0
% INFO    : Bus 4017	: V=1.02251427, theta=-11.3883534 -> V=0.999999, theta=0.0
% INFO    : Bus 4018	: V=1.04496624, theta=-21.0202755 -> V=1.0000025, theta=0.0
% INFO    : Bus 4019	: V=1.07357517, theta=-17.0160867 -> V=1.044445, theta=0.0
% INFO    : Bus 4020	: V=1.0815082, theta=-12.8780811 -> V=1.078945, theta=0.0
% INFO    : Bus 4021	: V=0.96009103, theta=-8.16349158 -> V=0.9444445, theta=0.0
% INFO    : Bus 4022	: V=1.0114665, theta=-23.7582433 -> V=1.0000025, theta=0.0
% INFO    : Bus 4023	: V=1.04388195, theta=-24.8473017 -> V=1.0111115, theta=0.0
% INFO    : Bus 4024	: V=1.02381654, theta=-9.38854837 -> V=1.0158755, theta=0.0
% INFO    : Bus 4025	: V=1.04560506, theta=-29.3448702 -> V=1.027779, theta=0.0
% INFO    : Bus 4026	: V=1.02936002, theta=-20.6553502 -> V=1.0158755, theta=0.0
% INFO    : Bus 4027	: V=1.04189444, theta=-26.5583775 -> V=1.022224, theta=0.0
% INFO    : Bus 4028	: V=1.02316922, theta=2.09855403 -> V=1.0158755, theta=0.0
% INFO    : Bus 4029	: V=1.07295924, theta=3.75082812 -> V=1.0377785, theta=0.0
% INFO    : Bus 4030	: V=1.04404416, theta=-10.428473 -> V=1.000694, theta=0.0
% INFO    : Bus 4031	: V=1.02100674, theta=-10.2080297 -> V=1.015872, theta=0.0
% INFO    : Bus 4032	: V=1.05542077, theta=-28.4143486 -> V=1.046665, theta=0.0
% INFO    : Bus 4033	: V=1.01746598, theta=-20.5232258 -> V=1.0158755, theta=0.0
% INFO    : Bus 4034	: V=1.04750496, theta=-16.0242076 -> V=1.046665, theta=0.0
% INFO    : Bus 4035	: V=1.05954646, theta=-15.8883858 -> V=1.044445, theta=0.0
% INFO    : Bus 4036	: V=1.03651248, theta=-28.7286591 -> V=1.022224, theta=0.0
% INFO    : Bus 4037	: V=0.978674388, theta=-4.94957903 -> V=0.9444445, theta=0.0
% INFO    : Bus 4038	: V=1.04715482, theta=-4.05823928 -> V=1.0111115, theta=0.0
% INFO    : Bus 4039	: V=1.06312479, theta=-23.849527 -> V=1.046665, theta=0.0
% INFO    : Bus 4040	: V=1.05176815, theta=-24.9231254 -> V=1.046665, theta=0.0
% INFO    : Bus 4041	: V=1.05877473, theta=-19.7030224 -> V=1.073685, theta=0.0
% INFO    : Bus 4042	: V=1.03447446, theta=-25.8275478 -> V=1.022224, theta=0.0
% INFO    : Bus 4043	: V=1.02265822, theta=-14.0436093 -> V=0.975, theta=0.0
% INFO    : Bus 4044	: V=1.05624096, theta=-5.93920074 -> V=1.0111115, theta=0.0
% INFO    : Bus 4045	: V=1.04148723, theta=-23.670352 -> V=0.984126, theta=0.0
% INFO    : Bus 4046	: V=1.03110256, theta=-60.7561946 -> V=1.0079355, theta=0.0
% INFO    : Bus 4047	: V=1.028, theta=-13.7685614 -> V=1.015872, theta=0.0
% INFO    : Bus 4048	: V=1.01062445, theta=-19.6098853 -> V=1.015872, theta=0.0
% INFO    : Bus 4049	: V=1.02214361, theta=-27.5755159 -> V=1.0000005, theta=0.0
% INFO    : Bus 4050	: V=1.02214378, theta=-27.575521 -> V=1.0000005, theta=0.0
% INFO    : Bus 4051	: V=1.0529232, theta=-27.4148415 -> V=1.0000025, theta=0.0
% INFO    : Bus 4052	: V=1.03728218, theta=-43.0679288 -> V=1.0079355, theta=0.0
% INFO    : Bus 4053	: V=1.02609677, theta=-6.69904421 -> V=1.0158755, theta=0.0
% INFO    : Bus 4054	: V=1.05040104, theta=-25.3856198 -> V=1.046665, theta=0.0
% INFO    : Bus 4055	: V=1.07284979, theta=-16.1904322 -> V=1.008724, theta=0.0
% INFO    : Bus 4056	: V=1.08413282, theta=-12.825963 -> V=1.0111115, theta=0.0
% INFO    : Bus 4057	: V=1.03407424, theta=-55.4221825 -> V=1.0079355, theta=0.0
% INFO    : Bus 4058	: V=1.05828172, theta=-19.8091868 -> V=1.016666, theta=0.0
% INFO    : Bus 4059	: V=1.07132815, theta=-0.176050106 -> V=1.0377785, theta=0.0
% INFO    : Bus 4060	: V=1.08353246, theta=2.01430852 -> V=1.072365, theta=0.0
% INFO    : Bus 4061	: V=1.03010168, theta=-6.00038983 -> V=1.0158755, theta=0.0
% INFO    : Bus 4062	: V=1.02944378, theta=-25.3026249 -> V=1.0000025, theta=0.0
% INFO    : Bus 4063	: V=1.04774291, theta=-35.2411053 -> V=1.027779, theta=0.0
% INFO    : Bus 4064	: V=1.01972119, theta=-38.8511701 -> V=1.022224, theta=0.0
% INFO    : Bus 4065	: V=0.989595549, theta=-30.1589672 -> V=1.0000005, theta=0.0
% INFO    : Bus 4066	: V=1.0189543, theta=-18.6242798 -> V=1.0158755, theta=0.0
% INFO    : Bus 4067	: V=1.03630708, theta=-33.744696 -> V=1.022224, theta=0.0
% INFO    : Bus 4068	: V=1.01092847, theta=-26.1787183 -> V=1.0000005, theta=0.0
% INFO    : Bus 4069	: V=1.01080481, theta=-26.1771975 -> V=1.0000005, theta=0.0
% INFO    : Bus 4070	: V=1.04926857, theta=-25.8455692 -> V=1.046665, theta=0.0
% INFO    : Bus 4071	: V=1.04428584, theta=-27.9814918 -> V=1.0000025, theta=0.0
% INFO    : Bus 4072	: V=1.00870436, theta=-9.20288385 -> V=1.0158755, theta=0.0
% INFO    : Bus 4073	: V=1.03440218, theta=-13.6910598 -> V=0.999999, theta=0.0
% INFO    : Bus 4074	: V=1.06678387, theta=-25.8524905 -> V=1.046665, theta=0.0
% INFO    : Bus 4075	: V=1.05463212, theta=-7.56796504 -> V=1.0111115, theta=0.0
% INFO    : Bus 4076	: V=1.06962416, theta=-21.7423403 -> V=1.0000025, theta=0.0
% INFO    : Bus 4077	: V=1.03193377, theta=-21.659652 -> V=1.000001, theta=0.0
% INFO    : Bus 4078	: V=1.03299608, theta=-48.0825373 -> V=1.0079355, theta=0.0
% INFO    : Bus 4079	: V=1.03840519, theta=-10.7362063 -> V=1.0158755, theta=0.0
% INFO    : Bus 4080	: V=1.05132805, theta=-4.11127017 -> V=1.0158755, theta=0.0
% INFO    : Bus 4081	: V=1.03949162, theta=-3.37660736 -> V=1.0377785, theta=0.0
% INFO    : Bus 4082	: V=1.03095195, theta=-31.2043596 -> V=1.022224, theta=0.0
% INFO    : Bus 4083	: V=1.02911114, theta=-27.2139572 -> V=1.0000025, theta=0.0
% INFO    : Bus 4084	: V=1.04022586, theta=-17.8854888 -> V=0.999999, theta=0.0
% INFO    : Bus 4085	: V=1.04339225, theta=-12.6670168 -> V=1.0111115, theta=0.0
% INFO    : Bus 4086	: V=0.982711721, theta=-24.3384902 -> V=1.0000005, theta=0.0
% INFO    : Bus 4087	: V=1.05394111, theta=-24.3566566 -> V=1.046665, theta=0.0
% INFO    : Bus 4088	: V=1.00921679, theta=-29.3026929 -> V=1.0000005, theta=0.0
% INFO    : Bus 4089	: V=1.00032152, theta=-23.5517015 -> V=1.0158755, theta=0.0
% INFO    : Bus 4090	: V=1.06086357, theta=-33.7946602 -> V=1.029224, theta=0.0
% INFO    : Bus 4091	: V=1.01703163, theta=-17.7107065 -> V=1.0158755, theta=0.0
% INFO    : Bus 4092	: V=1.02292513, theta=-26.8830981 -> V=1.0158755, theta=0.0
% INFO    : Bus 4093	: V=1.01680285, theta=-21.2221552 -> V=1.015872, theta=0.0
% INFO    : Bus 4094	: V=1.04777066, theta=-15.8030635 -> V=1.046665, theta=0.0
% INFO    : Bus 4095	: V=1.05003859, theta=-15.4012954 -> V=0.9888895, theta=0.0
% INFO    : Bus 4096	: V=1.05025555, theta=-15.3800795 -> V=0.9888895, theta=0.0
% INFO    : Bus 4097	: V=1.06817559, theta=-15.7761031 -> V=1.0377785, theta=0.0
% INFO    : Bus 4098	: V=1.07198292, theta=-13.4254815 -> V=1.072365, theta=0.0
% INFO    : Bus 4099	: V=1.01046384, theta=-25.7814835 -> V=1.0000005, theta=0.0
% INFO    : Bus 4100	: V=1.04168101, theta=-20.5893091 -> V=1.022224, theta=0.0
% INFO    : Bus 4101	: V=1.04106941, theta=-29.2980417 -> V=1.027779, theta=0.0
% INFO    : Bus 4102	: V=1.05135194, theta=-8.30168666 -> V=0.999999, theta=0.0
% INFO    : Bus 4103	: V=1.06744038, theta=-7.29460051 -> V=1.0111115, theta=0.0
% INFO    : Bus 4104	: V=1.01037278, theta=-12.0539328 -> V=0.999999, theta=0.0
% INFO    : Bus 4105	: V=1.03880354, theta=-36.9873755 -> V=1.022224, theta=0.0
% INFO    : Bus 4106	: V=1.03862575, theta=-14.8239287 -> V=0.999999, theta=0.0
% INFO    : Bus 4107	: V=1.04250477, theta=-41.9220096 -> V=1.022224, theta=0.0
% INFO    : Bus 4108	: V=1.04920956, theta=-20.5878723 -> V=1.0000025, theta=0.0
% INFO    : Bus 4109	: V=1.04921444, theta=-20.5873841 -> V=1.0000025, theta=0.0
% INFO    : Bus 4110	: V=1.03959532, theta=-20.7438729 -> V=1.000001, theta=0.0
% INFO    : Bus 4111	: V=1.05004259, theta=-16.9637567 -> V=1.0111115, theta=0.0
% INFO    : Bus 4112	: V=1.05662749, theta=-10.8902909 -> V=1.000001, theta=0.0
% INFO    : Bus 4113	: V=1.06492435, theta=-7.56548275 -> V=1.016666, theta=0.0
% INFO    : Bus 4114	: V=1.06271431, theta=-2.69426334 -> V=1.05263, theta=0.0
% INFO    : Bus 4115	: V=1.0401627, theta=-44.4079681 -> V=1.0079355, theta=0.0
% INFO    : Bus 4116	: V=1.02559934, theta=-23.2254774 -> V=1.0000025, theta=0.0
% INFO    : Bus 4117	: V=1.01131512, theta=-47.308968 -> V=1.0079355, theta=0.0
% INFO    : Bus 4118	: V=1.06754979, theta=-26.5392175 -> V=1.046665, theta=0.0
% INFO    : Bus 4119	: V=1.02672408, theta=-29.0261608 -> V=1.015872, theta=0.0
% INFO    : Bus 4120	: V=1.0486281, theta=-30.3967138 -> V=1.0000025, theta=0.0
% INFO    : Bus 4121	: V=1.035, theta=-10.6653262 -> V=0.999999, theta=0.0
% INFO    : Bus 4122	: V=1.02520574, theta=-12.5045802 -> V=1.0111115, theta=0.0
% INFO    : Bus 4123	: V=0.989157646, theta=-31.6992606 -> V=1.015872, theta=0.0
% INFO    : Bus 4124	: V=1.03725352, theta=-11.4674857 -> V=0.999999, theta=0.0
% INFO    : Bus 4125	: V=1.08670487, theta=-2.83978307 -> V=1.0377785, theta=0.0
% INFO    : Bus 4126	: V=1.10065199, theta=0.590942141 -> V=1.072365, theta=0.0
% INFO    : Bus 4127	: V=1.10145458, theta=0.618868989 -> V=1.072365, theta=0.0
% INFO    : Bus 4128	: V=1.00754336, theta=-31.0397921 -> V=1.015872, theta=0.0
% INFO    : Bus 4129	: V=1.05701924, theta=-6.85919909 -> V=1.0111115, theta=0.0
% INFO    : Bus 4130	: V=1.0298147, theta=-21.8770112 -> V=1.015874, theta=0.0
% INFO    : Bus 4131	: V=1.05577764, theta=-18.2417108 -> V=1.0000025, theta=0.0
% INFO    : Bus 4132	: V=1.04660161, theta=-38.9248099 -> V=1.022224, theta=0.0
% INFO    : Bus 4133	: V=1.06869229, theta=-41.9201863 -> V=1.026624, theta=0.0
% INFO    : Bus 4134	: V=1.07607757, theta=-37.5997114 -> V=1.04444, theta=0.0
% INFO    : Bus 4135	: V=1.03139473, theta=-12.67083 -> V=1.015872, theta=0.0
% INFO    : Bus 4136	: V=1.05675234, theta=-10.4166888 -> V=1.046665, theta=0.0
% INFO    : Bus 4137	: V=1.01150704, theta=-23.3421303 -> V=1.022224, theta=0.0
% INFO    : Bus 4138	: V=1.04017937, theta=-22.5905547 -> V=1.0000025, theta=0.0
% INFO    : Bus 4139	: V=1.05391741, theta=-12.5512937 -> V=1.004824, theta=0.0
% INFO    : Bus 4140	: V=1.04805949, theta=-13.0093315 -> V=1.001709, theta=0.0
% INFO    : Bus 4141	: V=1.04377783, theta=-9.14506375 -> V=1.0111115, theta=0.0
% INFO    : Bus 4142	: V=1.0303761, theta=-14.8252176 -> V=1.044445, theta=0.0
% INFO    : Bus 4143	: V=1.03051194, theta=-14.8077792 -> V=1.044445, theta=0.0
% INFO    : Bus 4144	: V=1.0371524, theta=-20.6973645 -> V=1.015874, theta=0.0
% INFO    : Bus 4145	: V=1.02776297, theta=-27.0938497 -> V=1.015872, theta=0.0
% INFO    : Bus 4146	: V=1.03203609, theta=-25.8625641 -> V=1.0000025, theta=0.0
% INFO    : Bus 4147	: V=1.04387476, theta=-3.02723359 -> V=1.0000025, theta=0.0
% INFO    : Bus 4148	: V=1.01994339, theta=-21.5489258 -> V=1.015872, theta=0.0
% INFO    : Bus 4149	: V=1.06400908, theta=-24.7553736 -> V=1.046665, theta=0.0
% INFO    : Bus 4150	: V=1.05728843, theta=-22.587779 -> V=1.027779, theta=0.0
% INFO    : Bus 4151	: V=1.05536684, theta=-23.6512106 -> V=1.027779, theta=0.0
% INFO    : Bus 4152	: V=1.0144341, theta=-16.2551507 -> V=1.015872, theta=0.0
% INFO    : Bus 4153	: V=1.03399401, theta=-30.5382186 -> V=1.022224, theta=0.0
% INFO    : Bus 4154	: V=1.03977823, theta=-42.2074645 -> V=1.022224, theta=0.0
% INFO    : Bus 4155	: V=1.02622772, theta=-19.7935791 -> V=1.0158755, theta=0.0
% INFO    : Bus 4156	: V=1.06842244, theta=-21.1114206 -> V=1.033333, theta=0.0
% INFO    : Bus 4157	: V=1.05174829, theta=-16.0929224 -> V=1.0288895, theta=0.0
% INFO    : Bus 4158	: V=1.01374289, theta=-28.4074946 -> V=1.015872, theta=0.0
% INFO    : Bus 4159	: V=1.07032946, theta=-20.2402988 -> V=1.0000025, theta=0.0
% INFO    : Bus 4160	: V=1.0504618, theta=-23.3928975 -> V=1.0000025, theta=0.0
% INFO    : Bus 4161	: V=1.054, theta=-21.098145 -> V=1.0000025, theta=0.0
% INFO    : Bus 4162	: V=1.03800659, theta=-45.4325182 -> V=1.022224, theta=0.0
% INFO    : Bus 4163	: V=1.07406173, theta=-40.6046336 -> V=1.04444, theta=0.0
% INFO    : Bus 4164	: V=1.05356468, theta=-18.475172 -> V=1.0000025, theta=0.0
% INFO    : Bus 4165	: V=1.0931429, theta=-18.4631273 -> V=1.0, theta=0.0
% INFO    : Bus 4166	: V=1.03251186, theta=-26.4351697 -> V=1.022224, theta=0.0
% INFO    : Bus 4167	: V=1.04981419, theta=-39.875212 -> V=1.022224, theta=0.0
% INFO    : Bus 4168	: V=1.03758527, theta=-25.9685357 -> V=1.0000025, theta=0.0
% INFO    : Bus 4169	: V=1.03927515, theta=-21.3253854 -> V=1.000001, theta=0.0
% INFO    : Bus 4170	: V=1.05272175, theta=-30.5885909 -> V=1.022224, theta=0.0
% INFO    : Bus 4171	: V=1.04193601, theta=-33.6914095 -> V=1.022224, theta=0.0
% INFO    : Bus 4172	: V=1.05162489, theta=-1.33237534 -> V=1.0377785, theta=0.0
% INFO    : Bus 4173	: V=1.03369093, theta=-53.3172178 -> V=1.0079355, theta=0.0
% INFO    : Bus 4174	: V=1.06755718, theta=-47.2353834 -> V=1.04444, theta=0.0
% INFO    : Bus 4175	: V=1.01414517, theta=-51.2637607 -> V=1.0079355, theta=0.0
% INFO    : Bus 4176	: V=1.02552315, theta=1.80227851 -> V=1.0158735, theta=0.0
% INFO    : Bus 4177	: V=1.0368721, theta=-12.0198473 -> V=0.999999, theta=0.0
% INFO    : Bus 4178	: V=1.03696055, theta=-12.0214766 -> V=0.999999, theta=0.0
% INFO    : Bus 4179	: V=1.07780103, theta=0.814330218 -> V=1.072365, theta=0.0
% INFO    : Bus 4180	: V=1.07779014, theta=0.815667832 -> V=1.072365, theta=0.0
% INFO    : Bus 4181	: V=1.02115465, theta=-29.0708696 -> V=1.0000025, theta=0.0
% INFO    : Bus 4182	: V=1.03166361, theta=-26.0882231 -> V=1.0000025, theta=0.0
% INFO    : Bus 4183	: V=1.02724216, theta=-19.2542359 -> V=1.0000025, theta=0.0
% INFO    : Bus 4184	: V=1.00599731, theta=-18.4374309 -> V=1.0158755, theta=0.0
% INFO    : Bus 4185	: V=1.0061988, theta=-18.3991565 -> V=1.0158755, theta=0.0
% INFO    : Bus 4186	: V=1.02321287, theta=-22.185762 -> V=1.022224, theta=0.0
% INFO    : Bus 4187	: V=1.05031206, theta=-7.08035773 -> V=1.0111115, theta=0.0
% INFO    : Bus 4188	: V=1.05469091, theta=-9.2498815 -> V=1.0111115, theta=0.0
% INFO    : Bus 4189	: V=1.01908657, theta=-28.3561343 -> V=1.0000025, theta=0.0
% INFO    : Bus 4190	: V=1.04333865, theta=-27.7023044 -> V=1.022224, theta=0.0
% INFO    : Bus 4191	: V=1.040739, theta=-34.3517361 -> V=1.022224, theta=0.0
% INFO    : Bus 4192	: V=1.05526143, theta=-21.1194689 -> V=1.022224, theta=0.0
% INFO    : Bus 4193	: V=1.05459524, theta=-21.1641585 -> V=1.022224, theta=0.0
% INFO    : Bus 4194	: V=1.04504123, theta=-15.7896889 -> V=0.999999, theta=0.0
% INFO    : Bus 4195	: V=1.04504123, theta=-15.7896889 -> V=0.999999, theta=0.0
% INFO    : Bus 4196	: V=1.04520964, theta=-15.7654163 -> V=0.999999, theta=0.0
% INFO    : Bus 4197	: V=1.04397783, theta=-20.0597819 -> V=1.0158755, theta=0.0
% INFO    : Bus 4198	: V=1.00447558, theta=-18.4607332 -> V=0.999999, theta=0.0
% INFO    : Bus 4199	: V=1.01005631, theta=-30.1715769 -> V=1.0000005, theta=0.0
% INFO    : Bus 4200	: V=1.06384567, theta=-24.5840573 -> V=1.046665, theta=0.0
% INFO    : Bus 4201	: V=1.05455249, theta=-28.7032264 -> V=1.046665, theta=0.0
% INFO    : Bus 4202	: V=1.04235124, theta=-14.345026 -> V=1.015872, theta=0.0
% INFO    : Bus 4203	: V=1.05263543, theta=-12.2304588 -> V=1.046665, theta=0.0
% INFO    : Bus 4204	: V=1.05040826, theta=-52.5452306 -> V=1.0079355, theta=0.0
% INFO    : Bus 4205	: V=1.04804663, theta=-30.0338523 -> V=1.022224, theta=0.0
% INFO    : Bus 4206	: V=1.04782182, theta=-29.8798077 -> V=1.022224, theta=0.0
% INFO    : Bus 4207	: V=1.03155379, theta=-12.6340802 -> V=0.999999, theta=0.0
% INFO    : Bus 4208	: V=1.03253816, theta=3.25799739 -> V=1.0158755, theta=0.0
% INFO    : Bus 4209	: V=1.03561026, theta=2.59141311 -> V=1.0158755, theta=0.0
% INFO    : Bus 4210	: V=1.08365288, theta=6.31872531 -> V=1.0389135, theta=0.0
% INFO    : Bus 4211	: V=1.09787044, theta=10.8881309 -> V=1.07265, theta=0.0
% INFO    : Bus 4212	: V=0.93918112, theta=-7.04259547 -> V=0.9444445, theta=0.0
% INFO    : Bus 4213	: V=1.06723269, theta=-29.8992066 -> V=0.975, theta=0.0
% INFO    : Bus 4214	: V=1.04181602, theta=-34.1612764 -> V=1.022224, theta=0.0
% INFO    : Bus 4215	: V=1.04251882, theta=-34.0861795 -> V=1.022224, theta=0.0
% INFO    : Bus 4216	: V=1.06730668, theta=-29.8859204 -> V=1.04444, theta=0.0
% INFO    : Bus 4217	: V=1.05199987, theta=-29.1290003 -> V=1.027779, theta=0.0
% INFO    : Bus 4218	: V=1.05080049, theta=-28.9528327 -> V=1.027779, theta=0.0
% INFO    : Bus 4219	: V=1.05937901, theta=-25.6851172 -> V=1.046665, theta=0.0
% INFO    : Bus 4220	: V=1.02134176, theta=-18.5400844 -> V=1.0158755, theta=0.0
% INFO    : Bus 4221	: V=1.01200683, theta=-19.8948813 -> V=1.0158755, theta=0.0
% INFO    : Bus 4222	: V=1.03478421, theta=-14.8598617 -> V=0.999999, theta=0.0
% INFO    : Bus 4223	: V=1.039, theta=-13.2943826 -> V=0.999999, theta=0.0
% INFO    : Bus 4224	: V=1.01780784, theta=-8.31022148 -> V=1.0158755, theta=0.0
% INFO    : Bus 4225	: V=1.02310728, theta=-13.4573802 -> V=0.999999, theta=0.0
% INFO    : Bus 4226	: V=1.01479345, theta=-17.7781506 -> V=0.999999, theta=0.0
% INFO    : Bus 4227	: V=1.03497631, theta=-44.5051482 -> V=1.022224, theta=0.0
% INFO    : Bus 4228	: V=1.04849946, theta=-15.6953254 -> V=1.0000025, theta=0.0
% INFO    : Bus 4229	: V=1.03149745, theta=-12.6074078 -> V=0.9888895, theta=0.0
% INFO    : Bus 4230	: V=1.03144711, theta=-12.6414313 -> V=0.9888895, theta=0.0
% INFO    : Bus 4231	: V=1.04221744, theta=-36.4524159 -> V=1.022224, theta=0.0
% INFO    : Bus 4232	: V=1.04937673, theta=-34.1921339 -> V=1.022224, theta=0.0
% INFO    : Bus 4233	: V=1.02776325, theta=-46.0427942 -> V=1.0079355, theta=0.0
% INFO    : Bus 4234	: V=1.0485366, theta=-33.5411472 -> V=1.022224, theta=0.0
% INFO    : Bus 4235	: V=1.08313809, theta=-30.3759771 -> V=1.04777, theta=0.0
% INFO    : Bus 4236	: V=1.064, theta=-16.222023 -> V=1.000001, theta=0.0
% INFO    : Bus 4237	: V=0.976, theta=-29.443054 -> V=1.015872, theta=0.0
% INFO    : Bus 4238	: V=1.04591091, theta=-27.0056523 -> V=1.0000025, theta=0.0
% INFO    : Bus 4239	: V=0.997823008, theta=-21.1148829 -> V=1.015872, theta=0.0
% INFO    : Bus 4240	: V=1.00002088, theta=-14.4960367 -> V=1.015872, theta=0.0
% INFO    : Bus 4241	: V=1.0553744, theta=-18.375009 -> V=1.0000025, theta=0.0
% INFO    : Bus 4242	: V=1.03515466, theta=-18.5588258 -> V=1.015872, theta=0.0
% INFO    : Bus 4243	: V=1.04367359, theta=-13.1688667 -> V=1.046665, theta=0.0
% INFO    : Bus 4244	: V=1.02386284, theta=-2.68068691 -> V=1.0158755, theta=0.0
% INFO    : Bus 4245	: V=1.04013551, theta=-17.7143217 -> V=1.015872, theta=0.0
% INFO    : Bus 4246	: V=1.04747659, theta=-14.6969358 -> V=1.046665, theta=0.0
% INFO    : Bus 4247	: V=1.03314326, theta=-21.0033256 -> V=1.0000025, theta=0.0
% INFO    : Bus 4248	: V=1.04472477, theta=-15.4552271 -> V=1.044445, theta=0.0
% INFO    : Bus 4249	: V=1.0281358, theta=-14.3479802 -> V=0.999999, theta=0.0
% INFO    : Bus 4250	: V=1.0151551, theta=-13.7985133 -> V=0.999999, theta=0.0
% INFO    : Bus 4251	: V=1.01950677, theta=-9.55631307 -> V=1.015872, theta=0.0
% INFO    : Bus 4252	: V=1.02378295, theta=-55.6699186 -> V=1.0079355, theta=0.0
% INFO    : Bus 4253	: V=1.04449375, theta=-30.5638675 -> V=1.022224, theta=0.0
% INFO    : Bus 4254	: V=1.05592817, theta=-5.92763231 -> V=1.0111115, theta=0.0
% INFO    : Bus 4255	: V=1.02644265, theta=-6.72244479 -> V=0.999999, theta=0.0
% INFO    : Bus 4256	: V=1.03274379, theta=-6.8499221 -> V=0.999999, theta=0.0
% INFO    : Bus 4257	: V=1.04093789, theta=-30.4314234 -> V=1.027779, theta=0.0
% INFO    : Bus 4258	: V=1.03882956, theta=-14.687308 -> V=0.999999, theta=0.0
% INFO    : Bus 4259	: V=1.0303936, theta=-39.7172225 -> V=1.022224, theta=0.0
% INFO    : Bus 4260	: V=0.986337406, theta=-23.1769978 -> V=1.015872, theta=0.0
% INFO    : Bus 4261	: V=1.04960028, theta=-16.1657439 -> V=1.033334, theta=0.0
% INFO    : Bus 4262	: V=0.999983176, theta=-20.9778025 -> V=1.015872, theta=0.0
% INFO    : Bus 4263	: V=1.02274665, theta=-22.2091253 -> V=1.0000025, theta=0.0
% INFO    : Bus 4264	: V=0.951654177, theta=-40.0621825 -> V=1.0000025, theta=0.0
% INFO    : Bus 4265	: V=1.01169897, theta=-30.6438812 -> V=1.015872, theta=0.0
% INFO    : Bus 4266	: V=1.05091307, theta=-24.9955574 -> V=0.975, theta=0.0
% INFO    : Bus 4267	: V=1.053, theta=-26.8629669 -> V=1.020497, theta=0.0
% INFO    : Bus 4268	: V=1.04570532, theta=-25.8699675 -> V=1.0233335, theta=0.0
% INFO    : Bus 4269	: V=1.04437957, theta=-24.336334 -> V=1.0000025, theta=0.0
% INFO    : Bus 4270	: V=0.995696523, theta=-30.8250476 -> V=1.015872, theta=0.0
% INFO    : Bus 4271	: V=0.995028648, theta=-30.9061078 -> V=1.015872, theta=0.0
% INFO    : Bus 4272	: V=1.01865938, theta=-6.71816542 -> V=0.999999, theta=0.0
% INFO    : Bus 4273	: V=1.03097151, theta=-6.8796648 -> V=1.0158755, theta=0.0
% INFO    : Bus 4274	: V=1.02108983, theta=-9.90530169 -> V=1.0158755, theta=0.0
% INFO    : Bus 4275	: V=1.03175269, theta=-19.0083067 -> V=1.022224, theta=0.0
% INFO    : Bus 4276	: V=1.07493847, theta=-18.0639455 -> V=1.04481, theta=0.0
% INFO    : Bus 4277	: V=1.08289161, theta=-14.5804067 -> V=1.07237, theta=0.0
% INFO    : Bus 4278	: V=1.08288766, theta=-14.5845505 -> V=1.07237, theta=0.0
% INFO    : Bus 4279	: V=1.02177092, theta=-11.5690653 -> V=0.999999, theta=0.0
% INFO    : Bus 4280	: V=1.05356399, theta=-24.5610315 -> V=1.027779, theta=0.0
% INFO    : Bus 4281	: V=1.02985416, theta=-15.5131373 -> V=1.0158755, theta=0.0
% INFO    : Bus 4282	: V=1.11199128, theta=-11.9080295 -> V=1.0392755, theta=0.0
% INFO    : Bus 4283	: V=1.07418326, theta=-11.9080295 -> V=1.0377785, theta=0.0
% INFO    : Bus 4284	: V=1.07805866, theta=-8.15834055 -> V=1.072365, theta=0.0
% INFO    : Bus 4285	: V=1.00587788, theta=-19.0660622 -> V=1.015872, theta=0.0
% INFO    : Bus 4286	: V=1.04662644, theta=-13.4473472 -> V=1.046665, theta=0.0
% INFO    : Bus 4287	: V=1.02266646, theta=-22.8057392 -> V=1.0000025, theta=0.0
% INFO    : Bus 4288	: V=1.03084182, theta=-32.4296466 -> V=1.027779, theta=0.0
% INFO    : Bus 4289	: V=1.03058716, theta=-31.2586725 -> V=1.027779, theta=0.0
% INFO    : Bus 4290	: V=1.03025351, theta=-31.2472444 -> V=1.027779, theta=0.0
% INFO    : Bus 4291	: V=1.022, theta=-11.5020235 -> V=0.999999, theta=0.0
% INFO    : Bus 4292	: V=1.04450851, theta=-11.9154528 -> V=0.999999, theta=0.0
% INFO    : Bus 4293	: V=1.05016484, theta=-26.0968706 -> V=1.0000025, theta=0.0
% INFO    : Bus 4294	: V=1.04663421, theta=-15.9010778 -> V=1.0158755, theta=0.0
% INFO    : Bus 4295	: V=1.07498503, theta=-18.6436236 -> V=1.000001, theta=0.0
% INFO    : Bus 4296	: V=1.08949526, theta=-15.0187847 -> V=1.046725, theta=0.0
% INFO    : Bus 4297	: V=1.03035267, theta=-52.1641712 -> V=1.0079355, theta=0.0
% INFO    : Bus 4298	: V=1.00429402, theta=-20.9317136 -> V=1.0158755, theta=0.0
% INFO    : Bus 4299	: V=1.00485451, theta=-20.9522852 -> V=1.0158755, theta=0.0
% INFO    : Bus 4300	: V=1.06608045, theta=-16.5076361 -> V=1.005964, theta=0.0
% INFO    : Bus 4301	: V=1.06343003, theta=-16.6414649 -> V=1.004889, theta=0.0
% INFO    : Bus 4302	: V=1.04738412, theta=-26.5372589 -> V=1.022224, theta=0.0
% INFO    : Bus 4303	: V=1.07470097, theta=-21.1525863 -> V=1.04444, theta=0.0
% INFO    : Bus 4304	: V=1.07433068, theta=-21.4240677 -> V=1.04444, theta=0.0
% INFO    : Bus 4305	: V=1.05496671, theta=-24.2904644 -> V=1.027779, theta=0.0
% INFO    : Bus 4306	: V=1.02459049, theta=-32.860407 -> V=1.0000025, theta=0.0
% INFO    : Bus 4307	: V=1.05, theta=-10.0365959 -> V=1.003079, theta=0.0
% INFO    : Bus 4308	: V=1.0363455, theta=-14.5478002 -> V=0.999999, theta=0.0
% INFO    : Bus 4309	: V=1.02629202, theta=-34.5167693 -> V=1.022224, theta=0.0
% INFO    : Bus 4310	: V=1.01059926, theta=-13.4005067 -> V=0.999999, theta=0.0
% INFO    : Bus 4311	: V=1.063, theta=-13.9812047 -> V=1.000001, theta=0.0
% INFO    : Bus 4312	: V=1.04735298, theta=-26.3849632 -> V=1.0000025, theta=0.0
% INFO    : Bus 4313	: V=1.0367212, theta=-46.1538911 -> V=1.022224, theta=0.0
% INFO    : Bus 4314	: V=1.03517459, theta=-51.6415496 -> V=1.0079355, theta=0.0
% INFO    : Bus 4315	: V=1.01003716, theta=-8.96672108 -> V=0.999999, theta=0.0
% INFO    : Bus 4316	: V=1.05628338, theta=-6.49317972 -> V=1.0111115, theta=0.0
% INFO    : Bus 4317	: V=1.04011787, theta=-28.4785335 -> V=1.0000025, theta=0.0
% INFO    : Bus 4318	: V=1.0447464, theta=-51.2133061 -> V=1.0079355, theta=0.0
% INFO    : Bus 4319	: V=1.02, theta=-10.5533633 -> V=0.999999, theta=0.0
% INFO    : Bus 4320	: V=1.02403455, theta=-20.7645632 -> V=1.0158755, theta=0.0
% INFO    : Bus 4321	: V=1.02079303, theta=-0.54102995 -> V=1.0158755, theta=0.0
% INFO    : Bus 4322	: V=1.02291427, theta=2.04945747 -> V=1.0158755, theta=0.0
% INFO    : Bus 4323	: V=1.07573686, theta=3.73093124 -> V=1.0377785, theta=0.0
% INFO    : Bus 4324	: V=1.07593127, theta=3.91381009 -> V=1.0377785, theta=0.0
% INFO    : Bus 4325	: V=1.03853411, theta=-25.3060124 -> V=1.0000025, theta=0.0
% INFO    : Bus 4326	: V=1.03586995, theta=-33.4228184 -> V=1.0000025, theta=0.0
% INFO    : Bus 4327	: V=1.03842206, theta=-18.5574238 -> V=0.999999, theta=0.0
% INFO    : Bus 4328	: V=1.02932092, theta=-35.1557602 -> V=1.022224, theta=0.0
% INFO    : Bus 4329	: V=1.0351241, theta=-21.3053666 -> V=1.0000025, theta=0.0
% INFO    : Bus 4330	: V=0.95257656, theta=-6.51858077 -> V=0.9444445, theta=0.0
% INFO    : Bus 4331	: V=1.06266314, theta=-37.1066539 -> V=0.975, theta=0.0
% INFO    : Bus 4332	: V=1.06266314, theta=-37.1066539 -> V=0.975, theta=0.0
% INFO    : Bus 4333	: V=1.06269014, theta=-37.1093588 -> V=0.975, theta=0.0
% INFO    : Bus 4334	: V=1.03427961, theta=-41.8139069 -> V=1.0079355, theta=0.0
% INFO    : Bus 4335	: V=1.0626967, theta=-37.0970249 -> V=1.04444, theta=0.0
% INFO    : Bus 4336	: V=1.03731964, theta=-19.2061164 -> V=1.022224, theta=0.0
% INFO    : Bus 4337	: V=1.045, theta=-28.3351152 -> V=1.0000025, theta=0.0
% INFO    : Bus 4338	: V=1.03546941, theta=0.926729229 -> V=1.0158755, theta=0.0
% INFO    : Bus 4339	: V=1.07991247, theta=4.87429086 -> V=1.0377785, theta=0.0
% INFO    : Bus 4340	: V=1.04775094, theta=-18.9762984 -> V=1.000001, theta=0.0
% INFO    : Bus 4341	: V=1.0241816, theta=-16.6116278 -> V=0.999999, theta=0.0
% INFO    : Bus 4342	: V=1.04591919, theta=-10.6473327 -> V=0.999999, theta=0.0
% INFO    : Bus 4343	: V=1.0461546, theta=-10.6548649 -> V=0.999999, theta=0.0
% INFO    : Bus 4344	: V=1.02396484, theta=-20.6031217 -> V=1.0000025, theta=0.0
% INFO    : Bus 4345	: V=1.0780808, theta=-35.594268 -> V=0.975, theta=0.0
% INFO    : Bus 4346	: V=1.03944802, theta=-36.8617173 -> V=1.022224, theta=0.0
% INFO    : Bus 4347	: V=1.07819424, theta=-35.5688106 -> V=1.045515, theta=0.0
% INFO    : Bus 4348	: V=1.01574538, theta=-55.031851 -> V=1.0079355, theta=0.0
% INFO    : Bus 4349	: V=1.03481587, theta=-26.9738558 -> V=1.0000025, theta=0.0
% INFO    : Bus 4350	: V=1.01679847, theta=-20.9295458 -> V=1.0000025, theta=0.0
% INFO    : Bus 4351	: V=1.00376871, theta=-24.4299494 -> V=1.0000025, theta=0.0
% INFO    : Bus 4352	: V=0.989232968, theta=-36.573082 -> V=1.015872, theta=0.0
% INFO    : Bus 4353	: V=0.98524572, theta=-34.2564279 -> V=1.015872, theta=0.0
% INFO    : Bus 4354	: V=1.02046652, theta=-27.407122 -> V=1.0000025, theta=0.0
% INFO    : Bus 4355	: V=1.0212763, theta=-30.561706 -> V=1.022224, theta=0.0
% INFO    : Bus 4356	: V=1.03671234, theta=-45.0890544 -> V=1.0079355, theta=0.0
% INFO    : Bus 4357	: V=1.01491935, theta=-25.1662636 -> V=1.0000005, theta=0.0
% INFO    : Bus 4358	: V=1.01320173, theta=-25.4664888 -> V=1.0000005, theta=0.0
% INFO    : Bus 4359	: V=1.02233529, theta=-28.3003969 -> V=1.0000005, theta=0.0
% INFO    : Bus 4360	: V=1.0586824, theta=-30.1650959 -> V=1.0000025, theta=0.0
% INFO    : Bus 4361	: V=1.00301897, theta=-12.7259703 -> V=0.999999, theta=0.0
% INFO    : Bus 4362	: V=1.05361366, theta=-19.7300505 -> V=1.022224, theta=0.0
% INFO    : Bus 4363	: V=1.055, theta=-21.4180259 -> V=1.000001, theta=0.0
% INFO    : Bus 4364	: V=1.05006459, theta=-23.5753422 -> V=1.0000025, theta=0.0
% INFO    : Bus 4365	: V=1.01142919, theta=-11.6880695 -> V=1.0000025, theta=0.0
% INFO    : Bus 4366	: V=1.03181774, theta=-6.64413037 -> V=1.0158755, theta=0.0
% INFO    : Bus 4367	: V=1.02513101, theta=-19.1031242 -> V=0.999999, theta=0.0
% INFO    : Bus 4368	: V=0.987227439, theta=-2.9077014 -> V=1.0158755, theta=0.0
% INFO    : Bus 4369	: V=1.01180876, theta=-9.31177692 -> V=1.0158755, theta=0.0
% INFO    : Bus 4370	: V=0.978674388, theta=-4.94957903 -> V=0.9444445, theta=0.0
% INFO    : Bus 4371	: V=1.04795386, theta=-39.6950025 -> V=1.022224, theta=0.0
% INFO    : Bus 4372	: V=1.02225316, theta=-16.6253982 -> V=1.0158755, theta=0.0
% INFO    : Bus 4373	: V=1.03595162, theta=-46.2495202 -> V=1.022224, theta=0.0
% INFO    : Bus 4374	: V=1.03747207, theta=-14.0277143 -> V=0.999999, theta=0.0
% INFO    : Bus 4375	: V=1.02469267, theta=-30.1579453 -> V=1.022224, theta=0.0
% INFO    : Bus 4376	: V=1.02376936, theta=-13.0413671 -> V=1.015872, theta=0.0
% INFO    : Bus 4377	: V=1.06376241, theta=-24.7971893 -> V=1.046665, theta=0.0
% INFO    : Bus 4378	: V=1.06689044, theta=-26.7184038 -> V=1.046665, theta=0.0
% INFO    : Bus 4379	: V=1.00143612, theta=-12.4059674 -> V=1.015872, theta=0.0
% INFO    : Bus 4380	: V=1.04017265, theta=-6.35611199 -> V=1.0158755, theta=0.0
% INFO    : Bus 4381	: V=1.06910371, theta=-3.41267181 -> V=1.0377785, theta=0.0
% INFO    : Bus 4382	: V=1.07908923, theta=-34.6149007 -> V=0.975, theta=0.0
% INFO    : Bus 4383	: V=1.03461671, theta=-38.8703209 -> V=1.0079355, theta=0.0
% INFO    : Bus 4384	: V=1.07916834, theta=-34.5902728 -> V=1.04444, theta=0.0
% INFO    : Bus 4385	: V=1.02989287, theta=-56.5001985 -> V=1.0079355, theta=0.0
% INFO    : Bus 4386	: V=1.05667675, theta=-21.312326 -> V=1.000001, theta=0.0
% INFO    : Bus 4387	: V=1.0720351, theta=-17.5105411 -> V=1.022222, theta=0.0
% INFO    : Bus 4388	: V=1.07072244, theta=-17.659735 -> V=1.022222, theta=0.0
% INFO    : Bus 4389	: V=1.04031687, theta=-24.8858956 -> V=1.0000025, theta=0.0
% INFO    : Bus 4390	: V=1.06894842, theta=-21.25659 -> V=1.044445, theta=0.0
% INFO    : Bus 4391	: V=1.04894599, theta=-25.9106697 -> V=1.046665, theta=0.0
% INFO    : Bus 4392	: V=1.03656336, theta=-17.4688298 -> V=0.999999, theta=0.0
% INFO    : Bus 4393	: V=1.0105108, theta=-45.2629361 -> V=1.0079355, theta=0.0
% INFO    : Bus 4394	: V=1.03519716, theta=-24.1173933 -> V=1.0000025, theta=0.0
% INFO    : Bus 4395	: V=1.0214008, theta=-51.9705971 -> V=1.0079355, theta=0.0
% INFO    : Bus 4396	: V=1.03568796, theta=-6.3394023 -> V=1.0158755, theta=0.0
% INFO    : Bus 4397	: V=1.09192722, theta=-13.0627605 -> V=1.046335, theta=0.0
% INFO    : Bus 4398	: V=1.04992639, theta=-22.9762419 -> V=1.000001, theta=0.0
% INFO    : Bus 4399	: V=1.01976967, theta=-12.7442357 -> V=0.999999, theta=0.0
% INFO    : Bus 4400	: V=1.02159855, theta=-17.8260102 -> V=0.999999, theta=0.0
% INFO    : Bus 4401	: V=1.02977442, theta=-15.6706033 -> V=1.015872, theta=0.0
% INFO    : Bus 4402	: V=1.03037483, theta=-19.24618 -> V=1.022224, theta=0.0
% INFO    : Bus 4403	: V=1.04426133, theta=-9.35591262 -> V=1.000054, theta=0.0
% INFO    : Bus 4404	: V=0.979171037, theta=-36.7042692 -> V=1.015872, theta=0.0
% INFO    : Bus 4405	: V=1.02373921, theta=-51.8623431 -> V=1.0079355, theta=0.0
% INFO    : Bus 4406	: V=0.977346861, theta=-48.6141232 -> V=1.0079355, theta=0.0
% INFO    : Bus 4407	: V=1.02924564, theta=-31.3370558 -> V=1.015872, theta=0.0
% INFO    : Bus 4408	: V=1.0536216, theta=-31.0676914 -> V=1.027779, theta=0.0
% INFO    : Bus 4409	: V=1.02678099, theta=-22.4937111 -> V=0.999999, theta=0.0
% INFO    : Bus 4410	: V=1.05251211, theta=-14.6865608 -> V=0.9888895, theta=0.0
% INFO    : Bus 4411	: V=1.05271283, theta=-14.6831825 -> V=0.9888895, theta=0.0
% INFO    : Bus 4412	: V=1.05299815, theta=-25.2644725 -> V=1.027779, theta=0.0
% INFO    : Bus 4413	: V=1.05287982, theta=-25.2616407 -> V=1.027779, theta=0.0
% INFO    : Bus 4414	: V=1.07412624, theta=-21.4392545 -> V=1.046665, theta=0.0
% INFO    : Bus 4415	: V=1.01347983, theta=-11.0345776 -> V=0.999999, theta=0.0
% INFO    : Bus 4416	: V=0.995883195, theta=-13.7098516 -> V=1.015872, theta=0.0
% INFO    : Bus 4417	: V=1.03749379, theta=-18.2604677 -> V=0.999999, theta=0.0
% INFO    : Bus 4418	: V=1.01328595, theta=-24.4521885 -> V=0.999999, theta=0.0
% INFO    : Bus 4419	: V=1.02283474, theta=-34.4311702 -> V=1.022224, theta=0.0
% INFO    : Bus 4420	: V=1.03832346, theta=-44.391626 -> V=1.0079355, theta=0.0
% INFO    : Bus 4421	: V=1.00459648, theta=-28.1596106 -> V=1.0000005, theta=0.0
% INFO    : Bus 4422	: V=1.00381333, theta=-28.6469436 -> V=1.0000005, theta=0.0
% INFO    : Bus 4423	: V=1.037, theta=-24.4236093 -> V=1.0000025, theta=0.0
% INFO    : Bus 4424	: V=1.07634951, theta=-18.3304172 -> V=1.000001, theta=0.0
% INFO    : Bus 4425	: V=1.02681905, theta=-23.9344126 -> V=1.0000025, theta=0.0
% INFO    : Bus 4426	: V=1.05392376, theta=-15.9184493 -> V=1.003704, theta=0.0
% INFO    : Bus 4427	: V=1.01978353, theta=-16.5857042 -> V=0.999999, theta=0.0
% INFO    : Bus 4428	: V=1.02184716, theta=-50.1789058 -> V=1.0079355, theta=0.0
% INFO    : Bus 4429	: V=1.05695194, theta=-25.1042631 -> V=1.0000025, theta=0.0
% INFO    : Bus 4430	: V=1.02643571, theta=-25.0220001 -> V=1.0158755, theta=0.0
% INFO    : Bus 4431	: V=1.00817721, theta=-27.720897 -> V=1.0158755, theta=0.0
% INFO    : Bus 4432	: V=1.04188422, theta=-26.4027507 -> V=1.0000025, theta=0.0
% INFO    : Bus 4433	: V=0.988048408, theta=-36.2086039 -> V=1.015872, theta=0.0
% INFO    : Bus 4434	: V=1.00794132, theta=-17.2412778 -> V=1.015872, theta=0.0
% INFO    : Bus 4435	: V=1.0707139, theta=-17.6264499 -> V=1.0269185, theta=0.0
% INFO    : Bus 4436	: V=1.05033711, theta=-13.6803267 -> V=1.046665, theta=0.0
% INFO    : Bus 4437	: V=1.03844258, theta=-23.9813625 -> V=1.0000025, theta=0.0
% INFO    : Bus 4438	: V=1.02990222, theta=-20.5619373 -> V=1.0158755, theta=0.0
% INFO    : Bus 4439	: V=1.02836172, theta=-25.950789 -> V=1.022224, theta=0.0
% INFO    : Bus 4440	: V=1.00032428, theta=-21.2124375 -> V=1.0158755, theta=0.0
% INFO    : Bus 4441	: V=1.00919917, theta=-13.4665412 -> V=0.999999, theta=0.0
% INFO    : Bus 4442	: V=1.02226695, theta=-15.9566138 -> V=1.015872, theta=0.0
% INFO    : Bus 4443	: V=1.052, theta=-25.2047281 -> V=1.0233335, theta=0.0
% INFO    : Bus 4444	: V=1.00552905, theta=-25.3223403 -> V=1.0000025, theta=0.0
% INFO    : Bus 4445	: V=1.0246127, theta=-23.4788468 -> V=1.000001, theta=0.0
% INFO    : Bus 4446	: V=1.03670576, theta=-18.836788 -> V=0.999999, theta=0.0
% INFO    : Bus 4447	: V=1.05489691, theta=-18.306621 -> V=1.0000025, theta=0.0
% INFO    : Bus 4448	: V=1.0406736, theta=-25.3357552 -> V=1.0000025, theta=0.0
% INFO    : Bus 4449	: V=1.07979323, theta=-16.8524791 -> V=1.044445, theta=0.0
% INFO    : Bus 4450	: V=1.02780695, theta=-16.3148588 -> V=1.015872, theta=0.0
% INFO    : Bus 4451	: V=1.04304055, theta=-30.8065483 -> V=1.027779, theta=0.0
% INFO    : Bus 4452	: V=1.03051842, theta=-22.0384666 -> V=1.0000025, theta=0.0
% INFO    : Bus 4453	: V=1.06796394, theta=-18.1803314 -> V=1.044445, theta=0.0
% INFO    : Bus 4454	: V=1.0207067, theta=-18.6741864 -> V=1.0158755, theta=0.0
% INFO    : Bus 4455	: V=1.0422457, theta=-24.390424 -> V=1.0000025, theta=0.0
% INFO    : Bus 4456	: V=1.03439365, theta=-12.5409609 -> V=0.999999, theta=0.0
% INFO    : Bus 4457	: V=1.04892526, theta=-10.9557101 -> V=1.002974, theta=0.0
% INFO    : Bus 4458	: V=1.0503493, theta=-8.62117269 -> V=1.0111115, theta=0.0
% INFO    : Bus 4459	: V=1.07713514, theta=-1.49287195 -> V=1.072365, theta=0.0
% INFO    : Bus 4460	: V=1.07631475, theta=-1.56165239 -> V=1.072365, theta=0.0
% INFO    : Bus 4461	: V=1.04622298, theta=-23.3481429 -> V=1.027779, theta=0.0
% INFO    : Bus 4462	: V=1.02308488, theta=-18.6723015 -> V=0.999999, theta=0.0
% INFO    : Bus 4463	: V=1.01781013, theta=-24.7626515 -> V=1.000001, theta=0.0
% INFO    : Bus 4464	: V=1.0332687, theta=-24.6047032 -> V=1.027779, theta=0.0
% INFO    : Bus 4465	: V=1.03555449, theta=2.5519155 -> V=1.0158755, theta=0.0
% INFO    : Bus 4466	: V=1.03560641, theta=2.55590155 -> V=1.0158755, theta=0.0
% INFO    : Bus 4467	: V=1.04599078, theta=-2.44419254 -> V=1.0000025, theta=0.0
% INFO    : Bus 4468	: V=1.07684114, theta=0.964666037 -> V=1.0288895, theta=0.0
% INFO    : Bus 4469	: V=1.03151575, theta=-23.6621176 -> V=1.0000025, theta=0.0
% INFO    : Bus 4470	: V=1.025, theta=-2.33222478 -> V=0.975, theta=0.0
% INFO    : Bus 4471	: V=1.055, theta=0.0172822096 -> V=0.975, theta=0.0
% INFO    : Bus 4472	: V=1.055, theta=0.0771425517 -> V=0.975, theta=0.0
% INFO    : Bus 4473	: V=1.053, theta=0.0571623243 -> V=0.975, theta=0.0
% INFO    : Bus 4474	: V=1.058, theta=0.106958984 -> V=0.975, theta=0.0
% INFO    : Bus 4475	: V=1.01773674, theta=-6.57770592 -> V=1.0158755, theta=0.0
% INFO    : Bus 4476	: V=1.05391325, theta=-1.10516271 -> V=1.0377785, theta=0.0
% INFO    : Bus 4477	: V=1.05391287, theta=-1.1045518 -> V=1.0377785, theta=0.0
% INFO    : Bus 4478	: V=1.05389261, theta=-1.10479407 -> V=1.0377785, theta=0.0
% INFO    : Bus 4479	: V=1.05394325, theta=-1.10418853 -> V=1.0377785, theta=0.0
% INFO    : Bus 4480	: V=1.01769352, theta=-6.7283984 -> V=1.0158755, theta=0.0
% INFO    : Bus 4481	: V=1.01920399, theta=-6.83931922 -> V=1.0158755, theta=0.0
% INFO    : Bus 4482	: V=1.05390724, theta=-1.11674822 -> V=1.0377785, theta=0.0
% INFO    : Bus 4483	: V=1.02878912, theta=-11.8340944 -> V=0.984126, theta=0.0
% INFO    : Bus 4484	: V=1.07804838, theta=4.88527026 -> V=1.0377785, theta=0.0
% INFO    : Bus 4485	: V=0.998627478, theta=-29.3916187 -> V=1.0000005, theta=0.0
% INFO    : Bus 4486	: V=1.00297321, theta=-31.8345059 -> V=1.015872, theta=0.0
% INFO    : Bus 4487	: V=1.02697226, theta=-19.2960823 -> V=1.0158755, theta=0.0
% INFO    : Bus 4488	: V=1.03902184, theta=-34.2582164 -> V=1.022224, theta=0.0
% INFO    : Bus 4489	: V=0.972216218, theta=-19.6660204 -> V=1.015872, theta=0.0
% INFO    : Bus 4490	: V=0.973368958, theta=-19.4872716 -> V=1.015872, theta=0.0
% INFO    : Bus 4491	: V=1.03194558, theta=3.23781224 -> V=1.0158755, theta=0.0
% INFO    : Bus 4492	: V=1.03555432, theta=2.55191983 -> V=1.0158755, theta=0.0
% INFO    : Bus 4493	: V=1.08813659, theta=-10.7991263 -> V=1.035657, theta=0.0
% INFO    : Bus 4494	: V=1.08813659, theta=-10.7991263 -> V=1.035657, theta=0.0
% INFO    : Bus 4495	: V=1.05005225, theta=-10.7991263 -> V=1.0233335, theta=0.0
% INFO    : Bus 4496	: V=1.02524038, theta=-22.734732 -> V=0.975, theta=0.0
% INFO    : Bus 4497	: V=1.02524038, theta=-22.734732 -> V=0.999999, theta=0.0
% INFO    : Bus 4498	: V=1.07826811, theta=-13.334773 -> V=1.000266, theta=0.0
% INFO    : Bus 4499	: V=1.06441229, theta=-1.39147041 -> V=1.072365, theta=0.0
% INFO    : Bus 4500	: V=1.00640283, theta=-19.9774473 -> V=1.015872, theta=0.0
% INFO    : Bus 4501	: V=1.0228685, theta=-29.3758569 -> V=1.022224, theta=0.0
% INFO    : Bus 4502	: V=1.00961887, theta=-37.8834402 -> V=1.022224, theta=0.0
% INFO    : Bus 4503	: V=1.039, theta=-11.0635625 -> V=0.975, theta=0.0
% INFO    : Bus 4504	: V=1.04020338, theta=-12.0475562 -> V=0.999999, theta=0.0
% INFO    : Bus 4505	: V=1.01863656, theta=-22.221325 -> V=1.022224, theta=0.0
% INFO    : Bus 4506	: V=1.01176501, theta=-18.4829671 -> V=0.999999, theta=0.0
% INFO    : Bus 4507	: V=1.079, theta=-16.3509552 -> V=1.044445, theta=0.0
% INFO    : Bus 4508	: V=1.0532432, theta=-21.1400795 -> V=1.0000025, theta=0.0
% INFO    : Bus 4509	: V=1.03762029, theta=-17.7463421 -> V=1.013334, theta=0.0
% INFO    : Bus 4510	: V=1.02989345, theta=-26.6707601 -> V=1.0000025, theta=0.0
% INFO    : Bus 4511	: V=1.02626892, theta=-29.1002053 -> V=1.015872, theta=0.0
% INFO    : Bus 4512	: V=1.01697297, theta=-19.6219785 -> V=1.015872, theta=0.0
% INFO    : Bus 4513	: V=1.0250782, theta=-39.0027065 -> V=1.022224, theta=0.0
% INFO    : Bus 4514	: V=1.04101498, theta=-23.426178 -> V=1.022224, theta=0.0
% INFO    : Bus 4515	: V=1.01924414, theta=-4.24632153 -> V=1.0000025, theta=0.0
% INFO    : Bus 4516	: V=1.056, theta=-12.252903 -> V=1.006624, theta=0.0
% INFO    : Bus 4517	: V=1.03922449, theta=-32.4516229 -> V=1.022224, theta=0.0
% INFO    : Bus 4518	: V=1.02425848, theta=-12.3601999 -> V=1.015872, theta=0.0
% INFO    : Bus 4519	: V=1.06102779, theta=-10.1545159 -> V=1.0233335, theta=0.0
% INFO    : Bus 4520	: V=1.05702414, theta=-9.03961138 -> V=1.046665, theta=0.0
% INFO    : Bus 4521	: V=1.02206264, theta=-13.3539171 -> V=0.9682545, theta=0.0
% INFO    : Bus 4522	: V=1.04672698, theta=-4.57464333 -> V=1.0000025, theta=0.0
% INFO    : Bus 4523	: V=1.02086917, theta=1.79490793 -> V=1.0158755, theta=0.0
% INFO    : Bus 4524	: V=1.03953414, theta=-25.5623225 -> V=1.0000025, theta=0.0
% INFO    : Bus 4525	: V=1.02343683, theta=-3.43408382 -> V=1.0158755, theta=0.0
% INFO    : Bus 4526	: V=1.0675897, theta=-13.6464008 -> V=1.04444, theta=0.0
% INFO    : Bus 4527	: V=1.08155387, theta=-9.61617079 -> V=1.07237, theta=0.0
% INFO    : Bus 4528	: V=1.00842045, theta=-22.2343583 -> V=1.015872, theta=0.0
% INFO    : Bus 4529	: V=1.03100186, theta=-13.2126187 -> V=0.999999, theta=0.0
% INFO    : Bus 4530	: V=0.565682915, theta=3.48119209 -> V=0.825, theta=0.0
% INFO    : Bus 4531	: V=1.02783975, theta=3.48119209 -> V=1.0158755, theta=0.0
% INFO    : Bus 4532	: V=1.02931158, theta=-45.7001475 -> V=1.0079355, theta=0.0
% INFO    : Bus 4533	: V=1.01805294, theta=-32.3508929 -> V=1.0000005, theta=0.0
% INFO    : Bus 4534	: V=1.01614486, theta=-11.376758 -> V=0.999999, theta=0.0
% INFO    : Bus 4535	: V=1.06419758, theta=-17.0897678 -> V=1.0000025, theta=0.0
% INFO    : Bus 4536	: V=1.05712105, theta=-15.4237236 -> V=1.000001, theta=0.0
% INFO    : Bus 4537	: V=1.07792725, theta=-14.6981406 -> V=1.044445, theta=0.0
% INFO    : Bus 4538	: V=1.04126812, theta=-24.8601816 -> V=1.0000025, theta=0.0
% INFO    : Bus 4539	: V=1.07273705, theta=-16.187723 -> V=1.008669, theta=0.0
% INFO    : Bus 4540	: V=1.04170967, theta=-42.1040802 -> V=1.022224, theta=0.0
% INFO    : Bus 4541	: V=1.02741019, theta=-16.3724542 -> V=1.015872, theta=0.0
% INFO    : Bus 4542	: V=1.06841135, theta=-14.4043186 -> V=1.044445, theta=0.0
% INFO    : Bus 4543	: V=1.06590551, theta=-10.7616689 -> V=1.078945, theta=0.0
% INFO    : Bus 4544	: V=1.05952735, theta=-10.2513681 -> V=0.999999, theta=0.0
% INFO    : Bus 4545	: V=1.03193549, theta=-42.0065203 -> V=1.0079355, theta=0.0
% INFO    : Bus 4546	: V=1.02585213, theta=-43.2609761 -> V=1.0079355, theta=0.0
% INFO    : Bus 4547	: V=1.03466943, theta=-41.9121936 -> V=1.0079355, theta=0.0
% INFO    : Bus 4548	: V=1.0500469, theta=-18.1477109 -> V=1.000001, theta=0.0
% INFO    : Bus 4549	: V=1.01299365, theta=-12.8052341 -> V=0.999999, theta=0.0
% INFO    : Bus 4550	: V=1.04864245, theta=-23.9599767 -> V=1.0000025, theta=0.0
% INFO    : Bus 4551	: V=1.06795264, theta=-23.4991172 -> V=1.0, theta=0.0
% INFO    : Bus 4552	: V=1.07971734, theta=-22.5550841 -> V=1.044445, theta=0.0
% INFO    : Bus 4553	: V=1.04133974, theta=-25.9251774 -> V=1.0000025, theta=0.0
% INFO    : Bus 4554	: V=1.03831199, theta=-26.3244264 -> V=1.0000025, theta=0.0
% INFO    : Bus 4555	: V=1.05903572, theta=-14.0870472 -> V=1.044445, theta=0.0
% INFO    : Bus 4556	: V=1.03407756, theta=-21.1515244 -> V=0.999999, theta=0.0
% INFO    : Bus 4557	: V=1.0476395, theta=-21.0651761 -> V=1.0000025, theta=0.0
% INFO    : Bus 4558	: V=1.02405308, theta=-29.4889384 -> V=1.0000005, theta=0.0
% INFO    : Bus 4559	: V=1.038, theta=-22.1570958 -> V=1.0000025, theta=0.0
% INFO    : Bus 4560	: V=1.06079623, theta=-10.3848812 -> V=1.002794, theta=0.0
% INFO    : Bus 4561	: V=1.03990063, theta=-18.1333216 -> V=0.999999, theta=0.0
% INFO    : Bus 4562	: V=1.02958735, theta=-19.9849982 -> V=0.999999, theta=0.0
% INFO    : Bus 4563	: V=1.04786771, theta=-25.6859312 -> V=1.0000025, theta=0.0
% INFO    : Bus 4564	: V=1.06587426, theta=-26.1926335 -> V=1.027779, theta=0.0
% INFO    : Bus 4565	: V=1.08873391, theta=-20.303978 -> V=1.073685, theta=0.0
% INFO    : Bus 4566	: V=1.046, theta=-15.1922978 -> V=1.0377785, theta=0.0
% INFO    : Bus 4567	: V=1.04906256, theta=-8.87344388 -> V=1.046665, theta=0.0
% INFO    : Bus 4568	: V=1.05315434, theta=-7.93265104 -> V=1.046665, theta=0.0
% INFO    : Bus 4569	: V=1.06037605, theta=-3.17374469 -> V=1.07859, theta=0.0
% INFO    : Bus 4570	: V=1.06781069, theta=-24.5032031 -> V=1.04444, theta=0.0
% INFO    : Bus 4571	: V=1.05182647, theta=-43.5971001 -> V=1.04444, theta=0.0
% INFO    : Bus 4572	: V=1.01028906, theta=-30.1779949 -> V=1.0000005, theta=0.0
% INFO    : Bus 4573	: V=1.12160461, theta=4.48195627 -> V=1.0403205, theta=0.0
% INFO    : Bus 4574	: V=1.03867004, theta=-26.2283683 -> V=1.0000025, theta=0.0
% INFO    : Bus 4575	: V=1.04893146, theta=-17.0523981 -> V=0.999999, theta=0.0
% INFO    : Bus 4576	: V=1.00798016, theta=-12.0308794 -> V=1.015872, theta=0.0
% INFO    : Bus 4577	: V=1.00797635, theta=-12.0307971 -> V=1.015872, theta=0.0
% INFO    : Bus 4578	: V=1.04645835, theta=-26.3420952 -> V=1.046665, theta=0.0
% INFO    : Bus 4579	: V=0.977829129, theta=-4.99557426 -> V=0.9444445, theta=0.0
% INFO    : Bus 4580	: V=1.034, theta=-27.3986058 -> V=1.0000025, theta=0.0
% INFO    : Bus 4581	: V=1.03182211, theta=-13.0637595 -> V=0.999999, theta=0.0
% INFO    : Bus 4582	: V=1.05420864, theta=-3.91720025 -> V=1.0000025, theta=0.0
% INFO    : Bus 4583	: V=1.03281892, theta=-20.8689094 -> V=1.000001, theta=0.0
% INFO    : Bus 4584	: V=1.07448384, theta=-28.5242699 -> V=1.04722, theta=0.0
% INFO    : Bus 4585	: V=1.04987711, theta=-22.9787484 -> V=1.033333, theta=0.0
% INFO    : Bus 4586	: V=0.985566027, theta=-35.2526001 -> V=1.0000025, theta=0.0
% INFO    : Bus 4587	: V=1.0731971, theta=-28.5876205 -> V=1.029964, theta=0.0
% INFO    : Bus 4588	: V=1.08786674, theta=-20.485303 -> V=1.073685, theta=0.0
% INFO    : Bus 4589	: V=1.0876406, theta=-20.4838424 -> V=1.073685, theta=0.0
% INFO    : Bus 4590	: V=1.04151652, theta=-14.6487565 -> V=1.015872, theta=0.0
% INFO    : Bus 4591	: V=1.03920092, theta=-10.3836777 -> V=1.046665, theta=0.0
% INFO    : Bus 4592	: V=1.04812191, theta=-13.3200871 -> V=1.001674, theta=0.0
% INFO    : Bus 4593	: V=1.04958913, theta=-22.5063517 -> V=1.046665, theta=0.0
% INFO    : Bus 4594	: V=1.06842954, theta=-17.8420531 -> V=1.073685, theta=0.0
% INFO    : Bus 4595	: V=1.06797141, theta=-18.1178871 -> V=1.073685, theta=0.0
% INFO    : Bus 4596	: V=1.01253063, theta=-29.2141519 -> V=1.022224, theta=0.0
% INFO    : Bus 4597	: V=1.02940401, theta=-25.3088169 -> V=1.0000025, theta=0.0
% INFO    : Bus 4598	: V=1.05298356, theta=-24.5269745 -> V=1.022224, theta=0.0
% INFO    : Bus 4599	: V=1.05130693, theta=-8.01641287 -> V=1.0158755, theta=0.0
% INFO    : Bus 4600	: V=0.981965724, theta=-41.5367248 -> V=1.0214115, theta=0.0
% INFO    : Bus 4601	: V=1.02267067, theta=-29.3706421 -> V=1.022224, theta=0.0
% INFO    : Bus 4602	: V=1.0540041, theta=-52.0137947 -> V=1.0079355, theta=0.0
% INFO    : Bus 4603	: V=1.06966759, theta=-44.5289238 -> V=1.04444, theta=0.0
% INFO    : Bus 4604	: V=1.04072699, theta=-6.27633198 -> V=1.0158755, theta=0.0
% INFO    : Bus 4605	: V=1.0012388, theta=-27.8793285 -> V=1.0000005, theta=0.0
% INFO    : Bus 4606	: V=1.04307488, theta=-38.464599 -> V=1.022224, theta=0.0
% INFO    : Bus 4607	: V=1.02225361, theta=-17.8215941 -> V=1.015872, theta=0.0
% INFO    : Bus 4608	: V=1.06090191, theta=-42.9918843 -> V=1.022699, theta=0.0
% INFO    : Bus 4609	: V=1.04089756, theta=-23.4092652 -> V=0.999999, theta=0.0
% INFO    : Bus 4610	: V=1.04827009, theta=-16.5171537 -> V=1.000001, theta=0.0
% INFO    : Bus 4611	: V=1.06099351, theta=-13.0741587 -> V=0.9888895, theta=0.0
% INFO    : Bus 4612	: V=1.01423306, theta=-10.8497726 -> V=1.0158755, theta=0.0
% INFO    : Bus 4613	: V=1.06084398, theta=-33.3132822 -> V=1.029194, theta=0.0
% INFO    : Bus 4614	: V=1.02395264, theta=-24.3446182 -> V=1.022224, theta=0.0
% INFO    : Bus 4615	: V=1.01791335, theta=-25.3270125 -> V=1.022224, theta=0.0
% INFO    : Bus 4616	: V=1.02332887, theta=1.95963268 -> V=1.0158755, theta=0.0
% INFO    : Bus 4617	: V=1.06864171, theta=-31.6330964 -> V=1.046665, theta=0.0
% INFO    : Bus 4618	: V=1.06069059, theta=-10.3852352 -> V=1.002739, theta=0.0
% INFO    : Bus 4619	: V=1.04609017, theta=-38.3590716 -> V=1.0000025, theta=0.0
% INFO    : Bus 4620	: V=1.02975531, theta=-15.2808746 -> V=0.999999, theta=0.0
% INFO    : Bus 4621	: V=1.06388014, theta=-14.0133199 -> V=1.002149, theta=0.0
% INFO    : Bus 4622	: V=1.0135113, theta=-37.7210692 -> V=1.022224, theta=0.0
% INFO    : Bus 4623	: V=1.02327256, theta=-15.8163879 -> V=1.015872, theta=0.0
% INFO    : Bus 4624	: V=1.01870489, theta=-28.1512327 -> V=1.022224, theta=0.0
% INFO    : Bus 4625	: V=1.02263865, theta=-25.7488477 -> V=1.0000005, theta=0.0
% INFO    : Bus 4626	: V=1.03887903, theta=-29.9965823 -> V=1.022224, theta=0.0
% INFO    : Bus 4627	: V=1.04146461, theta=-27.3250293 -> V=1.0000025, theta=0.0
% INFO    : Bus 4628	: V=1.04575705, theta=-24.6998099 -> V=1.0000025, theta=0.0
% INFO    : Bus 4629	: V=1.08002083, theta=-3.65880587 -> V=1.0377785, theta=0.0
% INFO    : Bus 4630	: V=1.03742402, theta=-11.8572434 -> V=0.999999, theta=0.0
% INFO    : Bus 4631	: V=1.05131147, theta=-25.8485048 -> V=1.027779, theta=0.0
% INFO    : Bus 4632	: V=1.07983157, theta=-19.1194051 -> V=1.073685, theta=0.0
% INFO    : Bus 4633	: V=1.07980382, theta=-19.1244132 -> V=1.073685, theta=0.0
% INFO    : Bus 4634	: V=1.03084594, theta=-19.8746945 -> V=1.0158755, theta=0.0
% INFO    : Bus 4635	: V=1.03274301, theta=-26.3751068 -> V=1.046665, theta=0.0
% INFO    : Bus 4636	: V=1.02373624, theta=-44.3007443 -> V=1.022224, theta=0.0
% INFO    : Bus 4637	: V=1.0275039, theta=-23.7557096 -> V=1.022224, theta=0.0
% INFO    : Bus 4638	: V=1.02635153, theta=-24.2311426 -> V=1.022224, theta=0.0
% INFO    : Bus 4639	: V=0.979941568, theta=-10.3864972 -> V=0.9444445, theta=0.0
% INFO    : Bus 4640	: V=1.06489015, theta=-26.9115248 -> V=1.046665, theta=0.0
% INFO    : Bus 4641	: V=1.06789627, theta=-25.713559 -> V=1.027779, theta=0.0
% INFO    : Bus 4642	: V=1.0912011, theta=-18.8597002 -> V=1.073685, theta=0.0
% INFO    : Bus 4643	: V=1.06290742, theta=-27.2555369 -> V=1.027779, theta=0.0
% INFO    : Bus 4644	: V=1.02787141, theta=-18.2870524 -> V=1.0158755, theta=0.0
% INFO    : Bus 4645	: V=1.06751114, theta=-16.0035749 -> V=1.0377785, theta=0.0
% INFO    : Bus 4646	: V=1.0674358, theta=-16.1060292 -> V=1.0377785, theta=0.0
% INFO    : Bus 4647	: V=1.04672794, theta=-4.57466745 -> V=1.0000025, theta=0.0
% INFO    : Bus 4648	: V=1.04987365, theta=-24.8146893 -> V=1.0000025, theta=0.0
% INFO    : Bus 4649	: V=1.07833891, theta=-16.4513455 -> V=1.0000025, theta=0.0
% INFO    : Bus 4650	: V=1.04168135, theta=-30.5712436 -> V=1.027779, theta=0.0
% INFO    : Bus 4651	: V=1.01482879, theta=-30.5407956 -> V=1.0000005, theta=0.0
% INFO    : Bus 4652	: V=1.03501734, theta=-24.92337 -> V=1.0000025, theta=0.0
% INFO    : Bus 4653	: V=1.02420643, theta=-24.6544946 -> V=1.022224, theta=0.0
% INFO    : Bus 4654	: V=1.03385451, theta=-23.1494014 -> V=1.022224, theta=0.0
% INFO    : Bus 4655	: V=1.07498885, theta=-24.6665025 -> V=1.046665, theta=0.0
% INFO    : Bus 4656	: V=1.08446556, theta=-20.384348 -> V=1.073685, theta=0.0
% INFO    : Bus 4657	: V=0.96258799, theta=-8.54246284 -> V=0.9444445, theta=0.0
% INFO    : Bus 4658	: V=1.0665866, theta=-25.8437903 -> V=1.027779, theta=0.0
% INFO    : Bus 4659	: V=1.01578728, theta=-11.7982101 -> V=0.999999, theta=0.0
% INFO    : Bus 4660	: V=1.03154405, theta=-32.0922627 -> V=1.022224, theta=0.0
% INFO    : Bus 4661	: V=1.0242725, theta=-24.6951229 -> V=1.022224, theta=0.0
% INFO    : Bus 4662	: V=1.02143872, theta=-27.8647101 -> V=1.0000005, theta=0.0
% INFO    : Bus 4663	: V=1.0563021, theta=-30.3246831 -> V=1.022224, theta=0.0
% INFO    : Bus 4664	: V=1.07086596, theta=-20.5686338 -> V=1.044445, theta=0.0
% INFO    : Bus 4665	: V=1.06238806, theta=-19.065662 -> V=1.0111115, theta=0.0
% INFO    : Bus 4666	: V=1.061, theta=-17.5549307 -> V=0.975, theta=0.0
% INFO    : Bus 4667	: V=1.06075203, theta=-17.5692164 -> V=1.0000025, theta=0.0
% INFO    : Bus 4668	: V=1.02326127, theta=-30.0716682 -> V=1.015872, theta=0.0
% INFO    : Bus 4669	: V=1.03532882, theta=-25.7645681 -> V=1.046665, theta=0.0
% INFO    : Bus 4670	: V=1.03913525, theta=-23.1919913 -> V=1.06579, theta=0.0
% INFO    : Bus 4671	: V=1.01036579, theta=-14.8449297 -> V=1.015872, theta=0.0
% INFO    : Bus 4672	: V=1.01781013, theta=-24.7626515 -> V=1.000001, theta=0.0
% INFO    : Bus 4673	: V=1.01976842, theta=-15.9569804 -> V=0.999999, theta=0.0
% INFO    : Bus 4674	: V=1.0308145, theta=-45.6885112 -> V=1.0079355, theta=0.0
% INFO    : Bus 4675	: V=1.03697173, theta=-50.4623402 -> V=1.0079355, theta=0.0
% INFO    : Bus 4676	: V=1.06817633, theta=-42.3320971 -> V=1.04444, theta=0.0
% INFO    : Bus 4677	: V=1.03759561, theta=-34.7416334 -> V=1.022224, theta=0.0
% INFO    : Bus 4678	: V=1.04318511, theta=-24.9677695 -> V=1.000001, theta=0.0
% INFO    : Bus 4679	: V=1.00514578, theta=-40.3887297 -> V=1.022224, theta=0.0
% INFO    : Bus 4680	: V=1.02317345, theta=-15.3499031 -> V=1.015872, theta=0.0
% INFO    : Bus 4681	: V=1.0603914, theta=-15.0461712 -> V=1.006864, theta=0.0
% INFO    : Bus 4682	: V=1.03959041, theta=-11.2323526 -> V=1.0111115, theta=0.0
% INFO    : Bus 4683	: V=1.03748477, theta=-27.9601281 -> V=1.022224, theta=0.0
% INFO    : Bus 4684	: V=1.01778712, theta=-9.95930791 -> V=1.015872, theta=0.0
% INFO    : Bus 4685	: V=1.01778697, theta=-9.9593362 -> V=1.015872, theta=0.0
% INFO    : Bus 4686	: V=1.01897004, theta=5.23098234 -> V=1.033334, theta=0.0
% INFO    : Bus 4687	: V=1.01592704, theta=5.01458935 -> V=1.033334, theta=0.0
% INFO    : Bus 4688	: V=1.01781678, theta=5.03159912 -> V=1.033334, theta=0.0
% INFO    : Bus 4689	: V=1.01596752, theta=5.46695134 -> V=1.033334, theta=0.0
% INFO    : Bus 4690	: V=1.03255422, theta=-20.626431 -> V=1.0158755, theta=0.0
% INFO    : Bus 4691	: V=1.03828344, theta=-38.27915 -> V=1.0079355, theta=0.0
% INFO    : Bus 4692	: V=1.0551832, theta=-21.6448036 -> V=1.022222, theta=0.0
% INFO    : Bus 4693	: V=1.02375208, theta=-13.0408257 -> V=1.015872, theta=0.0
% INFO    : Bus 4694	: V=0.991137254, theta=-21.585811 -> V=1.015872, theta=0.0
% INFO    : Bus 4695	: V=1.05869415, theta=-12.8831889 -> V=0.9888895, theta=0.0
% INFO    : Bus 4696	: V=1.05873359, theta=-12.8730982 -> V=0.9888895, theta=0.0
% INFO    : Bus 4697	: V=1.05848692, theta=-5.10444942 -> V=1.046665, theta=0.0
% INFO    : Bus 4698	: V=1.01698459, theta=4.23365336 -> V=1.046665, theta=0.0
% INFO    : Bus 4699	: V=1.01383646, theta=4.01297412 -> V=1.046665, theta=0.0
% INFO    : Bus 4700	: V=1.01678257, theta=4.39809271 -> V=1.046665, theta=0.0
% INFO    : Bus 4701	: V=1.01416566, theta=4.23954452 -> V=1.046665, theta=0.0
% INFO    : Bus 4702	: V=1.01558779, theta=4.04140914 -> V=1.046665, theta=0.0
% INFO    : Bus 4703	: V=1.01374588, theta=4.28306105 -> V=1.046665, theta=0.0
% INFO    : Bus 4704	: V=1.01600235, theta=4.25503819 -> V=1.046665, theta=0.0
% INFO    : Bus 4705	: V=1.01402552, theta=4.52794822 -> V=1.046665, theta=0.0
% INFO    : Bus 4706	: V=1.06881764, theta=0.650671015 -> V=1.078945, theta=0.0
% INFO    : Bus 4707	: V=1.03745849, theta=-30.0339234 -> V=1.0000025, theta=0.0
% INFO    : Bus 4708	: V=1.03177281, theta=-13.3440104 -> V=1.0158755, theta=0.0
% INFO    : Bus 4709	: V=1.02657619, theta=-6.4470583 -> V=1.0158755, theta=0.0
% INFO    : Bus 4710	: V=1.056, theta=-18.2094913 -> V=1.0000025, theta=0.0
% INFO    : Bus 4711	: V=1.09811217, theta=-18.1715093 -> V=1.0, theta=0.0
% INFO    : Bus 4712	: V=1.01742722, theta=-0.984377955 -> V=1.0158755, theta=0.0
% INFO    : Bus 4713	: V=1.068, theta=-27.4174586 -> V=1.0000025, theta=0.0
% INFO    : Bus 4714	: V=1.05678564, theta=-22.8091685 -> V=1.044445, theta=0.0
% INFO    : Bus 4715	: V=1.03829571, theta=-20.8709509 -> V=1.000001, theta=0.0
% INFO    : Bus 4716	: V=1.0716869, theta=-11.9488724 -> V=0.9888895, theta=0.0
% INFO    : Bus 4717	: V=1.07169944, theta=-11.9465471 -> V=0.9888895, theta=0.0
% INFO    : Bus 4718	: V=1.07144587, theta=-11.9670925 -> V=0.9888895, theta=0.0
% INFO    : Bus 4719	: V=1.02474403, theta=-23.8411877 -> V=1.000001, theta=0.0
% INFO    : Bus 4720	: V=1.04853304, theta=-25.9594172 -> V=1.046665, theta=0.0
% INFO    : Bus 4721	: V=1.0212376, theta=-8.80001236 -> V=1.0158755, theta=0.0
% INFO    : Bus 4722	: V=1.01150088, theta=-25.7284397 -> V=1.0000005, theta=0.0
% INFO    : Bus 4723	: V=1.03828616, theta=-29.181756 -> V=1.022224, theta=0.0
% INFO    : Bus 4724	: V=1.06287826, theta=-2.43708483 -> V=1.0377785, theta=0.0
% INFO    : Bus 4725	: V=1.01984234, theta=-4.65296344 -> V=0.999999, theta=0.0
% INFO    : Bus 4726	: V=1.06085443, theta=-33.3133373 -> V=1.029199, theta=0.0
% INFO    : Bus 4727	: V=1.02880279, theta=-13.5691195 -> V=1.0158755, theta=0.0
% INFO    : Bus 4728	: V=1.02728571, theta=-30.4961849 -> V=1.015872, theta=0.0
% INFO    : Bus 4729	: V=1.04211279, theta=-26.8308372 -> V=1.046665, theta=0.0
% INFO    : Bus 4730	: V=1.08059901, theta=-16.9634208 -> V=1.04689, theta=0.0
% INFO    : Bus 4731	: V=1.0144196, theta=-15.8875409 -> V=1.0000015, theta=0.0
% INFO    : Bus 4732	: V=1.00766563, theta=-15.5155995 -> V=0.999999, theta=0.0
% INFO    : Bus 4733	: V=1.03404142, theta=-9.1852807 -> V=0.999999, theta=0.0
% INFO    : Bus 4734	: V=1.02440743, theta=-2.63998061 -> V=1.0158755, theta=0.0
% INFO    : Bus 4735	: V=1.0097519, theta=-30.105469 -> V=1.015872, theta=0.0
% INFO    : Bus 4736	: V=1.03870447, theta=-26.3226254 -> V=1.046665, theta=0.0
% INFO    : Bus 4737	: V=0.96258799, theta=-8.54246284 -> V=0.9444445, theta=0.0
% INFO    : Bus 4738	: V=1.05102565, theta=-6.41487179 -> V=1.0111115, theta=0.0
% INFO    : Bus 4739	: V=1.02387925, theta=-28.0744202 -> V=1.0000025, theta=0.0
% INFO    : Bus 4740	: V=1.0426737, theta=-15.209714 -> V=0.999999, theta=0.0
% INFO    : Bus 4741	: V=1.03074933, theta=-26.2881935 -> V=1.0000025, theta=0.0
% INFO    : Bus 4742	: V=1.00552926, theta=-25.3223447 -> V=1.0000025, theta=0.0
% INFO    : Bus 4743	: V=1.03441792, theta=-16.9382248 -> V=1.0000025, theta=0.0
% INFO    : Bus 4744	: V=1.0368527, theta=-6.98160585 -> V=1.0158755, theta=0.0
% INFO    : Bus 4745	: V=1.01661289, theta=4.53786653 -> V=1.013331, theta=0.0
% INFO    : Bus 4746	: V=1.0641216, theta=-13.4351705 -> V=1.033333, theta=0.0
% INFO    : Bus 4747	: V=1.06418688, theta=-13.3819507 -> V=1.033333, theta=0.0
% INFO    : Bus 4748	: V=1.0535888, theta=-17.1515106 -> V=1.000001, theta=0.0
% INFO    : Bus 4749	: V=1.04733238, theta=-26.4809418 -> V=1.0000025, theta=0.0
% INFO    : Bus 4750	: V=1.008, theta=-17.2298419 -> V=1.015872, theta=0.0
% INFO    : Bus 4751	: V=1.008, theta=-17.2312771 -> V=1.015872, theta=0.0
% INFO    : Bus 4752	: V=1.02698811, theta=-58.6027706 -> V=1.0079355, theta=0.0
% INFO    : Bus 4753	: V=0.989174028, theta=-19.9822649 -> V=1.015872, theta=0.0
% INFO    : Bus 4754	: V=1.04938077, theta=-28.3681759 -> V=1.0090905, theta=0.0
% INFO    : Bus 4755	: V=1.06335049, theta=-23.5608589 -> V=1.046665, theta=0.0
% INFO    : Bus 4756	: V=1.06782413, theta=-23.6231314 -> V=1.046665, theta=0.0
% INFO    : Bus 4757	: V=1.05102877, theta=-7.01983215 -> V=1.0111115, theta=0.0
% INFO    : Bus 4758	: V=0.974677493, theta=-22.6033412 -> V=1.015872, theta=0.0
% INFO    : Bus 4759	: V=1.02364142, theta=-26.4105695 -> V=1.015872, theta=0.0
% INFO    : Bus 4760	: V=1.049, theta=-25.0184625 -> V=1.0233335, theta=0.0
% INFO    : Bus 4761	: V=1.00425979, theta=-12.6029497 -> V=1.015872, theta=0.0
% INFO    : Bus 4762	: V=1.00853817, theta=-33.0156147 -> V=1.015872, theta=0.0
% INFO    : Bus 4763	: V=1.04884117, theta=-28.8903101 -> V=1.027779, theta=0.0
% INFO    : Bus 4764	: V=1.0187846, theta=-16.3199886 -> V=1.0158755, theta=0.0
% INFO    : Bus 4765	: V=1.03797277, theta=-19.0104051 -> V=1.022224, theta=0.0
% INFO    : Bus 4766	: V=1.06799084, theta=-14.8607276 -> V=1.04444, theta=0.0
% INFO    : Bus 4767	: V=1.07412375, theta=-7.52470431 -> V=1.07237, theta=0.0
% INFO    : Bus 4768	: V=1.03323152, theta=-16.2370179 -> V=1.0158755, theta=0.0
% INFO    : Bus 4769	: V=1.03529351, theta=-10.6482115 -> V=1.0158755, theta=0.0
% INFO    : Bus 4770	: V=1.03103298, theta=-23.734601 -> V=1.0000025, theta=0.0
% INFO    : Bus 4771	: V=1.0298976, theta=-11.1199097 -> V=0.999999, theta=0.0
% INFO    : Bus 4772	: V=1.02603617, theta=-6.64679149 -> V=1.0111115, theta=0.0
% INFO    : Bus 4773	: V=1.02731155, theta=-19.5844524 -> V=1.022224, theta=0.0
% INFO    : Bus 4774	: V=1.06122454, theta=-12.9370675 -> V=0.9888895, theta=0.0
% INFO    : Bus 4775	: V=1.02533646, theta=-27.7471458 -> V=1.0000005, theta=0.0
% INFO    : Bus 4776	: V=1.0488248, theta=-23.9568498 -> V=1.046665, theta=0.0
% INFO    : Bus 4777	: V=1.01381209, theta=-27.4683045 -> V=1.0000025, theta=0.0
% INFO    : Bus 4778	: V=1.01991706, theta=-15.7089259 -> V=1.015872, theta=0.0
% INFO    : Bus 4779	: V=1.03275688, theta=-31.0376828 -> V=1.022224, theta=0.0
% INFO    : Bus 4780	: V=1.03565267, theta=-31.5068481 -> V=1.022224, theta=0.0
% INFO    : Bus 4781	: V=1.03054617, theta=-42.8445386 -> V=1.022224, theta=0.0
% INFO    : Bus 4782	: V=1.03810977, theta=-18.6974452 -> V=0.999999, theta=0.0
% INFO    : Bus 4783	: V=1.05253738, theta=-30.7215945 -> V=1.022224, theta=0.0
% INFO    : Bus 4784	: V=1.05725376, theta=-27.6414654 -> V=1.027779, theta=0.0
% INFO    : Bus 4785	: V=1.05766003, theta=-28.6316301 -> V=1.027779, theta=0.0
% INFO    : Bus 4786	: V=1.05475675, theta=-9.18785459 -> V=0.999999, theta=0.0
% INFO    : Bus 4787	: V=1.07618967, theta=-3.70822243 -> V=1.0111115, theta=0.0
% INFO    : Bus 4788	: V=1.01329224, theta=-27.5533756 -> V=1.0000005, theta=0.0
% INFO    : Bus 4789	: V=1.01293528, theta=-27.5616439 -> V=1.0000005, theta=0.0
% INFO    : Bus 4790	: V=0.974549491, theta=-17.349797 -> V=1.015872, theta=0.0
% INFO    : Bus 4791	: V=0.975698667, theta=-17.2106663 -> V=1.015872, theta=0.0
% INFO    : Bus 4792	: V=1.00717004, theta=-12.1734652 -> V=1.015872, theta=0.0
% INFO    : Bus 4793	: V=1.04083425, theta=-26.5445154 -> V=1.027779, theta=0.0
% INFO    : Bus 4794	: V=1.03129965, theta=-29.4970914 -> V=1.015872, theta=0.0
% INFO    : Bus 4795	: V=1.02624104, theta=2.04532935 -> V=1.0158755, theta=0.0
% INFO    : Bus 4796	: V=1.08365712, theta=4.00500223 -> V=1.0398335, theta=0.0
% INFO    : Bus 4797	: V=1.015, theta=-11.3166746 -> V=0.999999, theta=0.0
% INFO    : Bus 4798	: V=1.05049362, theta=-52.7062255 -> V=1.0079355, theta=0.0
% INFO    : Bus 4799	: V=0.999542471, theta=-29.3372811 -> V=1.0000005, theta=0.0
% INFO    : Bus 4800	: V=1.01416701, theta=-4.92500559 -> V=1.0158755, theta=0.0
% INFO    : Bus 4801	: V=1.02835578, theta=-19.3459209 -> V=1.022224, theta=0.0
% INFO    : Bus 4802	: V=1.04444747, theta=-33.4439595 -> V=1.022224, theta=0.0
% INFO    : Bus 4803	: V=1.06555309, theta=-17.0585686 -> V=1.04444, theta=0.0
% INFO    : Bus 4804	: V=1.01175313, theta=-22.1375548 -> V=1.0158755, theta=0.0
% INFO    : Bus 4805	: V=1.04379538, theta=-30.2742808 -> V=1.027779, theta=0.0
% INFO    : Bus 4806	: V=1.01445076, theta=-14.689828 -> V=1.015872, theta=0.0
% INFO    : Bus 4807	: V=1.05425716, theta=-37.5671535 -> V=1.027779, theta=0.0
% INFO    : Bus 4808	: V=1.06292526, theta=-18.3632127 -> V=1.0111115, theta=0.0
% INFO    : Bus 4809	: V=1.04493279, theta=-27.4672451 -> V=1.027779, theta=0.0
% INFO    : Bus 4810	: V=1.035, theta=-10.3572281 -> V=1.0158755, theta=0.0
% INFO    : Bus 4811	: V=1.023, theta=-11.7881852 -> V=0.975, theta=0.0
% INFO    : Bus 4812	: V=1.022, theta=-11.8731117 -> V=0.975, theta=0.0
% INFO    : Bus 4813	: V=1.02254877, theta=-12.6286047 -> V=0.999999, theta=0.0
% INFO    : Bus 4814	: V=1.02253792, theta=-12.6289909 -> V=0.999999, theta=0.0
% INFO    : Bus 4815	: V=1.04274654, theta=-30.7274313 -> V=1.022224, theta=0.0
% INFO    : Bus 4816	: V=1.02116727, theta=-12.8229653 -> V=0.999999, theta=0.0
% INFO    : Bus 4817	: V=1.077, theta=10.89559 -> V=0.975, theta=0.0
% INFO    : Bus 4818	: V=1.082, theta=0.765318174 -> V=0.975, theta=0.0
% INFO    : Bus 4819	: V=1.081, theta=2.7456725 -> V=0.975, theta=0.0
% INFO    : Bus 4820	: V=1.077, theta=4.81264291 -> V=0.975, theta=0.0
% INFO    : Bus 4821	: V=1.06949059, theta=-1.65288942 -> V=1.072365, theta=0.0
% INFO    : Bus 4822	: V=1.07286059, theta=-22.6877834 -> V=1.030699, theta=0.0
% INFO    : Bus 4823	: V=1.08179522, theta=-18.9348124 -> V=1.048925, theta=0.0
% INFO    : Bus 4824	: V=1.08110295, theta=-19.3191691 -> V=1.048615, theta=0.0
% INFO    : Bus 4825	: V=1.09030264, theta=-12.9695773 -> V=1.073685, theta=0.0
% INFO    : Bus 4826	: V=1.0085642, theta=-22.2553455 -> V=1.015872, theta=0.0
% INFO    : Bus 4827	: V=1.04320551, theta=-24.4030606 -> V=0.984126, theta=0.0
% INFO    : Bus 4828	: V=1.04367851, theta=-28.5479027 -> V=1.022224, theta=0.0
% INFO    : Bus 4829	: V=0.999948894, theta=-15.2601813 -> V=1.015872, theta=0.0
% INFO    : Bus 4830	: V=1.02951721, theta=-15.4736451 -> V=0.999999, theta=0.0
% INFO    : Bus 4831	: V=1.0363014, theta=-22.3532313 -> V=1.033333, theta=0.0
% INFO    : Bus 4832	: V=1.0217825, theta=-15.9646223 -> V=1.015872, theta=0.0
% INFO    : Bus 4833	: V=1.02039206, theta=-18.4937525 -> V=1.0158755, theta=0.0
% INFO    : Bus 4834	: V=1.01017413, theta=-20.2184781 -> V=1.0158755, theta=0.0
% INFO    : Bus 4835	: V=1.02161222, theta=-30.8572839 -> V=1.015872, theta=0.0
% INFO    : Bus 4836	: V=1.01140183, theta=-21.873335 -> V=1.0000025, theta=0.0
% INFO    : Bus 4837	: V=1.01092176, theta=-22.8546673 -> V=1.0000025, theta=0.0
% INFO    : Bus 4838	: V=1.06041967, theta=-15.0437128 -> V=1.006809, theta=0.0
% INFO    : Bus 4839	: V=1.04381101, theta=-15.5303226 -> V=0.9888895, theta=0.0
% INFO    : Bus 4840	: V=1.01504311, theta=-27.8453346 -> V=1.022224, theta=0.0
% INFO    : Bus 4841	: V=1.02941146, theta=-20.7094111 -> V=1.022224, theta=0.0
% INFO    : Bus 4842	: V=1.05217394, theta=-10.3846702 -> V=1.004369, theta=0.0
% INFO    : Bus 4843	: V=1.05418763, theta=-7.38968426 -> V=1.0111115, theta=0.0
% INFO    : Bus 4844	: V=1.04014485, theta=-22.5898049 -> V=1.0000025, theta=0.0
% INFO    : Bus 4845	: V=1.02853886, theta=-14.350667 -> V=1.015872, theta=0.0
% INFO    : Bus 4846	: V=0.933310418, theta=-7.37061986 -> V=0.9444445, theta=0.0
% INFO    : Bus 4847	: V=0.933310115, theta=-7.37060969 -> V=0.9444445, theta=0.0
% INFO    : Bus 4848	: V=1.05028444, theta=-5.58631747 -> V=1.0111115, theta=0.0
% INFO    : Bus 4849	: V=1.03800252, theta=-11.5088219 -> V=0.999999, theta=0.0
% INFO    : Bus 4850	: V=1.04220556, theta=-21.8618832 -> V=1.022224, theta=0.0
% INFO    : Bus 4851	: V=0.978387205, theta=-5.60453162 -> V=1.0158755, theta=0.0
% INFO    : Bus 4852	: V=1.06374247, theta=-23.0925463 -> V=1.0000025, theta=0.0
% INFO    : Bus 4853	: V=1.0733561, theta=-19.8503253 -> V=1.044445, theta=0.0
% INFO    : Bus 4854	: V=1.08046667, theta=-14.9267678 -> V=1.078945, theta=0.0
% INFO    : Bus 4855	: V=1.08256884, theta=-14.760276 -> V=1.07237, theta=0.0
% INFO    : Bus 4856	: V=1.05588845, theta=-27.8414272 -> V=1.046665, theta=0.0
% INFO    : Bus 4857	: V=1.02607693, theta=-23.434717 -> V=1.0000025, theta=0.0
% INFO    : Bus 4858	: V=1.06833675, theta=-18.7918686 -> V=1.044445, theta=0.0
% INFO    : Bus 4859	: V=1.02551056, theta=-9.5442487 -> V=0.999999, theta=0.0
% INFO    : Bus 4860	: V=1.04844712, theta=-21.7904716 -> V=0.999999, theta=0.0
% INFO    : Bus 4861	: V=1.01563524, theta=-13.7657584 -> V=0.999999, theta=0.0
% INFO    : Bus 4862	: V=1.0334761, theta=-9.23649112 -> V=0.999999, theta=0.0
% INFO    : Bus 4863	: V=1.03225902, theta=-40.8398388 -> V=1.022224, theta=0.0
% INFO    : Bus 4864	: V=1.04349925, theta=-9.57362032 -> V=0.999999, theta=0.0
% INFO    : Bus 4865	: V=1.0831346, theta=-21.3321035 -> V=1.016666, theta=0.0
% INFO    : Bus 4866	: V=1.04594407, theta=-21.373656 -> V=1.033334, theta=0.0
% INFO    : Bus 4867	: V=1.02568643, theta=-17.238153 -> V=1.0158755, theta=0.0
% INFO    : Bus 4868	: V=1.02378646, theta=-17.3954919 -> V=1.0158755, theta=0.0
% INFO    : Bus 4869	: V=1.04831748, theta=-32.2816592 -> V=1.0105205, theta=0.0
% INFO    : Bus 4870	: V=1.00804567, theta=-30.5032366 -> V=1.0000005, theta=0.0
% INFO    : Bus 4871	: V=1.00126938, theta=-29.3192803 -> V=1.0000005, theta=0.0
% INFO    : Bus 4872	: V=1.05492057, theta=-28.6136399 -> V=1.046665, theta=0.0
% INFO    : Bus 4873	: V=1.042, theta=-17.187102 -> V=0.999999, theta=0.0
% INFO    : Bus 4874	: V=1.05284591, theta=-14.6508962 -> V=0.9888895, theta=0.0
% INFO    : Bus 4875	: V=1.04227622, theta=-41.0273305 -> V=1.022224, theta=0.0
% INFO    : Bus 4876	: V=1.06481866, theta=-36.9060024 -> V=1.04444, theta=0.0
% INFO    : Bus 4877	: V=1.03456318, theta=-13.8111327 -> V=1.0111115, theta=0.0
% INFO    : Bus 4878	: V=1.02627779, theta=-11.077368 -> V=1.0158755, theta=0.0
% INFO    : Bus 4879	: V=1.03889564, theta=-10.5821564 -> V=0.9888895, theta=0.0
% INFO    : Bus 4880	: V=1.05410219, theta=-6.51049966 -> V=1.039472, theta=0.0
% INFO    : Bus 4881	: V=1.03729391, theta=-12.8642855 -> V=1.0158755, theta=0.0
% INFO    : Bus 4882	: V=1.01123396, theta=-22.001628 -> V=1.015872, theta=0.0
% INFO    : Bus 4883	: V=1.01556966, theta=-34.2054721 -> V=1.0000005, theta=0.0
% INFO    : Bus 4884	: V=1.02440824, theta=-15.9910845 -> V=1.015872, theta=0.0
% INFO    : Bus 4885	: V=1.06516851, theta=-20.4736961 -> V=1.000001, theta=0.0
% INFO    : Bus 4886	: V=1.03335382, theta=-14.162281 -> V=0.9888895, theta=0.0
% INFO    : Bus 4887	: V=1.0563019, theta=-33.0499469 -> V=1.027779, theta=0.0
% INFO    : Bus 4888	: V=1.03029899, theta=-22.3712258 -> V=1.0000025, theta=0.0
% INFO    : Bus 4889	: V=1.03603319, theta=0.913582483 -> V=1.0158755, theta=0.0
% INFO    : Bus 4890	: V=1.05473055, theta=-34.8458291 -> V=1.022224, theta=0.0
% INFO    : Bus 4891	: V=1.03161193, theta=-17.3629498 -> V=0.999999, theta=0.0
% INFO    : Bus 4892	: V=1.01318734, theta=-9.28154421 -> V=0.999999, theta=0.0
% INFO    : Bus 4893	: V=1.013, theta=-8.98839119 -> V=0.999999, theta=0.0
% INFO    : Bus 4894	: V=1.02321551, theta=-30.0702688 -> V=1.015872, theta=0.0
% INFO    : Bus 4895	: V=1.02879968, theta=-16.5785708 -> V=1.0158755, theta=0.0
% INFO    : Bus 4896	: V=1.06425014, theta=-12.5073603 -> V=1.0377785, theta=0.0
% INFO    : Bus 4897	: V=1.06880361, theta=-13.6365965 -> V=1.0377785, theta=0.0
% INFO    : Bus 4898	: V=1.07685213, theta=-9.42086493 -> V=1.072365, theta=0.0
% INFO    : Bus 4899	: V=1.03842655, theta=-20.0848706 -> V=1.022224, theta=0.0
% INFO    : Bus 4900	: V=1.04209073, theta=-29.0502517 -> V=1.027779, theta=0.0
% INFO    : Bus 4901	: V=1.05322504, theta=-22.6073957 -> V=1.0000025, theta=0.0
% INFO    : Bus 4902	: V=1.08007927, theta=4.82439213 -> V=1.0377785, theta=0.0
% INFO    : Bus 4903	: V=1.09219301, theta=8.35175479 -> V=1.072365, theta=0.0
% INFO    : Bus 4904	: V=1.0920352, theta=9.78516646 -> V=1.072365, theta=0.0
% INFO    : Bus 4905	: V=1.04455441, theta=-34.1260637 -> V=1.027779, theta=0.0
% INFO    : Bus 4906	: V=1.00329281, theta=-13.9010615 -> V=0.999999, theta=0.0
% INFO    : Bus 4907	: V=1.06718772, theta=-26.7149829 -> V=1.046665, theta=0.0
% INFO    : Bus 4908	: V=1.06306801, theta=-24.9452647 -> V=1.046665, theta=0.0
% INFO    : Bus 4909	: V=1.04014867, theta=-5.12464151 -> V=1.0158755, theta=0.0
% INFO    : Bus 4910	: V=1.04190832, theta=-4.52669976 -> V=1.0158755, theta=0.0
% INFO    : Bus 4911	: V=1.01029352, theta=-4.21651083 -> V=1.0, theta=0.0
% INFO    : Bus 4912	: V=1.0750465, theta=-1.50788947 -> V=1.0377785, theta=0.0
% INFO    : Bus 4913	: V=1.0846061, theta=1.08847313 -> V=1.072365, theta=0.0
% INFO    : Bus 4914	: V=1.01643506, theta=-24.2999675 -> V=1.022224, theta=0.0
% INFO    : Bus 4915	: V=1.005, theta=-17.8145257 -> V=1.015872, theta=0.0
% INFO    : Bus 4916	: V=1.03741441, theta=-28.5774341 -> V=1.015872, theta=0.0
% INFO    : Bus 4917	: V=1.04235853, theta=-24.1808376 -> V=1.046665, theta=0.0
% INFO    : Bus 4918	: V=1.03, theta=-21.6954502 -> V=1.0000025, theta=0.0
% INFO    : Bus 4919	: V=1.04131357, theta=-26.0989789 -> V=1.0000025, theta=0.0
% INFO    : Bus 4920	: V=1.03427826, theta=-33.6825732 -> V=1.022224, theta=0.0
% INFO    : Bus 4921	: V=1.0343952, theta=-15.1699315 -> V=1.015872, theta=0.0
% INFO    : Bus 4922	: V=1.04908308, theta=-10.8632019 -> V=1.046665, theta=0.0
% INFO    : Bus 4923	: V=1.05510656, theta=-3.78980491 -> V=1.0000025, theta=0.0
% INFO    : Bus 4924	: V=1.05518132, theta=-3.75808817 -> V=1.0000025, theta=0.0
% INFO    : Bus 4925	: V=1.05316539, theta=-35.8326075 -> V=1.027779, theta=0.0
% INFO    : Bus 4926	: V=1.04255707, theta=-14.6392273 -> V=0.999999, theta=0.0
% INFO    : Bus 4927	: V=1.01423274, theta=-29.9938361 -> V=1.0000005, theta=0.0
% INFO    : Bus 4928	: V=1.00949911, theta=-40.6863776 -> V=1.022224, theta=0.0
% INFO    : Bus 4929	: V=1.01680225, theta=-21.2255777 -> V=1.015872, theta=0.0
% INFO    : Bus 4930	: V=1.01445085, theta=-29.9959736 -> V=1.0000005, theta=0.0
% INFO    : Bus 4931	: V=1.01445414, theta=-29.9956782 -> V=1.0000005, theta=0.0
% INFO    : Bus 4932	: V=1.01439648, theta=-29.9985727 -> V=1.0000005, theta=0.0
% INFO    : Bus 4933	: V=1.06767705, theta=-26.5806407 -> V=1.046665, theta=0.0
% INFO    : Bus 4934	: V=1.06767803, theta=-26.5778435 -> V=1.046665, theta=0.0
% INFO    : Bus 4935	: V=1.02941947, theta=-7.20846626 -> V=1.0158755, theta=0.0
% INFO    : Bus 4936	: V=1.06938487, theta=-2.54276449 -> V=1.0377785, theta=0.0
% INFO    : Bus 4937	: V=1.06714318, theta=-26.6672461 -> V=1.046665, theta=0.0
% INFO    : Bus 4938	: V=1.01510335, theta=-11.615746 -> V=1.015872, theta=0.0
% INFO    : Bus 4939	: V=1.02472089, theta=-9.12243868 -> V=0.999999, theta=0.0
% INFO    : Bus 4940	: V=1.04050798, theta=-25.5178496 -> V=1.0051255, theta=0.0
% INFO    : Bus 4941	: V=0.953, theta=-7.76221285 -> V=0.9444445, theta=0.0
% INFO    : Bus 4942	: V=1.06609096, theta=-10.4976778 -> V=1.072365, theta=0.0
% INFO    : Bus 4943	: V=1.01702235, theta=-17.7188833 -> V=1.0158755, theta=0.0
% INFO    : Bus 4944	: V=1.07371177, theta=-13.3166798 -> V=1.072365, theta=0.0
% INFO    : Bus 4945	: V=1.04445942, theta=-33.9813746 -> V=1.027779, theta=0.0
% INFO    : Bus 4946	: V=1.02910059, theta=-18.0957084 -> V=0.999999, theta=0.0
% INFO    : Bus 4947	: V=1.03593031, theta=-14.6293997 -> V=0.999999, theta=0.0
% INFO    : Bus 4948	: V=1.02306964, theta=-12.6983602 -> V=1.0158755, theta=0.0
% INFO    : Bus 4949	: V=1.05408838, theta=-28.8871412 -> V=1.027779, theta=0.0
% INFO    : Bus 4950	: V=1.07155015, theta=-25.1651883 -> V=1.046665, theta=0.0
% INFO    : Bus 4951	: V=1.05872781, theta=-24.4679882 -> V=1.046665, theta=0.0
% INFO    : Bus 4952	: V=1.06266725, theta=-19.6030417 -> V=1.073685, theta=0.0
% INFO    : Bus 4953	: V=1.04789779, theta=-18.0580777 -> V=0.975, theta=0.0
% INFO    : Bus 4954	: V=1.05081062, theta=-20.8521342 -> V=1.022224, theta=0.0
% INFO    : Bus 4955	: V=1.04794515, theta=-18.0465281 -> V=1.04444, theta=0.0
% INFO    : Bus 4956	: V=1.0552532, theta=-21.1192453 -> V=1.022224, theta=0.0
% INFO    : Bus 4957	: V=1.04822412, theta=-26.6076985 -> V=1.0000025, theta=0.0
% INFO    : Bus 4958	: V=1.02127353, theta=-27.314977 -> V=1.0000005, theta=0.0
% INFO    : Bus 4959	: V=1.06279206, theta=-24.5551222 -> V=1.046665, theta=0.0
% INFO    : Bus 4960	: V=1.01923373, theta=-23.8052699 -> V=1.022224, theta=0.0
% INFO    : Bus 4961	: V=1.07967534, theta=-17.1922493 -> V=1.07237, theta=0.0
% INFO    : Bus 4962	: V=1.08253079, theta=-16.1823223 -> V=1.07237, theta=0.0
% INFO    : Bus 4963	: V=1.042, theta=-14.2239737 -> V=0.999999, theta=0.0
% INFO    : Bus 4964	: V=1.01454545, theta=-27.3285866 -> V=1.0000005, theta=0.0
% INFO    : Bus 4965	: V=1.04677465, theta=-4.57630766 -> V=1.000001, theta=0.0
% INFO    : Bus 4966	: V=1.03072153, theta=-26.8627265 -> V=1.0000005, theta=0.0
% INFO    : Bus 4967	: V=1.02873216, theta=-26.8659647 -> V=1.0000005, theta=0.0
% INFO    : Bus 4968	: V=1.06334069, theta=-23.5608161 -> V=1.046665, theta=0.0
% INFO    : Bus 4969	: V=1.0677954, theta=-23.6228842 -> V=1.046665, theta=0.0
% INFO    : Bus 4970	: V=1.05983099, theta=-18.9485292 -> V=1.073685, theta=0.0
% INFO    : Bus 4971	: V=1.04788223, theta=-14.5500677 -> V=0.999999, theta=0.0
% INFO    : Bus 4972	: V=1.04467091, theta=-19.0787071 -> V=1.000001, theta=0.0
% INFO    : Bus 4973	: V=1.04281053, theta=-19.3292292 -> V=1.000001, theta=0.0
% INFO    : Bus 4974	: V=1.04001995, theta=-17.0933064 -> V=1.0158755, theta=0.0
% INFO    : Bus 4975	: V=1.07060047, theta=-14.7121761 -> V=1.0377785, theta=0.0
% INFO    : Bus 4976	: V=1.022, theta=-10.5710143 -> V=0.999999, theta=0.0
% INFO    : Bus 4977	: V=1.1, theta=3.19410036 -> V=0.975, theta=0.0
% INFO    : Bus 4978	: V=1.118, theta=2.69151396 -> V=0.975, theta=0.0
% INFO    : Bus 4979	: V=1.118, theta=2.77418719 -> V=0.975, theta=0.0
% INFO    : Bus 4980	: V=1.06580707, theta=-1.25404397 -> V=1.0377785, theta=0.0
% INFO    : Bus 4981	: V=1.0855513, theta=-1.93356134 -> V=1.0377785, theta=0.0
% INFO    : Bus 4982	: V=1.08555069, theta=-1.93328047 -> V=1.0377785, theta=0.0
% INFO    : Bus 4983	: V=1.0227711, theta=-5.57907554 -> V=1.0158755, theta=0.0
% INFO    : Bus 4984	: V=1.08546493, theta=-1.9495641 -> V=1.0377785, theta=0.0
% INFO    : Bus 4985	: V=1.06571329, theta=-1.26948916 -> V=1.0377785, theta=0.0
% INFO    : Bus 4986	: V=1.02365897, theta=-5.87036933 -> V=1.0158755, theta=0.0
% INFO    : Bus 4987	: V=1.02983628, theta=2.36175347 -> V=1.0158755, theta=0.0
% INFO    : Bus 4988	: V=1.07619316, theta=4.93806612 -> V=1.0377785, theta=0.0
% INFO    : Bus 4989	: V=1.01012997, theta=-25.177103 -> V=0.999999, theta=0.0
% INFO    : Bus 4990	: V=1.03246759, theta=-12.7210349 -> V=0.999999, theta=0.0
% INFO    : Bus 4991	: V=1.05516716, theta=-19.0852798 -> V=1.002364, theta=0.0
% INFO    : Bus 4992	: V=1.0345054, theta=-15.0189721 -> V=1.0111115, theta=0.0
% INFO    : Bus 4993	: V=1.03107824, theta=-15.3304985 -> V=0.999999, theta=0.0
% INFO    : Bus 4994	: V=1.04103872, theta=-9.67135636 -> V=1.0111115, theta=0.0
% INFO    : Bus 4995	: V=1.00005561, theta=-20.9410917 -> V=0.999999, theta=0.0
% INFO    : Bus 4996	: V=1.03182916, theta=-12.0362602 -> V=0.999999, theta=0.0
% INFO    : Bus 4997	: V=1.0095466, theta=-21.3634233 -> V=1.0158755, theta=0.0
% INFO    : Bus 4998	: V=1.05382648, theta=-12.7871218 -> V=1.004609, theta=0.0
% INFO    : Bus 4999	: V=1.05273528, theta=-10.2017685 -> V=1.0111115, theta=0.0
% INFO    : Bus 5000	: V=1.05155639, theta=-11.6527597 -> V=0.999999, theta=0.0
% INFO    : Bus 5001	: V=1.03489131, theta=-11.8884667 -> V=1.0158755, theta=0.0
% INFO    : Bus 5002	: V=1.00941885, theta=-12.7203892 -> V=1.015872, theta=0.0
% INFO    : Bus 5003	: V=1.05001404, theta=-19.0572615 -> V=1.046665, theta=0.0
% INFO    : Bus 5004	: V=1.04944927, theta=-19.0523087 -> V=1.046665, theta=0.0
% INFO    : Bus 5005	: V=1.04717484, theta=-11.7456157 -> V=1.0000025, theta=0.0
% INFO    : Bus 5006	: V=1.04331586, theta=-23.6945742 -> V=1.022224, theta=0.0
% INFO    : Bus 5007	: V=1.03605317, theta=-26.8196797 -> V=1.022224, theta=0.0
% INFO    : Bus 5008	: V=1.06421842, theta=-14.5230579 -> V=1.002279, theta=0.0
% INFO    : Bus 5009	: V=1.03417859, theta=-23.5701833 -> V=1.0000025, theta=0.0
% INFO    : Bus 5010	: V=1.04308475, theta=-16.343011 -> V=0.999999, theta=0.0
% INFO    : Bus 5011	: V=1.02593739, theta=-9.93545958 -> V=1.0277795, theta=0.0
% INFO    : Bus 5012	: V=1.02147592, theta=-34.8880305 -> V=1.027779, theta=0.0
% INFO    : Bus 5013	: V=1.02758774, theta=-13.1376005 -> V=1.0158755, theta=0.0
% INFO    : Bus 5014	: V=1.02173198, theta=-27.8148311 -> V=1.0000005, theta=0.0
% INFO    : Bus 5015	: V=1.0575524, theta=-24.4880306 -> V=1.046665, theta=0.0
% INFO    : Bus 5016	: V=1.03863694, theta=-25.1123018 -> V=1.046665, theta=0.0
% INFO    : Bus 5017	: V=1.07, theta=-14.2482186 -> V=1.000001, theta=0.0
% INFO    : Bus 5018	: V=1.02217673, theta=-22.4687963 -> V=1.0000025, theta=0.0
% INFO    : Bus 5019	: V=1.0237027, theta=-32.4404831 -> V=1.022224, theta=0.0
% INFO    : Bus 5020	: V=1.04550605, theta=-30.2004718 -> V=1.022224, theta=0.0
% INFO    : Bus 5021	: V=1.03509223, theta=-27.6177465 -> V=1.0000025, theta=0.0
% INFO    : Bus 5022	: V=1.03724742, theta=-18.0367113 -> V=1.0000025, theta=0.0
% INFO    : Bus 5023	: V=1.015, theta=-20.0777517 -> V=1.0000025, theta=0.0
% INFO    : Bus 5024	: V=1.03523691, theta=-25.773644 -> V=0.9709345, theta=0.0
% INFO    : Bus 5025	: V=1.02257152, theta=3.10418104 -> V=1.0158755, theta=0.0
% INFO    : Bus 5026	: V=1.03146311, theta=-29.006689 -> V=1.0000025, theta=0.0
% INFO    : Bus 5027	: V=1.02025312, theta=-28.285441 -> V=1.0000005, theta=0.0
% INFO    : Bus 5028	: V=1.06523517, theta=-26.7722802 -> V=1.046665, theta=0.0
% INFO    : Bus 5029	: V=1.05178384, theta=-20.7337501 -> V=1.000001, theta=0.0
% INFO    : Bus 5030	: V=1.04475424, theta=-21.6974524 -> V=1.000001, theta=0.0
% INFO    : Bus 5031	: V=0.999613487, theta=-10.2164237 -> V=0.999999, theta=0.0
% INFO    : Bus 5032	: V=0.998933439, theta=-43.0671883 -> V=1.022224, theta=0.0
% INFO    : Bus 5033	: V=1.01633704, theta=-12.1418578 -> V=0.999999, theta=0.0
% INFO    : Bus 5034	: V=1.03598749, theta=-27.2064989 -> V=1.0000025, theta=0.0
% INFO    : Bus 5035	: V=1.03920415, theta=-13.4173703 -> V=1.0158755, theta=0.0
% INFO    : Bus 5036	: V=1.04349612, theta=-21.9227308 -> V=1.022222, theta=0.0
% INFO    : Bus 5037	: V=1.03307817, theta=1.09339191 -> V=1.0158755, theta=0.0
% INFO    : Bus 5038	: V=1.03326786, theta=-31.8018983 -> V=1.022224, theta=0.0
% INFO    : Bus 5039	: V=1.04033867, theta=-5.50930427 -> V=1.0111115, theta=0.0
% INFO    : Bus 5040	: V=1.02079181, theta=-10.6414433 -> V=1.0277795, theta=0.0
% INFO    : Bus 5041	: V=1.04391234, theta=-28.4605676 -> V=1.0063655, theta=0.0
% INFO    : Bus 5042	: V=1.03335128, theta=-6.08336595 -> V=1.0158755, theta=0.0
% INFO    : Bus 5043	: V=1.0244754, theta=-5.9495624 -> V=1.0158755, theta=0.0
% INFO    : Bus 5044	: V=1.04008264, theta=-21.8303194 -> V=1.0000025, theta=0.0
% INFO    : Bus 5045	: V=1.06743974, theta=-36.8151401 -> V=1.026524, theta=0.0
% INFO    : Bus 5046	: V=1.06142225, theta=-31.5338072 -> V=1.04444, theta=0.0
% INFO    : Bus 5047	: V=1.01115915, theta=-12.3587258 -> V=0.999999, theta=0.0
% INFO    : Bus 5048	: V=1.06008413, theta=-18.978263 -> V=1.033333, theta=0.0
% INFO    : Bus 5049	: V=1.04214108, theta=-23.7257373 -> V=1.0158755, theta=0.0
% INFO    : Bus 5050	: V=0.992437532, theta=-4.82483471 -> V=1.0158755, theta=0.0
% INFO    : Bus 5051	: V=1.00086582, theta=-27.8985587 -> V=1.0000005, theta=0.0
% INFO    : Bus 5052	: V=1.03867067, theta=-7.47887408 -> V=1.0158755, theta=0.0
% INFO    : Bus 5053	: V=1.02020345, theta=-6.34154365 -> V=1.0158755, theta=0.0
% INFO    : Bus 5054	: V=1.07630981, theta=-9.34382019 -> V=0.9895245, theta=0.0
% INFO    : Bus 5055	: V=1.06905109, theta=-10.5569753 -> V=0.9888895, theta=0.0
% INFO    : Bus 5056	: V=1.08715921, theta=-6.42317431 -> V=1.05263, theta=0.0
% INFO    : Bus 5057	: V=1.08885731, theta=-6.17485814 -> V=1.05263, theta=0.0
% INFO    : Bus 5058	: V=1.05011942, theta=-17.2851335 -> V=1.033333, theta=0.0
% INFO    : Bus 5059	: V=1.03526312, theta=-6.14611525 -> V=1.0158755, theta=0.0
% INFO    : Bus 5060	: V=1.05825922, theta=-19.2237976 -> V=1.022222, theta=0.0
% INFO    : Bus 5061	: V=1.05177373, theta=-14.7956484 -> V=0.9888895, theta=0.0
% INFO    : Bus 5062	: V=1.05173962, theta=-14.8299263 -> V=0.9888895, theta=0.0
% INFO    : Bus 5063	: V=1.0563095, theta=-13.4567147 -> V=0.9888895, theta=0.0
% INFO    : Bus 5064	: V=1.06422915, theta=-9.25444171 -> V=1.05263, theta=0.0
% INFO    : Bus 5065	: V=1.06790311, theta=-10.709215 -> V=0.9888895, theta=0.0
% INFO    : Bus 5066	: V=1.06747216, theta=-10.7386718 -> V=0.9888895, theta=0.0
% INFO    : Bus 5067	: V=1.05589554, theta=-13.7918967 -> V=0.9888895, theta=0.0
% INFO    : Bus 5068	: V=1.0354877, theta=0.926402492 -> V=1.0158755, theta=0.0
% INFO    : Bus 5069	: V=1.00929091, theta=-3.66276476 -> V=1.0158755, theta=0.0
% INFO    : Bus 5070	: V=1.06087171, theta=-22.9970106 -> V=1.027779, theta=0.0
% INFO    : Bus 5071	: V=1.05290614, theta=-25.1655608 -> V=1.027779, theta=0.0
% INFO    : Bus 5072	: V=1.07663965, theta=-20.503101 -> V=1.046665, theta=0.0
% INFO    : Bus 5073	: V=1.07080407, theta=-14.061947 -> V=1.000001, theta=0.0
% INFO    : Bus 5074	: V=1.04793461, theta=-11.6603642 -> V=1.000389, theta=0.0
% INFO    : Bus 5075	: V=1.03278979, theta=-36.2028253 -> V=1.027779, theta=0.0
% INFO    : Bus 5076	: V=1.03230671, theta=-18.4064183 -> V=0.999999, theta=0.0
% INFO    : Bus 5077	: V=1.03791939, theta=-26.7115498 -> V=1.027779, theta=0.0
% INFO    : Bus 5078	: V=1.06152406, theta=-26.9001004 -> V=1.046665, theta=0.0
% INFO    : Bus 5079	: V=1.06989116, theta=-20.9011607 -> V=1.073685, theta=0.0
% INFO    : Bus 5080	: V=1.03208828, theta=-18.6540709 -> V=0.999999, theta=0.0
% INFO    : Bus 5081	: V=1.02857302, theta=-35.9549354 -> V=1.022224, theta=0.0
% INFO    : Bus 5082	: V=1.05015724, theta=-20.3326662 -> V=1.0222235, theta=0.0
% INFO    : Bus 5083	: V=0.936523152, theta=-5.06927513 -> V=0.9444445, theta=0.0
% INFO    : Bus 5084	: V=1.03087171, theta=-20.3196785 -> V=0.999999, theta=0.0
% INFO    : Bus 5085	: V=1.04262005, theta=-19.1101959 -> V=1.022224, theta=0.0
% INFO    : Bus 5086	: V=1.00790567, theta=-27.3387416 -> V=1.0000005, theta=0.0
% INFO    : Bus 5087	: V=1.02337871, theta=-33.4003989 -> V=1.022224, theta=0.0
% INFO    : Bus 5088	: V=1.06092507, theta=-19.078941 -> V=1.0000025, theta=0.0
% INFO    : Bus 5089	: V=1.02112531, theta=1.7527171 -> V=1.0158755, theta=0.0
% INFO    : Bus 5090	: V=1.02294219, theta=-27.5986184 -> V=1.0000005, theta=0.0
% INFO    : Bus 5091	: V=1.07216592, theta=-30.1084324 -> V=1.04444, theta=0.0
% INFO    : Bus 5092	: V=1.03698877, theta=-14.465083 -> V=0.999999, theta=0.0
% INFO    : Bus 5093	: V=1.0466098, theta=-15.8889633 -> V=0.999999, theta=0.0
% INFO    : Bus 5094	: V=0.941115419, theta=-5.76832138 -> V=0.9444445, theta=0.0
% INFO    : Bus 5095	: V=0.977964419, theta=-9.79398057 -> V=0.9444445, theta=0.0
% INFO    : Bus 5096	: V=1.03732643, theta=-6.87232653 -> V=1.0158755, theta=0.0
% INFO    : Bus 5097	: V=1.04572104, theta=-27.2518177 -> V=1.022224, theta=0.0
% INFO    : Bus 5098	: V=1.06633999, theta=-16.4269657 -> V=0.9933315, theta=0.0
% INFO    : Bus 5099	: V=1.04606359, theta=-21.140902 -> V=1.0000025, theta=0.0
% INFO    : Bus 5100	: V=1.03756699, theta=-29.4513814 -> V=1.022224, theta=0.0
% INFO    : Bus 5101	: V=1.02173405, theta=-25.5842534 -> V=1.0000005, theta=0.0
% INFO    : Bus 5102	: V=1.07146914, theta=-17.7961928 -> V=1.005558, theta=0.0
% INFO    : Bus 5103	: V=1.07057965, theta=-17.884814 -> V=1.005558, theta=0.0
% INFO    : Bus 5104	: V=1.04291534, theta=-25.1578364 -> V=1.0000025, theta=0.0
% INFO    : Bus 5105	: V=1.03716399, theta=-19.1213168 -> V=1.0158755, theta=0.0
% INFO    : Bus 5106	: V=1.02910394, theta=-23.510594 -> V=1.022224, theta=0.0
% INFO    : Bus 5107	: V=0.949967688, theta=-6.96346435 -> V=0.9444445, theta=0.0
% INFO    : Bus 5108	: V=1.02319926, theta=-39.8880859 -> V=1.022224, theta=0.0
% INFO    : Bus 5109	: V=1.0263032, theta=0.186228311 -> V=1.0158755, theta=0.0
% INFO    : Bus 5110	: V=1.01553469, theta=-19.1133993 -> V=1.015872, theta=0.0
% INFO    : Bus 5111	: V=1.06022293, theta=-28.1731305 -> V=1.023144, theta=0.0
% INFO    : Bus 5112	: V=1.09802353, theta=-18.1699593 -> V=1.0333335, theta=0.0
% INFO    : Bus 5113	: V=1.05038164, theta=-22.3592309 -> V=1.005558, theta=0.0
% INFO    : Bus 5114	: V=1.02761194, theta=-25.8674422 -> V=1.0000025, theta=0.0
% INFO    : Bus 5115	: V=1.03809865, theta=-27.8744741 -> V=1.0000025, theta=0.0
% INFO    : Bus 5116	: V=1.06482367, theta=-24.549724 -> V=1.046665, theta=0.0
% INFO    : Bus 5117	: V=1.06500894, theta=-24.5371014 -> V=1.046665, theta=0.0
% INFO    : Bus 5118	: V=1.0539154, theta=-16.1507857 -> V=0.9933315, theta=0.0
% INFO    : Bus 5119	: V=0.998605662, theta=-12.5829341 -> V=1.015872, theta=0.0
% INFO    : Bus 5120	: V=1.06467413, theta=-18.509998 -> V=1.007134, theta=0.0
% INFO    : Bus 5121	: V=1.06350565, theta=-26.2296243 -> V=1.027779, theta=0.0
% INFO    : Bus 5122	: V=1.03536964, theta=-27.420133 -> V=1.0000025, theta=0.0
% INFO    : Bus 5123	: V=1.03188294, theta=-19.7843659 -> V=1.0000025, theta=0.0
% INFO    : Bus 5124	: V=1.03290028, theta=-10.420664 -> V=0.9888895, theta=0.0
% INFO    : Bus 5125	: V=1.06902367, theta=-17.9963737 -> V=1.046665, theta=0.0
% INFO    : Bus 5126	: V=1.02856712, theta=-20.0557734 -> V=1.0000025, theta=0.0
% INFO    : Bus 5127	: V=1.0190269, theta=-23.5294773 -> V=1.015872, theta=0.0
% INFO    : Bus 5128	: V=1.03855103, theta=-9.61590275 -> V=1.0000015, theta=0.0
% INFO    : Bus 5129	: V=1.02383269, theta=-22.397492 -> V=1.0000025, theta=0.0
% INFO    : Bus 5130	: V=1.02647167, theta=-9.06581715 -> V=0.999999, theta=0.0
% INFO    : Bus 5131	: V=1.03478556, theta=-15.1666837 -> V=1.0158755, theta=0.0
% INFO    : Bus 5132	: V=1.0395022, theta=-10.6512226 -> V=0.999999, theta=0.0
% INFO    : Bus 5133	: V=1.03805733, theta=-34.3715562 -> V=1.022224, theta=0.0
% INFO    : Bus 5134	: V=1.0131333, theta=-16.9735303 -> V=0.999999, theta=0.0
% INFO    : Bus 5135	: V=1.05747882, theta=-28.7752738 -> V=1.0000025, theta=0.0
% INFO    : Bus 5136	: V=1.02020862, theta=-28.2957025 -> V=1.0000005, theta=0.0
% INFO    : Bus 5137	: V=1.05847242, theta=-28.6647426 -> V=1.0000025, theta=0.0
% INFO    : Bus 5138	: V=1.03094977, theta=-12.9497922 -> V=0.999999, theta=0.0
% INFO    : Bus 5139	: V=1.01687987, theta=-28.5523312 -> V=1.0000005, theta=0.0
% INFO    : Bus 5140	: V=1.03183084, theta=-27.7839461 -> V=1.0000025, theta=0.0
% INFO    : Bus 5141	: V=1.02456728, theta=-14.7313085 -> V=0.999999, theta=0.0
% INFO    : Bus 5142	: V=1.03891089, theta=-15.8910489 -> V=0.9933315, theta=0.0
% INFO    : Bus 5143	: V=1.02704327, theta=-20.3106868 -> V=1.0000025, theta=0.0
% INFO    : Bus 5144	: V=1.02654925, theta=-20.3180503 -> V=1.0000025, theta=0.0
% INFO    : Bus 5145	: V=1.01168282, theta=-23.7381421 -> V=1.0000025, theta=0.0
% INFO    : Bus 5146	: V=1.01143054, theta=-23.7607805 -> V=1.0000025, theta=0.0
% INFO    : Bus 5147	: V=1.0408401, theta=-26.1979004 -> V=1.0000025, theta=0.0
% INFO    : Bus 5148	: V=1.02755438, theta=-21.1720191 -> V=1.022224, theta=0.0
% INFO    : Bus 5149	: V=1.05230342, theta=-11.9036627 -> V=1.0111115, theta=0.0
% INFO    : Bus 5150	: V=1.03572195, theta=-38.6827226 -> V=1.0079355, theta=0.0
% INFO    : Bus 5151	: V=1.04608359, theta=-23.1209723 -> V=1.0000025, theta=0.0
% INFO    : Bus 5152	: V=1.04811121, theta=-23.0404657 -> V=1.0000025, theta=0.0
% INFO    : Bus 5153	: V=1.0575077, theta=-9.60497353 -> V=1.046665, theta=0.0
% INFO    : Bus 5154	: V=1.01714163, theta=-24.0845061 -> V=1.022224, theta=0.0
% INFO    : Bus 5155	: V=1.01713831, theta=-24.0839937 -> V=1.022224, theta=0.0
% INFO    : Bus 5156	: V=1.04666247, theta=-19.536638 -> V=1.0222235, theta=0.0
% INFO    : Bus 5157	: V=1.04862595, theta=-33.5429628 -> V=1.022224, theta=0.0
% INFO    : Bus 5158	: V=1.02611733, theta=-20.4137198 -> V=1.0000025, theta=0.0
% INFO    : Bus 5159	: V=1.04426324, theta=-27.9386596 -> V=1.0000025, theta=0.0
% INFO    : Bus 5160	: V=1.04045561, theta=-28.8897274 -> V=1.0000025, theta=0.0
% INFO    : Bus 5161	: V=1.03037435, theta=-21.712723 -> V=1.0000025, theta=0.0
% INFO    : Bus 5162	: V=1.03766998, theta=-28.7558801 -> V=1.0000025, theta=0.0
% INFO    : Bus 5163	: V=1.05341616, theta=-22.6116478 -> V=1.0000025, theta=0.0
% INFO    : Bus 5164	: V=1.04513993, theta=-9.68939028 -> V=0.999999, theta=0.0
% INFO    : Bus 5165	: V=1.02425555, theta=-43.7456613 -> V=1.0079355, theta=0.0
% INFO    : Bus 5166	: V=1.01387647, theta=-27.4563658 -> V=1.0000025, theta=0.0
% INFO    : Bus 5167	: V=1.06076905, theta=-42.9554643 -> V=1.022639, theta=0.0
% INFO    : Bus 5168	: V=1.02175643, theta=-32.6594911 -> V=1.0000005, theta=0.0
% INFO    : Bus 5169	: V=1.03963123, theta=-18.298027 -> V=1.0158755, theta=0.0
% INFO    : Bus 5170	: V=1.02903234, theta=-39.7897216 -> V=1.022224, theta=0.0
% INFO    : Bus 5171	: V=1.02589236, theta=-30.0414434 -> V=1.022224, theta=0.0
% INFO    : Bus 5172	: V=1.02321257, theta=-32.6137174 -> V=1.0000005, theta=0.0
% INFO    : Bus 5173	: V=1.04997976, theta=-25.593915 -> V=1.046665, theta=0.0
% INFO    : Bus 5174	: V=1.0273229, theta=-54.8108076 -> V=1.0079355, theta=0.0
% INFO    : Bus 5175	: V=1.0499783, theta=-11.0110475 -> V=1.0233335, theta=0.0
% INFO    : Bus 5176	: V=1.04978368, theta=-25.6730816 -> V=1.046665, theta=0.0
% INFO    : Bus 5177	: V=1.03679577, theta=-38.6477756 -> V=1.0079355, theta=0.0
% INFO    : Bus 5178	: V=1.01741399, theta=-45.900509 -> V=1.0079355, theta=0.0
% INFO    : Bus 5179	: V=1.04013093, theta=-14.7920418 -> V=0.999999, theta=0.0
% INFO    : Bus 5180	: V=1.03251462, theta=-39.1841842 -> V=1.022224, theta=0.0
% INFO    : Bus 5181	: V=1.06155353, theta=-17.4445036 -> V=1.0000025, theta=0.0
% INFO    : Bus 5182	: V=1.05824258, theta=-19.4827941 -> V=1.024684, theta=0.0
% INFO    : Bus 5183	: V=1.03675894, theta=-34.4145413 -> V=1.022224, theta=0.0
% INFO    : Bus 5184	: V=1.06224332, theta=-34.5785295 -> V=1.04444, theta=0.0
% INFO    : Bus 5185	: V=1.04113273, theta=-21.4995597 -> V=1.0000025, theta=0.0
% INFO    : Bus 5186	: V=1.03726889, theta=-34.8413469 -> V=1.022224, theta=0.0
% INFO    : Bus 5187	: V=1.040617, theta=-24.7769772 -> V=1.022224, theta=0.0
% INFO    : Bus 5188	: V=1.03942924, theta=-20.9033581 -> V=1.0222235, theta=0.0
% INFO    : Bus 5189	: V=1.00696861, theta=-11.8772116 -> V=0.999999, theta=0.0
% INFO    : Bus 5190	: V=1.00486236, theta=-7.15788807 -> V=1.0158755, theta=0.0
% INFO    : Bus 5191	: V=1.04456205, theta=-33.4125909 -> V=1.022224, theta=0.0
% INFO    : Bus 5192	: V=1.02461238, theta=-36.6507349 -> V=1.022224, theta=0.0
% INFO    : Bus 5193	: V=1.04298413, theta=-12.6228115 -> V=0.999999, theta=0.0
% INFO    : Bus 5194	: V=1.07596817, theta=3.86447727 -> V=0.9888895, theta=0.0
% INFO    : Bus 5195	: V=1.02725409, theta=-23.8014485 -> V=1.0000025, theta=0.0
% INFO    : Bus 5196	: V=1.02610689, theta=-19.7695952 -> V=1.0158755, theta=0.0
% INFO    : Bus 5197	: V=1.04750758, theta=-12.0141402 -> V=1.001849, theta=0.0
% INFO    : Bus 5198	: V=1.01967329, theta=-8.66876191 -> V=0.999999, theta=0.0
% INFO    : Bus 5199	: V=1.02598801, theta=-5.49570672 -> V=1.0111115, theta=0.0
% INFO    : Bus 5200	: V=1.03149561, theta=-16.1561055 -> V=1.015872, theta=0.0
% INFO    : Bus 5201	: V=1.02547096, theta=-18.598667 -> V=1.015872, theta=0.0
% INFO    : Bus 5202	: V=1.04646848, theta=-16.7372454 -> V=1.046665, theta=0.0
% INFO    : Bus 5203	: V=0.995535827, theta=-21.2601669 -> V=1.015872, theta=0.0
% INFO    : Bus 5204	: V=1.04594948, theta=-28.3166176 -> V=1.0000025, theta=0.0
% INFO    : Bus 5205	: V=1.07824626, theta=-16.4486838 -> V=1.0000025, theta=0.0
% INFO    : Bus 5206	: V=1.07288297, theta=-22.6882333 -> V=1.030744, theta=0.0
% INFO    : Bus 5207	: V=1.03278107, theta=-23.6163952 -> V=1.0000025, theta=0.0
% INFO    : Bus 5208	: V=1.03329467, theta=-23.6095149 -> V=1.0000025, theta=0.0
% INFO    : Bus 5209	: V=1.01581056, theta=-21.6418999 -> V=1.0000025, theta=0.0
% INFO    : Bus 5210	: V=1.07122822, theta=-25.1867931 -> V=1.046665, theta=0.0
% INFO    : Bus 5211	: V=1.0312906, theta=3.13003914 -> V=1.0158755, theta=0.0
% INFO    : Bus 5212	: V=1.01762779, theta=-21.9785339 -> V=1.0000025, theta=0.0
% INFO    : Bus 5213	: V=1.07154719, theta=-25.1694227 -> V=1.04682, theta=0.0
% INFO    : Bus 5214	: V=1.01068533, theta=-22.6309663 -> V=1.0000025, theta=0.0
% INFO    : Bus 5215	: V=1.04050608, theta=-54.8425731 -> V=1.0079355, theta=0.0
% INFO    : Bus 5216	: V=1.04190337, theta=-27.3561494 -> V=1.0000025, theta=0.0
% INFO    : Bus 5217	: V=1.05355692, theta=-24.7414703 -> V=1.0000025, theta=0.0
% INFO    : Bus 5218	: V=1.05487327, theta=-24.5277179 -> V=1.0000025, theta=0.0
% INFO    : Bus 5219	: V=1.01544474, theta=-27.0628915 -> V=1.0000025, theta=0.0
% INFO    : Bus 5220	: V=1.059842, theta=-31.7989869 -> V=1.027779, theta=0.0
% INFO    : Bus 5221	: V=1.01568855, theta=-27.1077096 -> V=1.0000025, theta=0.0
% INFO    : Bus 5222	: V=1.02421143, theta=-17.2046705 -> V=1.015872, theta=0.0
% INFO    : Bus 5223	: V=1.00527934, theta=-28.985487 -> V=1.0000025, theta=0.0
% INFO    : Bus 5224	: V=1.02926659, theta=-25.3236319 -> V=1.0000025, theta=0.0
% INFO    : Bus 5225	: V=1.02770972, theta=-6.08757891 -> V=1.0111115, theta=0.0
% INFO    : Bus 5226	: V=1.02427706, theta=-26.2325772 -> V=1.0000025, theta=0.0
% INFO    : Bus 5227	: V=1.02427297, theta=-26.3053982 -> V=1.0000025, theta=0.0
% INFO    : Bus 5228	: V=1.02668253, theta=-25.7962337 -> V=1.0158755, theta=0.0
% INFO    : Bus 5229	: V=1.06175614, theta=-10.1315812 -> V=1.003274, theta=0.0
% INFO    : Bus 5230	: V=1.03485267, theta=-28.9418391 -> V=1.022224, theta=0.0
% INFO    : Bus 5231	: V=1.03836308, theta=-20.061018 -> V=1.022224, theta=0.0
% INFO    : Bus 5232	: V=1.02610315, theta=-7.53970783 -> V=0.999999, theta=0.0
% INFO    : Bus 5233	: V=1.06195945, theta=-20.7007301 -> V=1.0222235, theta=0.0
% INFO    : Bus 5234	: V=0.979762176, theta=-10.3538381 -> V=0.9444445, theta=0.0
% INFO    : Bus 5235	: V=1.06069956, theta=-16.3572254 -> V=1.073685, theta=0.0
% INFO    : Bus 5236	: V=1.00169929, theta=-9.8728844 -> V=0.999999, theta=0.0
% INFO    : Bus 5237	: V=1.02884931, theta=-24.2000915 -> V=1.022224, theta=0.0
% INFO    : Bus 5238	: V=1.02863042, theta=2.97648397 -> V=1.0158755, theta=0.0
% INFO    : Bus 5239	: V=1.05293076, theta=-21.7189793 -> V=1.0000015, theta=0.0
% INFO    : Bus 5240	: V=1.01847143, theta=-30.4213236 -> V=1.022224, theta=0.0
% INFO    : Bus 5241	: V=1.02455352, theta=-25.7765911 -> V=1.0000005, theta=0.0
% INFO    : Bus 5242	: V=1.0237306, theta=-25.709099 -> V=1.0000005, theta=0.0
% INFO    : Bus 5243	: V=1.02479104, theta=-10.237938 -> V=0.999999, theta=0.0
% INFO    : Bus 5244	: V=1.04886229, theta=-32.2887149 -> V=1.0108055, theta=0.0
% INFO    : Bus 5245	: V=1.02551704, theta=-14.7641367 -> V=1.015872, theta=0.0
% INFO    : Bus 5246	: V=1.03817868, theta=-6.84633761 -> V=1.0158755, theta=0.0
% INFO    : Bus 5247	: V=1.05206654, theta=-9.77496704 -> V=1.003335, theta=0.0
% INFO    : Bus 5248	: V=1.03426272, theta=-17.1797804 -> V=0.999999, theta=0.0
% INFO    : Bus 5249	: V=1.0175999, theta=0.753197496 -> V=1.0158755, theta=0.0
% INFO    : Bus 5250	: V=1.0230919, theta=-15.2749135 -> V=1.015872, theta=0.0
% INFO    : Bus 5251	: V=1.01150418, theta=-23.3420521 -> V=1.022224, theta=0.0
% INFO    : Bus 5252	: V=1.0203977, theta=-31.8510697 -> V=1.0000025, theta=0.0
% INFO    : Bus 5253	: V=1.05347068, theta=-23.9794715 -> V=1.046665, theta=0.0
% INFO    : Bus 5254	: V=1.05342743, theta=-24.0032055 -> V=1.046665, theta=0.0
% INFO    : Bus 5255	: V=1.06556517, theta=-30.6036623 -> V=1.04444, theta=0.0
% INFO    : Bus 5256	: V=1.06952985, theta=-43.58296 -> V=1.04444, theta=0.0
% INFO    : Bus 5257	: V=1.04825958, theta=-52.5416966 -> V=1.0079355, theta=0.0
% INFO    : Bus 5258	: V=1.05511216, theta=-22.1101317 -> V=1.0000025, theta=0.0
% INFO    : Bus 5259	: V=1.05916628, theta=-30.3123652 -> V=1.027779, theta=0.0
% INFO    : Bus 5260	: V=1.06384864, theta=-13.471228 -> V=1.005558, theta=0.0
% INFO    : Bus 5261	: V=1.06083291, theta=-14.2791398 -> V=1.005558, theta=0.0
% INFO    : Bus 5262	: V=1.09494625, theta=-11.592931 -> V=1.0474, theta=0.0
% INFO    : Bus 5263	: V=1.05112355, theta=-22.6265141 -> V=1.0000025, theta=0.0
% INFO    : Bus 5264	: V=1.03836145, theta=-26.7893596 -> V=1.000001, theta=0.0
% INFO    : Bus 5265	: V=1.02993852, theta=-6.8460043 -> V=1.0111115, theta=0.0
% INFO    : Bus 5266	: V=1.01143263, theta=-13.3268979 -> V=0.999999, theta=0.0
% INFO    : Bus 5267	: V=1.01880533, theta=-16.671291 -> V=1.015872, theta=0.0
% INFO    : Bus 5268	: V=1.02127108, theta=-10.3273039 -> V=0.999999, theta=0.0
% INFO    : Bus 5269	: V=1.02139996, theta=-9.25885993 -> V=0.999999, theta=0.0
% INFO    : Bus 5270	: V=1.04016702, theta=-31.4861445 -> V=1.027779, theta=0.0
% INFO    : Bus 5271	: V=1.00522066, theta=-11.7583139 -> V=1.015872, theta=0.0
% INFO    : Bus 5272	: V=1.03004445, theta=-13.1358764 -> V=0.999999, theta=0.0
% INFO    : Bus 5273	: V=1.02178036, theta=-32.0927949 -> V=1.0000005, theta=0.0
% INFO    : Bus 5274	: V=1.03917108, theta=-19.8088257 -> V=1.0158755, theta=0.0
% INFO    : Bus 5275	: V=1.05695596, theta=-27.6607239 -> V=1.027779, theta=0.0
% INFO    : Bus 5276	: V=1.05172662, theta=-21.3573225 -> V=1.022224, theta=0.0
% INFO    : Bus 5277	: V=1.06679797, theta=-7.34667369 -> V=1.0111115, theta=0.0
% INFO    : Bus 5278	: V=1.02456654, theta=-26.5860364 -> V=1.0000025, theta=0.0
% INFO    : Bus 5279	: V=1.01031755, theta=-25.5178139 -> V=1.0000025, theta=0.0
% INFO    : Bus 5280	: V=1.02433088, theta=-26.5705072 -> V=1.0000025, theta=0.0
% INFO    : Bus 5281	: V=1.01179914, theta=-25.4069259 -> V=1.0000025, theta=0.0
% INFO    : Bus 5282	: V=1.04001792, theta=-9.9833645 -> V=0.9933315, theta=0.0
% INFO    : Bus 5283	: V=1.05055744, theta=-13.3932106 -> V=0.9888895, theta=0.0
% INFO    : Bus 5284	: V=1.00521959, theta=-11.7574484 -> V=1.015872, theta=0.0
% INFO    : Bus 5285	: V=1.01897325, theta=-11.1523756 -> V=1.015872, theta=0.0
% INFO    : Bus 5286	: V=1.01886562, theta=-8.95756901 -> V=1.015872, theta=0.0
% INFO    : Bus 5287	: V=1.05499046, theta=-19.2873264 -> V=1.005558, theta=0.0
% INFO    : Bus 5288	: V=1.04058114, theta=-11.1241861 -> V=0.999999, theta=0.0
% INFO    : Bus 5289	: V=1.05776093, theta=-21.1127347 -> V=1.0222235, theta=0.0
% INFO    : Bus 5290	: V=1.0131908, theta=-14.9363124 -> V=1.015872, theta=0.0
% INFO    : Bus 5291	: V=1.02956685, theta=-12.6090247 -> V=1.0158755, theta=0.0
% INFO    : Bus 5292	: V=1.01095645, theta=-22.5619879 -> V=1.015872, theta=0.0
% INFO    : Bus 5293	: V=1.03999229, theta=-24.8214287 -> V=1.0000025, theta=0.0
% INFO    : Bus 5294	: V=1.04682103, theta=-23.894417 -> V=1.0000025, theta=0.0
% INFO    : Bus 5295	: V=0.987987016, theta=-25.0969752 -> V=1.0158755, theta=0.0
% INFO    : Bus 5296	: V=0.98797256, theta=-25.0995563 -> V=1.0158755, theta=0.0
% INFO    : Bus 5297	: V=1.04033035, theta=-20.1943476 -> V=1.0222235, theta=0.0
% INFO    : Bus 5298	: V=1.04844828, theta=-29.343188 -> V=1.027779, theta=0.0
% INFO    : Bus 5299	: V=1.07242751, theta=-36.3531659 -> V=1.032089, theta=0.0
% INFO    : Bus 5300	: V=1.01213481, theta=-22.4285504 -> V=1.015872, theta=0.0
% INFO    : Bus 5301	: V=1.04674564, theta=-23.7345901 -> V=1.022224, theta=0.0
% INFO    : Bus 5302	: V=1.05770309, theta=-11.9826508 -> V=0.9888895, theta=0.0
% INFO    : Bus 5303	: V=1.02286255, theta=-34.431785 -> V=1.022224, theta=0.0
% INFO    : Bus 5304	: V=1.01970403, theta=-27.3413095 -> V=1.0000005, theta=0.0
% INFO    : Bus 5305	: V=1.05598361, theta=-24.9260374 -> V=1.0000025, theta=0.0
% INFO    : Bus 5306	: V=1.06522085, theta=-22.5959658 -> V=1.027779, theta=0.0
% INFO    : Bus 5307	: V=1.02597361, theta=-2.83794976 -> V=1.0158755, theta=0.0
% INFO    : Bus 5308	: V=1.03525457, theta=-10.6748267 -> V=0.999999, theta=0.0
% INFO    : Bus 5309	: V=1.07971026, theta=-14.4461462 -> V=1.046665, theta=0.0
% INFO    : Bus 5310	: V=1.03402042, theta=-15.9277386 -> V=1.0158755, theta=0.0
% INFO    : Bus 5311	: V=1.06313698, theta=-37.0444741 -> V=1.04444, theta=0.0
% INFO    : Bus 5312	: V=1.06498739, theta=-11.101031 -> V=0.9933315, theta=0.0
% INFO    : Bus 5313	: V=1.03223954, theta=-19.069574 -> V=1.022224, theta=0.0
% INFO    : Bus 5314	: V=1.04153963, theta=-23.2911431 -> V=0.999999, theta=0.0
% INFO    : Bus 5315	: V=1.03785982, theta=-18.692115 -> V=0.999999, theta=0.0
% INFO    : Bus 5316	: V=1.02183258, theta=-11.3756421 -> V=0.999999, theta=0.0
% INFO    : Bus 5317	: V=1.0441532, theta=-25.9930453 -> V=1.027779, theta=0.0
% INFO    : Bus 5318	: V=1.03300642, theta=-24.6296051 -> V=1.027779, theta=0.0
% INFO    : Bus 5319	: V=1.00696819, theta=-33.7502243 -> V=1.0000005, theta=0.0
% INFO    : Bus 5320	: V=1.0496784, theta=-30.1062168 -> V=1.0027655, theta=0.0
% INFO    : Bus 5321	: V=1.07366259, theta=-25.0360053 -> V=1.046665, theta=0.0
% INFO    : Bus 5322	: V=1.08675129, theta=-13.6919519 -> V=1.046665, theta=0.0
% INFO    : Bus 5323	: V=1.03279364, theta=-15.8327776 -> V=1.0000015, theta=0.0
% INFO    : Bus 5324	: V=1.05600005, theta=-5.82839557 -> V=0.9888895, theta=0.0
% INFO    : Bus 5325	: V=1.04114745, theta=-21.5124305 -> V=1.0000025, theta=0.0
% INFO    : Bus 5326	: V=1.06399091, theta=-20.3070538 -> V=1.04444, theta=0.0
% INFO    : Bus 5327	: V=1.06767007, theta=-22.9124513 -> V=1.0000025, theta=0.0
% INFO    : Bus 5328	: V=1.0547548, theta=-41.6855785 -> V=1.022224, theta=0.0
% INFO    : Bus 5329	: V=1.07010195, theta=-19.6380958 -> V=1.005558, theta=0.0
% INFO    : Bus 5330	: V=1.00992039, theta=-22.1181175 -> V=1.015872, theta=0.0
% INFO    : Bus 5331	: V=1.03833909, theta=-21.2891319 -> V=1.0222235, theta=0.0
% INFO    : Bus 5332	: V=1.02669057, theta=-18.4724852 -> V=1.015872, theta=0.0
% INFO    : Bus 5333	: V=1.04763209, theta=-27.1976374 -> V=1.027779, theta=0.0
% INFO    : Bus 5334	: V=1.02447825, theta=-26.2949334 -> V=1.0000025, theta=0.0
% INFO    : Bus 5335	: V=1.04890949, theta=-19.0245803 -> V=1.0222235, theta=0.0
% INFO    : Bus 5336	: V=1.03291295, theta=-53.3605462 -> V=1.0079355, theta=0.0
% INFO    : Bus 5337	: V=1.02080499, theta=-0.541233502 -> V=1.0158755, theta=0.0
% INFO    : Bus 5338	: V=1.01570594, theta=-1.12820009 -> V=1.0158755, theta=0.0
% INFO    : Bus 5339	: V=1.01797054, theta=-23.1028181 -> V=1.0000025, theta=0.0
% INFO    : Bus 5340	: V=1.04113634, theta=-24.3703984 -> V=1.0000025, theta=0.0
% INFO    : Bus 5341	: V=1.03567051, theta=-25.8884425 -> V=1.046665, theta=0.0
% INFO    : Bus 5342	: V=1.03551763, theta=-25.9020273 -> V=1.046665, theta=0.0
% INFO    : Bus 5343	: V=1.02467964, theta=-23.938572 -> V=1.0222235, theta=0.0
% INFO    : Bus 5344	: V=1.04126335, theta=-10.6163052 -> V=0.999999, theta=0.0
% INFO    : Bus 5345	: V=1.02886058, theta=-30.3653228 -> V=1.022224, theta=0.0
% INFO    : Bus 5346	: V=1.02888069, theta=-9.7255296 -> V=0.999999, theta=0.0
% INFO    : Bus 5347	: V=1.0546647, theta=-20.5867417 -> V=1.0000015, theta=0.0
% INFO    : Bus 5348	: V=1.0617183, theta=-10.1429845 -> V=1.003259, theta=0.0
% INFO    : Bus 5349	: V=1.02159796, theta=-32.7716795 -> V=1.0000005, theta=0.0
% INFO    : Bus 5350	: V=1.03622447, theta=-21.9182694 -> V=1.022224, theta=0.0
% INFO    : Bus 5351	: V=1.04607144, theta=-21.1411226 -> V=1.0000025, theta=0.0
% INFO    : Bus 5352	: V=1.02812198, theta=-31.94915 -> V=1.022224, theta=0.0
% INFO    : Bus 5353	: V=1.04556581, theta=-22.8435746 -> V=1.005558, theta=0.0
% INFO    : Bus 5354	: V=1.04212836, theta=-19.2674648 -> V=1.0000025, theta=0.0
% INFO    : Bus 5355	: V=1.07496823, theta=-27.8981722 -> V=1.04744, theta=0.0
% INFO    : Bus 5356	: V=1.07460943, theta=-27.9346528 -> V=1.04726, theta=0.0
% INFO    : Bus 5357	: V=1.05768103, theta=-2.96336634 -> V=1.0000015, theta=0.0
% INFO    : Bus 5358	: V=1.02792335, theta=-18.9098432 -> V=0.999999, theta=0.0
% INFO    : Bus 5359	: V=1.07303891, theta=-20.2380152 -> V=1.005558, theta=0.0
% INFO    : Bus 5360	: V=1.07611708, theta=-18.3267738 -> V=1.0222235, theta=0.0
% INFO    : Bus 5361	: V=1.04488337, theta=-22.3871348 -> V=1.022224, theta=0.0
% INFO    : Bus 5362	: V=1.04996584, theta=-28.9557286 -> V=1.027779, theta=0.0
% INFO    : Bus 5363	: V=1.06587319, theta=-24.0952931 -> V=1.046665, theta=0.0
% INFO    : Bus 5364	: V=1.06351653, theta=-23.9593763 -> V=1.046665, theta=0.0
% INFO    : Bus 5365	: V=1.0769651, theta=4.13985418 -> V=0.9888895, theta=0.0
% INFO    : Bus 5366	: V=1.0212947, theta=-28.1930542 -> V=1.0000005, theta=0.0
% INFO    : Bus 5367	: V=1.03508544, theta=-20.725814 -> V=1.0000025, theta=0.0
% INFO    : Bus 5368	: V=1.02806822, theta=-15.7146438 -> V=1.0158755, theta=0.0
% INFO    : Bus 5369	: V=1.02256012, theta=-32.2854227 -> V=1.0000005, theta=0.0
% INFO    : Bus 5370	: V=1.03956732, theta=-36.8544005 -> V=1.022224, theta=0.0
% INFO    : Bus 5371	: V=1.04345275, theta=-39.1754456 -> V=1.022224, theta=0.0
% INFO    : Bus 5372	: V=1.04321945, theta=-16.3872775 -> V=1.0158755, theta=0.0
% INFO    : Bus 5373	: V=1.01398191, theta=-11.750941 -> V=0.999999, theta=0.0
% INFO    : Bus 5374	: V=1.00624547, theta=-20.7760624 -> V=1.0158755, theta=0.0
% INFO    : Bus 5375	: V=1.06464935, theta=-14.3519796 -> V=1.04444, theta=0.0
% INFO    : Bus 5376	: V=1.05293106, theta=-10.6235785 -> V=0.999999, theta=0.0
% INFO    : Bus 5377	: V=1.05451797, theta=-25.1583969 -> V=1.0000025, theta=0.0
% INFO    : Bus 5378	: V=1.04108275, theta=-11.7383572 -> V=1.0158755, theta=0.0
% INFO    : Bus 5379	: V=1.05657794, theta=-25.0282627 -> V=1.0000025, theta=0.0
% INFO    : Bus 5380	: V=1.06419866, theta=-14.4087477 -> V=1.04444, theta=0.0
% INFO    : Bus 5381	: V=0.943823998, theta=-6.89959063 -> V=0.9444445, theta=0.0
% INFO    : Bus 5382	: V=1.03248368, theta=-26.4436393 -> V=1.022224, theta=0.0
% INFO    : Bus 5383	: V=1.04659219, theta=-26.6268039 -> V=1.022224, theta=0.0
% INFO    : Bus 5384	: V=1.06917377, theta=-2.32623248 -> V=0.9888895, theta=0.0
% INFO    : Bus 5385	: V=1.05205477, theta=-24.8550167 -> V=1.046665, theta=0.0
% INFO    : Bus 5386	: V=1.0500469, theta=-18.1477109 -> V=1.0222235, theta=0.0
% INFO    : Bus 5387	: V=1.05422117, theta=-18.577589 -> V=1.0222235, theta=0.0
% INFO    : Bus 5388	: V=1.03443103, theta=-11.8301171 -> V=0.999999, theta=0.0
% INFO    : Bus 5389	: V=1.04146374, theta=-39.2549702 -> V=1.022224, theta=0.0
% INFO    : Bus 5390	: V=1.06443955, theta=-18.5068754 -> V=1.007019, theta=0.0
% INFO    : Bus 5391	: V=1.07345022, theta=-23.8861104 -> V=1.04444, theta=0.0
% INFO    : Bus 5392	: V=1.05670421, theta=-20.1529476 -> V=1.022224, theta=0.0
% INFO    : Bus 5393	: V=1.02918644, theta=-16.1027786 -> V=0.999999, theta=0.0
% INFO    : Bus 5394	: V=1.0556177, theta=-17.9462504 -> V=1.022224, theta=0.0
% INFO    : Bus 5395	: V=1.05220082, theta=-7.25259405 -> V=1.0111115, theta=0.0
% INFO    : Bus 5396	: V=1.05050983, theta=-20.9899811 -> V=1.0000025, theta=0.0
% INFO    : Bus 5397	: V=1.0277939, theta=-51.6488299 -> V=1.0079355, theta=0.0
% INFO    : Bus 5398	: V=1.01669838, theta=-14.0395769 -> V=1.0158755, theta=0.0
% INFO    : Bus 5399	: V=1.01576375, theta=-19.2275442 -> V=1.0158755, theta=0.0
% INFO    : Bus 5400	: V=1.04338156, theta=-33.9227207 -> V=1.022224, theta=0.0
% INFO    : Bus 5401	: V=1.0156532, theta=-22.893063 -> V=1.0000025, theta=0.0
% INFO    : Bus 5402	: V=1.0436176, theta=-41.8668326 -> V=1.022224, theta=0.0
% INFO    : Bus 5403	: V=1.0242914, theta=-36.9234847 -> V=1.022224, theta=0.0
% INFO    : Bus 5404	: V=1.05557135, theta=-23.563814 -> V=1.027779, theta=0.0
% INFO    : Bus 5405	: V=1.03537037, theta=-32.5689042 -> V=1.0042955, theta=0.0
% INFO    : Bus 5406	: V=0.964816375, theta=-8.10436376 -> V=0.9444445, theta=0.0
% INFO    : Bus 5407	: V=1.05632149, theta=-13.8559884 -> V=0.9933315, theta=0.0
% INFO    : Bus 5408	: V=1.02759416, theta=-3.79702385 -> V=1.0158755, theta=0.0
% INFO    : Bus 5409	: V=0.989822879, theta=-25.9111365 -> V=1.0000025, theta=0.0
% INFO    : Bus 5410	: V=1.01023887, theta=-14.5892672 -> V=1.0079355, theta=0.0
% INFO    : Bus 5411	: V=1.02698108, theta=-7.93753174 -> V=0.999999, theta=0.0
% INFO    : Bus 5412	: V=1.07370252, theta=-27.3023418 -> V=1.04678, theta=0.0
% INFO    : Bus 5413	: V=1.0287164, theta=-43.7197074 -> V=1.0079355, theta=0.0
% INFO    : Bus 5414	: V=1.07301599, theta=-27.3524133 -> V=1.046665, theta=0.0
% INFO    : Bus 5415	: V=1.03006454, theta=-5.24523915 -> V=1.0158755, theta=0.0
% INFO    : Bus 5416	: V=1.0555299, theta=-23.1570248 -> V=1.005558, theta=0.0
% INFO    : Bus 5417	: V=1.01352102, theta=-6.41260966 -> V=1.0158755, theta=0.0
% INFO    : Bus 5418	: V=1.07881456, theta=-4.19414409 -> V=0.9888895, theta=0.0
% INFO    : Bus 5419	: V=1.02551458, theta=1.9305902 -> V=1.0158755, theta=0.0
% INFO    : Bus 5420	: V=1.07584085, theta=3.81105781 -> V=0.9888895, theta=0.0
% INFO    : Bus 5421	: V=1.02100674, theta=-10.207998 -> V=1.015872, theta=0.0
% INFO    : Bus 5422	: V=1.06566883, theta=-18.1154614 -> V=1.005558, theta=0.0
% INFO    : Bus 5423	: V=1.05185914, theta=-23.4963119 -> V=1.0000025, theta=0.0
% INFO    : Bus 5424	: V=1.02511817, theta=-31.2893697 -> V=1.0000005, theta=0.0
% INFO    : Bus 5425	: V=1.03354812, theta=-26.2030916 -> V=1.022224, theta=0.0
% INFO    : Bus 5426	: V=1.0399466, theta=-30.5210448 -> V=1.022224, theta=0.0
% INFO    : Bus 5427	: V=1.05917993, theta=-42.7697896 -> V=1.022224, theta=0.0
% INFO    : Bus 5428	: V=1.03318044, theta=-21.0651469 -> V=1.022224, theta=0.0
% INFO    : Bus 5429	: V=1.02206015, theta=-29.5694205 -> V=1.0000005, theta=0.0
% INFO    : Bus 5430	: V=1.02075644, theta=-29.7921706 -> V=1.0000005, theta=0.0
% INFO    : Bus 5431	: V=1.04183741, theta=-12.1467507 -> V=1.046665, theta=0.0
% INFO    : Bus 5432	: V=1.04901929, theta=-10.2889539 -> V=1.0111115, theta=0.0
% INFO    : Bus 5433	: V=1.04057481, theta=-26.2538269 -> V=1.0000025, theta=0.0
% INFO    : Bus 5434	: V=1.04434156, theta=-30.5578315 -> V=1.022224, theta=0.0
% INFO    : Bus 5435	: V=1.02504035, theta=-5.92487931 -> V=1.0158755, theta=0.0
% INFO    : Bus 5436	: V=1.03352505, theta=-53.5800198 -> V=1.0079355, theta=0.0
% INFO    : Bus 5437	: V=1.02230594, theta=-58.3371795 -> V=1.0079355, theta=0.0
% INFO    : Bus 5438	: V=1.07676096, theta=-34.8516937 -> V=1.04444, theta=0.0
% INFO    : Bus 5439	: V=1.04517015, theta=-54.1233767 -> V=1.0079355, theta=0.0
% INFO    : Bus 5440	: V=1.03476502, theta=-25.7325342 -> V=1.0000025, theta=0.0
% INFO    : Bus 5441	: V=1.01239331, theta=-22.7137113 -> V=1.0000025, theta=0.0
% INFO    : Bus 5442	: V=1.05227114, theta=-25.5565257 -> V=1.0000025, theta=0.0
% INFO    : Bus 5443	: V=1.04776474, theta=-23.4599471 -> V=1.0000025, theta=0.0
% INFO    : Bus 5444	: V=1.04503991, theta=-24.3177801 -> V=1.0000025, theta=0.0
% INFO    : Bus 5445	: V=1.06012264, theta=-20.7537717 -> V=1.023454, theta=0.0
% INFO    : Bus 5446	: V=1.02995264, theta=-27.1875598 -> V=1.0000025, theta=0.0
% INFO    : Bus 5447	: V=1.06363649, theta=-7.58423154 -> V=1.046665, theta=0.0
% INFO    : Bus 5448	: V=1.020912, theta=-30.3285556 -> V=1.0000025, theta=0.0
% INFO    : Bus 5449	: V=1.04222143, theta=-36.4514008 -> V=1.022224, theta=0.0
% INFO    : Bus 5450	: V=1.06233479, theta=-28.133495 -> V=1.0000025, theta=0.0
% INFO    : Bus 5451	: V=1.03904426, theta=-24.5475031 -> V=1.0000025, theta=0.0
% INFO    : Bus 5452	: V=1.06257192, theta=-24.7317691 -> V=1.046665, theta=0.0
% INFO    : Bus 5453	: V=1.01932492, theta=-2.79680242 -> V=1.0158755, theta=0.0
% INFO    : Bus 5454	: V=1.08296804, theta=-11.5684333 -> V=1.046665, theta=0.0
% INFO    : Bus 5455	: V=1.05141897, theta=-7.58293465 -> V=1.0111115, theta=0.0
% INFO    : Bus 5456	: V=1.01849161, theta=-53.5536851 -> V=1.0079355, theta=0.0
% INFO    : Bus 5457	: V=1.09516772, theta=-11.527698 -> V=1.047365, theta=0.0
% INFO    : Bus 5458	: V=1.0137447, theta=-18.3671568 -> V=1.015872, theta=0.0
% INFO    : Bus 5459	: V=1.04114434, theta=-14.6422719 -> V=0.999999, theta=0.0
% INFO    : Bus 5460	: V=1.01727148, theta=-27.9922218 -> V=1.0000005, theta=0.0
% INFO    : Bus 5461	: V=1.03480396, theta=-25.8141106 -> V=1.0000025, theta=0.0
% INFO    : Bus 5462	: V=1.04584244, theta=-23.9057228 -> V=1.0000025, theta=0.0
% INFO    : Bus 5463	: V=1.05652707, theta=-25.9383518 -> V=1.046665, theta=0.0
% INFO    : Bus 5464	: V=1.03188541, theta=-10.675556 -> V=1.0158755, theta=0.0
% INFO    : Bus 5465	: V=1.05596923, theta=-26.1010884 -> V=1.046665, theta=0.0
% INFO    : Bus 5466	: V=1.02336449, theta=-12.9956361 -> V=0.999999, theta=0.0
% INFO    : Bus 5467	: V=1.04277887, theta=-23.6255962 -> V=0.999999, theta=0.0
% INFO    : Bus 5468	: V=1.02573081, theta=-31.3864667 -> V=1.0000005, theta=0.0
% INFO    : Bus 5469	: V=1.05510683, theta=-14.8036188 -> V=1.0000015, theta=0.0
% INFO    : Bus 5470	: V=1.05779217, theta=-24.0387251 -> V=1.046665, theta=0.0
% INFO    : Bus 5471	: V=1.03982024, theta=-33.1975071 -> V=1.022224, theta=0.0
% INFO    : Bus 5472	: V=1.02691709, theta=-55.5470225 -> V=1.0079355, theta=0.0
% INFO    : Bus 5473	: V=1.04149551, theta=-53.3683243 -> V=1.0079355, theta=0.0
% INFO    : Bus 5474	: V=1.03505407, theta=-11.3523043 -> V=0.999999, theta=0.0
% INFO    : Bus 5475	: V=1.0351233, theta=-11.3441224 -> V=0.999999, theta=0.0
% INFO    : Bus 5476	: V=1.01243861, theta=-27.563346 -> V=1.0000005, theta=0.0
% INFO    : Bus 5477	: V=1.04760323, theta=-21.4338763 -> V=1.022224, theta=0.0
% INFO    : Bus 5478	: V=1.05074543, theta=-16.7440693 -> V=1.001604, theta=0.0
% INFO    : Bus 5479	: V=1.03151323, theta=-36.037759 -> V=1.022224, theta=0.0
% INFO    : Bus 5480	: V=1.03983319, theta=-25.0901918 -> V=1.0000025, theta=0.0
% INFO    : Bus 5481	: V=1.02116325, theta=-3.25198564 -> V=1.0158755, theta=0.0
% INFO    : Bus 5482	: V=1.0208978, theta=-3.26687158 -> V=1.0158755, theta=0.0
% INFO    : Bus 5483	: V=1.0434662, theta=-25.8479946 -> V=1.0000025, theta=0.0
% INFO    : Bus 5484	: V=1.07668124, theta=-2.6136958 -> V=0.9888895, theta=0.0
% INFO    : Bus 5485	: V=1.03087615, theta=-16.1345004 -> V=1.0158755, theta=0.0
% INFO    : Bus 5486	: V=1.06677983, theta=1.76437271 -> V=0.9888895, theta=0.0
% INFO    : Bus 5487	: V=1.05424678, theta=-15.1128565 -> V=0.9888895, theta=0.0
% INFO    : Bus 5488	: V=1.02549775, theta=-24.0951992 -> V=1.0222235, theta=0.0
% INFO    : Bus 5489	: V=1.0425451, theta=-29.1014712 -> V=1.022224, theta=0.0
% INFO    : Bus 5490	: V=1.07288168, theta=-22.6882078 -> V=1.030739, theta=0.0
% INFO    : Bus 5491	: V=1.05321784, theta=-33.4381852 -> V=1.027779, theta=0.0
% INFO    : Bus 5492	: V=1.01037604, theta=-22.0961802 -> V=1.015872, theta=0.0
% INFO    : Bus 5493	: V=1.03922797, theta=-31.370249 -> V=1.027779, theta=0.0
% INFO    : Bus 5494	: V=1.0267923, theta=-36.6166922 -> V=1.022224, theta=0.0
% INFO    : Bus 5495	: V=1.04264422, theta=-32.0198811 -> V=1.022224, theta=0.0
% INFO    : Bus 5496	: V=1.00759226, theta=-25.3276944 -> V=1.0000005, theta=0.0
% INFO    : Bus 5497	: V=1.02354593, theta=-31.5457946 -> V=1.0000005, theta=0.0
% INFO    : Bus 5498	: V=1.03344479, theta=-19.8888838 -> V=1.0000015, theta=0.0
% INFO    : Bus 5499	: V=1.03112929, theta=-8.70544093 -> V=1.0111115, theta=0.0
% INFO    : Bus 5500	: V=1.05041211, theta=-32.3087263 -> V=1.0116105, theta=0.0
% INFO    : Bus 5501	: V=1.04672781, theta=-4.57466672 -> V=1.0000015, theta=0.0
% INFO    : Bus 5502	: V=1.05381136, theta=-6.59072226 -> V=0.9888895, theta=0.0
% INFO    : Bus 5503	: V=1.07207622, theta=-25.5526796 -> V=1.046945, theta=0.0
% INFO    : Bus 5504	: V=1.04460995, theta=-14.7539018 -> V=0.999999, theta=0.0
% INFO    : Bus 5505	: V=1.01994353, theta=-24.6179596 -> V=1.0000025, theta=0.0
% INFO    : Bus 5506	: V=1.02189687, theta=-9.10851362 -> V=1.0000015, theta=0.0
% INFO    : Bus 5507	: V=1.04150194, theta=-24.8219363 -> V=1.0000025, theta=0.0
% INFO    : Bus 5508	: V=1.04108322, theta=-24.8718713 -> V=1.0000025, theta=0.0
% INFO    : Bus 5509	: V=1.05302872, theta=-12.2573695 -> V=1.046665, theta=0.0
% INFO    : Bus 5510	: V=1.02882317, theta=-26.0157308 -> V=1.0000005, theta=0.0
% INFO    : Bus 5511	: V=1.03608866, theta=-25.46267 -> V=1.0029305, theta=0.0
% INFO    : Bus 5512	: V=1.01958738, theta=-23.2986685 -> V=1.046665, theta=0.0
% INFO    : Bus 5513	: V=1.01310461, theta=-12.0454755 -> V=0.999999, theta=0.0
% INFO    : Bus 5514	: V=1.03634291, theta=-26.7842258 -> V=1.0000025, theta=0.0
% INFO    : Bus 5515	: V=1.04734531, theta=-24.6429763 -> V=1.0000025, theta=0.0
% INFO    : Bus 5516	: V=1.05339935, theta=-7.40886252 -> V=1.0111115, theta=0.0
% INFO    : Bus 5517	: V=1.0521379, theta=-24.7902016 -> V=1.0000025, theta=0.0
% INFO    : Bus 5518	: V=1.08570844, theta=-22.9371942 -> V=1.046665, theta=0.0
% INFO    : Bus 5519	: V=1.02927252, theta=-28.4542397 -> V=1.022224, theta=0.0
% INFO    : Bus 5520	: V=1.01184103, theta=-33.580507 -> V=1.0000005, theta=0.0
% INFO    : Bus 5521	: V=1.02576699, theta=-18.6767298 -> V=1.0158755, theta=0.0
% INFO    : Bus 5522	: V=1.00665507, theta=-2.26047125 -> V=1.0158755, theta=0.0
% INFO    : Bus 5523	: V=1.0302053, theta=-15.0772144 -> V=1.015872, theta=0.0
% INFO    : Bus 5524	: V=1.0348286, theta=-10.785072 -> V=0.999999, theta=0.0
% INFO    : Bus 5525	: V=1.04343643, theta=-28.3735688 -> V=1.0000025, theta=0.0
% INFO    : Bus 5526	: V=1.01773278, theta=-4.14659023 -> V=1.0158755, theta=0.0
% INFO    : Bus 5527	: V=0.995065352, theta=-22.2173379 -> V=1.0158755, theta=0.0
% INFO    : Bus 5528	: V=0.995090597, theta=-22.2148396 -> V=1.0158755, theta=0.0
% INFO    : Bus 5529	: V=1.05559383, theta=-22.9565511 -> V=1.022224, theta=0.0
% INFO    : Bus 5530	: V=1.01034383, theta=-8.93802101 -> V=0.999999, theta=0.0
% INFO    : Bus 5531	: V=1.06283849, theta=-21.2189859 -> V=1.0000015, theta=0.0
% INFO    : Bus 5532	: V=1.0678205, theta=-21.0178238 -> V=1.0000015, theta=0.0
% INFO    : Bus 5533	: V=1.047053, theta=-10.3217854 -> V=1.001619, theta=0.0
% INFO    : Bus 5534	: V=1.04355628, theta=-24.8313939 -> V=1.0000025, theta=0.0
% INFO    : Bus 5535	: V=1.0503998, theta=-20.9872594 -> V=1.0000025, theta=0.0
% INFO    : Bus 5536	: V=1.09219082, theta=-19.2245603 -> V=1.0333335, theta=0.0
% INFO    : Bus 5537	: V=1.05839311, theta=-20.742302 -> V=1.0000025, theta=0.0
% INFO    : Bus 5538	: V=1.05797018, theta=-20.7203313 -> V=1.0000025, theta=0.0
% INFO    : Bus 5539	: V=1.03119275, theta=-12.9637182 -> V=1.0158755, theta=0.0
% INFO    : Bus 5540	: V=1.0298888, theta=-11.1197217 -> V=0.999999, theta=0.0
% INFO    : Bus 5541	: V=1.02582437, theta=-10.071343 -> V=0.999999, theta=0.0
% INFO    : Bus 5542	: V=1.03402202, theta=-12.5844339 -> V=1.0158755, theta=0.0
% INFO    : Bus 5543	: V=1.04800764, theta=-12.8711204 -> V=1.002359, theta=0.0
% INFO    : Bus 5544	: V=1.04600019, theta=-21.1392124 -> V=1.0000025, theta=0.0
% INFO    : Bus 5545	: V=1.04683889, theta=-22.109726 -> V=1.0222235, theta=0.0
% INFO    : Bus 5546	: V=1.01520433, theta=-10.3408849 -> V=1.015872, theta=0.0
% INFO    : Bus 5547	: V=1.04514033, theta=-22.2935365 -> V=1.0222235, theta=0.0
% INFO    : Bus 5548	: V=1.02534163, theta=-31.2512295 -> V=1.0000005, theta=0.0
% INFO    : Bus 5549	: V=1.03996528, theta=-18.4945336 -> V=0.999999, theta=0.0
% INFO    : Bus 5550	: V=1.05872436, theta=-24.5304174 -> V=1.046665, theta=0.0
% INFO    : Bus 5551	: V=1.05980039, theta=-24.5656898 -> V=1.046665, theta=0.0
% INFO    : Bus 5552	: V=1.04492145, theta=-11.1763066 -> V=0.999999, theta=0.0
% INFO    : Bus 5553	: V=1.02269549, theta=-16.9277745 -> V=1.0000015, theta=0.0
% INFO    : Bus 5554	: V=1.03389589, theta=-22.1203441 -> V=1.0000025, theta=0.0
% INFO    : Bus 5555	: V=1.03412681, theta=-22.1860143 -> V=1.0000025, theta=0.0
% INFO    : Bus 5556	: V=1.05938229, theta=-26.5928232 -> V=1.046665, theta=0.0
% INFO    : Bus 5557	: V=1.04447816, theta=-45.3259647 -> V=1.022224, theta=0.0
% INFO    : Bus 5558	: V=1.02462148, theta=-22.7232342 -> V=0.999999, theta=0.0
% INFO    : Bus 5559	: V=1.06766564, theta=-21.2566165 -> V=1.0000025, theta=0.0
% INFO    : Bus 5560	: V=1.0677262, theta=-21.219546 -> V=1.0000025, theta=0.0
% INFO    : Bus 5561	: V=1.07285861, theta=-18.6372829 -> V=1.0222235, theta=0.0
% INFO    : Bus 5562	: V=1.02773043, theta=-16.6825931 -> V=1.015872, theta=0.0
% INFO    : Bus 5563	: V=0.998683915, theta=-22.3005905 -> V=1.0000025, theta=0.0
% INFO    : Bus 5564	: V=1.00243594, theta=-21.3968682 -> V=1.0000025, theta=0.0
% INFO    : Bus 5565	: V=1.03588222, theta=-14.5003878 -> V=0.999999, theta=0.0
% INFO    : Bus 5566	: V=1.01413579, theta=-28.5940104 -> V=1.0000025, theta=0.0
% INFO    : Bus 5567	: V=1.02961949, theta=-27.6636089 -> V=1.0000025, theta=0.0
% INFO    : Bus 5568	: V=1.02969686, theta=-27.6736738 -> V=1.0000025, theta=0.0
% INFO    : Bus 5569	: V=1.01811242, theta=-22.9681548 -> V=1.0000025, theta=0.0
% INFO    : Bus 5570	: V=1.03908747, theta=-21.1081916 -> V=1.0000015, theta=0.0
% INFO    : Bus 5571	: V=1.04755569, theta=-23.7437656 -> V=1.005558, theta=0.0
% INFO    : Bus 5572	: V=1.0309892, theta=-16.7931415 -> V=0.999999, theta=0.0
% INFO    : Bus 5573	: V=1.01718267, theta=-11.7289325 -> V=1.0079355, theta=0.0
% INFO    : Bus 5574	: V=1.09794837, theta=-18.1685853 -> V=1.0333335, theta=0.0
% INFO    : Bus 5575	: V=1.05353278, theta=-14.9404766 -> V=1.0000015, theta=0.0
% INFO    : Bus 5576	: V=1.05061787, theta=-15.2793158 -> V=1.0158755, theta=0.0
% INFO    : Bus 5577	: V=1.03423602, theta=-24.7288644 -> V=1.027779, theta=0.0
% INFO    : Bus 5578	: V=1.05044076, theta=-52.5299444 -> V=1.0079355, theta=0.0
% INFO    : Bus 5579	: V=1.02097328, theta=-16.773366 -> V=1.015872, theta=0.0
% INFO    : Bus 5580	: V=1.04805816, theta=-29.2745215 -> V=1.027779, theta=0.0
% INFO    : Bus 5581	: V=1.03850607, theta=-26.2721512 -> V=1.0000025, theta=0.0
% INFO    : Bus 5582	: V=1.06840879, theta=-23.3030835 -> V=1.046665, theta=0.0
% INFO    : Bus 5583	: V=1.06042398, theta=-18.8952934 -> V=1.005558, theta=0.0
% INFO    : Bus 5584	: V=1.02182731, theta=-9.41058339 -> V=0.999999, theta=0.0
% INFO    : Bus 5585	: V=1.02936556, theta=-20.2178763 -> V=1.0158755, theta=0.0
% INFO    : Bus 5586	: V=1.02207184, theta=-16.6213843 -> V=1.0158755, theta=0.0
% INFO    : Bus 5587	: V=1.00421846, theta=-18.2929348 -> V=1.015872, theta=0.0
% INFO    : Bus 5588	: V=1.04213873, theta=-19.267685 -> V=1.0000025, theta=0.0
% INFO    : Bus 5589	: V=1.03932299, theta=-26.4501982 -> V=1.0000025, theta=0.0
% INFO    : Bus 5590	: V=1.0409675, theta=-25.6368834 -> V=1.0000025, theta=0.0
% INFO    : Bus 5591	: V=1.04834146, theta=-22.3659946 -> V=1.0000025, theta=0.0
% INFO    : Bus 5592	: V=1.04670365, theta=-22.4940904 -> V=1.0000025, theta=0.0
% INFO    : Bus 5593	: V=1.05005328, theta=-22.2200619 -> V=1.0000025, theta=0.0
% INFO    : Bus 5594	: V=1.03946429, theta=-26.3774443 -> V=1.0000025, theta=0.0
% INFO    : Bus 5595	: V=1.08232385, theta=4.83410984 -> V=0.9897745, theta=0.0
% INFO    : Bus 5596	: V=1.01975343, theta=-23.4365379 -> V=1.015872, theta=0.0
% INFO    : Bus 5597	: V=1.02569328, theta=-52.8344003 -> V=1.0079355, theta=0.0
% INFO    : Bus 5598	: V=1.01594359, theta=-23.8040061 -> V=1.015872, theta=0.0
% INFO    : Bus 5599	: V=1.02419227, theta=-29.0759967 -> V=1.0000025, theta=0.0
% INFO    : Bus 5600	: V=1.03610805, theta=-11.8924415 -> V=0.999999, theta=0.0
% INFO    : Bus 5601	: V=1.06491554, theta=-26.4065237 -> V=1.027779, theta=0.0
% INFO    : Bus 5602	: V=1.03742447, theta=-11.5973735 -> V=0.999999, theta=0.0
% INFO    : Bus 5603	: V=1.06490644, theta=-26.4117697 -> V=1.027779, theta=0.0
% INFO    : Bus 5604	: V=1.02501225, theta=-29.0290447 -> V=1.0000025, theta=0.0
% INFO    : Bus 5605	: V=1.033652, theta=-5.71104143 -> V=1.0158755, theta=0.0
% INFO    : Bus 5606	: V=1.03456203, theta=-5.62841086 -> V=1.0158755, theta=0.0
% INFO    : Bus 5607	: V=1.06101957, theta=-16.2316854 -> V=1.004034, theta=0.0
% INFO    : Bus 5608	: V=1.02298683, theta=-22.5952614 -> V=1.0000025, theta=0.0
% INFO    : Bus 5609	: V=1.02273408, theta=-42.6047862 -> V=1.022224, theta=0.0
% INFO    : Bus 5610	: V=1.01110068, theta=-34.0821878 -> V=1.015872, theta=0.0
% INFO    : Bus 5611	: V=1.01105534, theta=-34.0886048 -> V=1.015872, theta=0.0
% INFO    : Bus 5612	: V=1.03697118, theta=-34.7317376 -> V=1.022224, theta=0.0
% INFO    : Bus 5613	: V=1.01437852, theta=-30.9065515 -> V=1.022224, theta=0.0
% INFO    : Bus 5614	: V=1.02390944, theta=-44.4808733 -> V=1.022224, theta=0.0
% INFO    : Bus 5615	: V=1.01852228, theta=-51.7841479 -> V=1.0079355, theta=0.0
% INFO    : Bus 5616	: V=1.04068681, theta=-17.6516033 -> V=1.0000015, theta=0.0
% INFO    : Bus 5617	: V=1.03021851, theta=-50.6740014 -> V=1.0079355, theta=0.0
% INFO    : Bus 5618	: V=1.03322679, theta=-16.2368746 -> V=1.0158755, theta=0.0
% INFO    : Bus 5619	: V=1.0209729, theta=-16.2991895 -> V=0.999999, theta=0.0
% INFO    : Bus 5620	: V=1.02796418, theta=-9.58932965 -> V=0.999999, theta=0.0
% INFO    : Bus 5621	: V=1.03046525, theta=-39.4736084 -> V=1.022224, theta=0.0
% INFO    : Bus 5622	: V=1.01713242, theta=-55.9656408 -> V=1.0079355, theta=0.0
% INFO    : Bus 5623	: V=1.01374853, theta=-11.7620912 -> V=1.015872, theta=0.0
% INFO    : Bus 5624	: V=1.0392001, theta=-20.9451495 -> V=1.0222235, theta=0.0
% INFO    : Bus 5625	: V=1.0447443, theta=-15.743617 -> V=0.999999, theta=0.0
% INFO    : Bus 5626	: V=1.05246755, theta=-52.2505366 -> V=1.0079355, theta=0.0
% INFO    : Bus 5627	: V=1.04892714, theta=-17.0523093 -> V=0.999999, theta=0.0
% INFO    : Bus 5628	: V=1.0773267, theta=-35.1790964 -> V=1.04444, theta=0.0
% INFO    : Bus 5629	: V=1.00146016, theta=-27.8486809 -> V=1.0000005, theta=0.0
% INFO    : Bus 5630	: V=1.05411223, theta=-28.8874446 -> V=1.027779, theta=0.0
% INFO    : Bus 5631	: V=1.05362589, theta=-18.4681859 -> V=1.0000025, theta=0.0
% INFO    : Bus 5632	: V=1.02334506, theta=-43.4814995 -> V=1.022224, theta=0.0
% INFO    : Bus 5633	: V=1.05362589, theta=-18.4681859 -> V=1.0000025, theta=0.0
% INFO    : Bus 5634	: V=1.05639568, theta=-14.8397767 -> V=1.0000015, theta=0.0
% INFO    : Bus 5635	: V=1.03247028, theta=-39.2510737 -> V=1.022224, theta=0.0
% INFO    : Bus 5636	: V=1.064764, theta=-11.2326242 -> V=1.072365, theta=0.0
% INFO    : Bus 5637	: V=1.04387496, theta=-10.5035684 -> V=1.000084, theta=0.0
% INFO    : Bus 5638	: V=1.00878678, theta=-17.2301446 -> V=1.0199985, theta=0.0
% INFO    : Bus 5639	: V=1.04182725, theta=-10.5756103 -> V=0.999999, theta=0.0
% INFO    : Bus 5640	: V=1.03327245, theta=-31.7995077 -> V=1.022224, theta=0.0
% INFO    : Bus 5641	: V=1.02592095, theta=-7.55744689 -> V=0.999999, theta=0.0
% INFO    : Bus 5642	: V=1.05776543, theta=-29.6020415 -> V=1.0000025, theta=0.0
% INFO    : Bus 5643	: V=1.02525131, theta=-12.8008214 -> V=1.015872, theta=0.0
% INFO    : Bus 5644	: V=1.04278084, theta=-23.6256395 -> V=0.999999, theta=0.0
% INFO    : Bus 5645	: V=1.03171724, theta=-12.0556738 -> V=0.999999, theta=0.0
% INFO    : Bus 5646	: V=1.05087689, theta=-24.0712638 -> V=1.022224, theta=0.0
% INFO    : Bus 5647	: V=1.03204957, theta=-14.1030909 -> V=0.999999, theta=0.0
% INFO    : Bus 5648	: V=1.03937688, theta=-13.4051921 -> V=0.999999, theta=0.0
% INFO    : Bus 5649	: V=1.05600384, theta=-15.6663766 -> V=1.046665, theta=0.0
% INFO    : Bus 5650	: V=1.0541839, theta=-10.5288191 -> V=0.9888895, theta=0.0
% INFO    : Bus 5651	: V=1.02101335, theta=-11.148481 -> V=0.999999, theta=0.0
% INFO    : Bus 5652	: V=1.02934262, theta=-8.62959494 -> V=0.999999, theta=0.0
% INFO    : Bus 5653	: V=1.04563701, theta=-16.9719154 -> V=1.0000015, theta=0.0
% INFO    : Bus 5654	: V=1.06110078, theta=-13.0495565 -> V=0.9933315, theta=0.0
% INFO    : Bus 5655	: V=1.04006742, theta=-21.906787 -> V=1.005558, theta=0.0
% INFO    : Bus 5656	: V=1.07508835, theta=-29.3775566 -> V=1.04444, theta=0.0
% INFO    : Bus 5657	: V=1.04970202, theta=-15.6135627 -> V=1.046665, theta=0.0
% INFO    : Bus 5658	: V=1.02516198, theta=-10.0883322 -> V=0.999999, theta=0.0
% INFO    : Bus 5659	: V=1.05054277, theta=-32.3107507 -> V=1.0116855, theta=0.0
% INFO    : Bus 5660	: V=1.02517351, theta=-28.6723608 -> V=1.0000005, theta=0.0
% INFO    : Bus 5661	: V=1.05149677, theta=-5.90256679 -> V=1.0111115, theta=0.0
% INFO    : Bus 5662	: V=1.02233212, theta=-22.8898811 -> V=1.0000025, theta=0.0
% INFO    : Bus 5663	: V=1.01510335, theta=-11.615746 -> V=1.015872, theta=0.0
% INFO    : Bus 5664	: V=1.01480533, theta=-30.0360992 -> V=1.0000005, theta=0.0
% INFO    : Bus 5665	: V=1.05156042, theta=-38.3037614 -> V=1.022224, theta=0.0
% INFO    : Bus 5666	: V=1.03525567, theta=-16.7828986 -> V=1.027779, theta=0.0
% INFO    : Bus 5667	: V=1.02039378, theta=-13.4380383 -> V=0.999999, theta=0.0
% INFO    : Bus 5668	: V=1.06951546, theta=-27.8882064 -> V=1.046665, theta=0.0
% INFO    : Bus 5669	: V=1.06616241, theta=-27.493051 -> V=1.046665, theta=0.0
% INFO    : Bus 5670	: V=1.04550978, theta=-30.2003986 -> V=1.022224, theta=0.0
% INFO    : Bus 5671	: V=1.02751192, theta=-8.60685597 -> V=0.999999, theta=0.0
% INFO    : Bus 5672	: V=1.0524784, theta=-23.2507907 -> V=1.022224, theta=0.0
% INFO    : Bus 5673	: V=1.05426387, theta=-22.900375 -> V=1.022224, theta=0.0
% INFO    : Bus 5674	: V=1.0722088, theta=-25.56337 -> V=1.047005, theta=0.0
% INFO    : Bus 5675	: V=1.0575925, theta=-25.1033334 -> V=1.046665, theta=0.0
% INFO    : Bus 5676	: V=1.036465, theta=-14.0301129 -> V=0.999999, theta=0.0
% INFO    : Bus 5677	: V=1.02727647, theta=-27.6666104 -> V=1.0000025, theta=0.0
% INFO    : Bus 5678	: V=1.02740589, theta=-27.6251263 -> V=1.0000025, theta=0.0
% INFO    : Bus 5679	: V=1.02277812, theta=1.99201766 -> V=1.0158755, theta=0.0
% INFO    : Bus 5680	: V=1.02898831, theta=-42.2975741 -> V=1.0079355, theta=0.0
% INFO    : Bus 5681	: V=1.03067513, theta=-42.2056734 -> V=1.0079355, theta=0.0
% INFO    : Bus 5682	: V=1.00831056, theta=-22.859865 -> V=1.015872, theta=0.0
% INFO    : Bus 5683	: V=1.02807485, theta=-22.9755051 -> V=1.0222235, theta=0.0
% INFO    : Bus 5684	: V=1.04367028, theta=-24.5056895 -> V=1.0000025, theta=0.0
% INFO    : Bus 5685	: V=1.04080331, theta=-25.7957217 -> V=1.0233335, theta=0.0
% INFO    : Bus 5686	: V=1.06259515, theta=-12.4318718 -> V=0.9933315, theta=0.0
% INFO    : Bus 5687	: V=1.0408142, theta=-17.6925052 -> V=0.9933315, theta=0.0
% INFO    : Bus 5688	: V=1.01192474, theta=-29.453621 -> V=1.0000005, theta=0.0
% INFO    : Bus 5689	: V=1.0565659, theta=-6.72870723 -> V=1.0111115, theta=0.0
% INFO    : Bus 5690	: V=1.00173815, theta=-12.4316263 -> V=1.015872, theta=0.0
% INFO    : Bus 5691	: V=1.0486447, theta=-23.9600041 -> V=1.0000025, theta=0.0
% INFO    : Bus 5692	: V=1.05414157, theta=-11.57617 -> V=1.046665, theta=0.0
% INFO    : Bus 5693	: V=1.04047892, theta=-22.7257338 -> V=1.022224, theta=0.0
% INFO    : Bus 5694	: V=1.03048583, theta=-15.1687591 -> V=1.015872, theta=0.0
% INFO    : Bus 5695	: V=1.03917198, theta=-34.5071698 -> V=1.022224, theta=0.0
% INFO    : Bus 5696	: V=1.03472005, theta=-19.3767747 -> V=0.999999, theta=0.0
% INFO    : Bus 5697	: V=1.01519293, theta=-33.4691101 -> V=1.0000005, theta=0.0
% INFO    : Bus 5698	: V=1.07356017, theta=3.96290462 -> V=0.9888895, theta=0.0
% INFO    : Bus 5699	: V=1.09323823, theta=-12.0255008 -> V=1.047585, theta=0.0
% INFO    : Bus 5700	: V=1.02351511, theta=-3.43581047 -> V=1.0158755, theta=0.0
% INFO    : Bus 5701	: V=1.04572006, theta=-29.331315 -> V=1.027779, theta=0.0
% INFO    : Bus 5702	: V=1.07297792, theta=3.75469158 -> V=0.9888895, theta=0.0
% INFO    : Bus 5703	: V=1.04654685, theta=-29.3205417 -> V=1.027779, theta=0.0
% INFO    : Bus 5704	: V=1.03652528, theta=-28.7176081 -> V=1.022224, theta=0.0
% INFO    : Bus 5705	: V=1.05041368, theta=-25.3829842 -> V=1.046665, theta=0.0
% INFO    : Bus 5706	: V=1.04054676, theta=-54.8739757 -> V=1.0079355, theta=0.0
% INFO    : Bus 5707	: V=1.01218942, theta=-30.5884277 -> V=1.015872, theta=0.0
% INFO    : Bus 5708	: V=1.03111222, theta=-31.1802802 -> V=1.022224, theta=0.0
% INFO    : Bus 5709	: V=1.02739333, theta=-24.9409964 -> V=1.0158755, theta=0.0
% INFO    : Bus 5710	: V=1.03935705, theta=-14.7017742 -> V=0.999999, theta=0.0
% INFO    : Bus 5711	: V=1.00718285, theta=-25.1946602 -> V=1.022224, theta=0.0
% INFO    : Bus 5712	: V=1.03615513, theta=-34.9793647 -> V=1.022224, theta=0.0
% INFO    : Bus 5713	: V=1.04143488, theta=-36.7460496 -> V=1.022224, theta=0.0
% INFO    : Bus 5714	: V=1.06273213, theta=-2.69130307 -> V=1.05263, theta=0.0
% INFO    : Bus 5715	: V=1.04753162, theta=-10.9930646 -> V=1.0158755, theta=0.0
% INFO    : Bus 5716	: V=1.03972916, theta=-10.7112438 -> V=0.999999, theta=0.0
% INFO    : Bus 5717	: V=1.03248219, theta=-26.4816756 -> V=1.015872, theta=0.0
% INFO    : Bus 5718	: V=1.03725286, theta=-20.6678294 -> V=1.0000015, theta=0.0
% INFO    : Bus 5719	: V=1.01954456, theta=-18.5542458 -> V=1.015872, theta=0.0
% INFO    : Bus 5720	: V=1.01905543, theta=-16.0165957 -> V=1.015872, theta=0.0
% INFO    : Bus 5721	: V=1.01379589, theta=-28.3889905 -> V=1.015872, theta=0.0
% INFO    : Bus 5722	: V=1.05046793, theta=-23.3907652 -> V=1.0000025, theta=0.0
% INFO    : Bus 5723	: V=1.0510198, theta=-19.3273011 -> V=1.0000025, theta=0.0
% INFO    : Bus 5724	: V=1.02140052, theta=1.88135542 -> V=1.0158755, theta=0.0
% INFO    : Bus 5725	: V=1.03515207, theta=-9.50037702 -> V=0.999999, theta=0.0
% INFO    : Bus 5726	: V=1.02451234, theta=1.81516967 -> V=1.0158755, theta=0.0
% INFO    : Bus 5727	: V=1.02169544, theta=-28.7361818 -> V=1.0000025, theta=0.0
% INFO    : Bus 5728	: V=1.04591071, theta=-15.7819543 -> V=0.999999, theta=0.0
% INFO    : Bus 5729	: V=1.04781073, theta=-53.0662672 -> V=1.0079355, theta=0.0
% INFO    : Bus 5730	: V=1.03735417, theta=-44.1598006 -> V=1.022224, theta=0.0
% INFO    : Bus 5731	: V=1.02310081, theta=-55.1875442 -> V=1.0079355, theta=0.0
% INFO    : Bus 5732	: V=1.02152187, theta=-11.9378254 -> V=1.015872, theta=0.0
% INFO    : Bus 5733	: V=1.06407013, theta=-17.1023037 -> V=1.0000025, theta=0.0
% INFO    : Bus 5734	: V=0.939679901, theta=-6.81620277 -> V=0.9444445, theta=0.0
% INFO    : Bus 5735	: V=1.04925451, theta=-16.2094316 -> V=1.046665, theta=0.0
% INFO    : Bus 5736	: V=1.03065598, theta=-22.0135666 -> V=1.0000025, theta=0.0
% INFO    : Bus 5737	: V=0.966357016, theta=-37.9007951 -> V=1.0000025, theta=0.0
% INFO    : Bus 5738	: V=1.02688292, theta=-7.90346811 -> V=0.999999, theta=0.0
% INFO    : Bus 5739	: V=1.03254299, theta=-32.1935273 -> V=1.027779, theta=0.0
% INFO    : Bus 5740	: V=1.04450851, theta=-11.9154528 -> V=0.999999, theta=0.0
% INFO    : Bus 5741	: V=1.04501619, theta=-16.0211944 -> V=1.0158755, theta=0.0
% INFO    : Bus 5742	: V=1.06181292, theta=-14.4054446 -> V=1.0222235, theta=0.0
% INFO    : Bus 5743	: V=1.04531194, theta=-28.9252305 -> V=1.0000025, theta=0.0
% INFO    : Bus 5744	: V=0.952085335, theta=-6.56309711 -> V=0.9444445, theta=0.0
% INFO    : Bus 5745	: V=1.03789735, theta=-25.4965973 -> V=1.0000025, theta=0.0
% INFO    : Bus 5746	: V=1.04709601, theta=-25.1354337 -> V=1.0000025, theta=0.0
% INFO    : Bus 5747	: V=1.04236656, theta=-28.5952505 -> V=1.0000025, theta=0.0
% INFO    : Bus 5748	: V=1.02404265, theta=-20.5964853 -> V=1.0000025, theta=0.0
% INFO    : Bus 5749	: V=1.07825553, theta=-35.5586961 -> V=1.045545, theta=0.0
% INFO    : Bus 5750	: V=1.03045248, theta=-26.274429 -> V=1.0011555, theta=0.0
% INFO    : Bus 5751	: V=1.02060999, theta=-27.4012777 -> V=1.0000025, theta=0.0
% INFO    : Bus 5752	: V=1.0603841, theta=-19.8733673 -> V=1.022474, theta=0.0
% INFO    : Bus 5753	: V=1.03189728, theta=-6.62547435 -> V=1.0158755, theta=0.0
% INFO    : Bus 5754	: V=1.03442643, theta=-38.9836793 -> V=1.0079355, theta=0.0
% INFO    : Bus 5755	: V=1.04965708, theta=-23.6860719 -> V=1.022224, theta=0.0
% INFO    : Bus 5756	: V=1.07352312, theta=-2.13997506 -> V=0.9888895, theta=0.0
% INFO    : Bus 5757	: V=1.03567833, theta=-6.33727615 -> V=1.0158755, theta=0.0
% INFO    : Bus 5758	: V=1.01569386, theta=-46.0477825 -> V=1.0079355, theta=0.0
% INFO    : Bus 5759	: V=1.01809005, theta=-33.5497284 -> V=1.015872, theta=0.0
% INFO    : Bus 5760	: V=1.02923976, theta=-31.33771 -> V=1.015872, theta=0.0
% INFO    : Bus 5761	: V=1.02678533, theta=-22.4919133 -> V=0.999999, theta=0.0
% INFO    : Bus 5762	: V=1.00404856, theta=-28.591561 -> V=1.0000005, theta=0.0
% INFO    : Bus 5763	: V=1.00786257, theta=-27.9198886 -> V=1.0000005, theta=0.0
% INFO    : Bus 5764	: V=1.03264453, theta=-52.4072222 -> V=1.0079355, theta=0.0
% INFO    : Bus 5765	: V=1.00552905, theta=-25.3223403 -> V=1.0000025, theta=0.0
% INFO    : Bus 5766	: V=1.04301421, theta=-30.7436011 -> V=1.027779, theta=0.0
% INFO    : Bus 5767	: V=1.02012805, theta=-14.5340963 -> V=1.0158755, theta=0.0
% INFO    : Bus 5768	: V=1.02367254, theta=-4.02691302 -> V=1.0000015, theta=0.0
% INFO    : Bus 5769	: V=1.02697145, theta=-19.2960654 -> V=1.015872, theta=0.0
% INFO    : Bus 5770	: V=1.04059924, theta=-33.5928436 -> V=1.022224, theta=0.0
% INFO    : Bus 5771	: V=1.01179425, theta=-18.4806868 -> V=0.999999, theta=0.0
% INFO    : Bus 5772	: V=1.07901612, theta=-16.3526063 -> V=1.046665, theta=0.0
% INFO    : Bus 5773	: V=1.0528275, theta=-12.6832078 -> V=1.004439, theta=0.0
% INFO    : Bus 5774	: V=1.02104306, theta=-4.16945152 -> V=1.0000015, theta=0.0
% INFO    : Bus 5775	: V=1.04672655, theta=-4.57463063 -> V=1.0000015, theta=0.0
% INFO    : Bus 5776	: V=1.04105348, theta=-45.3522082 -> V=1.022224, theta=0.0
% INFO    : Bus 5777	: V=1.07801412, theta=-14.6752783 -> V=1.046665, theta=0.0
% INFO    : Bus 5778	: V=1.07173597, theta=-16.2578694 -> V=1.008329, theta=0.0
% INFO    : Bus 5779	: V=1.02761141, theta=-16.3837236 -> V=1.015872, theta=0.0
% INFO    : Bus 5780	: V=1.058, theta=-10.6344842 -> V=0.999999, theta=0.0
% INFO    : Bus 5781	: V=1.02960212, theta=-39.7728891 -> V=1.022224, theta=0.0
% INFO    : Bus 5782	: V=1.00569864, theta=-30.6892372 -> V=1.0000005, theta=0.0
% INFO    : Bus 5783	: V=1.01165614, theta=-11.656519 -> V=1.015872, theta=0.0
% INFO    : Bus 5784	: V=0.95263841, theta=-6.5206668 -> V=0.9444445, theta=0.0
% INFO    : Bus 5785	: V=0.978657828, theta=-4.95047874 -> V=0.9444445, theta=0.0
% INFO    : Bus 5786	: V=1.04814596, theta=-13.3179842 -> V=1.001684, theta=0.0
% INFO    : Bus 5787	: V=1.04469084, theta=-13.5659847 -> V=1.000104, theta=0.0
% INFO    : Bus 5788	: V=1.0154316, theta=-28.9177565 -> V=1.022224, theta=0.0
% INFO    : Bus 5789	: V=1.0529507, theta=-24.4894433 -> V=1.022224, theta=0.0
% INFO    : Bus 5790	: V=1.06089854, theta=-42.9724508 -> V=1.022704, theta=0.0
% INFO    : Bus 5791	: V=1.05897398, theta=-32.8059494 -> V=1.028279, theta=0.0
% INFO    : Bus 5792	: V=1.02326212, theta=-15.8161064 -> V=1.015872, theta=0.0
% INFO    : Bus 5793	: V=1.02522394, theta=-16.0643963 -> V=1.015872, theta=0.0
% INFO    : Bus 5794	: V=1.04575705, theta=-24.6998099 -> V=1.0000025, theta=0.0
% INFO    : Bus 5795	: V=1.06797081, theta=-15.8886512 -> V=0.9888895, theta=0.0
% INFO    : Bus 5796	: V=1.0408377, theta=-20.8227598 -> V=1.0000025, theta=0.0
% INFO    : Bus 5797	: V=1.0411038, theta=-20.8416678 -> V=1.0000025, theta=0.0
% INFO    : Bus 5798	: V=1.01578356, theta=-11.7981401 -> V=0.999999, theta=0.0
% INFO    : Bus 5799	: V=1.00411765, theta=-40.7915995 -> V=1.022224, theta=0.0
% INFO    : Bus 5800	: V=0.930833322, theta=-8.75494643 -> V=0.9444445, theta=0.0
% INFO    : Bus 5801	: V=1.0604157, theta=-15.0436175 -> V=1.006874, theta=0.0
% INFO    : Bus 5802	: V=1.0641605, theta=-20.0154363 -> V=1.0000025, theta=0.0
% INFO    : Bus 5803	: V=1.07292559, theta=-45.8504744 -> V=1.04444, theta=0.0
% INFO    : Bus 5804	: V=1.03669657, theta=-34.8960632 -> V=1.022224, theta=0.0
% INFO    : Bus 5805	: V=1.04605656, theta=-39.0032566 -> V=1.022224, theta=0.0
% INFO    : Bus 5806	: V=1.02374947, theta=-13.0407695 -> V=1.015872, theta=0.0
% INFO    : Bus 5807	: V=1.05873962, theta=-12.8730084 -> V=0.9933315, theta=0.0
% INFO    : Bus 5808	: V=1.03746268, theta=-29.9898294 -> V=1.0000025, theta=0.0
% INFO    : Bus 5809	: V=1.03305115, theta=-19.1008345 -> V=1.022224, theta=0.0
% INFO    : Bus 5810	: V=1.05590138, theta=-18.2183607 -> V=1.0000025, theta=0.0
% INFO    : Bus 5811	: V=1.02123427, theta=-8.75712272 -> V=1.0158755, theta=0.0
% INFO    : Bus 5812	: V=1.05040836, theta=-9.0710773 -> V=1.07252, theta=0.0
% INFO    : Bus 5813	: V=1.04986763, theta=-24.1941132 -> V=1.0000025, theta=0.0
% INFO    : Bus 5814	: V=1.04807373, theta=-24.1702384 -> V=1.0000025, theta=0.0
% INFO    : Bus 5815	: V=1.01748602, theta=-12.8708782 -> V=1.0079355, theta=0.0
% INFO    : Bus 5816	: V=1.01992207, theta=-15.7086543 -> V=1.015872, theta=0.0
% INFO    : Bus 5817	: V=0.975642995, theta=-17.2507479 -> V=1.015872, theta=0.0
% INFO    : Bus 5818	: V=1.04845042, theta=-23.8036249 -> V=1.046665, theta=0.0
% INFO    : Bus 5819	: V=1.02048686, theta=-10.9621556 -> V=0.999999, theta=0.0
% INFO    : Bus 5820	: V=1.01719483, theta=-24.1704583 -> V=1.0000025, theta=0.0
% INFO    : Bus 5821	: V=1.03039354, theta=-15.4733478 -> V=0.999999, theta=0.0
% INFO    : Bus 5822	: V=1.03349099, theta=-9.2356324 -> V=0.999999, theta=0.0
% INFO    : Bus 5823	: V=1.04232796, theta=-24.3728803 -> V=1.0000025, theta=0.0
% INFO    : Bus 5824	: V=1.05031319, theta=-31.0019088 -> V=1.022224, theta=0.0
% INFO    : Bus 5825	: V=1.0124151, theta=-25.2701682 -> V=1.0000005, theta=0.0
% INFO    : Bus 5826	: V=1.01322361, theta=-9.27835044 -> V=0.999999, theta=0.0
% INFO    : Bus 5827	: V=1.04235466, theta=-28.9937542 -> V=1.027779, theta=0.0
% INFO    : Bus 5828	: V=1.04257059, theta=-14.6360472 -> V=0.999999, theta=0.0
% INFO    : Bus 5829	: V=0.952844217, theta=-7.76596469 -> V=0.9444445, theta=0.0
% INFO    : Bus 5830	: V=1.04705288, theta=-25.1345675 -> V=1.0000025, theta=0.0
% INFO    : Bus 5831	: V=1.02187441, theta=-27.2871399 -> V=1.0000005, theta=0.0
% INFO    : Bus 5832	: V=1.04680857, theta=-4.56580466 -> V=1.0000015, theta=0.0
% INFO    : Bus 5833	: V=1.00007527, theta=-20.9409762 -> V=0.999999, theta=0.0
% INFO    : Bus 5834	: V=1.04330845, theta=-23.6896343 -> V=1.022224, theta=0.0
% INFO    : Bus 5835	: V=1.03340528, theta=-23.5405118 -> V=1.0000025, theta=0.0
% INFO    : Bus 5836	: V=1.03546152, theta=-23.4457674 -> V=1.0000025, theta=0.0
% INFO    : Bus 5837	: V=1.01510475, theta=-20.1420731 -> V=1.0000025, theta=0.0
% INFO    : Bus 5838	: V=1.04280838, theta=-5.12291785 -> V=1.0111115, theta=0.0
% INFO    : Bus 5839	: V=1.02576199, theta=-28.7451073 -> V=1.0000005, theta=0.0
% INFO    : Bus 5840	: V=1.05591145, theta=-13.7901171 -> V=0.9933315, theta=0.0
% INFO    : Bus 5841	: V=1.04991515, theta=-25.7220843 -> V=1.027779, theta=0.0
% INFO    : Bus 5842	: V=1.0462121, theta=-25.126839 -> V=1.027779, theta=0.0
% INFO    : Bus 5843	: V=1.0402195, theta=-17.8865194 -> V=0.999999, theta=0.0
% INFO    : Bus 5844	: V=1.02857199, theta=-35.9544659 -> V=1.022224, theta=0.0
% INFO    : Bus 5845	: V=1.05042358, theta=0.590830437 -> V=0.975, theta=0.0
% INFO    : Bus 5846	: V=1.05490836, theta=-2.22923398 -> V=0.975, theta=0.0
% INFO    : Bus 5847	: V=1.03688284, theta=10.0909777 -> V=0.975, theta=0.0
% INFO    : Bus 5848	: V=1.03684708, theta=10.0892352 -> V=0.975, theta=0.0
% INFO    : Bus 5849	: V=1.08002904, theta=15.0013787 -> V=0.975, theta=0.0
% INFO    : Bus 5850	: V=1.07444086, theta=1.84862146 -> V=0.975, theta=0.0
% INFO    : Bus 5851	: V=1.06064675, theta=4.60264909 -> V=0.975, theta=0.0
% INFO    : Bus 5852	: V=1.09698377, theta=9.94067156 -> V=0.975, theta=0.0
% INFO    : Bus 5853	: V=1.03274176, theta=-14.5353151 -> V=0.975, theta=0.0
% INFO    : Bus 5854	: V=1.11462722, theta=4.95060267 -> V=0.975, theta=0.0
% INFO    : Bus 5855	: V=1.10494024, theta=-2.74511091 -> V=0.975, theta=0.0
% INFO    : Bus 5856	: V=1.05039233, theta=-1.32161968 -> V=0.975, theta=0.0
% INFO    : Bus 5857	: V=1.05363696, theta=1.41518689 -> V=0.975, theta=0.0
% INFO    : Bus 5858	: V=1.04920846, theta=1.14399566 -> V=0.975, theta=0.0
% INFO    : Bus 5859	: V=1.04897881, theta=1.10833682 -> V=0.975, theta=0.0
% INFO    : Bus 5860	: V=1.11369978, theta=1.90225814 -> V=0.975, theta=0.0
% INFO    : Bus 5861	: V=1.0653813, theta=-17.0597483 -> V=0.975, theta=0.0
% INFO    : Bus 5862	: V=1.05160095, theta=-27.6771962 -> V=0.975, theta=0.0
% INFO    : Bus 5863	: V=1.04399769, theta=-26.5475717 -> V=0.975, theta=0.0
% INFO    : Bus 5864	: V=1.07498831, theta=-19.0247358 -> V=0.975, theta=0.0
% INFO    : Bus 5865	: V=1.07409943, theta=-27.3134572 -> V=0.975, theta=0.0
% INFO    : Bus 5866	: V=1.06501606, theta=-7.22050901 -> V=0.975, theta=0.0
% INFO    : Bus 5867	: V=1.07293441, theta=-20.0827171 -> V=0.975, theta=0.0
% INFO    : Bus 5868	: V=1.08445604, theta=-15.9170869 -> V=0.975, theta=0.0
% INFO    : Bus 5869	: V=1.0511538, theta=-13.5849926 -> V=0.975, theta=0.0
% INFO    : Bus 5870	: V=1.07520494, theta=-21.5219466 -> V=0.975, theta=0.0
% INFO    : Bus 5871	: V=1.0771471, theta=-15.4968735 -> V=0.975, theta=0.0
% INFO    : Bus 5872	: V=1.07540658, theta=-47.7874135 -> V=0.975, theta=0.0
% INFO    : Bus 5873	: V=1.07467601, theta=0.464574725 -> V=0.975, theta=0.0
% INFO    : Bus 5874	: V=1.06267891, theta=-27.9940924 -> V=0.975, theta=0.0
% INFO    : Bus 5875	: V=1.07090321, theta=-19.2239115 -> V=0.975, theta=0.0
% INFO    : Bus 5876	: V=1.05355839, theta=-7.92024397 -> V=0.975, theta=0.0
% INFO    : Bus 5877	: V=1.07968734, theta=-18.9129612 -> V=0.975, theta=0.0
% INFO    : Bus 5878	: V=1.04805826, theta=-21.8902358 -> V=0.975, theta=0.0
% INFO    : Bus 5879	: V=1.03556939, theta=-26.6877939 -> V=0.975, theta=0.0
% INFO    : Bus 5880	: V=1.07558738, theta=-30.0096889 -> V=0.975, theta=0.0
% INFO    : Bus 5881	: V=1.08972161, theta=-12.7156421 -> V=0.975, theta=0.0
% INFO    : Bus 5882	: V=1.05206699, theta=-26.0806873 -> V=0.975, theta=0.0
% INFO    : Bus 5883	: V=1.04876224, theta=-25.8267903 -> V=0.975, theta=0.0
% INFO    : Bus 5884	: V=1.06826665, theta=-16.216677 -> V=0.975, theta=0.0
% INFO    : Bus 5885	: V=1.04636128, theta=-25.8818446 -> V=0.975, theta=0.0
% INFO    : Bus 5886	: V=1.06896964, theta=-15.2720404 -> V=0.975, theta=0.0
% INFO    : Bus 5887	: V=1.07521142, theta=-15.5681853 -> V=0.975, theta=0.0
% INFO    : Bus 5888	: V=1.07312247, theta=-26.2260623 -> V=0.975, theta=0.0
% INFO    : Bus 5889	: V=1.05151204, theta=-6.53455534 -> V=0.975, theta=0.0
% INFO    : Bus 5890	: V=1.03997794, theta=-30.2277084 -> V=0.975, theta=0.0
% INFO    : Bus 5891	: V=1.05217267, theta=-27.8901795 -> V=0.975, theta=0.0
% INFO    : Bus 5892	: V=1.08379807, theta=-13.9765951 -> V=0.975, theta=0.0
% INFO    : Bus 5893	: V=1.04403624, theta=-26.6504551 -> V=0.975, theta=0.0
% INFO    : Bus 5894	: V=1.0739009, theta=-18.812051 -> V=0.975, theta=0.0
% INFO    : Bus 5895	: V=1.05938436, theta=-6.8576538 -> V=0.975, theta=0.0
% INFO    : Bus 5896	: V=1.09167578, theta=-15.1367754 -> V=0.975, theta=0.0
% INFO    : Bus 5897	: V=1.07591645, theta=-17.3278193 -> V=0.975, theta=0.0
% INFO    : Bus 5898	: V=1.04814943, theta=-17.5244458 -> V=0.975, theta=0.0
% INFO    : Bus 5899	: V=1.07406234, theta=-46.6687218 -> V=0.975, theta=0.0
% INFO    : Bus 5900	: V=1.0742348, theta=0.343366894 -> V=0.975, theta=0.0
% INFO    : Bus 5901	: V=1.06876163, theta=-27.2104674 -> V=0.975, theta=0.0
% INFO    : Bus 5902	: V=1.05018903, theta=-7.92451104 -> V=0.975, theta=0.0
% INFO    : Bus 5903	: V=1.07467136, theta=-24.7858432 -> V=0.975, theta=0.0
% INFO    : Bus 5904	: V=1.07963454, theta=-18.7791492 -> V=0.975, theta=0.0
% INFO    : Bus 5905	: V=1.04858958, theta=-22.1206676 -> V=0.975, theta=0.0
% INFO    : Bus 5906	: V=1.05274767, theta=-25.911534 -> V=0.975, theta=0.0
% INFO    : Bus 5907	: V=1.08977073, theta=-12.6634642 -> V=0.975, theta=0.0
% INFO    : Bus 5908	: V=1.04928279, theta=-25.8234092 -> V=0.975, theta=0.0
% INFO    : Bus 5909	: V=1.06886411, theta=-15.0708563 -> V=0.975, theta=0.0
% INFO    : Bus 5910	: V=1.07274165, theta=-20.7238294 -> V=0.975, theta=0.0
% INFO    : Bus 5911	: V=1.0731142, theta=-26.2544887 -> V=0.975, theta=0.0
% INFO    : Bus 5912	: V=1.07098085, theta=-25.5193885 -> V=0.975, theta=0.0
% INFO    : Bus 5913	: V=1.04591411, theta=-5.69807126 -> V=0.975, theta=0.0
% INFO    : Bus 5914	: V=1.06518539, theta=-17.1121602 -> V=0.975, theta=0.0
% INFO    : Bus 5915	: V=1.07235952, theta=-30.1611918 -> V=0.975, theta=0.0
% INFO    : Bus 5916	: V=1.0575539, theta=-12.0658119 -> V=0.975, theta=0.0
% INFO    : Bus 5917	: V=1.07747627, theta=-28.3731684 -> V=0.975, theta=0.0
% INFO    : Bus 5918	: V=1.04459508, theta=-19.8541546 -> V=0.975, theta=0.0
% INFO    : Bus 5919	: V=1.05526885, theta=-24.570332 -> V=0.975, theta=0.0
% INFO    : Bus 5920	: V=1.0572599, theta=-29.3363663 -> V=0.975, theta=0.0
% INFO    : Bus 5921	: V=1.052159, theta=-18.9586241 -> V=0.975, theta=0.0
% INFO    : Bus 5922	: V=1.09719937, theta=-20.0989295 -> V=0.975, theta=0.0
% INFO    : Bus 5923	: V=1.0781775, theta=-6.67577886 -> V=0.975, theta=0.0
% INFO    : Bus 5924	: V=1.06819172, theta=-26.8840589 -> V=0.975, theta=0.0
% INFO    : Bus 5925	: V=1.06812461, theta=-26.2419323 -> V=0.975, theta=0.0
% INFO    : Bus 5926	: V=1.03595826, theta=-26.8713614 -> V=0.975, theta=0.0
% INFO    : Bus 5927	: V=1.08118498, theta=-26.5139592 -> V=0.975, theta=0.0
% INFO    : Bus 5928	: V=1.08585204, theta=-3.34344162 -> V=0.975, theta=0.0
% INFO    : Bus 5929	: V=1.0742406, theta=-25.88011 -> V=0.975, theta=0.0
% INFO    : Bus 5930	: V=1.05972482, theta=-25.847435 -> V=0.975, theta=0.0
% INFO    : Bus 5931	: V=1.07587466, theta=-27.7589605 -> V=0.975, theta=0.0
% INFO    : Bus 5932	: V=1.08488657, theta=-35.8354576 -> V=0.975, theta=0.0
% INFO    : Bus 5933	: V=1.06858388, theta=-28.9029983 -> V=0.975, theta=0.0
% INFO    : Bus 5934	: V=1.06265846, theta=-28.0560229 -> V=0.975, theta=0.0
% INFO    : Bus 5935	: V=1.06825531, theta=-26.3248271 -> V=0.975, theta=0.0
% INFO    : Bus 5936	: V=1.05994131, theta=-25.8337566 -> V=0.975, theta=0.0
% INFO    : Bus 5937	: V=1.0844632, theta=-3.73812705 -> V=0.975, theta=0.0
% INFO    : Bus 5938	: V=1.07406764, theta=-25.8780054 -> V=0.975, theta=0.0
% INFO    : Bus 5939	: V=1.07430738, theta=-26.7682707 -> V=0.975, theta=0.0
% INFO    : Bus 5940	: V=1.06881503, theta=-24.5533699 -> V=0.975, theta=0.0
% INFO    : Bus 5941	: V=1.07412204, theta=-27.5537518 -> V=0.975, theta=0.0
% INFO    : Bus 5942	: V=1.10247119, theta=-9.56426257 -> V=0.975, theta=0.0
% INFO    : Bus 5943	: V=1.08479774, theta=-35.5492823 -> V=0.975, theta=0.0
% INFO    : Bus 5944	: V=1.07493174, theta=-12.3703534 -> V=0.975, theta=0.0
% INFO    : Bus 5945	: V=1.0757977, theta=-27.3258881 -> V=0.975, theta=0.0
% INFO    : Bus 5946	: V=1.06275178, theta=-24.0602364 -> V=0.975, theta=0.0
% INFO    : Bus 5947	: V=1.07649268, theta=3.54597663 -> V=0.975, theta=0.0
% INFO    : Bus 5948	: V=1.07072086, theta=-2.94519835 -> V=0.975, theta=0.0
% INFO    : Bus 5949	: V=1.08096633, theta=1.56384558 -> V=0.975, theta=0.0
% INFO    : Bus 5950	: V=1.05256292, theta=-31.2057727 -> V=0.975, theta=0.0
% INFO    : Bus 5951	: V=1.02875606, theta=-8.15562851 -> V=0.975, theta=0.0
% INFO    : Bus 5952	: V=1.061, theta=0.175596742 -> V=0.975, theta=0.0
% INFO    : Bus 5953	: V=1.10616889, theta=0.810985777 -> V=0.975, theta=0.0
% INFO    : Bus 5954	: V=1.06524597, theta=3.7499871 -> V=0.975, theta=0.0
% INFO    : Bus 5955	: V=1.14342142, theta=5.44652909 -> V=0.975, theta=0.0
% INFO    : Bus 5956	: V=1.0933214, theta=4.9681136 -> V=0.975, theta=0.0
% INFO    : Bus 5957	: V=1.05144281, theta=-5.51394632 -> V=0.975, theta=0.0
% INFO    : Bus 5958	: V=1.06683899, theta=-5.27848892 -> V=0.975, theta=0.0
% INFO    : Bus 5959	: V=1.06933593, theta=-5.23312379 -> V=0.975, theta=0.0
% INFO    : Bus 5960	: V=1.08599066, theta=-10.646481 -> V=0.975, theta=0.0
% INFO    : Bus 5961	: V=1.05691299, theta=-0.474113204 -> V=0.975, theta=0.0
% INFO    : Bus 5962	: V=1.078, theta=1.23185826 -> V=0.975, theta=0.0
% INFO    : Bus 5963	: V=1.08881364, theta=-5.24313516 -> V=0.975, theta=0.0
% INFO    : Bus 5964	: V=1.09532724, theta=-1.02099208 -> V=0.975, theta=0.0
% INFO    : Bus 5965	: V=1.081, theta=-3.56219817 -> V=0.975, theta=0.0
% INFO    : Bus 5966	: V=1.06945497, theta=-7.85237751 -> V=0.975, theta=0.0
% INFO    : Bus 5967	: V=1.05243941, theta=-6.80932416 -> V=0.975, theta=0.0
% INFO    : Bus 5968	: V=1.10245165, theta=-2.12660983 -> V=0.975, theta=0.0
% INFO    : Bus 5969	: V=1.09515802, theta=-18.6130622 -> V=0.975, theta=0.0
% INFO    : Bus 5970	: V=0.994590939, theta=-13.6184333 -> V=0.975, theta=0.0
% INFO    : Bus 5971	: V=1.05606709, theta=-11.5761576 -> V=0.975, theta=0.0
% INFO    : Bus 5972	: V=1.09509739, theta=2.64574303 -> V=0.975, theta=0.0
% INFO    : Bus 5973	: V=1.07394113, theta=-4.67541874 -> V=0.975, theta=0.0
% INFO    : Bus 5974	: V=1.07255525, theta=-5.69606819 -> V=0.975, theta=0.0
% INFO    : Bus 5975	: V=1.08636265, theta=-0.762415654 -> V=0.975, theta=0.0
% INFO    : Bus 5976	: V=1.03700823, theta=-2.20962196 -> V=0.975, theta=0.0
% INFO    : Bus 5977	: V=1.10714185, theta=-2.17276654 -> V=0.975, theta=0.0
% INFO    : Bus 5978	: V=1.067, theta=10.9753287 -> V=0.975, theta=0.0
% INFO    : Bus 5979	: V=1.08289133, theta=-5.66872337 -> V=0.975, theta=0.0
% INFO    : Bus 5980	: V=1.08892039, theta=-11.7588703 -> V=0.975, theta=0.0
% INFO    : Bus 5981	: V=1.06222844, theta=10.2108931 -> V=0.975, theta=0.0
% INFO    : Bus 5982	: V=1.10176895, theta=-0.472245608 -> V=0.975, theta=0.0
% INFO    : Bus 5983	: V=1.0496467, theta=0.721516713 -> V=0.975, theta=0.0
% INFO    : Bus 5984	: V=1.0780033, theta=4.90543704 -> V=0.975, theta=0.0
% INFO    : Bus 5985	: V=1.06726422, theta=-0.0496158134 -> V=0.975, theta=0.0
% INFO    : Bus 5986	: V=1.0892995, theta=-11.27153 -> V=0.975, theta=0.0
% INFO    : Bus 5987	: V=1.09872358, theta=9.52919955 -> V=0.975, theta=0.0
% INFO    : Bus 5988	: V=1.09337674, theta=-10.4234915 -> V=0.975, theta=0.0
% INFO    : Bus 5989	: V=1.00398919, theta=-21.5971688 -> V=0.975, theta=0.0
% INFO    : Bus 5990	: V=1.00506671, theta=-34.4427307 -> V=0.975, theta=0.0
% INFO    : Bus 5991	: V=1.06734027, theta=-8.36384735 -> V=0.975, theta=0.0
% INFO    : Bus 5992	: V=1.09, theta=-3.26402979 -> V=0.975, theta=0.0
% INFO    : Bus 5993	: V=0.993, theta=4.66618513 -> V=0.975, theta=0.0
% INFO    : Bus 5994	: V=1.06063939, theta=-5.75260161 -> V=0.975, theta=0.0
% INFO    : Bus 5995	: V=1.08071776, theta=-5.59582365 -> V=0.975, theta=0.0
% INFO    : Bus 5996	: V=1.066, theta=-6.81580214 -> V=0.975, theta=0.0
% INFO    : Bus 5997	: V=1.09022215, theta=-11.0638922 -> V=0.975, theta=0.0
% INFO    : Bus 5998	: V=1.06327598, theta=-5.59246809 -> V=0.975, theta=0.0
% INFO    : Bus 5999	: V=1.078, theta=4.93592486 -> V=0.975, theta=0.0
% INFO    : Bus 6000	: V=1.078, theta=4.93528533 -> V=0.975, theta=0.0
% INFO    : Bus 6001	: V=1.02818558, theta=-2.47464386 -> V=0.975, theta=0.0
% INFO    : Bus 6002	: V=1.06288537, theta=2.73308466 -> V=0.975, theta=0.0
% INFO    : Bus 6003	: V=1.06508207, theta=-7.96590371 -> V=0.975, theta=0.0
% INFO    : Bus 6004	: V=1.091, theta=2.05622365 -> V=0.975, theta=0.0
% INFO    : Bus 6005	: V=1.0090648, theta=-12.8418572 -> V=0.975, theta=0.0
% INFO    : Bus 6006	: V=1.05281628, theta=1.02407255 -> V=0.975, theta=0.0
% INFO    : Bus 6007	: V=1.08724059, theta=-3.84449339 -> V=0.975, theta=0.0
% INFO    : Bus 6008	: V=1.07318892, theta=-9.02176318 -> V=0.975, theta=0.0
% INFO    : Bus 6009	: V=1.08804285, theta=11.765113 -> V=0.975, theta=0.0
% INFO    : Bus 6010	: V=1.08829908, theta=11.7760332 -> V=0.975, theta=0.0
% INFO    : Bus 6011	: V=1.079, theta=3.42622368 -> V=0.975, theta=0.0
% INFO    : Bus 6012	: V=1.07787707, theta=2.92853448 -> V=0.975, theta=0.0
% INFO    : Bus 6013	: V=1.106, theta=6.63427135 -> V=0.975, theta=0.0
% INFO    : Bus 6014	: V=1.10402487, theta=6.07791276 -> V=0.975, theta=0.0
% INFO    : Bus 6015	: V=1.03521837, theta=9.92565966 -> V=0.975, theta=0.0
% INFO    : Bus 6016	: V=1.029, theta=19.0779441 -> V=0.975, theta=0.0
% INFO    : Bus 6017	: V=1.06837978, theta=11.8312166 -> V=0.975, theta=0.0
% INFO    : Bus 6018	: V=1.06347446, theta=9.86346503 -> V=0.975, theta=0.0
% INFO    : Bus 6019	: V=1.054, theta=3.94513518 -> V=0.975, theta=0.0
% INFO    : Bus 6020	: V=1.0672556, theta=10.9947972 -> V=0.975, theta=0.0
% INFO    : Bus 6021	: V=1.04977845, theta=0.325601886 -> V=0.975, theta=0.0
% INFO    : Bus 6022	: V=1.05685733, theta=-2.30700525 -> V=0.975, theta=0.0
% INFO    : Bus 6023	: V=1.08137176, theta=-1.96868591 -> V=0.975, theta=0.0
% INFO    : Bus 6024	: V=1.08981586, theta=-0.399659349 -> V=0.975, theta=0.0
% INFO    : Bus 6025	: V=1.10469462, theta=2.62859425 -> V=0.975, theta=0.0
% INFO    : Bus 6026	: V=1.05467325, theta=9.73400104 -> V=0.975, theta=0.0
% INFO    : Bus 6027	: V=1.03090455, theta=-4.48547008 -> V=0.975, theta=0.0
% INFO    : Bus 6028	: V=1.11195887, theta=3.39152715 -> V=0.975, theta=0.0
% INFO    : Bus 6029	: V=1.04820497, theta=8.37117482 -> V=0.975, theta=0.0
% INFO    : Bus 6030	: V=1.038, theta=10.2478176 -> V=0.975, theta=0.0
% INFO    : Bus 6031	: V=1.09285922, theta=9.67372406 -> V=0.975, theta=0.0
% INFO    : Bus 6032	: V=1.09404075, theta=9.25684914 -> V=0.975, theta=0.0
% INFO    : Bus 6033	: V=1.07911114, theta=13.3048621 -> V=0.975, theta=0.0
% INFO    : Bus 6034	: V=1.0336066, theta=-14.4027695 -> V=0.975, theta=0.0
% INFO    : Bus 6035	: V=1.08018719, theta=1.23145083 -> V=0.975, theta=0.0
% INFO    : Bus 6036	: V=1.03255616, theta=-2.13555155 -> V=0.975, theta=0.0
% INFO    : Bus 6037	: V=1.04805279, theta=-2.50297255 -> V=0.975, theta=0.0
% INFO    : Bus 6038	: V=1.07041916, theta=-3.37094067 -> V=0.975, theta=0.0
% INFO    : Bus 6039	: V=1.109, theta=-3.38543486 -> V=0.975, theta=0.0
% INFO    : Bus 6040	: V=1.09772889, theta=-8.35109361 -> V=0.975, theta=0.0
% INFO    : Bus 6041	: V=1.06434623, theta=-7.69930281 -> V=0.975, theta=0.0
% INFO    : Bus 6042	: V=0.989726032, theta=-14.0407787 -> V=0.975, theta=0.0
% INFO    : Bus 6043	: V=1.05377026, theta=-5.43590901 -> V=0.975, theta=0.0
% INFO    : Bus 6044	: V=1.06985156, theta=-2.86857773 -> V=0.975, theta=0.0
% INFO    : Bus 6045	: V=1.058, theta=10.2724474 -> V=0.975, theta=0.0
% INFO    : Bus 6046	: V=1.09912417, theta=-8.51218495 -> V=0.975, theta=0.0
% INFO    : Bus 6047	: V=1.09201809, theta=-2.33202751 -> V=0.975, theta=0.0
% INFO    : Bus 6048	: V=1.097, theta=1.328723 -> V=0.975, theta=0.0
% INFO    : Bus 6049	: V=1.07198732, theta=-3.79789144 -> V=0.975, theta=0.0
% INFO    : Bus 6050	: V=1.07198732, theta=-3.79789144 -> V=0.975, theta=0.0
% INFO    : Bus 6051	: V=1.07276961, theta=-4.3346214 -> V=0.975, theta=0.0
% INFO    : Bus 6052	: V=1.06739509, theta=-3.96668884 -> V=0.975, theta=0.0
% INFO    : Bus 6053	: V=1.05282783, theta=1.01254325 -> V=0.975, theta=0.0
% INFO    : Bus 6054	: V=1.05270025, theta=1.01343045 -> V=0.975, theta=0.0
% INFO    : Bus 6055	: V=1.09228306, theta=6.66958394 -> V=0.975, theta=0.0
% INFO    : Bus 6056	: V=1.072, theta=4.5790404 -> V=0.975, theta=0.0
% INFO    : Bus 6057	: V=1.08274157, theta=0.398708984 -> V=0.975, theta=0.0
% INFO    : Bus 6058	: V=1.08339994, theta=0.419959483 -> V=0.975, theta=0.0
% INFO    : Bus 6059	: V=1.07941794, theta=0.788696344 -> V=0.975, theta=0.0
% INFO    : Bus 6060	: V=1.06346467, theta=14.3524598 -> V=0.975, theta=0.0
% INFO    : Bus 6061	: V=1.07662902, theta=15.1360181 -> V=0.975, theta=0.0
% INFO    : Bus 6062	: V=1.08768378, theta=-4.43906103 -> V=0.975, theta=0.0
% INFO    : Bus 6063	: V=1.04610715, theta=-0.855366156 -> V=0.975, theta=0.0
% INFO    : Bus 6064	: V=1.07087204, theta=-0.105476401 -> V=0.975, theta=0.0
% INFO    : Bus 6065	: V=1.03285322, theta=0.223424124 -> V=0.975, theta=0.0
% INFO    : Bus 6066	: V=1.07401611, theta=-3.06511921 -> V=0.975, theta=0.0
% INFO    : Bus 6067	: V=1.07283024, theta=-1.45456683 -> V=0.975, theta=0.0
% INFO    : Bus 6068	: V=1.08322809, theta=-5.7368174 -> V=0.975, theta=0.0
% INFO    : Bus 6069	: V=1.07540271, theta=13.8524957 -> V=0.975, theta=0.0
% INFO    : Bus 6070	: V=1.10580561, theta=5.73487843 -> V=0.975, theta=0.0
% INFO    : Bus 6071	: V=1.02689285, theta=-7.26035277 -> V=0.975, theta=0.0
% INFO    : Bus 6072	: V=1.06949591, theta=-5.98869303 -> V=0.975, theta=0.0
% INFO    : Bus 6073	: V=1.07955655, theta=1.17854636 -> V=0.975, theta=0.0
% INFO    : Bus 6074	: V=1.10810767, theta=7.67618361 -> V=0.975, theta=0.0
% INFO    : Bus 6075	: V=1.0233459, theta=-4.72379742 -> V=0.975, theta=0.0
% INFO    : Bus 6076	: V=1.07082943, theta=-3.11731368 -> V=0.975, theta=0.0
% INFO    : Bus 6077	: V=0.998720783, theta=-15.8549212 -> V=0.975, theta=0.0
% INFO    : Bus 6078	: V=1.109, theta=8.09527466 -> V=0.975, theta=0.0
% INFO    : Bus 6079	: V=1.10868013, theta=8.05769225 -> V=0.975, theta=0.0
% INFO    : Bus 6080	: V=1.08, theta=15.001741 -> V=0.975, theta=0.0
% INFO    : Bus 6081	: V=1.06330484, theta=11.2300072 -> V=0.975, theta=0.0
% INFO    : Bus 6082	: V=1.098, theta=-2.38274965 -> V=0.975, theta=0.0
% INFO    : Bus 6083	: V=1.0713505, theta=-0.721588011 -> V=0.975, theta=0.0
% INFO    : Bus 6084	: V=1.097, theta=2.54545291 -> V=0.975, theta=0.0
% INFO    : Bus 6085	: V=1.111, theta=0.840783598 -> V=0.975, theta=0.0
% INFO    : Bus 6086	: V=1.07441995, theta=1.8428467 -> V=0.975, theta=0.0
% INFO    : Bus 6087	: V=1.09701746, theta=-2.68025958 -> V=0.975, theta=0.0
% INFO    : Bus 6088	: V=1.07640254, theta=-3.01333587 -> V=0.975, theta=0.0
% INFO    : Bus 6089	: V=1.0757993, theta=-1.2399452 -> V=0.975, theta=0.0
% INFO    : Bus 6090	: V=1.09562613, theta=2.46508577 -> V=0.975, theta=0.0
% INFO    : Bus 6091	: V=1.1085161, theta=0.692600065 -> V=0.975, theta=0.0
% INFO    : Bus 6092	: V=1.09642723, theta=-5.28270853 -> V=0.975, theta=0.0
% INFO    : Bus 6093	: V=1.094, theta=3.31009268 -> V=0.975, theta=0.0
% INFO    : Bus 6094	: V=1.076, theta=12.9628931 -> V=0.975, theta=0.0
% INFO    : Bus 6095	: V=1.04094233, theta=-7.37966523 -> V=0.975, theta=0.0
% INFO    : Bus 6096	: V=1.06398427, theta=-7.09540326 -> V=0.975, theta=0.0
% INFO    : Bus 6097	: V=1.09036724, theta=-4.62559455 -> V=0.975, theta=0.0
% INFO    : Bus 6098	: V=1.04909408, theta=1.3447923 -> V=0.975, theta=0.0
% INFO    : Bus 6099	: V=1.04866317, theta=1.32236478 -> V=0.975, theta=0.0
% INFO    : Bus 6100	: V=1.0573357, theta=4.18724558 -> V=0.975, theta=0.0
% INFO    : Bus 6101	: V=1.08044197, theta=1.19134689 -> V=0.975, theta=0.0
% INFO    : Bus 6102	: V=1.059, theta=11.1823565 -> V=0.975, theta=0.0
% INFO    : Bus 6103	: V=1.061, theta=10.8830302 -> V=0.975, theta=0.0
% INFO    : Bus 6104	: V=1.07715707, theta=2.08571776 -> V=0.975, theta=0.0
% INFO    : Bus 6105	: V=1.06856712, theta=-8.71694899 -> V=0.975, theta=0.0
% INFO    : Bus 6106	: V=1.07736771, theta=-0.192931639 -> V=0.975, theta=0.0
% INFO    : Bus 6107	: V=1.109, theta=-1.78844363 -> V=0.975, theta=0.0
% INFO    : Bus 6108	: V=1.0482509, theta=1.35734371 -> V=0.975, theta=0.0
% INFO    : Bus 6109	: V=1.08254555, theta=17.7890691 -> V=0.975, theta=0.0
% INFO    : Bus 6110	: V=1.04645495, theta=1.8377594 -> V=0.975, theta=0.0
% INFO    : Bus 6111	: V=1.00816974, theta=0.280053025 -> V=0.975, theta=0.0
% INFO    : Bus 6112	: V=1.07984821, theta=0.462456892 -> V=0.975, theta=0.0
% INFO    : Bus 6113	: V=1.09043135, theta=-10.0110093 -> V=0.975, theta=0.0
% INFO    : Bus 6114	: V=1.04962966, theta=1.8262517 -> V=0.975, theta=0.0
% INFO    : Bus 6115	: V=1.09823102, theta=-0.597397928 -> V=0.975, theta=0.0
% INFO    : Bus 6116	: V=1.097, theta=9.94768648 -> V=0.975, theta=0.0
% INFO    : Bus 6117	: V=1.07370961, theta=-3.81213653 -> V=0.975, theta=0.0
% INFO    : Bus 6118	: V=1.05589143, theta=-2.22341474 -> V=0.975, theta=0.0
% INFO    : Bus 6119	: V=1.07209316, theta=-4.06383858 -> V=0.975, theta=0.0
% INFO    : Bus 6120	: V=1.08050979, theta=1.20616995 -> V=0.975, theta=0.0
% INFO    : Bus 6121	: V=1.03263823, theta=-14.6088985 -> V=0.975, theta=0.0
% INFO    : Bus 6122	: V=1.058, theta=-5.94197331 -> V=0.975, theta=0.0
% INFO    : Bus 6123	: V=1.084, theta=-5.49326236 -> V=0.975, theta=0.0
% INFO    : Bus 6124	: V=1.094, theta=-9.19139821 -> V=0.975, theta=0.0
% INFO    : Bus 6125	: V=1.0316712, theta=-1.33589081 -> V=0.975, theta=0.0
% INFO    : Bus 6126	: V=1.09305118, theta=1.23298343 -> V=0.975, theta=0.0
% INFO    : Bus 6127	: V=1.08889672, theta=10.0981331 -> V=0.975, theta=0.0
% INFO    : Bus 6128	: V=1.1147425, theta=4.93760768 -> V=0.975, theta=0.0
% INFO    : Bus 6129	: V=1.085, theta=13.9737498 -> V=0.975, theta=0.0
% INFO    : Bus 6130	: V=1.07234891, theta=-5.04337968 -> V=0.975, theta=0.0
% INFO    : Bus 6131	: V=1.04987945, theta=-0.478908618 -> V=0.975, theta=0.0
% INFO    : Bus 6132	: V=1.06426798, theta=11.9983318 -> V=0.975, theta=0.0
% INFO    : Bus 6133	: V=1.03029173, theta=-2.75016567 -> V=0.975, theta=0.0
% INFO    : Bus 6134	: V=1.09273189, theta=9.68423047 -> V=0.975, theta=0.0
% INFO    : Bus 6135	: V=1.08505464, theta=-11.0359483 -> V=0.975, theta=0.0
% INFO    : Bus 6136	: V=1.09629089, theta=0.472804097 -> V=0.975, theta=0.0
% INFO    : Bus 6137	: V=1.08616214, theta=15.7943514 -> V=0.975, theta=0.0
% INFO    : Bus 6138	: V=0.990714061, theta=-13.0660765 -> V=0.975, theta=0.0
% INFO    : Bus 6139	: V=1.03023476, theta=0.974656471 -> V=0.975, theta=0.0
% INFO    : Bus 6140	: V=1.08402467, theta=1.62597326 -> V=0.975, theta=0.0
% INFO    : Bus 6141	: V=1.10868027, theta=8.05768929 -> V=0.975, theta=0.0
% INFO    : Bus 6142	: V=1.10168307, theta=-8.00242377 -> V=0.975, theta=0.0
% INFO    : Bus 6143	: V=1.03080349, theta=-7.01598382 -> V=0.975, theta=0.0
% INFO    : Bus 6144	: V=1.0535774, theta=-7.40551469 -> V=0.975, theta=0.0
% INFO    : Bus 6145	: V=1.08662022, theta=-5.57238197 -> V=0.975, theta=0.0
% INFO    : Bus 6146	: V=1.06651162, theta=-7.45399246 -> V=0.975, theta=0.0
% INFO    : Bus 6147	: V=1.06884902, theta=-8.37860664 -> V=0.975, theta=0.0
% INFO    : Bus 6148	: V=1.08008052, theta=1.17790234 -> V=0.975, theta=0.0
% INFO    : Bus 6149	: V=1.07068032, theta=-3.49299316 -> V=0.975, theta=0.0
% INFO    : Bus 6150	: V=1.1002649, theta=-0.873558065 -> V=0.975, theta=0.0
% INFO    : Bus 6151	: V=1.10890508, theta=7.76844608 -> V=0.975, theta=0.0
% INFO    : Bus 6152	: V=1.076, theta=-8.60413788 -> V=0.975, theta=0.0
% INFO    : Bus 6153	: V=0.869327649, theta=-23.0172773 -> V=0.975, theta=0.0
% INFO    : Bus 6154	: V=1.06186701, theta=-5.72198509 -> V=0.975, theta=0.0
% INFO    : Bus 6155	: V=1.088, theta=-3.35081781 -> V=0.975, theta=0.0
% INFO    : Bus 6156	: V=1.10466036, theta=-4.01822825 -> V=0.975, theta=0.0
% INFO    : Bus 6157	: V=1.10574865, theta=-5.7947326 -> V=0.975, theta=0.0
% INFO    : Bus 6158	: V=0.991258148, theta=-14.3744793 -> V=0.975, theta=0.0
% INFO    : Bus 6159	: V=1.08953485, theta=-10.1133849 -> V=0.975, theta=0.0
% INFO    : Bus 6160	: V=1.05053624, theta=-1.35103408 -> V=0.975, theta=0.0
% INFO    : Bus 6161	: V=1.07038796, theta=-7.67344768 -> V=0.975, theta=0.0
% INFO    : Bus 6162	: V=1.087, theta=17.0128193 -> V=0.975, theta=0.0
% INFO    : Bus 6163	: V=1.03454721, theta=-8.2200885 -> V=0.975, theta=0.0
% INFO    : Bus 6164	: V=1.064, theta=-6.95444993 -> V=0.975, theta=0.0
% INFO    : Bus 6165	: V=1.05571315, theta=-6.71675659 -> V=0.975, theta=0.0
% INFO    : Bus 6166	: V=1.07881332, theta=1.44152107 -> V=0.975, theta=0.0
% INFO    : Bus 6167	: V=1.03561492, theta=-1.60984813 -> V=0.975, theta=0.0
% INFO    : Bus 6168	: V=1.03059845, theta=-1.62325458 -> V=0.975, theta=0.0
% INFO    : Bus 6169	: V=1.0189769, theta=-3.05716922 -> V=0.975, theta=0.0
% INFO    : Bus 6170	: V=1.0692324, theta=0.573829145 -> V=0.975, theta=0.0
% INFO    : Bus 6171	: V=1.02983833, theta=-13.7595901 -> V=0.975, theta=0.0
% INFO    : Bus 6172	: V=1.07686788, theta=13.7783891 -> V=0.975, theta=0.0
% INFO    : Bus 6173	: V=0.994278215, theta=-11.8064852 -> V=0.975, theta=0.0
% INFO    : Bus 6174	: V=1.054, theta=-8.33156062 -> V=0.975, theta=0.0
% INFO    : Bus 6175	: V=1.06113349, theta=0.706918429 -> V=0.975, theta=0.0
% INFO    : Bus 6176	: V=1.09051899, theta=2.1693288 -> V=0.975, theta=0.0
% INFO    : Bus 6177	: V=1.07514093, theta=12.6566799 -> V=0.975, theta=0.0
% INFO    : Bus 6178	: V=1.107, theta=-2.53021006 -> V=0.975, theta=0.0
% INFO    : Bus 6179	: V=1.09343336, theta=-6.03237608 -> V=0.975, theta=0.0
% INFO    : Bus 6180	: V=1.08374066, theta=-4.88523531 -> V=0.975, theta=0.0
% INFO    : Bus 6181	: V=0.982029051, theta=-15.5380451 -> V=0.975, theta=0.0
% INFO    : Bus 6182	: V=1.02534466, theta=-16.1092536 -> V=0.975, theta=0.0
% INFO    : Bus 6183	: V=1.095, theta=4.82525925 -> V=0.975, theta=0.0
% INFO    : Bus 6184	: V=1.10299697, theta=-7.48649583 -> V=0.975, theta=0.0
% INFO    : Bus 6185	: V=1.046, theta=-1.01910036 -> V=0.975, theta=0.0
% INFO    : Bus 6186	: V=1.103, theta=-1.79298307 -> V=0.975, theta=0.0
% INFO    : Bus 6187	: V=1.00983839, theta=-21.111261 -> V=0.975, theta=0.0
% INFO    : Bus 6188	: V=1.00826917, theta=4.20396587 -> V=0.975, theta=0.0
% INFO    : Bus 6189	: V=1.04442771, theta=8.00218944 -> V=0.975, theta=0.0
% INFO    : Bus 6190	: V=1.07648619, theta=14.1324212 -> V=0.975, theta=0.0
% INFO    : Bus 6191	: V=1.02853375, theta=18.5938644 -> V=0.975, theta=0.0
% INFO    : Bus 6192	: V=1.02853375, theta=18.5938644 -> V=0.975, theta=0.0
% INFO    : Bus 6193	: V=1.05098855, theta=-2.96617262 -> V=0.975, theta=0.0
% INFO    : Bus 6194	: V=1.17529338, theta=-19.2459779 -> V=0.99802, theta=0.0
% INFO    : Bus 6195	: V=1.06408904, theta=-6.94400891 -> V=0.975, theta=0.0
% INFO    : Bus 6196	: V=1.0674085, theta=9.83672602 -> V=0.975, theta=0.0
% INFO    : Bus 6197	: V=1.05894024, theta=10.2470914 -> V=0.975, theta=0.0
% INFO    : Bus 6198	: V=1.05891356, theta=10.7286732 -> V=0.975, theta=0.0
% INFO    : Bus 6199	: V=1.05060563, theta=2.2752766 -> V=0.975, theta=0.0
% INFO    : Bus 6200	: V=1.06989226, theta=-3.15604866 -> V=0.975, theta=0.0
% INFO    : Bus 6201	: V=1.05154636, theta=1.22205029 -> V=0.975, theta=0.0
% INFO    : Bus 6202	: V=1.07900305, theta=1.42791673 -> V=0.975, theta=0.0
% INFO    : Bus 6203	: V=1.03262305, theta=-2.12687688 -> V=0.975, theta=0.0
% INFO    : Bus 6204	: V=1.09388532, theta=2.86379164 -> V=0.975, theta=0.0
% INFO    : Bus 6205	: V=1.07271548, theta=4.48179445 -> V=0.975, theta=0.0
% INFO    : Bus 6206	: V=1.06699443, theta=-7.51129238 -> V=0.975, theta=0.0
% INFO    : Bus 6207	: V=1.10945839, theta=2.01049919 -> V=0.975, theta=0.0
% INFO    : Bus 6208	: V=1.089, theta=-9.82419663 -> V=0.975, theta=0.0
% INFO    : Bus 6209	: V=1.038, theta=10.1382694 -> V=0.975, theta=0.0
% INFO    : Bus 6210	: V=1.09469208, theta=9.77878057 -> V=0.975, theta=0.0
% INFO    : Bus 6211	: V=1.066, theta=-5.03997283 -> V=0.975, theta=0.0
% INFO    : Bus 6212	: V=1.058, theta=-0.460754335 -> V=0.975, theta=0.0
% INFO    : Bus 6213	: V=1.06095853, theta=6.35575901 -> V=0.975, theta=0.0
% INFO    : Bus 6214	: V=1.05594143, theta=5.25211516 -> V=0.975, theta=0.0
% INFO    : Bus 6215	: V=1.06933119, theta=-7.9237301 -> V=0.975, theta=0.0
% INFO    : Bus 6216	: V=1.067, theta=-9.40797475 -> V=0.975, theta=0.0
% INFO    : Bus 6217	: V=1.04740593, theta=0.768612106 -> V=0.975, theta=0.0
% INFO    : Bus 6218	: V=1.04680577, theta=0.6453413 -> V=0.975, theta=0.0
% INFO    : Bus 6219	: V=1.06459836, theta=-7.32343999 -> V=0.975, theta=0.0
% INFO    : Bus 6220	: V=1.06417978, theta=-5.47230605 -> V=0.975, theta=0.0
% INFO    : Bus 6221	: V=1.086, theta=-4.89027456 -> V=0.975, theta=0.0
% INFO    : Bus 6222	: V=1.00355079, theta=-13.7801971 -> V=0.975, theta=0.0
% INFO    : Bus 6223	: V=1.05243244, theta=-11.8315087 -> V=0.975, theta=0.0
% INFO    : Bus 6224	: V=1.03566415, theta=-13.5229059 -> V=0.975, theta=0.0
% INFO    : Bus 6225	: V=1.07076776, theta=-10.7146088 -> V=0.975, theta=0.0
% INFO    : Bus 6226	: V=1.07369311, theta=2.87027979 -> V=0.975, theta=0.0
% INFO    : Bus 6227	: V=1.113343, theta=1.75048685 -> V=0.975, theta=0.0
% INFO    : Bus 6228	: V=1.06545832, theta=-5.4113275 -> V=0.975, theta=0.0
% INFO    : Bus 6229	: V=1.075, theta=-8.66046367 -> V=0.975, theta=0.0
% INFO    : Bus 6230	: V=1.10261641, theta=4.61947268 -> V=0.975, theta=0.0
% INFO    : Bus 6231	: V=1.08021441, theta=-1.32128459 -> V=0.975, theta=0.0
% INFO    : Bus 6232	: V=1.08270954, theta=-0.884298105 -> V=0.975, theta=0.0
% INFO    : Bus 6233	: V=1.06283507, theta=-2.39245842 -> V=0.975, theta=0.0
% INFO    : Bus 6234	: V=1.08008052, theta=-0.789126922 -> V=0.975, theta=0.0
% INFO    : Bus 6235	: V=1.07238469, theta=-0.888751078 -> V=0.975, theta=0.0
% INFO    : Bus 6236	: V=1.03003601, theta=-13.3165245 -> V=0.975, theta=0.0
% INFO    : Bus 6237	: V=1.071, theta=-8.22653491 -> V=0.975, theta=0.0
% INFO    : Bus 6238	: V=1.06739095, theta=-1.06881403 -> V=0.975, theta=0.0
% INFO    : Bus 6239	: V=1.07097935, theta=-1.00573293 -> V=0.975, theta=0.0
% INFO    : Bus 6240	: V=1.09875265, theta=6.31331184 -> V=0.975, theta=0.0
% INFO    : Bus 6241	: V=1.05134937, theta=6.21169562 -> V=0.975, theta=0.0
% INFO    : Bus 6242	: V=1.05329059, theta=5.09686251 -> V=0.975, theta=0.0
% INFO    : Bus 6243	: V=1.02841249, theta=-4.65949634 -> V=0.975, theta=0.0
% INFO    : Bus 6244	: V=1.08081399, theta=14.2903457 -> V=0.975, theta=0.0
% INFO    : Bus 6245	: V=0.969605583, theta=-3.64654095 -> V=0.975, theta=0.0
% INFO    : Bus 6246	: V=0.969605583, theta=-3.64654095 -> V=0.975, theta=0.0
% INFO    : Bus 6247	: V=1.07, theta=-18.1708808 -> V=0.975, theta=0.0
% INFO    : Bus 6248	: V=1.07, theta=-18.1708808 -> V=0.975, theta=0.0
% INFO    : Bus 6249	: V=1.075, theta=-16.269166 -> V=0.975, theta=0.0
% INFO    : Bus 6250	: V=0.966, theta=-8.89977847 -> V=0.975, theta=0.0
% INFO    : Bus 6251	: V=0.946425599, theta=-14.8173736 -> V=0.975, theta=0.0
% INFO    : Bus 6252	: V=0.979, theta=0.206567498 -> V=0.975, theta=0.0
% INFO    : Bus 6253	: V=1.072, theta=-6.34204477 -> V=0.975, theta=0.0
% INFO    : Bus 6254	: V=1.072, theta=-6.34204477 -> V=0.975, theta=0.0
% INFO    : Bus 6255	: V=1.051, theta=-6.52709369 -> V=0.975, theta=0.0
% INFO    : Bus 6256	: V=1.051, theta=-6.52709369 -> V=0.975, theta=0.0
% INFO    : Bus 6257	: V=0.958, theta=0.250802603 -> V=0.975, theta=0.0
% INFO    : Bus 6258	: V=0.955, theta=-2.18987372 -> V=0.975, theta=0.0
% INFO    : Bus 6259	: V=1.005, theta=2.24290801 -> V=0.975, theta=0.0
% INFO    : Bus 6260	: V=1.003, theta=1.51981651 -> V=0.975, theta=0.0
% INFO    : Bus 6261	: V=0.947, theta=1.02649897 -> V=0.975, theta=0.0
% INFO    : Bus 6262	: V=0.95, theta=1.5331218 -> V=0.975, theta=0.0
% INFO    : Bus 6263	: V=1.047, theta=-3.01878907 -> V=0.975, theta=0.0
% INFO    : Bus 6264	: V=1.046, theta=-2.74884326 -> V=0.975, theta=0.0
% INFO    : Bus 6265	: V=1.045, theta=-2.77372512 -> V=0.975, theta=0.0
% INFO    : Bus 6266	: V=1.043, theta=-3.00057845 -> V=0.975, theta=0.0
% INFO    : Bus 6268	: V=1.023, theta=9.67041184 -> V=0.975, theta=0.0
% INFO    : Bus 6269	: V=1.024, theta=9.66452412 -> V=0.975, theta=0.0
% INFO    : Bus 6270	: V=1.032, theta=10.1539991 -> V=0.975, theta=0.0
% INFO    : Bus 6271	: V=1.036, theta=10.5352686 -> V=0.975, theta=0.0
% INFO    : Bus 6272	: V=1.04, theta=10.4162802 -> V=0.975, theta=0.0
% INFO    : Bus 6273	: V=1.02, theta=-0.744171858 -> V=0.975, theta=0.0
% INFO    : Bus 6274	: V=1.023, theta=-0.161275817 -> V=0.975, theta=0.0
% INFO    : Bus 6275	: V=1.02, theta=-0.681572433 -> V=0.975, theta=0.0
% INFO    : Bus 6276	: V=1.023, theta=-0.161275817 -> V=0.975, theta=0.0
% INFO    : Bus 6277	: V=1.023, theta=-0.230660611 -> V=0.975, theta=0.0
% INFO    : Bus 6278	: V=1.024, theta=-8.85383506 -> V=0.975, theta=0.0
% INFO    : Bus 6279	: V=1.029, theta=-8.46087929 -> V=0.975, theta=0.0
% INFO    : Bus 6280	: V=0.966, theta=-10.0169542 -> V=0.975, theta=0.0
% INFO    : Bus 6281	: V=0.97, theta=-10.0441893 -> V=0.975, theta=0.0
% INFO    : Bus 6282	: V=0.978, theta=-6.66037959 -> V=0.975, theta=0.0
% INFO    : Bus 6283	: V=0.988, theta=-4.42302389 -> V=0.975, theta=0.0
% INFO    : Bus 6284	: V=0.978, theta=-3.19120372 -> V=0.975, theta=0.0
% INFO    : Bus 6285	: V=0.995, theta=5.23169074 -> V=0.975, theta=0.0
% INFO    : Bus 6286	: V=0.995, theta=5.23770074 -> V=0.975, theta=0.0
% INFO    : Bus 6287	: V=0.996, theta=5.09383089 -> V=0.975, theta=0.0
% INFO    : Bus 6288	: V=0.994, theta=4.80462445 -> V=0.975, theta=0.0
% INFO    : Bus 6289	: V=0.99, theta=1.45446877 -> V=0.975, theta=0.0
% INFO    : Bus 6290	: V=0.99, theta=1.43668602 -> V=0.975, theta=0.0
% INFO    : Bus 6291	: V=1.036, theta=-7.94533511 -> V=0.975, theta=0.0
% INFO    : Bus 6292	: V=1.036, theta=-7.94533511 -> V=0.975, theta=0.0
% INFO    : Bus 6293	: V=1.036, theta=-7.94533511 -> V=0.975, theta=0.0
% INFO    : Bus 6294	: V=1.035, theta=-7.96868408 -> V=0.975, theta=0.0
% INFO    : Bus 6295	: V=1.035, theta=-7.96868408 -> V=0.975, theta=0.0
% INFO    : Bus 6296	: V=1.035, theta=-7.96868408 -> V=0.975, theta=0.0
% INFO    : Bus 6297	: V=0.986, theta=-9.51634484 -> V=0.975, theta=0.0
% INFO    : Bus 6298	: V=1.012, theta=17.809857 -> V=0.975, theta=0.0
% INFO    : Bus 6299	: V=1.016, theta=19.2506111 -> V=0.975, theta=0.0
% INFO    : Bus 6300	: V=1.016, theta=19.0543271 -> V=0.975, theta=0.0
% INFO    : Bus 6301	: V=1.03, theta=-8.43740967 -> V=0.975, theta=0.0
% INFO    : Bus 6302	: V=0.991, theta=-36.5468642 -> V=0.975, theta=0.0
% INFO    : Bus 6303	: V=0.963, theta=1.51380572 -> V=0.975, theta=0.0
% INFO    : Bus 6304	: V=1.009, theta=-12.9223801 -> V=0.975, theta=0.0
% INFO    : Bus 6306	: V=1.008, theta=-12.8614528 -> V=0.975, theta=0.0
% INFO    : Bus 6307	: V=1.008, theta=-12.8760597 -> V=0.975, theta=0.0
% INFO    : Bus 6308	: V=1.049, theta=15.0443627 -> V=0.975, theta=0.0
% INFO    : Bus 6309	: V=1.022, theta=15.1334157 -> V=0.975, theta=0.0
% INFO    : Bus 6310	: V=1.0, theta=0.515937805 -> V=0.975, theta=0.0
% INFO    : Bus 6311	: V=1.002, theta=0.525348674 -> V=0.975, theta=0.0
% INFO    : Bus 6312	: V=0.983, theta=-18.0261452 -> V=0.975, theta=0.0
% INFO    : Bus 6313	: V=0.983, theta=-18.1049205 -> V=0.975, theta=0.0
% INFO    : Bus 6314	: V=1.008, theta=-19.8353327 -> V=0.975, theta=0.0
% INFO    : Bus 6315	: V=0.989905961, theta=-34.4129718 -> V=0.975, theta=0.0
% INFO    : Bus 6316	: V=1.007, theta=-29.0226274 -> V=0.975, theta=0.0
% INFO    : Bus 6317	: V=1.005, theta=-27.7735731 -> V=0.975, theta=0.0
% INFO    : Bus 6319	: V=0.987999857, theta=-31.8595546 -> V=0.975, theta=0.0
% INFO    : Bus 6320	: V=0.942, theta=-3.28849984 -> V=0.975, theta=0.0
% INFO    : Bus 6321	: V=1.007, theta=-1.83536396 -> V=0.975, theta=0.0
% INFO    : Bus 6322	: V=0.992, theta=-0.521320464 -> V=0.975, theta=0.0
% INFO    : Bus 6323	: V=0.991, theta=-0.930789127 -> V=0.975, theta=0.0
% INFO    : Bus 6324	: V=0.992, theta=-0.383091744 -> V=0.975, theta=0.0
% INFO    : Bus 6325	: V=0.992, theta=-0.521320464 -> V=0.975, theta=0.0
% INFO    : Bus 6326	: V=0.992, theta=-0.521320464 -> V=0.975, theta=0.0
% INFO    : Bus 6327	: V=0.991, theta=-0.792511805 -> V=0.975, theta=0.0
% INFO    : Bus 6328	: V=1.008, theta=9.82366051 -> V=0.975, theta=0.0
% INFO    : Bus 6329	: V=1.012, theta=9.87657401 -> V=0.975, theta=0.0
% INFO    : Bus 6330	: V=1.013, theta=9.93155533 -> V=0.975, theta=0.0
% INFO    : Bus 6331	: V=1.012, theta=9.67354004 -> V=0.975, theta=0.0
% INFO    : Bus 6332	: V=1.014, theta=-6.70146906 -> V=0.975, theta=0.0
% INFO    : Bus 6333	: V=1.014, theta=-6.70146906 -> V=0.975, theta=0.0
% INFO    : Bus 6334	: V=0.961156866, theta=-14.6142127 -> V=0.975, theta=0.0
% INFO    : Bus 6335	: V=0.990203086, theta=-14.6142368 -> V=0.975, theta=0.0
% INFO    : Bus 6336	: V=1.031, theta=12.4531581 -> V=0.975, theta=0.0
% INFO    : Bus 6337	: V=1.001, theta=-3.011096 -> V=0.975, theta=0.0
% INFO    : Bus 6338	: V=1.0, theta=-3.00435596 -> V=0.975, theta=0.0
% INFO    : Bus 6339	: V=1.001, theta=-2.95803985 -> V=0.975, theta=0.0
% INFO    : Bus 6340	: V=1.0, theta=-2.83758232 -> V=0.975, theta=0.0
% INFO    : Bus 6341	: V=1.04050723, theta=-13.6919548 -> V=0.975, theta=0.0
% INFO    : Bus 6342	: V=1.031, theta=-9.32000251 -> V=0.975, theta=0.0
% INFO    : Bus 6343	: V=1.035, theta=-10.1807379 -> V=0.975, theta=0.0
% INFO    : Bus 6344	: V=1.023, theta=-3.66192303 -> V=0.975, theta=0.0
% INFO    : Bus 6345	: V=1.007, theta=-3.32061841 -> V=0.975, theta=0.0
% INFO    : Bus 6346	: V=1.004, theta=-3.59190411 -> V=0.975, theta=0.0
% INFO    : Bus 6347	: V=1.005, theta=-3.29756663 -> V=0.975, theta=0.0
% INFO    : Bus 6348	: V=1.004, theta=-2.56473071 -> V=0.975, theta=0.0
% INFO    : Bus 6349	: V=1.006, theta=-2.48450896 -> V=0.975, theta=0.0
% INFO    : Bus 6350	: V=1.027, theta=-2.37284973 -> V=0.975, theta=0.0
% INFO    : Bus 6351	: V=1.029, theta=-2.39974454 -> V=0.975, theta=0.0
% INFO    : Bus 6352	: V=1.02675217, theta=-11.5284516 -> V=0.975, theta=0.0
% INFO    : Bus 6353	: V=1.02675217, theta=-11.5284516 -> V=0.975, theta=0.0
% INFO    : Bus 6354	: V=0.999, theta=-4.51768137 -> V=0.975, theta=0.0
% INFO    : Bus 6355	: V=1.015, theta=-7.53711366 -> V=0.975, theta=0.0
% INFO    : Bus 6356	: V=1.015, theta=-7.53711366 -> V=0.975, theta=0.0
% INFO    : Bus 6357	: V=1.018, theta=0.97522618 -> V=0.975, theta=0.0
% INFO    : Bus 6358	: V=1.017, theta=0.68309406 -> V=0.975, theta=0.0
% INFO    : Bus 6359	: V=1.015, theta=0.762106433 -> V=0.975, theta=0.0
% INFO    : Bus 6360	: V=1.014, theta=1.00341768 -> V=0.975, theta=0.0
% INFO    : Bus 6361	: V=1.014, theta=0.79958029 -> V=0.975, theta=0.0
% INFO    : Bus 6362	: V=1.018, theta=0.205684457 -> V=0.975, theta=0.0
% INFO    : Bus 6363	: V=0.984431377, theta=-12.219432 -> V=0.975, theta=0.0
% INFO    : Bus 6364	: V=1.001, theta=-27.1036973 -> V=0.975, theta=0.0
% INFO    : Bus 6365	: V=0.999, theta=-13.873776 -> V=0.975, theta=0.0
% INFO    : Bus 6366	: V=0.991105835, theta=-20.0604862 -> V=0.975, theta=0.0
% INFO    : Bus 6367	: V=0.982093657, theta=-18.3109341 -> V=0.975, theta=0.0
% INFO    : Bus 6369	: V=0.967, theta=-1.47721086 -> V=0.975, theta=0.0
% INFO    : Bus 6370	: V=0.966, theta=-1.58752138 -> V=0.975, theta=0.0
% INFO    : Bus 6371	: V=1.037, theta=-20.9646387 -> V=0.975, theta=0.0
% INFO    : Bus 6372	: V=1.037, theta=-20.9646387 -> V=0.975, theta=0.0
% INFO    : Bus 6373	: V=1.054, theta=-5.36820603 -> V=0.975, theta=0.0
% INFO    : Bus 6374	: V=1.054, theta=-5.61798571 -> V=0.975, theta=0.0
% INFO    : Bus 6375	: V=1.05756504, theta=-11.5276985 -> V=0.975, theta=0.0
% INFO    : Bus 6376	: V=1.005, theta=-1.20482472 -> V=0.975, theta=0.0
% INFO    : Bus 6377	: V=1.005, theta=-1.38802531 -> V=0.975, theta=0.0
% INFO    : Bus 6378	: V=1.005, theta=-1.38802531 -> V=0.975, theta=0.0
% INFO    : Bus 6379	: V=1.005, theta=-1.20482472 -> V=0.975, theta=0.0
% INFO    : Bus 6380	: V=0.969310072, theta=-14.8645098 -> V=0.975, theta=0.0
% INFO    : Bus 6381	: V=0.99, theta=-9.76777473 -> V=0.975, theta=0.0
% INFO    : Bus 6382	: V=0.99, theta=-9.89014911 -> V=0.975, theta=0.0
% INFO    : Bus 6383	: V=0.977, theta=-2.0887354 -> V=0.975, theta=0.0
% INFO    : Bus 6384	: V=0.973, theta=0.100863187 -> V=0.975, theta=0.0
% INFO    : Bus 6385	: V=0.979, theta=-1.00879376 -> V=0.975, theta=0.0
% INFO    : Bus 6386	: V=0.977, theta=-1.87225489 -> V=0.975, theta=0.0
% INFO    : Bus 6387	: V=1.006, theta=-9.36515565 -> V=0.975, theta=0.0
% INFO    : Bus 6388	: V=1.006, theta=-9.18147219 -> V=0.975, theta=0.0
% INFO    : Bus 6389	: V=1.006, theta=-9.36515565 -> V=0.975, theta=0.0
% INFO    : Bus 6390	: V=0.979, theta=-10.0040233 -> V=0.975, theta=0.0
% INFO    : Bus 6391	: V=1.017, theta=-8.96005849 -> V=0.975, theta=0.0
% INFO    : Bus 6392	: V=1.016, theta=-9.15050321 -> V=0.975, theta=0.0
% INFO    : Bus 6393	: V=1.017, theta=-8.96005849 -> V=0.975, theta=0.0
% INFO    : Bus 6394	: V=1.017, theta=-8.96005849 -> V=0.975, theta=0.0
% INFO    : Bus 6395	: V=1.002, theta=10.0955976 -> V=0.975, theta=0.0
% INFO    : Bus 6396	: V=1.004, theta=10.4330147 -> V=0.975, theta=0.0
% INFO    : Bus 6397	: V=0.958, theta=-22.6550692 -> V=0.975, theta=0.0
% INFO    : Bus 6398	: V=0.958, theta=-22.4009075 -> V=0.975, theta=0.0
% INFO    : Bus 6399	: V=0.984, theta=-8.79096167 -> V=0.975, theta=0.0
% INFO    : Bus 6400	: V=0.996, theta=-4.77890175 -> V=0.975, theta=0.0
% INFO    : Bus 6401	: V=1.072, theta=-13.5483818 -> V=0.975, theta=0.0
% INFO    : Bus 6402	: V=1.072, theta=-13.5483818 -> V=0.975, theta=0.0
% INFO    : Bus 6403	: V=0.976249619, theta=-19.0549983 -> V=0.975, theta=0.0
% INFO    : Bus 6404	: V=0.976249421, theta=-19.054996 -> V=0.975, theta=0.0
% INFO    : Bus 6405	: V=1.015, theta=-3.05844374 -> V=0.975, theta=0.0
% INFO    : Bus 6406	: V=1.015, theta=-2.78789737 -> V=0.975, theta=0.0
% INFO    : Bus 6407	: V=1.015, theta=-2.8885591 -> V=0.975, theta=0.0
% INFO    : Bus 6408	: V=1.015, theta=-2.77670727 -> V=0.975, theta=0.0
% INFO    : Bus 6409	: V=0.985, theta=-4.93390296 -> V=0.975, theta=0.0
% INFO    : Bus 6410	: V=0.985, theta=-5.03220941 -> V=0.975, theta=0.0
% INFO    : Bus 6411	: V=1.042, theta=8.47959244 -> V=0.975, theta=0.0
% INFO    : Bus 6412	: V=1.03, theta=8.68035452 -> V=0.975, theta=0.0
% INFO    : Bus 6413	: V=1.025, theta=-10.5218292 -> V=0.975, theta=0.0
% INFO    : Bus 6414	: V=0.992, theta=-9.88403917 -> V=0.975, theta=0.0
% INFO    : Bus 6415	: V=0.948712591, theta=-14.620116 -> V=0.975, theta=0.0
% INFO    : Bus 6416	: V=0.981, theta=-3.70767739 -> V=0.975, theta=0.0
% INFO    : Bus 6417	: V=0.991, theta=-7.94363811 -> V=0.975, theta=0.0
% INFO    : Bus 6418	: V=0.991, theta=-7.94363811 -> V=0.975, theta=0.0
% INFO    : Bus 6419	: V=1.003, theta=1.34923059 -> V=0.975, theta=0.0
% INFO    : Bus 6420	: V=1.034, theta=-1.33572085 -> V=0.975, theta=0.0
% INFO    : Bus 6421	: V=1.047, theta=-1.47546546 -> V=0.975, theta=0.0
% INFO    : Bus 6422	: V=1.043, theta=-1.41960481 -> V=0.975, theta=0.0
% INFO    : Bus 6423	: V=1.047, theta=-1.50156084 -> V=0.975, theta=0.0
% INFO    : Bus 6424	: V=1.035, theta=-4.73991069 -> V=0.975, theta=0.0
% INFO    : Bus 6425	: V=1.035, theta=-2.30591365 -> V=0.975, theta=0.0
% INFO    : Bus 6426	: V=1.037, theta=-2.57543303 -> V=0.975, theta=0.0
% INFO    : Bus 6427	: V=0.97147831, theta=-20.9741038 -> V=0.975, theta=0.0
% INFO    : Bus 6428	: V=0.97147831, theta=-20.9741038 -> V=0.975, theta=0.0
% INFO    : Bus 6429	: V=1.039, theta=-14.6171691 -> V=0.975, theta=0.0
% INFO    : Bus 6430	: V=0.981240897, theta=-20.9741038 -> V=0.975, theta=0.0
% INFO    : Bus 6431	: V=1.075, theta=-13.9224245 -> V=0.975, theta=0.0
% INFO    : Bus 6432	: V=1.075, theta=-14.0754451 -> V=0.975, theta=0.0
% INFO    : Bus 6433	: V=1.075, theta=-14.0754451 -> V=0.975, theta=0.0
% INFO    : Bus 6434	: V=0.94, theta=-12.4966283 -> V=0.975, theta=0.0
% INFO    : Bus 6435	: V=0.967, theta=-9.19106784 -> V=0.975, theta=0.0
% INFO    : Bus 6436	: V=0.971, theta=-7.90455473 -> V=0.975, theta=0.0
% INFO    : Bus 6437	: V=1.033, theta=-3.50720353 -> V=0.975, theta=0.0
% INFO    : Bus 6438	: V=1.032, theta=-3.73801731 -> V=0.975, theta=0.0
% INFO    : Bus 6439	: V=1.007, theta=-5.95152505 -> V=0.975, theta=0.0
% INFO    : Bus 6440	: V=1.041, theta=-4.5532125 -> V=0.975, theta=0.0
% INFO    : Bus 6441	: V=1.041, theta=-4.55430877 -> V=0.975, theta=0.0
% INFO    : Bus 6442	: V=1.041, theta=-0.999114536 -> V=0.975, theta=0.0
% INFO    : Bus 6443	: V=1.039, theta=-10.0234734 -> V=0.975, theta=0.0
% INFO    : Bus 6444	: V=1.05738522, theta=-38.9046213 -> V=0.975, theta=0.0
% INFO    : Bus 6445	: V=1.05738564, theta=-38.9046326 -> V=0.975, theta=0.0
% INFO    : Bus 6446	: V=1.05738624, theta=-38.9046487 -> V=0.975, theta=0.0
% INFO    : Bus 6447	: V=0.984, theta=1.79367571 -> V=0.975, theta=0.0
% INFO    : Bus 6448	: V=0.994306383, theta=-3.13780959 -> V=0.975, theta=0.0
% INFO    : Bus 6449	: V=0.984, theta=2.10405603 -> V=0.975, theta=0.0
% INFO    : Bus 6450	: V=0.994306383, theta=-3.13780959 -> V=0.975, theta=0.0
% INFO    : Bus 6451	: V=1.096, theta=5.77839563 -> V=0.975, theta=0.0
% INFO    : Bus 6452	: V=1.028, theta=-7.47097014 -> V=0.975, theta=0.0
% INFO    : Bus 6453	: V=1.007, theta=-8.28502505 -> V=0.975, theta=0.0
% INFO    : Bus 6454	: V=1.006, theta=-8.46090392 -> V=0.975, theta=0.0
% INFO    : Bus 6455	: V=1.027, theta=-9.4063417 -> V=0.975, theta=0.0
% INFO    : Bus 6456	: V=1.023, theta=-9.48591358 -> V=0.975, theta=0.0
% INFO    : Bus 6457	: V=1.022, theta=-9.79946806 -> V=0.975, theta=0.0
% INFO    : Bus 6458	: V=0.974, theta=-8.25529822 -> V=0.975, theta=0.0
% INFO    : Bus 6459	: V=0.99, theta=-0.129579848 -> V=0.975, theta=0.0
% INFO    : Bus 6460	: V=0.99, theta=-0.129579848 -> V=0.975, theta=0.0
% INFO    : Bus 6461	: V=0.978, theta=6.58828454 -> V=0.975, theta=0.0
% INFO    : Bus 6462	: V=0.942, theta=-4.43338949 -> V=0.975, theta=0.0
% INFO    : Bus 6463	: V=1.038, theta=-5.01359567 -> V=0.975, theta=0.0
% INFO    : Bus 6464	: V=0.998, theta=7.91096599 -> V=0.975, theta=0.0
% INFO    : Bus 6465	: V=0.999, theta=7.76079093 -> V=0.975, theta=0.0
% INFO    : Bus 6466	: V=1.013, theta=11.9644176 -> V=0.975, theta=0.0
% INFO    : Bus 6467	: V=1.008, theta=12.4099243 -> V=0.975, theta=0.0
% INFO    : Bus 6468	: V=1.016, theta=18.555375 -> V=0.975, theta=0.0
% INFO    : Bus 6469	: V=1.016, theta=19.5482597 -> V=0.975, theta=0.0
% INFO    : Bus 6470	: V=1.022, theta=-8.5284774 -> V=0.975, theta=0.0
% INFO    : Bus 6471	: V=1.022, theta=-8.5284774 -> V=0.975, theta=0.0
% INFO    : Bus 6472	: V=0.985, theta=-1.27503599 -> V=0.975, theta=0.0
% INFO    : Bus 6473	: V=0.985, theta=-1.4034198 -> V=0.975, theta=0.0
% INFO    : Bus 6474	: V=0.981, theta=-2.6525305 -> V=0.975, theta=0.0
% INFO    : Bus 6475	: V=0.94, theta=-2.09609471 -> V=0.975, theta=0.0
% INFO    : Bus 6476	: V=0.996, theta=-11.5839065 -> V=0.975, theta=0.0
% INFO    : Bus 6477	: V=1.001, theta=-8.15890153 -> V=0.975, theta=0.0
% INFO    : Bus 6478	: V=1.001, theta=-8.20598598 -> V=0.975, theta=0.0
% INFO    : Bus 6479	: V=1.018, theta=-9.85135837 -> V=0.975, theta=0.0
% INFO    : Bus 6480	: V=1.018, theta=-9.85135837 -> V=0.975, theta=0.0
% INFO    : Bus 6481	: V=1.018, theta=-9.85135837 -> V=0.975, theta=0.0
% INFO    : Bus 6482	: V=0.937, theta=1.54226173 -> V=0.975, theta=0.0
% INFO    : Bus 6483	: V=1.01, theta=-4.82252742 -> V=0.975, theta=0.0
% INFO    : Bus 6484	: V=1.01, theta=-4.75535891 -> V=0.975, theta=0.0
% INFO    : Bus 6485	: V=0.996, theta=11.9932091 -> V=0.975, theta=0.0
% INFO    : Bus 6486	: V=0.992, theta=11.6019536 -> V=0.975, theta=0.0
% INFO    : Bus 6487	: V=0.994, theta=12.0348469 -> V=0.975, theta=0.0
% INFO    : Bus 6488	: V=0.989, theta=12.5979006 -> V=0.975, theta=0.0
% INFO    : Bus 6489	: V=1.01805256, theta=-23.6231314 -> V=0.975, theta=0.0
% INFO    : Bus 6490	: V=1.01805256, theta=-23.6231314 -> V=0.975, theta=0.0
% INFO    : Bus 6491	: V=1.01378743, theta=-23.5608589 -> V=0.975, theta=0.0
% INFO    : Bus 6492	: V=0.928, theta=2.65195065 -> V=0.975, theta=0.0
% INFO    : Bus 6493	: V=0.928, theta=2.65195065 -> V=0.975, theta=0.0
% INFO    : Bus 6494	: V=0.928, theta=2.65195065 -> V=0.975, theta=0.0
% INFO    : Bus 6495	: V=1.028, theta=-21.9902323 -> V=0.975, theta=0.0
% INFO    : Bus 6496	: V=1.03, theta=-22.6114326 -> V=0.975, theta=0.0
% INFO    : Bus 6497	: V=1.055, theta=-4.94641777 -> V=0.975, theta=0.0
% INFO    : Bus 6498	: V=1.032, theta=-6.36157205 -> V=0.975, theta=0.0
% INFO    : Bus 6499	: V=1.032, theta=-6.36240704 -> V=0.975, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 4	: Vg=1.04 -> Vg=1.0111115
% INFO    : Gen at bus 4	: Vg=1.04 -> Vg=1.0111115
% INFO    : Gen at bus 5	: Vg=1.024 -> Vg=1.0079355
% INFO    : Gen at bus 11	: Pg=0.1, Qg=0.0 -> Pg=14.0, Qg=0.0
% INFO    : Gen at bus 11	: Vg=1.035 -> Vg=1.000001
% INFO    : Gen at bus 11	: Vg=1.035 -> Vg=1.000001
% INFO    : Gen at bus 17	: Vg=1.051 -> Vg=1.022224
% INFO    : Gen at bus 19	: Vg=1.032 -> Vg=0.999999
% INFO    : Gen at bus 22	: Vg=1.024 -> Vg=1.0158755
% INFO    : Gen at bus 24	: Vg=1.042 -> Vg=1.033333
% INFO    : Gen at bus 24	: Vg=1.042 -> Vg=1.033333
% INFO    : Gen at bus 25	: Pg=1.29, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 25	: Vg=1.078 -> Vg=1.022222
% INFO    : Gen at bus 25	: Vg=1.078 -> Vg=1.022222
% INFO    : Gen at bus 40	: Vg=1.061 -> Vg=1.027779
% INFO    : Gen at bus 47	: Pg=8.51, Qg=-10.0 -> Pg=8.0, Qg=-0.25
% INFO    : Gen at bus 47	: Vg=1.027 -> Vg=0.999999
% INFO    : Gen at bus 47	: Pg=8.51, Qg=-10.0 -> Pg=8.0, Qg=-0.25
% INFO    : Gen at bus 47	: Vg=1.027 -> Vg=0.999999
% INFO    : Gen at bus 48	: Vg=1.037 -> Vg=1.000001
% INFO    : Gen at bus 48	: Vg=1.037 -> Vg=1.000001
% INFO    : Gen at bus 57	: Pg=4.17, Qg=1.0 -> Pg=6.5, Qg=0.95
% INFO    : Gen at bus 57	: Vg=1.061 -> Vg=1.0000025
% INFO    : Gen at bus 64	: Vg=1.067 -> Vg=0.9888895
% INFO    : Gen at bus 64	: Vg=1.067 -> Vg=0.9888895
% INFO    : Gen at bus 69	: Vg=1.049 -> Vg=1.0079355
% INFO    : Gen at bus 70	: Vg=1.022 -> Vg=1.0158755
% INFO    : Gen at bus 85	: Pg=0.15, Qg=0.0 -> Pg=3.34, Qg=0.0
% INFO    : Gen at bus 85	: Vg=1.05 -> Vg=1.001094
% INFO    : Gen at bus 86	: Vg=1.035 -> Vg=1.022224
% INFO    : Gen at bus 102	: Pg=17.12, Qg=-8.03 -> Pg=23.0, Qg=6.0
% INFO    : Gen at bus 102	: Vg=1.03 -> Vg=1.0158755
% INFO    : Gen at bus 122	: Pg=5.92, Qg=0.48 -> Pg=6.0, Qg=1.5
% INFO    : Gen at bus 122	: Vg=1.038 -> Vg=1.0158755
% INFO    : Gen at bus 124	: Vg=1.047 -> Vg=1.022224
% INFO    : Gen at bus 125	: Pg=1.11, Qg=0.0 -> Pg=13.0, Qg=0.0
% INFO    : Gen at bus 125	: Vg=1.034 -> Vg=1.0158755
% INFO    : Gen at bus 125	: Vg=1.034 -> Vg=1.0158755
% INFO    : Gen at bus 132	: Pg=12.21, Qg=1.67 -> Pg=8.5, Qg=0.0
% INFO    : Gen at bus 132	: Vg=1.068 -> Vg=1.000001
% INFO    : Gen at bus 132	: Vg=1.068 -> Vg=1.000001
% INFO    : Gen at bus 132	: Vg=1.068 -> Vg=1.000001
% INFO    : Gen at bus 132	: Vg=1.068 -> Vg=1.000001
% INFO    : Gen at bus 137	: Vg=1.032 -> Vg=1.015872
% INFO    : Gen at bus 137	: Pg=10.14, Qg=-0.55 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 137	: Vg=1.032 -> Vg=1.015872
% INFO    : Gen at bus 155	: Vg=1.05 -> Vg=1.0000025
% INFO    : Gen at bus 158	: Pg=8.2, Qg=2.26 -> Pg=8.95, Qg=-1.5
% INFO    : Gen at bus 158	: Vg=0.963 -> Vg=0.9444445
% INFO    : Gen at bus 158	: Pg=8.2, Qg=2.26 -> Pg=8.95, Qg=-1.5
% INFO    : Gen at bus 158	: Vg=0.963 -> Vg=0.9444445
% INFO    : Gen at bus 176	: Vg=1.099 -> Vg=1.0
% INFO    : Gen at bus 187	: Vg=1.079 -> Vg=1.0000025
% INFO    : Gen at bus 187	: Vg=1.079 -> Vg=1.0000025
% INFO    : Gen at bus 190	: Vg=0.948 -> Vg=0.9444445
% INFO    : Gen at bus 192	: Pg=2.1, Qg=0.0 -> Pg=11.75, Qg=0.0
% INFO    : Gen at bus 192	: Vg=1.062 -> Vg=1.0000025
% INFO    : Gen at bus 194	: Pg=2.48, Qg=1.0 -> Pg=7.5, Qg=0.95
% INFO    : Gen at bus 194	: Vg=1.059 -> Vg=1.0000025
% INFO    : Gen at bus 194	: Pg=2.48, Qg=1.0 -> Pg=7.5, Qg=0.95
% INFO    : Gen at bus 194	: Vg=1.059 -> Vg=1.0000025
% INFO    : Gen at bus 217	: Vg=1.029 -> Vg=1.022224
% INFO    : Gen at bus 224	: Vg=1.099 -> Vg=1.0
% INFO    : Gen at bus 227	: Vg=1.027 -> Vg=1.0079355
% INFO    : Gen at bus 236	: Vg=1.051 -> Vg=1.000001
% INFO    : Gen at bus 236	: Vg=1.051 -> Vg=1.000001
% INFO    : Gen at bus 238	: Vg=1.04 -> Vg=1.022224
% INFO    : Gen at bus 238	: Vg=1.04 -> Vg=1.022224
% INFO    : Gen at bus 246	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 246	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 246	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 246	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 256	: Pg=8.11, Qg=-5.68 -> Pg=13.0, Qg=0.0
% INFO    : Gen at bus 256	: Vg=1.047 -> Vg=1.0000025
% INFO    : Gen at bus 256	: Pg=13.11, Qg=-5.68 -> Pg=13.0, Qg=0.0
% INFO    : Gen at bus 256	: Vg=1.047 -> Vg=1.0000025
% INFO    : Gen at bus 258	: Pg=25.27, Qg=0.9 -> Pg=15.0, Qg=0.95
% INFO    : Gen at bus 258	: Vg=1.079 -> Vg=1.000731
% INFO    : Gen at bus 261	: Vg=1.047 -> Vg=1.0000025
% INFO    : Gen at bus 269	: Vg=1.009 -> Vg=1.0000025
% INFO    : Gen at bus 282	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 295	: Vg=1.055 -> Vg=0.9888895
% INFO    : Gen at bus 296	: Pg=5.04, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 296	: Vg=1.02 -> Vg=1.0158755
% INFO    : Gen at bus 305	: Pg=0.15, Qg=-2.76 -> Pg=7.5, Qg=0.0
% INFO    : Gen at bus 305	: Vg=1.053 -> Vg=1.003694
% INFO    : Gen at bus 312	: Pg=2.19, Qg=0.0 -> Pg=12.9, Qg=0.0
% INFO    : Gen at bus 312	: Vg=1.022 -> Vg=1.000001
% INFO    : Gen at bus 312	: Pg=8.19, Qg=0.0 -> Pg=24.8, Qg=0.0
% INFO    : Gen at bus 312	: Vg=1.022 -> Vg=1.000001
% INFO    : Gen at bus 317	: Vg=1.064 -> Vg=1.0000025
% INFO    : Gen at bus 317	: Vg=1.064 -> Vg=1.0000025
% INFO    : Gen at bus 319	: Vg=1.037 -> Vg=1.0000025
% INFO    : Gen at bus 325	: Vg=1.037 -> Vg=0.999999
% INFO    : Gen at bus 332	: Vg=1.034 -> Vg=1.015872
% INFO    : Gen at bus 333	: Vg=1.048 -> Vg=1.0233335
% INFO    : Gen at bus 336	: Pg=7.91, Qg=-0.0 -> Pg=6.5, Qg=-0.5
% INFO    : Gen at bus 336	: Vg=1.026 -> Vg=1.0000025
% INFO    : Gen at bus 338	: Vg=1.078 -> Vg=1.0000025
% INFO    : Gen at bus 338	: Vg=1.078 -> Vg=1.0000025
% INFO    : Gen at bus 345	: Vg=1.035 -> Vg=1.027779
% INFO    : Gen at bus 345	: Pg=0.05, Qg=0.0 -> Pg=9.75, Qg=0.0
% INFO    : Gen at bus 345	: Vg=1.035 -> Vg=1.027779
% INFO    : Gen at bus 348	: Vg=1.062 -> Vg=1.022222
% INFO    : Gen at bus 357	: Vg=1.018 -> Vg=1.0158755
% INFO    : Gen at bus 357	: Vg=1.018 -> Vg=1.0158755
% INFO    : Gen at bus 364	: Pg=125.15, Qg=-1.03 -> Pg=65.0, Qg=16.5
% INFO    : Gen at bus 364	: Vg=1.049 -> Vg=1.046665
% INFO    : Gen at bus 391	: Vg=1.043 -> Vg=1.0000025
% INFO    : Gen at bus 409	: Vg=1.033 -> Vg=1.015872
% INFO    : Gen at bus 411	: Vg=1.038 -> Vg=1.022224
% INFO    : Gen at bus 411	: Vg=1.038 -> Vg=1.022224
% INFO    : Gen at bus 431	: Pg=2.06, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 431	: Vg=1.062 -> Vg=1.0000025
% INFO    : Gen at bus 440	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 447	: Pg=17.34, Qg=0.84 -> Pg=12.5, Qg=-0.5
% INFO    : Gen at bus 447	: Vg=0.999 -> Vg=1.015872
% INFO    : Gen at bus 462	: Vg=1.038 -> Vg=1.0079355
% INFO    : Gen at bus 462	: Vg=1.038 -> Vg=1.0079355
% INFO    : Gen at bus 464	: Pg=4.27, Qg=0.25 -> Pg=14.0, Qg=1.5
% INFO    : Gen at bus 464	: Vg=1.168 -> Vg=0.984405
% INFO    : Gen at bus 464	: Pg=4.27, Qg=0.25 -> Pg=14.0, Qg=1.5
% INFO    : Gen at bus 464	: Vg=1.168 -> Vg=0.984405
% INFO    : Gen at bus 466	: Vg=1.037 -> Vg=1.0079355
% INFO    : Gen at bus 470	: Vg=1.049 -> Vg=0.999999
% INFO    : Gen at bus 470	: Vg=1.049 -> Vg=0.999999
% INFO    : Gen at bus 479	: Vg=1.019 -> Vg=0.999999
% INFO    : Gen at bus 479	: Vg=1.019 -> Vg=0.999999
% INFO    : Gen at bus 479	: Vg=1.019 -> Vg=0.999999
% INFO    : Gen at bus 491	: Vg=1.055 -> Vg=1.033334
% INFO    : Gen at bus 508	: Vg=1.029 -> Vg=0.999999
% INFO    : Gen at bus 519	: Vg=1.007 -> Vg=1.015874
% INFO    : Gen at bus 520	: Vg=1.042 -> Vg=1.022224
% INFO    : Gen at bus 530	: Pg=1.87, Qg=0.06 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 530	: Vg=1.044 -> Vg=0.999999
% INFO    : Gen at bus 530	: Pg=1.87, Qg=0.06 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 530	: Vg=1.044 -> Vg=0.999999
% INFO    : Gen at bus 530	: Pg=1.87, Qg=0.06 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 530	: Vg=1.044 -> Vg=0.999999
% INFO    : Gen at bus 537	: Vg=1.035 -> Vg=1.022224
% INFO    : Gen at bus 537	: Pg=1.95, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 537	: Vg=1.035 -> Vg=1.022224
% INFO    : Gen at bus 546	: Pg=0.0, Qg=2.0 -> Pg=4.5, Qg=1.95
% INFO    : Gen at bus 546	: Vg=1.051 -> Vg=1.0000025
% INFO    : Gen at bus 548	: Vg=1.051 -> Vg=1.0000025
% INFO    : Gen at bus 570	: Vg=1.001 -> Vg=1.0158755
% INFO    : Gen at bus 570	: Vg=1.001 -> Vg=1.0158755
% INFO    : Gen at bus 570	: Vg=1.001 -> Vg=1.0158755
% INFO    : Gen at bus 583	: Pg=3.18, Qg=3.92 -> Pg=8.0, Qg=1.5
% INFO    : Gen at bus 583	: Vg=1.021 -> Vg=1.0000005
% INFO    : Gen at bus 585	: Vg=0.995 -> Vg=1.0158755
% INFO    : Gen at bus 586	: Vg=1.022 -> Vg=0.999999
% INFO    : Gen at bus 589	: Vg=1.03 -> Vg=1.000001
% INFO    : Gen at bus 593	: Vg=1.013 -> Vg=1.0000025
% INFO    : Gen at bus 600	: Vg=1.03 -> Vg=1.015872
% INFO    : Gen at bus 610	: Pg=39.12, Qg=-5.64 -> Pg=22.5, Qg=0.0
% INFO    : Gen at bus 610	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 610	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 612	: Vg=1.024 -> Vg=1.022224
% INFO    : Gen at bus 612	: Vg=1.024 -> Vg=1.022224
% INFO    : Gen at bus 612	: Vg=1.024 -> Vg=1.022224
% INFO    : Gen at bus 613	: Vg=1.022 -> Vg=1.0000005
% INFO    : Gen at bus 613	: Vg=1.022 -> Vg=1.0000005
% INFO    : Gen at bus 624	: Pg=-4.03, Qg=-8.3 -> Pg=0.0, Qg=0.0
% INFO    : Gen at bus 624	: Vg=1.039 -> Vg=1.0111115
% INFO    : Gen at bus 633	: Vg=1.039 -> Vg=0.999999
% INFO    : Gen at bus 636	: Vg=1.003 -> Vg=1.015872
% INFO    : Gen at bus 636	: Pg=0.97, Qg=4.5 -> Pg=7.5, Qg=3.5
% INFO    : Gen at bus 636	: Vg=1.003 -> Vg=1.015872
% INFO    : Gen at bus 641	: Pg=160.75, Qg=-1.52 -> Pg=119.5, Qg=2.5
% INFO    : Gen at bus 641	: Vg=1.104 -> Vg=1.079965
% INFO    : Gen at bus 652	: Vg=1.062 -> Vg=1.0000025
% INFO    : Gen at bus 670	: Pg=0.14, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 670	: Vg=1.033 -> Vg=1.022224
% INFO    : Gen at bus 670	: Pg=0.14, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 670	: Vg=1.033 -> Vg=1.022224
% INFO    : Gen at bus 671	: Vg=1.036 -> Vg=1.027779
% INFO    : Gen at bus 671	: Pg=1.13, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 671	: Vg=1.036 -> Vg=1.027779
% INFO    : Gen at bus 679	: Vg=1.016 -> Vg=1.022224
% INFO    : Gen at bus 680	: Vg=1.059 -> Vg=1.022374
% INFO    : Gen at bus 684	: Pg=2.24, Qg=1.87 -> Pg=4.5, Qg=0.5
% INFO    : Gen at bus 684	: Vg=0.966 -> Vg=0.9444445
% INFO    : Gen at bus 684	: Pg=2.24, Qg=1.87 -> Pg=4.5, Qg=0.5
% INFO    : Gen at bus 684	: Vg=0.966 -> Vg=0.9444445
% INFO    : Gen at bus 684	: Vg=0.966 -> Vg=0.9444445
% INFO    : Gen at bus 684	: Pg=2.24, Qg=1.87 -> Pg=5.5, Qg=1.5
% INFO    : Gen at bus 684	: Vg=0.966 -> Vg=0.9444445
% INFO    : Gen at bus 695	: Vg=1.05 -> Vg=1.022222
% INFO    : Gen at bus 695	: Vg=1.05 -> Vg=1.022222
% INFO    : Gen at bus 695	: Vg=1.05 -> Vg=1.022222
% INFO    : Gen at bus 699	: Pg=27.82, Qg=-7.74 -> Pg=18.5, Qg=-1.0
% INFO    : Gen at bus 699	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 699	: Pg=26.84, Qg=-7.74 -> Pg=18.5, Qg=-1.0
% INFO    : Gen at bus 699	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 698	: Pg=26.02, Qg=-8.2 -> Pg=18.5, Qg=0.0
% INFO    : Gen at bus 698	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 698	: Pg=28.0, Qg=-8.2 -> Pg=18.5, Qg=0.0
% INFO    : Gen at bus 698	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 697	: Pg=27.99, Qg=-8.19 -> Pg=18.5, Qg=-1.0
% INFO    : Gen at bus 697	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 697	: Pg=25.02, Qg=-8.19 -> Pg=18.5, Qg=-1.0
% INFO    : Gen at bus 697	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 705	: Vg=0.96 -> Vg=0.9444445
% INFO    : Gen at bus 705	: Vg=0.96 -> Vg=0.9444445
% INFO    : Gen at bus 705	: Pg=0.93, Qg=3.0 -> Pg=2.85, Qg=0.0
% INFO    : Gen at bus 705	: Vg=0.96 -> Vg=0.9444445
% INFO    : Gen at bus 705	: Vg=0.96 -> Vg=0.9444445
% INFO    : Gen at bus 732	: Vg=1.039 -> Vg=1.022224
% INFO    : Gen at bus 733	: Pg=27.26, Qg=-4.5 -> Pg=19.5, Qg=0.0
% INFO    : Gen at bus 733	: Vg=1.007 -> Vg=0.999999
% INFO    : Gen at bus 734	: Vg=1.006 -> Vg=1.0158755
% INFO    : Gen at bus 734	: Vg=1.006 -> Vg=1.0158755
% INFO    : Gen at bus 736	: Vg=1.049 -> Vg=1.000001
% INFO    : Gen at bus 736	: Pg=1.13, Qg=0.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 736	: Vg=1.049 -> Vg=1.000001
% INFO    : Gen at bus 737	: Vg=1.039 -> Vg=1.0000025
% INFO    : Gen at bus 744	: Vg=1.019 -> Vg=0.999999
% INFO    : Gen at bus 744	: Vg=1.019 -> Vg=0.999999
% INFO    : Gen at bus 745	: Pg=9.03, Qg=-8.28 -> Pg=13.3, Qg=0.0
% INFO    : Gen at bus 745	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 746	: Pg=1.93, Qg=2.0 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 746	: Vg=1.023 -> Vg=1.022224
% INFO    : Gen at bus 751	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 758	: Vg=1.06 -> Vg=0.9888895
% INFO    : Gen at bus 760	: Vg=1.045 -> Vg=1.000709
% INFO    : Gen at bus 761	: Vg=1.043 -> Vg=0.999999
% INFO    : Gen at bus 760	: Pg=16.76, Qg=-8.42 -> Pg=18.75, Qg=0.79
% INFO    : Gen at bus 760	: Vg=1.045 -> Vg=1.000709
% INFO    : Gen at bus 761	: Pg=15.68, Qg=-5.67 -> Pg=18.75, Qg=2.0
% INFO    : Gen at bus 761	: Vg=1.043 -> Vg=0.999999
% INFO    : Gen at bus 762	: Vg=0.596 -> Vg=0.825
% INFO    : Gen at bus 762	: Vg=0.596 -> Vg=0.825
% INFO    : Gen at bus 762	: Vg=0.596 -> Vg=0.825
% INFO    : Gen at bus 762	: Vg=0.596 -> Vg=0.825
% INFO    : Gen at bus 766	: Vg=1.025 -> Vg=1.0158755
% INFO    : Gen at bus 766	: Vg=1.025 -> Vg=1.0158755
% INFO    : Gen at bus 786	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 786	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 787	: Vg=1.022 -> Vg=0.975
% INFO    : Gen at bus 801	: Pg=23.78, Qg=-7.69 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 801	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 801	: Pg=24.76, Qg=-7.69 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 801	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 802	: Pg=25.53, Qg=-6.29 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 802	: Vg=1.017 -> Vg=0.975
% INFO    : Gen at bus 802	: Pg=24.52, Qg=-6.29 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 802	: Vg=1.017 -> Vg=0.975
% INFO    : Gen at bus 803	: Pg=24.52, Qg=-7.3 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 803	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 803	: Pg=24.52, Qg=-7.3 -> Pg=15.5, Qg=-1.0
% INFO    : Gen at bus 803	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 807	: Pg=31.08, Qg=0.0 -> Pg=20.4, Qg=0.0
% INFO    : Gen at bus 807	: Vg=1.023 -> Vg=1.0000025
% INFO    : Gen at bus 815	: Pg=21.82, Qg=-0.33 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 815	: Vg=1.019 -> Vg=1.015872
% INFO    : Gen at bus 815	: Vg=1.019 -> Vg=1.015872
% INFO    : Gen at bus 816	: Pg=22.35, Qg=-0.61 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 816	: Vg=1.019 -> Vg=1.015872
% INFO    : Gen at bus 816	: Pg=22.35, Qg=-0.61 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 816	: Vg=1.019 -> Vg=1.015872
% INFO    : Gen at bus 816	: Pg=20.35, Qg=-0.61 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 816	: Vg=1.019 -> Vg=1.015872
% INFO    : Gen at bus 816	: Pg=22.35, Qg=-0.61 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 816	: Vg=1.019 -> Vg=1.015872
% INFO    : Gen at bus 826	: Vg=1.057 -> Vg=1.0000025
% INFO    : Gen at bus 826	: Vg=1.057 -> Vg=1.0000025
% INFO    : Gen at bus 829	: Vg=1.058 -> Vg=1.022222
% INFO    : Gen at bus 830	: Pg=6.55, Qg=1.61 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 830	: Vg=1.053 -> Vg=1.0000025
% INFO    : Gen at bus 831	: Vg=0.978 -> Vg=0.9444445
% INFO    : Gen at bus 833	: Vg=1.079 -> Vg=1.0000025
% INFO    : Gen at bus 833	: Vg=1.079 -> Vg=1.0000025
% INFO    : Gen at bus 836	: Pg=3.01, Qg=3.0 -> Pg=7.5, Qg=2.95
% INFO    : Gen at bus 836	: Vg=1.033 -> Vg=1.0000025
% INFO    : Gen at bus 838	: Vg=1.071 -> Vg=1.0000025
% INFO    : Gen at bus 838	: Vg=1.071 -> Vg=1.0000025
% INFO    : Gen at bus 857	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 857	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 864	: Pg=3.69, Qg=7.0 -> Pg=7.0, Qg=0.0
% INFO    : Gen at bus 864	: Vg=1.016 -> Vg=1.0000025
% INFO    : Gen at bus 865	: Pg=6.08, Qg=7.0 -> Pg=7.0, Qg=0.0
% INFO    : Gen at bus 865	: Vg=1.018 -> Vg=1.0000025
% INFO    : Gen at bus 885	: Vg=1.048 -> Vg=1.0000025
% INFO    : Gen at bus 885	: Vg=1.048 -> Vg=1.0000025
% INFO    : Gen at bus 889	: Vg=0.998 -> Vg=0.975
% INFO    : Gen at bus 889	: Vg=0.998 -> Vg=0.975
% INFO    : Gen at bus 889	: Vg=0.998 -> Vg=0.975
% INFO    : Gen at bus 889	: Vg=0.998 -> Vg=0.975
% INFO    : Gen at bus 907	: Vg=1.066 -> Vg=1.027779
% INFO    : Gen at bus 940	: Pg=3.1, Qg=0.0 -> Pg=4.05, Qg=0.0
% INFO    : Gen at bus 940	: Vg=1.001 -> Vg=1.0000025
% INFO    : Gen at bus 944	: Vg=1.037 -> Vg=1.000001
% INFO    : Gen at bus 965	: Pg=38.25, Qg=2.96 -> Pg=25.0, Qg=9.0
% INFO    : Gen at bus 965	: Vg=1.062 -> Vg=0.975
% INFO    : Gen at bus 967	: Vg=1.042 -> Vg=1.022224
% INFO    : Gen at bus 973	: Pg=1.35, Qg=-1.05 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 973	: Vg=1.026 -> Vg=0.999999
% INFO    : Gen at bus 973	: Pg=1.35, Qg=-1.05 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 973	: Vg=1.026 -> Vg=0.999999
% INFO    : Gen at bus 983	: Vg=1.059 -> Vg=1.027779
% INFO    : Gen at bus 983	: Vg=1.059 -> Vg=1.027779
% INFO    : Gen at bus 983	: Vg=1.059 -> Vg=1.027779
% INFO    : Gen at bus 985	: Vg=1.02 -> Vg=0.984126
% INFO    : Gen at bus 987	: Vg=1.031 -> Vg=1.022224
% INFO    : Gen at bus 1009	: Pg=0.0, Qg=1.0 -> Pg=1.5, Qg=0.95
% INFO    : Gen at bus 1009	: Vg=1.062 -> Vg=1.000001
% INFO    : Gen at bus 1009	: Vg=1.062 -> Vg=1.000001
% INFO    : Gen at bus 1013	: Pg=1.75, Qg=4.0 -> Pg=3.6, Qg=0.0
% INFO    : Gen at bus 1013	: Vg=1.065 -> Vg=1.004549
% INFO    : Gen at bus 1025	: Vg=1.04 -> Vg=1.022224
% INFO    : Gen at bus 1048	: Vg=0.999 -> Vg=0.999999
% INFO    : Gen at bus 1050	: Pg=1.01, Qg=0.0 -> Pg=6.9, Qg=0.0
% INFO    : Gen at bus 1050	: Vg=0.994 -> Vg=1.015872
% INFO    : Gen at bus 1050	: Vg=0.994 -> Vg=1.015872
% INFO    : Gen at bus 1057	: Pg=7.0, Qg=1.59 -> Pg=9.4, Qg=1.5
% INFO    : Gen at bus 1057	: Vg=1.072 -> Vg=1.022222
% INFO    : Gen at bus 1058	: Vg=1.044 -> Vg=1.022224
% INFO    : Gen at bus 1065	: Vg=1.042 -> Vg=0.9736045
% INFO    : Gen at bus 1066	: Pg=3.11, Qg=2.0 -> Pg=6.0, Qg=1.95
% INFO    : Gen at bus 1066	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 1070	: Vg=1.018 -> Vg=1.0158755
% INFO    : Gen at bus 1108	: Pg=14.0, Qg=-0.68 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 1108	: Vg=1.077 -> Vg=0.975
% INFO    : Gen at bus 1108	: Vg=1.077 -> Vg=0.975
% INFO    : Gen at bus 1108	: Vg=1.077 -> Vg=0.975
% INFO    : Gen at bus 1108	: Pg=5.0, Qg=-0.68 -> Pg=6.5, Qg=0.0
% INFO    : Gen at bus 1108	: Vg=1.077 -> Vg=0.975
% INFO    : Gen at bus 1110	: Pg=11.4, Qg=-5.26 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 1110	: Vg=1.047 -> Vg=1.002384
% INFO    : Gen at bus 1110	: Pg=12.49, Qg=-5.26 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 1110	: Vg=1.047 -> Vg=1.002384
% INFO    : Gen at bus 1125	: Vg=1.04 -> Vg=1.0000025
% INFO    : Gen at bus 1128	: Vg=1.023 -> Vg=1.022224
% INFO    : Gen at bus 1135	: Vg=1.025 -> Vg=1.0000025
% INFO    : Gen at bus 1147	: Vg=1.038 -> Vg=1.022224
% INFO    : Gen at bus 1147	: Vg=1.038 -> Vg=1.022224
% INFO    : Gen at bus 1210	: Pg=31.23, Qg=4.49 -> Pg=31.0, Qg=0.0
% INFO    : Gen at bus 1210	: Vg=1.095 -> Vg=1.047405
% INFO    : Gen at bus 1211	: Pg=22.21, Qg=-10.57 -> Pg=20.7, Qg=0.215
% INFO    : Gen at bus 1211	: Vg=1.08 -> Vg=1.044445
% INFO    : Gen at bus 1221	: Vg=1.057 -> Vg=1.027779
% INFO    : Gen at bus 1246	: Vg=0.58 -> Vg=0.825
% INFO    : Gen at bus 1246	: Vg=0.58 -> Vg=0.825
% INFO    : Gen at bus 1256	: Vg=1.039 -> Vg=1.0079355
% INFO    : Gen at bus 1258	: Pg=5.14, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1258	: Vg=1.037 -> Vg=1.0158755
% INFO    : Gen at bus 1259	: Pg=5.14, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1259	: Vg=1.035 -> Vg=1.0158755
% INFO    : Gen at bus 1263	: Vg=1.001 -> Vg=1.015872
% INFO    : Gen at bus 1277	: Vg=1.045 -> Vg=1.033333
% INFO    : Gen at bus 1277	: Vg=1.045 -> Vg=1.033333
% INFO    : Gen at bus 1286	: Vg=1.065 -> Vg=1.0000025
% INFO    : Gen at bus 1286	: Vg=1.065 -> Vg=1.0000025
% INFO    : Gen at bus 1286	: Pg=1.04, Qg=2.0 -> Pg=4.0, Qg=-0.1
% INFO    : Gen at bus 1286	: Vg=1.065 -> Vg=1.0000025
% INFO    : Gen at bus 1303	: Vg=1.047 -> Vg=0.975
% INFO    : Gen at bus 1310	: Vg=1.064 -> Vg=1.0000025
% INFO    : Gen at bus 1310	: Vg=1.064 -> Vg=1.0000025
% INFO    : Gen at bus 1310	: Vg=1.064 -> Vg=1.0000025
% INFO    : Gen at bus 1313	: Vg=1.041 -> Vg=1.0000025
% INFO    : Gen at bus 1313	: Vg=1.041 -> Vg=1.0000025
% INFO    : Gen at bus 1315	: Vg=1.045 -> Vg=1.022224
% INFO    : Gen at bus 1315	: Vg=1.045 -> Vg=1.022224
% INFO    : Gen at bus 1323	: Vg=0.977 -> Vg=0.9444445
% INFO    : Gen at bus 1325	: Vg=1.064 -> Vg=1.000001
% INFO    : Gen at bus 1325	: Pg=0.13, Qg=1.0 -> Pg=2.5, Qg=0.95
% INFO    : Gen at bus 1325	: Vg=1.064 -> Vg=1.000001
% INFO    : Gen at bus 1340	: Vg=1.028 -> Vg=0.999999
% INFO    : Gen at bus 1344	: Pg=0.0, Qg=1.53 -> Pg=5.5, Qg=3.0
% INFO    : Gen at bus 1344	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 1344	: Pg=0.0, Qg=1.53 -> Pg=5.5, Qg=3.0
% INFO    : Gen at bus 1344	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 1354	: Pg=1.22, Qg=0.0 -> Pg=9.075, Qg=0.0
% INFO    : Gen at bus 1354	: Vg=1.049 -> Vg=1.0000025
% INFO    : Gen at bus 1354	: Pg=16.22, Qg=0.0 -> Pg=17.85, Qg=0.0
% INFO    : Gen at bus 1354	: Vg=1.049 -> Vg=1.0000025
% INFO    : Gen at bus 1354	: Pg=7.22, Qg=0.0 -> Pg=14.2, Qg=0.0
% INFO    : Gen at bus 1354	: Vg=1.049 -> Vg=1.0000025
% INFO    : Gen at bus 1357	: Pg=24.17, Qg=-7.27 -> Pg=22.5, Qg=0.0
% INFO    : Gen at bus 1357	: Vg=1.051 -> Vg=0.999999
% INFO    : Gen at bus 1356	: Pg=23.66, Qg=-0.77 -> Pg=22.5, Qg=0.0
% INFO    : Gen at bus 1356	: Vg=1.053 -> Vg=0.999999
% INFO    : Gen at bus 1363	: Vg=1.038 -> Vg=1.015872
% INFO    : Gen at bus 1363	: Pg=5.02, Qg=7.62 -> Pg=6.5, Qg=1.31
% INFO    : Gen at bus 1363	: Vg=1.038 -> Vg=1.015872
% INFO    : Gen at bus 1410	: Vg=1.009 -> Vg=1.015872
% INFO    : Gen at bus 1420	: Pg=39.14, Qg=0.94 -> Pg=25.0, Qg=0.0
% INFO    : Gen at bus 1420	: Vg=1.04 -> Vg=1.000001
% INFO    : Gen at bus 1420	: Pg=39.14, Qg=0.94 -> Pg=25.0, Qg=0.0
% INFO    : Gen at bus 1420	: Vg=1.04 -> Vg=1.000001
% INFO    : Gen at bus 1433	: Vg=1.01 -> Vg=1.015872
% INFO    : Gen at bus 1440	: Pg=7.24, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 1440	: Vg=1.015 -> Vg=1.015872
% INFO    : Gen at bus 1454	: Vg=0.608 -> Vg=0.825
% INFO    : Gen at bus 1454	: Vg=0.608 -> Vg=0.825
% INFO    : Gen at bus 1454	: Vg=0.608 -> Vg=0.825
% INFO    : Gen at bus 1463	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 1464	: Vg=1.033 -> Vg=1.027779
% INFO    : Gen at bus 1474	: Vg=1.03 -> Vg=1.015872
% INFO    : Gen at bus 1495	: Vg=1.046 -> Vg=1.022224
% INFO    : Gen at bus 1497	: Vg=1.048 -> Vg=1.0111115
% INFO    : Gen at bus 1497	: Vg=1.048 -> Vg=1.0111115
% INFO    : Gen at bus 1517	: Pg=215.55, Qg=72.65 -> Pg=141.5, Qg=20.0
% INFO    : Gen at bus 1517	: Vg=1.123 -> Vg=0.975
% INFO    : Gen at bus 1518	: Pg=159.51, Qg=23.7 -> Pg=125.5, Qg=12.5
% INFO    : Gen at bus 1518	: Vg=0.97 -> Vg=0.975
% INFO    : Gen at bus 1548	: Vg=1.041 -> Vg=1.022222
% INFO    : Gen at bus 1548	: Vg=1.041 -> Vg=1.022222
% INFO    : Gen at bus 1555	: Pg=6.24, Qg=1.68 -> Pg=25.0, Qg=6.5
% INFO    : Gen at bus 1555	: Vg=1.046 -> Vg=1.033333
% INFO    : Gen at bus 1559	: Vg=1.069 -> Vg=1.027779
% INFO    : Gen at bus 1559	: Vg=1.069 -> Vg=1.027779
% INFO    : Gen at bus 1560	: Vg=1.077 -> Vg=1.046665
% INFO    : Gen at bus 1561	: Vg=1.042 -> Vg=1.022224
% INFO    : Gen at bus 1565	: Vg=0.979 -> Vg=1.0158755
% INFO    : Gen at bus 1565	: Vg=0.979 -> Vg=1.0158755
% INFO    : Gen at bus 1579	: Vg=1.019 -> Vg=0.999999
% INFO    : Gen at bus 1593	: Pg=18.26, Qg=7.0 -> Pg=18.0, Qg=-0.5
% INFO    : Gen at bus 1593	: Vg=1.057 -> Vg=1.022224
% INFO    : Gen at bus 1593	: Pg=7.26, Qg=7.0 -> Pg=18.0, Qg=-0.5
% INFO    : Gen at bus 1593	: Vg=1.057 -> Vg=1.022224
% INFO    : Gen at bus 1599	: Pg=37.23, Qg=14.6 -> Pg=21.0, Qg=5.0
% INFO    : Gen at bus 1599	: Vg=1.05 -> Vg=1.0028855
% INFO    : Gen at bus 1613	: Pg=1.24, Qg=0.0 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 1613	: Vg=1.038 -> Vg=1.027779
% INFO    : Gen at bus 1613	: Vg=1.038 -> Vg=1.027779
% INFO    : Gen at bus 1624	: Pg=4.56, Qg=-3.21 -> Pg=39.0, Qg=-1.36
% INFO    : Gen at bus 1624	: Vg=1.056 -> Vg=1.0377785
% INFO    : Gen at bus 1637	: Vg=1.041 -> Vg=1.0000025
% INFO    : Gen at bus 1638	: Vg=1.051 -> Vg=1.0000025
% INFO    : Gen at bus 1638	: Pg=2.98, Qg=0.0 -> Pg=5.95, Qg=0.0
% INFO    : Gen at bus 1638	: Vg=1.051 -> Vg=1.0000025
% INFO    : Gen at bus 1639	: Pg=4.26, Qg=0.19 -> Pg=26.0, Qg=-1.5
% INFO    : Gen at bus 1639	: Vg=1.064 -> Vg=1.04444
% INFO    : Gen at bus 1642	: Vg=1.075 -> Vg=1.0000025
% INFO    : Gen at bus 1653	: Vg=1.052 -> Vg=1.0000025
% INFO    : Gen at bus 1669	: Vg=1.033 -> Vg=1.0111115
% INFO    : Gen at bus 1669	: Vg=1.033 -> Vg=1.0111115
% INFO    : Gen at bus 1678	: Pg=4.1, Qg=0.1 -> Pg=5.5, Qg=0.0
% INFO    : Gen at bus 1678	: Vg=1.018 -> Vg=1.015872
% INFO    : Gen at bus 1678	: Pg=4.1, Qg=0.1 -> Pg=5.5, Qg=0.0
% INFO    : Gen at bus 1678	: Vg=1.018 -> Vg=1.015872
% INFO    : Gen at bus 1679	: Vg=1.054 -> Vg=1.0000025
% INFO    : Gen at bus 1680	: Vg=1.024 -> Vg=1.015872
% INFO    : Gen at bus 1680	: Vg=1.024 -> Vg=1.015872
% INFO    : Gen at bus 1681	: Vg=1.026 -> Vg=0.999999
% INFO    : Gen at bus 1682	: Vg=1.041 -> Vg=1.0000025
% INFO    : Gen at bus 1687	: Pg=2.13, Qg=2.08 -> Pg=3.55, Qg=0.07
% INFO    : Gen at bus 1687	: Vg=1.018 -> Vg=1.0000025
% INFO    : Gen at bus 1691	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 1691	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 1691	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 1694	: Vg=1.076 -> Vg=1.0000025
% INFO    : Gen at bus 1697	: Vg=1.029 -> Vg=1.0000025
% INFO    : Gen at bus 1698	: Vg=1.049 -> Vg=1.0000025
% INFO    : Gen at bus 1700	: Pg=13.27, Qg=-0.96 -> Pg=14.45, Qg=0.0
% INFO    : Gen at bus 1700	: Vg=1.044 -> Vg=0.999999
% INFO    : Gen at bus 1711	: Vg=1.073 -> Vg=1.015874
% INFO    : Gen at bus 1722	: Vg=1.037 -> Vg=0.975
% INFO    : Gen at bus 1722	: Vg=1.037 -> Vg=0.975
% INFO    : Gen at bus 1725	: Vg=1.042 -> Vg=1.027779
% INFO    : Gen at bus 1727	: Vg=1.029 -> Vg=0.999999
% INFO    : Gen at bus 1734	: Pg=17.47, Qg=2.67 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 1734	: Vg=1.054 -> Vg=1.0000025
% INFO    : Gen at bus 1734	: Vg=1.054 -> Vg=1.0000025
% INFO    : Gen at bus 1741	: Pg=35.28, Qg=9.4 -> Pg=20.0, Qg=1.0
% INFO    : Gen at bus 1741	: Vg=1.113 -> Vg=0.975
% INFO    : Gen at bus 1742	: Pg=35.28, Qg=9.33 -> Pg=20.0, Qg=1.0
% INFO    : Gen at bus 1742	: Vg=1.112 -> Vg=0.975
% INFO    : Gen at bus 1743	: Pg=34.84, Qg=9.29 -> Pg=20.0, Qg=1.0
% INFO    : Gen at bus 1743	: Vg=1.113 -> Vg=0.975
% INFO    : Gen at bus 1797	: Vg=1.023 -> Vg=1.0000025
% INFO    : Gen at bus 1807	: Vg=1.05 -> Vg=1.0000025
% INFO    : Gen at bus 1824	: Vg=1.02 -> Vg=1.022224
% INFO    : Gen at bus 1831	: Vg=1.046 -> Vg=1.0111115
% INFO    : Gen at bus 1837	: Pg=3.17, Qg=0.0 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 1837	: Vg=1.045 -> Vg=1.0158755
% INFO    : Gen at bus 1837	: Pg=13.17, Qg=0.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 1837	: Vg=1.045 -> Vg=1.0158755
% INFO    : Gen at bus 1847	: Vg=1.046 -> Vg=1.016667
% INFO    : Gen at bus 1847	: Vg=1.046 -> Vg=1.016667
% INFO    : Gen at bus 1855	: Vg=1.048 -> Vg=1.0000025
% INFO    : Gen at bus 1858	: Vg=1.079 -> Vg=1.0000025
% INFO    : Gen at bus 1858	: Vg=1.079 -> Vg=1.0000025
% INFO    : Gen at bus 1863	: Pg=6.15, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1863	: Vg=1.034 -> Vg=1.0111115
% INFO    : Gen at bus 1863	: Pg=7.15, Qg=0.0 -> Pg=18.25, Qg=0.0
% INFO    : Gen at bus 1863	: Vg=1.034 -> Vg=1.0111115
% INFO    : Gen at bus 1863	: Pg=13.15, Qg=0.0 -> Pg=21.75, Qg=0.0
% INFO    : Gen at bus 1863	: Vg=1.034 -> Vg=1.0111115
% INFO    : Gen at bus 1864	: Vg=1.038 -> Vg=1.022224
% INFO    : Gen at bus 1865	: Pg=37.59, Qg=10.83 -> Pg=22.0, Qg=5.5
% INFO    : Gen at bus 1865	: Vg=1.014 -> Vg=1.0000005
% INFO    : Gen at bus 1866	: Vg=1.04 -> Vg=0.999999
% INFO    : Gen at bus 1871	: Pg=0.2, Qg=0.0 -> Pg=4.5, Qg=0.0
% INFO    : Gen at bus 1871	: Vg=1.076 -> Vg=1.000001
% INFO    : Gen at bus 1880	: Vg=1.04 -> Vg=1.022224
% INFO    : Gen at bus 1888	: Pg=16.38, Qg=-0.98 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1888	: Vg=1.042 -> Vg=0.975
% INFO    : Gen at bus 1889	: Pg=14.92, Qg=-2.05 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1889	: Vg=1.039 -> Vg=0.975
% INFO    : Gen at bus 1890	: Pg=17.8, Qg=0.59 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1890	: Vg=1.045 -> Vg=0.975
% INFO    : Gen at bus 1891	: Pg=17.28, Qg=1.06 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 1891	: Vg=1.046 -> Vg=0.975
% INFO    : Gen at bus 1903	: Vg=1.036 -> Vg=0.999999
% INFO    : Gen at bus 1922	: Vg=1.064 -> Vg=1.000001
% INFO    : Gen at bus 1934	: Vg=1.031 -> Vg=0.999999
% INFO    : Gen at bus 1933	: Vg=1.027 -> Vg=0.999999
% INFO    : Gen at bus 1942	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 1953	: Vg=1.037 -> Vg=1.0000025
% INFO    : Gen at bus 1961	: Pg=18.54, Qg=-2.47 -> Pg=12.0, Qg=0.5
% INFO    : Gen at bus 1961	: Vg=1.058 -> Vg=0.975
% INFO    : Gen at bus 1962	: Pg=17.57, Qg=0.02 -> Pg=12.0, Qg=0.105
% INFO    : Gen at bus 1962	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 1963	: Pg=18.54, Qg=-2.47 -> Pg=12.0, Qg=0.5
% INFO    : Gen at bus 1963	: Vg=1.058 -> Vg=0.975
% INFO    : Gen at bus 1964	: Pg=18.04, Qg=0.53 -> Pg=12.0, Qg=0.5
% INFO    : Gen at bus 1964	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 1965	: Pg=18.03, Qg=1.03 -> Pg=12.0, Qg=0.5
% INFO    : Gen at bus 1965	: Vg=1.062 -> Vg=0.975
% INFO    : Gen at bus 1974	: Pg=23.6, Qg=-3.27 -> Pg=14.5, Qg=0.0
% INFO    : Gen at bus 1974	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 1974	: Pg=22.62, Qg=-3.27 -> Pg=14.5, Qg=0.0
% INFO    : Gen at bus 1974	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 1975	: Pg=23.61, Qg=-9.1 -> Pg=14.5, Qg=-6.5
% INFO    : Gen at bus 1975	: Vg=1.009 -> Vg=0.999999
% INFO    : Gen at bus 1976	: Pg=24.31, Qg=-5.75 -> Pg=14.5, Qg=-5.0
% INFO    : Gen at bus 1976	: Vg=1.014 -> Vg=0.999999
% INFO    : Gen at bus 1978	: Vg=1.051 -> Vg=1.0000025
% INFO    : Gen at bus 1980	: Pg=0.5, Qg=0.02 -> Pg=2.55, Qg=0.0
% INFO    : Gen at bus 1980	: Vg=1.041 -> Vg=1.0000025
% INFO    : Gen at bus 1980	: Vg=1.041 -> Vg=1.0000025
% INFO    : Gen at bus 1986	: Vg=1.051 -> Vg=0.999999
% INFO    : Gen at bus 1994	: Vg=0.967 -> Vg=0.9444445
% INFO    : Gen at bus 2001	: Pg=40.12, Qg=17.67 -> Pg=23.0, Qg=6.0
% INFO    : Gen at bus 2001	: Vg=1.031 -> Vg=1.0158755
% INFO    : Gen at bus 2012	: Pg=13.99, Qg=-7.8 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2012	: Vg=1.033 -> Vg=1.0000025
% INFO    : Gen at bus 2013	: Pg=14.07, Qg=-1.54 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2013	: Vg=1.037 -> Vg=1.0000025
% INFO    : Gen at bus 2013	: Pg=14.07, Qg=-1.54 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2013	: Vg=1.037 -> Vg=1.0000025
% INFO    : Gen at bus 2018	: Vg=1.032 -> Vg=1.027779
% INFO    : Gen at bus 2022	: Pg=19.35, Qg=4.07 -> Pg=0.0, Qg=0.0
% INFO    : Gen at bus 2022	: Vg=1.055 -> Vg=1.000001
% INFO    : Gen at bus 2030	: Vg=1.025 -> Vg=1.0079355
% INFO    : Gen at bus 2044	: Pg=27.41, Qg=0.06 -> Pg=17.0, Qg=1.5
% INFO    : Gen at bus 2044	: Vg=1.03 -> Vg=0.999999
% INFO    : Gen at bus 2054	: Vg=1.026 -> Vg=1.0000025
% INFO    : Gen at bus 2078	: Vg=1.079 -> Vg=1.0000025
% INFO    : Gen at bus 2091	: Vg=1.026 -> Vg=1.0079355
% INFO    : Gen at bus 2092	: Pg=37.31, Qg=1.74 -> Pg=27.5, Qg=6.0
% INFO    : Gen at bus 2092	: Vg=1.058 -> Vg=1.022222
% INFO    : Gen at bus 2096	: Pg=3.64, Qg=4.39 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 2096	: Vg=1.029 -> Vg=1.0079355
% INFO    : Gen at bus 2116	: Vg=1.033 -> Vg=1.0079355
% INFO    : Gen at bus 2116	: Vg=1.033 -> Vg=1.0079355
% INFO    : Gen at bus 2144	: Vg=1.039 -> Vg=1.022224
% INFO    : Gen at bus 2144	: Vg=1.039 -> Vg=1.022224
% INFO    : Gen at bus 2154	: Pg=12.24, Qg=9.86 -> Pg=14.5, Qg=3.5
% INFO    : Gen at bus 2154	: Vg=1.066 -> Vg=1.027779
% INFO    : Gen at bus 2158	: Pg=39.76, Qg=-2.03 -> Pg=22.5, Qg=6.0
% INFO    : Gen at bus 2158	: Vg=1.022 -> Vg=1.0000005
% INFO    : Gen at bus 2159	: Vg=1.065 -> Vg=1.033333
% INFO    : Gen at bus 2175	: Vg=1.052 -> Vg=1.0000025
% INFO    : Gen at bus 2175	: Vg=1.052 -> Vg=1.0000025
% INFO    : Gen at bus 2180	: Vg=1.053 -> Vg=1.027779
% INFO    : Gen at bus 2183	: Vg=1.025 -> Vg=0.9682545
% INFO    : Gen at bus 2183	: Vg=1.025 -> Vg=0.9682545
% INFO    : Gen at bus 2185	: Vg=1.067 -> Vg=1.022222
% INFO    : Gen at bus 2186	: Pg=5.45, Qg=5.75 -> Pg=7.5, Qg=0.0
% INFO    : Gen at bus 2186	: Vg=0.965 -> Vg=0.9444445
% INFO    : Gen at bus 2188	: Pg=11.61, Qg=2.0 -> Pg=10.0, Qg=1.95
% INFO    : Gen at bus 2188	: Vg=1.068 -> Vg=1.000001
% INFO    : Gen at bus 2219	: Vg=1.056 -> Vg=1.022222
% INFO    : Gen at bus 2219	: Vg=1.056 -> Vg=1.022222
% INFO    : Gen at bus 2238	: Vg=1.016 -> Vg=1.0158755
% INFO    : Gen at bus 2238	: Pg=10.21, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 2238	: Vg=1.016 -> Vg=1.0158755
% INFO    : Gen at bus 2240	: Vg=1.077 -> Vg=0.975
% INFO    : Gen at bus 2240	: Pg=2.5, Qg=2.01 -> Pg=13.25, Qg=0.0
% INFO    : Gen at bus 2240	: Vg=1.077 -> Vg=0.975
% INFO    : Gen at bus 2274	: Vg=1.021 -> Vg=1.0158755
% INFO    : Gen at bus 2284	: Vg=1.05 -> Vg=1.022224
% INFO    : Gen at bus 2288	: Vg=1.007 -> Vg=1.0000005
% INFO    : Gen at bus 2290	: Pg=-4.65, Qg=2.94 -> Pg=0.0, Qg=0.0
% INFO    : Gen at bus 2290	: Vg=1.014 -> Vg=1.0000005
% INFO    : Gen at bus 2296	: Vg=1.028 -> Vg=1.0158755
% INFO    : Gen at bus 2296	: Vg=1.028 -> Vg=1.0158755
% INFO    : Gen at bus 2322	: Pg=1.12, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2322	: Vg=1.034 -> Vg=1.0158755
% INFO    : Gen at bus 2328	: Vg=1.029 -> Vg=1.015872
% INFO    : Gen at bus 2332	: Vg=1.044 -> Vg=1.0079355
% INFO    : Gen at bus 2334	: Pg=13.08, Qg=-5.22 -> Pg=14.0, Qg=1.5
% INFO    : Gen at bus 2334	: Vg=0.988 -> Vg=1.015872
% INFO    : Gen at bus 2334	: Pg=11.08, Qg=-5.22 -> Pg=14.0, Qg=1.5
% INFO    : Gen at bus 2334	: Vg=0.988 -> Vg=1.015872
% INFO    : Gen at bus 2334	: Pg=15.08, Qg=-5.22 -> Pg=14.0, Qg=1.5
% INFO    : Gen at bus 2334	: Vg=0.988 -> Vg=1.015872
% INFO    : Gen at bus 2335	: Vg=1.056 -> Vg=1.0000025
% INFO    : Gen at bus 2335	: Vg=1.056 -> Vg=1.0000025
% INFO    : Gen at bus 2336	: Vg=1.031 -> Vg=1.022224
% INFO    : Gen at bus 2357	: Pg=19.25, Qg=8.29 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2357	: Vg=1.101 -> Vg=0.975
% INFO    : Gen at bus 2358	: Pg=19.25, Qg=8.28 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2358	: Vg=1.101 -> Vg=0.975
% INFO    : Gen at bus 2359	: Pg=13.58, Qg=-2.09 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2359	: Vg=1.084 -> Vg=0.975
% INFO    : Gen at bus 2360	: Pg=19.04, Qg=8.68 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2360	: Vg=1.102 -> Vg=0.975
% INFO    : Gen at bus 2361	: Pg=15.25, Qg=9.6 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 2361	: Vg=1.104 -> Vg=0.975
% INFO    : Gen at bus 2371	: Vg=1.02 -> Vg=1.0158755
% INFO    : Gen at bus 2387	: Pg=2.07, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2387	: Vg=1.03 -> Vg=1.0000025
% INFO    : Gen at bus 2389	: Pg=3.02, Qg=0.0 -> Pg=17.45, Qg=0.0
% INFO    : Gen at bus 2389	: Vg=1.014 -> Vg=1.0000025
% INFO    : Gen at bus 2389	: Vg=1.014 -> Vg=1.0000025
% INFO    : Gen at bus 2405	: Pg=8.79, Qg=1.93 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 2405	: Vg=1.061 -> Vg=1.000001
% INFO    : Gen at bus 2407	: Vg=1.026 -> Vg=1.0079355
% INFO    : Gen at bus 2407	: Vg=1.026 -> Vg=1.0079355
% INFO    : Gen at bus 2414	: Vg=1.023 -> Vg=1.0158755
% INFO    : Gen at bus 2414	: Vg=1.023 -> Vg=1.0158755
% INFO    : Gen at bus 2414	: Vg=1.023 -> Vg=1.0158755
% INFO    : Gen at bus 2426	: Vg=1.029 -> Vg=1.0079355
% INFO    : Gen at bus 2430	: Pg=1.16, Qg=0.0 -> Pg=11.3, Qg=0.0
% INFO    : Gen at bus 2430	: Vg=1.036 -> Vg=0.999999
% INFO    : Gen at bus 2430	: Vg=1.036 -> Vg=0.999999
% INFO    : Gen at bus 2433	: Vg=1.041 -> Vg=0.999999
% INFO    : Gen at bus 2433	: Vg=1.041 -> Vg=0.999999
% INFO    : Gen at bus 2438	: Vg=1.024 -> Vg=1.0079355
% INFO    : Gen at bus 2437	: Vg=1.02 -> Vg=1.0079355
% INFO    : Gen at bus 2453	: Vg=1.095 -> Vg=1.047355
% INFO    : Gen at bus 2454	: Vg=1.003 -> Vg=1.015872
% INFO    : Gen at bus 2454	: Vg=1.003 -> Vg=1.015872
% INFO    : Gen at bus 2457	: Vg=1.007 -> Vg=1.022224
% INFO    : Gen at bus 2468	: Vg=1.041 -> Vg=0.999999
% INFO    : Gen at bus 2474	: Pg=18.13, Qg=0.0 -> Pg=13.0, Qg=0.0
% INFO    : Gen at bus 2474	: Vg=1.063 -> Vg=1.0000025
% INFO    : Gen at bus 2488	: Vg=1.023 -> Vg=1.015872
% INFO    : Gen at bus 2516	: Pg=39.32, Qg=3.4 -> Pg=44.0, Qg=5.5
% INFO    : Gen at bus 2516	: Vg=1.145 -> Vg=1.053858
% INFO    : Gen at bus 2516	: Pg=40.32, Qg=3.4 -> Pg=44.0, Qg=5.5
% INFO    : Gen at bus 2516	: Vg=1.145 -> Vg=1.053858
% INFO    : Gen at bus 2522	: Pg=10.03, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 2522	: Vg=1.01 -> Vg=1.0000025
% INFO    : Gen at bus 2522	: Pg=13.03, Qg=0.0 -> Pg=18.425, Qg=0.0
% INFO    : Gen at bus 2522	: Vg=1.01 -> Vg=1.0000025
% INFO    : Gen at bus 2523	: Vg=1.025 -> Vg=1.0000025
% INFO    : Gen at bus 2523	: Vg=1.025 -> Vg=1.0000025
% INFO    : Gen at bus 2525	: Pg=3.93, Qg=1.01 -> Pg=4.8, Qg=0.135
% INFO    : Gen at bus 2525	: Vg=1.034 -> Vg=1.0158755
% INFO    : Gen at bus 2538	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 2540	: Vg=1.047 -> Vg=0.999999
% INFO    : Gen at bus 2548	: Vg=1.039 -> Vg=1.0000025
% INFO    : Gen at bus 2548	: Pg=3.21, Qg=0.0 -> Pg=17.0, Qg=0.0
% INFO    : Gen at bus 2548	: Vg=1.039 -> Vg=1.0000025
% INFO    : Gen at bus 2551	: Pg=4.45, Qg=1.01 -> Pg=8.0, Qg=1.5
% INFO    : Gen at bus 2551	: Vg=1.025 -> Vg=0.999999
% INFO    : Gen at bus 2556	: Vg=1.029 -> Vg=1.0079355
% INFO    : Gen at bus 2569	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 2569	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 2574	: Vg=1.051 -> Vg=1.022224
% INFO    : Gen at bus 2579	: Vg=1.026 -> Vg=1.022224
% INFO    : Gen at bus 2579	: Vg=1.026 -> Vg=1.022224
% INFO    : Gen at bus 2585	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 2594	: Vg=1.031 -> Vg=1.0079355
% INFO    : Gen at bus 2594	: Vg=1.031 -> Vg=1.0079355
% INFO    : Gen at bus 2603	: Pg=13.02, Qg=0.0 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 2603	: Vg=1.045 -> Vg=1.0000025
% INFO    : Gen at bus 2604	: Vg=1.005 -> Vg=1.015872
% INFO    : Gen at bus 2609	: Vg=1.036 -> Vg=1.022224
% INFO    : Gen at bus 2617	: Vg=1.06 -> Vg=1.0111115
% INFO    : Gen at bus 2617	: Vg=1.06 -> Vg=1.0111115
% INFO    : Gen at bus 2620	: Pg=5.96, Qg=-0.44 -> Pg=14.0, Qg=4.5
% INFO    : Gen at bus 2620	: Vg=1.012 -> Vg=1.0158755
% INFO    : Gen at bus 2633	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 2633	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 2633	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 2636	: Vg=1.012 -> Vg=1.0000025
% INFO    : Gen at bus 2637	: Pg=13.11, Qg=-8.71 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 2637	: Vg=1.012 -> Vg=1.0000025
% INFO    : Gen at bus 2638	: Vg=1.052 -> Vg=1.0000025
% INFO    : Gen at bus 2638	: Pg=11.21, Qg=0.7 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 2638	: Vg=1.052 -> Vg=1.0000025
% INFO    : Gen at bus 2638	: Pg=1.21, Qg=0.7 -> Pg=14.5, Qg=-4.0
% INFO    : Gen at bus 2638	: Vg=1.052 -> Vg=1.0000025
% INFO    : Gen at bus 2639	: Vg=1.094 -> Vg=1.0074025
% INFO    : Gen at bus 2639	: Vg=1.094 -> Vg=1.0074025
% INFO    : Gen at bus 2639	: Vg=1.094 -> Vg=1.0074025
% INFO    : Gen at bus 2642	: Pg=0.16, Qg=0.0 -> Pg=17.5, Qg=0.0
% INFO    : Gen at bus 2642	: Vg=1.023 -> Vg=1.0158755
% INFO    : Gen at bus 2642	: Vg=1.023 -> Vg=1.0158755
% INFO    : Gen at bus 2645	: Pg=2.18, Qg=4.0 -> Pg=14.0, Qg=3.95
% INFO    : Gen at bus 2645	: Vg=1.064 -> Vg=1.0000025
% INFO    : Gen at bus 2652	: Vg=1.031 -> Vg=0.999999
% INFO    : Gen at bus 2652	: Pg=5.06, Qg=-0.15 -> Pg=4.9, Qg=0.0
% INFO    : Gen at bus 2652	: Vg=1.031 -> Vg=0.999999
% INFO    : Gen at bus 2653	: Pg=27.28, Qg=5.12 -> Pg=17.5, Qg=-1.5
% INFO    : Gen at bus 2653	: Vg=1.021 -> Vg=1.015872
% INFO    : Gen at bus 2653	: Pg=28.28, Qg=5.12 -> Pg=17.5, Qg=-1.5
% INFO    : Gen at bus 2653	: Vg=1.021 -> Vg=1.015872
% INFO    : Gen at bus 2656	: Vg=1.058 -> Vg=0.975
% INFO    : Gen at bus 2657	: Pg=1.18, Qg=1.0 -> Pg=3.5, Qg=0.95
% INFO    : Gen at bus 2657	: Vg=1.095 -> Vg=0.975
% INFO    : Gen at bus 2656	: Vg=1.058 -> Vg=0.975
% INFO    : Gen at bus 2655	: Vg=1.093 -> Vg=0.975
% INFO    : Gen at bus 2657	: Vg=1.095 -> Vg=0.975
% INFO    : Gen at bus 2658	: Pg=4.07, Qg=4.26 -> Pg=6.0, Qg=-1.37
% INFO    : Gen at bus 2658	: Vg=1.058 -> Vg=1.0000025
% INFO    : Gen at bus 2662	: Vg=0.617 -> Vg=0.825
% INFO    : Gen at bus 2662	: Vg=0.617 -> Vg=0.825
% INFO    : Gen at bus 2662	: Vg=0.617 -> Vg=0.825
% INFO    : Gen at bus 2662	: Vg=0.617 -> Vg=0.825
% INFO    : Gen at bus 2662	: Vg=0.617 -> Vg=0.825
% INFO    : Gen at bus 2667	: Vg=1.008 -> Vg=1.0079355
% INFO    : Gen at bus 2681	: Pg=0.2, Qg=0.0 -> Pg=18.2, Qg=0.0
% INFO    : Gen at bus 2681	: Vg=1.071 -> Vg=1.033333
% INFO    : Gen at bus 2688	: Pg=3.53, Qg=-4.9 -> Pg=7.5, Qg=-0.5
% INFO    : Gen at bus 2688	: Vg=1.028 -> Vg=1.0000005
% INFO    : Gen at bus 2722	: Vg=1.046 -> Vg=1.022224
% INFO    : Gen at bus 2727	: Pg=2.2, Qg=0.15 -> Pg=8.5, Qg=0.0
% INFO    : Gen at bus 2727	: Vg=1.062 -> Vg=1.000001
% INFO    : Gen at bus 2727	: Pg=2.2, Qg=0.15 -> Pg=8.5, Qg=0.0
% INFO    : Gen at bus 2727	: Vg=1.062 -> Vg=1.000001
% INFO    : Gen at bus 2759	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 2769	: Vg=1.031 -> Vg=1.0158755
% INFO    : Gen at bus 2805	: Vg=1.04 -> Vg=1.022224
% INFO    : Gen at bus 2806	: Pg=5.19, Qg=0.0 -> Pg=8.075, Qg=0.0
% INFO    : Gen at bus 2806	: Vg=1.022 -> Vg=0.984126
% INFO    : Gen at bus 2811	: Vg=1.063 -> Vg=1.0000025
% INFO    : Gen at bus 2815	: Vg=1.057 -> Vg=1.022224
% INFO    : Gen at bus 2826	: Pg=6.15, Qg=4.12 -> Pg=6.0, Qg=1.5
% INFO    : Gen at bus 2826	: Vg=1.015 -> Vg=1.0000005
% INFO    : Gen at bus 2831	: Vg=1.048 -> Vg=1.033334
% INFO    : Gen at bus 2833	: Pg=3.19, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 2833	: Vg=1.043 -> Vg=1.022224
% INFO    : Gen at bus 2833	: Vg=1.043 -> Vg=1.022224
% INFO    : Gen at bus 2836	: Vg=1.012 -> Vg=1.022224
% INFO    : Gen at bus 2836	: Pg=0.93, Qg=0.0 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 2836	: Vg=1.012 -> Vg=1.022224
% INFO    : Gen at bus 2838	: Vg=1.034 -> Vg=0.999999
% INFO    : Gen at bus 2838	: Vg=1.034 -> Vg=0.999999
% INFO    : Gen at bus 2850	: Vg=1.041 -> Vg=1.0079355
% INFO    : Gen at bus 2861	: Vg=1.032 -> Vg=1.022224
% INFO    : Gen at bus 2867	: Vg=1.07 -> Vg=1.027779
% INFO    : Gen at bus 2869	: Vg=1.028 -> Vg=1.022224
% INFO    : Gen at bus 2869	: Vg=1.028 -> Vg=1.022224
% INFO    : Gen at bus 2877	: Vg=1.032 -> Vg=1.0158755
% INFO    : Gen at bus 2892	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 2892	: Pg=4.0, Qg=2.11 -> Pg=16.25, Qg=0.0
% INFO    : Gen at bus 2892	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 2892	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 2897	: Vg=1.1 -> Vg=1.0
% INFO    : Gen at bus 2897	: Vg=1.1 -> Vg=1.0
% INFO    : Gen at bus 2897	: Vg=1.1 -> Vg=1.0
% INFO    : Gen at bus 2901	: Vg=1.027 -> Vg=1.0000025
% INFO    : Gen at bus 2921	: Vg=1.011 -> Vg=0.999999
% INFO    : Gen at bus 2922	: Vg=1.045 -> Vg=1.000001
% INFO    : Gen at bus 2934	: Vg=1.017 -> Vg=1.022224
% INFO    : Gen at bus 2941	: Vg=1.002 -> Vg=1.0158755
% INFO    : Gen at bus 2947	: Vg=1.057 -> Vg=1.022224
% INFO    : Gen at bus 2947	: Vg=1.057 -> Vg=1.022224
% INFO    : Gen at bus 2968	: Vg=1.031 -> Vg=1.0158755
% INFO    : Gen at bus 2975	: Vg=1.067 -> Vg=1.027779
% INFO    : Gen at bus 2986	: Pg=10.21, Qg=-3.33 -> Pg=17.0, Qg=0.0
% INFO    : Gen at bus 2986	: Vg=1.051 -> Vg=0.999999
% INFO    : Gen at bus 3013	: Vg=1.029 -> Vg=1.0158755
% INFO    : Gen at bus 3013	: Vg=1.029 -> Vg=1.0158755
% INFO    : Gen at bus 3014	: Vg=1.026 -> Vg=0.999999
% INFO    : Gen at bus 3015	: Vg=1.048 -> Vg=1.002359
% INFO    : Gen at bus 3015	: Pg=8.07, Qg=-3.06 -> Pg=6.5, Qg=0.0
% INFO    : Gen at bus 3015	: Vg=1.048 -> Vg=1.002359
% INFO    : Gen at bus 3017	: Vg=1.035 -> Vg=1.022224
% INFO    : Gen at bus 3020	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 3020	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 3022	: Vg=1.056 -> Vg=1.022222
% INFO    : Gen at bus 3029	: Vg=1.015 -> Vg=1.015872
% INFO    : Gen at bus 3031	: Vg=1.08 -> Vg=1.044445
% INFO    : Gen at bus 3042	: Pg=2.17, Qg=0.0 -> Pg=8.0, Qg=0.0
% INFO    : Gen at bus 3042	: Vg=1.006 -> Vg=1.015872
% INFO    : Gen at bus 3052	: Vg=1.042 -> Vg=0.999999
% INFO    : Gen at bus 3053	: Vg=1.042 -> Vg=1.022224
% INFO    : Gen at bus 3063	: Pg=4.06, Qg=0.0 -> Pg=8.625, Qg=0.0
% INFO    : Gen at bus 3063	: Vg=0.997 -> Vg=1.015872
% INFO    : Gen at bus 3091	: Pg=3.22, Qg=-1.39 -> Pg=9.75, Qg=-2.5
% INFO    : Gen at bus 3091	: Vg=0.98 -> Vg=0.9444445
% INFO    : Gen at bus 3100	: Vg=1.033 -> Vg=0.999999
% INFO    : Gen at bus 3103	: Vg=1.061 -> Vg=1.0377785
% INFO    : Gen at bus 3106	: Vg=1.028 -> Vg=1.0079355
% INFO    : Gen at bus 3109	: Pg=33.3, Qg=0.69 -> Pg=19.0, Qg=0.5
% INFO    : Gen at bus 3109	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 3110	: Pg=28.79, Qg=9.8 -> Pg=19.0, Qg=0.5
% INFO    : Gen at bus 3110	: Vg=1.097 -> Vg=0.975
% INFO    : Gen at bus 3111	: Pg=30.78, Qg=4.92 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 3111	: Vg=1.081 -> Vg=0.975
% INFO    : Gen at bus 3115	: Vg=1.046 -> Vg=1.022224
% INFO    : Gen at bus 3116	: Vg=1.047 -> Vg=0.999999
% INFO    : Gen at bus 3116	: Vg=1.047 -> Vg=0.999999
% INFO    : Gen at bus 3118	: Vg=1.026 -> Vg=0.999999
% INFO    : Gen at bus 3119	: Vg=1.03 -> Vg=1.0000025
% INFO    : Gen at bus 3124	: Vg=0.986 -> Vg=1.015872
% INFO    : Gen at bus 3125	: Vg=1.023 -> Vg=1.022224
% INFO    : Gen at bus 3125	: Vg=1.023 -> Vg=1.022224
% INFO    : Gen at bus 3129	: Pg=4.65, Qg=1.0 -> Pg=5.5, Qg=0.95
% INFO    : Gen at bus 3129	: Vg=1.073 -> Vg=1.000001
% INFO    : Gen at bus 3129	: Pg=4.65, Qg=0.1 -> Pg=7.0, Qg=0.0
% INFO    : Gen at bus 3129	: Vg=1.073 -> Vg=1.000001
% INFO    : Gen at bus 3133	: Vg=1.068 -> Vg=1.0377785
% INFO    : Gen at bus 3133	: Vg=1.068 -> Vg=1.0377785
% INFO    : Gen at bus 3135	: Vg=1.05 -> Vg=1.0000025
% INFO    : Gen at bus 3140	: Pg=1.0, Qg=0.0 -> Pg=5.25, Qg=0.0
% INFO    : Gen at bus 3140	: Vg=1.021 -> Vg=1.0000025
% INFO    : Gen at bus 3140	: Pg=2.0, Qg=0.0 -> Pg=4.3, Qg=0.0
% INFO    : Gen at bus 3140	: Vg=1.021 -> Vg=1.0000025
% INFO    : Gen at bus 3144	: Vg=1.015 -> Vg=1.0158755
% INFO    : Gen at bus 3150	: Pg=39.29, Qg=-1.73 -> Pg=26.5, Qg=6.0
% INFO    : Gen at bus 3150	: Vg=1.06 -> Vg=1.0111115
% INFO    : Gen at bus 3152	: Pg=5.05, Qg=1.0 -> Pg=8.0, Qg=0.95
% INFO    : Gen at bus 3152	: Vg=1.076 -> Vg=1.000001
% INFO    : Gen at bus 3152	: Pg=5.05, Qg=1.0 -> Pg=8.0, Qg=0.95
% INFO    : Gen at bus 3152	: Vg=1.076 -> Vg=1.000001
% INFO    : Gen at bus 3152	: Pg=3.19, Qg=2.78 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 3152	: Vg=1.076 -> Vg=1.000001
% INFO    : Gen at bus 3171	: Vg=1.018 -> Vg=1.0
% INFO    : Gen at bus 3171	: Vg=1.018 -> Vg=1.0
% INFO    : Gen at bus 3178	: Vg=1.042 -> Vg=1.000001
% INFO    : Gen at bus 3178	: Vg=1.042 -> Vg=1.000001
% INFO    : Gen at bus 3181	: Pg=2.18, Qg=0.0 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 3181	: Vg=1.068 -> Vg=1.006729
% INFO    : Gen at bus 3181	: Vg=1.068 -> Vg=1.006729
% INFO    : Gen at bus 3203	: Pg=6.19, Qg=1.98 -> Pg=10.0, Qg=1.0
% INFO    : Gen at bus 3203	: Vg=1.098 -> Vg=1.0
% INFO    : Gen at bus 3212	: Pg=1.07, Qg=0.0 -> Pg=11.3, Qg=0.0
% INFO    : Gen at bus 3212	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 3212	: Pg=0.07, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3212	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 3231	: Vg=1.013 -> Vg=1.0158755
% INFO    : Gen at bus 3232	: Pg=13.61, Qg=2.0 -> Pg=11.0, Qg=1.95
% INFO    : Gen at bus 3232	: Vg=1.07 -> Vg=1.000001
% INFO    : Gen at bus 3234	: Vg=1.011 -> Vg=0.999999
% INFO    : Gen at bus 3237	: Vg=1.054 -> Vg=1.027779
% INFO    : Gen at bus 3239	: Pg=4.93, Qg=-2.66 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 3239	: Vg=1.041 -> Vg=1.0000025
% INFO    : Gen at bus 3243	: Vg=1.039 -> Vg=1.022224
% INFO    : Gen at bus 3253	: Vg=1.054 -> Vg=1.027779
% INFO    : Gen at bus 3257	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 3258	: Pg=1.16, Qg=0.0 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 3258	: Vg=1.038 -> Vg=1.022224
% INFO    : Gen at bus 3258	: Pg=3.16, Qg=0.0 -> Pg=16.35, Qg=0.0
% INFO    : Gen at bus 3258	: Vg=1.038 -> Vg=1.022224
% INFO    : Gen at bus 3258	: Vg=1.038 -> Vg=1.022224
% INFO    : Gen at bus 3259	: Pg=12.46, Qg=8.96 -> Pg=21.0, Qg=2.5
% INFO    : Gen at bus 3259	: Vg=1.055 -> Vg=1.0
% INFO    : Gen at bus 3259	: Pg=15.71, Qg=8.96 -> Pg=21.0, Qg=2.5
% INFO    : Gen at bus 3259	: Vg=1.055 -> Vg=1.0
% INFO    : Gen at bus 3269	: Vg=1.038 -> Vg=1.0000025
% INFO    : Gen at bus 3269	: Vg=1.038 -> Vg=1.0000025
% INFO    : Gen at bus 3273	: Pg=30.95, Qg=12.01 -> Pg=18.05, Qg=2.5
% INFO    : Gen at bus 3273	: Vg=1.122 -> Vg=0.975
% INFO    : Gen at bus 3274	: Pg=31.4, Qg=12.97 -> Pg=18.05, Qg=2.5
% INFO    : Gen at bus 3274	: Vg=1.075 -> Vg=0.975
% INFO    : Gen at bus 3275	: Pg=31.4, Qg=4.12 -> Pg=18.05, Qg=2.5
% INFO    : Gen at bus 3275	: Vg=1.052 -> Vg=0.975
% INFO    : Gen at bus 3288	: Vg=1.026 -> Vg=0.999999
% INFO    : Gen at bus 3294	: Pg=4.89, Qg=0.86 -> Pg=6.5, Qg=0.0
% INFO    : Gen at bus 3294	: Vg=1.054 -> Vg=1.021232
% INFO    : Gen at bus 3301	: Pg=3.93, Qg=1.0 -> Pg=8.5, Qg=0.95
% INFO    : Gen at bus 3301	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 3301	: Pg=3.93, Qg=1.0 -> Pg=8.5, Qg=0.95
% INFO    : Gen at bus 3301	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 3306	: Vg=1.032 -> Vg=0.999999
% INFO    : Gen at bus 3306	: Pg=2.23, Qg=0.0 -> Pg=5.1, Qg=0.0
% INFO    : Gen at bus 3306	: Vg=1.032 -> Vg=0.999999
% INFO    : Gen at bus 3308	: Vg=1.049 -> Vg=1.022224
% INFO    : Gen at bus 3308	: Vg=1.049 -> Vg=1.022224
% INFO    : Gen at bus 3332	: Vg=1.017 -> Vg=1.022224
% INFO    : Gen at bus 3338	: Vg=1.041 -> Vg=0.999999
% INFO    : Gen at bus 3370	: Vg=1.048 -> Vg=1.027779
% INFO    : Gen at bus 3370	: Vg=1.048 -> Vg=1.027779
% INFO    : Gen at bus 3375	: Pg=1.14, Qg=0.0 -> Pg=19.9, Qg=0.0
% INFO    : Gen at bus 3375	: Vg=1.06 -> Vg=1.0111115
% INFO    : Gen at bus 3376	: Vg=1.07 -> Vg=1.0027125
% INFO    : Gen at bus 3398	: Pg=38.13, Qg=14.88 -> Pg=21.5, Qg=6.0
% INFO    : Gen at bus 3398	: Vg=1.043 -> Vg=1.0158755
% INFO    : Gen at bus 3401	: Pg=7.71, Qg=-6.41 -> Pg=12.0, Qg=-0.26
% INFO    : Gen at bus 3401	: Vg=1.061 -> Vg=1.004029
% INFO    : Gen at bus 3411	: Vg=1.043 -> Vg=1.0000025
% INFO    : Gen at bus 3411	: Pg=2.24, Qg=1.0 -> Pg=3.75, Qg=0.0
% INFO    : Gen at bus 3411	: Vg=1.043 -> Vg=1.0000025
% INFO    : Gen at bus 3411	: Vg=1.043 -> Vg=1.0000025
% INFO    : Gen at bus 3411	: Pg=2.24, Qg=1.0 -> Pg=3.75, Qg=0.0
% INFO    : Gen at bus 3411	: Vg=1.043 -> Vg=1.0000025
% INFO    : Gen at bus 3411	: Vg=1.043 -> Vg=1.0000025
% INFO    : Gen at bus 3416	: Vg=1.046 -> Vg=1.022224
% INFO    : Gen at bus 3416	: Vg=1.046 -> Vg=1.022224
% INFO    : Gen at bus 3417	: Pg=12.68, Qg=-2.56 -> Pg=11.55, Qg=0.0
% INFO    : Gen at bus 3417	: Vg=1.013 -> Vg=0.999999
% INFO    : Gen at bus 3417	: Pg=12.68, Qg=-2.56 -> Pg=11.55, Qg=0.0
% INFO    : Gen at bus 3417	: Vg=1.013 -> Vg=0.999999
% INFO    : Gen at bus 3424	: Vg=0.998 -> Vg=1.015872
% INFO    : Gen at bus 3427	: Vg=1.03 -> Vg=1.022224
% INFO    : Gen at bus 3430	: Vg=1.047 -> Vg=1.022224
% INFO    : Gen at bus 3433	: Vg=1.054 -> Vg=1.0079355
% INFO    : Gen at bus 3433	: Vg=1.054 -> Vg=1.0079355
% INFO    : Gen at bus 3438	: Vg=1.038 -> Vg=1.0079355
% INFO    : Gen at bus 3443	: Vg=1.048 -> Vg=1.0079355
% INFO    : Gen at bus 3444	: Vg=1.04 -> Vg=1.0079355
% INFO    : Gen at bus 3447	: Vg=1.067 -> Vg=1.027804
% INFO    : Gen at bus 3454	: Pg=0.97, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3454	: Vg=1.01 -> Vg=1.0158755
% INFO    : Gen at bus 3461	: Pg=7.33, Qg=-2.6 -> Pg=6.6, Qg=0.0
% INFO    : Gen at bus 3461	: Vg=1.028 -> Vg=0.999999
% INFO    : Gen at bus 3481	: Vg=1.035 -> Vg=1.0079355
% INFO    : Gen at bus 3484	: Vg=1.095 -> Vg=1.0
% INFO    : Gen at bus 3484	: Pg=28.58, Qg=-8.11 -> Pg=26.5, Qg=3.5
% INFO    : Gen at bus 3484	: Vg=1.095 -> Vg=1.0
% INFO    : Gen at bus 3488	: Vg=1.021 -> Vg=1.0079355
% INFO    : Gen at bus 3497	: Pg=22.02, Qg=-14.52 -> Pg=17.5, Qg=-0.585
% INFO    : Gen at bus 3497	: Vg=1.048 -> Vg=1.044445
% INFO    : Gen at bus 3498	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 3500	: Vg=1.054 -> Vg=0.999999
% INFO    : Gen at bus 3501	: Vg=1.047 -> Vg=0.999999
% INFO    : Gen at bus 3506	: Pg=19.11, Qg=0.0 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 3506	: Vg=1.037 -> Vg=1.0158755
% INFO    : Gen at bus 3506	: Vg=1.037 -> Vg=1.0158755
% INFO    : Gen at bus 3514	: Pg=0.55, Qg=-13.93 -> Pg=13.1, Qg=0.0
% INFO    : Gen at bus 3514	: Vg=1.058 -> Vg=0.999999
% INFO    : Gen at bus 3523	: Pg=5.12, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 3523	: Vg=0.999 -> Vg=1.015872
% INFO    : Gen at bus 3537	: Pg=3.85, Qg=-1.14 -> Pg=6.4, Qg=0.0
% INFO    : Gen at bus 3537	: Vg=1.048 -> Vg=0.999999
% INFO    : Gen at bus 3538	: Vg=1.057 -> Vg=1.0079355
% INFO    : Gen at bus 3543	: Vg=1.037 -> Vg=1.0158755
% INFO    : Gen at bus 3543	: Vg=1.037 -> Vg=1.0158755
% INFO    : Gen at bus 3543	: Vg=1.037 -> Vg=1.0158755
% INFO    : Gen at bus 3542	: Vg=1.122 -> Vg=1.0402155
% INFO    : Gen at bus 3577	: Vg=1.049 -> Vg=1.027779
% INFO    : Gen at bus 3580	: Pg=14.71, Qg=-3.04 -> Pg=10.4, Qg=-2.0
% INFO    : Gen at bus 3580	: Vg=1.027 -> Vg=0.975
% INFO    : Gen at bus 3580	: Pg=14.71, Qg=-3.04 -> Pg=10.4, Qg=0.0
% INFO    : Gen at bus 3580	: Vg=1.027 -> Vg=0.975
% INFO    : Gen at bus 3579	: Vg=1.038 -> Vg=0.975
% INFO    : Gen at bus 3579	: Pg=15.22, Qg=-2.7 -> Pg=10.4, Qg=0.0
% INFO    : Gen at bus 3579	: Vg=1.038 -> Vg=0.975
% INFO    : Gen at bus 3593	: Pg=11.83, Qg=-1.8 -> Pg=11.5, Qg=0.5
% INFO    : Gen at bus 3593	: Vg=1.077 -> Vg=1.000001
% INFO    : Gen at bus 3593	: Pg=11.83, Qg=-1.8 -> Pg=11.5, Qg=0.5
% INFO    : Gen at bus 3593	: Vg=1.077 -> Vg=1.000001
% INFO    : Gen at bus 3593	: Pg=12.81, Qg=-1.8 -> Pg=11.5, Qg=0.5
% INFO    : Gen at bus 3593	: Vg=1.077 -> Vg=1.000001
% INFO    : Gen at bus 3597	: Pg=10.8, Qg=1.43 -> Pg=0.0, Qg=10.0
% INFO    : Gen at bus 3597	: Vg=1.021 -> Vg=0.999999
% INFO    : Gen at bus 3597	: Pg=10.8, Qg=1.43 -> Pg=0.0, Qg=0.0
% INFO    : Gen at bus 3597	: Vg=1.021 -> Vg=0.999999
% INFO    : Gen at bus 3629	: Vg=1.061 -> Vg=1.006809
% INFO    : Gen at bus 3639	: Pg=0.09, Qg=0.0 -> Pg=7.445, Qg=0.0
% INFO    : Gen at bus 3639	: Vg=0.999 -> Vg=1.0000025
% INFO    : Gen at bus 3639	: Pg=27.09, Qg=0.0 -> Pg=17.385, Qg=0.0
% INFO    : Gen at bus 3639	: Vg=0.999 -> Vg=1.0000025
% INFO    : Gen at bus 3642	: Vg=1.008 -> Vg=1.022224
% INFO    : Gen at bus 3644	: Pg=0.0, Qg=1.0 -> Pg=3.5, Qg=0.95
% INFO    : Gen at bus 3644	: Vg=1.053 -> Vg=1.0000025
% INFO    : Gen at bus 3644	: Pg=0.0, Qg=1.0 -> Pg=3.5, Qg=0.95
% INFO    : Gen at bus 3644	: Vg=1.053 -> Vg=1.0000025
% INFO    : Gen at bus 3645	: Vg=1.038 -> Vg=1.0158755
% INFO    : Gen at bus 3650	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 3653	: Vg=1.035 -> Vg=1.0158755
% INFO    : Gen at bus 3654	: Vg=1.031 -> Vg=1.0079355
% INFO    : Gen at bus 3659	: Pg=5.72, Qg=-0.82 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3659	: Vg=1.013 -> Vg=0.999999
% INFO    : Gen at bus 3659	: Pg=5.72, Qg=-0.82 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3659	: Vg=1.013 -> Vg=0.999999
% INFO    : Gen at bus 3660	: Vg=1.032 -> Vg=0.999999
% INFO    : Gen at bus 3676	: Vg=1.031 -> Vg=1.015872
% INFO    : Gen at bus 3678	: Vg=1.021 -> Vg=0.999999
% INFO    : Gen at bus 3684	: Pg=0.17, Qg=0.21 -> Pg=4.75, Qg=0.0
% INFO    : Gen at bus 3684	: Vg=1.035 -> Vg=0.999999
% INFO    : Gen at bus 3686	: Vg=1.05 -> Vg=1.0111115
% INFO    : Gen at bus 3688	: Vg=1.043 -> Vg=0.999999
% INFO    : Gen at bus 3705	: Vg=1.037 -> Vg=1.0079355
% INFO    : Gen at bus 3707	: Pg=6.76, Qg=7.41 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 3707	: Vg=1.055 -> Vg=1.027779
% INFO    : Gen at bus 3708	: Vg=1.024 -> Vg=0.999999
% INFO    : Gen at bus 3709	: Pg=39.22, Qg=2.55 -> Pg=22.0, Qg=0.0
% INFO    : Gen at bus 3709	: Vg=1.042 -> Vg=0.999999
% INFO    : Gen at bus 3736	: Vg=1.039 -> Vg=0.999999
% INFO    : Gen at bus 3740	: Pg=6.36, Qg=1.16 -> Pg=8.4, Qg=0.25
% INFO    : Gen at bus 3740	: Vg=1.034 -> Vg=0.999999
% INFO    : Gen at bus 3745	: Pg=4.96, Qg=0.0 -> Pg=21.5, Qg=0.0
% INFO    : Gen at bus 3745	: Vg=1.053 -> Vg=1.022224
% INFO    : Gen at bus 3750	: Pg=0.18, Qg=0.0 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 3750	: Vg=1.035 -> Vg=0.984126
% INFO    : Gen at bus 3750	: Pg=3.18, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 3750	: Vg=1.035 -> Vg=0.984126
% INFO    : Gen at bus 3752	: Vg=1.028 -> Vg=1.0079355
% INFO    : Gen at bus 3753	: Pg=4.01, Qg=0.74 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3753	: Vg=1.023 -> Vg=1.0158755
% INFO    : Gen at bus 3788	: Vg=1.061 -> Vg=1.0000025
% INFO    : Gen at bus 3788	: Vg=1.061 -> Vg=1.0000025
% INFO    : Gen at bus 3791	: Pg=2.2, Qg=0.0 -> Pg=13.125, Qg=0.0
% INFO    : Gen at bus 3791	: Vg=1.045 -> Vg=1.0000025
% INFO    : Gen at bus 3791	: Pg=5.2, Qg=0.0 -> Pg=10.125, Qg=0.0
% INFO    : Gen at bus 3791	: Vg=1.045 -> Vg=1.0000025
% INFO    : Gen at bus 3791	: Vg=1.045 -> Vg=1.0000025
% INFO    : Gen at bus 3793	: Pg=2.07, Qg=0.0 -> Pg=10.01, Qg=0.0
% INFO    : Gen at bus 3793	: Vg=1.025 -> Vg=1.0000025
% INFO    : Gen at bus 3793	: Pg=0.07, Qg=0.0 -> Pg=10.175, Qg=0.0
% INFO    : Gen at bus 3793	: Vg=1.025 -> Vg=1.0000025
% INFO    : Gen at bus 3808	: Pg=33.13, Qg=-3.48 -> Pg=18.9, Qg=2.0
% INFO    : Gen at bus 3808	: Vg=1.049 -> Vg=0.975
% INFO    : Gen at bus 3809	: Pg=30.81, Qg=0.12 -> Pg=18.9, Qg=2.0
% INFO    : Gen at bus 3809	: Vg=1.062 -> Vg=0.975
% INFO    : Gen at bus 3810	: Pg=30.32, Qg=2.07 -> Pg=18.9, Qg=2.0
% INFO    : Gen at bus 3810	: Vg=1.069 -> Vg=0.975
% INFO    : Gen at bus 3814	: Vg=1.042 -> Vg=1.022224
% INFO    : Gen at bus 3818	: Pg=0.17, Qg=0.0 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 3818	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 3828	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 3834	: Pg=4.58, Qg=-3.57 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 3834	: Vg=1.027 -> Vg=0.999999
% INFO    : Gen at bus 3834	: Pg=4.58, Qg=-3.57 -> Pg=6.5, Qg=0.0
% INFO    : Gen at bus 3834	: Vg=1.027 -> Vg=0.999999
% INFO    : Gen at bus 3845	: Pg=4.28, Qg=-2.24 -> Pg=11.0, Qg=1.0
% INFO    : Gen at bus 3845	: Vg=1.039 -> Vg=1.0000025
% INFO    : Gen at bus 3855	: Vg=1.051 -> Vg=1.022224
% INFO    : Gen at bus 3860	: Pg=3.82, Qg=3.0 -> Pg=4.5, Qg=0.0
% INFO    : Gen at bus 3860	: Vg=1.032 -> Vg=1.022224
% INFO    : Gen at bus 3861	: Vg=1.062 -> Vg=1.0000025
% INFO    : Gen at bus 3868	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 3881	: Vg=1.023 -> Vg=1.0277795
% INFO    : Gen at bus 3885	: Vg=1.043 -> Vg=1.0079355
% INFO    : Gen at bus 3885	: Vg=1.043 -> Vg=1.0079355
% INFO    : Gen at bus 3896	: Vg=1.042 -> Vg=1.0079355
% INFO    : Gen at bus 3896	: Vg=1.042 -> Vg=1.0079355
% INFO    : Gen at bus 3911	: Vg=1.052 -> Vg=1.0000025
% INFO    : Gen at bus 3916	: Vg=1.058 -> Vg=1.015874
% INFO    : Gen at bus 3917	: Pg=5.2, Qg=0.0 -> Pg=27.5, Qg=0.0
% INFO    : Gen at bus 3917	: Vg=1.048 -> Vg=1.026667
% INFO    : Gen at bus 3919	: Vg=1.032 -> Vg=1.015872
% INFO    : Gen at bus 3931	: Vg=1.042 -> Vg=1.000001
% INFO    : Gen at bus 3932	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 3943	: Vg=1.021 -> Vg=1.0158755
% INFO    : Gen at bus 3961	: Pg=33.09, Qg=-2.82 -> Pg=20.5, Qg=0.0
% INFO    : Gen at bus 3961	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 3961	: Pg=34.08, Qg=-2.82 -> Pg=20.5, Qg=0.0
% INFO    : Gen at bus 3961	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 3960	: Pg=32.3, Qg=-1.31 -> Pg=20.5, Qg=-5.0
% INFO    : Gen at bus 3960	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 3960	: Pg=31.33, Qg=-1.31 -> Pg=20.5, Qg=-5.0
% INFO    : Gen at bus 3960	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 3969	: Vg=1.032 -> Vg=1.000001
% INFO    : Gen at bus 3969	: Vg=1.032 -> Vg=1.000001
% INFO    : Gen at bus 3979	: Vg=1.005 -> Vg=1.015872
% INFO    : Gen at bus 3979	: Vg=1.005 -> Vg=1.015872
% INFO    : Gen at bus 3979	: Pg=1.23, Qg=1.92 -> Pg=4.0, Qg=0.0
% INFO    : Gen at bus 3979	: Vg=1.005 -> Vg=1.015872
% INFO    : Gen at bus 3990	: Vg=1.062 -> Vg=1.0000025
% INFO    : Gen at bus 3990	: Pg=11.12, Qg=0.0 -> Pg=12.4, Qg=0.0
% INFO    : Gen at bus 3990	: Vg=1.062 -> Vg=1.0000025
% INFO    : Gen at bus 3992	: Vg=1.053 -> Vg=1.022222
% INFO    : Gen at bus 3992	: Vg=1.053 -> Vg=1.022222
% INFO    : Gen at bus 4017	: Vg=1.022 -> Vg=0.999999
% INFO    : Gen at bus 4021	: Vg=0.961 -> Vg=0.9444445
% INFO    : Gen at bus 4023	: Vg=1.045 -> Vg=1.0111115
% INFO    : Gen at bus 4023	: Vg=1.045 -> Vg=1.0111115
% INFO    : Gen at bus 4046	: Vg=1.032 -> Vg=1.0079355
% INFO    : Gen at bus 4047	: Pg=18.9, Qg=4.79 -> Pg=13.5, Qg=-2.5
% INFO    : Gen at bus 4047	: Vg=1.028 -> Vg=1.015872
% INFO    : Gen at bus 4047	: Pg=19.88, Qg=4.79 -> Pg=13.5, Qg=-2.5
% INFO    : Gen at bus 4047	: Vg=1.028 -> Vg=1.015872
% INFO    : Gen at bus 4057	: Vg=1.039 -> Vg=1.0079355
% INFO    : Gen at bus 4063	: Vg=1.057 -> Vg=1.027779
% INFO    : Gen at bus 4100	: Vg=1.045 -> Vg=1.022224
% INFO    : Gen at bus 4117	: Vg=1.026 -> Vg=1.0079355
% INFO    : Gen at bus 4121	: Pg=7.5, Qg=-1.13 -> Pg=6.15, Qg=0.0
% INFO    : Gen at bus 4121	: Vg=1.035 -> Vg=0.999999
% INFO    : Gen at bus 4121	: Vg=1.035 -> Vg=0.999999
% INFO    : Gen at bus 4121	: Pg=7.2, Qg=-1.13 -> Pg=6.15, Qg=0.0
% INFO    : Gen at bus 4121	: Vg=1.035 -> Vg=0.999999
% INFO    : Gen at bus 4123	: Vg=0.991 -> Vg=1.015872
% INFO    : Gen at bus 4123	: Vg=0.991 -> Vg=1.015872
% INFO    : Gen at bus 4161	: Pg=17.16, Qg=1.97 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 4161	: Vg=1.054 -> Vg=1.0000025
% INFO    : Gen at bus 4190	: Vg=1.045 -> Vg=1.022224
% INFO    : Gen at bus 4190	: Vg=1.045 -> Vg=1.022224
% INFO    : Gen at bus 4209	: Vg=1.037 -> Vg=1.0158755
% INFO    : Gen at bus 4208	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 4223	: Pg=8.09, Qg=5.73 -> Pg=6.5, Qg=6.5
% INFO    : Gen at bus 4223	: Vg=1.039 -> Vg=0.999999
% INFO    : Gen at bus 4227	: Vg=1.037 -> Vg=1.022224
% INFO    : Gen at bus 4236	: Pg=24.21, Qg=2.19 -> Pg=21.0, Qg=0.0
% INFO    : Gen at bus 4236	: Vg=1.064 -> Vg=1.000001
% INFO    : Gen at bus 4237	: Pg=10.8, Qg=5.02 -> Pg=9.5, Qg=0.16
% INFO    : Gen at bus 4237	: Vg=0.976 -> Vg=1.015872
% INFO    : Gen at bus 4252	: Vg=1.029 -> Vg=1.0079355
% INFO    : Gen at bus 4252	: Vg=1.029 -> Vg=1.0079355
% INFO    : Gen at bus 4266	: Pg=6.5, Qg=4.48 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 4266	: Vg=1.051 -> Vg=0.975
% INFO    : Gen at bus 4266	: Pg=6.5, Qg=-2.15 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 4266	: Vg=1.051 -> Vg=0.975
% INFO    : Gen at bus 4267	: Vg=1.053 -> Vg=1.020497
% INFO    : Gen at bus 4267	: Pg=6.87, Qg=5.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 4267	: Vg=1.053 -> Vg=1.020497
% INFO    : Gen at bus 4285	: Vg=1.003 -> Vg=1.015872
% INFO    : Gen at bus 4291	: Pg=17.2, Qg=-0.23 -> Pg=23.0, Qg=-7.0
% INFO    : Gen at bus 4291	: Vg=1.022 -> Vg=0.999999
% INFO    : Gen at bus 4292	: Vg=1.046 -> Vg=0.999999
% INFO    : Gen at bus 4293	: Vg=1.052 -> Vg=1.0000025
% INFO    : Gen at bus 4297	: Vg=1.037 -> Vg=1.0079355
% INFO    : Gen at bus 4301	: Vg=1.064 -> Vg=1.004889
% INFO    : Gen at bus 4301	: Vg=1.064 -> Vg=1.004889
% INFO    : Gen at bus 4307	: Pg=39.23, Qg=11.51 -> Pg=22.0, Qg=0.0
% INFO    : Gen at bus 4307	: Vg=1.05 -> Vg=1.003079
% INFO    : Gen at bus 4311	: Pg=13.29, Qg=-3.68 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 4311	: Vg=1.063 -> Vg=1.000001
% INFO    : Gen at bus 4312	: Vg=1.051 -> Vg=1.0000025
% INFO    : Gen at bus 4316	: Vg=1.057 -> Vg=1.0111115
% INFO    : Gen at bus 4318	: Vg=1.053 -> Vg=1.0079355
% INFO    : Gen at bus 4318	: Vg=1.053 -> Vg=1.0079355
% INFO    : Gen at bus 4319	: Pg=21.45, Qg=5.8 -> Pg=19.5, Qg=0.0
% INFO    : Gen at bus 4319	: Vg=1.02 -> Vg=0.999999
% INFO    : Gen at bus 4329	: Vg=1.036 -> Vg=1.0000025
% INFO    : Gen at bus 4329	: Pg=3.17, Qg=0.0 -> Pg=16.5, Qg=0.0
% INFO    : Gen at bus 4329	: Vg=1.036 -> Vg=1.0000025
% INFO    : Gen at bus 4337	: Pg=20.17, Qg=2.0 -> Pg=13.0, Qg=1.95
% INFO    : Gen at bus 4337	: Vg=1.045 -> Vg=1.0000025
% INFO    : Gen at bus 4344	: Vg=1.029 -> Vg=1.0000025
% INFO    : Gen at bus 4363	: Pg=2.71, Qg=3.0 -> Pg=7.5, Qg=2.95
% INFO    : Gen at bus 4363	: Vg=1.055 -> Vg=1.000001
% INFO    : Gen at bus 4363	: Vg=1.055 -> Vg=1.000001
% INFO    : Gen at bus 4368	: Vg=0.989 -> Vg=1.0158755
% INFO    : Gen at bus 4371	: Vg=1.05 -> Vg=1.022224
% INFO    : Gen at bus 4376	: Vg=1.032 -> Vg=1.015872
% INFO    : Gen at bus 4376	: Vg=1.032 -> Vg=1.015872
% INFO    : Gen at bus 4376	: Vg=1.032 -> Vg=1.015872
% INFO    : Gen at bus 4385	: Vg=1.034 -> Vg=1.0079355
% INFO    : Gen at bus 4405	: Vg=1.029 -> Vg=1.0079355
% INFO    : Gen at bus 4405	: Vg=1.029 -> Vg=1.0079355
% INFO    : Gen at bus 4406	: Vg=0.98 -> Vg=1.0079355
% INFO    : Gen at bus 4406	: Vg=0.98 -> Vg=1.0079355
% INFO    : Gen at bus 4407	: Vg=1.033 -> Vg=1.015872
% INFO    : Gen at bus 4423	: Pg=0.04, Qg=2.0 -> Pg=3.0, Qg=0.0
% INFO    : Gen at bus 4423	: Vg=1.037 -> Vg=1.0000025
% INFO    : Gen at bus 4441	: Vg=1.009 -> Vg=0.999999
% INFO    : Gen at bus 4441	: Vg=1.009 -> Vg=0.999999
% INFO    : Gen at bus 4443	: Pg=9.57, Qg=13.86 -> Pg=13.0, Qg=-0.5
% INFO    : Gen at bus 4443	: Vg=1.052 -> Vg=1.0233335
% INFO    : Gen at bus 4443	: Pg=9.57, Qg=13.86 -> Pg=13.0, Qg=-0.5
% INFO    : Gen at bus 4443	: Vg=1.052 -> Vg=1.0233335
% INFO    : Gen at bus 4447	: Pg=20.13, Qg=0.0 -> Pg=14.95, Qg=0.0
% INFO    : Gen at bus 4447	: Vg=1.055 -> Vg=1.0000025
% INFO    : Gen at bus 4448	: Pg=1.73, Qg=0.0 -> Pg=6.85, Qg=0.0
% INFO    : Gen at bus 4448	: Vg=1.041 -> Vg=1.0000025
% INFO    : Gen at bus 4467	: Vg=1.046 -> Vg=1.0000025
% INFO    : Gen at bus 4469	: Vg=1.032 -> Vg=1.0000025
% INFO    : Gen at bus 4470	: Pg=18.06, Qg=1.56 -> Pg=11.85, Qg=0.055
% INFO    : Gen at bus 4470	: Vg=1.025 -> Vg=0.975
% INFO    : Gen at bus 4471	: Pg=18.96, Qg=0.67 -> Pg=11.85, Qg=2.0
% INFO    : Gen at bus 4471	: Vg=1.055 -> Vg=0.975
% INFO    : Gen at bus 4472	: Pg=18.96, Qg=0.7 -> Pg=11.85, Qg=2.0
% INFO    : Gen at bus 4472	: Vg=1.055 -> Vg=0.975
% INFO    : Gen at bus 4473	: Pg=18.96, Qg=-0.81 -> Pg=11.85, Qg=2.0
% INFO    : Gen at bus 4473	: Vg=1.053 -> Vg=0.975
% INFO    : Gen at bus 4474	: Pg=18.96, Qg=3.73 -> Pg=11.85, Qg=2.0
% INFO    : Gen at bus 4474	: Vg=1.058 -> Vg=0.975
% INFO    : Gen at bus 4487	: Vg=1.026 -> Vg=1.0158755
% INFO    : Gen at bus 4500	: Vg=1.004 -> Vg=1.015872
% INFO    : Gen at bus 4503	: Pg=11.2, Qg=-1.29 -> Pg=10.5, Qg=1.1
% INFO    : Gen at bus 4503	: Vg=1.039 -> Vg=0.975
% INFO    : Gen at bus 4503	: Pg=12.21, Qg=-1.29 -> Pg=10.5, Qg=1.0
% INFO    : Gen at bus 4503	: Vg=1.039 -> Vg=0.975
% INFO    : Gen at bus 4507	: Pg=30.79, Qg=-25.34 -> Pg=43.5, Qg=-0.38
% INFO    : Gen at bus 4507	: Vg=1.079 -> Vg=1.044445
% INFO    : Gen at bus 4516	: Pg=12.91, Qg=1.85 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 4516	: Vg=1.056 -> Vg=1.006624
% INFO    : Gen at bus 4516	: Pg=12.91, Qg=1.85 -> Pg=11.0, Qg=1.0
% INFO    : Gen at bus 4516	: Vg=1.056 -> Vg=1.006624
% INFO    : Gen at bus 4530	: Vg=0.61 -> Vg=0.825
% INFO    : Gen at bus 4530	: Vg=0.61 -> Vg=0.825
% INFO    : Gen at bus 4530	: Vg=0.61 -> Vg=0.825
% INFO    : Gen at bus 4530	: Vg=0.61 -> Vg=0.825
% INFO    : Gen at bus 4530	: Vg=0.61 -> Vg=0.825
% INFO    : Gen at bus 4559	: Pg=10.18, Qg=7.1 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 4559	: Vg=1.038 -> Vg=1.0000025
% INFO    : Gen at bus 4563	: Vg=1.049 -> Vg=1.0000025
% INFO    : Gen at bus 4566	: Pg=41.0, Qg=23.77 -> Pg=44.5, Qg=9.0
% INFO    : Gen at bus 4566	: Vg=1.046 -> Vg=1.0377785
% INFO    : Gen at bus 4566	: Pg=43.0, Qg=23.77 -> Pg=44.5, Qg=9.0
% INFO    : Gen at bus 4566	: Vg=1.046 -> Vg=1.0377785
% INFO    : Gen at bus 4574	: Vg=1.042 -> Vg=1.0000025
% INFO    : Gen at bus 4575	: Vg=1.054 -> Vg=0.999999
% INFO    : Gen at bus 4577	: Vg=1.008 -> Vg=1.015872
% INFO    : Gen at bus 4580	: Pg=1.33, Qg=1.55 -> Pg=6.35, Qg=0.0
% INFO    : Gen at bus 4580	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 4580	: Pg=1.33, Qg=1.0 -> Pg=6.35, Qg=0.95
% INFO    : Gen at bus 4580	: Vg=1.034 -> Vg=1.0000025
% INFO    : Gen at bus 4615	: Vg=1.019 -> Vg=1.022224
% INFO    : Gen at bus 4626	: Vg=1.041 -> Vg=1.022224
% INFO    : Gen at bus 4627	: Vg=1.045 -> Vg=1.0000025
% INFO    : Gen at bus 4628	: Vg=1.047 -> Vg=1.0000025
% INFO    : Gen at bus 4637	: Vg=1.029 -> Vg=1.022224
% INFO    : Gen at bus 4638	: Vg=1.027 -> Vg=1.022224
% INFO    : Gen at bus 4643	: Vg=1.067 -> Vg=1.027779
% INFO    : Gen at bus 4649	: Vg=1.079 -> Vg=1.0000025
% INFO    : Gen at bus 4653	: Vg=1.025 -> Vg=1.022224
% INFO    : Gen at bus 4654	: Pg=2.18, Qg=0.0 -> Pg=17.5, Qg=0.0
% INFO    : Gen at bus 4654	: Vg=1.035 -> Vg=1.022224
% INFO    : Gen at bus 4661	: Vg=1.025 -> Vg=1.022224
% INFO    : Gen at bus 4661	: Pg=0.09, Qg=0.0 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 4661	: Vg=1.025 -> Vg=1.022224
% INFO    : Gen at bus 4666	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 4666	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 4666	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 4666	: Pg=2.28, Qg=0.1 -> Pg=3.5, Qg=0.0
% INFO    : Gen at bus 4666	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 4666	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 4678	: Vg=1.044 -> Vg=1.000001
% INFO    : Gen at bus 4693	: Vg=1.032 -> Vg=1.015872
% INFO    : Gen at bus 4693	: Vg=1.032 -> Vg=1.015872
% INFO    : Gen at bus 4693	: Vg=1.032 -> Vg=1.015872
% INFO    : Gen at bus 4710	: Pg=1.13, Qg=0.35 -> Pg=5.75, Qg=0.0
% INFO    : Gen at bus 4710	: Vg=1.056 -> Vg=1.0000025
% INFO    : Gen at bus 4710	: Vg=1.056 -> Vg=1.0000025
% INFO    : Gen at bus 4711	: Vg=1.1 -> Vg=1.0
% INFO    : Gen at bus 4711	: Vg=1.1 -> Vg=1.0
% INFO    : Gen at bus 4712	: Vg=1.018 -> Vg=1.0158755
% INFO    : Gen at bus 4713	: Pg=1.08, Qg=1.0 -> Pg=5.0, Qg=0.95
% INFO    : Gen at bus 4713	: Vg=1.068 -> Vg=1.0000025
% INFO    : Gen at bus 4713	: Pg=4.08, Qg=1.0 -> Pg=7.5, Qg=0.95
% INFO    : Gen at bus 4713	: Vg=1.068 -> Vg=1.0000025
% INFO    : Gen at bus 4713	: Pg=6.08, Qg=1.0 -> Pg=7.5, Qg=0.95
% INFO    : Gen at bus 4713	: Vg=1.068 -> Vg=1.0000025
% INFO    : Gen at bus 4749	: Vg=1.052 -> Vg=1.0000025
% INFO    : Gen at bus 4750	: Pg=4.1, Qg=2.38 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 4750	: Vg=1.008 -> Vg=1.015872
% INFO    : Gen at bus 4750	: Pg=4.1, Qg=2.38 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 4750	: Vg=1.008 -> Vg=1.015872
% INFO    : Gen at bus 4751	: Pg=3.1, Qg=4.38 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 4751	: Vg=1.008 -> Vg=1.015872
% INFO    : Gen at bus 4751	: Pg=4.1, Qg=4.38 -> Pg=5.0, Qg=0.0
% INFO    : Gen at bus 4751	: Vg=1.008 -> Vg=1.015872
% INFO    : Gen at bus 4760	: Pg=11.55, Qg=0.16 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 4760	: Vg=1.049 -> Vg=1.0233335
% INFO    : Gen at bus 4763	: Vg=1.053 -> Vg=1.027779
% INFO    : Gen at bus 4770	: Vg=1.032 -> Vg=1.0000025
% INFO    : Gen at bus 4775	: Vg=1.029 -> Vg=1.0000005
% INFO    : Gen at bus 4781	: Vg=1.033 -> Vg=1.022224
% INFO    : Gen at bus 4786	: Vg=1.053 -> Vg=0.999999
% INFO    : Gen at bus 4797	: Pg=15.31, Qg=-1.55 -> Pg=13.5, Qg=0.0
% INFO    : Gen at bus 4797	: Vg=1.015 -> Vg=0.999999
% INFO    : Gen at bus 4807	: Vg=1.064 -> Vg=1.027779
% INFO    : Gen at bus 4810	: Pg=1.5, Qg=-0.64 -> Pg=3.2, Qg=0.0
% INFO    : Gen at bus 4810	: Vg=1.035 -> Vg=1.0158755
% INFO    : Gen at bus 4811	: Pg=9.2, Qg=-0.13 -> Pg=8.0, Qg=-0.45
% INFO    : Gen at bus 4811	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 4811	: Pg=10.2, Qg=-0.13 -> Pg=7.5, Qg=-0.5
% INFO    : Gen at bus 4811	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 4812	: Pg=9.2, Qg=-0.64 -> Pg=7.5, Qg=-0.5
% INFO    : Gen at bus 4812	: Vg=1.022 -> Vg=0.975
% INFO    : Gen at bus 4812	: Pg=8.2, Qg=-0.64 -> Pg=8.0, Qg=-0.45
% INFO    : Gen at bus 4812	: Vg=1.022 -> Vg=0.975
% INFO    : Gen at bus 4818	: Vg=1.082 -> Vg=0.975
% INFO    : Gen at bus 4820	: Vg=1.077 -> Vg=0.975
% INFO    : Gen at bus 4820	: Pg=139.07, Qg=12.21 -> Pg=0.0, Qg=-5.0
% INFO    : Gen at bus 4820	: Vg=1.077 -> Vg=0.975
% INFO    : Gen at bus 4817	: Pg=134.15, Qg=15.35 -> Pg=0.0, Qg=-5.0
% INFO    : Gen at bus 4817	: Vg=1.077 -> Vg=0.975
% INFO    : Gen at bus 4817	: Pg=135.14, Qg=15.35 -> Pg=0.0, Qg=-5.0
% INFO    : Gen at bus 4817	: Vg=1.077 -> Vg=0.975
% INFO    : Gen at bus 4819	: Pg=53.37, Qg=3.69 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 4819	: Vg=1.081 -> Vg=0.975
% INFO    : Gen at bus 4819	: Pg=42.36, Qg=3.69 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 4819	: Vg=1.081 -> Vg=0.975
% INFO    : Gen at bus 4818	: Pg=52.63, Qg=13.14 -> Pg=75.0, Qg=0.0
% INFO    : Gen at bus 4818	: Vg=1.082 -> Vg=0.975
% INFO    : Gen at bus 4827	: Vg=1.046 -> Vg=0.984126
% INFO    : Gen at bus 4827	: Vg=1.046 -> Vg=0.984126
% INFO    : Gen at bus 4838	: Vg=1.061 -> Vg=1.006809
% INFO    : Gen at bus 4846	: Vg=0.936 -> Vg=0.9444445
% INFO    : Gen at bus 4846	: Vg=0.936 -> Vg=0.9444445
% INFO    : Gen at bus 4859	: Vg=1.03 -> Vg=0.999999
% INFO    : Gen at bus 4859	: Vg=1.03 -> Vg=0.999999
% INFO    : Gen at bus 4866	: Vg=1.037 -> Vg=1.033334
% INFO    : Gen at bus 4873	: Pg=6.6, Qg=-2.96 -> Pg=6.4, Qg=0.0
% INFO    : Gen at bus 4873	: Vg=1.042 -> Vg=0.999999
% INFO    : Gen at bus 4877	: Pg=6.12, Qg=0.0 -> Pg=17.51, Qg=0.0
% INFO    : Gen at bus 4877	: Vg=1.035 -> Vg=1.0111115
% INFO    : Gen at bus 4877	: Pg=3.12, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 4877	: Vg=1.035 -> Vg=1.0111115
% INFO    : Gen at bus 4889	: Vg=1.037 -> Vg=1.0158755
% INFO    : Gen at bus 4893	: Pg=0.2, Qg=-1.15 -> Pg=8.05, Qg=0.0
% INFO    : Gen at bus 4893	: Vg=1.013 -> Vg=0.999999
% INFO    : Gen at bus 4895	: Pg=4.16, Qg=0.0 -> Pg=10.8, Qg=0.0
% INFO    : Gen at bus 4895	: Vg=1.03 -> Vg=1.0158755
% INFO    : Gen at bus 4895	: Pg=4.16, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 4895	: Vg=1.03 -> Vg=1.0158755
% INFO    : Gen at bus 4895	: Pg=2.16, Qg=0.0 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 4895	: Vg=1.03 -> Vg=1.0158755
% INFO    : Gen at bus 4915	: Pg=22.06, Qg=7.41 -> Pg=16.0, Qg=2.0
% INFO    : Gen at bus 4915	: Vg=1.005 -> Vg=1.015872
% INFO    : Gen at bus 4918	: Pg=24.68, Qg=2.9 -> Pg=16.5, Qg=0.0
% INFO    : Gen at bus 4918	: Vg=1.03 -> Vg=1.0000025
% INFO    : Gen at bus 4925	: Vg=1.062 -> Vg=1.027779
% INFO    : Gen at bus 4941	: Pg=4.15, Qg=3.02 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 4941	: Vg=0.953 -> Vg=0.9444445
% INFO    : Gen at bus 4945	: Vg=1.053 -> Vg=1.027779
% INFO    : Gen at bus 4956	: Pg=2.12, Qg=0.0 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 4956	: Vg=1.056 -> Vg=1.022224
% INFO    : Gen at bus 4956	: Pg=2.12, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 4956	: Vg=1.056 -> Vg=1.022224
% INFO    : Gen at bus 4963	: Vg=1.042 -> Vg=0.999999
% INFO    : Gen at bus 4963	: Pg=24.76, Qg=-9.29 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 4963	: Vg=1.042 -> Vg=0.999999
% INFO    : Gen at bus 4976	: Pg=1.14, Qg=-0.37 -> Pg=16.0, Qg=-1.0
% INFO    : Gen at bus 4976	: Vg=1.022 -> Vg=0.999999
% INFO    : Gen at bus 4977	: Pg=25.93, Qg=10.56 -> Pg=17.55, Qg=-4.5
% INFO    : Gen at bus 4977	: Vg=1.1 -> Vg=0.975
% INFO    : Gen at bus 4978	: Pg=27.87, Qg=10.21 -> Pg=17.55, Qg=-4.5
% INFO    : Gen at bus 4978	: Vg=1.118 -> Vg=0.975
% INFO    : Gen at bus 4979	: Pg=28.36, Qg=10.26 -> Pg=17.55, Qg=-4.5
% INFO    : Gen at bus 4979	: Vg=1.118 -> Vg=0.975
% INFO    : Gen at bus 4986	: Vg=1.025 -> Vg=1.0158755
% INFO    : Gen at bus 4987	: Pg=5.37, Qg=0.0 -> Pg=15.25, Qg=0.0
% INFO    : Gen at bus 4987	: Vg=1.033 -> Vg=1.0158755
% INFO    : Gen at bus 5005	: Pg=3.21, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 5005	: Vg=1.047 -> Vg=1.0000025
% INFO    : Gen at bus 5005	: Pg=6.21, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 5005	: Vg=1.047 -> Vg=1.0000025
% INFO    : Gen at bus 5007	: Vg=1.037 -> Vg=1.022224
% INFO    : Gen at bus 5013	: Pg=4.05, Qg=0.0 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 5013	: Vg=1.028 -> Vg=1.0158755
% INFO    : Gen at bus 5017	: Pg=15.59, Qg=4.0 -> Pg=18.0, Qg=3.95
% INFO    : Gen at bus 5017	: Vg=1.07 -> Vg=1.000001
% INFO    : Gen at bus 5023	: Pg=45.03, Qg=-8.7 -> Pg=25.3, Qg=0.505
% INFO    : Gen at bus 5023	: Vg=1.015 -> Vg=1.0000025
% INFO    : Gen at bus 5031	: Vg=0.995 -> Vg=0.999999
% INFO    : Gen at bus 5032	: Vg=1.005 -> Vg=1.022224
% INFO    : Gen at bus 5034	: Vg=1.037 -> Vg=1.0000025
% INFO    : Gen at bus 5034	: Vg=1.037 -> Vg=1.0000025
% INFO    : Gen at bus 5036	: Vg=1.044 -> Vg=1.022222
% INFO    : Gen at bus 5036	: Vg=1.044 -> Vg=1.022222
% INFO    : Gen at bus 5040	: Vg=1.022 -> Vg=1.0277795
% INFO    : Gen at bus 5042	: Vg=1.034 -> Vg=1.0158755
% INFO    : Gen at bus 5042	: Vg=1.034 -> Vg=1.0158755
% INFO    : Gen at bus 5048	: Vg=1.061 -> Vg=1.033333
% INFO    : Gen at bus 5948	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 5948	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 5948	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 5949	: Vg=1.076 -> Vg=0.975
% INFO    : Gen at bus 5949	: Vg=1.076 -> Vg=0.975
% INFO    : Gen at bus 5951	: Vg=1.031 -> Vg=0.975
% INFO    : Gen at bus 5952	: Pg=975.31, Qg=3.0 -> Pg=700.0, Qg=70.0
% INFO    : Gen at bus 5952	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 5952	: Pg=997.31, Qg=3.0 -> Pg=700.0, Qg=70.0
% INFO    : Gen at bus 5952	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 5954	: Vg=1.065 -> Vg=0.975
% INFO    : Gen at bus 5955	: Vg=1.129 -> Vg=0.975
% INFO    : Gen at bus 5957	: Vg=1.052 -> Vg=0.975
% INFO    : Gen at bus 5957	: Vg=1.052 -> Vg=0.975
% INFO    : Gen at bus 5958	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 5958	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 5962	: Pg=495.33, Qg=-110.51 -> Pg=275.0, Qg=-40.0
% INFO    : Gen at bus 5962	: Vg=1.078 -> Vg=0.975
% INFO    : Gen at bus 5965	: Pg=79.82, Qg=-33.42 -> Pg=42.265, Qg=-4.03
% INFO    : Gen at bus 5965	: Vg=1.081 -> Vg=0.975
% INFO    : Gen at bus 5965	: Pg=79.82, Qg=-33.42 -> Pg=42.265, Qg=-4.03
% INFO    : Gen at bus 5965	: Vg=1.081 -> Vg=0.975
% INFO    : Gen at bus 5973	: Vg=1.074 -> Vg=0.975
% INFO    : Gen at bus 5973	: Vg=1.074 -> Vg=0.975
% INFO    : Gen at bus 5976	: Vg=1.026 -> Vg=0.975
% INFO    : Gen at bus 5976	: Vg=1.026 -> Vg=0.975
% INFO    : Gen at bus 5978	: Pg=416.09, Qg=5.85 -> Pg=225.0, Qg=0.0
% INFO    : Gen at bus 5978	: Vg=1.067 -> Vg=0.975
% INFO    : Gen at bus 5978	: Pg=414.09, Qg=5.85 -> Pg=225.0, Qg=0.0
% INFO    : Gen at bus 5978	: Vg=1.067 -> Vg=0.975
% INFO    : Gen at bus 5987	: Vg=1.107 -> Vg=0.975
% INFO    : Gen at bus 5987	: Vg=1.107 -> Vg=0.975
% INFO    : Gen at bus 5992	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 5992	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 5992	: Pg=44.3, Qg=4.51 -> Pg=24.5, Qg=0.0
% INFO    : Gen at bus 5992	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 5992	: Pg=44.3, Qg=4.51 -> Pg=24.5, Qg=0.0
% INFO    : Gen at bus 5992	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 5992	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 5992	: Vg=1.09 -> Vg=0.975
% INFO    : Gen at bus 5993	: Pg=204.96, Qg=49.86 -> Pg=104.835, Qg=0.0
% INFO    : Gen at bus 5993	: Vg=0.993 -> Vg=0.975
% INFO    : Gen at bus 5993	: Pg=212.99, Qg=49.86 -> Pg=108.85, Qg=0.0
% INFO    : Gen at bus 5993	: Vg=0.993 -> Vg=0.975
% INFO    : Gen at bus 5993	: Pg=399.59, Qg=49.86 -> Pg=202.15, Qg=0.0
% INFO    : Gen at bus 5993	: Vg=0.993 -> Vg=0.975
% INFO    : Gen at bus 5996	: Pg=476.47, Qg=32.41 -> Pg=240.665, Qg=0.0
% INFO    : Gen at bus 5996	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 5999	: Pg=136.27, Qg=4.16 -> Pg=450.0, Qg=0.0
% INFO    : Gen at bus 5999	: Vg=1.078 -> Vg=0.975
% INFO    : Gen at bus 6000	: Pg=133.41, Qg=-7.83 -> Pg=250.0, Qg=0.0
% INFO    : Gen at bus 6000	: Vg=1.078 -> Vg=0.975
% INFO    : Gen at bus 6004	: Pg=1.82, Qg=3.76 -> Pg=301.5, Qg=66.5
% INFO    : Gen at bus 6004	: Vg=1.091 -> Vg=0.975
% INFO    : Gen at bus 6004	: Vg=1.091 -> Vg=0.975
% INFO    : Gen at bus 6004	: Pg=0.91, Qg=3.76 -> Pg=304.5, Qg=66.5
% INFO    : Gen at bus 6004	: Vg=1.091 -> Vg=0.975
% INFO    : Gen at bus 6004	: Pg=6.38, Qg=3.76 -> Pg=279.0, Qg=98.0
% INFO    : Gen at bus 6004	: Vg=1.091 -> Vg=0.975
% INFO    : Gen at bus 6012	: Vg=1.078 -> Vg=0.975
% INFO    : Gen at bus 6011	: Pg=71.56, Qg=-84.8 -> Pg=38.105, Qg=-30.975
% INFO    : Gen at bus 6011	: Vg=1.079 -> Vg=0.975
% INFO    : Gen at bus 6013	: Pg=260.71, Qg=-6.7 -> Pg=132.685, Qg=0.0
% INFO    : Gen at bus 6013	: Vg=1.106 -> Vg=0.975
% INFO    : Gen at bus 6016	: Pg=462.15, Qg=-141.81 -> Pg=233.445, Qg=-1.04
% INFO    : Gen at bus 6016	: Vg=1.029 -> Vg=0.975
% INFO    : Gen at bus 6017	: Vg=1.069 -> Vg=0.975
% INFO    : Gen at bus 6019	: Pg=1050.92, Qg=22.87 -> Pg=653.0, Qg=235.0
% INFO    : Gen at bus 6019	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6019	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6019	: Pg=406.92, Qg=22.87 -> Pg=304.0, Qg=84.0
% INFO    : Gen at bus 6019	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6019	: Pg=406.92, Qg=22.87 -> Pg=304.0, Qg=72.5
% INFO    : Gen at bus 6019	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6030	: Pg=99.0, Qg=3.36 -> Pg=350.0, Qg=142.5
% INFO    : Gen at bus 6030	: Vg=1.038 -> Vg=0.975
% INFO    : Gen at bus 6035	: Vg=1.073 -> Vg=0.975
% INFO    : Gen at bus 6039	: Pg=2.91, Qg=-3.57 -> Pg=3.865, Qg=-0.645
% INFO    : Gen at bus 6039	: Vg=1.109 -> Vg=0.975
% INFO    : Gen at bus 6045	: Pg=501.11, Qg=51.67 -> Pg=253.0, Qg=0.0
% INFO    : Gen at bus 6045	: Vg=1.058 -> Vg=0.975
% INFO    : Gen at bus 6048	: Pg=1070.7, Qg=-23.94 -> Pg=537.725, Qg=0.0
% INFO    : Gen at bus 6048	: Vg=1.097 -> Vg=0.975
% INFO    : Gen at bus 6056	: Pg=1039.13, Qg=55.95 -> Pg=675.0, Qg=70.0
% INFO    : Gen at bus 6056	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6056	: Pg=504.13, Qg=55.95 -> Pg=605.0, Qg=70.0
% INFO    : Gen at bus 6056	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6056	: Pg=479.13, Qg=55.95 -> Pg=605.0, Qg=70.0
% INFO    : Gen at bus 6056	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6059	: Vg=1.074 -> Vg=0.975
% INFO    : Gen at bus 6060	: Vg=1.063 -> Vg=0.975
% INFO    : Gen at bus 6073	: Vg=1.075 -> Vg=0.975
% INFO    : Gen at bus 6074	: Vg=1.111 -> Vg=0.975
% INFO    : Gen at bus 6078	: Pg=1382.35, Qg=-12.04 -> Pg=693.5, Qg=0.0
% INFO    : Gen at bus 6078	: Vg=1.109 -> Vg=0.975
% INFO    : Gen at bus 6079	: Vg=1.109 -> Vg=0.975
% INFO    : Gen at bus 6080	: Pg=216.27, Qg=75.0 -> Pg=110.5, Qg=4.35
% INFO    : Gen at bus 6080	: Vg=1.08 -> Vg=0.975
% INFO    : Gen at bus 6082	: Vg=1.098 -> Vg=0.975
% INFO    : Gen at bus 6083	: Vg=1.075 -> Vg=0.975
% INFO    : Gen at bus 6082	: Pg=38.31, Qg=-23.92 -> Pg=21.5, Qg=-5.55
% INFO    : Gen at bus 6082	: Vg=1.098 -> Vg=0.975
% INFO    : Gen at bus 6082	: Pg=5.31, Qg=-23.92 -> Pg=5.0, Qg=-10.5
% INFO    : Gen at bus 6082	: Vg=1.098 -> Vg=0.975
% INFO    : Gen at bus 6085	: Pg=41.29, Qg=71.68 -> Pg=23.02, Qg=28.935
% INFO    : Gen at bus 6085	: Vg=1.111 -> Vg=0.975
% INFO    : Gen at bus 6084	: Pg=16.19, Qg=15.24 -> Pg=10.46, Qg=4.495
% INFO    : Gen at bus 6084	: Vg=1.097 -> Vg=0.975
% INFO    : Gen at bus 6093	: Pg=1220.95, Qg=-213.89 -> Pg=612.835, Qg=0.0
% INFO    : Gen at bus 6093	: Vg=1.094 -> Vg=0.975
% INFO    : Gen at bus 6094	: Pg=436.17, Qg=-8.4 -> Pg=225.0, Qg=0.0
% INFO    : Gen at bus 6094	: Vg=1.076 -> Vg=0.975
% INFO    : Gen at bus 6096	: Vg=1.062 -> Vg=0.975
% INFO    : Gen at bus 6103	: Pg=187.13, Qg=2.02 -> Pg=96.0, Qg=0.0
% INFO    : Gen at bus 6103	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 6102	: Pg=184.15, Qg=1.03 -> Pg=94.5, Qg=0.0
% INFO    : Gen at bus 6102	: Vg=1.059 -> Vg=0.975
% INFO    : Gen at bus 6103	: Pg=184.13, Qg=2.02 -> Pg=94.5, Qg=0.0
% INFO    : Gen at bus 6103	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 6102	: Vg=1.059 -> Vg=0.975
% INFO    : Gen at bus 6105	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 6105	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 6107	: Pg=83.94, Qg=44.78 -> Pg=44.37, Qg=9.085
% INFO    : Gen at bus 6107	: Vg=1.109 -> Vg=0.975
% INFO    : Gen at bus 6116	: Pg=730.35, Qg=-81.66 -> Pg=367.5, Qg=0.0
% INFO    : Gen at bus 6116	: Vg=1.097 -> Vg=0.975
% INFO    : Gen at bus 6120	: Vg=1.069 -> Vg=0.975
% INFO    : Gen at bus 6122	: Pg=1.31, Qg=-6.63 -> Pg=3.055, Qg=-2.4
% INFO    : Gen at bus 6122	: Vg=1.058 -> Vg=0.975
% INFO    : Gen at bus 6123	: Pg=181.23, Qg=-12.95 -> Pg=93.0, Qg=0.0
% INFO    : Gen at bus 6123	: Vg=1.084 -> Vg=0.975
% INFO    : Gen at bus 6123	: Pg=184.23, Qg=-12.95 -> Pg=94.5, Qg=0.0
% INFO    : Gen at bus 6123	: Vg=1.084 -> Vg=0.975
% INFO    : Gen at bus 6124	: Pg=-4.82, Qg=3.68 -> Pg=0.0, Qg=-35.0
% INFO    : Gen at bus 6124	: Vg=1.094 -> Vg=0.975
% INFO    : Gen at bus 6124	: Pg=-4.82, Qg=3.68 -> Pg=0.0, Qg=-35.0
% INFO    : Gen at bus 6124	: Vg=1.094 -> Vg=0.975
% INFO    : Gen at bus 6124	: Pg=-4.82, Qg=3.68 -> Pg=0.0, Qg=-35.0
% INFO    : Gen at bus 6124	: Vg=1.094 -> Vg=0.975
% INFO    : Gen at bus 6124	: Pg=-4.82, Qg=3.68 -> Pg=0.0, Qg=-35.0
% INFO    : Gen at bus 6124	: Vg=1.094 -> Vg=0.975
% INFO    : Gen at bus 6129	: Pg=454.25, Qg=58.32 -> Pg=229.5, Qg=0.0
% INFO    : Gen at bus 6129	: Vg=1.085 -> Vg=0.975
% INFO    : Gen at bus 6129	: Pg=136.25, Qg=57.8 -> Pg=70.5, Qg=7.75
% INFO    : Gen at bus 6129	: Vg=1.085 -> Vg=0.975
% INFO    : Gen at bus 6129	: Pg=57.25, Qg=57.8 -> Pg=31.0, Qg=19.6
% INFO    : Gen at bus 6129	: Vg=1.085 -> Vg=0.975
% INFO    : Gen at bus 6129	: Pg=113.25, Qg=57.8 -> Pg=59.0, Qg=11.2
% INFO    : Gen at bus 6129	: Vg=1.085 -> Vg=0.975
% INFO    : Gen at bus 6129	: Pg=64.25, Qg=57.8 -> Pg=34.5, Qg=18.55
% INFO    : Gen at bus 6129	: Vg=1.085 -> Vg=0.975
% INFO    : Gen at bus 6136	: Vg=1.099 -> Vg=0.975
% INFO    : Gen at bus 6147	: Vg=1.068 -> Vg=0.975
% INFO    : Gen at bus 6147	: Vg=1.068 -> Vg=0.975
% INFO    : Gen at bus 6148	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 6150	: Vg=1.103 -> Vg=0.975
% INFO    : Gen at bus 6152	: Pg=417.74, Qg=-69.12 -> Pg=211.31, Qg=0.0
% INFO    : Gen at bus 6152	: Vg=1.076 -> Vg=0.975
% INFO    : Gen at bus 6152	: Pg=172.54, Qg=-68.92 -> Pg=88.715, Qg=-7.845
% INFO    : Gen at bus 6152	: Vg=1.076 -> Vg=0.975
% INFO    : Gen at bus 6155	: Pg=167.57, Qg=-8.97 -> Pg=86.135, Qg=0.0
% INFO    : Gen at bus 6155	: Vg=1.088 -> Vg=0.975
% INFO    : Gen at bus 6155	: Pg=167.57, Qg=-8.97 -> Pg=86.135, Qg=0.0
% INFO    : Gen at bus 6155	: Vg=1.088 -> Vg=0.975
% INFO    : Gen at bus 6162	: Pg=2894.13, Qg=154.67 -> Pg=1449.42, Qg=0.0
% INFO    : Gen at bus 6162	: Vg=1.087 -> Vg=0.975
% INFO    : Gen at bus 6163	: Vg=1.033 -> Vg=0.975
% INFO    : Gen at bus 6164	: Pg=14.35, Qg=16.22 -> Pg=9.605, Qg=5.315
% INFO    : Gen at bus 6164	: Vg=1.064 -> Vg=0.975
% INFO    : Gen at bus 6164	: Pg=14.35, Qg=16.22 -> Pg=9.605, Qg=5.315
% INFO    : Gen at bus 6164	: Vg=1.064 -> Vg=0.975
% INFO    : Gen at bus 6166	: Vg=1.073 -> Vg=0.975
% INFO    : Gen at bus 6169	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6174	: Pg=79.21, Qg=88.47 -> Pg=135.0, Qg=0.0
% INFO    : Gen at bus 6174	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6178	: Pg=270.5, Qg=-28.53 -> Pg=137.655, Qg=0.0
% INFO    : Gen at bus 6178	: Vg=1.107 -> Vg=0.975
% INFO    : Gen at bus 6178	: Pg=266.92, Qg=-28.53 -> Pg=135.865, Qg=0.0
% INFO    : Gen at bus 6178	: Vg=1.107 -> Vg=0.975
% INFO    : Gen at bus 6179	: Vg=1.095 -> Vg=0.975
% INFO    : Gen at bus 6183	: Pg=353.93, Qg=7.8 -> Pg=385.0, Qg=0.0
% INFO    : Gen at bus 6183	: Vg=1.095 -> Vg=0.975
% INFO    : Gen at bus 6183	: Pg=352.91, Qg=7.8 -> Pg=385.0, Qg=0.0
% INFO    : Gen at bus 6183	: Vg=1.095 -> Vg=0.975
% INFO    : Gen at bus 6184	: Vg=1.121 -> Vg=0.975
% INFO    : Gen at bus 6184	: Vg=1.121 -> Vg=0.975
% INFO    : Gen at bus 6184	: Vg=1.121 -> Vg=0.975
% INFO    : Gen at bus 6185	: Pg=66.37, Qg=-2.16 -> Pg=100.0, Qg=0.0
% INFO    : Gen at bus 6185	: Vg=1.046 -> Vg=0.975
% INFO    : Gen at bus 6186	: Vg=1.103 -> Vg=0.975
% INFO    : Gen at bus 6186	: Pg=2.77, Qg=-105.92 -> Pg=3.78, Qg=-51.83
% INFO    : Gen at bus 6186	: Vg=1.103 -> Vg=0.975
% INFO    : Gen at bus 6202	: Vg=1.073 -> Vg=0.975
% INFO    : Gen at bus 6205	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6206	: Vg=1.068 -> Vg=0.975
% INFO    : Gen at bus 6206	: Vg=1.068 -> Vg=0.975
% INFO    : Gen at bus 6206	: Vg=1.068 -> Vg=0.975
% INFO    : Gen at bus 6208	: Vg=1.089 -> Vg=0.975
% INFO    : Gen at bus 6208	: Vg=1.089 -> Vg=0.975
% INFO    : Gen at bus 6208	: Pg=173.09, Qg=35.86 -> Pg=125.0, Qg=0.0
% INFO    : Gen at bus 6208	: Vg=1.089 -> Vg=0.975
% INFO    : Gen at bus 6208	: Pg=167.09, Qg=35.86 -> Pg=125.0, Qg=0.0
% INFO    : Gen at bus 6208	: Vg=1.089 -> Vg=0.975
% INFO    : Gen at bus 6208	: Pg=182.09, Qg=35.86 -> Pg=125.0, Qg=0.0
% INFO    : Gen at bus 6208	: Vg=1.089 -> Vg=0.975
% INFO    : Gen at bus 6208	: Vg=1.089 -> Vg=0.975
% INFO    : Gen at bus 6208	: Vg=1.089 -> Vg=0.975
% INFO    : Gen at bus 6209	: Pg=651.35, Qg=-120.67 -> Pg=328.0, Qg=139.5
% INFO    : Gen at bus 6209	: Vg=1.038 -> Vg=0.975
% INFO    : Gen at bus 6211	: Pg=67.33, Qg=-9.33 -> Pg=36.05, Qg=0.0
% INFO    : Gen at bus 6211	: Vg=1.066 -> Vg=0.975
% INFO    : Gen at bus 6212	: Pg=1038.3, Qg=-214.51 -> Pg=700.0, Qg=70.0
% INFO    : Gen at bus 6212	: Vg=1.058 -> Vg=0.975
% INFO    : Gen at bus 6216	: Pg=70.34, Qg=-5.14 -> Pg=37.58, Qg=0.0
% INFO    : Gen at bus 6216	: Vg=1.067 -> Vg=0.975
% INFO    : Gen at bus 6219	: Vg=1.065 -> Vg=0.975
% INFO    : Gen at bus 6219	: Vg=1.065 -> Vg=0.975
% INFO    : Gen at bus 6221	: Pg=112.14, Qg=38.08 -> Pg=58.445, Qg=1.505
% INFO    : Gen at bus 6221	: Vg=1.086 -> Vg=0.975
% INFO    : Gen at bus 6221	: Pg=112.14, Qg=38.08 -> Pg=58.445, Qg=1.505
% INFO    : Gen at bus 6221	: Vg=1.086 -> Vg=0.975
% INFO    : Gen at bus 6229	: Pg=357.69, Qg=-5.39 -> Pg=181.29, Qg=0.0
% INFO    : Gen at bus 6229	: Vg=1.075 -> Vg=0.975
% INFO    : Gen at bus 6235	: Vg=1.069 -> Vg=0.975
% INFO    : Gen at bus 6237	: Pg=494.35, Qg=-20.45 -> Pg=625.0, Qg=-14.0
% INFO    : Gen at bus 6237	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 6237	: Pg=365.14, Qg=-20.45 -> Pg=285.0, Qg=-44.0
% INFO    : Gen at bus 6237	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 6237	: Pg=365.14, Qg=-20.45 -> Pg=285.0, Qg=-44.0
% INFO    : Gen at bus 6237	: Vg=1.071 -> Vg=0.975
% INFO    : Gen at bus 6245	: Vg=0.967 -> Vg=0.975
% INFO    : Gen at bus 6246	: Vg=0.967 -> Vg=0.975
% INFO    : Gen at bus 6247	: Pg=14.72, Qg=7.0 -> Pg=11.5, Qg=2.565
% INFO    : Gen at bus 6247	: Vg=1.07 -> Vg=0.975
% INFO    : Gen at bus 6248	: Pg=14.72, Qg=7.0 -> Pg=11.5, Qg=2.565
% INFO    : Gen at bus 6248	: Vg=1.07 -> Vg=0.975
% INFO    : Gen at bus 6249	: Pg=21.59, Qg=8.64 -> Pg=13.5, Qg=4.515
% INFO    : Gen at bus 6249	: Vg=1.075 -> Vg=0.975
% INFO    : Gen at bus 6250	: Pg=65.98, Qg=18.11 -> Pg=43.0, Qg=16.295
% INFO    : Gen at bus 6250	: Vg=0.966 -> Vg=0.975
% INFO    : Gen at bus 6251	: Vg=0.946 -> Vg=0.975
% INFO    : Gen at bus 6252	: Pg=63.61, Qg=-1.41 -> Pg=62.0, Qg=28.595
% INFO    : Gen at bus 6252	: Vg=0.979 -> Vg=0.975
% INFO    : Gen at bus 6253	: Pg=21.26, Qg=10.13 -> Pg=16.0, Qg=1.665
% INFO    : Gen at bus 6253	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6254	: Pg=21.26, Qg=10.13 -> Pg=16.0, Qg=1.665
% INFO    : Gen at bus 6254	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6255	: Pg=19.88, Qg=3.69 -> Pg=16.0, Qg=1.545
% INFO    : Gen at bus 6255	: Vg=1.051 -> Vg=0.975
% INFO    : Gen at bus 6256	: Pg=19.88, Qg=3.69 -> Pg=16.0, Qg=1.545
% INFO    : Gen at bus 6256	: Vg=1.051 -> Vg=0.975
% INFO    : Gen at bus 6257	: Pg=74.76, Qg=-28.7 -> Pg=46.0, Qg=14.82
% INFO    : Gen at bus 6257	: Vg=0.958 -> Vg=0.975
% INFO    : Gen at bus 6258	: Pg=42.96, Qg=-33.64 -> Pg=46.0, Qg=13.09
% INFO    : Gen at bus 6258	: Vg=0.955 -> Vg=0.975
% INFO    : Gen at bus 6259	: Pg=71.99, Qg=-1.98 -> Pg=46.0, Qg=17.7
% INFO    : Gen at bus 6259	: Vg=1.005 -> Vg=0.975
% INFO    : Gen at bus 6260	: Pg=63.35, Qg=-3.81 -> Pg=46.0, Qg=17.7
% INFO    : Gen at bus 6260	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 6261	: Pg=66.1, Qg=-38.68 -> Pg=46.0, Qg=11.99
% INFO    : Gen at bus 6261	: Vg=0.947 -> Vg=0.975
% INFO    : Gen at bus 6262	: Pg=71.93, Qg=-36.35 -> Pg=46.0, Qg=13.155
% INFO    : Gen at bus 6262	: Vg=0.95 -> Vg=0.975
% INFO    : Gen at bus 6263	: Pg=934.7, Qg=147.61 -> Pg=594.59, Qg=-35.685
% INFO    : Gen at bus 6263	: Vg=1.047 -> Vg=0.975
% INFO    : Gen at bus 6264	: Pg=972.67, Qg=144.16 -> Pg=632.56, Qg=-26.07
% INFO    : Gen at bus 6264	: Vg=1.046 -> Vg=0.975
% INFO    : Gen at bus 6265	: Pg=967.71, Qg=135.89 -> Pg=612.59, Qg=-31.15
% INFO    : Gen at bus 6265	: Vg=1.045 -> Vg=0.975
% INFO    : Gen at bus 6266	: Pg=931.7, Qg=120.29 -> Pg=591.59, Qg=-36.5
% INFO    : Gen at bus 6266	: Vg=1.043 -> Vg=0.975
% INFO    : Gen at bus 6268	: Pg=190.61, Qg=53.17 -> Pg=204.0, Qg=31.78
% INFO    : Gen at bus 6268	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 6269	: Pg=189.58, Qg=55.35 -> Pg=202.0, Qg=31.955
% INFO    : Gen at bus 6269	: Vg=1.024 -> Vg=0.975
% INFO    : Gen at bus 6270	: Pg=183.58, Qg=37.87 -> Pg=202.0, Qg=22.52
% INFO    : Gen at bus 6270	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 6271	: Pg=249.06, Qg=40.98 -> Pg=213.5, Qg=42.55
% INFO    : Gen at bus 6271	: Vg=1.036 -> Vg=0.975
% INFO    : Gen at bus 6272	: Pg=123.56, Qg=24.26 -> Pg=122.0, Qg=17.885
% INFO    : Gen at bus 6272	: Vg=1.04 -> Vg=0.975
% INFO    : Gen at bus 6273	: Pg=52.63, Qg=13.77 -> Pg=29.0, Qg=-0.45
% INFO    : Gen at bus 6273	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 6274	: Pg=53.32, Qg=14.44 -> Pg=29.0, Qg=0.975
% INFO    : Gen at bus 6274	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 6275	: Pg=53.32, Qg=13.9 -> Pg=29.0, Qg=-0.45
% INFO    : Gen at bus 6275	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 6276	: Pg=53.32, Qg=14.44 -> Pg=29.0, Qg=0.975
% INFO    : Gen at bus 6276	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 6277	: Pg=52.63, Qg=14.3 -> Pg=29.0, Qg=0.905
% INFO    : Gen at bus 6277	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 6278	: Pg=133.0, Qg=95.81 -> Pg=198.0, Qg=45.885
% INFO    : Gen at bus 6278	: Vg=1.024 -> Vg=0.975
% INFO    : Gen at bus 6279	: Pg=81.31, Qg=-9.19 -> Pg=69.5, Qg=21.71
% INFO    : Gen at bus 6279	: Vg=1.029 -> Vg=0.975
% INFO    : Gen at bus 6280	: Pg=30.43, Qg=-14.3 -> Pg=24.5, Qg=4.605
% INFO    : Gen at bus 6280	: Vg=0.966 -> Vg=0.975
% INFO    : Gen at bus 6281	: Pg=30.43, Qg=-14.32 -> Pg=24.5, Qg=4.57
% INFO    : Gen at bus 6281	: Vg=0.97 -> Vg=0.975
% INFO    : Gen at bus 6282	: Pg=16.17, Qg=-10.31 -> Pg=16.0, Qg=4.37
% INFO    : Gen at bus 6282	: Vg=0.978 -> Vg=0.975
% INFO    : Gen at bus 6283	: Pg=9.26, Qg=-13.86 -> Pg=16.0, Qg=2.37
% INFO    : Gen at bus 6283	: Vg=0.988 -> Vg=0.975
% INFO    : Gen at bus 6284	: Pg=12.26, Qg=-13.12 -> Pg=16.0, Qg=4.21
% INFO    : Gen at bus 6284	: Vg=0.978 -> Vg=0.975
% INFO    : Gen at bus 6285	: Pg=935.22, Qg=127.89 -> Pg=604.97, Qg=162.7
% INFO    : Gen at bus 6285	: Vg=0.995 -> Vg=0.975
% INFO    : Gen at bus 6286	: Pg=926.76, Qg=122.25 -> Pg=605.21, Qg=162.315
% INFO    : Gen at bus 6286	: Vg=0.995 -> Vg=0.975
% INFO    : Gen at bus 6287	: Pg=923.22, Qg=138.52 -> Pg=602.96, Qg=149.25
% INFO    : Gen at bus 6287	: Vg=0.996 -> Vg=0.975
% INFO    : Gen at bus 6288	: Pg=874.74, Qg=114.15 -> Pg=595.2, Qg=145.69
% INFO    : Gen at bus 6288	: Vg=0.994 -> Vg=0.975
% INFO    : Gen at bus 6289	: Pg=1281.6, Qg=88.24 -> Pg=813.0, Qg=218.085
% INFO    : Gen at bus 6289	: Vg=0.99 -> Vg=0.975
% INFO    : Gen at bus 6290	: Pg=1281.6, Qg=88.76 -> Pg=813.0, Qg=218.085
% INFO    : Gen at bus 6290	: Vg=0.99 -> Vg=0.975
% INFO    : Gen at bus 6291	: Pg=29.36, Qg=3.17 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6291	: Vg=1.036 -> Vg=0.975
% INFO    : Gen at bus 6292	: Pg=29.36, Qg=3.17 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6292	: Vg=1.036 -> Vg=0.975
% INFO    : Gen at bus 6293	: Pg=29.36, Qg=3.17 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6293	: Vg=1.036 -> Vg=0.975
% INFO    : Gen at bus 6294	: Pg=29.12, Qg=2.63 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6294	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 6295	: Pg=29.12, Qg=2.63 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6295	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 6296	: Pg=29.12, Qg=2.63 -> Pg=17.5, Qg=1.8
% INFO    : Gen at bus 6296	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 6297	: Pg=15.1, Qg=6.18 -> Pg=10.0, Qg=1.615
% INFO    : Gen at bus 6297	: Vg=0.986 -> Vg=0.975
% INFO    : Gen at bus 6298	: Pg=1281.81, Qg=168.93 -> Pg=833.5, Qg=226.955
% INFO    : Gen at bus 6298	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 6299	: Pg=1293.84, Qg=202.55 -> Pg=863.5, Qg=235.535
% INFO    : Gen at bus 6299	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 6300	: Pg=1250.84, Qg=196.97 -> Pg=863.5, Qg=235.535
% INFO    : Gen at bus 6300	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 6301	: Pg=62.15, Qg=-7.87 -> Pg=47.5, Qg=10.18
% INFO    : Gen at bus 6301	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6302	: Pg=1.4, Qg=6.39 -> Pg=1.45, Qg=91.015
% INFO    : Gen at bus 6302	: Vg=0.991 -> Vg=0.975
% INFO    : Gen at bus 6303	: Pg=156.52, Qg=-53.19 -> Pg=0.0, Qg=27.97
% INFO    : Gen at bus 6303	: Vg=0.963 -> Vg=0.975
% INFO    : Gen at bus 6304	: Pg=939.31, Qg=174.11 -> Pg=591.98, Qg=174.145
% INFO    : Gen at bus 6304	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 6306	: Pg=952.04, Qg=161.4 -> Pg=602.01, Qg=194.51
% INFO    : Gen at bus 6306	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 6307	: Pg=950.04, Qg=163.9 -> Pg=600.01, Qg=203.3
% INFO    : Gen at bus 6307	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 6308	: Pg=1498.32, Qg=534.37 -> Pg=953.0, Qg=217.35
% INFO    : Gen at bus 6308	: Vg=1.049 -> Vg=0.975
% INFO    : Gen at bus 6309	: Pg=1498.32, Qg=351.13 -> Pg=953.0, Qg=217.35
% INFO    : Gen at bus 6309	: Vg=1.022 -> Vg=0.975
% INFO    : Gen at bus 6310	: Pg=1493.11, Qg=18.61 -> Pg=948.0, Qg=-28.08
% INFO    : Gen at bus 6310	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 6311	: Pg=1493.12, Qg=31.89 -> Pg=948.0, Qg=-38.82
% INFO    : Gen at bus 6311	: Vg=1.002 -> Vg=0.975
% INFO    : Gen at bus 6312	: Pg=65.54, Qg=-1.05 -> Pg=66.75, Qg=21.35
% INFO    : Gen at bus 6312	: Vg=0.983 -> Vg=0.975
% INFO    : Gen at bus 6313	: Pg=63.54, Qg=-0.41 -> Pg=66.75, Qg=21.35
% INFO    : Gen at bus 6313	: Vg=0.983 -> Vg=0.975
% INFO    : Gen at bus 6314	: Pg=123.74, Qg=7.0 -> Pg=76.2, Qg=35.07
% INFO    : Gen at bus 6314	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 6315	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6316	: Pg=477.81, Qg=108.34 -> Pg=460.0, Qg=94.405
% INFO    : Gen at bus 6316	: Vg=1.007 -> Vg=0.975
% INFO    : Gen at bus 6317	: Pg=602.83, Qg=113.03 -> Pg=460.0, Qg=55.15
% INFO    : Gen at bus 6317	: Vg=1.005 -> Vg=0.975
% INFO    : Gen at bus 6319	: Vg=0.99 -> Vg=0.975
% INFO    : Gen at bus 6320	: Pg=10.58, Qg=-8.04 -> Pg=9.0, Qg=0.91
% INFO    : Gen at bus 6320	: Vg=0.942 -> Vg=0.975
% INFO    : Gen at bus 6321	: Pg=23.98, Qg=-6.78 -> Pg=19.0, Qg=-0.325
% INFO    : Gen at bus 6321	: Vg=1.007 -> Vg=0.975
% INFO    : Gen at bus 6322	: Pg=37.54, Qg=8.09 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6322	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6323	: Pg=34.66, Qg=7.51 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6323	: Vg=0.991 -> Vg=0.975
% INFO    : Gen at bus 6324	: Pg=38.5, Qg=8.3 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6324	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6325	: Pg=37.54, Qg=8.09 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6325	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6326	: Pg=37.54, Qg=8.09 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6326	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6327	: Pg=35.62, Qg=7.7 -> Pg=25.0, Qg=3.42
% INFO    : Gen at bus 6327	: Vg=0.991 -> Vg=0.975
% INFO    : Gen at bus 6328	: Pg=939.07, Qg=195.1 -> Pg=640.0, Qg=196.325
% INFO    : Gen at bus 6328	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 6329	: Pg=950.08, Qg=226.33 -> Pg=640.0, Qg=196.325
% INFO    : Gen at bus 6329	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 6330	: Pg=961.09, Qg=239.9 -> Pg=640.0, Qg=218.295
% INFO    : Gen at bus 6330	: Vg=1.013 -> Vg=0.975
% INFO    : Gen at bus 6331	: Pg=925.32, Qg=226.58 -> Pg=605.0, Qg=208.07
% INFO    : Gen at bus 6331	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 6332	: Pg=27.0, Qg=2.49 -> Pg=28.5, Qg=4.565
% INFO    : Gen at bus 6332	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 6333	: Pg=27.0, Qg=2.49 -> Pg=28.5, Qg=4.565
% INFO    : Gen at bus 6333	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 6334	: Vg=0.959 -> Vg=0.975
% INFO    : Gen at bus 6335	: Vg=0.988 -> Vg=0.975
% INFO    : Gen at bus 6336	: Pg=402.46, Qg=20.52 -> Pg=341.3, Qg=54.86
% INFO    : Gen at bus 6336	: Vg=1.031 -> Vg=0.975
% INFO    : Gen at bus 6337	: Pg=916.68, Qg=138.13 -> Pg=576.54, Qg=188.515
% INFO    : Gen at bus 6337	: Vg=1.001 -> Vg=0.975
% INFO    : Gen at bus 6338	: Pg=916.68, Qg=130.76 -> Pg=576.54, Qg=188.515
% INFO    : Gen at bus 6338	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 6339	: Pg=923.69, Qg=140.0 -> Pg=583.54, Qg=189.84
% INFO    : Gen at bus 6339	: Vg=1.001 -> Vg=0.975
% INFO    : Gen at bus 6340	: Pg=938.69, Qg=136.52 -> Pg=598.55, Qg=192.78
% INFO    : Gen at bus 6340	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 6341	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 6342	: Pg=1306.49, Qg=112.42 -> Pg=860.0, Qg=-28.245
% INFO    : Gen at bus 6342	: Vg=1.031 -> Vg=0.975
% INFO    : Gen at bus 6343	: Pg=1189.5, Qg=130.57 -> Pg=860.0, Qg=-28.245
% INFO    : Gen at bus 6343	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 6344	: Pg=24.79, Qg=-4.26 -> Pg=15.75, Qg=4.47
% INFO    : Gen at bus 6344	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 6345	: Pg=51.22, Qg=-1.49 -> Pg=32.5, Qg=7.34
% INFO    : Gen at bus 6345	: Vg=1.007 -> Vg=0.975
% INFO    : Gen at bus 6346	: Pg=51.63, Qg=-1.68 -> Pg=35.0, Qg=0.32
% INFO    : Gen at bus 6346	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 6347	: Pg=55.73, Qg=-1.08 -> Pg=32.5, Qg=8.95
% INFO    : Gen at bus 6347	: Vg=1.005 -> Vg=0.975
% INFO    : Gen at bus 6348	: Pg=56.75, Qg=-0.17 -> Pg=32.5, Qg=10.38
% INFO    : Gen at bus 6348	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 6349	: Pg=54.12, Qg=-0.37 -> Pg=35.0, Qg=9.63
% INFO    : Gen at bus 6349	: Vg=1.006 -> Vg=0.975
% INFO    : Gen at bus 6350	: Pg=1303.11, Qg=125.54 -> Pg=798.0, Qg=36.21
% INFO    : Gen at bus 6350	: Vg=1.027 -> Vg=0.975
% INFO    : Gen at bus 6351	: Pg=1303.11, Qg=156.58 -> Pg=798.0, Qg=36.21
% INFO    : Gen at bus 6351	: Vg=1.029 -> Vg=0.975
% INFO    : Gen at bus 6352	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 6353	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 6354	: Pg=377.88, Qg=57.71 -> Pg=273.76, Qg=84.835
% INFO    : Gen at bus 6354	: Vg=0.999 -> Vg=0.975
% INFO    : Gen at bus 6355	: Pg=23.42, Qg=-2.74 -> Pg=18.0, Qg=-1.11
% INFO    : Gen at bus 6355	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 6356	: Pg=23.42, Qg=-2.74 -> Pg=18.0, Qg=-1.11
% INFO    : Gen at bus 6356	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 6357	: Pg=938.84, Qg=211.25 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 6357	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6358	: Pg=931.31, Qg=215.24 -> Pg=607.0, Qg=190.895
% INFO    : Gen at bus 6358	: Vg=1.017 -> Vg=0.975
% INFO    : Gen at bus 6359	: Pg=939.32, Qg=204.86 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 6359	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 6360	: Pg=938.84, Qg=186.8 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 6360	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 6361	: Pg=942.28, Qg=197.62 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 6361	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 6362	: Pg=841.7, Qg=200.19 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 6362	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6363	: Vg=0.985 -> Vg=0.975
% INFO    : Gen at bus 6364	: Pg=428.76, Qg=30.9 -> Pg=336.8, Qg=72.235
% INFO    : Gen at bus 6364	: Vg=1.001 -> Vg=0.975
% INFO    : Gen at bus 6365	: Pg=248.21, Qg=14.51 -> Pg=195.0, Qg=33.755
% INFO    : Gen at bus 6365	: Vg=0.999 -> Vg=0.975
% INFO    : Gen at bus 6366	: Vg=0.993 -> Vg=0.975
% INFO    : Gen at bus 6367	: Vg=0.985 -> Vg=0.975
% INFO    : Gen at bus 6369	: Pg=31.93, Qg=-11.19 -> Pg=28.5, Qg=10.68
% INFO    : Gen at bus 6369	: Vg=0.967 -> Vg=0.975
% INFO    : Gen at bus 6370	: Pg=30.99, Qg=-11.33 -> Pg=28.5, Qg=10.61
% INFO    : Gen at bus 6370	: Vg=0.966 -> Vg=0.975
% INFO    : Gen at bus 6371	: Pg=10.04, Qg=8.02 -> Pg=8.0, Qg=6.455
% INFO    : Gen at bus 6371	: Vg=1.037 -> Vg=0.975
% INFO    : Gen at bus 6372	: Pg=10.04, Qg=8.02 -> Pg=15.5, Qg=5.97
% INFO    : Gen at bus 6372	: Vg=1.037 -> Vg=0.975
% INFO    : Gen at bus 6373	: Pg=8.23, Qg=-1.68 -> Pg=9.75, Qg=1.46
% INFO    : Gen at bus 6373	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6374	: Pg=7.3, Qg=-1.79 -> Pg=9.75, Qg=1.46
% INFO    : Gen at bus 6374	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 6375	: Vg=1.029 -> Vg=0.975
% INFO    : Gen at bus 6376	: Pg=27.59, Qg=7.07 -> Pg=17.5, Qg=0.04
% INFO    : Gen at bus 6376	: Vg=1.005 -> Vg=0.975
% INFO    : Gen at bus 6377	: Pg=26.58, Qg=6.87 -> Pg=17.5, Qg=-0.065
% INFO    : Gen at bus 6377	: Vg=1.005 -> Vg=0.975
% INFO    : Gen at bus 6378	: Pg=26.58, Qg=6.87 -> Pg=17.5, Qg=-0.15
% INFO    : Gen at bus 6378	: Vg=1.005 -> Vg=0.975
% INFO    : Gen at bus 6379	: Pg=27.59, Qg=7.07 -> Pg=17.5, Qg=0.04
% INFO    : Gen at bus 6379	: Vg=1.005 -> Vg=0.975
% INFO    : Gen at bus 6380	: Vg=0.97 -> Vg=0.975
% INFO    : Gen at bus 6381	: Pg=38.31, Qg=-4.1 -> Pg=23.5, Qg=2.32
% INFO    : Gen at bus 6381	: Vg=0.99 -> Vg=0.975
% INFO    : Gen at bus 6382	: Pg=37.35, Qg=-4.28 -> Pg=23.5, Qg=2.23
% INFO    : Gen at bus 6382	: Vg=0.99 -> Vg=0.975
% INFO    : Gen at bus 6383	: Pg=47.83, Qg=-10.0 -> Pg=36.5, Qg=10.17
% INFO    : Gen at bus 6383	: Vg=0.977 -> Vg=0.975
% INFO    : Gen at bus 6384	: Pg=54.91, Qg=-7.09 -> Pg=34.5, Qg=13.355
% INFO    : Gen at bus 6384	: Vg=0.973 -> Vg=0.975
% INFO    : Gen at bus 6385	: Pg=54.9, Qg=-8.36 -> Pg=38.0, Qg=11.28
% INFO    : Gen at bus 6385	: Vg=0.979 -> Vg=0.975
% INFO    : Gen at bus 6386	: Pg=50.86, Qg=-9.6 -> Pg=38.75, Qg=10.505
% INFO    : Gen at bus 6386	: Vg=0.977 -> Vg=0.975
% INFO    : Gen at bus 6387	: Pg=19.42, Qg=5.36 -> Pg=15.5, Qg=2.14
% INFO    : Gen at bus 6387	: Vg=1.006 -> Vg=0.975
% INFO    : Gen at bus 6388	: Pg=20.39, Qg=5.52 -> Pg=15.5, Qg=2.14
% INFO    : Gen at bus 6388	: Vg=1.006 -> Vg=0.975
% INFO    : Gen at bus 6389	: Pg=19.42, Qg=5.36 -> Pg=15.5, Qg=2.14
% INFO    : Gen at bus 6389	: Vg=1.006 -> Vg=0.975
% INFO    : Gen at bus 6390	: Pg=32.28, Qg=10.55 -> Pg=25.0, Qg=8.08
% INFO    : Gen at bus 6390	: Vg=0.979 -> Vg=0.975
% INFO    : Gen at bus 6391	: Pg=20.56, Qg=1.21 -> Pg=18.5, Qg=3.79
% INFO    : Gen at bus 6391	: Vg=1.017 -> Vg=0.975
% INFO    : Gen at bus 6392	: Pg=19.59, Qg=1.04 -> Pg=18.5, Qg=3.79
% INFO    : Gen at bus 6392	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 6393	: Pg=20.56, Qg=1.21 -> Pg=18.5, Qg=3.79
% INFO    : Gen at bus 6393	: Vg=1.017 -> Vg=0.975
% INFO    : Gen at bus 6394	: Pg=20.56, Qg=1.21 -> Pg=18.5, Qg=3.79
% INFO    : Gen at bus 6394	: Vg=1.017 -> Vg=0.975
% INFO    : Gen at bus 6395	: Pg=212.81, Qg=23.04 -> Pg=193.5, Qg=68.455
% INFO    : Gen at bus 6395	: Vg=1.002 -> Vg=0.975
% INFO    : Gen at bus 6396	: Pg=225.82, Qg=27.68 -> Pg=193.5, Qg=68.455
% INFO    : Gen at bus 6396	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 6397	: Pg=0.93, Qg=0.69 -> Pg=9.5, Qg=1.75
% INFO    : Gen at bus 6397	: Vg=0.958 -> Vg=0.975
% INFO    : Gen at bus 6398	: Pg=1.77, Qg=0.75 -> Pg=9.5, Qg=1.75
% INFO    : Gen at bus 6398	: Vg=0.958 -> Vg=0.975
% INFO    : Gen at bus 6399	: Pg=86.14, Qg=-9.26 -> Pg=61.0, Qg=7.36
% INFO    : Gen at bus 6399	: Vg=0.984 -> Vg=0.975
% INFO    : Gen at bus 6400	: Pg=371.87, Qg=-16.98 -> Pg=310.9, Qg=26.99
% INFO    : Gen at bus 6400	: Vg=0.996 -> Vg=0.975
% INFO    : Gen at bus 6401	: Pg=25.11, Qg=27.9 -> Pg=26.0, Qg=10.215
% INFO    : Gen at bus 6401	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6402	: Pg=25.11, Qg=27.9 -> Pg=26.0, Qg=10.215
% INFO    : Gen at bus 6402	: Vg=1.072 -> Vg=0.975
% INFO    : Gen at bus 6403	: Vg=0.978 -> Vg=0.975
% INFO    : Gen at bus 6404	: Vg=0.978 -> Vg=0.975
% INFO    : Gen at bus 6405	: Pg=160.71, Qg=12.41 -> Pg=4.5, Qg=69.52
% INFO    : Gen at bus 6405	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 6406	: Pg=167.73, Qg=13.92 -> Pg=4.5, Qg=69.84
% INFO    : Gen at bus 6406	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 6407	: Pg=164.71, Qg=12.95 -> Pg=4.5, Qg=69.84
% INFO    : Gen at bus 6407	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 6408	: Pg=167.72, Qg=13.59 -> Pg=4.5, Qg=69.935
% INFO    : Gen at bus 6408	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 6409	: Pg=35.74, Qg=-6.82 -> Pg=32.5, Qg=12.59
% INFO    : Gen at bus 6409	: Vg=0.985 -> Vg=0.975
% INFO    : Gen at bus 6410	: Pg=34.68, Qg=-6.95 -> Pg=32.5, Qg=12.59
% INFO    : Gen at bus 6410	: Vg=0.985 -> Vg=0.975
% INFO    : Gen at bus 6411	: Pg=874.93, Qg=303.83 -> Pg=593.5, Qg=182.745
% INFO    : Gen at bus 6411	: Vg=1.042 -> Vg=0.975
% INFO    : Gen at bus 6412	: Pg=893.93, Qg=208.07 -> Pg=593.5, Qg=193.685
% INFO    : Gen at bus 6412	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6413	: Pg=235.7, Qg=58.27 -> Pg=242.0, Qg=22.125
% INFO    : Gen at bus 6413	: Vg=1.025 -> Vg=0.975
% INFO    : Gen at bus 6414	: Pg=186.07, Qg=55.04 -> Pg=149.0, Qg=42.4
% INFO    : Gen at bus 6414	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6415	: Vg=0.947 -> Vg=0.975
% INFO    : Gen at bus 6416	: Pg=1301.64, Qg=106.2 -> Pg=824.5, Qg=229.315
% INFO    : Gen at bus 6416	: Vg=0.981 -> Vg=0.975
% INFO    : Gen at bus 6417	: Pg=51.36, Qg=7.83 -> Pg=30.5, Qg=2.34
% INFO    : Gen at bus 6417	: Vg=0.991 -> Vg=0.975
% INFO    : Gen at bus 6418	: Pg=51.36, Qg=7.83 -> Pg=30.5, Qg=2.34
% INFO    : Gen at bus 6418	: Vg=0.991 -> Vg=0.975
% INFO    : Gen at bus 6419	: Pg=27.76, Qg=8.54 -> Pg=17.5, Qg=6.57
% INFO    : Gen at bus 6419	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 6420	: Pg=1290.64, Qg=289.31 -> Pg=865.0, Qg=235.84
% INFO    : Gen at bus 6420	: Vg=1.034 -> Vg=0.975
% INFO    : Gen at bus 6421	: Pg=1300.61, Qg=396.49 -> Pg=865.0, Qg=235.84
% INFO    : Gen at bus 6421	: Vg=1.047 -> Vg=0.975
% INFO    : Gen at bus 6422	: Pg=1305.61, Qg=377.44 -> Pg=865.0, Qg=230.335
% INFO    : Gen at bus 6422	: Vg=1.043 -> Vg=0.975
% INFO    : Gen at bus 6423	: Pg=1285.15, Qg=419.87 -> Pg=820.0, Qg=210.31
% INFO    : Gen at bus 6423	: Vg=1.047 -> Vg=0.975
% INFO    : Gen at bus 6424	: Pg=9.83, Qg=7.66 -> Pg=25.9, Qg=13.51
% INFO    : Gen at bus 6424	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 6425	: Pg=1318.09, Qg=341.96 -> Pg=860.0, Qg=234.135
% INFO    : Gen at bus 6425	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 6426	: Pg=1270.62, Qg=359.27 -> Pg=860.0, Qg=234.135
% INFO    : Gen at bus 6426	: Vg=1.037 -> Vg=0.975
% INFO    : Gen at bus 6427	: Vg=0.976 -> Vg=0.975
% INFO    : Gen at bus 6428	: Vg=0.976 -> Vg=0.975
% INFO    : Gen at bus 6429	: Pg=515.54, Qg=331.77 -> Pg=393.0, Qg=119.845
% INFO    : Gen at bus 6429	: Vg=1.039 -> Vg=0.975
% INFO    : Gen at bus 6430	: Vg=0.985 -> Vg=0.975
% INFO    : Gen at bus 6431	: Pg=17.65, Qg=15.84 -> Pg=21.5, Qg=6.31
% INFO    : Gen at bus 6431	: Vg=1.075 -> Vg=0.975
% INFO    : Gen at bus 6432	: Pg=16.71, Qg=15.71 -> Pg=21.5, Qg=6.31
% INFO    : Gen at bus 6432	: Vg=1.075 -> Vg=0.975
% INFO    : Gen at bus 6433	: Pg=16.71, Qg=15.71 -> Pg=21.5, Qg=6.31
% INFO    : Gen at bus 6433	: Vg=1.075 -> Vg=0.975
% INFO    : Gen at bus 6434	: Pg=40.81, Qg=-31.8 -> Pg=40.0, Qg=4.5
% INFO    : Gen at bus 6434	: Vg=0.94 -> Vg=0.975
% INFO    : Gen at bus 6435	: Pg=232.28, Qg=10.62 -> Pg=165.0, Qg=16.655
% INFO    : Gen at bus 6435	: Vg=0.967 -> Vg=0.975
% INFO    : Gen at bus 6436	: Pg=598.4, Qg=86.57 -> Pg=450.0, Qg=57.26
% INFO    : Gen at bus 6436	: Vg=0.971 -> Vg=0.975
% INFO    : Gen at bus 6437	: Pg=37.03, Qg=-0.26 -> Pg=28.0, Qg=4.12
% INFO    : Gen at bus 6437	: Vg=1.033 -> Vg=0.975
% INFO    : Gen at bus 6438	: Pg=34.99, Qg=-0.59 -> Pg=28.0, Qg=4.12
% INFO    : Gen at bus 6438	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 6439	: Pg=1.18, Qg=-0.66 -> Pg=29.0, Qg=29.66
% INFO    : Gen at bus 6439	: Vg=1.007 -> Vg=0.975
% INFO    : Gen at bus 6440	: Pg=17.63, Qg=3.35 -> Pg=11.55, Qg=3.15
% INFO    : Gen at bus 6440	: Vg=1.041 -> Vg=0.975
% INFO    : Gen at bus 6441	: Pg=17.63, Qg=3.34 -> Pg=11.55, Qg=3.14
% INFO    : Gen at bus 6441	: Vg=1.041 -> Vg=0.975
% INFO    : Gen at bus 6442	: Pg=408.34, Qg=130.52 -> Pg=335.3, Qg=81.55
% INFO    : Gen at bus 6442	: Vg=1.041 -> Vg=0.975
% INFO    : Gen at bus 6443	: Pg=36.05, Qg=7.48 -> Pg=20.5, Qg=2.215
% INFO    : Gen at bus 6443	: Vg=1.039 -> Vg=0.975
% INFO    : Gen at bus 6444	: Vg=1.087 -> Vg=0.975
% INFO    : Gen at bus 6445	: Vg=1.094 -> Vg=0.975
% INFO    : Gen at bus 6446	: Vg=1.094 -> Vg=0.975
% INFO    : Gen at bus 6447	: Pg=25.65, Qg=-0.84 -> Pg=16.0, Qg=4.57
% INFO    : Gen at bus 6447	: Vg=0.984 -> Vg=0.975
% INFO    : Gen at bus 6448	: Vg=0.977 -> Vg=0.975
% INFO    : Gen at bus 6449	: Pg=27.26, Qg=-0.5 -> Pg=16.0, Qg=4.57
% INFO    : Gen at bus 6449	: Vg=0.984 -> Vg=0.975
% INFO    : Gen at bus 6450	: Vg=0.977 -> Vg=0.975
% INFO    : Gen at bus 6451	: Pg=109.38, Qg=88.32 -> Pg=0.0, Qg=13.035
% INFO    : Gen at bus 6451	: Vg=1.096 -> Vg=0.975
% INFO    : Gen at bus 6452	: Pg=23.59, Qg=1.01 -> Pg=22.0, Qg=4.315
% INFO    : Gen at bus 6452	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 6453	: Pg=26.11, Qg=4.03 -> Pg=15.5, Qg=2.94
% INFO    : Gen at bus 6453	: Vg=1.007 -> Vg=0.975
% INFO    : Gen at bus 6454	: Pg=25.15, Qg=3.84 -> Pg=15.5, Qg=2.94
% INFO    : Gen at bus 6454	: Vg=1.006 -> Vg=0.975
% INFO    : Gen at bus 6455	: Pg=15.7, Qg=-9.54 -> Pg=19.0, Qg=4.36
% INFO    : Gen at bus 6455	: Vg=1.027 -> Vg=0.975
% INFO    : Gen at bus 6456	: Pg=15.7, Qg=-9.59 -> Pg=19.0, Qg=4.225
% INFO    : Gen at bus 6456	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 6457	: Pg=13.66, Qg=-9.81 -> Pg=19.0, Qg=4.225
% INFO    : Gen at bus 6457	: Vg=1.022 -> Vg=0.975
% INFO    : Gen at bus 6458	: Pg=35.16, Qg=-7.99 -> Pg=33.0, Qg=7.725
% INFO    : Gen at bus 6458	: Vg=0.974 -> Vg=0.975
% INFO    : Gen at bus 6459	: Pg=40.32, Qg=-2.33 -> Pg=42.0, Qg=15.305
% INFO    : Gen at bus 6459	: Vg=0.99 -> Vg=0.975
% INFO    : Gen at bus 6460	: Pg=40.32, Qg=-2.33 -> Pg=42.0, Qg=15.305
% INFO    : Gen at bus 6460	: Vg=0.99 -> Vg=0.975
% INFO    : Gen at bus 6461	: Pg=28.28, Qg=3.06 -> Pg=16.5, Qg=11.24
% INFO    : Gen at bus 6461	: Vg=0.978 -> Vg=0.975
% INFO    : Gen at bus 6462	: Pg=3.3, Qg=-4.63 -> Pg=16.5, Qg=10.805
% INFO    : Gen at bus 6462	: Vg=0.942 -> Vg=0.975
% INFO    : Gen at bus 6463	: Pg=113.75, Qg=13.69 -> Pg=65.0, Qg=6.33
% INFO    : Gen at bus 6463	: Vg=1.038 -> Vg=0.975
% INFO    : Gen at bus 6464	: Pg=1307.72, Qg=197.86 -> Pg=807.0, Qg=215.91
% INFO    : Gen at bus 6464	: Vg=0.998 -> Vg=0.975
% INFO    : Gen at bus 6465	: Pg=1281.72, Qg=202.19 -> Pg=807.0, Qg=215.91
% INFO    : Gen at bus 6465	: Vg=0.999 -> Vg=0.975
% INFO    : Gen at bus 6466	: Pg=277.41, Qg=42.32 -> Pg=217.5, Qg=91.59
% INFO    : Gen at bus 6466	: Vg=1.013 -> Vg=0.975
% INFO    : Gen at bus 6467	: Pg=553.6, Qg=89.03 -> Pg=410.0, Qg=53.715
% INFO    : Gen at bus 6467	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 6468	: Pg=362.9, Qg=114.04 -> Pg=285.0, Qg=47.37
% INFO    : Gen at bus 6468	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 6469	: Pg=411.91, Qg=120.82 -> Pg=285.0, Qg=50.72
% INFO    : Gen at bus 6469	: Vg=1.016 -> Vg=0.975
% INFO    : Gen at bus 6470	: Pg=45.07, Qg=11.22 -> Pg=25.0, Qg=1.74
% INFO    : Gen at bus 6470	: Vg=1.022 -> Vg=0.975
% INFO    : Gen at bus 6471	: Pg=45.07, Qg=11.22 -> Pg=25.0, Qg=1.74
% INFO    : Gen at bus 6471	: Vg=1.022 -> Vg=0.975
% INFO    : Gen at bus 6472	: Pg=35.59, Qg=-8.15 -> Pg=24.5, Qg=5.365
% INFO    : Gen at bus 6472	: Vg=0.985 -> Vg=0.975
% INFO    : Gen at bus 6473	: Pg=34.61, Qg=-8.32 -> Pg=24.5, Qg=5.365
% INFO    : Gen at bus 6473	: Vg=0.985 -> Vg=0.975
% INFO    : Gen at bus 6474	: Pg=20.41, Qg=5.3 -> Pg=15.0, Qg=4.19
% INFO    : Gen at bus 6474	: Vg=0.981 -> Vg=0.975
% INFO    : Gen at bus 6475	: Pg=21.42, Qg=-4.56 -> Pg=15.0, Qg=4.19
% INFO    : Gen at bus 6475	: Vg=0.94 -> Vg=0.975
% INFO    : Gen at bus 6476	: Pg=52.24, Qg=16.59 -> Pg=42.5, Qg=19.785
% INFO    : Gen at bus 6476	: Vg=0.996 -> Vg=0.975
% INFO    : Gen at bus 6477	: Pg=921.82, Qg=129.12 -> Pg=589.43, Qg=195.9
% INFO    : Gen at bus 6477	: Vg=1.001 -> Vg=0.975
% INFO    : Gen at bus 6478	: Pg=914.83, Qg=127.68 -> Pg=592.43, Qg=196.445
% INFO    : Gen at bus 6478	: Vg=1.001 -> Vg=0.975
% INFO    : Gen at bus 6479	: Pg=32.12, Qg=10.97 -> Pg=24.5, Qg=0.785
% INFO    : Gen at bus 6479	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6480	: Pg=32.12, Qg=10.97 -> Pg=24.5, Qg=0.785
% INFO    : Gen at bus 6480	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6481	: Pg=32.12, Qg=10.97 -> Pg=24.5, Qg=0.785
% INFO    : Gen at bus 6481	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 6482	: Pg=51.63, Qg=-60.2 -> Pg=78.0, Qg=26.095
% INFO    : Gen at bus 6482	: Vg=0.937 -> Vg=0.975
% INFO    : Gen at bus 6483	: Pg=62.9, Qg=2.01 -> Pg=49.5, Qg=-5.525
% INFO    : Gen at bus 6483	: Vg=1.01 -> Vg=0.975
% INFO    : Gen at bus 6484	: Pg=63.9, Qg=2.16 -> Pg=49.5, Qg=-5.525
% INFO    : Gen at bus 6484	: Vg=1.01 -> Vg=0.975
% INFO    : Gen at bus 6485	: Pg=931.06, Qg=240.74 -> Pg=630.0, Qg=121.775
% INFO    : Gen at bus 6485	: Vg=0.996 -> Vg=0.975
% INFO    : Gen at bus 6486	: Pg=901.89, Qg=223.06 -> Pg=630.0, Qg=116.775
% INFO    : Gen at bus 6486	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 6487	: Pg=959.93, Qg=231.78 -> Pg=630.0, Qg=116.775
% INFO    : Gen at bus 6487	: Vg=0.994 -> Vg=0.975
% INFO    : Gen at bus 6488	: Pg=970.27, Qg=207.91 -> Pg=630.0, Qg=116.775
% INFO    : Gen at bus 6488	: Vg=0.989 -> Vg=0.975
% INFO    : Gen at bus 6489	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 6490	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 6491	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 6492	: Pg=59.29, Qg=1.57 -> Pg=0.0, Qg=19.4
% INFO    : Gen at bus 6492	: Vg=0.928 -> Vg=0.975
% INFO    : Gen at bus 6493	: Pg=59.29, Qg=1.57 -> Pg=0.0, Qg=19.4
% INFO    : Gen at bus 6493	: Vg=0.928 -> Vg=0.975
% INFO    : Gen at bus 6494	: Pg=59.29, Qg=1.57 -> Pg=0.0, Qg=19.4
% INFO    : Gen at bus 6494	: Vg=0.928 -> Vg=0.975
% INFO    : Gen at bus 6495	: Pg=198.61, Qg=108.3 -> Pg=203.0, Qg=30.365
% INFO    : Gen at bus 6495	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 6496	: Pg=174.61, Qg=109.36 -> Pg=203.0, Qg=30.365
% INFO    : Gen at bus 6496	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 6497	: Pg=149.8, Qg=29.05 -> Pg=90.0, Qg=27.8
% INFO    : Gen at bus 6497	: Vg=1.055 -> Vg=0.975
% INFO    : Gen at bus 6498	: Pg=46.06, Qg=17.79 -> Pg=68.0, Qg=43.88
% INFO    : Gen at bus 6498	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 6499	: Pg=46.05, Qg=17.78 -> Pg=64.0, Qg=38.95
% INFO    : Gen at bus 6499	: Vg=1.032 -> Vg=0.975
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
